*  **********************************************
*  *             TSMC SPICE MODEL               *
*  **********************************************
*  
*    PROCESS :  65nm Mixed Signal RF SALICIDE Low-K IMD (1.2/2.5/over-drive 3.3V) (CRN65LP) 
*    MODEL   :  BSIM4 ( V4.5 )
*    DOC. NO.:  T-N65-CM-SP-007   
*    VERSION :  V1.5
*    DATE    :  Aug. 06, 2009
*    HSPICE VERSION : A-2008.03
*
************************************************************************************
*     Updated history:	
*
*  1. crn65lp_v1d0p1  :  new created
*      a. RF MOS model
*         1. svt & hvt (Si validated)
*         2. lvt , 2.5V I/O (guess model)
*         3. statistical & mismatch model (Si validated)
*      b. RF MOSVAR model 
*         1. svt (Si validated)
*         2. mismatch model (guess model)
*      c. RF resistor model 
*         1. P-type POLY (Si validated)
*         2. mismatch model (Si validated)
*      d. MOSCAP mismatch model
*         1. mismatch model (guess model)
*
*  2. crn65lp_v1d0p2 :
*      a. RF MOS model 
*         1. Corrected typo in SLeff & SReff calculation
*            (svt, hvt, lvt, I/O 2.5V, I/O 3.3V)
*          OLD
*          *.param Ledgeeff=0.45u (for core)
*          *.param Ledgeeff=0.73u (for I/O)
*          *.param dummyflag=0
*          *.param SLeff='Lspace+dummyflag*(Ledgeeff-Lspace)'
*          *.param SReff='Lspace+dummyflag*(Ledgeeff-Lspace)'
*          NEW
*          .param Ledgeeff=0.24u (for core)
*          .param Ledgeeff=0.31u (for I/O)
*          .param dummyflag=1
*          .param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
*          .param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
*         2. Add 3.3V I/O model
*      b. MOS model
*         1. Corrected MOS parameters (mos_mlvt)
*         OLD                        NEW
*         nch_mlvt                 
*         +noia=2.50E+42             +noia=noian_mlvt	  
*         +noib=1.00E+23             +noib=noibn_mlvt 
*         +noic=1.00E+07             +noic=noicn_mlvt 
*         +rgatemod=0                +rgatemod=1*rgflag_mlvt
*         +xgl=-3e-09+dxln_mlvt      +xgl=-1.85e-08
*         +rshg=1                    +rshg=15.06
*         pch_mlvt
*         +noia=5.00E+42             +noia=noiap_mlvt	  
*         +noib=1.55E+24             +noib=noibp_mlvt 
*         +noic=1.00E+10             +noic=noicp_mlvt 
*         +rgatemod=0                +rgatemod=1*rgflag_mlvt
*         +xgl=-(0+dxlp_mlvt)        +xgl=-6.3e-09
*         +rshg=1                    +rshg=14.93
*      c. Updated BB and Added RF RTMOM Model (guess model)  
*
*  3. crn65lp_v1d0p3 :
*      a. Updated BB RTMOM Model based on Silicon data
*      b. Updated RF RTMOM Model consistent with BB RTMOM model
*
*  4. crn65lp_v1d0p4 :
*      a. Updated RF MOS Binning Boundaries
*      b. Add 1.2V mLow-Vt RF CMOS devices
*
*  5. crn65lp_v1d0p5 :
*      a. Updated RF Junction Varactor Model based on Silicon data
*         Added RF Junction Varactor on Newll Model based on Silicon data
*      b. Updated core/IO MOS varactor mismatch model
*         Added core/IO MOS varactor statistical model        
*         Updated IO MOS varactor model           
*      c. Updated RF & BB MIMCAP model based on Silicon data
*      d  Added RF & BB RTMOM mismatch and statistical model        
*      e  Added RF & BB Resistor statistical model ,1/f flicker corner model and updated Rsub equation
*      f. Updated RF inductor model and with statistical model           
*
*  6.crn65lp_v1d0p6: (11-30-06)	
*      a. Updated standard/high/inter-median/low vt and native core devices to reflect silicon change                                                       *
*      b. Updated 1.8V/2.5V/3.3V IO devices to reflect silicon change				
*      c. Updated diodes to reflect silicon change                                                              
*      d. Updated BJT Model to match the newly collected silicon data (with
*         RPO layer)							
*      e. Updated all resistor models except Metal 1~z			
*      f. Remove all statistical model
*      g. Updated UTM inductor model
*      h. Add RDL inductor model
*      i. Add resistor model, rmt for UTM metal.
*
*  7.crn65lp_v1d0:  (1-31-07)
*      a. Updated flicker noise and flicker noise corner model based on LO_V1.2 Si.
*      b. Updated RF-CMOS parasitic resistance equations (RD, RS & RG )based on LO_V1.2 Si.
*      c. Updated T-noise model for RF-CMOS (svt, hvt, lvt, ilvt, io18, io25, io33).
*      d. Updated T-noise model for LO-CMOS (mac, hvt_mac, lvt_mac, mlvt_mac, 18_mac, 25_mac, 33_mac). 
*      e. Add Guard-ring model function and update both of UTM (Mu+Mz) inductor model and RDL(Mz+ALRDL) inductor model.
*      f. Add 5T-RTMOM model and multi-x-couple mismactch model for milti-x-couple mismatch application.
*      g. Add HVT and Mismatch RFMOSVAR model.
*      h. Modify rppolywo SS & FF corner range from 20% to wide-width 13% and narrow-width 15%.
*      i. Modify RSH/RSHG/XGL value in MOS models.
*      j. Modify 1.2V Native-Vt NMOS.
*      k. Modify cjswn and cjswp values in 1.2V SVT CMOS model.
*
*  8.crn65lp_v1d1:  (4-20-07)
*      a. Add statistical models.
*      b. LO models and SVT/HVT/mLVT/LVT/native/IO/bipolar/diode/resistor/varactor statistical models are based on Mixed 
*         signal models CMN65LP_2d5_lk_v1d1(T-N65-CM-SP-002 v1.1).
*
*  9.crn65lp_v1d2p1:(5-9-07)
*      a. Update rppolywo and rppolywo_rf VCR coefficient
*      b. Recover the "m=multi" in eldo model.
*
*  10.crn65lp_v1d2p2:(6-7-07)
*      a. Delete the useless sections in spectre model card, stat_mis_rfjvar, stat_mis_rfind, stat_mis_mos_cap, 
*         and random variables in stat_mis_na
*
*  11.crn65lp_v1d2p3:(08-10-07)
*      a. revised Tnoise typo in nmos_rf_18, nmos_rf_25 and nmos_rf_33 in spectre model card.
*
*  12.crn65lp_v1d2:(08-31-07)
*      a. revised T-noise typo in nch_18.5 of nch_18_mac
*      b. updated CJ=0 & CJSW=0 of unused intrinsic RF-CMOS to avoid simulator version dependency    
*      c. add BB & RF UTM direct contact MIMCAP.
*      d. updated BB & RF RTMOM corner from +/-20% to +/-15%.  
*      e. Typo for rend0/(w-dw) and correct to rend0/w for subckt rppolywo_rf 
*      f. Update spiral inductor model with new subckt and fitting method.
*
*  13.crn65lp_v1d3:(1-23-08)
*      a. Fixed the typo of Rc for Rend in RF RPO resistor model
*      b. add PMOS varactor model 
*      c. add the area dependent flicker noise corner model for MOS
*         SVT, HVT, MLVT, LVT, 18(25ud18), 25IO, 33(25od33)
*      d. Added RF IO pad (from 1p6m to 1p9m for MuMz scheme)
*      e. Removed BB_LINCAP of eldo model card
*
*  14.crn65lp_v1d4:(10-31-08)
*       a. Added RF ESD Diode Model
*       b. Added 5T/6T RF MOS Model
*       c. 1/f noise corner MC model of mos 
*       d. Add dw into Rend of BB rnodwo, rpodwo, rnpolywo, rppolywo, rnodwo_m, rpodwo_m,
 rnpolywo_m, and rppolywo_m model and RF rppolywo_rf model "
*       e. Revise the mismatch parameters for all devices to improve the Id mismatch fitting in sub-vt region 
*       f. Modified HVT NMOS flicker noise model from new data
*       g. WPE effect on the rf mos model
*       h. Modified the PMOSVAR equation for gate leakage
*       i. Update 2T resistor Monte-Carlo model based on CMN65LP_2d5_lk_v1d2
*       j. Modified the RPO_Resistor VCR and TCR model equations. (based on CMN65LP_2d5_lk_v1d2)
*          1.new VCR and TCR equations to re-fit the RPO resistor with single effective Rend as one   
*          2.RF resistors align BB new model TCR & VCR equations and format. change as par_rfres_rpo=AGAUSS(0,1,1) 
*            and par_rfres_sa=AGAUSS(0,1,1) rsh='rppolylrf*(1+factmis)'&'rsh='rppolysrf*(1+factmis)' 
*            from rsh='rppolylrf*(1+factmis*2)&'rsh='rppolysrf*(1+factmis*2)' 
*       k. MC model of 3-T resistance  (based on CMN65LP_2d5_lk_v1d2)
*       l. Updated multi-finger mismatch macro model equation  (based on CMN65LP_2d5_lk_v1d2)
*       m. Add inter metal resistor My in resistor model  (based on CMN65LP_2d5_lk_v1d2)
*       n. Correct Dwend in Rend equation of RPO-resistor models  (based on CMN65LP_2d5_lk_v1d2)
*       o. scale1 instead of scale in the resistor eldo model card  (based on CMN65LP_2d5_lk_v1d2)
*       p. Added native IO 2.5V over-drive 3.3V NMOS device model  (based on CMN65LP_2d5_lk_v1d2)
*       q. Added NDIO_na25od33 model copied from NDIO_na25  (based on CMN65LP_2d5_lk_v1d2)
*       r. Added metal resistor Rmap, Rmr, and Rmap_ut in resistor model. (based on CMN65LP_2d5_lk_v1d2)  
*       s. Added 'mf' into metal resistor model. (based on CMN65LP_2d5_lk_v1d2)                                
*
*  15.crn65lp_v1d5:(08-06-09)
* 	a. replace rdbx as new equation to fit testkey so that get correct rbx 
*       b. Added schottky barrier diode model
*       c. Added scale function into RF devices.
*       e. Added scale function into BB RTMOM and BB MIM model.
*       f. Add parameter "sigma_factor_flicker" to adjust the flicker noise corner spread.
*       g. Flicker noise monte-carlo model format update, and add parameter "noiseflag_mc_mis".
*          Only one type of flicker noise monte-carlo model is allowed.
*          1. "noiseflag_mc=1" when using the same dice, and "noiseflag_mc=0" when turn off
*          2. "noiseflag_mc_mis=1" when using different dices, and "noiseflag_mc_mis=0" when turn off
*       h. Revised the Cox equation in BB 3T MIM model based on the last interconnect model. 
*       i. updated BB&RF RTMOM model based on new test-key and silicon data.
*          
*
******************************************************************************
*                                                                            *
*       THIS MODEL LIB CONTAINS :                                            *
*                                                                            *
*   A RF models                                                              *
*                                                                            *
*       1.LIB TT_RFMOS                                                       *
*             SS_RFMOS                                                       *
*             FF_RFMOS                                                       *
*             SF_RFMOS                                                       *
*             FS_RFMOS                                                       *
*             MC_RFMOS                                                       *
*   ( 1.2V Standard-Vt devices with different geometric and corner models)   *
*									     *
*       2.LIB TT_RFMOS_hvt                                                   *
*             SS_RFMOS_hvt                                                   *
*             FF_RFMOS_hvt                                                   *
*             SF_RFMOS_hvt                                                   *
*             FS_RFMOS_hvt                                                   *
*             MC_RFMOS_hvt                                                   *
*   ( 1.2V High-Vt devices with different geometric and corner models)       *
*									     *
*       3.LIB TT_RFMOS_mlvt                                                  *
*             SS_RFMOS_mlvt                                                  *
*             FF_RFMOS_mlvt                                                  *
*             SF_RFMOS_mlvt                                                  *
*             FS_RFMOS_mlvt                                                  *
*             MC_RFMOS_mlvt                                                  *
*   ( 1.2V mLow-Vt devices with different geometric and corner models)       *
*                                                                            *
*       4.LIB TT_RFMOS_lvt                                                   *
*             SS_RFMOS_lvt                                                   *
*             FF_RFMOS_lvt                                                   *
*             SF_RFMOS_lvt                                                   *
*             FS_RFMOS_lvt                                                   *
*             MC_RFMOS_lvt                                                   *
*   ( 1.2V Low-Vt devices with different geometric and corner models)       *
*                                                                            *
*       5.LIB TT_RFMOS_18                                                    *
*             SS_RFMOS_18                                                    *
*             FF_RFMOS_18                                                    *
*             SF_RFMOS_18                                                    *
*             FS_RFMOS_18                                                    *
*             MC_RFMOS_18                                                    *
*   ( 2.5V under-drive 1.8V devices with different geometric and corner models)  *
*									     *
*       6.LIB TT_RFMOS_25                                                    *
*             SS_RFMOS_25                                                    *
*             FF_RFMOS_25                                                    *
*             SF_RFMOS_25                                                    *
*             FS_RFMOS_25                                                    *
*             MC_RFMOS_25                                                    *
*   ( 2.5V devices with different geometric and corner models)               *
*									     *
*       7.LIB TT_RFMOS_33                                                    *
*             SS_RFMOS_33                                                    *
*             FF_RFMOS_33                                                    *
*             SF_RFMOS_33                                                    *
*             FS_RFMOS_33                                                    *
*             MC_RFMOS_33                                                    *
*   ( 2.5V over-drive 3.3V devices with different geometric and corner models) *
*                                                                            *
*       8. MIM capacitor corner model                                        *
*                                                                            *
*          a.LIB TT_RFMIM:Typical model                                      *
*          b.LIB FF_RFMIM:Fast corner model                                  *
*          c.LIB SS_RFMIM:Slow corner model                                  *
*          d.LIB MC_RFMIM:Statistical model                                  *
*                                                                            *
*       9. Inductor corner model                                             *
*                                                                            *
*          a.LIB TT_RFIND:Typical model                                      *
*          b.LIB FF_RFIND:Fast corner model                                  *
*          c.LIB SS_RFIND:Slow corner model                                  *
*          d.LIB MC_RFIND:Statistical model                                  *
*                                                                            *
*       10. 1.2V MOS varactor corner model                                   *
*                                                                            *
*          a.LIB TT_RFMVAR:Typical model                                     *
*          b.LIB FF_RFMVAR:Fast corner model                                 *
*          c.LIB SS_RFMVAR:Slow corner model                                 *
*          d.LIB MC_RFMVAR:Statistical model                                 *
*                                                                            *
*       11. 1.2V High-Vt MOS varactor corner model                           *
*                                                                            *
*          a.LIB TT_RFMVAR_hvt:Typical model                                 *
*          b.LIB FF_RFMVAR_hvt:Fast corner model                             *
*          c.LIB SS_RFMVAR_hvt:Slow corner model                             *
*          d.LIB MC_RFMVAR_hvt:Statistical model                             *
*                                                                            *
*       12. 2.5V MOS varactor corner model                                   *
*                                                                            *
*          a.LIB TT_RFMVAR_25:Typical model                                  *
*          b.LIB FF_RFMVAR_25:Fast corner model                              *
*          c.LIB SS_RFMVAR_25:Slow corner model                              *
*          d.LIB MC_RFMVAR_25:Statistical model                              *
*                                                                            *
*       13. P+/NW Junction varactor corner model                             *
*                                                                            *
*          a.LIB TT_RFJVAR:Typical model                                     *
*          b.LIB FF_RFJVAR:Fast corner model                                 *
*          c.LIB SS_RFJVAR:Slow corner model                                 *
*          d.LIB MC_RFJVAR:Statistical model                                 *
*                                                                            *
*       14. Resistor corner model                                            *
*                                                                            *
*          i). Salicided poly resistor                                       *
*                                                                            *
*             (a).LIB TT_RFRES_SA:Typical model                              *
*             (b).LIB FF_RFRES_SA:Fast corner model                          *
*             (c).LIB SS_RFRES_SA:Slow corner model                          *
*             (d).LIB MC_RFRES_SA:Statistical model                          *
*                                                                            *
*          ii). Non-salicided P+ poly resistor                               *
*                                                                            *
*             (a).LIB TT_RFRES_RPO:Typical model                             *
*             (b).LIB FF_RFRES_RPO:Fast corner model                         *
*             (c).LIB SS_RFRES_RPO:Slow corner model                         *
*             (d).LIB MC_RFRES_RPO:Statistical model                         *
*                                                                            *
*       15. RTMOM corner model                                               *
*                                                                            *
*          a.LIB TT_RFRTMOM:Typical model                                    *
*          b.LIB FF_RFRTMOM:Fast corner model                                *
*          c.LIB SS_RFRTMOM:Slow corner model                                *
*          d.LIB MC_RFRTMOM:Statistical model                                *
*                                                                            *
*       16. RFIO ESD Low-Capacitance Pad Model                               *
*                                                                            *
*          (a).lib tt_lowcpad:Typical model                                  *
*          (b).lib ff_lowcpad:Fast corner model                              *
*          (c).lib ss_lowcpad:Slow corner model                              *
*                                                                            *
*       17. RF High-Current Diode Model                                      *
*                                                                            *
*          (a).lib tt_dio_hia_rf:Typical model                               *
*          (b).lib ff_dio_hia_rf:Fast corner model                           *
*          (c).lib ss_dio_hia_rf:Slow corner model                           *
*          (d).lib mc_dio_hia_rf:Statistical model                           *
*                                                                            *
*       18. Schottky barrier diode Model                                     *
*                                                                            *
*          (a).lib tt_rfsbd:Typical model                                    *
*          (b).lib ff_rfsbd:Fast corner model                                *
*          (c).lib ss_rfsbd:Slow corner model                                *
*          (d).lib mc_rfsbd:Statistical model                                *
*                                                                            *
***************************************************************************************************
*	 a. Instance parameter for RF-MOS with substrate network
*           rbflag   (default=1): the switch to turn-on(=1) or turn-off(=0) substrate model
*                                 rbflag=0 is preferrable for digital circuit simulation 
*           x1 d g s b nmos_rf mismatchflag=1 rbflag=1
*
*	 b. Instance parameter for RF-MOS with layout-dependent effect (LOD & WPE) 
*          (LOD & WPE parameter values, please look up the CRN65LP_LOD_WPE_Table.txt)
*      
*    ex.    x1 d g s b nmos_rf mismatchflag=1 rbflag=1
*           + lr=0.06e-6 wr=1e-6 nr=4 sa=0.7675e-6 sca=1.3045 scb=1.328E-06 scc=1.523E-12
*
*    ex.    x1 d g s b nmos_rf_25 mismatchflag=1 rbflag=1
*           + lr=0.28e-6 wr=1e-6 nr=4 sa=1.341e-6 sca=0.9741 scb=3.618E-07 scc=1.808E-13
*                                                                            
***************************************************************************************************




.LIB stat_noise
.param par1fn_mc=random_fn random_fn=AGAUSS(0,1,3)
.ENDL stat_noise

.LIB noiseflagrf
.param scale_mos_rf=1
.param noiseflagnrf=0
.param noiseflagprf=0
.param noiseflagnrf_mc=0
.param noiseflagprf_mc=0
.param noiseflagnrf_mc_mis=0
.param noiseflagprf_mc_mis=0
.param sigma_factor_flicker_rf=1
.param par2fnrf_mc=AGAUSS(0,1,3)
.param par2fprf_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf

.LIB noiseflagrf_hvt
.param scale_mos_rf_hvt=1
.param noiseflagnrf_hvt=0
.param noiseflagprf_hvt=0
.param noiseflagnrf_hvt_mc=0
.param noiseflagprf_hvt_mc=0
.param noiseflagnrf_hvt_mc_mis=0
.param noiseflagprf_hvt_mc_mis=0
.param sigma_factor_flicker_rf_hvt=1
.param par2fnrf_hvt_mc=AGAUSS(0,1,3)
.param par2fprf_hvt_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_hvt

.LIB noiseflagrf_mlvt
.param scale_mos_rf_mlvt=1
.param noiseflagnrf_mlvt=0
.param noiseflagprf_mlvt=0
.param noiseflagnrf_mlvt_mc=0
.param noiseflagprf_mlvt_mc=0
.param noiseflagnrf_mlvt_mc_mis=0
.param noiseflagprf_mlvt_mc_mis=0
.param sigma_factor_flicker_rf_mlvt=1
.param par2fnrf_mlvt_mc=AGAUSS(0,1,3)
.param par2fprf_mlvt_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_mlvt

.LIB noiseflagrf_lvt
.param scale_mos_rf_lvt=1
.param noiseflagnrf_lvt=0
.param noiseflagprf_lvt=0
.param noiseflagnrf_lvt_mc=0
.param noiseflagprf_lvt_mc=0
.param noiseflagnrf_lvt_mc_mis=0
.param noiseflagprf_lvt_mc_mis=0
.param sigma_factor_flicker_rf_lvt=1
.param par2fnrf_lvt_mc=AGAUSS(0,1,3)
.param par2fprf_lvt_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_lvt

.LIB noiseflagrf_18
.param scale_mos_rf_18=1
.param noiseflagnrf_18=0
.param noiseflagprf_18=0
.param noiseflagnrf_18_mc=0
.param noiseflagprf_18_mc=0
.param noiseflagnrf_18_mc_mis=0
.param noiseflagprf_18_mc_mis=0
.param sigma_factor_flicker_rf_18=1
.param par2fnrf_18_mc=AGAUSS(0,1,3)
.param par2fprf_18_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_18

.LIB noiseflagrf_25
.param scale_mos_rf_25=1
.param noiseflagnrf_25=0
.param noiseflagprf_25=0
.param noiseflagnrf_25_mc=0
.param noiseflagprf_25_mc=0
.param noiseflagnrf_25_mc_mis=0
.param noiseflagprf_25_mc_mis=0
.param sigma_factor_flicker_rf_25=1
.param par2fnrf_25_mc=AGAUSS(0,1,3)
.param par2fprf_25_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_25

.LIB noiseflagrf_33
.param scale_mos_rf_33=1
.param noiseflagnrf_33=0
.param noiseflagprf_33=0
.param noiseflagnrf_33_mc=0
.param noiseflagprf_33_mc=0
.param noiseflagnrf_33_mc_mis=0
.param noiseflagprf_33_mc_mis=0
.param sigma_factor_flicker_rf_33=1
.param par2fnrf_33_mc=AGAUSS(0,1,3)
.param par2fprf_33_mc=AGAUSS(0,1,3)
.ENDL noiseflagrf_33


**************************************************************************************************
*
* 1.2V CORE SVT MOS MODEL
*
*
*
*              .lib RF_MOS
*
*              Model name       nr               lr (um)           wr (um)
*                            low   high        low     high     low    high
*            -----------------------------------------------------------------
*              nmos_rf        1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*              pmos_rf        1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*              pmos_rf_nw     1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*              nmos_rf_6t     1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*              pmos_rf_5t     1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*              pmos_rf_nw_5t  1     32         0.06    0.24     0.6    6.0
*            -----------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************

***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+A1rf='par1*5.7353*3/2.1'
+A2rf='par2*4.3947*3/2.1'
+A3rf='par3*3.8969*3/2.1'
+A4rf='par4*2.1385*3/2.1'
+A5rf='par5*1.017*3/2.1'
+toxnrf           ='2.6e-09+(4.0971e-012)*A1rf+(-3.6618e-012)*A2rf+(-1.1634e-011)*A3rf+(-5.2349e-012)*A4rf+(9.0461e-013)*A5rf'
+dxlnrf           ='0+(2.2463e-010)*A1rf+(-3.3035e-010)*A2rf+(-1.202e-009)*A3rf+(-5.4657e-010)*A4rf+(1.0098e-010)*A5rf'
+dxwnrf           ='0+(-2.1836e-010)*A1rf+(1.5263e-009)*A2rf+(1.6182e-009)*A3rf+(9.7014e-010)*A4rf+(-1.894e-010)*A5rf'
+dvthnrf          ='0+(0.0022015)*A1rf+(-0.0027641)*A2rf+(0.0013134)*A3rf+(0.00013438)*A4rf+(-8.7415e-005)*A5rf'
+dlvthnrf         ='0+(1.4358e-010)*A1rf+(-1.8027e-010)*A2rf+(8.5658e-011)*A3rf+(8.7637e-012)*A4rf+(-5.701e-012)*A5rf'
+dwvthnrf         ='0+(2.7348e-010)*A1rf+(-3.5411e-010)*A2rf+(1.8146e-010)*A3rf+(-1.3311e-011)*A4rf+(-1.1259e-011)*A5rf'
+dpvthnrf         ='0+(2.6778e-017)*A1rf+(-3.1326e-017)*A2rf+(2.0129e-017)*A3rf+(-7.9316e-018)*A4rf+(-1.3078e-018)*A5rf'
+cjnrf            ='0.001251+(8.3819e-006)*A1rf+(-1.0525e-005)*A2rf+(5.0002e-006)*A3rf+(5.1126e-007)*A4rf+(-3.3274e-007)*A5rf'
+cjswnrf          ='7.9e-11+(5.2652e-013)*A1rf+(-6.6363e-013)*A2rf+(3.17e-013)*A3rf+(3.2782e-014)*A4rf+(-2.1021e-014)*A5rf'
+cjswgnrf         ='2.04e-10+(1.3669e-012)*A1rf+(-1.7161e-012)*A2rf+(8.1547e-013)*A3rf+(8.343e-014)*A4rf+(-5.4274e-014)*A5rf'
+cgonrf           ='8.28670e-11+(-3.5472e-013)*A1rf+(3.1703e-013)*A2rf+(1.0072e-012)*A3rf+(4.5323e-013)*A4rf+(-7.8319e-014)*A5rf'
+cglnrf           ='9.96116e-12+(-4.266e-014)*A1rf+(3.812e-014)*A2rf+(1.2109e-013)*A3rf+(5.4425e-014)*A4rf+(-9.4143e-015)*A5rf'
+cfnrf            ='1.200000e-010+(-5.1367e-013)*A1rf+(4.5909e-013)*A2rf+(1.4586e-012)*A3rf+(6.5632e-013)*A4rf+(-1.1341e-013)*A5rf+5.4e-11'
+ntoxnrf          ='1+(-0.043827)*A1rf+(0.035889)*A2rf+(0.10819)*A3rf+(0.028624)*A4rf+(-0.0078852)*A5rf'
+du0nrf           ='0+(2.8716e-005)*A1rf+(-3.6053e-005)*A2rf+(1.7132e-005)*A3rf+(1.7527e-006)*A4rf+(-1.1402e-006)*A5rf'
+dlu0nrf          ='0+(2.2787e-012)*A1rf+(-1.0714e-012)*A2rf+(-1.6898e-012)*A3rf+(5.1397e-012)*A4rf+(-2.3755e-014)*A5rf'
+dwu0nrf          ='0+(7.2475e-012)*A1rf+(-1.0173e-011)*A2rf+(6.1534e-012)*A3rf+(-2.558e-012)*A4rf+(-3.2781e-013)*A5rf'
+dpu0nrf          ='0+(-9.5719e-019)*A1rf+(1.2018e-018)*A2rf+(-5.7106e-019)*A3rf+(-5.8424e-020)*A4rf+(3.8007e-020)*A5rf'
+dleta0nrf        ='0+(-3.7373e-011)*A1rf+(3.2607e-011)*A2rf+(2.0973e-012)*A3rf+(-4.2286e-011)*A4rf+(9.5018e-013)*A5rf'
+dweta0nrf        ='max(-10.0e-9,0+(-4.7409e-010)*A1rf+(8.9946e-010)*A2rf+(-8.0122e-010)*A3rf+(8.2116e-010)*A4rf+(3.0168e-011)*A5rf)'
+dpeta0nrf        ='0+(1.294e-017)*A1rf+(-3.8281e-017)*A2rf+(4.204e-017)*A3rf+(-5.4391e-017)*A4rf+(-1.2033e-018)*A5rf'
+dvsatnrf         ='max(-26000,0+(352.63)*A1rf+(2494.3)*A2rf+(-762.23)*A3rf+(239.08)*A4rf+(-69.558)*A5rf)'
+dlvsatnrf        ='0+(1.6967e-005)*A1rf+(-0.00018169)*A2rf+(6.5693e-005)*A3rf+(-1.5713e-005)*A4rf+(2.2596e-006)*A5rf'
+dpvsatnrf        ='0+(2.6099e-012)*A1rf+(-9.2175e-013)*A2rf+(2.8583e-013)*A3rf+(1.3074e-012)*A4rf+(-1.2806e-013)*A5rf'
+dk2nrf           ='0+(0.00042845)*A1rf+(-0.00050214)*A2rf+(0.00019463)*A3rf+(0.00012616)*A4rf+(-1.5678e-005)*A5rf'
+dlcitnrf         ='0+(-1.267e-012)*A1rf+(-3.5649e-013)*A2rf+(-2.9996e-012)*A3rf+(-2.5869e-012)*A4rf+(3.3949e-013)*A5rf'
+dwcitnrf         ='0+(-2.7345e-012)*A1rf+(1.2857e-012)*A2rf+(2.0278e-012)*A3rf+(-6.1676e-012)*A4rf+(2.8506e-014)*A5rf'
+dlvoffnrf        ='0+(-4.7859e-011)*A1rf+(6.0089e-011)*A2rf+(-2.8553e-011)*A3rf+(-2.9212e-012)*A4rf+(1.9003e-012)*A5rf'
+dpvoffnrf        ='0+(1.285e-018)*A1rf+(2.0405e-020)*A2rf+(1.2082e-018)*A3rf+(-1.7478e-018)*A4rf+(-1.2216e-019)*A5rf'
+dlnfactornrf     ='max(-6e-9,0+(-6.2903e-010)*A1rf+(8.9714e-010)*A2rf+(-5.5823e-010)*A3rf+(2.6164e-010)*A4rf+(2.898e-011)*A5rf)'
+dpnfactornrf     ='0+(7.0527e-017)*A1rf+(4.9885e-016)*A2rf+(-1.5245e-016)*A3rf+(4.7816e-017)*A4rf+(-1.3912e-017)*A5rf'
+dla0nrf          ='0+(9.5719e-009)*A1rf+(-1.2018e-008)*A2rf+(5.7106e-009)*A3rf+(5.8424e-010)*A4rf+(-3.8007e-010)*A5rf'
+ss_flagrf        ='max(-0.10,0+(0.045574)*A1rf+(-0.021428)*A2rf+(-0.033796)*A3rf+(0.10279)*A4rf+(-0.0004751)*A5rf)'
+ff_flagrf        ='0+(-0.048025)*A1rf+(0.010395)*A2rf+(0.0063398)*A3rf+(0.11857)*A4rf+(-0.00058697)*A5rf'
+sf_flagrf        ='0+(-0.0086543)*A1rf+(-0.060646)*A2rf+(0.023442)*A3rf+(-0.051073)*A4rf+(-0.21784)*A5rf'
+fs_flagrf        ='0+(0.0089773)*A1rf+(0.064067)*A2rf+(-0.014669)*A3rf+(-0.039119)*A4rf+(-0.22132)*A5rf'
+toxprf           ='2.8e-09+(4.0971e-012)*A1rf+(-3.6618e-012)*A2rf+(-1.1634e-011)*A3rf+(-5.2349e-012)*A4rf+(9.0461e-013)*A5rf'
+dxlprf           ='0+(2.2463e-010)*A1rf+(-3.3035e-010)*A2rf+(-1.202e-009)*A3rf+(-5.4657e-010)*A4rf+(1.0098e-010)*A5rf'
+dxwprf           ='0+(-5.0047e-010)*A1rf+(-4.6914e-010)*A2rf+(2.228e-009)*A3rf+(7.7887e-010)*A4rf+(-1.3375e-010)*A5rf'
+dvthprf          ='0+(-0.0029743)*A1rf+(-0.0019047)*A2rf+(9.2954e-005)*A3rf+(-0.00059925)*A4rf+(0.00022477)*A5rf'
+dlvthprf         ='0+(-4.3016e-011)*A1rf+(-7.3011e-012)*A2rf+(1.4293e-011)*A3rf+(-4.6111e-011)*A4rf+(2.0631e-012)*A5rf'
+dwvthprf         ='0+(-4.5014e-010)*A1rf+(-3.3888e-010)*A2rf+(-1.8304e-011)*A3rf+(2.9186e-012)*A4rf+(3.6986e-011)*A5rf'
+dpvthprf         ='0+(-2.3675e-017)*A1rf+(-1.3642e-017)*A2rf+(1.711e-018)*A3rf+(-7.5782e-018)*A4rf+(1.7e-018)*A5rf'
+cjprf            ='0.001077+(9.3432e-006)*A1rf+(5.983e-006)*A2rf+(-2.9125e-007)*A3rf+(1.8827e-006)*A4rf+(-7.0611e-007)*A5rf'
+cjswprf          ='6.4e-11+(5.5708e-013)*A1rf+(3.5491e-013)*A2rf+(-1.8154e-014)*A3rf+(1.1154e-013)*A4rf+(-4.1954e-014)*A5rf'
+cjswgprf         ='2.2e-10+(1.9085e-012)*A1rf+(1.2222e-012)*A2rf+(-5.9645e-014)*A3rf+(3.8452e-013)*A4rf+(-1.4423e-013)*A5rf'
+cgoprf           ='7.70111e-11+(-3.2965e-013)*A1rf+(2.9463e-013)*A2rf+(9.3606e-013)*A3rf+(4.212e-013)*A4rf+(-7.2784e-014)*A5rf'
+cglprf           ='2.69027e-11+(-1.1516e-013)*A1rf+(1.0293e-013)*A2rf+(3.27e-013)*A3rf+(1.4715e-013)*A4rf+(-2.5426e-014)*A5rf'
+cfprf            ='1.200000e-010+(-5.1367e-013)*A1rf+(4.5909e-013)*A2rf+(1.4586e-012)*A3rf+(6.5632e-013)*A4rf+(-1.1341e-013)*A5rf+5.6e-11'
+drdswprf         ='0+(-2.4786)*A1rf+(-1.5872)*A2rf+(0.077461)*A3rf+(-0.49937)*A4rf+(0.18731)*A5rf'
+ntoxprf          ='1+(-0.13098)*A1rf+(0.094482)*A2rf+(0.26006)*A3rf+(-0.021039)*A4rf+(-0.016591)*A5rf'
+du0prf           ='0+(4.9572e-005)*A1rf+(3.1745e-005)*A2rf+(-1.5492e-006)*A3rf+(9.9875e-006)*A4rf+(-3.7461e-006)*A5rf'
+dlu0prf          ='0+(-3.8116e-012)*A1rf+(-5.4352e-012)*A2rf+(1.1107e-012)*A3rf+(-9.8974e-013)*A4rf+(3.4468e-013)*A5rf'
+dwu0prf          ='0+(-7.8355e-013)*A1rf+(-1.0079e-012)*A2rf+(-2.9923e-013)*A3rf+(7.7825e-013)*A4rf+(8.8902e-014)*A5rf'
+dpu0prf          ='0+(1.2393e-018)*A1rf+(7.9362e-019)*A2rf+(-3.8731e-020)*A3rf+(2.4969e-019)*A4rf+(-9.3653e-020)*A5rf'
+dleta0prf        ='0+(-1.3105e-010)*A1rf+(-4.849e-011)*A2rf+(2.6756e-011)*A3rf+(-9.193e-011)*A4rf+(7.8248e-012)*A5rf'
+dpeta0prf        ='0+(-3.0063e-018)*A1rf+(-5.4681e-018)*A2rf+(-2.1721e-018)*A3rf+(5.9471e-018)*A4rf+(4.3501e-019)*A5rf'
+dlvsatprf        ='0+(0.0002106)*A1rf+(8.6782e-005*0.30)*A2rf+(-3.7335e-005)*A3rf+(0.00013136)*A4rf+(-1.3095e-005)*A5rf'
+dwvsatprf        ='max(-0.0031,0+(-0.00014887)*A1rf+(-0.0001915)*A2rf+(-5.6853e-005)*A3rf+(0.00014787)*A4rf+(1.6891e-005)*A5rf)'
+dpvsatprf        ='0+(7.8355e-014)*A1rf+(1.0079e-013)*A2rf+(2.9923e-014)*A3rf+(-7.7825e-014)*A4rf+(-8.8902e-015)*A5rf'
+dk2prf           ='0+(0.00099144)*A1rf+(0.0006349)*A2rf+(-3.0985e-005)*A3rf+(0.00019975)*A4rf+(-7.4923e-005)*A5rf'
+dlcitprf         ='0+(-1.6224e-012)*A1rf+(-1.1415e-012)*A2rf+(-6.6752e-012)*A3rf+(-3.118e-012)*A4rf+(6.6949e-013)*A5rf'
+dlvoffprf        ='0+(3.9178e-011)*A1rf+(5.0395e-011)*A2rf+(1.4961e-011)*A3rf+(-3.8912e-011)*A4rf+(-4.4451e-012)*A5rf'
+dnfactorprf      ='0+(-0.0054849)*A1rf+(-0.0070553)*A2rf+(-0.0020946)*A3rf+(0.0054477)*A4rf+(0.00062232)*A5rf'
+dlnfactorprf     ='0+(-1.0527e-009)*A1rf+(1.8265e-010)*A2rf+(-2.9996e-010)*A3rf+(-5.1262e-011)*A4rf+(6.5355e-011)*A5rf'
+dpnfactorprf     ='max(-4.0e-15,0+(-3.9835e-016)*A1rf+(-6.3254e-018)*A2rf+(-3.7456e-016)*A3rf+(5.4181e-016)*A4rf+(3.7869e-017)*A5rf)'
+dlk2prf          ='0+(-4.5574e-012)*A1rf+(2.1428e-012)*A2rf+(3.3796e-012)*A3rf+(-1.0279e-011)*A4rf+(4.751e-014)*A5rf'
+dwk2prf          ='0+(1.1154e-010)*A1rf+(7.1426e-011)*A2rf+(-3.4858e-012)*A3rf+(2.2472e-011)*A4rf+(-8.4288e-012)*A5rf'
+dpk2prf          ='0+(2.8064e-018)*A1rf+(2.8094e-018)*A2rf+(5.5973e-019)*A3rf+(-1.3068e-018)*A4rf+(-2.7146e-019)*A5rf'
+dpdiblc2prf      ='max(-0.00032,0+(-5.14e-005)*A1rf+(-8.1618e-007)*A2rf+(-4.833e-005)*A3rf+(6.991e-005)*A4rf+(4.8863e-006)*A5rf)'
+datprf           ='0+(-460.44)*A1rf+(-165.92)*A2rf+(386.31)*A3rf+(-706.07)*A4rf+(1243.7)*A5rf'
+dlatprf          ='0+(-0.00028469)*A1rf+(-0.00019815)*A2rf+(-0.00016663)*A3rf+(0.00018612)*A4rf+(-0.00067267)*A5rf'
+dpatprf          ='0+(2.1352e-011)*A1rf+(1.4861e-011)*A2rf+(1.2497e-011)*A3rf+(-1.3959e-011)*A4rf+(5.045e-011)*A5rf'
+ddlcnrf          =7.27377e-09
+drdswnrf         =0
+deta0nrf         =0
+dwvsatnrf        =0
+dwvoffnrf        =0
+dnfactornrf      =0
+dwnfactornrf     =0
+dpdiblc2nrf      =0
+ddlcprf          =8.26573e-09
+deta0prf         =0
+dweta0prf        =0
+dvsatprf         =0
+dwcitprf         =0
+dpcitprf         =0
+dwvoffprf        =0
+dpvoffprf        =0
+dwnfactorprf     =0
+dlpclmprf        =0
+dppclmprf        =0
+dwatprf          =0
+is_d_dnw_nrf= 1         x_jsw_d_dnw_nrf= 0         n_d_dnw_nrf= 1         rs_d_dnw_nrf= 1
+cj_d_dnw_nrf= 1          cjsw_d_dnw_nrf= 1
+is_d_dnw_prf= 1         x_jsw_d_dnw_prf= 0         n_d_dnw_prf= 1         rs_d_dnw_prf= 1
+cj_d_dnw_prf= 1          cjsw_d_dnw_prf= 1
+is_d_prf= 1                 x_jsw_d_prf= 0             n_d_prf= 1             rs_d_prf= 1
+cj_d_prf= 1                  cjsw_d_prf= 1
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL mc_RFMOS








.LIB TT_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+toxnrf           = 2.6e-09       dxlnrf           = 0             dxwnrf           = 0
+dvthnrf          = 0             dlvthnrf         = 0             dwvthnrf         = 0
+dpvthnrf         = 0             cjnrf            = 0.001251      cjswnrf          = 7.9e-11
+cjswgnrf         = 2.04e-10
+cgonrf           = 8.28670e-11
+cglnrf           = 9.96116e-12
+ddlcnrf          = 7.27377e-09
+cfnrf            = '1.20e-10 + 5.4e-11' drdswnrf         = 0
+ntoxnrf          = 1             du0nrf           = 0             dlu0nrf          = 0
+dwu0nrf          = 0             dpu0nrf          = 0             deta0nrf         = 0
+dleta0nrf        = 0             dweta0nrf        = 0             dpeta0nrf        = 0
+dvsatnrf         = 0             dlvsatnrf        = 0             dwvsatnrf        = 0
+dpvsatnrf        = 0             dk2nrf           = 0             dlcitnrf         = 0
+dwcitnrf         = 0             dlvoffnrf        = 0             dwvoffnrf        = 0
+dpvoffnrf        = 0             dnfactornrf      = 0             dwnfactornrf     = 0
+dlnfactornrf     = 0             dpnfactornrf     = 0             dpdiblc2nrf      = 0
+dla0nrf          = 0             ss_flagrf        = 0             ff_flagrf        = 0
+sf_flagrf        = 0             fs_flagrf        = 0
+toxprf           = 2.8e-09       dxlprf           = 0             dxwprf           = 0
+dvthprf          = 0             dlvthprf         = 0             dwvthprf         = 0
+dpvthprf         = 0             cjprf            = 0.001077      cjswprf          = 6.4e-11
+cjswgprf         = 2.2e-10       cgoprf           = 7.70111e-11   cglprf           = 2.69027e-11
+ddlcprf          = 8.26573e-09   cfprf            = '1.20e-10 + 5.6e-11' drdswprf         = 0
+ntoxprf          = 1             du0prf           = 0             dlu0prf          = 0
+dwu0prf          = 0             dpu0prf          = 0             deta0prf         = 0
+dleta0prf        = 0             dweta0prf        = 0             dpeta0prf        = 0
+dvsatprf         = 0             dlvsatprf        = 0             dwvsatprf        = 0
+dpvsatprf        = 0             dk2prf           = 0             dlcitprf         = 0
+dwcitprf         = 0             dpcitprf         = 0             dlvoffprf        = 0
+dwvoffprf        = 0             dpvoffprf        = 0             dnfactorprf      = 0
+dlnfactorprf     = 0             dwnfactorprf     = 0             dpnfactorprf     = 0
+dlk2prf          = 0             dwk2prf          = 0             dpk2prf          = 0
+dpdiblc2prf      = 0
+dlpclmprf        = 0             dppclmprf         = 0
+datprf           = 0
+dlatprf          = 0
+dwatprf          = 0
+dpatprf          = 0
+is_d_dnw_nrf= 1         x_jsw_d_dnw_nrf= 0         n_d_dnw_nrf= 1         rs_d_dnw_nrf= 1
+cj_d_dnw_nrf= 1          cjsw_d_dnw_nrf= 1
+is_d_dnw_prf= 1         x_jsw_d_dnw_prf= 0         n_d_dnw_prf= 1         rs_d_dnw_prf= 1
+cj_d_dnw_prf= 1          cjsw_d_dnw_prf= 1
+is_d_prf= 1                 x_jsw_d_prf= 0             n_d_prf= 1             rs_d_prf= 1
+cj_d_prf= 1                  cjsw_d_prf= 1
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL TT_RFMOS



***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+toxnrf           = 2.667e-09     dxlnrf           = 5e-09         dxwnrf           = -8e-09
+dvthnrf          = 0.023         dlvthnrf         = 1.5e-09       dwvthnrf         = 2.7e-09
+dpvthnrf         = 2.2e-16       cjnrf            = 0.00133857    cjswnrf          = 8.45e-11
+cjswgnrf         = 2.1828e-10    cgonrf           = 7.70663e-11   cglnrf           = 9.26338e-12
+ddlcnrf          = 7.27377e-09   cfnrf            = '1.1160e-10 + 5.4e-11' drdswnrf         = 0
+ntoxnrf          = 0.24          du0nrf           = 3.0e-04       dlu0nrf          = 5.0e-011
+dwu0nrf          = 0.6e-10       dpu0nrf          = -1.0e-17      deta0nrf         = 0
+dleta0nrf        = -0.6e-09      dweta0nrf        = -5.0e-10      dpeta0nrf        = -1.5e-16
+dvsatnrf         = -0.0e04       dlvsatnrf        = 0.35e-03      dwvsatnrf        = 0
+dpvsatnrf        = 3.0e-11       dk2nrf           = 0.005         dlcitnrf         = -1e-11
+dwcitnrf         = -6e-11        dlvoffnrf        = -5.0e-10      dwvoffnrf        = 0
+dpvoffnrf        = 0             dnfactornrf      = -0.0e-2       dwnfactornrf     = 0
+dlnfactornrf     = -0.5e-08      dpnfactornrf     = -0.0e-15      dpdiblc2nrf      = 0
+dla0nrf          = 10e-08        ss_flagrf        = 1             ff_flagrf        = 0
+sf_flagrf        = 0             fs_flagrf        = 0
+toxprf           = 2.867e-09     dxlprf           = 5e-09         dxwprf           = -8e-09
+dvthprf          = -0.024        dlvthprf         = -6e-10        dwvthprf         = -3.0e-09
+dpvthprf         = -2.1e-16      cjprf            = 0.00115239    cjswprf          = 6.85e-11
+cjswgprf         = 2.354e-10     cgoprf           = 7.16203e-11   cglprf           = 2.50195e-11
+ddlcprf          = 8.26573e-09   cfprf            = '1.1160e-10 + 5.6e-11' drdswprf         = -20
+ntoxprf          = -1.44         du0prf           = 0.0004        dlu0prf          = -2.7e-11
+dwu0prf          = 0             dpu0prf          = 1e-17         deta0prf         = 0
+dleta0prf        = -1.5e-9       dweta0prf        = 0             dpeta0prf        = 2e-17
+dvsatprf         = 0             dlvsatprf        = 0.0023        dwvsatprf        = -0.000
+dpvsatprf        = -0e-12        dk2prf           = 0.008         dlcitprf         = 0
+dwcitprf         = 0             dpcitprf         = 0             dlvoffprf        = 0
+dwvoffprf        = 0             dpvoffprf        = 0             dnfactorprf      = 0
+dlnfactorprf     = -9e-09        dwnfactorprf     = 0             dpnfactorprf     = 0
+dlk2prf          = -1.0e-10      dwk2prf          = 9e-10         dpk2prf          = 1e-17
+dpdiblc2prf      = 0
+dlpclmprf        = 0e-7          dppclmprf        = 0
+datprf           = -9000
+dlatprf          = 0
+dwatprf          = 0
+dpatprf          = 0
+is_d_dnw_nrf= 0.7         x_jsw_d_dnw_nrf= -1         n_d_dnw_nrf= 0.9975         rs_d_dnw_nrf= 1.2
+cj_d_dnw_nrf= 1.07          cjsw_d_dnw_nrf= 1.07
+is_d_dnw_prf= 0.7         x_jsw_d_dnw_prf= -1         n_d_dnw_prf= 0.9975         rs_d_dnw_prf= 1.2
+cj_d_dnw_prf= 1.07          cjsw_d_dnw_prf=  1.07
+is_d_prf= 0.7                 x_jsw_d_prf= -1             n_d_prf= 0.9975             rs_d_prf= 1.2
+cj_d_prf= 1.07                  cjsw_d_prf=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL SS_RFMOS


***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+toxnrf           = 2.533e-09     dxlnrf           = -5e-09        dxwnrf           = 8e-09
+dvthnrf          = -0.023        dlvthnrf         = -1.5e-09      dwvthnrf         = -3.0e-09
+dpvthnrf         = -3.2e-16      cjnrf            = 0.00116343    cjswnrf          = 7.35e-11
+cjswgnrf         = 1.8972e-10    cgonrf           = 8.86677e-11   cglnrf           = 1.06584e-11
+ddlcnrf          = 7.27377e-09   cfnrf            = '1.2840e-10 + 5.4e-11' drdswnrf         = 0
+ntoxnrf          = 1.59          du0nrf           = -3.0e-04      dlu0nrf          = -0.0e-011
+dwu0nrf          = -0.9e-10      dpu0nrf          = 1.0e-17       deta0nrf         = 0
+dleta0nrf        = 0.2e-9        dweta0nrf        = 9.0e-09       dpeta0nrf        = -4.0e-16
+dvsatnrf         = 0.0e4         dlvsatnrf        = -0.4e-03     dwvsatnrf        = 0.0e-03
+dpvsatnrf        = -2.0e-11      dk2nrf           = -0.004        dlcitnrf         = 0
+dwcitnrf         = 0             dlvoffnrf        = 5.0e-10       dwvoffnrf        = 0
+dpvoffnrf        = -0.2e-16       dnfactornrf      = 0             dwnfactornrf     = 0e-08
+dlnfactornrf     = 0.8e-08       dpnfactornrf     = 0.0e-14       dpdiblc2nrf      = 0
+dla0nrf          = -10e-08       ss_flagrf        = 0             ff_flagrf        = 1
+sf_flagrf        = 0             fs_flagrf        = 0
+toxprf           = 2.733e-09     dxlprf           = -5e-09        dxwprf           = 8e-09
+dvthprf          = 0.024         dlvthprf         = 2e-10         dwvthprf         = 4e-09
+dpvthprf         = 1.8e-16       cjprf            = 0.00100161    cjswprf          = 5.95e-11
+cjswgprf         = 2.046e-10     cgoprf           = 8.24019e-11   cglprf           = 2.878599e-11
+ddlcprf          = 8.26573e-09   cfprf            = '1.2840e-10 + 5.6e-11' drdswprf         = 20
+ntoxprf          = 2.27          du0prf           = -0.0004       dlu0prf          = 2.7e-11
+dwu0prf          = 1e-11         dpu0prf          = -1e-17        deta0prf         = 0
+dleta0prf        = 8e-10         dweta0prf        = 0             dpeta0prf        = 5e-17
+dvsatprf         = 0             dlvsatprf        = -0.00135      dwvsatprf        = 0.0019
+dpvsatprf        = -1e-12        dk2prf           = -0.008        dlcitprf         = 0
+dwcitprf         = 0             dpcitprf         = 0             dlvoffprf        = -5e-10
+dwvoffprf        = 0             dpvoffprf        = 0             dnfactorprf      = 0.07
+dlnfactorprf     = 1.0e-8        dwnfactorprf     = 0             dpnfactorprf     = 6.2e-15
+dlk2prf          = 0             dwk2prf          = -9e-10        dpk2prf          = -3e-17
+dpdiblc2prf      = 0.0008
+dlpclmprf        = 0             dppclmprf        = 0
+datprf           = 9000
+dlatprf          = 0
+dwatprf          = 0
+dpatprf          = 0
+is_d_dnw_nrf= 1.3         x_jsw_d_dnw_nrf= 1         n_d_dnw_nrf= 1.0025         rs_d_dnw_nrf= 0.8
+cj_d_dnw_nrf= 0.93          cjsw_d_dnw_nrf= 0.93
+is_d_dnw_prf= 1.3         x_jsw_d_dnw_prf= 1         n_d_dnw_prf= 1.0025         rs_d_dnw_prf= 0.8
+cj_d_dnw_prf= 0.93          cjsw_d_dnw_prf=  0.93
+is_d_prf= 1.3                 x_jsw_d_prf= 1             n_d_prf= 1.0025             rs_d_prf= 0.8
+cj_d_prf= 0.93                  cjsw_d_prf=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL FF_RFMOS



***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+A1Nrf=0.8 A1Prf=-0.8 A2Nrf=0 A2Prf=0 A3Nrf=-1 A3Prf=1 A4NPrf=0
+toxnrf = '2.6e-09 + 6.7000e-011*A4NPrf'     dxlnrf = '5e-009*A2Nrf'                     dxwnrf = '8e-009*A3Nrf'
+dvthnrf = '0.023*A1Nrf'                     dlvthnrf = '1.5e-009*A1Nrf'                 dwvthnrf = '3e-009*A1Nrf'
+dpvthnrf = '2.7e-016*A1Nrf'                 cjnrf = '0.001251 * (1+0.070*A1Nrf)'        cjswnrf = '7.9e-11 * (1+0.070*A1Nrf)'
+cjswgnrf = '2.04e-10 * (1+0.070*A1Nrf)'     cgonrf = '8.28670e-11 * (1-0.070*A4NPrf)'     cglnrf = '9.96116e-12 * (1-0.070*A4NPrf)'
+ddlcnrf = 7.27377e-09
+cfnrf = '1.20e-10*(1-0.070*A4NPrf)+5.4e-11'
+drdswnrf = 0                              ntoxnrf = '1 + -5.9000e-001*A4NPrf'         du0nrf = '0.0003*A1Nrf'
+dlu0nrf = '0*A1Nrf'                         dwu0nrf = '9e-011*A1Nrf'                    dpu0nrf = '-1e-017*A1Nrf'
+deta0nrf = 0                              dleta0nrf = '-2e-010*A1Nrf'                 dweta0nrf = '-9e-009*A1Nrf'
+dpeta0nrf = '4.2e-016*A1Nrf'                dvsatnrf = '-25000*A1Nrf'                   dlvsatnrf = '0.00175*A1Nrf'
+dwvsatnrf = '0*A1Nrf'                       dpvsatnrf = '3e-012*A1Nrf'                  dk2nrf = '0.004*A1Nrf'
+dlcitnrf = 0                              dwcitnrf = 0                              dlvoffnrf = '-5e-010*A1Nrf'
+dwvoffnrf = 0                             dpvoffnrf = 0                             dnfactornrf = 0
+dwnfactornrf = '0*A1Nrf'                    dlnfactornrf = '-8e-009*A1Nrf'              dpnfactornrf = '-5e-015*A1Nrf'
+dpdiblc2nrf = 0                           dla0nrf = '1e-007*A1Nrf'                    ss_flagrf = 0
+ff_flagrf = 0                             sf_flagrf = 1                             fs_flagrf = 0
+toxprf = '2.8e-09 + 6.7000e-11*A4NPrf'      dxlprf = '5e-09*A2Prf'                      dxwprf = '8e-09*A3Prf'
+dvthprf = '-0.024*A1Prf'                    dlvthprf = '-2e-10*A1Prf'                   dwvthprf = '-4e-09*A1Prf'
+dpvthprf = '-1.8e-16*A1Prf'                 cjprf = '0.001077 * (1+0.070*A1Prf)'        cjswprf = '6.4e-11 * (1+0.070*A1Prf)'
+cjswgprf = '2.2e-10 * (1+0.070*A1Prf)'      cgoprf = '7.70111e-11 * (1-0.070*A4NPrf)'   cglprf = '2.69027e-11 * (1-0.070*A4NPrf)'
+ddlcprf = 8.26573e-09
+cfprf = '1.20e-10*(1-0.070*A4NPrf)+5.6e-11'
+drdswprf = '-20*A1Prf'                      ntoxprf = '1 + -1.2700e+00*A4NPrf'          du0prf = '0.0004*A1Prf'
+dlu0prf = '-6e-11*A1Prf'                    dwu0prf = '-1e-11*A1Prf'                    dpu0prf = '1e-17*A1Prf'
+deta0prf = 0                              dleta0prf = '-8e-10*A1Prf'                  dweta0prf = 0
+dpeta0prf = '-5e-17*A1Prf'                  dvsatprf = 0                              dlvsatprf = '0.00135*A1Prf'
+dwvsatprf = '-0.0019*A1Prf'                 dpvsatprf = '1e-12*A1Prf'                   dk2prf = '0.008*A1Prf'
+dlcitprf = 0                              dwcitprf = 0                              dpcitprf = 0
+dlvoffprf = '5e-10*A1Prf'                   dwvoffprf = 0                             dpvoffprf = 0
+dnfactorprf = '-0.07*A1Prf'                 dlnfactorprf = '-1e-08*A1Prf*0'             dwnfactorprf = 0
+dpnfactorprf = '-6.2e-15*A1Prf*0'           dlk2prf = 0                               dwk2prf = '9e-10*A1Prf'
+dpk2prf = '3e-17*A1Prf'                     dpdiblc2prf = '-0.0008*A1Prf*0'             dlpclmprf = 0
+dppclmprf = 0                             datprf = '-7000*A1Prf'                      dlatprf = 0
+dwatprf              = 0                  dpatprf              = 0
+is_d_dnw_nrf= 1         x_jsw_d_dnw_nrf= 0         n_d_dnw_nrf= 1         rs_d_dnw_nrf= 1
+cj_d_dnw_nrf= 1          cjsw_d_dnw_nrf= 1
+is_d_dnw_prf= 1         x_jsw_d_dnw_prf= 0         n_d_dnw_prf= 1         rs_d_dnw_prf= 1
+cj_d_dnw_prf= 1          cjsw_d_dnw_prf= 1
+is_d_prf= 1                 x_jsw_d_prf= 0             n_d_prf= 1             rs_d_prf= 1
+cj_d_prf= 1                  cjsw_d_prf= 1
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL SF_RFMOS



***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS
.lib 'crn65lp_v1d5.l' noiseflagrf
.param
+parn1rf=AGAUSS(0,1,1)
+parn2rf=AGAUSS(0,1,1)
+parp1rf=AGAUSS(0,1,1)
+parp2rf=AGAUSS(0,1,1)
+A1Nrf=-0.8 A1Prf=0.8 A2Nrf=0 A2Prf=0 A3Nrf=1 A3Prf=-1 A4NPrf=0
+toxnrf = '2.6e-09 + 6.7000e-011*A4NPrf'     dxlnrf = '5e-009*A2Nrf'                     dxwnrf = '8e-009*A3Nrf'
+dvthnrf = '0.023*A1Nrf'                     dlvthnrf = '1.5e-009*A1Nrf'                 dwvthnrf = '3e-009*A1Nrf'
+dpvthnrf = '2.7e-016*A1Nrf'                 cjnrf = '0.001251 * (1+0.070*A1Nrf)'        cjswnrf = '7.9e-11 * (1+0.070*A1Nrf)'
+cjswgnrf = '2.04e-10 * (1+0.070*A1Nrf)'     cgonrf = '8.28670e-11 * (1-0.070*A4NPrf)'     cglnrf = '9.96116e-12 * (1-0.070*A4NPrf)'
+ddlcnrf = 7.27377e-09
+cfnrf = '1.20e-10*(1-0.070*A4NPrf)+5.4e-11'
+drdswnrf = 0                              ntoxnrf = '1 + -5.9000e-001*A4NPrf'         du0nrf = '0.0003*A1Nrf'
+dlu0nrf = '0*A1Nrf'                         dwu0nrf = '9e-011*A1Nrf'                    dpu0nrf = '-1e-017*A1Nrf'
+deta0nrf = 0                              dleta0nrf = '-2e-010*A1Nrf'                 dweta0nrf = '-9e-009*A1Nrf'
+dpeta0nrf = '4.2e-016*A1Nrf'                dvsatnrf = '-25000*A1Nrf'                   dlvsatnrf = '0.00175*A1Nrf'
+dwvsatnrf = '0*A1Nrf'                       dpvsatnrf = '3e-012*A1Nrf'                  dk2nrf = '0.004*A1Nrf'
+dlcitnrf = 0                              dwcitnrf = 0                              dlvoffnrf = '-5e-010*A1Nrf'
+dwvoffnrf = 0                             dpvoffnrf = 0                             dnfactornrf = 0
+dwnfactornrf = '0*A1Nrf'                    dlnfactornrf = '-8e-009*A1Nrf'              dpnfactornrf = '-5e-015*A1Nrf'
+dpdiblc2nrf = 0                           dla0nrf = '1e-007*A1Nrf'                    ss_flagrf = 0
+ff_flagrf = 0                             sf_flagrf = 0                             fs_flagrf = 1
+toxprf = '2.8e-09 + 6.7000e-11*A4NPrf'      dxlprf = '5e-09*A2Prf'                      dxwprf = '8e-09*A3Prf'
+dvthprf = '-0.024*A1Prf'                    dlvthprf = '-2e-10*A1Prf'                   dwvthprf = '-4e-09*A1Prf'
+dpvthprf = '-1.8e-16*A1Prf'                 cjprf = '0.001077 * (1+0.070*A1Prf)'        cjswprf = '6.4e-11 * (1+0.070*A1Prf)'
+cjswgprf = '2.2e-10 * (1+0.070*A1Prf)'      cgoprf = '7.70111e-11 * (1-0.070*A4NPrf)'   cglprf = '2.69027e-11 * (1-0.070*A4NPrf)'
+ddlcprf = 8.26573e-09
+cfprf = '1.20e-10*(1-0.070*A4NPrf)+5.6e-11'
+drdswprf = '-20*A1Prf'                      ntoxprf = '1 + -1.2700e+00*A4NPrf'          du0prf = '0.0004*A1Prf'
+dlu0prf = '-6e-11*A1Prf'                    dwu0prf = '-1e-11*A1Prf'                    dpu0prf = '1e-17*A1Prf'
+deta0prf = 0                              dleta0prf = '-8e-10*A1Prf'                  dweta0prf = 0
+dpeta0prf = '-5e-17*A1Prf'                  dvsatprf = 0                              dlvsatprf = '0.00135*A1Prf'
+dwvsatprf = '-0.0019*A1Prf'                 dpvsatprf = '1e-12*A1Prf'                   dk2prf = '0.008*A1Prf'
+dlcitprf = 0                              dwcitprf = 0                              dpcitprf = 0
+dlvoffprf = '5e-10*A1Prf'                   dwvoffprf = 0                             dpvoffprf = 0
+dnfactorprf = '-0.07*A1Prf'                 dlnfactorprf = '-1e-08*A1Prf*0'             dwnfactorprf = 0
+dpnfactorprf = '-6.2e-15*A1Prf*0'           dlk2prf = 0                               dwk2prf = '9e-10*A1Prf'
+dpk2prf = '3e-17*A1Prf'                     dpdiblc2prf = '-0.0008*A1Prf*0'             dlpclmprf = 0
+dppclmprf = 0                             datprf = '-7000*A1Prf'                      dlatprf = 0
+dwatprf              = 0                  dpatprf              = 0
+is_d_dnw_nrf= 1         x_jsw_d_dnw_nrf= 0         n_d_dnw_nrf= 1         rs_d_dnw_nrf= 1
+cj_d_dnw_nrf= 1          cjsw_d_dnw_nrf= 1
+is_d_dnw_prf= 1         x_jsw_d_dnw_prf= 0         n_d_dnw_prf= 1         rs_d_dnw_prf= 1
+cj_d_dnw_prf= 1          cjsw_d_dnw_prf= 1
+is_d_prf= 1                 x_jsw_d_prf= 0             n_d_prf= 1             rs_d_prf= 1
+cj_d_prf= 1                  cjsw_d_prf= 1
.lib 'crn65lp_v1d5.l' RF_MOS
.ENDL FS_RFMOS


.LIB RF_MOS

.subckt nmos_rf D G S B lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parn1rf  temp2=parn2rf
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf='0.00216908*geo_fac*toxnrf*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1603.5*lr*scale/nr/(wr*scale)+2.575)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.084e05/(lr*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(lr*scale*1e6)+0.4837'


.param fn_dice='noiseflagnrf_mc*par1fn_mc+noiseflagnrf_mc_mis*par2fnrf_mc'
.param c1fnrf=8.00E+41           c2fnrf=5.00E+22           c3fnrf=1.00E+7        
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.555*log(((wr*scale*lr*scale*nr)/(12.7E-6*1E-6*1))**0.5)))'
.param noianrf='c1fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'
.param noibnrf='c2fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'
.param noicnrf='c3fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'



**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************
.MODEL nch_rf.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf+dwmisnrf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthnrf+vthmisnrf)'  LVTH0      = '-2.6209825e-009+dlvthnrf'
+WVTH0      = '6.8814839e-010+dwvthnrf'
+PVTH0      = '-5.3326435e-017+dpvthnrf'
+K1         = 0.31994             K2         = '0.0071010498+dk2nrf' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitnrf'
+WCIT       = '-2.634146e-010+dwcitnrf'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffnrf'
+WVOFF      = '-2.7301032e-008+dwvoffnrf'
+PVOFF      = '3.8940424e-015+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf'    ETA0       = '0.10402516+deta0nrf' LETA0      = '-1.6784547e-010+dleta0nrf'
+WETA0      = '-3.0136772e-008+dweta0nrf'
+PETA0      = '1.6875216e-015+dpeta0nrf'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0nrf'  LU0        = '6.0443544e-011+dlu0nrf'
+WU0        = '-3.4587047e-010+dwu0nrf'
+PU0        = '-1.2567478e-016+dpu0nrf'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatnrf-195.445*ff_flagrf+312.712*ss_flagrf'
+LVSAT      = '-0.00073522225+dlvsatnrf+1.87198e-05*ff_flagrf-2.99517e-05*ss_flagrf'
+WVSAT      = '0.013868259+dwvsatnrf+0.00195836*ff_flagrf-0.00313337*ss_flagrf'
+PVSAT      = '-1.6704557e-009+dpvsatnrf-1.87572e-10*ff_flagrf+3.00116e-10*ss_flagrf'
+A0         = '0.71811517-0.157167*ff_flagrf'
+LA0        = '-2.3073092e-007+dla0nrf+2.80797e-08*ff_flagrf'
+WA0        = '4.6955716e-007+1.57482e-06*ff_flagrf'
+PA0        = '-7.5179779e-014-2.81358e-13*ff_flagrf'
+AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2nrf'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf'
+RDW        = '65+drdswnrf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxnrf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf'
+CGDO       = 'cgonrf'              CGBO       = 0                   CGDL       = 'cglnrf'
+CGSL       = 'cglnrf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf'
+WNFACTOR   = '0+dwnfactornrf'      PNFACTOR   = '0+dpnfactornrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )  


.MODEL nch_rf.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+WMIN       = '1e-006-(dxwnrf+dwmisnrf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41095635+(dvthnrf+vthmisnrf)'  LVTH0      = '4.4351783e-010+dlvthnrf'
+WVTH0      = '-9.3492206e-009+dwvthnrf'
+PVTH0      = '9.0806281e-016+dpvthnrf'
+K1         = 0.31994             K2         = '0.0013060071+dk2nrf' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 9.8452363e-005      LCIT       = '1.9928338e-010+dlcitnrf'
+WCIT       = '-1.6453517e-009+dwcitnrf'
+PCIT       = 1.1079017e-016      VOFF       = -0.13957401         LVOFF      = '-3.8809298e-009+dlvoffnrf'
+WVOFF      = '2.9811114e-008+dwvoffnrf'
+PVOFF      = '-1.576216e-015+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf-0.357015*ss_flagrf+0.357015*ff_flagrf'
+ETA0       = '0.00035892377+deta0nrf-0.00181714*ff_flagrf'
+LETA0      = '9.7614105e-009+dleta0nrf+1.74047e-10*ff_flagrf'
+WETA0      = '1.4881786e-009+dweta0nrf+1.82078e-08*ff_flagrf'
+PETA0      = '-1.3415478e-015+dpeta0nrf-1.74395e-15*ff_flagrf'
+ETAB       = -0.081412532        LETAB      = -1.9907778e-010     WETAB      = -4.2459433e-008
+PETAB      = 1.9947594e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0nrf'   LU0        = '4.5926676e-011+dlu0nrf'
+WU0        = '-4.2433976e-009+dwu0nrf'
+PU0        = '2.4763426e-016+dpu0nrf'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024      UB         = 1.7366172e-018      LUB        = 9.8246845e-028
+WUB        = -1.7615195e-025     PUB        = -8.5364064e-033     UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '84649.699+dvsatnrf+1470.82*ff_flagrf'
+LVSAT      = '0.00071705169+dlvsatnrf-0.000140875*ff_flagrf'
+WVSAT      = '0.0039042958+dwvsatnrf-0.00509818*ff_flagrf'
+PVSAT      = '-7.1609734e-010+dpvsatnrf+4.88305e-10*ff_flagrf'
+A0         = '1.6696481+0.354057*ff_flagrf'
+LA0        = '-3.2186969e-007+dla0nrf-2.08856e-08*ff_flagrf'
+WA0        = '-2.4506944e-006-3.54765e-06*ff_flagrf'
+PA0        = '2.0452483e-013+2.09274e-13*ff_flagrf'
+AGS        = '3.3966895+1.45371*ss_flagrf'
+Pags     = '0+1.39516e-12*ss_flagrf'
+Wags     = '0-1.45662e-05*ss_flagrf'
+LAGS       = '1.5356668e-007-1.39237e-07*ss_flagrf'
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxnrf'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf'              CGDO       = 'cgonrf'
+CGBO       = 0                   CGDL       = 'cglnrf'              CGSL       = 'cglnrf'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.097099973        LKT2       = 3.1797651e-009      WKT2       = 1.7596724e-008
+PKT2       = -1.2711311e-015     UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf+3.4195e-08*ss_flagrf-3.4195e-08*ff_flagrf'
+WNFACTOR   = '0+dwnfactornrf+3.64155e-07*ss_flagrf-3.64155e-07*ff_flagrf'
+PNFACTOR   = '0+dpnfactornrf-3.48789e-14*ss_flagrf+3.48789e-14*ff_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )  


.MODEL nch_rf.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf+dwmisnrf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthnrf+vthmisnrf)'  LVTH0      = '-2.4452732e-009+dlvthnrf'
+WVTH0      = '-2.656096e-009+dwvthnrf'
+PVTH0      = '-2.3254991e-016+dpvthnrf'
+K1         = 0.31994             K2         = '-0.0077298678+dk2nrf'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitnrf'
+WCIT       = '4.0796102e-010+dwcitnrf'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffnrf'
+WVOFF      = '-1.6424805e-008+dwvoffnrf'
+PVOFF      = '8.6103596e-016+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf'    ETA0       = '0.044118879+deta0nrf'
+LETA0      = '3.7906852e-009+dleta0nrf'
+WETA0      = '3.0967637e-008+dweta0nrf'
+PETA0      = '-2.3501797e-015+dpeta0nrf'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0nrf'  LU0        = '-6.7466293e-010+dlu0nrf'
+WU0        = '-7.6703892e-009+dwu0nrf'
+PU0        = '6.2413382e-016+dpu0nrf'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatnrf+4397.51*ff_flagrf-7036.02*ss_flagrf'
+LVSAT      = '-0.0010680136+dlvsatnrf-0.000421195*ff_flagrf+0.000673912*ss_flagrf'
+WVSAT      = '0.0069449685+dwvsatnrf-0.00272646*ff_flagrf+0.00436233*ss_flagrf'
+PVSAT      = '-1.3310085e-009+dpvsatnrf+2.61141e-10*ff_flagrf-4.17826e-10*ss_flagrf'
+A0         = '2.0693451+3.53626*ff_flagrf'
+LA0        = '-7.0903035e-007+dla0nrf-6.31793e-07*ff_flagrf'
+WA0        = '-9.0869732e-007-2.19248e-06*ff_flagrf'
+PA0        = '4.1268564e-013+3.91711e-13*ff_flagrf'
+AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf'              CGDO       = 'cgonrf'              CGBO       = 0
+CGDL       = 'cglnrf'              CGSL       = 'cglnrf'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 0
+CJD        = 0			MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf'      WNFACTOR   = '0+dwnfactornrf'      PNFACTOR   = '0+dpnfactornrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )  


.MODEL nch_rf.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf+dwmisnrf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.4204795+(dvthnrf+vthmisnrf)-0.00994084*ff_flagrf'
+LVTH0      = '2.1124771e-011+dlvthnrf+9.52137e-10*ff_flagrf'
+WVTH0      = '-1.9062833e-008+dwvthnrf+1.01397e-08*ff_flagrf'
+PVTH0      = '1.3389037e-015+dpvthnrf-9.7118e-16*ff_flagrf'
+K1         = 0.31994             K2         = '-0.014947392+dk2nrf' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitnrf'
+WCIT       = '-4.2348127e-010+dwcitnrf'
+PCIT       = 6.2821635e-017      VOFF       = -0.10368237         LVOFF      = '-5.3664414e-009+dlvoffnrf'
+WVOFF      = '-6.7983641e-009+dwvoffnrf'
+PVOFF      = '-6.0994162e-017+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf-0.745563*ss_flagrf'
+ETA0       = '-0.051871703+deta0nrf+0.0408857*ff_flagrf'
+LETA0      = '1.2984759e-008+dleta0nrf-3.91605e-09*ff_flagrf'
+WETA0      = '5.4763418e-008+dweta0nrf-2.53491e-08*ff_flagrf'
+PETA0      = '-4.6293634e-015+dpeta0nrf+2.42795e-15*ff_flagrf'
+ETAB       = -0.16081204         LETAB      = 4.4792501e-009      WETAB      = 3.8528064e-008
+PETAB      = -2.7771351e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0nrf'  LU0        = '1.4350807e-010+dlu0nrf'
+WU0        = '-2.7003787e-009+dwu0nrf'
+PU0        = '1.4810125e-016+dpu0nrf'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023      UB         = 9.4237903e-019      LUB        = 5.867745e-026
+WUB        = 6.3397101e-025      PUB        = -6.7385287e-032     UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatnrf-11977.1*ff_flagrf'
+LVSAT      = '-0.00026235326+dlvsatnrf+0.00114717*ff_flagrf'
+WVSAT      = '-0.0099049722+dwvsatnrf+0.00861872*ff_flagrf'
+PVSAT      = '2.8289571e-010+dpvsatnrf-8.25503e-10*ff_flagrf'
+A0         = '-8.937762-7.96629*ff_flagrf'
+LA0        = '3.4524137e-007+dla0nrf+4.69926e-07*ff_flagrf'
+WA0        = '8.3688639e-006+4.9391e-06*ff_flagrf'
+PA0        = '-4.7592845e-013-2.91354e-13*ff_flagrf'
+AGS        = '6.4966895-32.7086*ss_flagrf'
+LAGS       = '1.5356668e-007+3.13284e-06*ss_flagrf'
+WAGS       = '-3.162e-006+2.02793e-05*ss_flagrf'
+PAGS       = '-1.6753592e-027-1.94236e-12*ss_flagrf'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf'              CGDO       = 'cgonrf'              CGBO       = 0
+CGDL       = 'cglnrf'              CGSL       = 'cglnrf'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0                   KT2        = -0.10354588
+LKT2       = 3.8169646e-009      WKT2       = 2.4171549e-008      PKT2       = -1.9210747e-015
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 0			CJD        = 0			MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 0			CJSWD      = 0			MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 0			CJSWGD     = 0			MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf+7.14103e-08*ss_flagrf'
+WNFACTOR   = '0+dwnfactornrf+7.60474e-07*ss_flagrf'
+PNFACTOR   = '0+dpnfactornrf-7.28385e-14*ss_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL ndio_rf_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswnrf'
+AREA   = 3.08E-8                 MJSW   = 0.005                   TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 0.0004                  FCS    = 0			   )

.MODEL ndio_rf_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgnrf'
+AREA   = 3.08E-8                 MJSW   = 0.52                    TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0015                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 2.4e-05                 FCS    = 0			   )

.ends nmos_rf

.subckt pmos_rf D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parp1rf  temp2=parp2rf
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf='0.00253346*geo_fac*toxprf*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mc*par1fn_mc+noiseflagprf_mc_mis*par2fprf_mc'
.param c1fprf=9.50E+41           c2fprf=1.55E+24           c3fprf=1.00E+10      
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf='c1fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noibprf='c2fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noicprf='c3fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'


**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'




**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf+vthmisprf)' LVTH0      = '3.2178643e-009+dlvthprf'
+WVTH0      = '1.3206912e-008+dwvthprf'
+PVTH0      = '-8.8880115e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.027489247+dk2prf'  LK2        = '7.5980421e-010+dlk2prf'
+WK2        = '-8.0262273e-009+dwk2prf'
+PK2        = '1.0831329e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf'
+WCIT       = '-9.439202e-010+dwcitprf'
+PCIT       = '7.5195034e-017+dpcitprf'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf'
+WVOFF      = '-5.7821145e-009+dwvoffprf'
+PVOFF      = '1.283818e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.15306049+deta0prf' LETA0      = '-4.6449316e-013+dleta0prf'
+WETA0      = '-4.8996634e-009+dweta0prf'
+PETA0      = '1.2028151e-018+dpeta0prf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf'  LU0        = '1.3663252e-012+dlu0prf'
+WU0        = '8.2210644e-011+dwu0prf'
+PU0        = '-1.3690578e-017+dpu0prf'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf'  LVSAT      = '0.0017671522+dlvsatprf'
+WVSAT      = '0.0019549554+dwvsatprf'
+PVSAT      = '-4.4983329e-010+dpvsatprf'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf'
+LAT        = '-0.036846346+dlatprf'
+WAT        = '-0.32267684+dwatprf'
+PAT        = '3.5967105e-08+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf'
+WNFACTOR   = '0+dwnfactorprf'      PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+(dvthprf+vthmisprf)' LVTH0      = '-3.4158001e-009+dlvthprf'
+WVTH0      = '-1.3529255e-008+dwvthprf'
+PVTH0      = '1.7447113e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.03417205+dk2prf'   LK2        = '1.0154813e-010+dlk2prf'
+WK2        = '-1.8062006e-008+dwk2prf'
+PK2        = '1.0968375e-015+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitprf'
+WCIT       = '-9.8077622e-010+dwcitprf'
+PCIT       = '7.8825353e-017+dpcitprf'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffprf'
+WVOFF      = '-1.7801351e-008+dwvoffprf'
+PVOFF      = '2.4677127e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.756116*ff_flagrf-0.661602*ss_flagrf+0.378058*sf_flagrf-0.604893*fs_flagrf'
+ETA0       = '0.14447861+deta0prf-0.0378058*ss_flagrf'
+LETA0      = '8.4485e-010+dleta0prf+3.72386e-09*ss_flagrf'
+WETA0      = '-7.6134723e-009+dweta0prf+3.85619e-08*ss_flagrf'
+PETA0      = '2.6851299e-016+dpeta0prf-3.79834e-15*ss_flagrf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf-1.92425e-05*ff_flagrf-0.000320331*ss_flagrf+0.0*sf_flagrf+1.5394e-05*fs_flagrf'
+LU0        = '4.0694732e-012+dlu0prf+1.89538e-12*ff_flagrf+3.15525e-11*ss_flagrf+0.0*sf_flagrf-1.5163e-12*fs_flagrf'
+WU0        = '-1.5318415e-010+dwu0prf+1.9281e-10*ff_flagrf-1.9281e-10*ss_flagrf+0.0*sf_flagrf-1.54248e-10*fs_flagrf'
+PU0        = '9.495809e-018+dpu0prf-1.89917e-17*ff_flagrf+1.89917e-17*ss_flagrf+0.0*sf_flagrf+1.51934e-17*fs_flagrf'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatprf+5670.87*ff_flagrf-8489.34*ss_flagrf+4536.7*sf_flagrf-4536.7*fs_flagrf'
+LVSAT      = '0.00035562736+dlvsatprf-0.000558579*ff_flagrf+0.000836197*ss_flagrf-0.000446864*sf_flagrf+0.000446864*fs_flagrf'
+WVSAT      = '0.0010707586+dwvsatprf-0.00578429*ff_flagrf-4.8e-09*ss_flagrf-0.00462743*sf_flagrf+0.00462743*fs_flagrf'
+PVSAT      = '-3.6273991e-010+dpvsatprf+5.69751e-10*ff_flagrf-2e-17*ss_flagrf+4.55801e-10*sf_flagrf-4.55801e-10*fs_flagrf'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flagrf-0.547845*ss_flagrf+0.45367*sf_flagrf-0.450591*fs_flagrf'
+LPCLM      = '3.5007467e-009+dlpclmprf-5.54788e-08*ff_flagrf+5.39625e-08*ss_flagrf-4.46864e-08*sf_flagrf+4.43831e-08*fs_flagrf'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flagrf+3.85619e-07*ss_flagrf-4.62743e-07*sf_flagrf+4.31893e-07*fs_flagrf'
+PPCLM      = '-3.439044e-015+dppclmprf+5.31768e-14*ff_flagrf-3.79834e-14*ss_flagrf+4.55801e-14*sf_flagrf-4.25414e-14*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf'
+LAT        = '0.0065683527+dlatprf'
+WAT        = '0.09819304+dwatprf'
+PAT        = '-5.4885776e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf-7.44773e-08*ff_flagrf+6.51676e-08*ss_flagrf-3.72386e-08*sf_flagrf+5.95818e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-7.71239e-07*ff_flagrf+6.74834e-07*ss_flagrf-3.85619e-07*sf_flagrf+6.16991e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+7.59668e-14*ff_flagrf-6.64709e-14*ss_flagrf+3.79834e-14*sf_flagrf-6.07734e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf+vthmisprf)' LVTH0      = '1.8657789e-009+dlvthprf'
+WVTH0      = '2.5644645e-010+dwvthprf'
+PVTH0      = '4.9032594e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.021012137+dk2prf'  LK2        = '8.7204533e-010+dlk2prf'
+WK2        = '-1.4195742e-009+dwk2prf'
+PK2        = '-6.1726576e-018+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf'
+WCIT       = '1.6122937e-009+dwcitprf'
+PCIT       = '-1.9902291e-016+dpcitprf'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf'
+WVOFF      = '-2.10792e-009+dwvoffprf'
+PVOFF      = '4.8255944e-016+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.14756059+deta0prf' LETA0      = '-1.9572049e-010+dleta0prf'
+WETA0      = '7.102273e-010+dweta0prf'
+PETA0      = '2.0036393e-016+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf'  LU0        = '-1.2055811e-011+dlu0prf'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf'  LVSAT      = '0.0033816548+dlvsatprf'
+WVSAT      = '0.0091118432+dwvsatprf'
+PVSAT      = '-2.096626e-009+dpvsatprf'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf'
+LAT        = '-0.010714171+dlatprf'
+WAT        = '-0.11098338+dwatprf'
+PAT        = '9.3122869e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf'
+PU0        = '0+dpu0prf'           LNFACTOR   = '0+dlnfactorprf'      WNFACTOR   = '0+dwnfactorprf'
+PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+(dvthprf+vthmisprf)'  LVTH0      = '1.2618987e-009+dlvthprf'
+WVTH0      = '3.5960684e-008+dwvthprf'
+PVTH0      = '-3.0265415e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.022738541+dk2prf'  LK2        = '7.0199448e-010+dlk2prf'
+WK2        = '-6.399827e-009+dwk2prf'
+PK2        = '4.8438224e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitprf'
+WCIT       = '3.1067772e-010+dwcitprf'
+PCIT       = '-7.0813731e-017+dpcitprf'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffprf'
+WVOFF      = '2.1045293e-008+dwvoffprf'
+PVOFF      = '-1.798032e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.394754*ff_flagrf+0.394754*ss_flagrf+0.315803*sf_flagrf-0.315803*fs_flagrf'
+ETA0       = '0.11688678+deta0prf' LETA0      = '2.82565e-009+dleta0prf'
+WETA0      = '2.0530196e-008+dweta0prf'
+PETA0      = '-1.751903e-015+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf+0.000432956*ff_flagrf-0.00129887*ss_flagrf+0.0*sf_flagrf-0.000346365*fs_flagrf'
+LU0        = '1.337909e-011+dlu0prf-4.2646e-11*ff_flagrf+1.27938e-10*ss_flagrf+0.0*sf_flagrf+3.41168e-11*fs_flagrf'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatprf+2631.69*ff_flagrf-21647.8*ss_flagrf+2105.35*sf_flagrf-2105.35*fs_flagrf'
+LVSAT      = '-0.00025921987+dlvsatprf-0.000259221*ff_flagrf+0.0021323*ss_flagrf-0.000207377*sf_flagrf+0.000207377*fs_flagrf'
+WVSAT      = '-0.014858007+dwvsatprf-0.00268433*ff_flagrf+0.0134216*ss_flagrf-0.00214746*sf_flagrf+0.00214746*fs_flagrf'
+PVSAT      = '2.6440426e-010+dpvsatprf+2.64405e-10*ff_flagrf-1.32203e-09*ss_flagrf+2.11524e-10*sf_flagrf-2.11524e-10*fs_flagrf'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flagrf-0.432956*ss_flagrf+0.0*sf_flagrf-0.0692729*fs_flagrf'
+LPCLM      = '-7.7061899e-009+dlpclmprf-8.52921e-09*ff_flagrf+4.2646e-08*ss_flagrf+0.0*sf_flagrf+6.82337e-09*fs_flagrf'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flagrf+2.68433e-07*ss_flagrf+0.0*sf_flagrf+4.29492e-08*fs_flagrf'
+PPCLM      = '7.9920313e-015+dppclmprf+5.28811e-15*ff_flagrf-2.64405e-14*ss_flagrf+0.0*sf_flagrf-4.23049e-15*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf'
+LAT        = '-0.0064077479+dlatprf'
+WAT        = '-0.095092602+dwatprf'
+PAT        = '7.7470449e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf-2.68433e-10*ff_flagrf+8.05298e-10*ss_flagrf+0.0*sf_flagrf+2.14746e-10*fs_flagrf'
+PU0        = '0+dpu0prf+2.64405e-17*ff_flagrf-7.93216e-17*ss_flagrf+0.0*sf_flagrf-2.11524e-17*fs_flagrf'
+LNFACTOR   = '0+dlnfactorprf-3.88831e-08*ff_flagrf-3.88831e-08*ss_flagrf-3.11065e-08*sf_flagrf+3.11065e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-4.02649e-07*ff_flagrf-4.02649e-07*ss_flagrf-3.22119e-07*sf_flagrf+3.22119e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+3.96608e-14*ff_flagrf+3.96608e-14*ss_flagrf+3.17286e-14*sf_flagrf-3.17286e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf

.subckt pmos_rf_nw D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parp1rf  temp2=parp2rf
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf='0.00253346*geo_fac*toxprf*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mc*par1fn_mc+noiseflagprf_mc_mis*par2fprf_mc'
.param c1fprf=9.50E+41           c2fprf=1.55E+24           c3fprf=1.00E+10      
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf='c1fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noibprf='c2fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noicprf='c3fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'




**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf+vthmisprf)' LVTH0      = '3.2178643e-009+dlvthprf'
+WVTH0      = '1.3206912e-008+dwvthprf'
+PVTH0      = '-8.8880115e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.027489247+dk2prf'  LK2        = '7.5980421e-010+dlk2prf'
+WK2        = '-8.0262273e-009+dwk2prf'
+PK2        = '1.0831329e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf'
+WCIT       = '-9.439202e-010+dwcitprf'
+PCIT       = '7.5195034e-017+dpcitprf'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf'
+WVOFF      = '-5.7821145e-009+dwvoffprf'
+PVOFF      = '1.283818e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.15306049+deta0prf' LETA0      = '-4.6449316e-013+dleta0prf'
+WETA0      = '-4.8996634e-009+dweta0prf'
+PETA0      = '1.2028151e-018+dpeta0prf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf'  LU0        = '1.3663252e-012+dlu0prf'
+WU0        = '8.2210644e-011+dwu0prf'
+PU0        = '-1.3690578e-017+dpu0prf'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf'  LVSAT      = '0.0017671522+dlvsatprf'
+WVSAT      = '0.0019549554+dwvsatprf'
+PVSAT      = '-4.4983329e-010+dpvsatprf'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf'
+LAT        = '-0.036846346+dlatprf'
+WAT        = '-0.32267684+dwatprf'
+PAT        = '3.5967105e-08+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf'
+WNFACTOR   = '0+dwnfactorprf'      PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+(dvthprf+vthmisprf)' LVTH0      = '-3.4158001e-009+dlvthprf'
+WVTH0      = '-1.3529255e-008+dwvthprf'
+PVTH0      = '1.7447113e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.03417205+dk2prf'   LK2        = '1.0154813e-010+dlk2prf'
+WK2        = '-1.8062006e-008+dwk2prf'
+PK2        = '1.0968375e-015+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitprf'
+WCIT       = '-9.8077622e-010+dwcitprf'
+PCIT       = '7.8825353e-017+dpcitprf'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffprf'
+WVOFF      = '-1.7801351e-008+dwvoffprf'
+PVOFF      = '2.4677127e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.756116*ff_flagrf-0.661602*ss_flagrf+0.378058*sf_flagrf-0.604893*fs_flagrf'
+ETA0       = '0.14447861+deta0prf-0.0378058*ss_flagrf'
+LETA0      = '8.4485e-010+dleta0prf+3.72386e-09*ss_flagrf'
+WETA0      = '-7.6134723e-009+dweta0prf+3.85619e-08*ss_flagrf'
+PETA0      = '2.6851299e-016+dpeta0prf-3.79834e-15*ss_flagrf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf-1.92425e-05*ff_flagrf-0.000320331*ss_flagrf+0.0*sf_flagrf+1.5394e-05*fs_flagrf'
+LU0        = '4.0694732e-012+dlu0prf+1.89538e-12*ff_flagrf+3.15525e-11*ss_flagrf+0.0*sf_flagrf-1.5163e-12*fs_flagrf'
+WU0        = '-1.5318415e-010+dwu0prf+1.9281e-10*ff_flagrf-1.9281e-10*ss_flagrf+0.0*sf_flagrf-1.54248e-10*fs_flagrf'
+PU0        = '9.495809e-018+dpu0prf-1.89917e-17*ff_flagrf+1.89917e-17*ss_flagrf+0.0*sf_flagrf+1.51934e-17*fs_flagrf'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatprf+5670.87*ff_flagrf-8489.34*ss_flagrf+4536.7*sf_flagrf-4536.7*fs_flagrf'
+LVSAT      = '0.00035562736+dlvsatprf-0.000558579*ff_flagrf+0.000836197*ss_flagrf-0.000446864*sf_flagrf+0.000446864*fs_flagrf'
+WVSAT      = '0.0010707586+dwvsatprf-0.00578429*ff_flagrf-4.8e-09*ss_flagrf-0.00462743*sf_flagrf+0.00462743*fs_flagrf'
+PVSAT      = '-3.6273991e-010+dpvsatprf+5.69751e-10*ff_flagrf-2e-17*ss_flagrf+4.55801e-10*sf_flagrf-4.55801e-10*fs_flagrf'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flagrf-0.547845*ss_flagrf+0.45367*sf_flagrf-0.450591*fs_flagrf'
+LPCLM      = '3.5007467e-009+dlpclmprf-5.54788e-08*ff_flagrf+5.39625e-08*ss_flagrf-4.46864e-08*sf_flagrf+4.43831e-08*fs_flagrf'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flagrf+3.85619e-07*ss_flagrf-4.62743e-07*sf_flagrf+4.31893e-07*fs_flagrf'
+PPCLM      = '-3.439044e-015+dppclmprf+5.31768e-14*ff_flagrf-3.79834e-14*ss_flagrf+4.55801e-14*sf_flagrf-4.25414e-14*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf'
+LAT        = '0.0065683527+dlatprf'
+WAT        = '0.09819304+dwatprf'
+PAT        = '-5.4885776e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf-7.44773e-08*ff_flagrf+6.51676e-08*ss_flagrf-3.72386e-08*sf_flagrf+5.95818e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-7.71239e-07*ff_flagrf+6.74834e-07*ss_flagrf-3.85619e-07*sf_flagrf+6.16991e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+7.59668e-14*ff_flagrf-6.64709e-14*ss_flagrf+3.79834e-14*sf_flagrf-6.07734e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf+vthmisprf)' LVTH0      = '1.8657789e-009+dlvthprf'
+WVTH0      = '2.5644645e-010+dwvthprf'
+PVTH0      = '4.9032594e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.021012137+dk2prf'  LK2        = '8.7204533e-010+dlk2prf'
+WK2        = '-1.4195742e-009+dwk2prf'
+PK2        = '-6.1726576e-018+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf'
+WCIT       = '1.6122937e-009+dwcitprf'
+PCIT       = '-1.9902291e-016+dpcitprf'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf'
+WVOFF      = '-2.10792e-009+dwvoffprf'
+PVOFF      = '4.8255944e-016+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.14756059+deta0prf' LETA0      = '-1.9572049e-010+dleta0prf'
+WETA0      = '7.102273e-010+dweta0prf'
+PETA0      = '2.0036393e-016+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf'  LU0        = '-1.2055811e-011+dlu0prf'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf'  LVSAT      = '0.0033816548+dlvsatprf'
+WVSAT      = '0.0091118432+dwvsatprf'
+PVSAT      = '-2.096626e-009+dpvsatprf'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf'
+LAT        = '-0.010714171+dlatprf'
+WAT        = '-0.11098338+dwatprf'
+PAT        = '9.3122869e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf'
+PU0        = '0+dpu0prf'           LNFACTOR   = '0+dlnfactorprf'      WNFACTOR   = '0+dwnfactorprf'
+PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+(dvthprf+vthmisprf)'  LVTH0      = '1.2618987e-009+dlvthprf'
+WVTH0      = '3.5960684e-008+dwvthprf'
+PVTH0      = '-3.0265415e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.022738541+dk2prf'  LK2        = '7.0199448e-010+dlk2prf'
+WK2        = '-6.399827e-009+dwk2prf'
+PK2        = '4.8438224e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitprf'
+WCIT       = '3.1067772e-010+dwcitprf'
+PCIT       = '-7.0813731e-017+dpcitprf'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffprf'
+WVOFF      = '2.1045293e-008+dwvoffprf'
+PVOFF      = '-1.798032e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.394754*ff_flagrf+0.394754*ss_flagrf+0.315803*sf_flagrf-0.315803*fs_flagrf'
+ETA0       = '0.11688678+deta0prf' LETA0      = '2.82565e-009+dleta0prf'
+WETA0      = '2.0530196e-008+dweta0prf'
+PETA0      = '-1.751903e-015+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf+0.000432956*ff_flagrf-0.00129887*ss_flagrf+0.0*sf_flagrf-0.000346365*fs_flagrf'
+LU0        = '1.337909e-011+dlu0prf-4.2646e-11*ff_flagrf+1.27938e-10*ss_flagrf+0.0*sf_flagrf+3.41168e-11*fs_flagrf'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatprf+2631.69*ff_flagrf-21647.8*ss_flagrf+2105.35*sf_flagrf-2105.35*fs_flagrf'
+LVSAT      = '-0.00025921987+dlvsatprf-0.000259221*ff_flagrf+0.0021323*ss_flagrf-0.000207377*sf_flagrf+0.000207377*fs_flagrf'
+WVSAT      = '-0.014858007+dwvsatprf-0.00268433*ff_flagrf+0.0134216*ss_flagrf-0.00214746*sf_flagrf+0.00214746*fs_flagrf'
+PVSAT      = '2.6440426e-010+dpvsatprf+2.64405e-10*ff_flagrf-1.32203e-09*ss_flagrf+2.11524e-10*sf_flagrf-2.11524e-10*fs_flagrf'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flagrf-0.432956*ss_flagrf+0.0*sf_flagrf-0.0692729*fs_flagrf'
+LPCLM      = '-7.7061899e-009+dlpclmprf-8.52921e-09*ff_flagrf+4.2646e-08*ss_flagrf+0.0*sf_flagrf+6.82337e-09*fs_flagrf'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flagrf+2.68433e-07*ss_flagrf+0.0*sf_flagrf+4.29492e-08*fs_flagrf'
+PPCLM      = '7.9920313e-015+dppclmprf+5.28811e-15*ff_flagrf-2.64405e-14*ss_flagrf+0.0*sf_flagrf-4.23049e-15*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf'
+LAT        = '-0.0064077479+dlatprf'
+WAT        = '-0.095092602+dwatprf'
+PAT        = '7.7470449e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf-2.68433e-10*ff_flagrf+8.05298e-10*ss_flagrf+0.0*sf_flagrf+2.14746e-10*fs_flagrf'
+PU0        = '0+dpu0prf+2.64405e-17*ff_flagrf-7.93216e-17*ss_flagrf+0.0*sf_flagrf-2.11524e-17*fs_flagrf'
+LNFACTOR   = '0+dlnfactorprf-3.88831e-08*ff_flagrf-3.88831e-08*ss_flagrf-3.11065e-08*sf_flagrf+3.11065e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-4.02649e-07*ff_flagrf-4.02649e-07*ss_flagrf-3.22119e-07*sf_flagrf+3.22119e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+3.96608e-14*ff_flagrf+3.96608e-14*ss_flagrf+3.17286e-14*sf_flagrf-3.17286e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf_nw

.subckt nmos_rf_6t D G S B NG PG lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parn1rf  temp2=parn2rf
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf='0.00216908*geo_fac*toxnrf*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1603.5*lr*scale/nr/(wr*scale)+2.575)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.084e05/(lr*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(lr*scale*1e6)+0.4837'

.param fn_dice='noiseflagnrf_mc*par1fn_mc+noiseflagnrf_mc_mis*par2fnrf_mc'
.param c1fnrf=8.00E+41           c2fnrf=5.00E+22           c3fnrf=1.00E+7        
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.555*log(((wr*scale*lr*scale*nr)/(12.7E-6*1E-6*1))**0.5)))'
.param noianrf='c1fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'
.param noibnrf='c2fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'
.param noicnrf='c3fnrf*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************
.MODEL nch_rf.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf+dwmisnrf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthnrf+vthmisnrf)'  LVTH0      = '-2.6209825e-009+dlvthnrf'
+WVTH0      = '6.8814839e-010+dwvthnrf'
+PVTH0      = '-5.3326435e-017+dpvthnrf'
+K1         = 0.31994             K2         = '0.0071010498+dk2nrf' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitnrf'
+WCIT       = '-2.634146e-010+dwcitnrf'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffnrf'
+WVOFF      = '-2.7301032e-008+dwvoffnrf'
+PVOFF      = '3.8940424e-015+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf'    ETA0       = '0.10402516+deta0nrf' LETA0      = '-1.6784547e-010+dleta0nrf'
+WETA0      = '-3.0136772e-008+dweta0nrf'
+PETA0      = '1.6875216e-015+dpeta0nrf'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0nrf'  LU0        = '6.0443544e-011+dlu0nrf'
+WU0        = '-3.4587047e-010+dwu0nrf'
+PU0        = '-1.2567478e-016+dpu0nrf'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatnrf-195.445*ff_flagrf+312.712*ss_flagrf'
+LVSAT      = '-0.00073522225+dlvsatnrf+1.87198e-05*ff_flagrf-2.99517e-05*ss_flagrf'
+WVSAT      = '0.013868259+dwvsatnrf+0.00195836*ff_flagrf-0.00313337*ss_flagrf'
+PVSAT      = '-1.6704557e-009+dpvsatnrf-1.87572e-10*ff_flagrf+3.00116e-10*ss_flagrf'
+A0         = '0.71811517-0.157167*ff_flagrf'
+LA0        = '-2.3073092e-007+dla0nrf+2.80797e-08*ff_flagrf'
+WA0        = '4.6955716e-007+1.57482e-06*ff_flagrf'
+PA0        = '-7.5179779e-014-2.81358e-13*ff_flagrf'
+AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2nrf'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf'
+RDW        = '65+drdswnrf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxnrf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf'
+CGDO       = 'cgonrf'              CGBO       = 0                   CGDL       = 'cglnrf'
+CGSL       = 'cglnrf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf'
+WNFACTOR   = '0+dwnfactornrf'      PNFACTOR   = '0+dpnfactornrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+WMIN       = '1e-006-(dxwnrf+dwmisnrf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41095635+(dvthnrf+vthmisnrf)'  LVTH0      = '4.4351783e-010+dlvthnrf'
+WVTH0      = '-9.3492206e-009+dwvthnrf'
+PVTH0      = '9.0806281e-016+dpvthnrf'
+K1         = 0.31994             K2         = '0.0013060071+dk2nrf' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 9.8452363e-005      LCIT       = '1.9928338e-010+dlcitnrf'
+WCIT       = '-1.6453517e-009+dwcitnrf'
+PCIT       = 1.1079017e-016      VOFF       = -0.13957401         LVOFF      = '-3.8809298e-009+dlvoffnrf'
+WVOFF      = '2.9811114e-008+dwvoffnrf'
+PVOFF      = '-1.576216e-015+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf-0.357015*ss_flagrf+0.357015*ff_flagrf'
+ETA0       = '0.00035892377+deta0nrf-0.00181714*ff_flagrf'
+LETA0      = '9.7614105e-009+dleta0nrf+1.74047e-10*ff_flagrf'
+WETA0      = '1.4881786e-009+dweta0nrf+1.82078e-08*ff_flagrf'
+PETA0      = '-1.3415478e-015+dpeta0nrf-1.74395e-15*ff_flagrf'
+ETAB       = -0.081412532        LETAB      = -1.9907778e-010     WETAB      = -4.2459433e-008
+PETAB      = 1.9947594e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0nrf'   LU0        = '4.5926676e-011+dlu0nrf'
+WU0        = '-4.2433976e-009+dwu0nrf'
+PU0        = '2.4763426e-016+dpu0nrf'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024      UB         = 1.7366172e-018      LUB        = 9.8246845e-028
+WUB        = -1.7615195e-025     PUB        = -8.5364064e-033     UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '84649.699+dvsatnrf+1470.82*ff_flagrf'
+LVSAT      = '0.00071705169+dlvsatnrf-0.000140875*ff_flagrf'
+WVSAT      = '0.0039042958+dwvsatnrf-0.00509818*ff_flagrf'
+PVSAT      = '-7.1609734e-010+dpvsatnrf+4.88305e-10*ff_flagrf'
+A0         = '1.6696481+0.354057*ff_flagrf'
+LA0        = '-3.2186969e-007+dla0nrf-2.08856e-08*ff_flagrf'
+WA0        = '-2.4506944e-006-3.54765e-06*ff_flagrf'
+PA0        = '2.0452483e-013+2.09274e-13*ff_flagrf'
+AGS        = '3.3966895+1.45371*ss_flagrf'
+Pags     = '0+1.39516e-12*ss_flagrf'
+Wags     = '0-1.45662e-05*ss_flagrf'
+LAGS       = '1.5356668e-007-1.39237e-07*ss_flagrf'
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxnrf'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf'              CGDO       = 'cgonrf'
+CGBO       = 0                   CGDL       = 'cglnrf'              CGSL       = 'cglnrf'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.097099973        LKT2       = 3.1797651e-009      WKT2       = 1.7596724e-008
+PKT2       = -1.2711311e-015     UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf+3.4195e-08*ss_flagrf-3.4195e-08*ff_flagrf'
+WNFACTOR   = '0+dwnfactornrf+3.64155e-07*ss_flagrf-3.64155e-07*ff_flagrf'
+PNFACTOR   = '0+dpnfactornrf-3.48789e-14*ss_flagrf+3.48789e-14*ff_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf+dwmisnrf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthnrf+vthmisnrf)'  LVTH0      = '-2.4452732e-009+dlvthnrf'
+WVTH0      = '-2.656096e-009+dwvthnrf'
+PVTH0      = '-2.3254991e-016+dpvthnrf'
+K1         = 0.31994             K2         = '-0.0077298678+dk2nrf'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitnrf'
+WCIT       = '4.0796102e-010+dwcitnrf'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffnrf'
+WVOFF      = '-1.6424805e-008+dwvoffnrf'
+PVOFF      = '8.6103596e-016+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf'    ETA0       = '0.044118879+deta0nrf'
+LETA0      = '3.7906852e-009+dleta0nrf'
+WETA0      = '3.0967637e-008+dweta0nrf'
+PETA0      = '-2.3501797e-015+dpeta0nrf'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0nrf'  LU0        = '-6.7466293e-010+dlu0nrf'
+WU0        = '-7.6703892e-009+dwu0nrf'
+PU0        = '6.2413382e-016+dpu0nrf'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatnrf+4397.51*ff_flagrf-7036.02*ss_flagrf'
+LVSAT      = '-0.0010680136+dlvsatnrf-0.000421195*ff_flagrf+0.000673912*ss_flagrf'
+WVSAT      = '0.0069449685+dwvsatnrf-0.00272646*ff_flagrf+0.00436233*ss_flagrf'
+PVSAT      = '-1.3310085e-009+dpvsatnrf+2.61141e-10*ff_flagrf-4.17826e-10*ss_flagrf'
+A0         = '2.0693451+3.53626*ff_flagrf'
+LA0        = '-7.0903035e-007+dla0nrf-6.31793e-07*ff_flagrf'
+WA0        = '-9.0869732e-007-2.19248e-06*ff_flagrf'
+PA0        = '4.1268564e-013+3.91711e-13*ff_flagrf'
+AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf'              CGDO       = 'cgonrf'              CGBO       = 0
+CGDL       = 'cglnrf'              CGSL       = 'cglnrf'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 0
+CJD        = 0			MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf'      WNFACTOR   = '0+dwnfactornrf'      PNFACTOR   = '0+dpnfactornrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf+dlmisnrf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf+dwmisnrf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf+toxmisnrf)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf+dlmisnrf)'       XW         = '2.0e-08+(dxwnrf+dwmisnrf)'      DLC        = '-5.415E-09+ddlcnrf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.4204795+(dvthnrf+vthmisnrf)-0.00994084*ff_flagrf'
+LVTH0      = '2.1124771e-011+dlvthnrf+9.52137e-10*ff_flagrf'
+WVTH0      = '-1.9062833e-008+dwvthnrf+1.01397e-08*ff_flagrf'
+PVTH0      = '1.3389037e-015+dpvthnrf-9.7118e-16*ff_flagrf'
+K1         = 0.31994             K2         = '-0.014947392+dk2nrf' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitnrf'
+WCIT       = '-4.2348127e-010+dwcitnrf'
+PCIT       = 6.2821635e-017      VOFF       = -0.10368237         LVOFF      = '-5.3664414e-009+dlvoffnrf'
+WVOFF      = '-6.7983641e-009+dwvoffnrf'
+PVOFF      = '-6.0994162e-017+dpvoffnrf'
+NFACTOR    = '0.75+dnfactornrf-0.745563*ss_flagrf'
+ETA0       = '-0.051871703+deta0nrf+0.0408857*ff_flagrf'
+LETA0      = '1.2984759e-008+dleta0nrf-3.91605e-09*ff_flagrf'
+WETA0      = '5.4763418e-008+dweta0nrf-2.53491e-08*ff_flagrf'
+PETA0      = '-4.6293634e-015+dpeta0nrf+2.42795e-15*ff_flagrf'
+ETAB       = -0.16081204         LETAB      = 4.4792501e-009      WETAB      = 3.8528064e-008
+PETAB      = -2.7771351e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0nrf'  LU0        = '1.4350807e-010+dlu0nrf'
+WU0        = '-2.7003787e-009+dwu0nrf'
+PU0        = '1.4810125e-016+dpu0nrf'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023      UB         = 9.4237903e-019      LUB        = 5.867745e-026
+WUB        = 6.3397101e-025      PUB        = -6.7385287e-032     UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatnrf-11977.1*ff_flagrf'
+LVSAT      = '-0.00026235326+dlvsatnrf+0.00114717*ff_flagrf'
+WVSAT      = '-0.0099049722+dwvsatnrf+0.00861872*ff_flagrf'
+PVSAT      = '2.8289571e-010+dpvsatnrf-8.25503e-10*ff_flagrf'
+A0         = '-8.937762-7.96629*ff_flagrf'
+LA0        = '3.4524137e-007+dla0nrf+4.69926e-07*ff_flagrf'
+WA0        = '8.3688639e-006+4.9391e-06*ff_flagrf'
+PA0        = '-4.7592845e-013-2.91354e-13*ff_flagrf'
+AGS        = '6.4966895-32.7086*ss_flagrf'
+LAGS       = '1.5356668e-007+3.13284e-06*ss_flagrf'
+WAGS       = '-3.162e-006+2.02793e-05*ss_flagrf'
+PAGS       = '-1.6753592e-027-1.94236e-12*ss_flagrf'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf'         RDW        = '65+drdswnrf'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf'              CGDO       = 'cgonrf'              CGBO       = 0
+CGDL       = 'cglnrf'              CGSL       = 'cglnrf'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0                   KT2        = -0.10354588
+LKT2       = 3.8169646e-009      WKT2       = 2.4171549e-008      PKT2       = -1.9210747e-015
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianrf'
+NOIB       = 'noibnrf'
+NOIC       = 'noicnrf'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 0			CJD        = 0			MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 0			CJSWD      = 0			MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 0			CJSWGD     = 0			MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf+7.14103e-08*ss_flagrf'
+WNFACTOR   = '0+dwnfactornrf+7.60474e-07*ss_flagrf'
+PNFACTOR   = '0+dpnfactornrf-7.28385e-14*ss_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL ndio_rf_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswnrf'
+AREA   = 3.08E-8                 MJSW   = 0.005                   TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 0.0004                  FCS    = 0			   )

.MODEL ndio_rf_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgnrf'
+AREA   = 3.08E-8                 MJSW   = 0.52                    TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0015                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 2.4e-05                 FCS    = 0			   )

.MODEL PWDNW_nrf D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf'
+ N      = '1.02*n_d_dnw_nrf'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf)'  CJ     = '7.31E-04*cj_d_dnw_nrf'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf'
+ N      = '1.02*n_d_dnw_nrf'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf)'  CJ     = '1.15E-04*cj_d_dnw_nrf' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_6t



.subckt pmos_rf_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parp1rf  temp2=parp2rf
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf='0.00253346*geo_fac*toxprf*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mc*par1fn_mc+noiseflagprf_mc_mis*par2fprf_mc'
.param c1fprf=9.50E+41           c2fprf=1.55E+24           c3fprf=1.00E+10      
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf='c1fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noibprf='c2fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noicprf='c3fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf+vthmisprf)' LVTH0      = '3.2178643e-009+dlvthprf'
+WVTH0      = '1.3206912e-008+dwvthprf'
+PVTH0      = '-8.8880115e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.027489247+dk2prf'  LK2        = '7.5980421e-010+dlk2prf'
+WK2        = '-8.0262273e-009+dwk2prf'
+PK2        = '1.0831329e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf'
+WCIT       = '-9.439202e-010+dwcitprf'
+PCIT       = '7.5195034e-017+dpcitprf'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf'
+WVOFF      = '-5.7821145e-009+dwvoffprf'
+PVOFF      = '1.283818e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.15306049+deta0prf' LETA0      = '-4.6449316e-013+dleta0prf'
+WETA0      = '-4.8996634e-009+dweta0prf'
+PETA0      = '1.2028151e-018+dpeta0prf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf'  LU0        = '1.3663252e-012+dlu0prf'
+WU0        = '8.2210644e-011+dwu0prf'
+PU0        = '-1.3690578e-017+dpu0prf'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf'  LVSAT      = '0.0017671522+dlvsatprf'
+WVSAT      = '0.0019549554+dwvsatprf'
+PVSAT      = '-4.4983329e-010+dpvsatprf'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf'
+LAT        = '-0.036846346+dlatprf'
+WAT        = '-0.32267684+dwatprf'
+PAT        = '3.5967105e-08+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf'
+WNFACTOR   = '0+dwnfactorprf'      PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+(dvthprf+vthmisprf)' LVTH0      = '-3.4158001e-009+dlvthprf'
+WVTH0      = '-1.3529255e-008+dwvthprf'
+PVTH0      = '1.7447113e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.03417205+dk2prf'   LK2        = '1.0154813e-010+dlk2prf'
+WK2        = '-1.8062006e-008+dwk2prf'
+PK2        = '1.0968375e-015+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitprf'
+WCIT       = '-9.8077622e-010+dwcitprf'
+PCIT       = '7.8825353e-017+dpcitprf'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffprf'
+WVOFF      = '-1.7801351e-008+dwvoffprf'
+PVOFF      = '2.4677127e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.756116*ff_flagrf-0.661602*ss_flagrf+0.378058*sf_flagrf-0.604893*fs_flagrf'
+ETA0       = '0.14447861+deta0prf-0.0378058*ss_flagrf'
+LETA0      = '8.4485e-010+dleta0prf+3.72386e-09*ss_flagrf'
+WETA0      = '-7.6134723e-009+dweta0prf+3.85619e-08*ss_flagrf'
+PETA0      = '2.6851299e-016+dpeta0prf-3.79834e-15*ss_flagrf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf-1.92425e-05*ff_flagrf-0.000320331*ss_flagrf+0.0*sf_flagrf+1.5394e-05*fs_flagrf'
+LU0        = '4.0694732e-012+dlu0prf+1.89538e-12*ff_flagrf+3.15525e-11*ss_flagrf+0.0*sf_flagrf-1.5163e-12*fs_flagrf'
+WU0        = '-1.5318415e-010+dwu0prf+1.9281e-10*ff_flagrf-1.9281e-10*ss_flagrf+0.0*sf_flagrf-1.54248e-10*fs_flagrf'
+PU0        = '9.495809e-018+dpu0prf-1.89917e-17*ff_flagrf+1.89917e-17*ss_flagrf+0.0*sf_flagrf+1.51934e-17*fs_flagrf'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatprf+5670.87*ff_flagrf-8489.34*ss_flagrf+4536.7*sf_flagrf-4536.7*fs_flagrf'
+LVSAT      = '0.00035562736+dlvsatprf-0.000558579*ff_flagrf+0.000836197*ss_flagrf-0.000446864*sf_flagrf+0.000446864*fs_flagrf'
+WVSAT      = '0.0010707586+dwvsatprf-0.00578429*ff_flagrf-4.8e-09*ss_flagrf-0.00462743*sf_flagrf+0.00462743*fs_flagrf'
+PVSAT      = '-3.6273991e-010+dpvsatprf+5.69751e-10*ff_flagrf-2e-17*ss_flagrf+4.55801e-10*sf_flagrf-4.55801e-10*fs_flagrf'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flagrf-0.547845*ss_flagrf+0.45367*sf_flagrf-0.450591*fs_flagrf'
+LPCLM      = '3.5007467e-009+dlpclmprf-5.54788e-08*ff_flagrf+5.39625e-08*ss_flagrf-4.46864e-08*sf_flagrf+4.43831e-08*fs_flagrf'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flagrf+3.85619e-07*ss_flagrf-4.62743e-07*sf_flagrf+4.31893e-07*fs_flagrf'
+PPCLM      = '-3.439044e-015+dppclmprf+5.31768e-14*ff_flagrf-3.79834e-14*ss_flagrf+4.55801e-14*sf_flagrf-4.25414e-14*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf'
+LAT        = '0.0065683527+dlatprf'
+WAT        = '0.09819304+dwatprf'
+PAT        = '-5.4885776e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf-7.44773e-08*ff_flagrf+6.51676e-08*ss_flagrf-3.72386e-08*sf_flagrf+5.95818e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-7.71239e-07*ff_flagrf+6.74834e-07*ss_flagrf-3.85619e-07*sf_flagrf+6.16991e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+7.59668e-14*ff_flagrf-6.64709e-14*ss_flagrf+3.79834e-14*sf_flagrf-6.07734e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf+vthmisprf)' LVTH0      = '1.8657789e-009+dlvthprf'
+WVTH0      = '2.5644645e-010+dwvthprf'
+PVTH0      = '4.9032594e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.021012137+dk2prf'  LK2        = '8.7204533e-010+dlk2prf'
+WK2        = '-1.4195742e-009+dwk2prf'
+PK2        = '-6.1726576e-018+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf'
+WCIT       = '1.6122937e-009+dwcitprf'
+PCIT       = '-1.9902291e-016+dpcitprf'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf'
+WVOFF      = '-2.10792e-009+dwvoffprf'
+PVOFF      = '4.8255944e-016+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.14756059+deta0prf' LETA0      = '-1.9572049e-010+dleta0prf'
+WETA0      = '7.102273e-010+dweta0prf'
+PETA0      = '2.0036393e-016+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf'  LU0        = '-1.2055811e-011+dlu0prf'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf'  LVSAT      = '0.0033816548+dlvsatprf'
+WVSAT      = '0.0091118432+dwvsatprf'
+PVSAT      = '-2.096626e-009+dpvsatprf'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf'
+LAT        = '-0.010714171+dlatprf'
+WAT        = '-0.11098338+dwatprf'
+PAT        = '9.3122869e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf'
+PU0        = '0+dpu0prf'           LNFACTOR   = '0+dlnfactorprf'      WNFACTOR   = '0+dwnfactorprf'
+PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+(dvthprf+vthmisprf)'  LVTH0      = '1.2618987e-009+dlvthprf'
+WVTH0      = '3.5960684e-008+dwvthprf'
+PVTH0      = '-3.0265415e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.022738541+dk2prf'  LK2        = '7.0199448e-010+dlk2prf'
+WK2        = '-6.399827e-009+dwk2prf'
+PK2        = '4.8438224e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitprf'
+WCIT       = '3.1067772e-010+dwcitprf'
+PCIT       = '-7.0813731e-017+dpcitprf'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffprf'
+WVOFF      = '2.1045293e-008+dwvoffprf'
+PVOFF      = '-1.798032e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.394754*ff_flagrf+0.394754*ss_flagrf+0.315803*sf_flagrf-0.315803*fs_flagrf'
+ETA0       = '0.11688678+deta0prf' LETA0      = '2.82565e-009+dleta0prf'
+WETA0      = '2.0530196e-008+dweta0prf'
+PETA0      = '-1.751903e-015+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf+0.000432956*ff_flagrf-0.00129887*ss_flagrf+0.0*sf_flagrf-0.000346365*fs_flagrf'
+LU0        = '1.337909e-011+dlu0prf-4.2646e-11*ff_flagrf+1.27938e-10*ss_flagrf+0.0*sf_flagrf+3.41168e-11*fs_flagrf'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatprf+2631.69*ff_flagrf-21647.8*ss_flagrf+2105.35*sf_flagrf-2105.35*fs_flagrf'
+LVSAT      = '-0.00025921987+dlvsatprf-0.000259221*ff_flagrf+0.0021323*ss_flagrf-0.000207377*sf_flagrf+0.000207377*fs_flagrf'
+WVSAT      = '-0.014858007+dwvsatprf-0.00268433*ff_flagrf+0.0134216*ss_flagrf-0.00214746*sf_flagrf+0.00214746*fs_flagrf'
+PVSAT      = '2.6440426e-010+dpvsatprf+2.64405e-10*ff_flagrf-1.32203e-09*ss_flagrf+2.11524e-10*sf_flagrf-2.11524e-10*fs_flagrf'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flagrf-0.432956*ss_flagrf+0.0*sf_flagrf-0.0692729*fs_flagrf'
+LPCLM      = '-7.7061899e-009+dlpclmprf-8.52921e-09*ff_flagrf+4.2646e-08*ss_flagrf+0.0*sf_flagrf+6.82337e-09*fs_flagrf'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flagrf+2.68433e-07*ss_flagrf+0.0*sf_flagrf+4.29492e-08*fs_flagrf'
+PPCLM      = '7.9920313e-015+dppclmprf+5.28811e-15*ff_flagrf-2.64405e-14*ss_flagrf+0.0*sf_flagrf-4.23049e-15*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf'
+LAT        = '-0.0064077479+dlatprf'
+WAT        = '-0.095092602+dwatprf'
+PAT        = '7.7470449e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf-2.68433e-10*ff_flagrf+8.05298e-10*ss_flagrf+0.0*sf_flagrf+2.14746e-10*fs_flagrf'
+PU0        = '0+dpu0prf+2.64405e-17*ff_flagrf-7.93216e-17*ss_flagrf+0.0*sf_flagrf-2.11524e-17*fs_flagrf'
+LNFACTOR   = '0+dlnfactorprf-3.88831e-08*ff_flagrf-3.88831e-08*ss_flagrf-3.11065e-08*sf_flagrf+3.11065e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-4.02649e-07*ff_flagrf-4.02649e-07*ss_flagrf-3.22119e-07*sf_flagrf+3.22119e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+3.96608e-14*ff_flagrf+3.96608e-14*ss_flagrf+3.17286e-14*sf_flagrf-3.17286e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf'
+ N      = '1.02*n_d_dnw_prf'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf)'  CJ     = '1.15E-04*cj_d_dnw_prf' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf'
+ N      = '1.02*n_d_prf'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf)'  CJ     = '1.37E-04*cj_d_prf'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )


.ends pmos_rf_5t

.subckt pmos_rf_nw_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf'
.param
+temp1=parp1rf  temp2=parp2rf
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf='0.00253346*geo_fac*toxprf*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mc*par1fn_mc+noiseflagprf_mc_mis*par2fprf_mc'
.param c1fprf=9.50E+41           c2fprf=1.55E+24           c3fprf=1.00E+10      
.param arearatio='sigma_factor_flicker_rf*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf='c1fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noibprf='c2fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'
.param noicprf='c3fprf*2.718**((fn_dice+(1-fn_dice)*noiseflagprf)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf+vthmisprf)' LVTH0      = '3.2178643e-009+dlvthprf'
+WVTH0      = '1.3206912e-008+dwvthprf'
+PVTH0      = '-8.8880115e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.027489247+dk2prf'  LK2        = '7.5980421e-010+dlk2prf'
+WK2        = '-8.0262273e-009+dwk2prf'
+PK2        = '1.0831329e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf'
+WCIT       = '-9.439202e-010+dwcitprf'
+PCIT       = '7.5195034e-017+dpcitprf'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf'
+WVOFF      = '-5.7821145e-009+dwvoffprf'
+PVOFF      = '1.283818e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.15306049+deta0prf' LETA0      = '-4.6449316e-013+dleta0prf'
+WETA0      = '-4.8996634e-009+dweta0prf'
+PETA0      = '1.2028151e-018+dpeta0prf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf'  LU0        = '1.3663252e-012+dlu0prf'
+WU0        = '8.2210644e-011+dwu0prf'
+PU0        = '-1.3690578e-017+dpu0prf'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf'  LVSAT      = '0.0017671522+dlvsatprf'
+WVSAT      = '0.0019549554+dwvsatprf'
+PVSAT      = '-4.4983329e-010+dpvsatprf'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf'
+LAT        = '-0.036846346+dlatprf'
+WAT        = '-0.32267684+dwatprf'
+PAT        = '3.5967105e-08+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf'
+WNFACTOR   = '0+dwnfactorprf'      PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = '1e-006-(dxwprf+dwmisprf)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+(dvthprf+vthmisprf)' LVTH0      = '-3.4158001e-009+dlvthprf'
+WVTH0      = '-1.3529255e-008+dwvthprf'
+PVTH0      = '1.7447113e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.03417205+dk2prf'   LK2        = '1.0154813e-010+dlk2prf'
+WK2        = '-1.8062006e-008+dwk2prf'
+PK2        = '1.0968375e-015+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitprf'
+WCIT       = '-9.8077622e-010+dwcitprf'
+PCIT       = '7.8825353e-017+dpcitprf'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffprf'
+WVOFF      = '-1.7801351e-008+dwvoffprf'
+PVOFF      = '2.4677127e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.756116*ff_flagrf-0.661602*ss_flagrf+0.378058*sf_flagrf-0.604893*fs_flagrf'
+ETA0       = '0.14447861+deta0prf-0.0378058*ss_flagrf'
+LETA0      = '8.4485e-010+dleta0prf+3.72386e-09*ss_flagrf'
+WETA0      = '-7.6134723e-009+dweta0prf+3.85619e-08*ss_flagrf'
+PETA0      = '2.6851299e-016+dpeta0prf-3.79834e-15*ss_flagrf'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf-1.92425e-05*ff_flagrf-0.000320331*ss_flagrf+0.0*sf_flagrf+1.5394e-05*fs_flagrf'
+LU0        = '4.0694732e-012+dlu0prf+1.89538e-12*ff_flagrf+3.15525e-11*ss_flagrf+0.0*sf_flagrf-1.5163e-12*fs_flagrf'
+WU0        = '-1.5318415e-010+dwu0prf+1.9281e-10*ff_flagrf-1.9281e-10*ss_flagrf+0.0*sf_flagrf-1.54248e-10*fs_flagrf'
+PU0        = '9.495809e-018+dpu0prf-1.89917e-17*ff_flagrf+1.89917e-17*ss_flagrf+0.0*sf_flagrf+1.51934e-17*fs_flagrf'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatprf+5670.87*ff_flagrf-8489.34*ss_flagrf+4536.7*sf_flagrf-4536.7*fs_flagrf'
+LVSAT      = '0.00035562736+dlvsatprf-0.000558579*ff_flagrf+0.000836197*ss_flagrf-0.000446864*sf_flagrf+0.000446864*fs_flagrf'
+WVSAT      = '0.0010707586+dwvsatprf-0.00578429*ff_flagrf-4.8e-09*ss_flagrf-0.00462743*sf_flagrf+0.00462743*fs_flagrf'
+PVSAT      = '-3.6273991e-010+dpvsatprf+5.69751e-10*ff_flagrf-2e-17*ss_flagrf+4.55801e-10*sf_flagrf-4.55801e-10*fs_flagrf'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flagrf-0.547845*ss_flagrf+0.45367*sf_flagrf-0.450591*fs_flagrf'
+LPCLM      = '3.5007467e-009+dlpclmprf-5.54788e-08*ff_flagrf+5.39625e-08*ss_flagrf-4.46864e-08*sf_flagrf+4.43831e-08*fs_flagrf'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flagrf+3.85619e-07*ss_flagrf-4.62743e-07*sf_flagrf+4.31893e-07*fs_flagrf'
+PPCLM      = '-3.439044e-015+dppclmprf+5.31768e-14*ff_flagrf-3.79834e-14*ss_flagrf+4.55801e-14*sf_flagrf-4.25414e-14*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf'
+LAT        = '0.0065683527+dlatprf'
+WAT        = '0.09819304+dwatprf'
+PAT        = '-5.4885776e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf-7.44773e-08*ff_flagrf+6.51676e-08*ss_flagrf-3.72386e-08*sf_flagrf+5.95818e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-7.71239e-07*ff_flagrf+6.74834e-07*ss_flagrf-3.85619e-07*sf_flagrf+6.16991e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+7.59668e-14*ff_flagrf-6.64709e-14*ss_flagrf+3.79834e-14*sf_flagrf-6.07734e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf+dlmisprf)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf+vthmisprf)' LVTH0      = '1.8657789e-009+dlvthprf'
+WVTH0      = '2.5644645e-010+dwvthprf'
+PVTH0      = '4.9032594e-016+dpvthprf'
+K1         = 0.23752             K2         = '0.021012137+dk2prf'  LK2        = '8.7204533e-010+dlk2prf'
+WK2        = '-1.4195742e-009+dwk2prf'
+PK2        = '-6.1726576e-018+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf'
+WCIT       = '1.6122937e-009+dwcitprf'
+PCIT       = '-1.9902291e-016+dpcitprf'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf'
+WVOFF      = '-2.10792e-009+dwvoffprf'
+PVOFF      = '4.8255944e-016+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf'     ETA0       = '0.14756059+deta0prf' LETA0      = '-1.9572049e-010+dleta0prf'
+WETA0      = '7.102273e-010+dweta0prf'
+PETA0      = '2.0036393e-016+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf'  LU0        = '-1.2055811e-011+dlu0prf'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf'  LVSAT      = '0.0033816548+dlvsatprf'
+WVSAT      = '0.0091118432+dwvsatprf'
+PVSAT      = '-2.096626e-009+dpvsatprf'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf'
+LAT        = '-0.010714171+dlatprf'
+WAT        = '-0.11098338+dwatprf'
+PAT        = '9.3122869e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf'
+PU0        = '0+dpu0prf'           LNFACTOR   = '0+dlnfactorprf'      WNFACTOR   = '0+dwnfactorprf'
+PNFACTOR   = '0+dpnfactorprf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf+dlmisprf)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf+dwmisprf)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf+toxmisprf)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf+dlmisprf)'        XW         = '2.0e-08+(dxwprf+dwmisprf)'      DLC        = '-6.55e-09+ddlcprf'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+(dvthprf+vthmisprf)'  LVTH0      = '1.2618987e-009+dlvthprf'
+WVTH0      = '3.5960684e-008+dwvthprf'
+PVTH0      = '-3.0265415e-015+dpvthprf'
+K1         = 0.23752             K2         = '0.022738541+dk2prf'  LK2        = '7.0199448e-010+dlk2prf'
+WK2        = '-6.399827e-009+dwk2prf'
+PK2        = '4.8438224e-016+dpk2prf'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitprf'
+WCIT       = '3.1067772e-010+dwcitprf'
+PCIT       = '-7.0813731e-017+dpcitprf'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffprf'
+WVOFF      = '2.1045293e-008+dwvoffprf'
+PVOFF      = '-1.798032e-015+dpvoffprf'
+NFACTOR    = '0.7+dnfactorprf+0.394754*ff_flagrf+0.394754*ss_flagrf+0.315803*sf_flagrf-0.315803*fs_flagrf'
+ETA0       = '0.11688678+deta0prf' LETA0      = '2.82565e-009+dleta0prf'
+WETA0      = '2.0530196e-008+dweta0prf'
+PETA0      = '-1.751903e-015+dpeta0prf'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf+0.000432956*ff_flagrf-0.00129887*ss_flagrf+0.0*sf_flagrf-0.000346365*fs_flagrf'
+LU0        = '1.337909e-011+dlu0prf-4.2646e-11*ff_flagrf+1.27938e-10*ss_flagrf+0.0*sf_flagrf+3.41168e-11*fs_flagrf'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatprf+2631.69*ff_flagrf-21647.8*ss_flagrf+2105.35*sf_flagrf-2105.35*fs_flagrf'
+LVSAT      = '-0.00025921987+dlvsatprf-0.000259221*ff_flagrf+0.0021323*ss_flagrf-0.000207377*sf_flagrf+0.000207377*fs_flagrf'
+WVSAT      = '-0.014858007+dwvsatprf-0.00268433*ff_flagrf+0.0134216*ss_flagrf-0.00214746*sf_flagrf+0.00214746*fs_flagrf'
+PVSAT      = '2.6440426e-010+dpvsatprf+2.64405e-10*ff_flagrf-1.32203e-09*ss_flagrf+2.11524e-10*sf_flagrf-2.11524e-10*fs_flagrf'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flagrf-0.432956*ss_flagrf+0.0*sf_flagrf-0.0692729*fs_flagrf'
+LPCLM      = '-7.7061899e-009+dlpclmprf-8.52921e-09*ff_flagrf+4.2646e-08*ss_flagrf+0.0*sf_flagrf+6.82337e-09*fs_flagrf'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flagrf+2.68433e-07*ss_flagrf+0.0*sf_flagrf+4.29492e-08*fs_flagrf'
+PPCLM      = '7.9920313e-015+dppclmprf+5.28811e-15*ff_flagrf-2.64405e-14*ss_flagrf+0.0*sf_flagrf-4.23049e-15*fs_flagrf'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf'
+RDW        = '75+drdswprf'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf'
+CGDO       = 'cgoprf'              CGBO       = 0                   CGDL       = 'cglprf'
+CGSL       = 'cglprf'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf'
+LAT        = '-0.0064077479+dlatprf'
+WAT        = '-0.095092602+dwatprf'
+PAT        = '7.7470449e-09+dpatprf'
+NOIA       = 'noiaprf'
+NOIB       = 'noibprf'
+NOIC       = 'noicprf'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf-2.68433e-10*ff_flagrf+8.05298e-10*ss_flagrf+0.0*sf_flagrf+2.14746e-10*fs_flagrf'
+PU0        = '0+dpu0prf+2.64405e-17*ff_flagrf-7.93216e-17*ss_flagrf+0.0*sf_flagrf-2.11524e-17*fs_flagrf'
+LNFACTOR   = '0+dlnfactorprf-3.88831e-08*ff_flagrf-3.88831e-08*ss_flagrf-3.11065e-08*sf_flagrf+3.11065e-08*fs_flagrf'
+WNFACTOR   = '0+dwnfactorprf-4.02649e-07*ff_flagrf-4.02649e-07*ss_flagrf-3.22119e-07*sf_flagrf+3.22119e-07*fs_flagrf'
+PNFACTOR   = '0+dpnfactorprf+3.96608e-14*ff_flagrf+3.96608e-14*ss_flagrf+3.17286e-14*sf_flagrf-3.17286e-14*fs_flagrf'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf'                 PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf'
+ N      = '1.02*n_d_dnw_prf'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf)'  CJ     = '1.15E-04*cj_d_dnw_prf' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf'
+ N      = '1.02*n_d_prf'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf)'  CJ     = '1.37E-04*cj_d_prf'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_nw_5t


.ENDL RF_MOS






**************************************************************************************************
*
* 1.2V CORE hvt MOS MODEL
*
*
*
*              .lib RF_MOS_hvt
*
*              Model name            nr               lr (um)           wr (um)
*                                low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_hvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_hvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_hvt_nw     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              nmos_rf_hvt_6t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_hvt_5t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_hvt_nw_5t  1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************

***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+A1rf_hvt='-par1*5.4189e+000*3/2.1'
+A2rf_hvt='-par2*4.3704e+000*3/2.1'
+A3rf_hvt='-par3*3.1178e+000*3/2.1'
+A4rf_hvt='-par4*1.9530e+000*3/2.1'
+toxnrf_hvt        = '2.6000e-009+(-7.4904e-012)*A1rf_hvt+(-1.8124e-012)*A2rf_hvt+(-1.1128e-011)*A3rf_hvt+(4.5387e-012)*A4rf_hvt'
+dxlnrf_hvt        = '0.0000e+000+(-5.7247e-010)*A1rf_hvt+(-2.0717e-010)*A2rf_hvt+(-1.2667e-009)*A3rf_hvt+(5.2275e-010)*A4rf_hvt'
+dxwnrf_hvt        = 'max(-20e-9,0.0000e+000+(9.1309e-010)*A1rf_hvt+(-6.8212e-010)*A2rf_hvt+(2.4039e-009)*A3rf_hvt+(-5.4317e-010)*A4rf_hvt)'
+dvthnrf_hvt       = '0.0000e+000+(-2.1429e-003)*A1rf_hvt+(2.2248e-003)*A2rf_hvt+(4.4850e-004)*A3rf_hvt+(-1.2686e-003)*A4rf_hvt'
+dlvthnrf_hvt      = '0.0000e+000+(-9.3533e-011)*A1rf_hvt+(9.9323e-011)*A2rf_hvt+(2.0387e-011)*A3rf_hvt+(-5.2212e-011)*A4rf_hvt'
+dwvthnrf_hvt      = '0.0000e+000+(-3.9482e-010)*A1rf_hvt+(6.5874e-010)*A2rf_hvt+(1.7377e-010)*A3rf_hvt+(1.2165e-010)*A4rf_hvt'
+dpvthnrf_hvt      = '0.0000e+000+(-1.4592e-017)*A1rf_hvt+(-1.2112e-018)*A2rf_hvt+(-2.1770e-017)*A3rf_hvt+(-1.7468e-017)*A4rf_hvt'
+cjnrf_hvt         = '1.4720e-003+(-1.0768e-005)*A1rf_hvt+(1.1510e-005)*A2rf_hvt+(2.3747e-006)*A3rf_hvt+(-5.9026e-006)*A4rf_hvt'
+cjswnrf_hvt       = '9.5000e-011+(-6.9492e-013)*A1rf_hvt+(7.4282e-013)*A2rf_hvt+(1.5326e-013)*A3rf_hvt+(-3.8094e-013)*A4rf_hvt'
+cjswgnrf_hvt      = '2.5900e-010+(-1.8946e-012)*A1rf_hvt+(2.0252e-012)*A2rf_hvt+(4.1783e-013)*A3rf_hvt+(-1.0386e-012)*A4rf_hvt'
+cgonrf_hvt        = '7.8989e-011+(6.1815e-013)*A1rf_hvt+(1.4957e-013)*A2rf_hvt+(9.1836e-013)*A3rf_hvt+(-3.7456e-013)*A4rf_hvt'
+cglnrf_hvt        = '1.5523e-012+(1.2148e-014)*A1rf_hvt+(2.9393e-015)*A2rf_hvt+(1.8047e-014)*A3rf_hvt+(-7.3606e-015)*A4rf_hvt'
+dlcitnrf_hvt      = '0.0000e+000+(-6.1772e-012)*A1rf_hvt+(7.4696e-012)*A2rf_hvt+(6.0819e-012)*A3rf_hvt+(-5.5477e-012)*A4rf_hvt'
+dwcitnrf_hvt      = '0.0000e+000+(1.5548e-011)*A1rf_hvt+(-2.9770e-011)*A2rf_hvt+(-8.2456e-012)*A3rf_hvt+(-1.0259e-011)*A4rf_hvt'
+dpcitnrf_hvt      = '0.0000e+000+(-2.6527e-018)*A1rf_hvt+(4.0848e-018)*A2rf_hvt+(1.0426e-018)*A3rf_hvt+(3.3017e-019)*A4rf_hvt'
+ntoxnrf_hvt       = '1.0000e+000+(8.7883e-002)*A1rf_hvt+(2.0085e-002)*A2rf_hvt+(1.0874e-001)*A3rf_hvt+(-2.1196e-003)*A4rf_hvt'
+dlu0nrf_hvt       = '0.0000e+000+(-3.3384e-012)*A1rf_hvt+(1.4317e-012)*A2rf_hvt+(-4.6449e-014)*A3rf_hvt+(-4.8822e-012)*A4rf_hvt'
+dwu0nrf_hvt       = '0.0000e+000+(-9.5069e-012)*A1rf_hvt+(1.0425e-011)*A2rf_hvt+(2.1930e-012)*A3rf_hvt+(-4.8359e-012)*A4rf_hvt'
+dpu0nrf_hvt       = '0.0000e+000+(5.5020e-019)*A1rf_hvt+(-4.2375e-019)*A2rf_hvt+(-6.1133e-020)*A3rf_hvt+(5.3639e-019)*A4rf_hvt'
+dlvsatnrf_hvt     = '0.0000e+000+(-1.5485e-005)*A1rf_hvt+(3.6278e-005)*A2rf_hvt+(1.0640e-005)*A3rf_hvt+(1.9685e-005)*A4rf_hvt'
+dwvsatnrf_hvt     = 'max(-0.7e-3,0.0000e+000+(-1.1508e-004)*A1rf_hvt+(1.0986e-004)*A2rf_hvt+(2.0562e-005)*A3rf_hvt+(-8.1865e-005)*A4rf_hvt)'
+dpvsatnrf_hvt     = '0.0000e+000+(-3.2131e-013)*A1rf_hvt+(-5.9028e-012)*A2rf_hvt+(-2.2170e-012)*A3rf_hvt+(-9.0979e-012)*A4rf_hvt'
+deta0nrf_hvt      = '0.0000e+000+(-3.7017e-004)*A1rf_hvt+(-6.4558e-005)*A2rf_hvt+(-8.6943e-005)*A3rf_hvt+(-8.6031e-004)*A4rf_hvt'
+dleta0nrf_hvt     = '0.0000e+000+(-4.6456e-011)*A1rf_hvt+(1.0883e-010)*A2rf_hvt+(3.1920e-011)*A3rf_hvt+(5.9055e-011)*A4rf_hvt'
+dweta0nrf_hvt     = '0.0000e+000+(4.1294e-011)*A1rf_hvt+(-9.6740e-011)*A2rf_hvt+(-2.8373e-011)*A3rf_hvt+(-5.2494e-011)*A4rf_hvt'
+dpeta0nrf_hvt     = '0.0000e+000+(2.5809e-018)*A1rf_hvt+(-6.0463e-018)*A2rf_hvt+(-1.7733e-018)*A3rf_hvt+(-3.2808e-018)*A4rf_hvt'
+dk2nrf_hvt        = '0.0000e+000+(-3.1350e-004)*A1rf_hvt+(3.3511e-004)*A2rf_hvt+(6.9138e-005)*A3rf_hvt+(-1.7185e-004)*A4rf_hvt'
+dwk2nrf_hvt       = '0.0000e+000+(-3.6511e-010)*A1rf_hvt+(4.5603e-010)*A2rf_hvt+(1.0461e-010)*A3rf_hvt+(-1.0624e-010)*A4rf_hvt'
+dpclmnrf_hvt      = '0.0000e+000+(1.0323e-003)*A1rf_hvt+(-2.4185e-003)*A2rf_hvt+(-7.0933e-004)*A3rf_hvt+(-1.3123e-003)*A4rf_hvt'
+da0nrf_hvt        = '0.0000e+000+(3.2235e-003)*A1rf_hvt+(5.7593e-003)*A2rf_hvt+(2.6607e-003)*A3rf_hvt+(1.4915e-002)*A4rf_hvt'
+dla0nrf_hvt       = '0.0000e+000+(-1.6518e-009)*A1rf_hvt+(3.8696e-009)*A2rf_hvt+(1.1349e-009)*A3rf_hvt+(2.0997e-009)*A4rf_hvt'
+dwa0nrf_hvt       = '0.0000e+000+(5.1617e-009)*A1rf_hvt+(-1.2093e-008)*A2rf_hvt+(-3.5467e-009)*A3rf_hvt+(-6.5617e-009)*A4rf_hvt'
+cfnrf_hvt         = '1.2000e-010+(9.3910e-013)*A1rf_hvt+(2.2723e-013)*A2rf_hvt+(1.3952e-012)*A3rf_hvt+(-5.6903e-013)*A4rf_hvt+5e-11'
+ss_flagrf_hvt     = '0.0000e+000+(-5.2882e-002)*A1rf_hvt+(-9.2226e-003)*A2rf_hvt+(-1.2420e-002)*A3rf_hvt+(-1.2290e-001)*A4rf_hvt'
+ff_flagrf_hvt     = 'max(-0.4,0.0000e+000+(5.3522e-002)*A1rf_hvt+(-1.0937e-002)*A2rf_hvt+(-2.0828e-002)*A3rf_hvt+(-1.1703e-001)*A4rf_hvt)'
+toxprf_hvt        = '2.8000e-009+(-7.4904e-012)*A1rf_hvt+(-1.8124e-012)*A2rf_hvt+(-1.1128e-011)*A3rf_hvt+(4.5387e-012)*A4rf_hvt'
+dxlprf_hvt        = '0.0000e+000+(-5.4550e-010)*A1rf_hvt+(-6.3340e-011)*A2rf_hvt+(-3.9422e-010)*A3rf_hvt+(1.5466e-010)*A4rf_hvt'
+dxwprf_hvt        = 'max(-22e-9,0.0000e+000+(9.1882e-010)*A1rf_hvt+(1.3451e-009)*A2rf_hvt+(1.6496e-009)*A3rf_hvt+(-1.1296e-009)*A4rf_hvt)'
+dvthprf_hvt       = '0.0000e+000+(2.1122e-003)*A1rf_hvt+(1.8778e-003)*A2rf_hvt+(-1.6204e-003)*A3rf_hvt+(-1.7446e-004)*A4rf_hvt'
+dlvthprf_hvt      = '0.0000e+000+(9.5050e-011)*A1rf_hvt+(8.4501e-011)*A2rf_hvt+(-7.2917e-011)*A3rf_hvt+(-7.8507e-012)*A4rf_hvt'
+dwvthprf_hvt      = '0.0000e+000+(2.2184e-010)*A1rf_hvt+(1.6699e-010)*A2rf_hvt+(-1.2779e-010)*A3rf_hvt+(8.3492e-011)*A4rf_hvt'
+dpvthprf_hvt      = '0.0000e+000+(2.9039e-017)*A1rf_hvt+(2.7706e-017)*A2rf_hvt+(-2.4927e-017)*A3rf_hvt+(-8.7620e-018)*A4rf_hvt'
+cjprf_hvt         = '1.0910e-003+(-8.0655e-006)*A1rf_hvt+(-7.1704e-006)*A2rf_hvt+(6.1874e-006)*A3rf_hvt+(6.6618e-007)*A4rf_hvt'
+cjswprf_hvt       = '6.4000e-011+(-4.7314e-013)*A1rf_hvt+(-4.2063e-013)*A2rf_hvt+(3.6296e-013)*A3rf_hvt+(3.9079e-014)*A4rf_hvt'
+cjswgprf_hvt      = '2.9000e-010+(-2.1439e-012)*A1rf_hvt+(-1.9060e-012)*A2rf_hvt+(1.6447e-012)*A3rf_hvt+(1.7708e-013)*A4rf_hvt'
+cgoprf_hvt        = '4.7923e-011+(3.7504e-013)*A1rf_hvt+(9.0744e-014)*A2rf_hvt+(5.5718e-013)*A3rf_hvt+(-2.2725e-013)*A4rf_hvt'
+cglprf_hvt        = '5.2044e-011+(4.0729e-013)*A1rf_hvt+(9.8549e-014)*A2rf_hvt+(6.0510e-013)*A3rf_hvt+(-2.4679e-013)*A4rf_hvt'
+dlcitprf_hvt      = '0.0000e+000+(-5.5921e-012)*A1rf_hvt+(-4.3906e-012)*A2rf_hvt+(1.1965e-011)*A3rf_hvt+(-1.1923e-012)*A4rf_hvt'
+dwcitprf_hvt      = '0.0000e+000+(2.3744e-012)*A1rf_hvt+(3.0556e-012)*A2rf_hvt+(-3.1462e-012)*A3rf_hvt+(-3.3779e-012)*A4rf_hvt'
+dpcitprf_hvt      = '0.0000e+000+(-6.3367e-019)*A1rf_hvt+(-5.6334e-019)*A2rf_hvt+(4.8611e-019)*A3rf_hvt+(5.2338e-020)*A4rf_hvt'
+ntoxprf_hvt       = '1.0000e+000+(2.1738e-001)*A1rf_hvt+(4.7881e-002)*A2rf_hvt+(2.3564e-001)*A3rf_hvt+(7.2812e-002)*A4rf_hvt'
+dlu0prf_hvt       = '0.0000e+000+(-4.3163e-012)*A1rf_hvt+(-2.8812e-012)*A2rf_hvt+(8.7626e-012)*A3rf_hvt+(-2.6214e-012)*A4rf_hvt'
+dwu0prf_hvt       = '0.0000e+000+(2.1122e-012)*A1rf_hvt+(1.8778e-012)*A2rf_hvt+(-1.6204e-012)*A3rf_hvt+(-1.7446e-013)*A4rf_hvt'
+dpu0prf_hvt       = '0.0000e+000+(1.1603e-018)*A1rf_hvt+(1.4506e-018)*A2rf_hvt+(5.5986e-019)*A3rf_hvt+(-1.4346e-018)*A4rf_hvt'
+dlvsatprf_hvt     = '0.0000e+000+(-1.0035e-004)*A1rf_hvt+(-7.7879e-005)*A2rf_hvt+(6.1089e-005)*A3rf_hvt+(-2.9892e-005)*A4rf_hvt'
+dpvsatprf_hvt     = '0.0000e+000+(4.7457e-013)*A1rf_hvt+(7.6201e-013)*A2rf_hvt+(-8.4095e-013)*A3rf_hvt+(-1.1846e-012)*A4rf_hvt'
+dk2prf_hvt        = '0.0000e+000+(-3.1683e-004)*A1rf_hvt+(-2.8167e-004)*A2rf_hvt+(2.4306e-004)*A3rf_hvt+(2.6169e-005)*A4rf_hvt'
+dwk2prf_hvt       = '0.0000e+000+(-3.6956e-010)*A1rf_hvt+(-3.6634e-010)*A2rf_hvt+(3.3649e-010)*A3rf_hvt+(1.5779e-010)*A4rf_hvt'
+dla0prf_hvt       = '0.0000e+000+(-5.2806e-009)*A1rf_hvt+(-4.6945e-009)*A2rf_hvt+(4.0509e-009)*A3rf_hvt+(4.3615e-010)*A4rf_hvt'
+dlubprf_hvt       = '0.0000e+000+(8.9793e-028)*A1rf_hvt+(6.8490e-028)*A2rf_hvt+(-5.2987e-028)*A3rf_hvt+(3.0764e-028)*A4rf_hvt'
+dpubprf_hvt       = '0.0000e+000+(6.3276e-035)*A1rf_hvt+(1.0160e-034)*A2rf_hvt+(-1.1213e-034)*A3rf_hvt+(-1.5795e-034)*A4rf_hvt'
+cfprf_hvt         = '1.2000e-010+(9.3910e-013)*A1rf_hvt+(2.2723e-013)*A2rf_hvt+(1.3952e-012)*A3rf_hvt+(-5.6903e-013)*A4rf_hvt+5e-11'
+ddlcnrf_hvt       = '6.6302e-009'
+dcitnrf_hvt       = '0.0000e+000'
+dnfactornrf_hvt   = '0.0000e+000'
+dlnfactornrf_hvt  = '0.0000e+000'
+dwnfactornrf_hvt  = '0.0000e+000'
+dpnfactornrf_hvt  = '0.0000e+000'
+du0nrf_hvt        = '0.0000e+000'
+dvsatnrf_hvt      = '0.0000e+000'
+dlk2nrf_hvt       = '0.0000e+000'
+dpk2nrf_hvt       = '0.0000e+000'
+drdswnrf_hvt      = '0.0000e+000'
+dpdiblc2nrf_hvt   = '0.0000e+000'
+dlpdiblc2nrf_hvt  = '0.0000e+000'
+dpa0nrf_hvt       = '0.0000e+000'
+dvoffnrf_hvt      = '0.0000e+000'
+dlvoffnrf_hvt     = '0.0000e+000'
+dwvoffnrf_hvt     = '0.0000e+000'
+dpvoffnrf_hvt     = '0.0000e+000'
+datnrf_hvt        = '0.0000e+000'
+sf_flagrf_hvt     = '0.0000e+000'
+fs_flagrf_hvt     = '0.0000e+000'
+ddlcprf_hvt       = '7.3569e-009'
+dcitprf_hvt       = '0.0000e+000'
+dnfactorprf_hvt   = '0.0000e+000'
+dlnfactorprf_hvt  = '0.0000e+000'
+dwnfactorprf_hvt  = '0.0000e+000'
+dpnfactorprf_hvt  = '0.0000e+000'
+du0prf_hvt        = '0.0000e+000'
+dvsatprf_hvt      = '0.0000e+000'
+dwvsatprf_hvt     = '0.0000e+000'
+deta0prf_hvt      = '0.0000e+000'
+dleta0prf_hvt     = '0.0000e+000'
+dweta0prf_hvt     = '0.0000e+000'
+dpeta0prf_hvt     = '0.0000e+000'
+dlk2prf_hvt       = '0.0000e+000'
+dpk2prf_hvt       = '0.0000e+000'
+drdswprf_hvt      = '0.0000e+000'
+dpclmprf_hvt      = '0.0000e+000'
+dlpclmprf_hvt     = '0.0000e+000'
+dwpclmprf_hvt     = '0.0000e+000'
+dppclmprf_hvt     = '0.0000e+000'
+dpdiblc2prf_hvt   = '0.0000e+000'
+da0prf_hvt        = '0.0000e+000'
+dwa0prf_hvt       = '0.0000e+000'
+dpa0prf_hvt       = '0.0000e+000'
+dvoffprf_hvt      = '0.0000e+000'
+dlvoffprf_hvt     = '0.0000e+000'
+dwvoffprf_hvt     = '0.0000e+000'
+dpvoffprf_hvt     = '0.0000e+000'
+datprf_hvt        = '0.0000e+000'
+dubprf_hvt        = '0.0000e+000'
+dwubprf_hvt       = '0.0000e+000'
+is_d_dnw_nrf_hvt= 1         x_jsw_d_dnw_nrf_hvt= 0         n_d_dnw_nrf_hvt= 1         rs_d_dnw_nrf_hvt= 1
+cj_d_dnw_nrf_hvt= 1          cjsw_d_dnw_nrf_hvt= 1
+is_d_dnw_prf_hvt= 1         x_jsw_d_dnw_prf_hvt= 0         n_d_dnw_prf_hvt= 1         rs_d_dnw_prf_hvt= 1
+cj_d_dnw_prf_hvt= 1          cjsw_d_dnw_prf_hvt= 1
+is_d_prf_hvt= 1                 x_jsw_d_prf_hvt= 0             n_d_prf_hvt= 1             rs_d_prf_hvt= 1
+cj_d_prf_hvt= 1                  cjsw_d_prf_hvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL mc_RFMOS_hvt








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+toxnrf_hvt       = 2.6e-09       dxlnrf_hvt       = 0             dxwnrf_hvt       = 0
+dvthnrf_hvt      = 0             dlvthnrf_hvt     = 0             dwvthnrf_hvt     = 0
+dpvthnrf_hvt     = 0             cjnrf_hvt        = 0.001472      cjswnrf_hvt      = 9.5e-11
+cjswgnrf_hvt     = 2.59e-10      cgonrf_hvt       = 7.89886e-11   cglnrf_hvt       = 1.55225e-12
+ddlcnrf_hvt      = 6.6302e-09    dcitnrf_hvt      = 0             dlcitnrf_hvt     = 0
+dwcitnrf_hvt     = 0             dpcitnrf_hvt     = 0             ntoxnrf_hvt      = 1
+dnfactornrf_hvt  = 0             dlnfactornrf_hvt = 0             dwnfactornrf_hvt = 0
+dpnfactornrf_hvt = 0             du0nrf_hvt       = 0             dlu0nrf_hvt      = 0
+dwu0nrf_hvt      = 0             dpu0nrf_hvt      = 0             dvsatnrf_hvt     = 0
+dlvsatnrf_hvt    = 0             dwvsatnrf_hvt    = 0             dpvsatnrf_hvt    = 0
+deta0nrf_hvt     = 0             dleta0nrf_hvt    = 0             dweta0nrf_hvt    = 0
+dpeta0nrf_hvt    = 0             dk2nrf_hvt       = 0             dlk2nrf_hvt      = 0
+dwk2nrf_hvt      = 0             dpk2nrf_hvt      = 0             drdswnrf_hvt     = 0
+dpclmnrf_hvt     = 0             dpdiblc2nrf_hvt  = 0             dlpdiblc2nrf_hvt = 0
+da0nrf_hvt       = 0             dla0nrf_hvt      = 0             dwa0nrf_hvt      = 0
+dpa0nrf_hvt      = 0             dvoffnrf_hvt     = 0             dlvoffnrf_hvt    = 0
+dwvoffnrf_hvt    = 0             dpvoffnrf_hvt    = 0             datnrf_hvt       = 0
+cfnrf_hvt        = '1.20e-10 + 5.4e-11' ss_flagrf_hvt    = 0             ff_flagrf_hvt    = 0
+sf_flagrf_hvt    = 0             fs_flagrf_hvt    = 0
+toxprf_hvt       = 2.8e-09       dxlprf_hvt       = 0             dxwprf_hvt       = 0
+dvthprf_hvt      = 0             dlvthprf_hvt     = 0             dwvthprf_hvt     = 0
+dpvthprf_hvt     = 0             cjprf_hvt        = 0.001091      cjswprf_hvt      = 6.4e-11
+cjswgprf_hvt     = 2.9e-10       cgoprf_hvt       = 4.79229e-11   cglprf_hvt       = 5.20444e-11
+ddlcprf_hvt      = 7.35688e-09   dcitprf_hvt      = 0             dlcitprf_hvt     = 0
+dwcitprf_hvt     = 0             dpcitprf_hvt     = 0             ntoxprf_hvt      = 1
+dnfactorprf_hvt  = 0             dlnfactorprf_hvt = 0             dwnfactorprf_hvt = 0
+dpnfactorprf_hvt = 0             du0prf_hvt       = 0             dlu0prf_hvt      = 0
+dwu0prf_hvt      = 0             dpu0prf_hvt      = 0             dvsatprf_hvt     = 0
+dlvsatprf_hvt    = 0             dwvsatprf_hvt    = 0             dpvsatprf_hvt    = 0
+deta0prf_hvt     = 0             dleta0prf_hvt    = 0             dweta0prf_hvt    = 0
+dpeta0prf_hvt    = 0             dk2prf_hvt       = 0             dlk2prf_hvt      = 0
+dwk2prf_hvt      = 0             dpk2prf_hvt      = 0             drdswprf_hvt     = 0
+dpclmprf_hvt     = 0             dlpclmprf_hvt    = 0             dwpclmprf_hvt    = 0
+dppclmprf_hvt    = 0             dpdiblc2prf_hvt  = 0             da0prf_hvt       = 0
+dla0prf_hvt      = 0             dwa0prf_hvt      = 0             dpa0prf_hvt      = 0
+dvoffprf_hvt     = 0             dlvoffprf_hvt    = 0             dwvoffprf_hvt    = 0
+dpvoffprf_hvt    = 0             datprf_hvt       = 0             dubprf_hvt       = 0
+dlubprf_hvt      = 0             dwubprf_hvt      = 0             dpubprf_hvt      = 0
+cfprf_hvt            = '1.20e-10 + 5.6e-11'
+is_d_dnw_nrf_hvt= 1         x_jsw_d_dnw_nrf_hvt= 0         n_d_dnw_nrf_hvt= 1         rs_d_dnw_nrf_hvt= 1
+cj_d_dnw_nrf_hvt= 1          cjsw_d_dnw_nrf_hvt= 1
+is_d_dnw_prf_hvt= 1         x_jsw_d_dnw_prf_hvt= 0         n_d_dnw_prf_hvt= 1         rs_d_dnw_prf_hvt= 1
+cj_d_dnw_prf_hvt= 1          cjsw_d_dnw_prf_hvt= 1
+is_d_prf_hvt= 1                 x_jsw_d_prf_hvt= 0             n_d_prf_hvt= 1             rs_d_prf_hvt= 1
+cj_d_prf_hvt= 1                  cjsw_d_prf_hvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL TT_RFMOS_hvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+toxnrf_hvt       = 2.667e-09     dxlnrf_hvt       = 5e-09         dxwnrf_hvt       = -8e-09
+dvthnrf_hvt      = 0.021         dlvthnrf_hvt     = 9e-10         dwvthnrf_hvt     = 2e-09
+dpvthnrf_hvt     = 2.3e-16       cjnrf_hvt        = 0.00157504    cjswnrf_hvt      = 1.0165e-10
+cjswgnrf_hvt     = 2.7713e-10    cgonrf_hvt       = 7.3459398e-11 cglnrf_hvt       = 1.4435925e-12
+ddlcnrf_hvt      = 6.6302e-09    dcitnrf_hvt      = 0             dlcitnrf_hvt     = 6.1e-11
+dwcitnrf_hvt     = -5e-11        dpcitnrf_hvt     = 1.6e-17       ntoxnrf_hvt      = 0.04
+dnfactornrf_hvt  = 0             dlnfactornrf_hvt = 0             dwnfactornrf_hvt = 0
+dpnfactornrf_hvt = 0             du0nrf_hvt       = 0             dlu0nrf_hvt      = 4.8e-11
+dwu0nrf_hvt      = 8.9e-11       dpu0nrf_hvt      = -6.5e-18      dvsatnrf_hvt     = 0
+dlvsatnrf_hvt    = 0             dwvsatnrf_hvt    = 1.2e-3        dpvsatnrf_hvt    = 0.5e-10
+deta0nrf_hvt     = 0.007         dleta0nrf_hvt    = 0             dweta0nrf_hvt    = 0
+dpeta0nrf_hvt    = 0             dk2nrf_hvt       = 0.003         dlk2nrf_hvt      = 0
+dwk2nrf_hvt      = 3e-09         dpk2nrf_hvt      = 0             drdswnrf_hvt     = 0
+dpclmnrf_hvt     = 0             dpdiblc2nrf_hvt  = 0             dlpdiblc2nrf_hvt = 0
+da0nrf_hvt       = -0.1          dla0nrf_hvt      = 0             dwa0nrf_hvt      = 0
+dpa0nrf_hvt      = 0             dvoffnrf_hvt     = 0             dlvoffnrf_hvt    = 0
+dwvoffnrf_hvt    = 0             dpvoffnrf_hvt    = 0             datnrf_hvt       = 0
+cfnrf_hvt        = '1.116e-10 + 5.4e-11' ss_flagrf_hvt    = 1             ff_flagrf_hvt    = 0
+sf_flagrf_hvt    = 0             fs_flagrf_hvt    = 0
+toxprf_hvt       = 2.867e-09     dxlprf_hvt       = 5e-09         dxwprf_hvt       = -8e-09
+dvthprf_hvt      = -0.02         dlvthprf_hvt     = -0.9e-9       dwvthprf_hvt     = -2.5e-09
+dpvthprf_hvt     = -2.5e-16      cjprf_hvt        = 0.00116737    cjswprf_hvt      = 6.848e-11
+cjswgprf_hvt     = 3.103e-10     cgoprf_hvt       = 4.4568297e-11 cglprf_hvt       = 4.8401292e-11
+ddlcprf_hvt      = 7.35688e-09   dcitprf_hvt      = 0             dlcitprf_hvt     = 5e-11
+dwcitprf_hvt     = -1e-11        dpcitprf_hvt     = 6e-18         ntoxprf_hvt      = -1.64
+dnfactorprf_hvt  = 0             dlnfactorprf_hvt = 0             dwnfactorprf_hvt = 0
+dpnfactorprf_hvt = 0             du0prf_hvt       = 0             dlu0prf_hvt      = 4.5e-11
+dwu0prf_hvt      = -2e-11        dpu0prf_hvt      = -8e-18        dvsatprf_hvt     = 0
+dlvsatprf_hvt    = 0.0011        dwvsatprf_hvt    = 0             dpvsatprf_hvt    = 0
+deta0prf_hvt     = 0             dleta0prf_hvt    = 0             dweta0prf_hvt    = 0
+dpeta0prf_hvt    = 0             dk2prf_hvt       = 0.003         dlk2prf_hvt      = 0
+dwk2prf_hvt      = 3e-09         dpk2prf_hvt      = 0             drdswprf_hvt     = 0
+dpclmprf_hvt     = 0             dlpclmprf_hvt    = 0             dwpclmprf_hvt    = 0
+dppclmprf_hvt    = 0             dpdiblc2prf_hvt  = 0             da0prf_hvt       = 0
+dla0prf_hvt      = 0.5e-7        dwa0prf_hvt      = 0             dpa0prf_hvt      = 0
+dvoffprf_hvt     = 0             dlvoffprf_hvt    = 0             dwvoffprf_hvt    = 0
+dpvoffprf_hvt    = 0             datprf_hvt       = 0             dubprf_hvt       = 0
+dlubprf_hvt      = -1.0e-26      dwubprf_hvt      = 0             dpubprf_hvt      = 0
+cfprf_hvt            = '1.116e-10 + 5.6e-11'
+is_d_dnw_nrf_hvt= 0.7         x_jsw_d_dnw_nrf_hvt= -1         n_d_dnw_nrf_hvt= 0.9975         rs_d_dnw_nrf_hvt= 1.2
+cj_d_dnw_nrf_hvt= 1.07          cjsw_d_dnw_nrf_hvt= 1.07
+is_d_dnw_prf_hvt= 0.7         x_jsw_d_dnw_prf_hvt= -1         n_d_dnw_prf_hvt= 0.9975         rs_d_dnw_prf_hvt= 1.2
+cj_d_dnw_prf_hvt= 1.07          cjsw_d_dnw_prf_hvt=  1.07
+is_d_prf_hvt= 0.7                 x_jsw_d_prf_hvt= -1             n_d_prf_hvt= 0.9975             rs_d_prf_hvt= 1.2
+cj_d_prf_hvt= 1.07                  cjsw_d_prf_hvt=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL SS_RFMOS_hvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+toxnrf_hvt       = 2.533e-09     dxlnrf_hvt       = -5e-09        dxwnrf_hvt       = 8e-09
+dvthnrf_hvt      = -0.02         dlvthnrf_hvt     = -8.9e-10      dwvthnrf_hvt     = -5.6e-09
+dpvthnrf_hvt     = -0.35e-16     cjnrf_hvt        = 0.00136896    cjswnrf_hvt      = 8.835e-11
+cjswgnrf_hvt     = 2.4087e-10    cgonrf_hvt       = 8.4517802e-11 cglnrf_hvt       = 1.6609075e-12
+ddlcnrf_hvt      = 6.6302e-09    dcitnrf_hvt      = 0             dlcitnrf_hvt     = -0.6e-10
+dwcitnrf_hvt     = 25e-11        dpcitnrf_hvt     = -3.5e-17      ntoxnrf_hvt      = 1.63
+dnfactornrf_hvt  = 0             dlnfactornrf_hvt = 0             dwnfactornrf_hvt = 0
+dpnfactornrf_hvt = 0             du0nrf_hvt       = 0             dlu0nrf_hvt      = -1.55e-11
+dwu0nrf_hvt      = -9.3e-11      dpu0nrf_hvt      = 4.0e-18       dvsatnrf_hvt     = 0
+dlvsatnrf_hvt    = -3.0e-4       dwvsatnrf_hvt    = -1e-3         dpvsatnrf_hvt    = 4.5e-11
+deta0nrf_hvt     = 0             dleta0nrf_hvt    = -9e-10        dweta0nrf_hvt    = 8e-10
+dpeta0nrf_hvt    = 5e-17         dk2nrf_hvt       = -0.003        dlk2nrf_hvt      = 0
+dwk2nrf_hvt      = -4e-09        dpk2nrf_hvt      = 0             drdswnrf_hvt     = 0
+dpclmnrf_hvt     = 0.02          dpdiblc2nrf_hvt  = 0             dlpdiblc2nrf_hvt = 0
+da0nrf_hvt       = -0.04         dla0nrf_hvt      = -3.2e-8       dwa0nrf_hvt      = 1e-7
+dpa0nrf_hvt      = 0             dvoffnrf_hvt     = 0             dlvoffnrf_hvt    = 0
+dwvoffnrf_hvt    = 0             dpvoffnrf_hvt    = 0             datnrf_hvt       = 0
+cfnrf_hvt        = '1.284e-10 + 5.4e-11' ss_flagrf_hvt    = 0             ff_flagrf_hvt    = 1
+sf_flagrf_hvt    = 0             fs_flagrf_hvt    = 0
+toxprf_hvt       = 2.733e-09     dxlprf_hvt       = -5e-09        dxwprf_hvt       = 8e-09
+dvthprf_hvt      = 0.02          dlvthprf_hvt     = 0.9e-9        dwvthprf_hvt     = 1.7e-09
+dpvthprf_hvt     = 3e-16         cjprf_hvt        = 0.00101463    cjswprf_hvt      = 5.952e-11
+cjswgprf_hvt     = 2.697e-10     cgoprf_hvt       = 5.1277503e-11 cglprf_hvt       = 5.5687508e-11
+ddlcprf_hvt      = 7.35688e-09   dcitprf_hvt      = 0             dlcitprf_hvt     = -0.6e-10
+dwcitprf_hvt     = 3.5e-11       dpcitprf_hvt     = -6e-18        ntoxprf_hvt      = 2.32
+dnfactorprf_hvt  = 0             dlnfactorprf_hvt = 0             dwnfactorprf_hvt = 0
+dpnfactorprf_hvt = 0             du0prf_hvt       = 0             dlu0prf_hvt      = -4.0e-11
+dwu0prf_hvt      = 2e-11         dpu0prf_hvt      = 1.3e-17       dvsatprf_hvt     = 0
+dlvsatprf_hvt    = -0.0008       dwvsatprf_hvt    = 0             dpvsatprf_hvt    = 0.9e-11
+deta0prf_hvt     = 0             dleta0prf_hvt    = 0             dweta0prf_hvt    = 0
+dpeta0prf_hvt    = 0             dk2prf_hvt       = -0.003        dlk2prf_hvt      = 0
+dwk2prf_hvt      = -4e-09        dpk2prf_hvt      = 0             drdswprf_hvt     = 0
+dpclmprf_hvt     = 0             dlpclmprf_hvt    = 0             dwpclmprf_hvt    = 0
+dppclmprf_hvt    = 0             dpdiblc2prf_hvt  = 0             da0prf_hvt       = 0
+dla0prf_hvt      = -0.5e-7       dwa0prf_hvt      = 0             dpa0prf_hvt      = 0
+dvoffprf_hvt     = 0             dlvoffprf_hvt    = 0             dwvoffprf_hvt    = 0
+dpvoffprf_hvt    = 0             datprf_hvt       = 0             dubprf_hvt       = 0
+dlubprf_hvt      = 0.7e-26       dwubprf_hvt      = 0             dpubprf_hvt      = 1.2e-33
+cfprf_hvt            = '1.284e-10 + 5.6e-11'
+is_d_dnw_nrf_hvt= 1.3         x_jsw_d_dnw_nrf_hvt= 1         n_d_dnw_nrf_hvt= 1.0025         rs_d_dnw_nrf_hvt= 0.8
+cj_d_dnw_nrf_hvt= 0.93          cjsw_d_dnw_nrf_hvt= 0.93
+is_d_dnw_prf_hvt= 1.3         x_jsw_d_dnw_prf_hvt= 1         n_d_dnw_prf_hvt= 1.0025         rs_d_dnw_prf_hvt= 0.8
+cj_d_dnw_prf_hvt= 0.93          cjsw_d_dnw_prf_hvt=  0.93
+is_d_prf_hvt= 1.3                 x_jsw_d_prf_hvt= 1             n_d_prf_hvt= 1.0025             rs_d_prf_hvt= 0.8
+cj_d_prf_hvt= 0.93                  cjsw_d_prf_hvt=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL FF_RFMOS_hvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+A1Nrf_hvt=0.8 A1Prf_hvt=-0.8 A2Nrf_hvt=0 A2Prf_hvt=0 A3Nrf_hvt=-1 A3Prf_hvt=1 A4NPrf_hvt=0
+toxnrf_hvt = '2.6e-09 + 6.7000e-011*A4NPrf_hvt'     dxlnrf_hvt = '5e-009*A2Nrf_hvt'                     dxwnrf_hvt = '8e-009*A3Nrf_hvt'
+dvthnrf_hvt = '0.02*A1Nrf_hvt'                      dlvthnrf_hvt = '8.9e-010*A1Nrf_hvt'                 dwvthnrf_hvt = '5.6e-009*A1Nrf_hvt'
+dpvthnrf_hvt = '3.5e-017*A1Nrf_hvt'                 cjnrf_hvt = '0.001472 * (1+0.070*A1Nrf_hvt)'        cjswnrf_hvt = '9.5e-11 * (1+0.070*A1Nrf_hvt)'
+cjswgnrf_hvt = '2.59e-10 * (1+0.070*A1Nrf_hvt)'     cgonrf_hvt = '7.89886e-11 * (1-0.070*A4NPrf_hvt)'   cglnrf_hvt = '1.55225e-12 * (1-0.070*A4NPrf_hvt)'
+ddlcnrf_hvt = 6.6302e-09                          dcitnrf_hvt = 0                                   dlcitnrf_hvt = '6e-011*A1Nrf_hvt'
+dwcitnrf_hvt = '-2.5e-010*A1Nrf_hvt'                dpcitnrf_hvt = '3.5e-017*A1Nrf_hvt'                 ntoxnrf_hvt = '1 + -6.3000e-001*A4NPrf_hvt'
+dnfactornrf_hvt = 0                               dlnfactornrf_hvt = 0                              dwnfactornrf_hvt = 0
+dpnfactornrf_hvt = 0                              du0nrf_hvt = 0                                    dlu0nrf_hvt = '1.55e-011*A1Nrf_hvt'
+dwu0nrf_hvt = '9.3e-011*A1Nrf_hvt'                  dpu0nrf_hvt = '-4e-018*A1Nrf_hvt'                   dvsatnrf_hvt = 0
+dlvsatnrf_hvt = '0.0003*A1Nrf_hvt'                  dwvsatnrf_hvt = '0.001*A1Nrf_hvt'                   dpvsatnrf_hvt = '-4.5e-011*A1Nrf_hvt'
+deta0nrf_hvt = 0                                  dleta0nrf_hvt = '9e-010*A1Nrf_hvt'                  dweta0nrf_hvt = '-8e-010*A1Nrf_hvt'
+dpeta0nrf_hvt = '-5e-017*A1Nrf_hvt'                 dk2nrf_hvt = '0.003*A1Nrf_hvt'                      dlk2nrf_hvt = 0
+dwk2nrf_hvt = '4e-009*A1Nrf_hvt'                    dpk2nrf_hvt = 0                                   drdswnrf_hvt = 0
+dpclmnrf_hvt = '-0.02*A1Nrf_hvt'                    dpdiblc2nrf_hvt = 0                               dlpdiblc2nrf_hvt = 0
+da0nrf_hvt = '0.04*A1Nrf_hvt'                       dla0nrf_hvt = '3.2e-008*A1Nrf_hvt'                  dwa0nrf_hvt = '-1e-007*A1Nrf_hvt'
+dpa0nrf_hvt = 0                                   dvoffnrf_hvt = 0                                  dlvoffnrf_hvt = 0
+dwvoffnrf_hvt = 0                                 dpvoffnrf_hvt = 0                                 datnrf_hvt = 0
+cfnrf_hvt = '1.20e-10*(1-0.070*A4NPrf_hvt)+5.4e-11'
+ss_flagrf_hvt = 0                                 ff_flagrf_hvt = 0                                 sf_flagrf_hvt = 0
+fs_flagrf_hvt = 0
+toxprf_hvt = '2.8e-09 + 6.7000e-011*A4NPrf_hvt'     dxlprf_hvt = '5e-009*A2Prf_hvt'                     dxwprf_hvt = '8e-009*A3Prf_hvt'
+dvthprf_hvt = '-0.02*A1Prf_hvt'                     dlvthprf_hvt = '-9e-010*A1Prf_hvt'                  dwvthprf_hvt = '-1.7e-009*A1Prf_hvt'
+dpvthprf_hvt = '-3e-016*A1Prf_hvt'                  cjprf_hvt = '0.001091 * (1+0.070*A1Prf_hvt)'        cjswprf_hvt = '6.4e-11 * (1+0.070*A1Prf_hvt)'
+cjswgprf_hvt = '2.9e-10 * (1+0.070*A1Prf_hvt)'      cgoprf_hvt = '4.79229e-11 * (1-0.070*A4NPrf_hvt)'   cglprf_hvt = '5.20444e-11 * (1-0.070*A4NPrf_hvt)'
+ddlcprf_hvt = 7.35688e-09                         dcitprf_hvt = 0                                   dlcitprf_hvt = '6e-011*A1Prf_hvt'
+dwcitprf_hvt = '-3.5e-011*A1Prf_hvt'                dpcitprf_hvt = '6e-018*A1Prf_hvt'                   ntoxprf_hvt = '1 + -1.3200e+000*A4NPrf_hvt'
+dnfactorprf_hvt = 0                               dlnfactorprf_hvt = 0                              dwnfactorprf_hvt = 0
+dpnfactorprf_hvt = 0                              du0prf_hvt = 0                                    dlu0prf_hvt = '4e-011*A1Prf_hvt'
+dwu0prf_hvt = '-2e-011*A1Prf_hvt'                   dpu0prf_hvt = '-1.3e-017*A1Prf_hvt'                 dvsatprf_hvt = 0
+dlvsatprf_hvt = '0.0008*A1Prf_hvt'                  dwvsatprf_hvt = 0                                 dpvsatprf_hvt = '-9e-012*A1Prf_hvt'
+deta0prf_hvt = 0                                  dleta0prf_hvt = 0                                 dweta0prf_hvt = 0
+dpeta0prf_hvt = 0                                 dk2prf_hvt = '0.003*A1Prf_hvt'                      dlk2prf_hvt = 0
+dwk2prf_hvt = '4e-009*A1Prf_hvt'                    dpk2prf_hvt = 0                                   drdswprf_hvt = 0
+dpclmprf_hvt = 0                                  dlpclmprf_hvt = 0                                 dwpclmprf_hvt = 0
+dppclmprf_hvt = 0                                 dpdiblc2prf_hvt = 0                               da0prf_hvt = 0
+dla0prf_hvt = '5e-008*A1Prf_hvt'                    dwa0prf_hvt = 0                                   dpa0prf_hvt = 0
+dvoffprf_hvt = 0                                  dlvoffprf_hvt = 0                                 dwvoffprf_hvt = 0
+dpvoffprf_hvt = 0                                 datprf_hvt = 0                                    dubprf_hvt = 0
+dlubprf_hvt = '-7e-027*A1Prf_hvt'                   dwubprf_hvt = 0                                   dpubprf_hvt = '-1.2e-033*A1Prf_hvt'
+cfprf_hvt = '1.20e-10*(1-0.070*A4NPrf_hvt)+5.6e-11'
+is_d_dnw_nrf_hvt= 1         x_jsw_d_dnw_nrf_hvt= 0         n_d_dnw_nrf_hvt= 1         rs_d_dnw_nrf_hvt= 1
+cj_d_dnw_nrf_hvt= 1          cjsw_d_dnw_nrf_hvt= 1
+is_d_dnw_prf_hvt= 1         x_jsw_d_dnw_prf_hvt= 0         n_d_dnw_prf_hvt= 1         rs_d_dnw_prf_hvt= 1
+cj_d_dnw_prf_hvt= 1          cjsw_d_dnw_prf_hvt= 1
+is_d_prf_hvt= 1                 x_jsw_d_prf_hvt= 0             n_d_prf_hvt= 1             rs_d_prf_hvt= 1
+cj_d_prf_hvt= 1                  cjsw_d_prf_hvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL SF_RFMOS_hvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_hvt
.lib 'crn65lp_v1d5.l' noiseflagrf_hvt
.param
+parn1rf_hvt=AGAUSS(0,1,1)
+parn2rf_hvt=AGAUSS(0,1,1)
+parp1rf_hvt=AGAUSS(0,1,1)
+parp2rf_hvt=AGAUSS(0,1,1)
+A1Nrf_hvt=-0.8 A1Prf_hvt=0.8 A2Nrf_hvt=0 A2Prf_hvt=0 A3Nrf_hvt=1 A3Prf_hvt=-1 A4NPrf_hvt=0
+toxnrf_hvt = '2.6e-09 + 6.7000e-011*A4NPrf_hvt'     dxlnrf_hvt = '5e-009*A2Nrf_hvt'                     dxwnrf_hvt = '8e-009*A3Nrf_hvt'
+dvthnrf_hvt = '0.02*A1Nrf_hvt'                      dlvthnrf_hvt = '8.9e-010*A1Nrf_hvt'                 dwvthnrf_hvt = '5.6e-009*A1Nrf_hvt'
+dpvthnrf_hvt = '3.5e-017*A1Nrf_hvt'                 cjnrf_hvt = '0.001472 * (1+0.070*A1Nrf_hvt)'        cjswnrf_hvt = '9.5e-11 * (1+0.070*A1Nrf_hvt)'
+cjswgnrf_hvt = '2.59e-10 * (1+0.070*A1Nrf_hvt)'     cgonrf_hvt = '7.89886e-11 * (1-0.070*A4NPrf_hvt)'   cglnrf_hvt = '1.55225e-12 * (1-0.070*A4NPrf_hvt)'
+ddlcnrf_hvt = 6.6302e-09                          dcitnrf_hvt = 0                                   dlcitnrf_hvt = '6e-011*A1Nrf_hvt'
+dwcitnrf_hvt = '-2.5e-010*A1Nrf_hvt'                dpcitnrf_hvt = '3.5e-017*A1Nrf_hvt'                 ntoxnrf_hvt = '1 + -6.3000e-001*A4NPrf_hvt'
+dnfactornrf_hvt = 0                               dlnfactornrf_hvt = 0                              dwnfactornrf_hvt = 0
+dpnfactornrf_hvt = 0                              du0nrf_hvt = 0                                    dlu0nrf_hvt = '1.55e-011*A1Nrf_hvt'
+dwu0nrf_hvt = '9.3e-011*A1Nrf_hvt'                  dpu0nrf_hvt = '-4e-018*A1Nrf_hvt'                   dvsatnrf_hvt = 0
+dlvsatnrf_hvt = '0.0003*A1Nrf_hvt'                  dwvsatnrf_hvt = '0.001*A1Nrf_hvt'                   dpvsatnrf_hvt = '-4.5e-011*A1Nrf_hvt'
+deta0nrf_hvt = 0                                  dleta0nrf_hvt = '9e-010*A1Nrf_hvt'                  dweta0nrf_hvt = '-8e-010*A1Nrf_hvt'
+dpeta0nrf_hvt = '-5e-017*A1Nrf_hvt'                 dk2nrf_hvt = '0.003*A1Nrf_hvt'                      dlk2nrf_hvt = 0
+dwk2nrf_hvt = '4e-009*A1Nrf_hvt'                    dpk2nrf_hvt = 0                                   drdswnrf_hvt = 0
+dpclmnrf_hvt = '-0.02*A1Nrf_hvt'                    dpdiblc2nrf_hvt = 0                               dlpdiblc2nrf_hvt = 0
+da0nrf_hvt = '0.04*A1Nrf_hvt'                       dla0nrf_hvt = '3.2e-008*A1Nrf_hvt'                  dwa0nrf_hvt = '-1e-007*A1Nrf_hvt'
+dpa0nrf_hvt = 0                                   dvoffnrf_hvt = 0                                  dlvoffnrf_hvt = 0
+dwvoffnrf_hvt = 0                                 dpvoffnrf_hvt = 0                                 datnrf_hvt = 0
+cfnrf_hvt = '1.20e-10*(1-0.070*A4NPrf_hvt)+5.4e-11'
+ss_flagrf_hvt = 0                                 ff_flagrf_hvt = 0                                 sf_flagrf_hvt = 0
+fs_flagrf_hvt = 0
+toxprf_hvt = '2.8e-09 + 6.7000e-011*A4NPrf_hvt'     dxlprf_hvt = '5e-009*A2Prf_hvt'                     dxwprf_hvt = '8e-009*A3Prf_hvt'
+dvthprf_hvt = '-0.02*A1Prf_hvt'                     dlvthprf_hvt = '-9e-010*A1Prf_hvt'                  dwvthprf_hvt = '-1.7e-009*A1Prf_hvt'
+dpvthprf_hvt = '-3e-016*A1Prf_hvt'                  cjprf_hvt = '0.001091 * (1+0.070*A1Prf_hvt)'        cjswprf_hvt = '6.4e-11 * (1+0.070*A1Prf_hvt)'
+cjswgprf_hvt = '2.9e-10 * (1+0.070*A1Prf_hvt)'      cgoprf_hvt = '4.79229e-11 * (1-0.070*A4NPrf_hvt)'   cglprf_hvt = '5.20444e-11 * (1-0.070*A4NPrf_hvt)'
+ddlcprf_hvt = 7.35688e-09                         dcitprf_hvt = 0                                   dlcitprf_hvt = '6e-011*A1Prf_hvt'
+dwcitprf_hvt = '-3.5e-011*A1Prf_hvt'                dpcitprf_hvt = '6e-018*A1Prf_hvt'                   ntoxprf_hvt = '1 + -1.3200e+000*A4NPrf_hvt'
+dnfactorprf_hvt = 0                               dlnfactorprf_hvt = 0                              dwnfactorprf_hvt = 0
+dpnfactorprf_hvt = 0                              du0prf_hvt = 0                                    dlu0prf_hvt = '4e-011*A1Prf_hvt'
+dwu0prf_hvt = '-2e-011*A1Prf_hvt'                   dpu0prf_hvt = '-1.3e-017*A1Prf_hvt'                 dvsatprf_hvt = 0
+dlvsatprf_hvt = '0.0008*A1Prf_hvt'                  dwvsatprf_hvt = 0                                 dpvsatprf_hvt = '-9e-012*A1Prf_hvt'
+deta0prf_hvt = 0                                  dleta0prf_hvt = 0                                 dweta0prf_hvt = 0
+dpeta0prf_hvt = 0                                 dk2prf_hvt = '0.003*A1Prf_hvt'                      dlk2prf_hvt = 0
+dwk2prf_hvt = '4e-009*A1Prf_hvt'                    dpk2prf_hvt = 0                                   drdswprf_hvt = 0
+dpclmprf_hvt = 0                                  dlpclmprf_hvt = 0                                 dwpclmprf_hvt = 0
+dppclmprf_hvt = 0                                 dpdiblc2prf_hvt = 0                               da0prf_hvt = 0
+dla0prf_hvt = '5e-008*A1Prf_hvt'                    dwa0prf_hvt = 0                                   dpa0prf_hvt = 0
+dvoffprf_hvt = 0                                  dlvoffprf_hvt = 0                                 dwvoffprf_hvt = 0
+dpvoffprf_hvt = 0                                 datprf_hvt = 0                                    dubprf_hvt = 0
+dlubprf_hvt = '-7e-027*A1Prf_hvt'                   dwubprf_hvt = 0                                   dpubprf_hvt = '-1.2e-033*A1Prf_hvt'
+cfprf_hvt = '1.20e-10*(1-0.070*A4NPrf_hvt)+5.6e-11'
+is_d_dnw_nrf_hvt= 1         x_jsw_d_dnw_nrf_hvt= 0         n_d_dnw_nrf_hvt= 1         rs_d_dnw_nrf_hvt= 1
+cj_d_dnw_nrf_hvt= 1          cjsw_d_dnw_nrf_hvt= 1
+is_d_dnw_prf_hvt= 1         x_jsw_d_dnw_prf_hvt= 0         n_d_dnw_prf_hvt= 1         rs_d_dnw_prf_hvt= 1
+cj_d_dnw_prf_hvt= 1          cjsw_d_dnw_prf_hvt= 1
+is_d_prf_hvt= 1                 x_jsw_d_prf_hvt= 0             n_d_prf_hvt= 1             rs_d_prf_hvt= 1
+cj_d_prf_hvt= 1                  cjsw_d_prf_hvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_hvt
.ENDL FS_RFMOS_hvt


.LIB RF_MOS_hvt

.subckt nmos_rf_hvt D G S B lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parn1rf_hvt  temp2=parn2rf_hvt
+fac1='0.513264*temp1*sigma+0.858231*temp2*sigma'
+fac2='0.513264*temp1*sigma-0.858231*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_hvt='(0.0065945219859-0.000546287615/(lef*1e6)+0.00003025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_hvt='0.00226307*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_hvt='-0.00226307*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_hvt='0.00226307*geo_fac*toxnrf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1681.8*lr*scale/nr/(wr*scale)+1.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='4.491e05/(lr*scale*1e6)+1.770e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4761'

.param fn_dice='noiseflagnrf_hvt_mc*par1fn_mc+noiseflagnrf_hvt_mc_mis*par2fnrf_hvt_mc'
.param c1fnrf_hvt=3E+42           c2fnrf_hvt=1.00E+23           c3fnrf_hvt=1.00E+7   
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(7.5E-6*1E-6*1))**0.5)))'
.param noianrf_hvt='c1fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'
.param noibnrf_hvt='c2fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'
.param noicnrf_hvt='c3fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_hvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT NMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************


.MODEL nch_rf_hvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+LMAX       = 2.401e-007			
+WMIN       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+WMAX       = 6.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'
+DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51029903+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '-3.4568481e-009+dlvthnrf_hvt'
+WVTH0      = '1.7612109e-009+dwvthnrf_hvt'
+PVTH0      = '1.9820236e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0068379101+dk2nrf_hvt'
+LK2        = '-1.7834614e-009+dlk2nrf_hvt'
+WK2        = '-1.9940316e-008+dwk2nrf_hvt'
+PK2        = '1.7118143e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049520102+dcitnrf_hvt'
+LCIT       = '1.3082307e-010+dlcitnrf_hvt'
+WCIT       = '2.420774e-011+dwcitnrf_hvt'
+PCIT       = '-2.1570692e-017+dpcitnrf_hvt'
+VOFF       = '-0.14181909+dvoffnrf_hvt'
+LVOFF      = '-2.9141003e-009+dlvoffnrf_hvt'
+WVOFF      = '-3.0824876e-008+dwvoffnrf_hvt'
+PVOFF      = '1.882346e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '0.054322285+deta0nrf_hvt'
+LETA0      = '-5.43961e-014+dleta0nrf_hvt'
+WETA0      = '-5.3612063e-009+dweta0nrf_hvt'
+PETA0      = '8.8158482e-021+dpeta0nrf_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010674795+du0nrf_hvt'
+LU0        = '1.4865632e-011+dlu0nrf_hvt'
+UA         = -1.7554817e-009     LUA        = 4.8032508e-018      WUA        = 1.8406019e-016
+PUA        = -6.7525646e-024     UB         = 1.5597693e-018      LUB        = 1.8962419e-027
+WUB        = -1.8611524e-025     PUB        = 4.6287498e-033      UC         = 6.0350359e-011
+LUC        = 1.2160087e-019      WUC        = -1.2276744e-016     PUC        = 9.0428094e-024
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '1.405171+da0nrf_hvt' LA0        = '-1.5789634e-007+dla0nrf_hvt'
+WA0        = '-3.2635924e-007+dwa0nrf_hvt'
+PA0        = '8.62959e-014+dpa0nrf_hvt'
+AGS        = 3.0235749           LAGS       = -1.7466347e-007     WAGS       = -2.6515905e-006
+PAGS       = 2.5397146e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.053375301
+LKETA      = -6.1921743e-009     WKETA      = 8.0470522e-008      PKETA      = -3.9408717e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.012039198+dpclmnrf_hvt'
+LPCLM      = 6.7062822e-008      WPCLM      = 8.1876225e-009      PPCLM      = 8.3788294e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2nrf_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2nrf_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'
+RDW        = '52.68+drdswnrf_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010745391
+LAIGSD     = 9.2277033e-012      WAIGSD     = -4.3800595e-011     PAIGSD     = -2.6259973e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'
+CGDO       = 'cgonrf_hvt'          CGBO       = 0                   CGDL       = 'cglnrf_hvt'
+CGSL       = 'cglnrf_hvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016164685        LTVOFF     = -1.5095014e-010
+WTVOFF     = -1.476013e-009      PTVOFF     = 1.7806138e-016      KT1        = -0.2886127
+LKT1       = -1.2022581e-008     WKT1       = -2.5745648e-008     PKT1       = 6.2419957e-015
+KT1L       = 0                   KT2        = -0.081503825        LKT2       = -4.2581776e-011
+WKT2       = -9.6903242e-009     PKT2       = 1.5024456e-015      UTE        = -1
+UA1        = 5.5431357e-010      LUA1       = 4.4335296e-017      WUA1       = 2.5673461e-017
+PUA1       = -3.0479576e-023     UB1        = -4.7522522e-019     LUB1       = -3.3992745e-026
+WUB1       = 4.0088836e-027      PUB1       = 1.1254274e-032      UC1        = 1.4667601e-010
+LUC1       = -5.9821505e-018     WUC1       = -2.6719068e-017     PUC1       = 5.2519947e-025
+PRT        = 0                   AT         = '63846.319+datnrf_hvt'
+LAT        = -0.0020618081       WAT        = -0.0047370519       PAT        = -5.2519947e-010
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+WU0        = '0+dwu0nrf_hvt'       PU0        = '0+dpu0nrf_hvt'       LVSAT      = '0+dlvsatnrf_hvt'
+WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf_hvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+WMIN       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'    DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46122686+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '1.2433235e-009+dlvthnrf_hvt'
+WVTH0      = '2.3057213e-008+dwvthnrf_hvt'
+PVTH0      = '-5.7724504e-017+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0089135286+dk2nrf_hvt'
+LK2        = '-1.584657e-009+dlk2nrf_hvt'
+WK2        = '-1.8011708e-008+dwk2nrf_hvt'
+PK2        = '1.5270907e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.2775734e-005+dcitnrf_hvt'
+LCIT       = '1.7415672e-010+dlcitnrf_hvt'
+WCIT       = '1.2127215e-010+dwcitnrf_hvt'
+PCIT       = '-3.08676e-017+dpcitnrf_hvt'
+VOFF       = '-0.12918363+dvoffnrf_hvt'
+LVOFF      = '-4.1243344e-009+dlvoffnrf_hvt'
+WVOFF      = '-1.7751302e-008+dwvoffnrf_hvt'
+PVOFF      = '6.3014862e-016+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '-0.0038339129+deta0nrf_hvt'
+LETA0      = '5.5701928e-009+dleta0nrf_hvt'
+WETA0      = '7.9124665e-009+dweta0nrf_hvt'
+PETA0      = '-1.2713542e-015+dpeta0nrf_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010717766+du0nrf_hvt'
+LU0        = '1.0749846e-011+dlu0nrf_hvt'
+UA         = -1.8691811e-009     LUA        = 1.5693471e-017      WUA        = -8.7281901e-017
+PUA        = 1.9236798e-023      UB         = 1.5879251e-018      LUB        = -8.0054308e-028
+WUB        = 1.9551478e-025      PUB        = -3.1924079e-032     UC         = 7.2032623e-011
+LUC        = -9.9733571e-019     WUC        = 1.6075185e-017      PUC        = -4.255648e-024
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '3.1625332+da0nrf_hvt'
+LA0        = '-3.262179e-007+dla0nrf_hvt'
+WA0        = '-1.6825379e-007+dwa0nrf_hvt'
+PA0        = '7.1152433e-014+dpa0nrf_hvt'
+AGS        = -1.0966783          LAGS       = 2.1997769e-007      WAGS       = -7.3831551e-006
+PAGS       = 7.071645e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.22825247
+LKETA      = 1.05577e-008        WKETA      = 1.3120105e-007      PKETA      = -8.7998818e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.71125481+dpclmnrf_hvt'
+LPCLM      = 9.1391598e-011      WPCLM      = -2.438004e-008      PPCLM      = 1.1498186e-014
+PDIBLC1    = 0
+PDIBLC2    = '-0.00078408711+dpdiblc2nrf_hvt-0.00320674*ff_flagrf_hvt'
+LPDIBLC2   = '1.7088129e-010+dlpdiblc2nrf_hvt+3.07143e-10*ff_flagrf_hvt'
+WPDIBLC2   = '1.8110816e-009-4.5e-15*ff_flagrf_hvt'
+PPDIBLC2   = '-1.7346684e-016-4.2e-22*ff_flagrf_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 8.9756956e-009      LAGIDL     = -2.3448056e-016     WAGIDL     = -2.4529918e-014
+PAGIDL     = 2.3494952e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010802719         LAIGSD     = 3.7368513e-012
+WAIGSD     = -4.0900567e-010     PAIGSD     = 8.7196609e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'          CGDO       = 'cgonrf_hvt'
+CGBO       = 0                   CGDL       = 'cglnrf_hvt'          CGSL       = 'cglnrf_hvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0011725623       LTVOFF     = 1.1618546e-010      WTVOFF     = 1.3030646e-009
+PTVOFF     = -8.8120893e-017     KT1        = -0.50365453         LKT1       = 8.574298e-009
+WKT1       = 1.1812929e-007      PKT1       = -7.5384608e-015     KT1L       = 0
+KT2        = -0.0972308          LKT2       = 1.4637605e-009      WKT2       = 1.8446502e-009
+PKT2       = 3.9761654e-016      UTE        = -1                  UA1        = 2.2638308e-009
+LUA1       = -1.1940363e-016     WUA1       = -1.1202924e-015     PUA1       = 7.9281947e-023
+UB1        = -1.7844563e-018     LUB1       = 9.1406454e-026      WUB1       = 7.5148988e-025
+PUB1       = -6.0340054e-032     UC1        = 9.2788654e-011      LUC1       = -8.2077635e-019
+WUC1       = -3.9625329e-017     PUC1       = 1.7613715e-024      PRT        = 0
+AT         = '56281.889+datnrf_hvt'
+LAT        = -0.0013372809       WAT        = -0.016775112        PAT        = 6.2781559e-010
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+WU0        = '0+dwu0nrf_hvt'       PU0        = '0+dpu0nrf_hvt'       LVSAT      = '0+dlvsatnrf_hvt'
+WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf_hvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+LMAX       = 2.401e-007			
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'
+DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48556798+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '1.1250376e-009+dlvthnrf_hvt'
+WVTH0      = '2.6986884e-008+dwvthnrf_hvt'
+PVTH0      = '-2.6914998e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.014789467+dk2nrf_hvt'
+LK2        = '-3.3319642e-010+dlk2nrf_hvt'
+WK2        = '-1.1829728e-008+dwk2nrf_hvt'
+PK2        = '2.3254395e-016+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028841387+dcitnrf_hvt'
+LCIT       = '-1.0469212e-010+dlcitnrf_hvt'
+WCIT       = '-2.4125087e-009+dwcitnrf_hvt'
+PCIT       = '2.186548e-016+dpcitnrf_hvt'
+VOFF       = '-0.13884306+dvoffnrf_hvt'
+LVOFF      = '-4.0172593e-009+dlvoffnrf_hvt'
+WVOFF      = '-3.3860426e-008+dwvoffnrf_hvt'
+PVOFF      = '3.0075683e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '0.013614777+deta0nrf_hvt'
+LETA0      = '-8.5871322e-014+dleta0nrf_hvt'
+WETA0      = '3.6160453e-008+dweta0nrf_hvt'
+PETA0      = '4.0920575e-020+dpeta0nrf_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011933619+du0nrf_hvt'
+LU0        = '-3.8898403e-011+dlu0nrf_hvt'
+WU0        = '-1.2840002e-009+dwu0nrf_hvt'
+PU0        = '5.4839316e-017+dpu0nrf_hvt'
+UA         = -1.6143173e-009     LUA        = -2.5370678e-017     WUA        = 4.0072486e-017
+PUA        = 2.4024843e-023      UB         = 1.427875e-018       LUB        = 3.8898349e-026
+WUB        = -5.158308e-026      PUB        = -3.3113399e-032     UC         = -9.4317845e-011
+LUC        = 2.3526431e-017      WUC        = 3.4994131e-017      PUC        = -1.4830118e-023
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '1.4060353+da0nrf_hvt'
+LA0        = '-1.3455132e-007+dla0nrf_hvt'
+WA0        = '-3.2724079e-007+dwa0nrf_hvt'
+PA0        = '6.2483975e-014+dpa0nrf_hvt'
+AGS        = -4.3278073          LAGS       = 7.0745881e-007      WAGS       = 4.8468194e-006
+PAGS       = -6.4579327e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.06923171
+LKETA      = -2.2877216e-008     WKETA      = -4.4588629e-008     PKETA      = 1.3077871e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.18340503+dpclmnrf_hvt'
+LPCLM      = 1.1231153e-007      WPCLM      = 2.0754074e-007      PPCLM      = -3.7774855e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.0060264624+dpdiblc2nrf_hvt'
+LPDIBLC2   = '6.7300019e-010+dlpdiblc2nrf_hvt'
+WPDIBLC2   = 5.4255947e-009      PPDIBLC2   = -5.196678e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.125462e-008      WAGIDL     = 1.8137864e-014      BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010725544
+LAIGSD     = -6.7721212e-011     WAIGSD     = -2.3555899e-011     PAIGSD     = 5.222792e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'
+CGDO       = 'cgonrf_hvt'          CGBO       = 0                   CGDL       = 'cglnrf_hvt'
+CGSL       = 'cglnrf_hvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -2.3944289e-005     LTVOFF     = 8.148018e-011
+WTVOFF     = 1.9720807e-010      PTVOFF     = -5.9017549e-017     KT1        = -0.3895338
+LKT1       = -2.7004246e-010     WKT1       = 7.7193873e-008      PKT1       = -5.7455934e-015
+KT1L       = 0                   KT2        = -0.11399975         LKT2       = 3.6552111e-009
+WKT2       = 2.3455522e-008      PKT2       = -2.2693031e-015     UTE        = -1
+UA1        = 7.384309e-010       LUA1       = 5.0950433e-017      WUA1       = -1.6212622e-016
+PUA1       = -3.7227017e-023     UB1        = -5.5970626e-019     LUB1       = -6.8530563e-026
+WUB1       = 9.017955e-026       PUB1       = 4.6482849e-032      UC1        = 1.8326101e-010
+LUC1       = -1.5221581e-017     WUC1       = -6.4035764e-017     PUC1       = 9.9494187e-024
+PRT        = 0                   AT         = '50471.488+datnrf_hvt'
+LAT        = -0.0013990211       WAT        = 0.0089052757        PAT        = -1.2012422e-009
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+LVSAT      = '0+dlvsatnrf_hvt'     WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf_hvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'    DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.52889853+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '-3.0251973e-009+dlvthnrf_hvt'
+WVTH0      = '-4.5967889e-008+dwvthnrf_hvt'
+PVTH0      = '4.2961667e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0034807992+dk2nrf_hvt'
+LK2        = '-1.4163497e-009+dlk2nrf_hvt'
+WK2        = '-2.3553092e-008+dwk2nrf_hvt'
+PK2        = '1.3554172e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0022436261+dcitnrf_hvt+0.00149113*ff_flagrf_hvt'
+LCIT       = '3.8644929e-010+dlcitnrf_hvt-1.42821e-10*ff_flagrf_hvt'
+WCIT       = '2.453402e-009+dwcitnrf_hvt-1.52096e-09*ff_flagrf_hvt'
+PCIT       = '-2.4740602e-016+dpcitnrf_hvt+1.45678e-16*ff_flagrf_hvt'
+VOFF       = '-0.15526103+dvoffnrf_hvt'
+LVOFF      = '-2.4447333e-009+dlvoffnrf_hvt'
+WVOFF      = '8.8476402e-009+dwvoffnrf_hvt'
+PVOFF      = '-1.0830445e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '-0.098943963+deta0nrf_hvt'
+LETA0      = '1.078088e-008+dleta0nrf_hvt'
+WETA0      = '1.0492472e-007+dweta0nrf_hvt'
+PETA0      = '-6.5862555e-015+dpeta0nrf_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011390414+du0nrf_hvt'
+LU0        = '1.3130169e-011+dlu0nrf_hvt'
+WU0        = '-6.8610119e-010+dwu0nrf_hvt'
+PU0        = '-2.4279295e-018+dpu0nrf_hvt'
+UA         = -2.6549763e-009     LUA        = 7.4304472e-017      WUA        = 7.1422917e-016
+PUA        = -4.0546423e-023     UB         = 2.8034532e-018      LUB        = -9.2855625e-026
+WUB        = -1.0443238e-024     PUB        = 6.1972105e-032      UC         = 3.5201396e-010
+LUC        = -1.9223586e-017     WUC        = -2.6950578e-016     PUC        = 1.4335127e-023
+VSAT       = '75059.289+dvsatnrf_hvt'
+LVSAT      = '0.00095212923+dlvsatnrf_hvt'
+WVSAT      = '0.010139525+dwvsatnrf_hvt'
+PVSAT      = '-9.7117181e-010+dpvsatnrf_hvt'
+A0         = '3.6588742+da0nrf_hvt'
+LA0        = '-3.5033003e-007+dla0nrf_hvt'
+WA0        = '-6.7452153e-007+dwa0nrf_hvt'
+PA0        = '9.5746803e-014+dpa0nrf_hvt'
+AGS        = -12.31189           LAGS       = 1.4721806e-006      WAGS       = 4.0563604e-006
+PAGS       = -5.7008247e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.30170439
+LKETA      = 1.265134e-008       WKETA      = 2.0612201e-007      PKETA      = -1.0935395e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '1.4612224+dpclmnrf_hvt'
+LPCLM      = -4.5212201e-008     WPCLM      = -7.8934701e-007     PPCLM      = 5.770785e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0020245416+dpdiblc2nrf_hvt-0.00320674*ff_flagrf_hvt'
+LPDIBLC2   = '-9.8131414e-011+dlpdiblc2nrf_hvt+3.07142e-10*ff_flagrf_hvt'
+WPDIBLC2   = '-1.0537197e-009+3.3e-15*ff_flagrf_hvt'
+PPDIBLC2   = '1.0092612e-016-3.3e-22*ff_flagrf_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 7.6302591e-010      LAGIDL     = -1.1510597e-015     WAGIDL     = -1.6152995e-014
+PAGIDL     = 3.284406e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0084736815        LAIGSD     = 1.4796395e-010
+WAIGSD     = 1.9666123e-009      PAIGSD     = -1.3839198e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'          CGDO       = 'cgonrf_hvt'
+CGBO       = 0                   CGDL       = 'cglnrf_hvt'          CGSL       = 'cglnrf_hvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00087605272       LTVOFF     = -4.7222538e-012     WTVOFF     = -7.8652278e-010
+PTVOFF     = 3.5204978e-017      KT1        = -0.38345064         LKT1       = -8.5269239e-010
+WKT1       = -4.478684e-009      PKT1       = 2.0770694e-015      KT1L       = 0
+KT2        = -0.10972811         LKT2       = 3.2460696e-009      WKT2       = 1.4591905e-008
+PKT2       = -1.4203388e-015     UTE        = -1                  UA1        = 2.7399852e-009
+LUA1       = -1.4076004e-016     WUA1       = -1.6059698e-015     PUA1       = 1.0106548e-022
+UB1        = -2.8047868e-018     LUB1       = 1.4650505e-025      WUB1       = 1.792227e-024
+PUB1       = -1.1654062e-031     UC1        = -5.9952012e-012     LUC1       = 2.9055298e-018
+WUC1       = 6.1134203e-017      PUC1       = -2.0394608e-024     PRT        = 0
+AT         = '30229.258+datnrf_hvt'
+LAT        = 0.00053979585       WAT        = 0.0097985706        PAT        = -1.2868027e-009
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL ndio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 1.99e-07                IKR    = 1E10
+N      = 1                       BV     = 8.85                    IBV    = 0.03
+JSW    = 5.1e-13                 CJ     = 'cjnrf_hvt'             PJ     = 7.2E-4
+MJ     = 0.5                     FC     = 0                       CJSW   = 'cjswnrf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.05                    TLEVC  = 1
+CTA    = 0.000773                CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.0018                  FCS    = 0			   )

.MODEL ndio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 1.99e-07                IKR    = 1E10
+N      = 1                       BV     = 8.85                    IBV    = 0.03
+JSW    = 5.1e-13                 CJ     = 'cjnrf_hvt'             PJ     = 7.2E-4
+MJ     = 0.5                     FC     = 0                       CJSW   = 'cjswgnrf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.445                   TLEVC  = 1
+CTA    = 0.000773                CTP    = 0.00104                 
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1.02
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.00198                 FCS    = 0			   )

.ends nmos_rf_hvt

.subckt pmos_rf_hvt D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parp1rf_hvt  temp2=parp2rf_hvt
+fac1='0.865112*temp1*sigma+0.501579*temp2*sigma'
+fac2='0.865112*temp1*sigma-0.501579*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_hvt='(0.0037385-0.0003287615/(lef*1e6)+0.000021625807/(lef*lef*1e12)-0.00002287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_hvt = '0.00203822*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_hvt = '-0.00203822*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_hvt='0.00203822*geo_fac*toxprf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1963.4*lr*scale/nr/(wr*scale)+0.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.131e06/(lr*scale*1e6)+2.64e07'
.param rnoiax='0.00561/(lr*scale*1e6)+0.5135'

.param fn_dice='noiseflagprf_hvt_mc*par1fn_mc+noiseflagprf_hvt_mc_mis*par2fprf_hvt_mc'
.param c1fprf_hvt=2.10E+42           c2fprf_hvt=1.55E+24           c3fprf_hvt=1.00E+10     
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_hvt='c1fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noibprf_hvt='c2fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noicprf_hvt='c3fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx  

M0 DI GI SI BI pch_rf_hvt L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_hvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-7.2984626e-010+dlvthprf_hvt'
+WVTH0      = '-9.7044399e-009+dwvthprf_hvt'
+PVTH0      = '1.3534114e-015+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2prf_hvt'
+LK2        = '5.9104693e-010+dlk2prf_hvt'
+WK2        = '-1.0179173e-008+dwk2prf_hvt'
+PK2        = '-3.6554416e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitprf_hvt'
+LCIT       = '1.4213307e-010+dlcitprf_hvt'
+WCIT       = '-4.6699281e-010+dwcitprf_hvt'
+PCIT       = '-6.4541088e-019+dpcitprf_hvt'
+VOFF       = '-0.11759164+dvoffprf_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffprf_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffprf_hvt'
+PVOFF      = '1.6253402e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0052266667+deta0prf_hvt'
+WETA0      = '-2.2712e-009+dweta0prf_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0prf_hvt'
+LU0        = '1.7777142e-010+dlu0prf_hvt'
+WU0        = '1.018685e-009+dwu0prf_hvt'
+PU0        = '-1.7430005e-016+dpu0prf_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubprf_hvt'
+LUB        = '-8.2046654e-029+dlubprf_hvt'
+WUB        = '1.8606441e-027+dwubprf_hvt'
+PUB        = '-1.030774e-033+dpubprf_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatprf_hvt'  A0         = '1.8037767+da0prf_hvt'
+LA0        = '3.4946811e-008+dla0prf_hvt'
+WA0        = '-6.0772635e-007+dwa0prf_hvt'
+PA0        = '7.6080253e-014+dpa0prf_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmprf_hvt'
+LPCLM      = '3.3020183e-009+dlpclmprf_hvt'
+WPCLM      = '1.7467444e-008+dwpclmprf_hvt'
+PPCLM      = '7.2950988e-015+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datprf_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf_hvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-3.0821854e-010+dlvthprf_hvt'
+WVTH0      = '6.2963879e-009+dwvthprf_hvt'
+PVTH0      = '-2.2267017e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2prf_hvt'
+LK2        = '-2.378406e-009+dlk2prf_hvt'
+WK2        = '-3.2823766e-008+dwk2prf_hvt'
+PK2        = '1.8649482e-015+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitprf_hvt'
+LCIT       = '2.7955334e-010+dlcitprf_hvt'
+WCIT       = '-5.1403406e-010+dwcitprf_hvt'
+PCIT       = '3.988153e-018+dpcitprf_hvt'
+VOFF       = '-0.094349901+dvoffprf_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffprf_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffprf_hvt'
+PVOFF      = '2.1065519e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0016702266+deta0prf_hvt'
+LETA0      = '3.5030935e-010+dleta0prf_hvt'
+WETA0      = '-4.0623502e-009+dweta0prf_hvt'
+PETA0      = '1.7642829e-016+dpeta0prf_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0prf_hvt'
+LU0        = '-3.7049814e-010+dlu0prf_hvt'
+WU0        = '-1.7061645e-009+dwu0prf_hvt'
+PU0        = '9.4097621e-017+dpu0prf_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubprf_hvt'
+LUB        = '6.3755797e-028+dlubprf_hvt'
+WUB        = '-1.488923e-026+dwubprf_hvt'
+PUB        = '6.1908859e-034+dpubprf_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatprf_hvt+384.85*ff_flagrf_hvt'
+A0         = '2.8058311+da0prf_hvt'
+LA0        = '-6.375555e-008+dla0prf_hvt'
+WA0        = '5.861974e-008+dwa0prf_hvt'
+PA0        = '1.0445163e-014+dpa0prf_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmprf_hvt'
+LPCLM      = '1.4911452e-008+dlpclmprf_hvt'
+WPCLM      = '4.4648173e-007+dwpclmprf_hvt'
+PPCLM      = '-3.4962808e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2prf_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datprf_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt-3.79076e-05*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt-0.00385619*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt+3.79834e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf_hvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '1.4188652e-009+dlvthprf_hvt'
+WVTH0      = '2.0428322e-009+dwvthprf_hvt'
+PVTH0      = '-8.3827437e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2prf_hvt'
+LK2        = '-5.8855075e-010+dlk2prf_hvt'
+WK2        = '-1.0212046e-008+dwk2prf_hvt'
+PK2        = '8.3764547e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitprf_hvt'
+LCIT       = '1.2700497e-010+dlcitprf_hvt'
+WCIT       = '-3.1452806e-010+dwcitprf_hvt'
+PCIT       = '1.478525e-017+dpcitprf_hvt'
+VOFF       = '-0.1071063+dvoffprf_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffprf_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffprf_hvt'
+PVOFF      = '3.6780146e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.00269+deta0prf_hvt'
+WETA0      = '3.162e-010+dweta0prf_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0prf_hvt'
+LU0        = '2.8729247e-010+dlu0prf_hvt'
+WU0        = '1.9076404e-009+dwu0prf_hvt'
+PU0        = '-2.8601153e-016+dpu0prf_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubprf_hvt'
+LUB        = '1.9066399e-027+dlubprf_hvt'
+WUB        = '3.0779517e-026+dwubprf_hvt'
+PUB        = '-3.0592342e-033+dpubprf_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatprf_hvt'  A0         = '-0.4400886+da0prf_hvt'
+LA0        = '4.149252e-007+dla0prf_hvt'
+WA0        = '1.6810163e-006+dwa0prf_hvt'
+PA0        = '-3.1149771e-013+dpa0prf_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmprf_hvt'
+LPCLM      = '1.2227911e-007+dlpclmprf_hvt'
+WPCLM      = '9.3617077e-007+dwpclmprf_hvt'
+PPCLM      = '-1.1406153e-013+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datprf_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf_hvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-1.262382e-009+dlvthprf_hvt'
+WVTH0      = '-1.4087635e-008+dwvthprf_hvt'
+PVTH0      = '7.505766e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2prf_hvt'
+LK2        = '-1.0794234e-009+dlk2prf_hvt'
+WK2        = '-7.190122e-009+dwk2prf_hvt'
+PK2        = '5.3998597e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitprf_hvt'
+LCIT       = '9.8047363e-011+dlcitprf_hvt'
+WCIT       = '-2.0844672e-009+dwcitprf_hvt'
+PCIT       = '1.8912425e-016+dpcitprf_hvt'
+VOFF       = '-0.12945599+dvoffprf_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffprf_hvt'
+WVOFF      = '6.3228005e-009+dwvoffprf_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '-0.0055935647+deta0prf_hvt'
+LETA0      = '8.1593113e-010+dleta0prf_hvt'
+WETA0      = '3.3467169e-009+dweta0prf_hvt'
+PETA0      = '-2.9850592e-016+dpeta0prf_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0prf_hvt'
+LU0        = '-6.3113981e-010+dlu0prf_hvt'
+WU0        = '-4.6503664e-009+dwu0prf_hvt'
+PU0        = '3.5995213e-016+dpu0prf_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubprf_hvt'
+LUB        = '7.2916293e-029+dlubprf_hvt'
+WUB        = '-1.2410913e-026+dwubprf_hvt'
+PUB        = '1.1950231e-033+dpubprf_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatprf_hvt-8659.12*ff_flagrf_hvt'
+A0         = '6.2698767+da0prf_hvt'
+LA0        = '-2.4600638e-007+dla0prf_hvt'
+WA0        = '-3.4747068e-006+dwa0prf_hvt'
+PA0        = '1.9634101e-013+dpa0prf_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmprf_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmprf_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmprf_hvt'
+PPCLM      = '8.7145749e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2prf_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datprf_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt+0.000852921*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt+0.00536865*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt-5.28811e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.04                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.000204                
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0016                  FCS    = 0			   )

.MODEL pdio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswgprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.92                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.0008                  
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1.22                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0003                  FCS    = 0			   )

.ends pmos_rf_hvt


.subckt pmos_rf_hvt_nw D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parp1rf_hvt  temp2=parp2rf_hvt
+fac1='0.865112*temp1*sigma+0.501579*temp2*sigma'
+fac2='0.865112*temp1*sigma-0.501579*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_hvt='(0.0037385-0.0003287615/(lef*1e6)+0.000021625807/(lef*lef*1e12)-0.00002287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_hvt = '0.00203822*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_hvt = '-0.00203822*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_hvt='0.00203822*geo_fac*toxprf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1963.4*lr*scale/nr/(wr*scale)+0.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.131e06/(lr*scale*1e6)+2.64e07'
.param rnoiax='0.00561/(lr*scale*1e6)+0.5135'

.param fn_dice='noiseflagprf_hvt_mc*par1fn_mc+noiseflagprf_hvt_mc_mis*par2fprf_hvt_mc'
.param c1fprf_hvt=2.10E+42           c2fprf_hvt=1.55E+24           c3fprf_hvt=1.00E+10     
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_hvt='c1fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noibprf_hvt='c2fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noicprf_hvt='c3fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx  

M0 DI GI SI BI pch_rf_hvt L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_hvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-7.2984626e-010+dlvthprf_hvt'
+WVTH0      = '-9.7044399e-009+dwvthprf_hvt'
+PVTH0      = '1.3534114e-015+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2prf_hvt'
+LK2        = '5.9104693e-010+dlk2prf_hvt'
+WK2        = '-1.0179173e-008+dwk2prf_hvt'
+PK2        = '-3.6554416e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitprf_hvt'
+LCIT       = '1.4213307e-010+dlcitprf_hvt'
+WCIT       = '-4.6699281e-010+dwcitprf_hvt'
+PCIT       = '-6.4541088e-019+dpcitprf_hvt'
+VOFF       = '-0.11759164+dvoffprf_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffprf_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffprf_hvt'
+PVOFF      = '1.6253402e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0052266667+deta0prf_hvt'
+WETA0      = '-2.2712e-009+dweta0prf_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0prf_hvt'
+LU0        = '1.7777142e-010+dlu0prf_hvt'
+WU0        = '1.018685e-009+dwu0prf_hvt'
+PU0        = '-1.7430005e-016+dpu0prf_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubprf_hvt'
+LUB        = '-8.2046654e-029+dlubprf_hvt'
+WUB        = '1.8606441e-027+dwubprf_hvt'
+PUB        = '-1.030774e-033+dpubprf_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatprf_hvt'  A0         = '1.8037767+da0prf_hvt'
+LA0        = '3.4946811e-008+dla0prf_hvt'
+WA0        = '-6.0772635e-007+dwa0prf_hvt'
+PA0        = '7.6080253e-014+dpa0prf_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmprf_hvt'
+LPCLM      = '3.3020183e-009+dlpclmprf_hvt'
+WPCLM      = '1.7467444e-008+dwpclmprf_hvt'
+PPCLM      = '7.2950988e-015+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datprf_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf_hvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-3.0821854e-010+dlvthprf_hvt'
+WVTH0      = '6.2963879e-009+dwvthprf_hvt'
+PVTH0      = '-2.2267017e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2prf_hvt'
+LK2        = '-2.378406e-009+dlk2prf_hvt'
+WK2        = '-3.2823766e-008+dwk2prf_hvt'
+PK2        = '1.8649482e-015+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitprf_hvt'
+LCIT       = '2.7955334e-010+dlcitprf_hvt'
+WCIT       = '-5.1403406e-010+dwcitprf_hvt'
+PCIT       = '3.988153e-018+dpcitprf_hvt'
+VOFF       = '-0.094349901+dvoffprf_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffprf_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffprf_hvt'
+PVOFF      = '2.1065519e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0016702266+deta0prf_hvt'
+LETA0      = '3.5030935e-010+dleta0prf_hvt'
+WETA0      = '-4.0623502e-009+dweta0prf_hvt'
+PETA0      = '1.7642829e-016+dpeta0prf_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0prf_hvt'
+LU0        = '-3.7049814e-010+dlu0prf_hvt'
+WU0        = '-1.7061645e-009+dwu0prf_hvt'
+PU0        = '9.4097621e-017+dpu0prf_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubprf_hvt'
+LUB        = '6.3755797e-028+dlubprf_hvt'
+WUB        = '-1.488923e-026+dwubprf_hvt'
+PUB        = '6.1908859e-034+dpubprf_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatprf_hvt+384.85*ff_flagrf_hvt'
+A0         = '2.8058311+da0prf_hvt'
+LA0        = '-6.375555e-008+dla0prf_hvt'
+WA0        = '5.861974e-008+dwa0prf_hvt'
+PA0        = '1.0445163e-014+dpa0prf_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmprf_hvt'
+LPCLM      = '1.4911452e-008+dlpclmprf_hvt'
+WPCLM      = '4.4648173e-007+dwpclmprf_hvt'
+PPCLM      = '-3.4962808e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2prf_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datprf_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt-3.79076e-05*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt-0.00385619*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt+3.79834e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pch_rf_hvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '1.4188652e-009+dlvthprf_hvt'
+WVTH0      = '2.0428322e-009+dwvthprf_hvt'
+PVTH0      = '-8.3827437e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2prf_hvt'
+LK2        = '-5.8855075e-010+dlk2prf_hvt'
+WK2        = '-1.0212046e-008+dwk2prf_hvt'
+PK2        = '8.3764547e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitprf_hvt'
+LCIT       = '1.2700497e-010+dlcitprf_hvt'
+WCIT       = '-3.1452806e-010+dwcitprf_hvt'
+PCIT       = '1.478525e-017+dpcitprf_hvt'
+VOFF       = '-0.1071063+dvoffprf_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffprf_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffprf_hvt'
+PVOFF      = '3.6780146e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.00269+deta0prf_hvt'
+WETA0      = '3.162e-010+dweta0prf_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0prf_hvt'
+LU0        = '2.8729247e-010+dlu0prf_hvt'
+WU0        = '1.9076404e-009+dwu0prf_hvt'
+PU0        = '-2.8601153e-016+dpu0prf_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubprf_hvt'
+LUB        = '1.9066399e-027+dlubprf_hvt'
+WUB        = '3.0779517e-026+dwubprf_hvt'
+PUB        = '-3.0592342e-033+dpubprf_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatprf_hvt'  A0         = '-0.4400886+da0prf_hvt'
+LA0        = '4.149252e-007+dla0prf_hvt'
+WA0        = '1.6810163e-006+dwa0prf_hvt'
+PA0        = '-3.1149771e-013+dpa0prf_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmprf_hvt'
+LPCLM      = '1.2227911e-007+dlpclmprf_hvt'
+WPCLM      = '9.3617077e-007+dwpclmprf_hvt'
+PPCLM      = '-1.1406153e-013+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datprf_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )    


.MODEL pch_rf_hvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-1.262382e-009+dlvthprf_hvt'
+WVTH0      = '-1.4087635e-008+dwvthprf_hvt'
+PVTH0      = '7.505766e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2prf_hvt'
+LK2        = '-1.0794234e-009+dlk2prf_hvt'
+WK2        = '-7.190122e-009+dwk2prf_hvt'
+PK2        = '5.3998597e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitprf_hvt'
+LCIT       = '9.8047363e-011+dlcitprf_hvt'
+WCIT       = '-2.0844672e-009+dwcitprf_hvt'
+PCIT       = '1.8912425e-016+dpcitprf_hvt'
+VOFF       = '-0.12945599+dvoffprf_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffprf_hvt'
+WVOFF      = '6.3228005e-009+dwvoffprf_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '-0.0055935647+deta0prf_hvt'
+LETA0      = '8.1593113e-010+dleta0prf_hvt'
+WETA0      = '3.3467169e-009+dweta0prf_hvt'
+PETA0      = '-2.9850592e-016+dpeta0prf_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0prf_hvt'
+LU0        = '-6.3113981e-010+dlu0prf_hvt'
+WU0        = '-4.6503664e-009+dwu0prf_hvt'
+PU0        = '3.5995213e-016+dpu0prf_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubprf_hvt'
+LUB        = '7.2916293e-029+dlubprf_hvt'
+WUB        = '-1.2410913e-026+dwubprf_hvt'
+PUB        = '1.1950231e-033+dpubprf_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatprf_hvt-8659.12*ff_flagrf_hvt'
+A0         = '6.2698767+da0prf_hvt'
+LA0        = '-2.4600638e-007+dla0prf_hvt'
+WA0        = '-3.4747068e-006+dwa0prf_hvt'
+PA0        = '1.9634101e-013+dpa0prf_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmprf_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmprf_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmprf_hvt'
+PPCLM      = '8.7145749e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2prf_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datprf_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt+0.000852921*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt+0.00536865*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt-5.28811e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL pdio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.04                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.000204                
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0016                  FCS    = 0			   )

.MODEL pdio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswgprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.92                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.0008                  
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1.22                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0003                  FCS    = 0			   )

.ends pmos_rf_hvt_nw

.subckt nmos_rf_hvt_6t D G S B NG PG lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parn1rf_hvt  temp2=parn2rf_hvt
+fac1='0.513264*temp1*sigma+0.858231*temp2*sigma'
+fac2='0.513264*temp1*sigma-0.858231*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_hvt='(0.0065945219859-0.000546287615/(lef*1e6)+0.00003025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_hvt='0.00226307*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_hvt='-0.00226307*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_hvt='0.00226307*geo_fac*toxnrf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1681.8*lr*scale/nr/(wr*scale)+1.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='4.491e05/(lr*scale*1e6)+1.770e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4761'

.param fn_dice='noiseflagnrf_hvt_mc*par1fn_mc+noiseflagnrf_hvt_mc_mis*par2fnrf_hvt_mc'
.param c1fnrf_hvt=3E+42           c2fnrf_hvt=1.00E+23           c3fnrf_hvt=1.00E+7   
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(7.5E-6*1E-6*1))**0.5)))'
.param noianrf_hvt='c1fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'
.param noibnrf_hvt='c2fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'
.param noicnrf_hvt='c3fnrf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_hvt    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_hvt  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx    
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_hvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT NMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************


.MODEL nch_rf_hvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+LMAX       = 2.401e-007			
+WMIN       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+WMAX       = 6.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'
+DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51029903+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '-3.4568481e-009+dlvthnrf_hvt'
+WVTH0      = '1.7612109e-009+dwvthnrf_hvt'
+PVTH0      = '1.9820236e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0068379101+dk2nrf_hvt'
+LK2        = '-1.7834614e-009+dlk2nrf_hvt'
+WK2        = '-1.9940316e-008+dwk2nrf_hvt'
+PK2        = '1.7118143e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049520102+dcitnrf_hvt'
+LCIT       = '1.3082307e-010+dlcitnrf_hvt'
+WCIT       = '2.420774e-011+dwcitnrf_hvt'
+PCIT       = '-2.1570692e-017+dpcitnrf_hvt'
+VOFF       = '-0.14181909+dvoffnrf_hvt'
+LVOFF      = '-2.9141003e-009+dlvoffnrf_hvt'
+WVOFF      = '-3.0824876e-008+dwvoffnrf_hvt'
+PVOFF      = '1.882346e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '0.054322285+deta0nrf_hvt'
+LETA0      = '-5.43961e-014+dleta0nrf_hvt'
+WETA0      = '-5.3612063e-009+dweta0nrf_hvt'
+PETA0      = '8.8158482e-021+dpeta0nrf_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010674795+du0nrf_hvt'
+LU0        = '1.4865632e-011+dlu0nrf_hvt'
+UA         = -1.7554817e-009     LUA        = 4.8032508e-018      WUA        = 1.8406019e-016
+PUA        = -6.7525646e-024     UB         = 1.5597693e-018      LUB        = 1.8962419e-027
+WUB        = -1.8611524e-025     PUB        = 4.6287498e-033      UC         = 6.0350359e-011
+LUC        = 1.2160087e-019      WUC        = -1.2276744e-016     PUC        = 9.0428094e-024
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '1.405171+da0nrf_hvt' LA0        = '-1.5789634e-007+dla0nrf_hvt'
+WA0        = '-3.2635924e-007+dwa0nrf_hvt'
+PA0        = '8.62959e-014+dpa0nrf_hvt'
+AGS        = 3.0235749           LAGS       = -1.7466347e-007     WAGS       = -2.6515905e-006
+PAGS       = 2.5397146e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.053375301
+LKETA      = -6.1921743e-009     WKETA      = 8.0470522e-008      PKETA      = -3.9408717e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.012039198+dpclmnrf_hvt'
+LPCLM      = 6.7062822e-008      WPCLM      = 8.1876225e-009      PPCLM      = 8.3788294e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2nrf_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2nrf_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'
+RDW        = '52.68+drdswnrf_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010745391
+LAIGSD     = 9.2277033e-012      WAIGSD     = -4.3800595e-011     PAIGSD     = -2.6259973e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'
+CGDO       = 'cgonrf_hvt'          CGBO       = 0                   CGDL       = 'cglnrf_hvt'
+CGSL       = 'cglnrf_hvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016164685        LTVOFF     = -1.5095014e-010
+WTVOFF     = -1.476013e-009      PTVOFF     = 1.7806138e-016      KT1        = -0.2886127
+LKT1       = -1.2022581e-008     WKT1       = -2.5745648e-008     PKT1       = 6.2419957e-015
+KT1L       = 0                   KT2        = -0.081503825        LKT2       = -4.2581776e-011
+WKT2       = -9.6903242e-009     PKT2       = 1.5024456e-015      UTE        = -1
+UA1        = 5.5431357e-010      LUA1       = 4.4335296e-017      WUA1       = 2.5673461e-017
+PUA1       = -3.0479576e-023     UB1        = -4.7522522e-019     LUB1       = -3.3992745e-026
+WUB1       = 4.0088836e-027      PUB1       = 1.1254274e-032      UC1        = 1.4667601e-010
+LUC1       = -5.9821505e-018     WUC1       = -2.6719068e-017     PUC1       = 5.2519947e-025
+PRT        = 0                   AT         = '63846.319+datnrf_hvt'
+LAT        = -0.0020618081       WAT        = -0.0047370519       PAT        = -5.2519947e-010
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+WU0        = '0+dwu0nrf_hvt'       PU0        = '0+dpu0nrf_hvt'       LVSAT      = '0+dlvsatnrf_hvt'
+WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf_hvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+WMIN       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'    DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46122686+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '1.2433235e-009+dlvthnrf_hvt'
+WVTH0      = '2.3057213e-008+dwvthnrf_hvt'
+PVTH0      = '-5.7724504e-017+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0089135286+dk2nrf_hvt'
+LK2        = '-1.584657e-009+dlk2nrf_hvt'
+WK2        = '-1.8011708e-008+dwk2nrf_hvt'
+PK2        = '1.5270907e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.2775734e-005+dcitnrf_hvt'
+LCIT       = '1.7415672e-010+dlcitnrf_hvt'
+WCIT       = '1.2127215e-010+dwcitnrf_hvt'
+PCIT       = '-3.08676e-017+dpcitnrf_hvt'
+VOFF       = '-0.12918363+dvoffnrf_hvt'
+LVOFF      = '-4.1243344e-009+dlvoffnrf_hvt'
+WVOFF      = '-1.7751302e-008+dwvoffnrf_hvt'
+PVOFF      = '6.3014862e-016+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '-0.0038339129+deta0nrf_hvt'
+LETA0      = '5.5701928e-009+dleta0nrf_hvt'
+WETA0      = '7.9124665e-009+dweta0nrf_hvt'
+PETA0      = '-1.2713542e-015+dpeta0nrf_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010717766+du0nrf_hvt'
+LU0        = '1.0749846e-011+dlu0nrf_hvt'
+UA         = -1.8691811e-009     LUA        = 1.5693471e-017      WUA        = -8.7281901e-017
+PUA        = 1.9236798e-023      UB         = 1.5879251e-018      LUB        = -8.0054308e-028
+WUB        = 1.9551478e-025      PUB        = -3.1924079e-032     UC         = 7.2032623e-011
+LUC        = -9.9733571e-019     WUC        = 1.6075185e-017      PUC        = -4.255648e-024
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '3.1625332+da0nrf_hvt'
+LA0        = '-3.262179e-007+dla0nrf_hvt'
+WA0        = '-1.6825379e-007+dwa0nrf_hvt'
+PA0        = '7.1152433e-014+dpa0nrf_hvt'
+AGS        = -1.0966783          LAGS       = 2.1997769e-007      WAGS       = -7.3831551e-006
+PAGS       = 7.071645e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.22825247
+LKETA      = 1.05577e-008        WKETA      = 1.3120105e-007      PKETA      = -8.7998818e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.71125481+dpclmnrf_hvt'
+LPCLM      = 9.1391598e-011      WPCLM      = -2.438004e-008      PPCLM      = 1.1498186e-014
+PDIBLC1    = 0
+PDIBLC2    = '-0.00078408711+dpdiblc2nrf_hvt-0.00320674*ff_flagrf_hvt'
+LPDIBLC2   = '1.7088129e-010+dlpdiblc2nrf_hvt+3.07143e-10*ff_flagrf_hvt'
+WPDIBLC2   = '1.8110816e-009-4.5e-15*ff_flagrf_hvt'
+PPDIBLC2   = '-1.7346684e-016-4.2e-22*ff_flagrf_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 8.9756956e-009      LAGIDL     = -2.3448056e-016     WAGIDL     = -2.4529918e-014
+PAGIDL     = 2.3494952e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010802719         LAIGSD     = 3.7368513e-012
+WAIGSD     = -4.0900567e-010     PAIGSD     = 8.7196609e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'          CGDO       = 'cgonrf_hvt'
+CGBO       = 0                   CGDL       = 'cglnrf_hvt'          CGSL       = 'cglnrf_hvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0011725623       LTVOFF     = 1.1618546e-010      WTVOFF     = 1.3030646e-009
+PTVOFF     = -8.8120893e-017     KT1        = -0.50365453         LKT1       = 8.574298e-009
+WKT1       = 1.1812929e-007      PKT1       = -7.5384608e-015     KT1L       = 0
+KT2        = -0.0972308          LKT2       = 1.4637605e-009      WKT2       = 1.8446502e-009
+PKT2       = 3.9761654e-016      UTE        = -1                  UA1        = 2.2638308e-009
+LUA1       = -1.1940363e-016     WUA1       = -1.1202924e-015     PUA1       = 7.9281947e-023
+UB1        = -1.7844563e-018     LUB1       = 9.1406454e-026      WUB1       = 7.5148988e-025
+PUB1       = -6.0340054e-032     UC1        = 9.2788654e-011      LUC1       = -8.2077635e-019
+WUC1       = -3.9625329e-017     PUC1       = 1.7613715e-024      PRT        = 0
+AT         = '56281.889+datnrf_hvt'
+LAT        = -0.0013372809       WAT        = -0.016775112        PAT        = 6.2781559e-010
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+WU0        = '0+dwu0nrf_hvt'       PU0        = '0+dpu0nrf_hvt'       LVSAT      = '0+dlvsatnrf_hvt'
+WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )   


.MODEL nch_rf_hvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+LMAX       = 2.401e-007			
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'
+DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48556798+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '1.1250376e-009+dlvthnrf_hvt'
+WVTH0      = '2.6986884e-008+dwvthnrf_hvt'
+PVTH0      = '-2.6914998e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.014789467+dk2nrf_hvt'
+LK2        = '-3.3319642e-010+dlk2nrf_hvt'
+WK2        = '-1.1829728e-008+dwk2nrf_hvt'
+PK2        = '2.3254395e-016+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028841387+dcitnrf_hvt'
+LCIT       = '-1.0469212e-010+dlcitnrf_hvt'
+WCIT       = '-2.4125087e-009+dwcitnrf_hvt'
+PCIT       = '2.186548e-016+dpcitnrf_hvt'
+VOFF       = '-0.13884306+dvoffnrf_hvt'
+LVOFF      = '-4.0172593e-009+dlvoffnrf_hvt'
+WVOFF      = '-3.3860426e-008+dwvoffnrf_hvt'
+PVOFF      = '3.0075683e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '0.013614777+deta0nrf_hvt'
+LETA0      = '-8.5871322e-014+dleta0nrf_hvt'
+WETA0      = '3.6160453e-008+dweta0nrf_hvt'
+PETA0      = '4.0920575e-020+dpeta0nrf_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011933619+du0nrf_hvt'
+LU0        = '-3.8898403e-011+dlu0nrf_hvt'
+WU0        = '-1.2840002e-009+dwu0nrf_hvt'
+PU0        = '5.4839316e-017+dpu0nrf_hvt'
+UA         = -1.6143173e-009     LUA        = -2.5370678e-017     WUA        = 4.0072486e-017
+PUA        = 2.4024843e-023      UB         = 1.427875e-018       LUB        = 3.8898349e-026
+WUB        = -5.158308e-026      PUB        = -3.3113399e-032     UC         = -9.4317845e-011
+LUC        = 2.3526431e-017      WUC        = 3.4994131e-017      PUC        = -1.4830118e-023
+VSAT       = '85000+dvsatnrf_hvt'  A0         = '1.4060353+da0nrf_hvt'
+LA0        = '-1.3455132e-007+dla0nrf_hvt'
+WA0        = '-3.2724079e-007+dwa0nrf_hvt'
+PA0        = '6.2483975e-014+dpa0nrf_hvt'
+AGS        = -4.3278073          LAGS       = 7.0745881e-007      WAGS       = 4.8468194e-006
+PAGS       = -6.4579327e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.06923171
+LKETA      = -2.2877216e-008     WKETA      = -4.4588629e-008     PKETA      = 1.3077871e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.18340503+dpclmnrf_hvt'
+LPCLM      = 1.1231153e-007      WPCLM      = 2.0754074e-007      PPCLM      = -3.7774855e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.0060264624+dpdiblc2nrf_hvt'
+LPDIBLC2   = '6.7300019e-010+dlpdiblc2nrf_hvt'
+WPDIBLC2   = 5.4255947e-009      PPDIBLC2   = -5.196678e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.125462e-008      WAGIDL     = 1.8137864e-014      BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010725544
+LAIGSD     = -6.7721212e-011     WAIGSD     = -2.3555899e-011     PAIGSD     = 5.222792e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'
+CGDO       = 'cgonrf_hvt'          CGBO       = 0                   CGDL       = 'cglnrf_hvt'
+CGSL       = 'cglnrf_hvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -2.3944289e-005     LTVOFF     = 8.148018e-011
+WTVOFF     = 1.9720807e-010      PTVOFF     = -5.9017549e-017     KT1        = -0.3895338
+LKT1       = -2.7004246e-010     WKT1       = 7.7193873e-008      PKT1       = -5.7455934e-015
+KT1L       = 0                   KT2        = -0.11399975         LKT2       = 3.6552111e-009
+WKT2       = 2.3455522e-008      PKT2       = -2.2693031e-015     UTE        = -1
+UA1        = 7.384309e-010       LUA1       = 5.0950433e-017      WUA1       = -1.6212622e-016
+PUA1       = -3.7227017e-023     UB1        = -5.5970626e-019     LUB1       = -6.8530563e-026
+WUB1       = 9.017955e-026       PUB1       = 4.6482849e-032      UC1        = 1.8326101e-010
+LUC1       = -1.5221581e-017     WUC1       = -6.4035764e-017     PUC1       = 9.9494187e-024
+PRT        = 0                   AT         = '50471.488+datnrf_hvt'
+LAT        = -0.0013990211       WAT        = 0.0089052757        PAT        = -1.2012422e-009
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+LVSAT      = '0+dlvsatnrf_hvt'     WVSAT      = '0+dwvsatnrf_hvt'     PVSAT      = '0+dpvsatnrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL nch_rf_hvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999926e-008-(dxlnrf_hvt+dlmisnrf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_hvt+dwmisnrf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_hvt+toxmisnrf_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_hvt+dlmisnrf_hvt)'   XW         = '2e-08+(dxwnrf_hvt+dwmisnrf_hvt)'    DLC        = '-5.415E-09+ddlcnrf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.52889853+(dvthnrf_hvt+vthmisnrf_hvt)'
+LVTH0      = '-3.0251973e-009+dlvthnrf_hvt'
+WVTH0      = '-4.5967889e-008+dwvthnrf_hvt'
+PVTH0      = '4.2961667e-015+dpvthnrf_hvt'
+K1         = 0.48686             K2         = '-0.0034807992+dk2nrf_hvt'
+LK2        = '-1.4163497e-009+dlk2nrf_hvt'
+WK2        = '-2.3553092e-008+dwk2nrf_hvt'
+PK2        = '1.3554172e-015+dpk2nrf_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0022436261+dcitnrf_hvt+0.00149113*ff_flagrf_hvt'
+LCIT       = '3.8644929e-010+dlcitnrf_hvt-1.42821e-10*ff_flagrf_hvt'
+WCIT       = '2.453402e-009+dwcitnrf_hvt-1.52096e-09*ff_flagrf_hvt'
+PCIT       = '-2.4740602e-016+dpcitnrf_hvt+1.45678e-16*ff_flagrf_hvt'
+VOFF       = '-0.15526103+dvoffnrf_hvt'
+LVOFF      = '-2.4447333e-009+dlvoffnrf_hvt'
+WVOFF      = '8.8476402e-009+dwvoffnrf_hvt'
+PVOFF      = '-1.0830445e-015+dpvoffnrf_hvt'
+NFACTOR    = '1+dnfactornrf_hvt'   ETA0       = '-0.098943963+deta0nrf_hvt'
+LETA0      = '1.078088e-008+dleta0nrf_hvt'
+WETA0      = '1.0492472e-007+dweta0nrf_hvt'
+PETA0      = '-6.5862555e-015+dpeta0nrf_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011390414+du0nrf_hvt'
+LU0        = '1.3130169e-011+dlu0nrf_hvt'
+WU0        = '-6.8610119e-010+dwu0nrf_hvt'
+PU0        = '-2.4279295e-018+dpu0nrf_hvt'
+UA         = -2.6549763e-009     LUA        = 7.4304472e-017      WUA        = 7.1422917e-016
+PUA        = -4.0546423e-023     UB         = 2.8034532e-018      LUB        = -9.2855625e-026
+WUB        = -1.0443238e-024     PUB        = 6.1972105e-032      UC         = 3.5201396e-010
+LUC        = -1.9223586e-017     WUC        = -2.6950578e-016     PUC        = 1.4335127e-023
+VSAT       = '75059.289+dvsatnrf_hvt'
+LVSAT      = '0.00095212923+dlvsatnrf_hvt'
+WVSAT      = '0.010139525+dwvsatnrf_hvt'
+PVSAT      = '-9.7117181e-010+dpvsatnrf_hvt'
+A0         = '3.6588742+da0nrf_hvt'
+LA0        = '-3.5033003e-007+dla0nrf_hvt'
+WA0        = '-6.7452153e-007+dwa0nrf_hvt'
+PA0        = '9.5746803e-014+dpa0nrf_hvt'
+AGS        = -12.31189           LAGS       = 1.4721806e-006      WAGS       = 4.0563604e-006
+PAGS       = -5.7008247e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.30170439
+LKETA      = 1.265134e-008       WKETA      = 2.0612201e-007      PKETA      = -1.0935395e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '1.4612224+dpclmnrf_hvt'
+LPCLM      = -4.5212201e-008     WPCLM      = -7.8934701e-007     PPCLM      = 5.770785e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0020245416+dpdiblc2nrf_hvt-0.00320674*ff_flagrf_hvt'
+LPDIBLC2   = '-9.8131414e-011+dlpdiblc2nrf_hvt+3.07142e-10*ff_flagrf_hvt'
+WPDIBLC2   = '-1.0537197e-009+3.3e-15*ff_flagrf_hvt'
+PPDIBLC2   = '1.0092612e-016-3.3e-22*ff_flagrf_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswnrf_hvt'  RDW        = '52.68+drdswnrf_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 7.6302591e-010      LAGIDL     = -1.1510597e-015     WAGIDL     = -1.6152995e-014
+PAGIDL     = 3.284406e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0084736815        LAIGSD     = 1.4796395e-010
+WAIGSD     = 1.9666123e-009      PAIGSD     = -1.3839198e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxnrf_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_hvt'          CGDO       = 'cgonrf_hvt'
+CGBO       = 0                   CGDL       = 'cglnrf_hvt'          CGSL       = 'cglnrf_hvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00087605272       LTVOFF     = -4.7222538e-012     WTVOFF     = -7.8652278e-010
+PTVOFF     = 3.5204978e-017      KT1        = -0.38345064         LKT1       = -8.5269239e-010
+WKT1       = -4.478684e-009      PKT1       = 2.0770694e-015      KT1L       = 0
+KT2        = -0.10972811         LKT2       = 3.2460696e-009      WKT2       = 1.4591905e-008
+PKT2       = -1.4203388e-015     UTE        = -1                  UA1        = 2.7399852e-009
+LUA1       = -1.4076004e-016     WUA1       = -1.6059698e-015     PUA1       = 1.0106548e-022
+UB1        = -2.8047868e-018     LUB1       = 1.4650505e-025      WUB1       = 1.792227e-024
+PUB1       = -1.1654062e-031     UC1        = -5.9952012e-012     LUC1       = 2.9055298e-018
+WUC1       = 6.1134203e-017      PUC1       = -2.0394608e-024     PRT        = 0
+AT         = '30229.258+datnrf_hvt'
+LAT        = 0.00053979585       WAT        = 0.0097985706        PAT        = -1.2868027e-009
+NOIA       = 'noianrf_hvt'			NOIB       = 'noibnrf_hvt'			NOIC       = 'noicnrf_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_hvt'  WNFACTOR   = '0+dwnfactornrf_hvt'  PNFACTOR   = '0+dpnfactornrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL ndio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 1.99e-07                IKR    = 1E10
+N      = 1                       BV     = 8.85                    IBV    = 0.03
+JSW    = 5.1e-13                 CJ     = 'cjnrf_hvt'             PJ     = 7.2E-4
+MJ     = 0.5                     FC     = 0                       CJSW   = 'cjswnrf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.05                    TLEVC  = 1
+CTA    = 0.000773                CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.0018                  FCS    = 0			   )

.MODEL ndio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 1.99e-07                IKR    = 1E10
+N      = 1                       BV     = 8.85                    IBV    = 0.03
+JSW    = 5.1e-13                 CJ     = 'cjnrf_hvt'             PJ     = 7.2E-4
+MJ     = 0.5                     FC     = 0                       CJSW   = 'cjswgnrf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.445                   TLEVC  = 1
+CTA    = 0.000773                CTP    = 0.00104                 
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1.02
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.00198                 FCS    = 0			   )

.MODEL PWDNW_nrf_hvt D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_hvt'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_hvt'
+ N      = '1.02*n_d_dnw_nrf_hvt'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_hvt)'  CJ     = '7.31E-04*cj_d_dnw_nrf_hvt'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_hvt'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_hvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_hvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_hvt'
+ N      = '1.02*n_d_dnw_nrf_hvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_hvt)'  CJ     = '1.15E-04*cj_d_dnw_nrf_hvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_hvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_hvt_6t

.subckt pmos_rf_hvt_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parp1rf_hvt  temp2=parp2rf_hvt
+fac1='0.865112*temp1*sigma+0.501579*temp2*sigma'
+fac2='0.865112*temp1*sigma-0.501579*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_hvt='(0.0037385-0.0003287615/(lef*1e6)+0.000021625807/(lef*lef*1e12)-0.00002287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_hvt = '0.00203822*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_hvt = '-0.00203822*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_hvt='0.00203822*geo_fac*toxprf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1963.4*lr*scale/nr/(wr*scale)+0.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.131e06/(lr*scale*1e6)+2.64e07'
.param rnoiax='0.00561/(lr*scale*1e6)+0.5135'

.param fn_dice='noiseflagprf_hvt_mc*par1fn_mc+noiseflagprf_hvt_mc_mis*par2fprf_hvt_mc'
.param c1fprf_hvt=2.10E+42           c2fprf_hvt=1.55E+24           c3fprf_hvt=1.00E+10     
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_hvt='c1fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noibprf_hvt='c2fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noicprf_hvt='c3fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_hvt  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx  

M0 DI GI SI BI pch_rf_hvt L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_hvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-7.2984626e-010+dlvthprf_hvt'
+WVTH0      = '-9.7044399e-009+dwvthprf_hvt'
+PVTH0      = '1.3534114e-015+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2prf_hvt'
+LK2        = '5.9104693e-010+dlk2prf_hvt'
+WK2        = '-1.0179173e-008+dwk2prf_hvt'
+PK2        = '-3.6554416e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitprf_hvt'
+LCIT       = '1.4213307e-010+dlcitprf_hvt'
+WCIT       = '-4.6699281e-010+dwcitprf_hvt'
+PCIT       = '-6.4541088e-019+dpcitprf_hvt'
+VOFF       = '-0.11759164+dvoffprf_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffprf_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffprf_hvt'
+PVOFF      = '1.6253402e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0052266667+deta0prf_hvt'
+WETA0      = '-2.2712e-009+dweta0prf_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0prf_hvt'
+LU0        = '1.7777142e-010+dlu0prf_hvt'
+WU0        = '1.018685e-009+dwu0prf_hvt'
+PU0        = '-1.7430005e-016+dpu0prf_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubprf_hvt'
+LUB        = '-8.2046654e-029+dlubprf_hvt'
+WUB        = '1.8606441e-027+dwubprf_hvt'
+PUB        = '-1.030774e-033+dpubprf_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatprf_hvt'  A0         = '1.8037767+da0prf_hvt'
+LA0        = '3.4946811e-008+dla0prf_hvt'
+WA0        = '-6.0772635e-007+dwa0prf_hvt'
+PA0        = '7.6080253e-014+dpa0prf_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmprf_hvt'
+LPCLM      = '3.3020183e-009+dlpclmprf_hvt'
+WPCLM      = '1.7467444e-008+dwpclmprf_hvt'
+PPCLM      = '7.2950988e-015+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datprf_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL pch_rf_hvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-3.0821854e-010+dlvthprf_hvt'
+WVTH0      = '6.2963879e-009+dwvthprf_hvt'
+PVTH0      = '-2.2267017e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2prf_hvt'
+LK2        = '-2.378406e-009+dlk2prf_hvt'
+WK2        = '-3.2823766e-008+dwk2prf_hvt'
+PK2        = '1.8649482e-015+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitprf_hvt'
+LCIT       = '2.7955334e-010+dlcitprf_hvt'
+WCIT       = '-5.1403406e-010+dwcitprf_hvt'
+PCIT       = '3.988153e-018+dpcitprf_hvt'
+VOFF       = '-0.094349901+dvoffprf_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffprf_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffprf_hvt'
+PVOFF      = '2.1065519e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0016702266+deta0prf_hvt'
+LETA0      = '3.5030935e-010+dleta0prf_hvt'
+WETA0      = '-4.0623502e-009+dweta0prf_hvt'
+PETA0      = '1.7642829e-016+dpeta0prf_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0prf_hvt'
+LU0        = '-3.7049814e-010+dlu0prf_hvt'
+WU0        = '-1.7061645e-009+dwu0prf_hvt'
+PU0        = '9.4097621e-017+dpu0prf_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubprf_hvt'
+LUB        = '6.3755797e-028+dlubprf_hvt'
+WUB        = '-1.488923e-026+dwubprf_hvt'
+PUB        = '6.1908859e-034+dpubprf_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatprf_hvt+384.85*ff_flagrf_hvt'
+A0         = '2.8058311+da0prf_hvt'
+LA0        = '-6.375555e-008+dla0prf_hvt'
+WA0        = '5.861974e-008+dwa0prf_hvt'
+PA0        = '1.0445163e-014+dpa0prf_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmprf_hvt'
+LPCLM      = '1.4911452e-008+dlpclmprf_hvt'
+WPCLM      = '4.4648173e-007+dwpclmprf_hvt'
+PPCLM      = '-3.4962808e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2prf_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datprf_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt-3.79076e-05*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt-0.00385619*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt+3.79834e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL pch_rf_hvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '1.4188652e-009+dlvthprf_hvt'
+WVTH0      = '2.0428322e-009+dwvthprf_hvt'
+PVTH0      = '-8.3827437e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2prf_hvt'
+LK2        = '-5.8855075e-010+dlk2prf_hvt'
+WK2        = '-1.0212046e-008+dwk2prf_hvt'
+PK2        = '8.3764547e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitprf_hvt'
+LCIT       = '1.2700497e-010+dlcitprf_hvt'
+WCIT       = '-3.1452806e-010+dwcitprf_hvt'
+PCIT       = '1.478525e-017+dpcitprf_hvt'
+VOFF       = '-0.1071063+dvoffprf_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffprf_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffprf_hvt'
+PVOFF      = '3.6780146e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.00269+deta0prf_hvt'
+WETA0      = '3.162e-010+dweta0prf_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0prf_hvt'
+LU0        = '2.8729247e-010+dlu0prf_hvt'
+WU0        = '1.9076404e-009+dwu0prf_hvt'
+PU0        = '-2.8601153e-016+dpu0prf_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubprf_hvt'
+LUB        = '1.9066399e-027+dlubprf_hvt'
+WUB        = '3.0779517e-026+dwubprf_hvt'
+PUB        = '-3.0592342e-033+dpubprf_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatprf_hvt'  A0         = '-0.4400886+da0prf_hvt'
+LA0        = '4.149252e-007+dla0prf_hvt'
+WA0        = '1.6810163e-006+dwa0prf_hvt'
+PA0        = '-3.1149771e-013+dpa0prf_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmprf_hvt'
+LPCLM      = '1.2227911e-007+dlpclmprf_hvt'
+WPCLM      = '9.3617077e-007+dwpclmprf_hvt'
+PPCLM      = '-1.1406153e-013+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datprf_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL pch_rf_hvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-1.262382e-009+dlvthprf_hvt'
+WVTH0      = '-1.4087635e-008+dwvthprf_hvt'
+PVTH0      = '7.505766e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2prf_hvt'
+LK2        = '-1.0794234e-009+dlk2prf_hvt'
+WK2        = '-7.190122e-009+dwk2prf_hvt'
+PK2        = '5.3998597e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitprf_hvt'
+LCIT       = '9.8047363e-011+dlcitprf_hvt'
+WCIT       = '-2.0844672e-009+dwcitprf_hvt'
+PCIT       = '1.8912425e-016+dpcitprf_hvt'
+VOFF       = '-0.12945599+dvoffprf_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffprf_hvt'
+WVOFF      = '6.3228005e-009+dwvoffprf_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '-0.0055935647+deta0prf_hvt'
+LETA0      = '8.1593113e-010+dleta0prf_hvt'
+WETA0      = '3.3467169e-009+dweta0prf_hvt'
+PETA0      = '-2.9850592e-016+dpeta0prf_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0prf_hvt'
+LU0        = '-6.3113981e-010+dlu0prf_hvt'
+WU0        = '-4.6503664e-009+dwu0prf_hvt'
+PU0        = '3.5995213e-016+dpu0prf_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubprf_hvt'
+LUB        = '7.2916293e-029+dlubprf_hvt'
+WUB        = '-1.2410913e-026+dwubprf_hvt'
+PUB        = '1.1950231e-033+dpubprf_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatprf_hvt-8659.12*ff_flagrf_hvt'
+A0         = '6.2698767+da0prf_hvt'
+LA0        = '-2.4600638e-007+dla0prf_hvt'
+WA0        = '-3.4747068e-006+dwa0prf_hvt'
+PA0        = '1.9634101e-013+dpa0prf_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmprf_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmprf_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmprf_hvt'
+PPCLM      = '8.7145749e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2prf_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datprf_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt+0.000852921*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt+0.00536865*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt-5.28811e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   ) 


.MODEL pdio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.04                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.000204                
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0016                  FCS    = 0			   )

.MODEL pdio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswgprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.92                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.0008                  
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1.22                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0003                  FCS    = 0			   )

.MODEL DNWPSUB_prf_hvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_hvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_hvt'
+ N      = '1.02*n_d_dnw_prf_hvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_hvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_hvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_hvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_hvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_hvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_hvt'
+ N      = '1.02*n_d_prf_hvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_hvt)'  CJ     = '1.37E-04*cj_d_prf_hvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_hvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_hvt_5t


.subckt pmos_rf_hvt_nw_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_hvt'
.param
+temp1=parp1rf_hvt  temp2=parp2rf_hvt
+fac1='0.865112*temp1*sigma+0.501579*temp2*sigma'
+fac2='0.865112*temp1*sigma-0.501579*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_hvt='(0.0037385-0.0003287615/(lef*1e6)+0.000021625807/(lef*lef*1e12)-0.00002287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_hvt = '0.00203822*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_hvt = '-0.00203822*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_hvt='0.00203822*geo_fac*toxprf_hvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1963.4*lr*scale/nr/(wr*scale)+0.6)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.131e06/(lr*scale*1e6)+2.64e07'
.param rnoiax='0.00561/(lr*scale*1e6)+0.5135'

.param fn_dice='noiseflagprf_hvt_mc*par1fn_mc+noiseflagprf_hvt_mc_mis*par2fprf_hvt_mc'
.param c1fprf_hvt=2.10E+42           c2fprf_hvt=1.55E+24           c3fprf_hvt=1.00E+10     
.param arearatio='sigma_factor_flicker_rf_hvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_hvt='c1fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noibprf_hvt='c2fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'
.param noicprf_hvt='c3fprf_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_hvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_hvt  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_hvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_hvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_hvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_hvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx  
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx  

M0 DI GI SI BI pch_rf_hvt L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_hvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-7.2984626e-010+dlvthprf_hvt'
+WVTH0      = '-9.7044399e-009+dwvthprf_hvt'
+PVTH0      = '1.3534114e-015+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2prf_hvt'
+LK2        = '5.9104693e-010+dlk2prf_hvt'
+WK2        = '-1.0179173e-008+dwk2prf_hvt'
+PK2        = '-3.6554416e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitprf_hvt'
+LCIT       = '1.4213307e-010+dlcitprf_hvt'
+WCIT       = '-4.6699281e-010+dwcitprf_hvt'
+PCIT       = '-6.4541088e-019+dpcitprf_hvt'
+VOFF       = '-0.11759164+dvoffprf_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffprf_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffprf_hvt'
+PVOFF      = '1.6253402e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0052266667+deta0prf_hvt'
+WETA0      = '-2.2712e-009+dweta0prf_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0prf_hvt'
+LU0        = '1.7777142e-010+dlu0prf_hvt'
+WU0        = '1.018685e-009+dwu0prf_hvt'
+PU0        = '-1.7430005e-016+dpu0prf_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubprf_hvt'
+LUB        = '-8.2046654e-029+dlubprf_hvt'
+WUB        = '1.8606441e-027+dwubprf_hvt'
+PUB        = '-1.030774e-033+dpubprf_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatprf_hvt'  A0         = '1.8037767+da0prf_hvt'
+LA0        = '3.4946811e-008+dla0prf_hvt'
+WA0        = '-6.0772635e-007+dwa0prf_hvt'
+PA0        = '7.6080253e-014+dpa0prf_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmprf_hvt'
+LPCLM      = '3.3020183e-009+dlpclmprf_hvt'
+WPCLM      = '1.7467444e-008+dwpclmprf_hvt'
+PPCLM      = '7.2950988e-015+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datprf_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_rf_hvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-3.0821854e-010+dlvthprf_hvt'
+WVTH0      = '6.2963879e-009+dwvthprf_hvt'
+PVTH0      = '-2.2267017e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2prf_hvt'
+LK2        = '-2.378406e-009+dlk2prf_hvt'
+WK2        = '-3.2823766e-008+dwk2prf_hvt'
+PK2        = '1.8649482e-015+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitprf_hvt'
+LCIT       = '2.7955334e-010+dlcitprf_hvt'
+WCIT       = '-5.1403406e-010+dwcitprf_hvt'
+PCIT       = '3.988153e-018+dpcitprf_hvt'
+VOFF       = '-0.094349901+dvoffprf_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffprf_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffprf_hvt'
+PVOFF      = '2.1065519e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.0016702266+deta0prf_hvt'
+LETA0      = '3.5030935e-010+dleta0prf_hvt'
+WETA0      = '-4.0623502e-009+dweta0prf_hvt'
+PETA0      = '1.7642829e-016+dpeta0prf_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0prf_hvt'
+LU0        = '-3.7049814e-010+dlu0prf_hvt'
+WU0        = '-1.7061645e-009+dwu0prf_hvt'
+PU0        = '9.4097621e-017+dpu0prf_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubprf_hvt'
+LUB        = '6.3755797e-028+dlubprf_hvt'
+WUB        = '-1.488923e-026+dwubprf_hvt'
+PUB        = '6.1908859e-034+dpubprf_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatprf_hvt+384.85*ff_flagrf_hvt'
+A0         = '2.8058311+da0prf_hvt'
+LA0        = '-6.375555e-008+dla0prf_hvt'
+WA0        = '5.861974e-008+dwa0prf_hvt'
+PA0        = '1.0445163e-014+dpa0prf_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmprf_hvt'
+LPCLM      = '1.4911452e-008+dlpclmprf_hvt'
+WPCLM      = '4.4648173e-007+dwpclmprf_hvt'
+PPCLM      = '-3.4962808e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2prf_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datprf_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt-3.79076e-05*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt-0.00385619*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt+3.79834e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_hvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '1.4188652e-009+dlvthprf_hvt'
+WVTH0      = '2.0428322e-009+dwvthprf_hvt'
+PVTH0      = '-8.3827437e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2prf_hvt'
+LK2        = '-5.8855075e-010+dlk2prf_hvt'
+WK2        = '-1.0212046e-008+dwk2prf_hvt'
+PK2        = '8.3764547e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitprf_hvt'
+LCIT       = '1.2700497e-010+dlcitprf_hvt'
+WCIT       = '-3.1452806e-010+dwcitprf_hvt'
+PCIT       = '1.478525e-017+dpcitprf_hvt'
+VOFF       = '-0.1071063+dvoffprf_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffprf_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffprf_hvt'
+PVOFF      = '3.6780146e-015+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '0.00269+deta0prf_hvt'
+WETA0      = '3.162e-010+dweta0prf_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0prf_hvt'
+LU0        = '2.8729247e-010+dlu0prf_hvt'
+WU0        = '1.9076404e-009+dwu0prf_hvt'
+PU0        = '-2.8601153e-016+dpu0prf_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubprf_hvt'
+LUB        = '1.9066399e-027+dlubprf_hvt'
+WUB        = '3.0779517e-026+dwubprf_hvt'
+PUB        = '-3.0592342e-033+dpubprf_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatprf_hvt'  A0         = '-0.4400886+da0prf_hvt'
+LA0        = '4.149252e-007+dla0prf_hvt'
+WA0        = '1.6810163e-006+dwa0prf_hvt'
+PA0        = '-3.1149771e-013+dpa0prf_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmprf_hvt'
+LPCLM      = '1.2227911e-007+dlpclmprf_hvt'
+WPCLM      = '9.3617077e-007+dwpclmprf_hvt'
+PPCLM      = '-1.1406153e-013+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2prf_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datprf_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LETA0      = '0+dleta0prf_hvt'     PETA0      = '0+dpeta0prf_hvt'     LVSAT      = '0+dlvsatprf_hvt'
+WVSAT      = '0+dwvsatprf_hvt'     PVSAT      = '0+dpvsatprf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_hvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_hvt+dlmisprf_hvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_hvt+dwmisprf_hvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_hvt+toxmisprf_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_hvt+dlmisprf_hvt)'    XW         = '2e-08+(dxwprf_hvt+dwmisprf_hvt)'    DLC        = '-6.55e-09+ddlcprf_hvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+(dvthprf_hvt+vthmisprf_hvt)'
+LVTH0      = '-1.262382e-009+dlvthprf_hvt'
+WVTH0      = '-1.4087635e-008+dwvthprf_hvt'
+PVTH0      = '7.505766e-016+dpvthprf_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2prf_hvt'
+LK2        = '-1.0794234e-009+dlk2prf_hvt'
+WK2        = '-7.190122e-009+dwk2prf_hvt'
+PK2        = '5.3998597e-016+dpk2prf_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitprf_hvt'
+LCIT       = '9.8047363e-011+dlcitprf_hvt'
+WCIT       = '-2.0844672e-009+dwcitprf_hvt'
+PCIT       = '1.8912425e-016+dpcitprf_hvt'
+VOFF       = '-0.12945599+dvoffprf_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffprf_hvt'
+WVOFF      = '6.3228005e-009+dwvoffprf_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffprf_hvt'
+NFACTOR    = '1+dnfactorprf_hvt'   ETA0       = '-0.0055935647+deta0prf_hvt'
+LETA0      = '8.1593113e-010+dleta0prf_hvt'
+WETA0      = '3.3467169e-009+dweta0prf_hvt'
+PETA0      = '-2.9850592e-016+dpeta0prf_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0prf_hvt'
+LU0        = '-6.3113981e-010+dlu0prf_hvt'
+WU0        = '-4.6503664e-009+dwu0prf_hvt'
+PU0        = '3.5995213e-016+dpu0prf_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubprf_hvt'
+LUB        = '7.2916293e-029+dlubprf_hvt'
+WUB        = '-1.2410913e-026+dwubprf_hvt'
+PUB        = '1.1950231e-033+dpubprf_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatprf_hvt-8659.12*ff_flagrf_hvt'
+A0         = '6.2698767+da0prf_hvt'
+LA0        = '-2.4600638e-007+dla0prf_hvt'
+WA0        = '-3.4747068e-006+dwa0prf_hvt'
+PA0        = '1.9634101e-013+dpa0prf_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmprf_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmprf_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmprf_hvt'
+PPCLM      = '8.7145749e-014+dppclmprf_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2prf_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswprf_hvt'  RDW        = '92.68+drdswprf_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxprf_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_hvt'          CGDO       = 'cgoprf_hvt'          CGBO       = 0
+CGDL       = 'cglprf_hvt'          CGSL       = 'cglprf_hvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datprf_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiaprf_hvt'			NOIB       = 'noibprf_hvt'			NOIC       = 'noicprf_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 0
+CJD        = 0			MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_hvt'  WNFACTOR   = '0+dwnfactorprf_hvt'  PNFACTOR   = '0+dpnfactorprf_hvt'
+LVSAT      = '0+dlvsatprf_hvt+0.000852921*ff_flagrf_hvt'
+WVSAT      = '0+dwvsatprf_hvt+0.00536865*ff_flagrf_hvt'
+PVSAT      = '0+dpvsatprf_hvt-5.28811e-10*ff_flagrf_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_hvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.04                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.000204                
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0016                  FCS    = 0			   )

.MODEL pdio_rf_hvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9.4                     IBV    = 0.03
+JSW    = 2.13e-13                CJ     = 'cjprf_hvt'             PJ     = 7.2E-4
+MJ     = 0.42                    FC     = 0                       CJSW   = 'cjswgprf_hvt'
+AREA   = 3.08E-8                 MJSW   = 0.92                    TLEVC  = 1
+CTA    = 0.000877                CTP    = 0.0008                  
+TCV    = -7.4E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1.22                    PB     = 1.02
+IK     = 1E20                    TPB    = 0.0023                  TREF   = 25
+TPHP   = 0.0003                  FCS    = 0			   )

.MODEL DNWPSUB_prf_hvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_hvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_hvt'
+ N      = '1.02*n_d_dnw_prf_hvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_hvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_hvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_hvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_hvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_hvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_hvt'
+ N      = '1.02*n_d_prf_hvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_hvt)'  CJ     = '1.37E-04*cj_d_prf_hvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_hvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_hvt_nw_5t


.ENDL RF_MOS_hvt




**************************************************************************************************
*
* 1.2V CORE mlvt MOS MODEL
*
*
*
*              .lib RF_MOS_mlvt
*
*              Model name             nr               lr (um)           wr (um)
*                                 low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_mlvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_mlvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_mlvt_nw     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              nmos_rf_mlvt_6t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_mlvt_5t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_mlvt_nw_5t  1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*           End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************


***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+A1rf_mlvt='par1*5.6347*3/1.99'
+A2rf_mlvt='par2*4.0042*3/1.99'
+A3rf_mlvt='par3*3.6874*3/1.99'
+A4rf_mlvt='par4*2.1364*3/1.99'
+A5rf_mlvt='par5*1.0272*3/1.99'
+toxnrf_mlvt      ='2.6e-09+(4.6487e-012)*A1rf_mlvt+(-1.0377e-011)*A2rf_mlvt+(-5.6685e-012)*A3rf_mlvt+(-5.5834e-012)*A4rf_mlvt+(9.2037e-013)*A5rf_mlvt'
+dxlnrf_mlvt      ='-6.000000e-009+(3.2055e-010)*A1rf_mlvt+(-8.797e-010)*A2rf_mlvt+(-5.1527e-010)*A3rf_mlvt+(-4.7864e-010)*A4rf_mlvt+(8.2509e-011)*A5rf_mlvt'
+dxwnrf_mlvt      ='0+(-2.4818e-010)*A1rf_mlvt+(2.2966e-009)*A2rf_mlvt+(4.7596e-011)*A3rf_mlvt+(9.4536e-010)*A4rf_mlvt+(-1.8637e-010)*A5rf_mlvt'
+dvthnrf_mlvt     ='0+(0.0022197)*A1rf_mlvt+(-0.0015133)*A2rf_mlvt+(0.0038396)*A3rf_mlvt+(0.00016367)*A4rf_mlvt+(-0.00012209)*A5rf_mlvt'
+dlvthnrf_mlvt    ='0+(1.5982e-010)*A1rf_mlvt+(-1.0896e-010)*A2rf_mlvt+(2.7645e-010)*A3rf_mlvt+(1.1785e-011)*A4rf_mlvt+(-8.7906e-012)*A5rf_mlvt'
+dwvthnrf_mlvt    ='0+(2.5185e-010)*A1rf_mlvt+(-1.7035e-010)*A2rf_mlvt+(4.6206e-010)*A3rf_mlvt+(-1.0387e-011)*A4rf_mlvt+(-1.4659e-011)*A5rf_mlvt'
+dpvthnrf_mlvt    ='0+(2.115e-017)*A1rf_mlvt+(-1.4238e-017)*A2rf_mlvt+(4.0107e-017)*A3rf_mlvt+(-2.3015e-018)*A4rf_mlvt+(-1.2708e-018)*A5rf_mlvt'
+cjnrf_mlvt       ='0.001251+(7.7749e-006)*A1rf_mlvt+(-5.3018e-006)*A2rf_mlvt+(1.3449e-005)*A3rf_mlvt+(5.7299e-007)*A4rf_mlvt+(-4.2758e-007)*A5rf_mlvt'
+cjswnrf_mlvt     ='9.5e-11+(5.9044e-013)*A1rf_mlvt+(-4.0255e-013)*A2rf_mlvt+(1.0213e-012)*A3rf_mlvt+(4.3537e-014)*A4rf_mlvt+(-3.2476e-014)*A5rf_mlvt'
+cjswgnrf_mlvt    ='2.04e-10+(1.2679e-012)*A1rf_mlvt+(-8.6443e-013)*A2rf_mlvt+(2.1932e-012)*A3rf_mlvt+(9.349e-014)*A4rf_mlvt+(-6.9739e-014)*A5rf_mlvt'
+cgonrf_mlvt      ='8.28670e-11+(-4.0247e-013)*A1rf_mlvt+(8.9839e-013)*A2rf_mlvt+(4.9077e-013)*A3rf_mlvt+(4.834e-013)*A4rf_mlvt+(-7.9683e-014)*A5rf_mlvt'
+cglnrf_mlvt      ='9.96116e-12+(-4.8378e-014)*A1rf_mlvt+(1.0799e-013)*A2rf_mlvt+(5.8994e-014)*A3rf_mlvt+(5.8102e-014)*A4rf_mlvt+(-9.5786e-015)*A5rf_mlvt'
+cfnrf_mlvt       ='1.200000e-010+(-5.8282e-013)*A1rf_mlvt+(1.301e-012)*A2rf_mlvt+(7.1068e-013)*A3rf_mlvt+(7.0001e-013)*A4rf_mlvt+(-1.1539e-013)*A5rf_mlvt+4.5e-11'
+ntoxnrf_mlvt     ='1+(-0.049161)*A1rf_mlvt+(0.097754)*A2rf_mlvt+(0.050659)*A3rf_mlvt+(0.032151)*A4rf_mlvt+(-0.0081093)*A5rf_mlvt'
+du0nrf_mlvt      ='0+(2.6636e-005)*A1rf_mlvt+(-1.816e-005)*A2rf_mlvt+(4.6076e-005)*A3rf_mlvt+(1.9641e-006)*A4rf_mlvt+(-1.4651e-006)*A5rf_mlvt'
+dlu0nrf_mlvt     ='0+(4.4394e-012)*A1rf_mlvt+(-3.0267e-012)*A2rf_mlvt+(7.6793e-012)*A3rf_mlvt+(3.2735e-013)*A4rf_mlvt+(-2.4418e-013)*A5rf_mlvt'
+dleta0nrf_mlvt   ='0+(-1.4514e-011)*A1rf_mlvt+(1.1253e-011)*A2rf_mlvt+(1.3087e-012)*A3rf_mlvt+(-3.0028e-011)*A4rf_mlvt+(-8.0882e-015)*A5rf_mlvt'
+dpeta0nrf_mlvt   ='0+(-2.0204e-018)*A1rf_mlvt+(1.1512e-018)*A2rf_mlvt+(-7.8974e-018)*A3rf_mlvt+(4.6773e-018)*A4rf_mlvt+(2.4553e-019)*A5rf_mlvt'
+dlvsatnrf_mlvt   ='0+(2.3721e-005)*A1rf_mlvt+(-8.8143e-007)*A2rf_mlvt+(1.0578e-005*0.84)*A3rf_mlvt+(5.929e-006)*A4rf_mlvt+(-1.3991e-006)*A5rf_mlvt'
+dpvsatnrf_mlvt   ='0+(-3.2327e-013)*A1rf_mlvt+(1.8419e-013)*A2rf_mlvt+(-1.2636e-012)*A3rf_mlvt+(7.4836e-013)*A4rf_mlvt+(3.9285e-014)*A5rf_mlvt'
+dk2nrf_mlvt      ='0+(0.00040353)*A1rf_mlvt+(-0.00027965)*A2rf_mlvt+(0.00060998)*A3rf_mlvt+(0.00012628)*A4rf_mlvt+(-1.9508e-005)*A5rf_mlvt'
+dlcitnrf_mlvt    ='0+(-1.3182e-012)*A1rf_mlvt+(-5.2657e-012)*A2rf_mlvt+(-4.6123e-012)*A3rf_mlvt+(-3.0987e-012)*A4rf_mlvt+(6.9126e-013)*A5rf_mlvt'
+dwcitnrf_mlvt    ='0+(-2.9027e-012)*A1rf_mlvt+(2.2506e-012)*A2rf_mlvt+(2.6174e-013)*A3rf_mlvt+(-6.0055e-012)*A4rf_mlvt+(-1.6176e-015)*A5rf_mlvt'
+dlvoffnrf_mlvt   ='0+(-4.4394e-011)*A1rf_mlvt+(3.0267e-011)*A2rf_mlvt+(-7.6793e-011)*A3rf_mlvt+(-3.2735e-012)*A4rf_mlvt+(2.4418e-012)*A5rf_mlvt'
+dpvoffnrf_mlvt   ='0+(8.4858e-018)*A1rf_mlvt+(-4.8351e-018)*A2rf_mlvt+(3.3169e-017)*A3rf_mlvt+(-1.9645e-017)*A4rf_mlvt+(-1.0312e-018)*A5rf_mlvt'
+dla0nrf_mlvt     ='0+(4.8379e-009)*A1rf_mlvt+(-3.751e-009)*A2rf_mlvt+(-4.3623e-010)*A3rf_mlvt+(1.0009e-008)*A4rf_mlvt+(2.6961e-012)*A5rf_mlvt'
+ss_flagrf_mlvt   ='0+(0.048379)*A1rf_mlvt+(-0.03751)*A2rf_mlvt+(-0.0043623)*A3rf_mlvt+(0.10009)*A4rf_mlvt+(2.6961e-005)*A5rf_mlvt'
+ff_flagrf_mlvt   ='0+(-0.047369)*A1rf_mlvt+(0.012053)*A2rf_mlvt+(-0.012002)*A3rf_mlvt+(0.12145)*A4rf_mlvt+(0.00011527)*A5rf_mlvt'
+sf_flagrf_mlvt   ='0+(-0.013094)*A1rf_mlvt+(-0.035826)*A2rf_mlvt+(0.065008)*A3rf_mlvt+(-0.0468)*A4rf_mlvt+(-0.21631)*A5rf_mlvt'
+fs_flagrf_mlvt   ='0+(0.012084)*A1rf_mlvt+(0.04371)*A2rf_mlvt+(-0.05977)*A3rf_mlvt+(-0.04295)*A4rf_mlvt+(-0.21896)*A5rf_mlvt'
+toxprf_mlvt      ='2.8e-09+(4.6487e-012)*A1rf_mlvt+(-1.0377e-011)*A2rf_mlvt+(-5.6685e-012)*A3rf_mlvt+(-5.5834e-012)*A4rf_mlvt+(9.2037e-013)*A5rf_mlvt'
+dxlprf_mlvt      ='max(-16e-9,-6.000000e-009+(3.2055e-010)*A1rf_mlvt+(-8.797e-010)*A2rf_mlvt+(-5.1527e-010)*A3rf_mlvt+(-4.7864e-010)*A4rf_mlvt+(8.2509e-011)*A5rf_mlvt)'
+dxwprf_mlvt      ='0+(-6.5104e-010)*A1rf_mlvt+(1.024e-009)*A2rf_mlvt+(2.044e-009)*A3rf_mlvt+(8.8377e-010)*A4rf_mlvt+(-1.4402e-010)*A5rf_mlvt'
+dvthprf_mlvt     ='0+(-0.0030978)*A1rf_mlvt+(-0.0016014)*A2rf_mlvt+(0.0011054)*A3rf_mlvt+(-0.00030495)*A4rf_mlvt+(0.00021883)*A5rf_mlvt'
+dlvthprf_mlvt    ='0+(-9.2761e-011)*A1rf_mlvt+(-1.9819e-011)*A2rf_mlvt+(2.7296e-011)*A3rf_mlvt+(-5.203e-011)*A4rf_mlvt+(5.0028e-012)*A5rf_mlvt'
+dwvthprf_mlvt    ='0+(-4.6791e-010)*A1rf_mlvt+(-3.044e-010)*A2rf_mlvt+(1.7988e-010)*A3rf_mlvt+(4.9267e-011)*A4rf_mlvt+(3.6499e-011)*A5rf_mlvt'
+dpvthprf_mlvt    ='max(-2.4e-16,0+(-3.5336e-017)*A1rf_mlvt+(-2.2643e-017)*A2rf_mlvt+(1.3513e-017)*A3rf_mlvt+(3.1945e-018)*A4rf_mlvt+(2.7373e-018)*A5rf_mlvt)'
+cjprf_mlvt       ='0.001077+(9.7309e-006)*A1rf_mlvt+(5.0307e-006)*A2rf_mlvt+(-3.4717e-006)*A3rf_mlvt+(9.5824e-007)*A4rf_mlvt+(-6.8748e-007)*A5rf_mlvt'
+cjswprf_mlvt     ='7.5e-11+(6.7764e-013)*A1rf_mlvt+(3.503e-013)*A2rf_mlvt+(-2.4181e-013)*A3rf_mlvt+(6.6709e-014)*A4rf_mlvt+(-4.787e-014)*A5rf_mlvt'
+cjswgprf_mlvt    ='2.2e-10+(1.9877e-012)*A1rf_mlvt+(1.0275e-012)*A2rf_mlvt+(-7.0932e-013)*A3rf_mlvt+(1.9568e-013)*A4rf_mlvt+(-1.4042e-013)*A5rf_mlvt'
+cgoprf_mlvt      ='7.70111e-11+(-3.7403e-013)*A1rf_mlvt+(8.3491e-013)*A2rf_mlvt+(4.5609e-013)*A3rf_mlvt+(4.4924e-013)*A4rf_mlvt+(-7.4052e-014)*A5rf_mlvt'
+cglprf_mlvt      ='2.69027e-11+(-1.3066e-013)*A1rf_mlvt+(2.9166e-013)*A2rf_mlvt+(1.5933e-013)*A3rf_mlvt+(1.5693e-013)*A4rf_mlvt+(-2.5869e-014)*A5rf_mlvt'
+cfprf_mlvt       ='1.200000e-010+(-5.8282e-013)*A1rf_mlvt+(1.301e-012)*A2rf_mlvt+(7.1068e-013)*A3rf_mlvt+(7.0001e-013)*A4rf_mlvt+(-1.1539e-013)*A5rf_mlvt+5.6e-11'
+drdswprf_mlvt    ='0+(-2.5815)*A1rf_mlvt+(-1.3345)*A2rf_mlvt+(0.9212)*A3rf_mlvt+(-0.25413)*A4rf_mlvt+(0.18236)*A5rf_mlvt'
+ntoxprf_mlvt     ='1+(-0.14472)*A1rf_mlvt+(0.24058)*A2rf_mlvt+(0.11255)*A3rf_mlvt+(-0.011274)*A4rf_mlvt+(-0.017477)*A5rf_mlvt'
+du0prf_mlvt      ='0+(5.1629e-005)*A1rf_mlvt+(2.6689e-005)*A2rf_mlvt+(-1.8424e-005)*A3rf_mlvt+(5.0826e-006)*A4rf_mlvt+(-3.6472e-006)*A5rf_mlvt'
+dlu0prf_mlvt     ='0+(-4.1497e-012)*A1rf_mlvt+(-3.9013e-012)*A2rf_mlvt+(4.5378e-012)*A3rf_mlvt+(-4.447e-013)*A4rf_mlvt+(3.1606e-013)*A5rf_mlvt'
+dwu0prf_mlvt     ='0+(-8.0694e-013)*A1rf_mlvt+(-1.0423e-012)*A2rf_mlvt+(4.1697e-013)*A3rf_mlvt+(8.7386e-013)*A4rf_mlvt+(9.1451e-014)*A5rf_mlvt'
+dpu0prf_mlvt     ='0+(1.2907e-018)*A1rf_mlvt+(6.6724e-019)*A2rf_mlvt+(-4.606e-019)*A3rf_mlvt+(1.2706e-019)*A4rf_mlvt+(-9.1181e-020)*A5rf_mlvt'
+dleta0prf_mlvt   ='0+(-4.356e-011)*A1rf_mlvt+(-1.6266e-011)*A2rf_mlvt+(1.4254e-011)*A3rf_mlvt+(-1.3821e-011)*A4rf_mlvt+(2.7327e-012)*A5rf_mlvt'
+dpeta0prf_mlvt   ='0+(-8.3888e-018)*A1rf_mlvt+(-1.8358e-018)*A2rf_mlvt+(2.4775e-018)*A3rf_mlvt+(-4.639e-018)*A4rf_mlvt+(4.5483e-019)*A5rf_mlvt'
+dlvsatprf_mlvt   ='max(-0.002,0+(0.00022021)*A1rf_mlvt+(5.4443e-005)*A2rf_mlvt+(-6.6325e-005)*A3rf_mlvt+(0.00011224)*A4rf_mlvt+(-1.2284e-005)*A5rf_mlvt)'
+dwvsatprf_mlvt   ='max(-0.0030,0+(-0.00015332)*A1rf_mlvt+(-0.00019804*0.3)*A2rf_mlvt+(7.9225e-005)*A3rf_mlvt+(0.00016603)*A4rf_mlvt+(1.7376e-005)*A5rf_mlvt)'
+dpvsatprf_mlvt   ='0+(7.3376e-012)*A1rf_mlvt+(-5.5223e-012)*A2rf_mlvt+(-6.9604e-013)*A3rf_mlvt+(1.4926e-011)*A4rf_mlvt+(-5.101e-015)*A5rf_mlvt'
+dk2prf_mlvt      ='0+(0.0010326)*A1rf_mlvt+(0.00053379)*A2rf_mlvt+(-0.00036848)*A3rf_mlvt+(0.00010165)*A4rf_mlvt+(-7.2945e-005)*A5rf_mlvt'
+dlcitprf_mlvt    ='0+(1.3182e-012)*A1rf_mlvt+(5.2657e-012)*A2rf_mlvt+(4.6123e-012)*A3rf_mlvt+(3.0987e-012)*A4rf_mlvt+(-6.9126e-013)*A5rf_mlvt'
+dlvoffprf_mlvt   ='0+(4.0347e-011)*A1rf_mlvt+(5.2117e-011)*A2rf_mlvt+(-2.0849e-011)*A3rf_mlvt+(-4.3693e-011)*A4rf_mlvt+(-4.5725e-012)*A5rf_mlvt'
+dnfactorprf_mlvt ='0+(-0.0056486)*A1rf_mlvt+(-0.0072963)*A2rf_mlvt+(0.0029188)*A3rf_mlvt+(0.006117)*A4rf_mlvt+(0.00064015)*A5rf_mlvt'
+dlnfactorprf_mlvt='max(-0.68e-8,0+(-1.969e-009)*A1rf_mlvt+(-1.192e-009)*A2rf_mlvt+(-2.4126e-010)*A3rf_mlvt+(1.0586e-009)*A4rf_mlvt+(1.7554e-010)*A5rf_mlvt)'
+dpnfactorprf_mlvt='max(-2e-15,0+(-3.7542e-016)*A1rf_mlvt+(-2.5175e-016)*A2rf_mlvt+(-3.6037e-016)*A3rf_mlvt+(5.6089e-016)*A4rf_mlvt+(4.3573e-017)*A5rf_mlvt)'
+dlk2prf_mlvt     ='0+(-4.8379e-012)*A1rf_mlvt+(3.751e-012)*A2rf_mlvt+(4.3623e-013)*A3rf_mlvt+(-1.0009e-011)*A4rf_mlvt+(-2.6961e-015)*A5rf_mlvt'
+dwk2prf_mlvt     ='0+(1.1617e-010)*A1rf_mlvt+(6.0051e-011)*A2rf_mlvt+(-4.1454e-011)*A3rf_mlvt+(1.1436e-011)*A4rf_mlvt+(-8.2063e-012)*A5rf_mlvt'
+dpk2prf_mlvt     ='0+(2.9046e-018)*A1rf_mlvt+(2.7519e-018)*A2rf_mlvt+(-1.2945e-018)*A3rf_mlvt+(-1.6207e-018)*A4rf_mlvt+(-2.7408e-019)*A5rf_mlvt'
+dpdiblc2prf_mlvt ='max(-0.0003,0+(-4.8441e-005)*A1rf_mlvt+(-3.2484e-005)*A2rf_mlvt+(-4.65e-005)*A3rf_mlvt+(7.2372e-005)*A4rf_mlvt+(5.6223e-006)*A5rf_mlvt)'
+datprf_mlvt      ='0+(-1562.4)*A1rf_mlvt+(192.29)*A2rf_mlvt+(1267.6)*A3rf_mlvt+(-1927.9)*A4rf_mlvt+(4203.3)*A5rf_mlvt'
+dlatprf_mlvt     ='0+(-0.00028411)*A1rf_mlvt+(-0.00027706)*A2rf_mlvt+(-2.4475e-005)*A3rf_mlvt+(0.0002121)*A4rf_mlvt+(-0.00066409)*A5rf_mlvt'
+dpatprf_mlvt     ='0+(2.1308e-011)*A1rf_mlvt+(2.078e-011)*A2rf_mlvt+(1.8356e-012)*A3rf_mlvt+(-1.5908e-011)*A4rf_mlvt+(4.9807e-011)*A5rf_mlvt'
+ddlcnrf_mlvt     =7.27377e-09
+drdswnrf_mlvt    =0
+dwu0nrf_mlvt     =0
+dpu0nrf_mlvt     =0
+deta0nrf_mlvt    =0
+dweta0nrf_mlvt   =0
+dvsatnrf_mlvt    =0
+dwvsatnrf_mlvt   =0
+dwvoffnrf_mlvt   =0
+dnfactornrf_mlvt =0
+dwnfactornrf_mlvt=0
+dlnfactornrf_mlvt=0
+dpnfactornrf_mlvt=0
+dpdiblc2nrf_mlvt =0
+ddlcprf_mlvt     =8.26573e-09
+deta0prf_mlvt    =0
+dweta0prf_mlvt   =0
+dvsatprf_mlvt    =0
+dwcitprf_mlvt    =0
+dpcitprf_mlvt    =0
+dwvoffprf_mlvt   =0
+dpvoffprf_mlvt   =0
+dwnfactorprf_mlvt=0
+dlpclmprf_mlvt   =0
+dppclmprf_mlvt   =0
+dwatprf_mlvt     =0
+is_d_dnw_nrf_mlvt= 1         x_jsw_d_dnw_nrf_mlvt= 0         n_d_dnw_nrf_mlvt= 1         rs_d_dnw_nrf_mlvt= 1
+cj_d_dnw_nrf_mlvt= 1          cjsw_d_dnw_nrf_mlvt= 1
+is_d_dnw_prf_mlvt= 1         x_jsw_d_dnw_prf_mlvt= 0         n_d_dnw_prf_mlvt= 1         rs_d_dnw_prf_mlvt= 1
+cj_d_dnw_prf_mlvt= 1          cjsw_d_dnw_prf_mlvt= 1
+is_d_prf_mlvt= 1                 x_jsw_d_prf_mlvt= 0             n_d_prf_mlvt= 1             rs_d_prf_mlvt= 1
+cj_d_prf_mlvt= 1                  cjsw_d_prf_mlvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL mc_RFMOS_mlvt








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+toxnrf_mlvt           = 2.6e-09       dxlnrf_mlvt           = '0-6e-09'             dxwnrf_mlvt           = 0
+dvthnrf_mlvt          = 0             dlvthnrf_mlvt         = 0             dwvthnrf_mlvt         = 0
+dpvthnrf_mlvt         = 0             cjnrf_mlvt            = 0.001251      cjswnrf_mlvt          = 9.5e-11
+cjswgnrf_mlvt         = 2.04e-10      cgonrf_mlvt           = 8.28670e-11   cglnrf_mlvt           = 9.96116e-12
+ddlcnrf_mlvt          = 7.27377e-09   cfnrf_mlvt            = '1.20e-10 + 4.5e-11' drdswnrf_mlvt         = 0
+ntoxnrf_mlvt          = 1             du0nrf_mlvt           = 0             dlu0nrf_mlvt          = 0
+dwu0nrf_mlvt          = 0             dpu0nrf_mlvt          = 0             deta0nrf_mlvt         = 0
+dleta0nrf_mlvt        = 0             dweta0nrf_mlvt        = 0             dpeta0nrf_mlvt        = 0
+dvsatnrf_mlvt         = 0             dlvsatnrf_mlvt        = 0             dwvsatnrf_mlvt        = 0
+dpvsatnrf_mlvt        = 0             dk2nrf_mlvt           = 0             dlcitnrf_mlvt         = 0
+dwcitnrf_mlvt         = 0             dlvoffnrf_mlvt         = 0             dwvoffnrf_mlvt         = 0
+dpvoffnrf_mlvt         = 0             dnfactornrf_mlvt      = 0             dwnfactornrf_mlvt     = 0
+dlnfactornrf_mlvt     = 0             dpnfactornrf_mlvt     = 0             dpdiblc2nrf_mlvt      = 0
+dla0nrf_mlvt          = 0             ss_flagrf_mlvt        = 0             ff_flagrf_mlvt        = 0
+sf_flagrf_mlvt        = 0             fs_flagrf_mlvt        = 0
+toxprf_mlvt           = 2.8e-09       dxlprf_mlvt           = '0-6e-9'             dxwprf_mlvt           = 0
+dvthprf_mlvt          = 0             dlvthprf_mlvt         = 0             dwvthprf_mlvt         = 0
+dpvthprf_mlvt         = 0             cjprf_mlvt            = 0.001077      cjswprf_mlvt          = 7.5e-11
+cjswgprf_mlvt         = 2.2e-10       cgoprf_mlvt           = 7.70111e-11   cglprf_mlvt           = 2.69027e-11
+ddlcprf_mlvt          = 8.26573e-09   cfprf_mlvt            = '1.20e-10 + 5.6e-11' drdswprf_mlvt         = 0
+ntoxprf_mlvt          = 1             du0prf_mlvt           = 0             dlu0prf_mlvt          = 0
+dwu0prf_mlvt          = 0             dpu0prf_mlvt          = 0             deta0prf_mlvt         = 0
+dleta0prf_mlvt        = 0             dweta0prf_mlvt        = 0             dpeta0prf_mlvt        = 0
+dvsatprf_mlvt         = 0             dlvsatprf_mlvt        = 0             dwvsatprf_mlvt        = 0
+dpvsatprf_mlvt        = 0             dk2prf_mlvt           = 0             dlcitprf_mlvt         = 0
+dwcitprf_mlvt         = 0             dpcitprf_mlvt         = 0             dlvoffprf_mlvt        = 0
+dwvoffprf_mlvt        = 0             dpvoffprf_mlvt        = 0             dnfactorprf_mlvt      = 0
+dlnfactorprf_mlvt     = 0             dwnfactorprf_mlvt     = 0             dpnfactorprf_mlvt     = 0
+dlk2prf_mlvt          = 0             dwk2prf_mlvt          = 0             dpk2prf_mlvt          = 0
+dpdiblc2prf_mlvt      = 0
+dlpclmprf_mlvt        = 0             dppclmprf_mlvt         = 0
+datprf_mlvt           = 0
+dlatprf_mlvt          = 0
+dwatprf_mlvt          = 0
+dpatprf_mlvt          = 0
+is_d_dnw_nrf_mlvt= 1         x_jsw_d_dnw_nrf_mlvt= 0         n_d_dnw_nrf_mlvt= 1         rs_d_dnw_nrf_mlvt= 1
+cj_d_dnw_nrf_mlvt= 1          cjsw_d_dnw_nrf_mlvt= 1
+is_d_dnw_prf_mlvt= 1         x_jsw_d_dnw_prf_mlvt= 0         n_d_dnw_prf_mlvt= 1         rs_d_dnw_prf_mlvt= 1
+cj_d_dnw_prf_mlvt= 1          cjsw_d_dnw_prf_mlvt= 1
+is_d_prf_mlvt= 1                 x_jsw_d_prf_mlvt= 0             n_d_prf_mlvt= 1             rs_d_prf_mlvt= 1
+cj_d_prf_mlvt= 1                  cjsw_d_prf_mlvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL TT_RFMOS_mlvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+toxnrf_mlvt           = 2.667e-09     dxlnrf_mlvt           = '5e-09-6e-09'         dxwnrf_mlvt           = -8e-09
+dvthnrf_mlvt          = 0.025         dlvthnrf_mlvt         = 1.8e-09       dwvthnrf_mlvt         = 2.7e-09
+dpvthnrf_mlvt         = 2.2e-16       cjnrf_mlvt            = 0.00133857    cjswnrf_mlvt          = 1.0165e-10
+cjswgnrf_mlvt         = 2.1828e-10    cgonrf_mlvt           = 7.70663e-11   cglnrf_mlvt           = 9.26388e-12
+ddlcnrf_mlvt          = 7.27377e-09   cfnrf_mlvt            = '1.1160e-10 + 4.5e-11' drdswnrf_mlvt         = 0
+ntoxnrf_mlvt          = 0.24          du0nrf_mlvt           = 3.0e-04       dlu0nrf_mlvt          = 5.0e-011
+dwu0nrf_mlvt          = 0.0e-10       dpu0nrf_mlvt          = -0.0e-17      deta0nrf_mlvt         = 0
+dleta0nrf_mlvt        = -0.3e-09      dweta0nrf_mlvt        = -0.0e-10      dpeta0nrf_mlvt        = -0.0e-16
+dvsatnrf_mlvt         = -0.0e04       dlvsatnrf_mlvt        = 0.24e-03       dwvsatnrf_mlvt        = 0
+dpvsatnrf_mlvt        = 0.0e-11       dk2nrf_mlvt           = 0.005         dlcitnrf_mlvt         = -0e-11
+dwcitnrf_mlvt         = -6e-11        dlvoffnrf_mlvt         = -5.0e-10      dwvoffnrf_mlvt         = 0
+dpvoffnrf_mlvt         = 0             dnfactornrf_mlvt      = -0.0e-2       dwnfactornrf_mlvt     = 0
+dlnfactornrf_mlvt     = -0.0e-08      dpnfactornrf_mlvt     = -0.0e-15      dpdiblc2nrf_mlvt      = 0
+dla0nrf_mlvt          = 10e-08             ss_flagrf_mlvt        = 1             ff_flagrf_mlvt        = 0
+sf_flagrf_mlvt        = 0             fs_flagrf_mlvt        = 0
+toxprf_mlvt           = 2.867e-09     dxlprf_mlvt           = '5e-09-6e-9'  dxwprf_mlvt           = -8e-09
+dvthprf_mlvt          = -0.024        dlvthprf_mlvt         = -10e-10       dwvthprf_mlvt         = -3.0e-09
+dpvthprf_mlvt         = -2.3e-16      cjprf_mlvt            = 0.00115239    cjswprf_mlvt          = 8.025e-11
+cjswgprf_mlvt         = 2.354e-10     cgoprf_mlvt           = 7.16203e-11   cglprf_mlvt           = 2.50195e-11
+ddlcprf_mlvt          = 8.26573e-09   cfprf_mlvt            = '1.1160e-10 + 5.6e-11' drdswprf_mlvt         = -20
+ntoxprf_mlvt          = -1.44         du0prf_mlvt           = 0.0004        dlu0prf_mlvt          = -2.7e-11
+dwu0prf_mlvt          = 0             dpu0prf_mlvt          = 1e-17         deta0prf_mlvt         = 0
+dleta0prf_mlvt        = -0.4e-9       dweta0prf_mlvt        = 0             dpeta0prf_mlvt        = -9e-17
+dvsatprf_mlvt         = 0             dlvsatprf_mlvt        = 0.0023        dwvsatprf_mlvt        = -0.000
+dpvsatprf_mlvt        = 15e-11        dk2prf_mlvt           = 0.008         dlcitprf_mlvt         = 0
+dwcitprf_mlvt         = 0             dpcitprf_mlvt         = 0             dlvoffprf_mlvt        = 0
+dwvoffprf_mlvt        = 0             dpvoffprf_mlvt        = 0             dnfactorprf_mlvt      = 0
+dlnfactorprf_mlvt     = -9e-09        dwnfactorprf_mlvt     = 0             dpnfactorprf_mlvt     = 0
+dlk2prf_mlvt          = -1.0e-10      dwk2prf_mlvt          = 9e-10         dpk2prf_mlvt          = 1e-17
+dpdiblc2prf_mlvt      = 0
+dlpclmprf_mlvt        = 0e-7          dppclmprf_mlvt        = 0
+datprf_mlvt           = -27500
+dlatprf_mlvt          = 0
+dwatprf_mlvt          = 0
+dpatprf_mlvt          = 0
+is_d_dnw_nrf_mlvt= 0.7         x_jsw_d_dnw_nrf_mlvt= -1         n_d_dnw_nrf_mlvt= 0.9975         rs_d_dnw_nrf_mlvt= 1.2
+cj_d_dnw_nrf_mlvt= 1.07          cjsw_d_dnw_nrf_mlvt= 1.07
+is_d_dnw_prf_mlvt= 0.7         x_jsw_d_dnw_prf_mlvt= -1         n_d_dnw_prf_mlvt= 0.9975         rs_d_dnw_prf_mlvt= 1.2
+cj_d_dnw_prf_mlvt= 1.07          cjsw_d_dnw_prf_mlvt=  1.07
+is_d_prf_mlvt= 0.7                 x_jsw_d_prf_mlvt= -1             n_d_prf_mlvt= 0.9975             rs_d_prf_mlvt= 1.2
+cj_d_prf_mlvt= 1.07                  cjsw_d_prf_mlvt=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL SS_RFMOS_mlvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+toxnrf_mlvt           = 2.533e-09     dxlnrf_mlvt           = '-5e-09-6e-09'        dxwnrf_mlvt           = 8e-09
+dvthnrf_mlvt          = -0.025        dlvthnrf_mlvt         = -1.8e-09      dwvthnrf_mlvt         = -3.0e-09
+dpvthnrf_mlvt         = -2.6e-16      cjnrf_mlvt            = 0.00116343    cjswnrf_mlvt          = 8.835e-11
+cjswgnrf_mlvt         = 1.8972e-10    cgonrf_mlvt           = 8.86677e-11   cglnrf_mlvt           = 1.06584e-11
+ddlcnrf_mlvt          = 7.27377e-09   cfnrf_mlvt            = '1.2840e-10 + 4.5e-11' drdswnrf_mlvt         = 0
+ntoxnrf_mlvt          = 1.59          du0nrf_mlvt           = -3.0e-04      dlu0nrf_mlvt          = -5.0e-011
+dwu0nrf_mlvt          = -0.0e-10      dpu0nrf_mlvt          = 0.0e-17       deta0nrf_mlvt         = 0
+dleta0nrf_mlvt        = -0.0e-9       dweta0nrf_mlvt        = 0.0e-09       dpeta0nrf_mlvt        = 0.5e-16
+dvsatnrf_mlvt         = 0.0e4         dlvsatnrf_mlvt        = -0.2e-03      dwvsatnrf_mlvt        = 0.0e-03
+dpvsatnrf_mlvt        = 0.8e-11       dk2nrf_mlvt           = -0.004        dlcitnrf_mlvt         = 0
+dwcitnrf_mlvt         = 0             dlvoffnrf_mlvt         = 5.0e-10      dwvoffnrf_mlvt         = 0
+dpvoffnrf_mlvt         = -2.1e-16             dnfactornrf_mlvt      = 0             dwnfactornrf_mlvt     = 0e-08
+dlnfactornrf_mlvt     = 0.0e-08       dpnfactornrf_mlvt     = 0.0e-14       dpdiblc2nrf_mlvt      = 0
+dla0nrf_mlvt          = -0e-08        ss_flagrf_mlvt        = 0             ff_flagrf_mlvt        = 1
+sf_flagrf_mlvt        = 0             fs_flagrf_mlvt        = 0
+toxprf_mlvt           = 2.733e-09     dxlprf_mlvt           = '-5e-09-6e-9' dxwprf_mlvt           = 8e-09
+dvthprf_mlvt          = 0.024         dlvthprf_mlvt         = 5.5e-10       dwvthprf_mlvt         = 4e-09
+dpvthprf_mlvt         = 3e-16         cjprf_mlvt            = 0.00100161    cjswprf_mlvt          = 6.975e-11
+cjswgprf_mlvt         = 2.046e-10     cgoprf_mlvt           = 8.24019e-11   cglprf_mlvt           = 2.87859e-11
+ddlcprf_mlvt          = 8.26573e-09   cfprf_mlvt            = '1.2840e-10 + 5.6e-11' drdswprf_mlvt         = 20
+ntoxprf_mlvt          = 2.27          du0prf_mlvt           = -0.0004       dlu0prf_mlvt          = 2.7e-11
+dwu0prf_mlvt          = 1e-11         dpu0prf_mlvt          = -1e-17        deta0prf_mlvt         = 0
+dleta0prf_mlvt        = 3e-10         dweta0prf_mlvt        = 0             dpeta0prf_mlvt        = 5e-17
+dvsatprf_mlvt         = 0             dlvsatprf_mlvt        = -0.00135      dwvsatprf_mlvt        = 0.0019
+dpvsatprf_mlvt        = -1e-12        dk2prf_mlvt           = -0.008        dlcitprf_mlvt         = 0
+dwcitprf_mlvt         = 0             dpcitprf_mlvt         = 0             dlvoffprf_mlvt        = -5e-10
+dwvoffprf_mlvt        = 0             dpvoffprf_mlvt        = 0             dnfactorprf_mlvt      = 0.07
+dlnfactorprf_mlvt     = 2.2e-8        dwnfactorprf_mlvt     = 0             dpnfactorprf_mlvt     = 6.2e-15
+dlk2prf_mlvt          = 0             dwk2prf_mlvt          = -9e-10        dpk2prf_mlvt          = -3e-17
+dpdiblc2prf_mlvt      = 0.0008
+dlpclmprf_mlvt        = 0             dppclmprf_mlvt        = 0
+datprf_mlvt           = 27500
+dlatprf_mlvt          = 0
+dwatprf_mlvt          = 0
+dpatprf_mlvt          = 0
+is_d_dnw_nrf_mlvt= 1.3         x_jsw_d_dnw_nrf_mlvt= 1         n_d_dnw_nrf_mlvt= 1.0025         rs_d_dnw_nrf_mlvt= 0.8
+cj_d_dnw_nrf_mlvt= 0.93          cjsw_d_dnw_nrf_mlvt= 0.93
+is_d_dnw_prf_mlvt= 1.3         x_jsw_d_dnw_prf_mlvt= 1         n_d_dnw_prf_mlvt= 1.0025         rs_d_dnw_prf_mlvt= 0.8
+cj_d_dnw_prf_mlvt= 0.93          cjsw_d_dnw_prf_mlvt=  0.93
+is_d_prf_mlvt= 1.3                 x_jsw_d_prf_mlvt= 1             n_d_prf_mlvt= 1.0025             rs_d_prf_mlvt= 0.8
+cj_d_prf_mlvt= 0.93                  cjsw_d_prf_mlvt=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL FF_RFMOS_mlvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+A1Nrf_mlvt=0.8 A1Prf_mlvt=-0.8 A2Nrf_mlvt=0 A2Prf_mlvt=0 A3Nrf_mlvt=-1 A3Prf_mlvt=1 A4NPrf_mlvt=0
+toxnrf_mlvt = '2.6e-09 + 6.7000e-011*A4NPrf_mlvt'     dxlnrf_mlvt = '(-5e-009*A2Nrf_mlvt)-6e-09'                     dxwnrf_mlvt = '8e-009*A3Nrf_mlvt'
+dvthnrf_mlvt = '0.025*A1Nrf_mlvt'                     dlvthnrf_mlvt = '1.8e-009*A1Nrf_mlvt'                 dwvthnrf_mlvt = '3e-009*A1Nrf_mlvt'
+dpvthnrf_mlvt = '2.6e-016*A1Nrf_mlvt'                 cjnrf_mlvt = '0.001251 * (1+0.070*A1Nrf_mlvt)'        cjswnrf_mlvt = '9.5e-11 * (1+0.070*A1Nrf_mlvt)'
+cjswgnrf_mlvt = '2.04e-10 * (1+0.070*A1Nrf_mlvt)'     cgonrf_mlvt = '8.28670e-11 * (1-0.070*A4NPrf_mlvt)'   cglnrf_mlvt = '9.96116e-12 * (1-0.070*A4NPrf_mlvt)'
+ddlcnrf_mlvt = 7.27377e-09
+cfnrf_mlvt = '1.20e-10*(1-0.070*A4NPrf_mlvt)+4.5e-11'
+drdswnrf_mlvt = 0                              ntoxnrf_mlvt = '1 + -5.9000e-001*A4NPrf_mlvt'         du0nrf_mlvt = '0.0003*A1Nrf_mlvt'
+dlu0nrf_mlvt = '5e-011*A1Nrf_mlvt'                    dwu0nrf_mlvt = '0.0e-011*A1Nrf_mlvt'                  dpu0nrf_mlvt = '0.0e-017*A1Nrf_mlvt'
+deta0nrf_mlvt = 0                              dleta0nrf_mlvt = '-0e-010*A1Nrf_mlvt'                 dweta0nrf_mlvt = '-0e-009*A1Nrf_mlvt'
+dpeta0nrf_mlvt = '-0.5e-016*A1Nrf_mlvt'               dvsatnrf_mlvt = '-0.0e4*A1Nrf_mlvt'                   dlvsatnrf_mlvt = '0.000*A1Nrf_mlvt'
+dwvsatnrf_mlvt = '0*A1Nrf_mlvt'                       dpvsatnrf_mlvt = '-8e-012*A1Nrf_mlvt'                 dk2nrf_mlvt = '0.004*A1Nrf_mlvt'
+dlcitnrf_mlvt = 0                              dwcitnrf_mlvt = 0                              dlvoffnrf_mlvt = '-5e-010*A1Nrf_mlvt'
+dwvoffnrf_mlvt = 0                             dpvoffnrf_mlvt = '2.1e-016*A1Nrf_mlvt'                dnfactornrf_mlvt = 0
+dwnfactornrf_mlvt = '0*A1Nrf_mlvt'                    dlnfactornrf_mlvt = '-0.0e-008*A1Nrf_mlvt'            dpnfactornrf_mlvt = '-0e-014*A1Nrf_mlvt'
+dpdiblc2nrf_mlvt = 0                           dla0nrf_mlvt = 0                               ss_flagrf_mlvt = 0
+ff_flagrf_mlvt = 0                             sf_flagrf_mlvt = 1                             fs_flagrf_mlvt = 0
+A1Nrf_mlvt_mlvt=0.8 A1Prf_mlvt_mlvt=-0.8 A2Nrf_mlvt_mlvt=0 A2Prf_mlvt_mlvt=0 A3Nrf_mlvt_mlvt=-1 A3Prf_mlvt_mlvt=1 A4NPrf_mlvt_mlvt=0
+toxprf_mlvt = '2.8e-09 + 6.7000e-11*A4NPrf_mlvt_mlvt'      dxlprf_mlvt = '5e-09*A2Prf_mlvt_mlvt-6e-9'                 dxwprf_mlvt = '8e-09*A3Prf_mlvt_mlvt'
+dvthprf_mlvt = '-0.024*A1Prf_mlvt_mlvt'                    dlvthprf_mlvt = '-5.5e-10*A1Prf_mlvt_mlvt'                 dwvthprf_mlvt = '-4e-09*A1Prf_mlvt_mlvt'
+dpvthprf_mlvt = '-3e-16*A1Prf_mlvt_mlvt'                   cjprf_mlvt = '0.001077 * (1+0.070*A1Prf_mlvt_mlvt)'        cjswprf_mlvt = '7.5e-11 * (1+0.070*A1Prf_mlvt_mlvt)'
+cjswgprf_mlvt = '2.2e-10 * (1+0.070*A1Prf_mlvt_mlvt)'      cgoprf_mlvt = '7.70111e-11 * (1-0.070*A4NPrf_mlvt_mlvt)'   cglprf_mlvt = '2.69027e-11 * (1-0.070*A4NPrf_mlvt_mlvt)'
+ddlcprf_mlvt = 8.26573e-09
+cfprf_mlvt = '1.20e-10*(1-0.070*A4NPrf_mlvt_mlvt)+5.6e-11'
+drdswprf_mlvt = '-20*A1Prf_mlvt_mlvt'                      ntoxprf_mlvt = '1 + -1.2700e+00*A4NPrf_mlvt_mlvt'          du0prf_mlvt = '0.0004*A1Prf_mlvt_mlvt'
+dlu0prf_mlvt = '-6.0e-11*A1Prf_mlvt_mlvt'                  dwu0prf_mlvt = '-1e-11*A1Prf_mlvt_mlvt'                    dpu0prf_mlvt = '1e-17*A1Prf_mlvt_mlvt'
+deta0prf_mlvt = 0                                   dleta0prf_mlvt = '-3e-10*A1Prf_mlvt_mlvt'                  dweta0prf_mlvt = 0
+dpeta0prf_mlvt = '-5e-17*A1Prf_mlvt_mlvt'                  dvsatprf_mlvt = 0                                   dlvsatprf_mlvt = '0.00135*A1Prf_mlvt_mlvt'
+dwvsatprf_mlvt = '-0.0019*A1Prf_mlvt_mlvt'                 dpvsatprf_mlvt = '1e-12*A1Prf_mlvt_mlvt'                   dk2prf_mlvt = '0.008*A1Prf_mlvt_mlvt'
+dlcitprf_mlvt = 0                                   dwcitprf_mlvt = 0                                   dpcitprf_mlvt = 0
+dlvoffprf_mlvt = '5e-10*A1Prf_mlvt_mlvt'                   dwvoffprf_mlvt = 0                                  dpvoffprf_mlvt = 0
+dnfactorprf_mlvt = '-0.07*A1Prf_mlvt_mlvt'                 dlnfactorprf_mlvt = '-1.0e-08*A1Prf_mlvt_mlvt'             dwnfactorprf_mlvt = 0
+dpnfactorprf_mlvt = '-6.2e-15*A1Prf_mlvt_mlvt*0'             dlk2prf_mlvt = 0                                    dwk2prf_mlvt = '9e-10*A1Prf_mlvt_mlvt'
+dpk2prf_mlvt = '3e-17*A1Prf_mlvt_mlvt'                     dpdiblc2prf_mlvt = '-0.0008*A1Prf_mlvt_mlvt*0'               dlpclmprf_mlvt = 0
+dppclmprf_mlvt = 0                                  datprf_mlvt = '-24000*A1Prf_mlvt_mlvt'                     dlatprf_mlvt = 0
+dwatprf_mlvt         = 0                  dpatprf_mlvt         = 0
+is_d_dnw_nrf_mlvt= 1         x_jsw_d_dnw_nrf_mlvt= 0         n_d_dnw_nrf_mlvt= 1         rs_d_dnw_nrf_mlvt= 1
+cj_d_dnw_nrf_mlvt= 1          cjsw_d_dnw_nrf_mlvt= 1
+is_d_dnw_prf_mlvt= 1         x_jsw_d_dnw_prf_mlvt= 0         n_d_dnw_prf_mlvt= 1         rs_d_dnw_prf_mlvt= 1
+cj_d_dnw_prf_mlvt= 1          cjsw_d_dnw_prf_mlvt= 1
+is_d_prf_mlvt= 1                 x_jsw_d_prf_mlvt= 0             n_d_prf_mlvt= 1             rs_d_prf_mlvt= 1
+cj_d_prf_mlvt= 1                  cjsw_d_prf_mlvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL SF_RFMOS_mlvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_mlvt
.lib 'crn65lp_v1d5.l' noiseflagrf_mlvt
.param
+parn1rf_mlvt=AGAUSS(0,1,1)
+parn2rf_mlvt=AGAUSS(0,1,1)
+parp1rf_mlvt=AGAUSS(0,1,1)
+parp2rf_mlvt=AGAUSS(0,1,1)
+A1Nrf_mlvt=-0.8 A1Prf_mlvt=0.8 A2Nrf_mlvt=0 A2Prf_mlvt=0 A3Nrf_mlvt=1 A3Prf_mlvt=-1 A4NPrf_mlvt=0
+toxnrf_mlvt = '2.6e-09 + 6.7000e-011*A4NPrf_mlvt'     dxlnrf_mlvt = '(-5e-009*A2Nrf_mlvt)-6e-09'                     dxwnrf_mlvt = '8e-009*A3Nrf_mlvt'
+dvthnrf_mlvt = '0.025*A1Nrf_mlvt'                     dlvthnrf_mlvt = '1.8e-009*A1Nrf_mlvt'                 dwvthnrf_mlvt = '3e-009*A1Nrf_mlvt'
+dpvthnrf_mlvt = '2.6e-016*A1Nrf_mlvt'                 cjnrf_mlvt = '0.001251 * (1+0.070*A1Nrf_mlvt)'        cjswnrf_mlvt = '9.5e-11 * (1+0.070*A1Nrf_mlvt)'
+cjswgnrf_mlvt = '2.04e-10 * (1+0.070*A1Nrf_mlvt)'     cgonrf_mlvt = '8.28670e-11 * (1-0.070*A4NPrf_mlvt)'   cglnrf_mlvt = '9.96116e-12 * (1-0.070*A4NPrf_mlvt)'
+ddlcnrf_mlvt = 7.27377e-09
+cfnrf_mlvt = '1.20e-10*(1-0.070*A4NPrf_mlvt)+4.5e-11'
+drdswnrf_mlvt = 0                              ntoxnrf_mlvt = '1 + -5.9000e-001*A4NPrf_mlvt'         du0nrf_mlvt = '0.0003*A1Nrf_mlvt'
+dlu0nrf_mlvt = '5e-011*A1Nrf_mlvt'                    dwu0nrf_mlvt = '0.0e-011*A1Nrf_mlvt'                  dpu0nrf_mlvt = '0.0e-017*A1Nrf_mlvt'
+deta0nrf_mlvt = 0                              dleta0nrf_mlvt = '-0e-010*A1Nrf_mlvt'                 dweta0nrf_mlvt = '-0e-009*A1Nrf_mlvt'
+dpeta0nrf_mlvt = '-0.5e-016*A1Nrf_mlvt'               dvsatnrf_mlvt = '-0.0e4*A1Nrf_mlvt'                   dlvsatnrf_mlvt = '0.000*A1Nrf_mlvt'
+dwvsatnrf_mlvt = '0*A1Nrf_mlvt'                       dpvsatnrf_mlvt = '-8e-012*A1Nrf_mlvt'                 dk2nrf_mlvt = '0.004*A1Nrf_mlvt'
+dlcitnrf_mlvt = 0                              dwcitnrf_mlvt = 0                              dlvoffnrf_mlvt = '-5e-010*A1Nrf_mlvt'
+dwvoffnrf_mlvt = 0                             dpvoffnrf_mlvt = '2.1e-016*A1Nrf_mlvt'                dnfactornrf_mlvt = 0
+dwnfactornrf_mlvt = '0*A1Nrf_mlvt'                    dlnfactornrf_mlvt = '-0.0e-008*A1Nrf_mlvt'            dpnfactornrf_mlvt = '-0e-014*A1Nrf_mlvt'
+dpdiblc2nrf_mlvt = 0                           dla0nrf_mlvt = 0                               ss_flagrf_mlvt = 0
+ff_flagrf_mlvt = 0                             sf_flagrf_mlvt = 0                             fs_flagrf_mlvt = 1
+A1Nrf_mlvt_mlvt=-0.8 A1Prf_mlvt_mlvt=0.8 A2Nrf_mlvt_mlvt=0 A2Prf_mlvt_mlvt=0 A3Nrf_mlvt_mlvt=1 A3Prf_mlvt_mlvt=-1 A4NPrf_mlvt_mlvt=0
+toxprf_mlvt = '2.8e-09 + 6.7000e-11*A4NPrf_mlvt_mlvt'      dxlprf_mlvt = '5e-09*A2Prf_mlvt_mlvt-6e-9'                 dxwprf_mlvt = '8e-09*A3Prf_mlvt_mlvt'
+dvthprf_mlvt = '-0.024*A1Prf_mlvt_mlvt'                    dlvthprf_mlvt = '-5.5e-10*A1Prf_mlvt_mlvt'                 dwvthprf_mlvt = '-4e-09*A1Prf_mlvt_mlvt'
+dpvthprf_mlvt = '-3e-16*A1Prf_mlvt_mlvt'                   cjprf_mlvt = '0.001077 * (1+0.070*A1Prf_mlvt_mlvt)'        cjswprf_mlvt = '7.5e-11 * (1+0.070*A1Prf_mlvt_mlvt)'
+cjswgprf_mlvt = '2.2e-10 * (1+0.070*A1Prf_mlvt_mlvt)'      cgoprf_mlvt = '7.70111e-11 * (1-0.070*A4NPrf_mlvt_mlvt)'   cglprf_mlvt = '2.69027e-11 * (1-0.070*A4NPrf_mlvt_mlvt)'
+ddlcprf_mlvt = 8.26573e-09
+cfprf_mlvt = '1.20e-10*(1-0.070*A4NPrf_mlvt_mlvt)+5.6e-11'
+drdswprf_mlvt = '-20*A1Prf_mlvt_mlvt'                      ntoxprf_mlvt = '1 + -1.2700e+00*A4NPrf_mlvt_mlvt'          du0prf_mlvt = '0.0004*A1Prf_mlvt_mlvt'
+dlu0prf_mlvt = '-6.0e-11*A1Prf_mlvt_mlvt'                  dwu0prf_mlvt = '-1e-11*A1Prf_mlvt_mlvt'                    dpu0prf_mlvt = '1e-17*A1Prf_mlvt_mlvt'
+deta0prf_mlvt = 0                                   dleta0prf_mlvt = '-3e-10*A1Prf_mlvt_mlvt'                  dweta0prf_mlvt = 0
+dpeta0prf_mlvt = '-5e-17*A1Prf_mlvt_mlvt'                  dvsatprf_mlvt = 0                                   dlvsatprf_mlvt = '0.00135*A1Prf_mlvt_mlvt'
+dwvsatprf_mlvt = '-0.0019*A1Prf_mlvt_mlvt'                 dpvsatprf_mlvt = '1e-12*A1Prf_mlvt_mlvt'                   dk2prf_mlvt = '0.008*A1Prf_mlvt_mlvt'
+dlcitprf_mlvt = 0                                   dwcitprf_mlvt = 0                                   dpcitprf_mlvt = 0
+dlvoffprf_mlvt = '5e-10*A1Prf_mlvt_mlvt'                   dwvoffprf_mlvt = 0                                  dpvoffprf_mlvt = 0
+dnfactorprf_mlvt = '-0.07*A1Prf_mlvt_mlvt'                 dlnfactorprf_mlvt = '-1.0e-08*A1Prf_mlvt_mlvt'             dwnfactorprf_mlvt = 0
+dpnfactorprf_mlvt = '-6.2e-15*A1Prf_mlvt_mlvt*0'             dlk2prf_mlvt = 0                                    dwk2prf_mlvt = '9e-10*A1Prf_mlvt_mlvt'
+dpk2prf_mlvt = '3e-17*A1Prf_mlvt_mlvt'                     dpdiblc2prf_mlvt = '-0.0008*A1Prf_mlvt_mlvt*0'               dlpclmprf_mlvt = 0
+dppclmprf_mlvt = 0                                  datprf_mlvt = '-24000*A1Prf_mlvt_mlvt'                     dlatprf_mlvt = 0
+dwatprf_mlvt         = 0                  dpatprf_mlvt         = 0
+is_d_dnw_nrf_mlvt= 1         x_jsw_d_dnw_nrf_mlvt= 0         n_d_dnw_nrf_mlvt= 1         rs_d_dnw_nrf_mlvt= 1
+cj_d_dnw_nrf_mlvt= 1          cjsw_d_dnw_nrf_mlvt= 1
+is_d_dnw_prf_mlvt= 1         x_jsw_d_dnw_prf_mlvt= 0         n_d_dnw_prf_mlvt= 1         rs_d_dnw_prf_mlvt= 1
+cj_d_dnw_prf_mlvt= 1          cjsw_d_dnw_prf_mlvt= 1
+is_d_prf_mlvt= 1                 x_jsw_d_prf_mlvt= 0             n_d_prf_mlvt= 1             rs_d_prf_mlvt= 1
+cj_d_prf_mlvt= 1                  cjsw_d_prf_mlvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_mlvt
.ENDL FS_RFMOS_mlvt



.LIB RF_MOS_mlvt

.subckt nmos_rf_mlvt D G S B lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parn1rf_mlvt  temp2=parn2rf_mlvt
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_mlvt='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_mlvt='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_mlvt='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_mlvt='0.00216908*geo_fac*toxnrf_mlvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1603.5*lr*scale/nr/(wr*scale)+2.575)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.084e05/(lr*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(lr*scale*1e6)+0.4837'

.param fn_dice='noiseflagnrf_mlvt_mc*par1fn_mc+noiseflagnrf_mlvt_mc_mis*par2fnrf_mlvt_mc'
.param c1fnrf_mlvt=8.00E+41           c2fnrf_mlvt=5.00E+22           c3fnrf_mlvt=1.00E+7 
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.555*log(((wr*scale*lr*scale*nr)/(12.7E-6*1E-6*1))**0.5)))'
.param noianrf_mlvt='c1fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'
.param noibnrf_mlvt='c2fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'
.param noicnrf_mlvt='c3fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V mlvt-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_mlvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthnrf_mlvt+vthmisnrf_mlvt)'  LVTH0      = '-2.6209825e-009+dlvthnrf_mlvt'
+WVTH0      = '6.8814839e-010+dwvthnrf_mlvt'
+PVTH0      = '-5.3326435e-017+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '0.0071010498+dk2nrf_mlvt' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitnrf_mlvt'
+WCIT       = '-2.634146e-010+dwcitnrf_mlvt'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffnrf_mlvt'
+WVOFF      = '-2.7301032e-008+dwvoffnrf_mlvt'
+PVOFF      = '3.8940424e-015+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt'    ETA0       = '0.10402516+deta0nrf_mlvt' LETA0      = '-1.6784547e-010+dleta0nrf_mlvt'
+WETA0      = '-3.0136772e-008+dweta0nrf_mlvt'
+PETA0      = '1.6875216e-015+dpeta0nrf_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0nrf_mlvt'  LU0        = '6.0443544e-011+dlu0nrf_mlvt'
+WU0        = '-3.4587047e-010+dwu0nrf_mlvt'
+PU0        = '-1.2567478e-016+dpu0nrf_mlvt'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatnrf_mlvt'  LVSAT      = '-0.00073522225+dlvsatnrf_mlvt'
+WVSAT      = '0.013868259+dwvsatnrf_mlvt'
+PVSAT      = '-1.6704557e-009+dpvsatnrf_mlvt'
+A0         = 0.71811517          LA0        = '-2.3073092e-007+dla0nrf_mlvt'
+WA0        = 4.6955716e-007      PA0        = -7.5179779e-014     AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2nrf_mlvt'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf_mlvt'
+RDW        = '65+drdswnrf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxnrf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_mlvt'
+CGDO       = 'cgonrf_mlvt'              CGBO       = 0                   CGDL       = 'cglnrf_mlvt'
+CGSL       = 'cglnrf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt'
+WNFACTOR   = '0+dwnfactornrf_mlvt'      PNFACTOR   = '0+dpnfactornrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+WMIN       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44338471+(dvthnrf_mlvt+vthmisnrf_mlvt)'
+LVTH0      = '-2.6624817e-09+dlvthnrf_mlvt'
+WVTH0      = '-1.6551106e-08+dwvthnrf_mlvt'
+PVTH0      = '1.597862e-15+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '0.0013060071+dk2nrf_mlvt' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0020197491
+LCIT       = '4.0216548e-10+dlcitnrf_mlvt'
+WCIT       = '5.152138e-10+dwcitnrf_mlvt'
+PCIT       = -9.614958e-17
+VOFF       = -0.16044316
+LVOFF      = '-1.8820754e-09+dlvoffnrf_mlvt'
+WVOFF      = '3.5572622e-08+dwvoffnrf_mlvt'
+PVOFF      = '-2.1280553e-15+dpvoffnrf_mlvt'
+NFACTOR    = '0.60878657+dnfactornrf_mlvt+0.207839*ss_flagrf_mlvt'
+ETA0       = '-0.013762419+deta0nrf_mlvt+0.00706067*ff_flagrf_mlvt+0.0141213*ss_flagrf_mlvt'
+LETA0      = '1.1113958e-08+dleta0nrf_mlvt-6.76274e-10*ff_flagrf_mlvt-1.35255e-09*ss_flagrf_mlvt'
+WETA0      = '1.5891949e-08+dweta0nrf_mlvt-7.20189e-09*ff_flagrf_mlvt-1.44038e-08*ss_flagrf_mlvt'
+PETA0      = '-2.7211461e-15+dpeta0nrf_mlvt+6.89799e-16*ff_flagrf_mlvt+1.3796e-15*ss_flagrf_mlvt'
+ETAB       = -0.11384089
+LETAB      = 2.9069217e-09
+WETAB      = -3.5257548e-08
+PETAB      = 1.3049602e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0nrf_mlvt'   LU0        = '4.5926676e-011+dlu0nrf_mlvt'
+WU0        = '-4.2433976e-009+dwu0nrf_mlvt'
+PU0        = '2.4763426e-016+dpu0nrf_mlvt'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024
+UB         = 1.7538672e-18
+LUB        = -6.6974505e-28
+WUB        = -3.4899719e-25
+PUB        = 8.0187736e-33
+UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '90298.236+dvsatnrf_mlvt+72.6857*ff_flagrf_mlvt'
+LVSAT      = '0.00017603274+dlvsatnrf_mlvt-6.96186e-06*ff_flagrf_mlvt'
+WVSAT      = '-0.0018572123+dwvsatnrf_mlvt-0.000728311*ff_flagrf_mlvt'
+PVSAT      = '-1.6425802e-10+dpvsatnrf_mlvt+6.97579e-11*ff_flagrf_mlvt'
+A0         = 1.6696481           LA0        = '-3.2186969e-007+dla0nrf_mlvt'
+WA0        = -2.4506944e-006     PA0        = 2.0452483e-013      AGS        = 3.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'
+CGBO       = 0                   CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.12701693
+LKT2       = 6.0452217e-09
+WKT2       = 3.7762002e-08
+PKT2       = -3.2025688e-15
+UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '1.3525474e-08+dlnfactornrf_mlvt-1.99069e-08*ss_flagrf_mlvt'
+WNFACTOR   = '1.440377e-07+dwnfactornrf_mlvt-2.11996e-07*ss_flagrf_mlvt'
+PNFACTOR   = '-1.3795983e-14+dpnfactornrf_mlvt+2.0305e-14*ss_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthnrf_mlvt+vthmisnrf_mlvt)'  LVTH0      = '-2.4452732e-009+dlvthnrf_mlvt'
+WVTH0      = '-2.656096e-009+dwvthnrf_mlvt'
+PVTH0      = '-2.3254991e-016+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '-0.0077298678+dk2nrf_mlvt'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitnrf_mlvt'
+WCIT       = '4.0796102e-010+dwcitnrf_mlvt'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffnrf_mlvt'
+WVOFF      = '-1.6424805e-008+dwvoffnrf_mlvt'
+PVOFF      = '8.6103596e-016+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt'    ETA0       = '0.044118879+deta0nrf_mlvt'
+LETA0      = '3.7906852e-009+dleta0nrf_mlvt'
+WETA0      = '3.0967637e-008+dweta0nrf_mlvt'
+PETA0      = '-2.3501797e-015+dpeta0nrf_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0nrf_mlvt'  LU0        = '-6.7466293e-010+dlu0nrf_mlvt'
+WU0        = '-7.6703892e-009+dwu0nrf_mlvt'
+PU0        = '6.2413382e-016+dpu0nrf_mlvt'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatnrf_mlvt'  LVSAT      = '-0.0010680136+dlvsatnrf_mlvt'
+WVSAT      = '0.0069449685+dwvsatnrf_mlvt'
+PVSAT      = '-1.3310085e-009+dpvsatnrf_mlvt'
+A0         = 2.0693451           LA0        = '-7.0903035e-007+dla0nrf_mlvt'
+WA0        = -9.0869732e-007     PA0        = 4.1268564e-013      AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'              CGBO       = 0
+CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 0
+CJD        = 0			MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt'      WNFACTOR   = '0+dwnfactornrf_mlvt'      PNFACTOR   = '0+dpnfactornrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44977917+(dvthnrf_mlvt+vthmisnrf_mlvt)-0.00994084*ff_flagrf_mlvt'
+LVTH0      = '-2.7852085e-09+dlvthnrf_mlvt+9.52137e-10*ff_flagrf_mlvt'
+WVTH0      = '-2.3073464e-08+dwvthnrf_mlvt+1.01397e-08*ff_flagrf_mlvt'
+PVTH0      = '1.7230434e-15+dpvthnrf_mlvt-9.7118e-16*ff_flagrf_mlvt'
+K1         = 0.31994             K2         = '-0.014947392+dk2nrf_mlvt' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitnrf_mlvt'
+WCIT       = '-4.2348127e-010+dwcitnrf_mlvt'
+PCIT       = 6.2821635e-017
+VOFF       = -0.11890298
+LVOFF      = '-3.9086059e-09+dlvoffnrf_mlvt'
+WVOFF      = '-6.798364e-09+dwvoffnrf_mlvt'
+PVOFF      = '-6.09942e-17+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt+0.745563*ff_flagrf_mlvt-0.745563*ss_flagrf_mlvt'
+ETA0       = '-0.051871703+deta0nrf_mlvt+0.0294899*ff_flagrf_mlvt-0.0393199*ss_flagrf_mlvt'
+LETA0      = '1.2984759e-008+dleta0nrf_mlvt-2.82456e-09*ff_flagrf_mlvt+3.76608e-09*ss_flagrf_mlvt'
+WETA0      = '5.4763418e-008+dweta0nrf_mlvt-3.00797e-08*ff_flagrf_mlvt+4.01063e-08*ss_flagrf_mlvt'
+PETA0      = '-4.6293634e-015+dpeta0nrf_mlvt+2.88105e-15*ff_flagrf_mlvt-3.8414e-15*ss_flagrf_mlvt'
+ETAB       = -0.18617972
+LETAB      = 6.908976e-09
+WETAB      = 3.8528064e-08
+PETAB      = -2.7771351e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0nrf_mlvt'  LU0        = '1.4350807e-010+dlu0nrf_mlvt'
+WU0        = '-2.7003787e-009+dwu0nrf_mlvt'
+PU0        = '1.4810125e-016+dpu0nrf_mlvt'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023
+UB         = 6.5255326e-19
+LUB        = 8.6437068e-26
+WUB        = 7.7434308e-25
+PUB        = -8.0830175e-32
+UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatnrf_mlvt-5278.06*ff_flagrf_mlvt+3931.99*ss_flagrf_mlvt'
+LVSAT      = '-0.00026235326+dlvsatnrf_mlvt+0.000505535*ff_flagrf_mlvt-0.000376608*ss_flagrf_mlvt'
+WVSAT      = '-0.0099049722+dwvsatnrf_mlvt+0.00472945*ff_flagrf_mlvt-0.00401063*ss_flagrf_mlvt'
+PVSAT      = '2.8289571e-010+dpvsatnrf_mlvt-4.52989e-10*ff_flagrf_mlvt+3.8414e-10*ss_flagrf_mlvt'
+A0         = -8.937762           LA0        = '3.4524137e-007+dla0nrf_mlvt'
+WA0        = 8.3688639e-006      PA0        = -4.7592845e-013     AGS        = 6.4966895
+LAGS       = 1.5356668e-007      WAGS       = -3.162e-006         PAGS       = -1.6753592e-027
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'              CGBO       = 0
+CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0
+KT2        = -0.080271035
+LKT2       = 1.5876912e-09
+WKT2       = -9.918812e-09
+PKT2       = 1.3441123e-15
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 0			CJD        = 0			MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 0			CJSWD      = 0			MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 0			CJSWGD     = 0			MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt-7.14103e-08*ff_flagrf_mlvt+7.14103e-08*ss_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactornrf_mlvt-7.60474e-07*ff_flagrf_mlvt+7.60474e-07*ss_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactornrf_mlvt+7.28385e-14*ff_flagrf_mlvt-7.28385e-14*ss_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswnrf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.005                   TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 0.0004                  FCS    = 0			   )

.MODEL ndio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgnrf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.52                    TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0015                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 2.4e-05                 FCS    = 0			   )

.ends nmos_rf_mlvt

.subckt pmos_rf_mlvt D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parp1rf_mlvt  temp2=parp2rf_mlvt
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_mlvt='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_mlvt = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_mlvt = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_mlvt='0.00253346*geo_fac*toxprf_mlvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mlvt_mc*par1fn_mc+noiseflagprf_mlvt_mc_mis*par2fprf_mlvt_mc'
.param c1fprf_mlvt=9.50E+41           c2fprf_mlvt=1.55E+24           c3fprf_mlvt=1.00E+10
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_mlvt='c1fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noibprf_mlvt='c2fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noicprf_mlvt='c3fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_mlvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '3.2178643e-009+dlvthprf_mlvt'
+WVTH0      = '1.3206912e-008+dwvthprf_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2prf_mlvt'  LK2        = '7.5980421e-010+dlk2prf_mlvt'
+WK2        = '-8.0262273e-009+dwk2prf_mlvt'
+PK2        = '1.0831329e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf_mlvt'
+WCIT       = '-9.439202e-010+dwcitprf_mlvt'
+PCIT       = '7.5195034e-017+dpcitprf_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffprf_mlvt'
+PVOFF      = '1.283818e-015+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.15306049+deta0prf_mlvt' LETA0      = '-4.6449316e-013+dleta0prf_mlvt'
+WETA0      = '-4.8996634e-009+dweta0prf_mlvt'
+PETA0      = '1.2028151e-018+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf_mlvt'  LU0        = '1.3663252e-012+dlu0prf_mlvt'
+WU0        = '8.2210644e-011+dwu0prf_mlvt'
+PU0        = '-1.3690578e-017+dpu0prf_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf_mlvt'  LVSAT      = '0.0017671522+dlvsatprf_mlvt'
+WVSAT      = '0.0019549554+dwvsatprf_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatprf_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf_mlvt'
+LAT        = '-0.036846346+dlatprf_mlvt'
+WAT        = '-0.32267684+dwatprf_mlvt'
+PAT        = '3.5967105e-08+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt'      PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+(dvthprf_mlvt+vthmisprf_mlvt)-0.00675618*ff_flagrf_mlvt-0.00540495*sf_flagrf_mlvt+0.00540495*fs_flagrf_mlvt'
+LVTH0      = '-2.750318e-09+dlvthprf_mlvt+6.65482e-10*ff_flagrf_mlvt+5.32386e-10*sf_flagrf_mlvt-5.32386e-10*fs_flagrf_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthprf_mlvt-1.6e-15*ff_flagrf_mlvt+2.7e-15*sf_flagrf_mlvt-2.7e-15*fs_flagrf_mlvt'
+PVTH0      = '1.7447113e-15+dpvthprf_mlvt+4.7e-22*ff_flagrf_mlvt+1.7e-22*sf_flagrf_mlvt-1.7e-22*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2prf_mlvt'   LK2        = '1.0154813e-010+dlk2prf_mlvt'
+WK2        = '-1.8062006e-008+dwk2prf_mlvt'
+PK2        = '1.0968375e-015+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitprf_mlvt'
+WCIT       = '9.334878e-11+dwcitprf_mlvt'
+PCIT       = '-2.6975657e-17+dpcitprf_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flagrf_mlvt-0.00601751*sf_flagrf_mlvt+0.00601751*fs_flagrf_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffprf_mlvt+7.40903e-10*ff_flagrf_mlvt+5.92723e-10*sf_flagrf_mlvt-5.92723e-10*fs_flagrf_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffprf_mlvt+7.67232e-09*ff_flagrf_mlvt+6.13786e-09*sf_flagrf_mlvt-6.13786e-09*fs_flagrf_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffprf_mlvt-7.55721e-16*ff_flagrf_mlvt-6.04577e-16*sf_flagrf_mlvt+6.04577e-16*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.36078*ff_flagrf_mlvt+0.288624*sf_flagrf_mlvt-0.288624*fs_flagrf_mlvt'
+ETA0       = '0.14001953+deta0prf_mlvt'
+LETA0      = '1.2840682e-09+dleta0prf_mlvt'
+WETA0      = '-3.0630437e-08+dweta0prf_mlvt'
+PETA0      = '2.5356774e-15+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf_mlvt-0.000346007*ss_flagrf_mlvt'
+LU0        = '4.0694732e-012+dlu0prf_mlvt+3.40816e-11*ss_flagrf_mlvt'
+WU0        = '-1.5318415e-010+dwu0prf_mlvt+3.52927e-10*ss_flagrf_mlvt'
+PU0        = '9.495809e-018+dpu0prf_mlvt-3.47632e-17*ss_flagrf_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatprf_mlvt'
+LVSAT      = '-0.0010658424+dlvsatprf_mlvt'
+WVSAT      = '-0.0081360267+dwvsatprf_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatprf_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flagrf_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmprf_mlvt+4.44542e-08*ss_flagrf_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flagrf_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmprf_mlvt-4.53433e-14*ss_flagrf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf_mlvt'
+LAT        = '0.0065683527+dlatprf_mlvt'
+WAT        = '0.09819304+dwatprf_mlvt'
+PAT        = '-5.4885776e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt-3.55368e-08*ff_flagrf_mlvt-2.84294e-08*sf_flagrf_mlvt+2.84294e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-2.3017e-07*ff_flagrf_mlvt-1.84136e-07*sf_flagrf_mlvt+1.84136e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+2.26717e-14*ff_flagrf_mlvt+1.81374e-14*sf_flagrf_mlvt-1.81374e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '1.8657789e-009+dlvthprf_mlvt'
+WVTH0      = '2.5644645e-010+dwvthprf_mlvt'
+PVTH0      = '4.9032594e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2prf_mlvt'  LK2        = '8.7204533e-010+dlk2prf_mlvt'
+WK2        = '-1.4195742e-009+dwk2prf_mlvt'
+PK2        = '-6.1726576e-018+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf_mlvt'
+WCIT       = '1.6122937e-009+dwcitprf_mlvt'
+PCIT       = '-1.9902291e-016+dpcitprf_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffprf_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.14756059+deta0prf_mlvt' LETA0      = '-1.9572049e-010+dleta0prf_mlvt'
+WETA0      = '7.102273e-010+dweta0prf_mlvt'
+PETA0      = '2.0036393e-016+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf_mlvt'  LU0        = '-1.2055811e-011+dlu0prf_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf_mlvt'  LVSAT      = '0.0033816548+dlvsatprf_mlvt'
+WVSAT      = '0.0091118432+dwvsatprf_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatprf_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf_mlvt'
+LAT        = '-0.010714171+dlatprf_mlvt'
+WAT        = '-0.11098338+dwatprf_mlvt'
+PAT        = '9.3122869e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt'
+PU0        = '0+dpu0prf_mlvt'           LNFACTOR   = '0+dlnfactorprf_mlvt'      WNFACTOR   = '0+dwnfactorprf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_rf_mlvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+(dvthprf_mlvt+vthmisprf_mlvt)-0.0172283*ff_flagrf_mlvt-0.0137826*sf_flagrf_mlvt+0.0137826*fs_flagrf_mlvt'
+LVTH0      = '2.958878e-09+dlvthprf_mlvt+1.69698e-09*ff_flagrf_mlvt+1.35758e-09*sf_flagrf_mlvt-1.35758e-09*fs_flagrf_mlvt'
+WVTH0      = '4.664221e-08+dwvthprf_mlvt+1.06815e-08*ff_flagrf_mlvt+8.54522e-09*sf_flagrf_mlvt-8.54522e-09*fs_flagrf_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthprf_mlvt-1.05213e-15*ff_flagrf_mlvt-8.41702e-16*sf_flagrf_mlvt+8.41702e-16*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2prf_mlvt'  LK2        = '7.0199448e-010+dlk2prf_mlvt'
+WK2        = '-6.399827e-009+dwk2prf_mlvt'
+PK2        = '4.8438224e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitprf_mlvt'
+WCIT       = '9.515692e-10+dwcitprf_mlvt'
+PCIT       = '-1.3394136e-16+dpcitprf_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flagrf_mlvt-0.0117287*sf_flagrf_mlvt+0.0117287*fs_flagrf_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffprf_mlvt+1.4441e-09*ff_flagrf_mlvt+1.15528e-09*sf_flagrf_mlvt-1.15528e-09*fs_flagrf_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffprf_mlvt+1.49541e-08*ff_flagrf_mlvt+1.19633e-08*sf_flagrf_mlvt-1.19633e-08*fs_flagrf_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffprf_mlvt-1.47298e-15*ff_flagrf_mlvt-1.17838e-15*sf_flagrf_mlvt+1.17838e-15*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.97289*ff_flagrf_mlvt+0.275652*sf_flagrf_mlvt-0.275652*fs_flagrf_mlvt'
+ETA0       = '0.07520113+deta0prf_mlvt'
+LETA0      = '6.9316746e-09+dleta0prf_mlvt'
+WETA0      = '3.5484332e-08+dweta0prf_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf_mlvt+0.000837767*ff_flagrf_mlvt+0.000670213*sf_flagrf_mlvt-0.000670213*fs_flagrf_mlvt'
+LU0        = '1.337909e-011+dlu0prf_mlvt-8.25198e-11*ff_flagrf_mlvt-6.60158e-11*sf_flagrf_mlvt+6.60158e-11*fs_flagrf_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatprf_mlvt-4188.83*ff_flagrf_mlvt-3351.07*sf_flagrf_mlvt+3351.07*fs_flagrf_mlvt'
+LVSAT      = '-0.0022357018+dlvsatprf_mlvt+0.000412599*ff_flagrf_mlvt+0.000330079*sf_flagrf_mlvt-0.000330079*fs_flagrf_mlvt'
+WVSAT      = '-0.029812142+dwvsatprf_mlvt+0.00427261*ff_flagrf_mlvt+0.00341809*sf_flagrf_mlvt-0.00341809*fs_flagrf_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatprf_mlvt-4.20851e-10*ff_flagrf_mlvt-3.36681e-10*sf_flagrf_mlvt+3.36681e-10*fs_flagrf_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmprf_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf_mlvt'
+LAT        = '-0.0064077479+dlatprf_mlvt'
+WAT        = '-0.095092602+dwatprf_mlvt'
+PAT        = '7.7470449e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt-8.54522e-10*ff_flagrf_mlvt-6.83618e-10*sf_flagrf_mlvt+6.83618e-10*fs_flagrf_mlvt'
+PU0        = '0+dpu0prf_mlvt+8.41702e-17*ff_flagrf_mlvt+6.73361e-17*sf_flagrf_mlvt-6.73361e-17*fs_flagrf_mlvt'
+LNFACTOR   = '0+dlnfactorprf_mlvt-9.58294e-08*ff_flagrf_mlvt-2.71517e-08*sf_flagrf_mlvt+2.71517e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-8.54523e-07*ff_flagrf_mlvt-1.70904e-07*sf_flagrf_mlvt+1.70904e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+8.41701e-14*ff_flagrf_mlvt+1.6834e-14*sf_flagrf_mlvt-1.6834e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf_mlvt

.subckt pmos_rf_mlvt_nw D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parp1rf_mlvt  temp2=parp2rf_mlvt
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_mlvt='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_mlvt = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_mlvt = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_mlvt='0.00253346*geo_fac*toxprf_mlvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mlvt_mc*par1fn_mc+noiseflagprf_mlvt_mc_mis*par2fprf_mlvt_mc'
.param c1fprf_mlvt=9.50E+41           c2fprf_mlvt=1.55E+24           c3fprf_mlvt=1.00E+10
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_mlvt='c1fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noibprf_mlvt='c2fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noicprf_mlvt='c3fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_mlvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '3.2178643e-009+dlvthprf_mlvt'
+WVTH0      = '1.3206912e-008+dwvthprf_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2prf_mlvt'  LK2        = '7.5980421e-010+dlk2prf_mlvt'
+WK2        = '-8.0262273e-009+dwk2prf_mlvt'
+PK2        = '1.0831329e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf_mlvt'
+WCIT       = '-9.439202e-010+dwcitprf_mlvt'
+PCIT       = '7.5195034e-017+dpcitprf_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffprf_mlvt'
+PVOFF      = '1.283818e-015+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.15306049+deta0prf_mlvt' LETA0      = '-4.6449316e-013+dleta0prf_mlvt'
+WETA0      = '-4.8996634e-009+dweta0prf_mlvt'
+PETA0      = '1.2028151e-018+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf_mlvt'  LU0        = '1.3663252e-012+dlu0prf_mlvt'
+WU0        = '8.2210644e-011+dwu0prf_mlvt'
+PU0        = '-1.3690578e-017+dpu0prf_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf_mlvt'  LVSAT      = '0.0017671522+dlvsatprf_mlvt'
+WVSAT      = '0.0019549554+dwvsatprf_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatprf_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf_mlvt'
+LAT        = '-0.036846346+dlatprf_mlvt'
+WAT        = '-0.32267684+dwatprf_mlvt'
+PAT        = '3.5967105e-08+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt'      PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+(dvthprf_mlvt+vthmisprf_mlvt)-0.00675618*ff_flagrf_mlvt-0.00540495*sf_flagrf_mlvt+0.00540495*fs_flagrf_mlvt'
+LVTH0      = '-2.750318e-09+dlvthprf_mlvt+6.65482e-10*ff_flagrf_mlvt+5.32386e-10*sf_flagrf_mlvt-5.32386e-10*fs_flagrf_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthprf_mlvt-1.6e-15*ff_flagrf_mlvt+2.7e-15*sf_flagrf_mlvt-2.7e-15*fs_flagrf_mlvt'
+PVTH0      = '1.7447113e-15+dpvthprf_mlvt+4.7e-22*ff_flagrf_mlvt+1.7e-22*sf_flagrf_mlvt-1.7e-22*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2prf_mlvt'   LK2        = '1.0154813e-010+dlk2prf_mlvt'
+WK2        = '-1.8062006e-008+dwk2prf_mlvt'
+PK2        = '1.0968375e-015+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitprf_mlvt'
+WCIT       = '9.334878e-11+dwcitprf_mlvt'
+PCIT       = '-2.6975657e-17+dpcitprf_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flagrf_mlvt-0.00601751*sf_flagrf_mlvt+0.00601751*fs_flagrf_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffprf_mlvt+7.40903e-10*ff_flagrf_mlvt+5.92723e-10*sf_flagrf_mlvt-5.92723e-10*fs_flagrf_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffprf_mlvt+7.67232e-09*ff_flagrf_mlvt+6.13786e-09*sf_flagrf_mlvt-6.13786e-09*fs_flagrf_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffprf_mlvt-7.55721e-16*ff_flagrf_mlvt-6.04577e-16*sf_flagrf_mlvt+6.04577e-16*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.36078*ff_flagrf_mlvt+0.288624*sf_flagrf_mlvt-0.288624*fs_flagrf_mlvt'
+ETA0       = '0.14001953+deta0prf_mlvt'
+LETA0      = '1.2840682e-09+dleta0prf_mlvt'
+WETA0      = '-3.0630437e-08+dweta0prf_mlvt'
+PETA0      = '2.5356774e-15+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf_mlvt-0.000346007*ss_flagrf_mlvt'
+LU0        = '4.0694732e-012+dlu0prf_mlvt+3.40816e-11*ss_flagrf_mlvt'
+WU0        = '-1.5318415e-010+dwu0prf_mlvt+3.52927e-10*ss_flagrf_mlvt'
+PU0        = '9.495809e-018+dpu0prf_mlvt-3.47632e-17*ss_flagrf_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatprf_mlvt'
+LVSAT      = '-0.0010658424+dlvsatprf_mlvt'
+WVSAT      = '-0.0081360267+dwvsatprf_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatprf_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flagrf_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmprf_mlvt+4.44542e-08*ss_flagrf_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flagrf_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmprf_mlvt-4.53433e-14*ss_flagrf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf_mlvt'
+LAT        = '0.0065683527+dlatprf_mlvt'
+WAT        = '0.09819304+dwatprf_mlvt'
+PAT        = '-5.4885776e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt-3.55368e-08*ff_flagrf_mlvt-2.84294e-08*sf_flagrf_mlvt+2.84294e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-2.3017e-07*ff_flagrf_mlvt-1.84136e-07*sf_flagrf_mlvt+1.84136e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+2.26717e-14*ff_flagrf_mlvt+1.81374e-14*sf_flagrf_mlvt-1.81374e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '1.8657789e-009+dlvthprf_mlvt'
+WVTH0      = '2.5644645e-010+dwvthprf_mlvt'
+PVTH0      = '4.9032594e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2prf_mlvt'  LK2        = '8.7204533e-010+dlk2prf_mlvt'
+WK2        = '-1.4195742e-009+dwk2prf_mlvt'
+PK2        = '-6.1726576e-018+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf_mlvt'
+WCIT       = '1.6122937e-009+dwcitprf_mlvt'
+PCIT       = '-1.9902291e-016+dpcitprf_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffprf_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.14756059+deta0prf_mlvt' LETA0      = '-1.9572049e-010+dleta0prf_mlvt'
+WETA0      = '7.102273e-010+dweta0prf_mlvt'
+PETA0      = '2.0036393e-016+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf_mlvt'  LU0        = '-1.2055811e-011+dlu0prf_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf_mlvt'  LVSAT      = '0.0033816548+dlvsatprf_mlvt'
+WVSAT      = '0.0091118432+dwvsatprf_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatprf_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf_mlvt'
+LAT        = '-0.010714171+dlatprf_mlvt'
+WAT        = '-0.11098338+dwatprf_mlvt'
+PAT        = '9.3122869e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt'
+PU0        = '0+dpu0prf_mlvt'           LNFACTOR   = '0+dlnfactorprf_mlvt'      WNFACTOR   = '0+dwnfactorprf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+(dvthprf_mlvt+vthmisprf_mlvt)-0.0172283*ff_flagrf_mlvt-0.0137826*sf_flagrf_mlvt+0.0137826*fs_flagrf_mlvt'
+LVTH0      = '2.958878e-09+dlvthprf_mlvt+1.69698e-09*ff_flagrf_mlvt+1.35758e-09*sf_flagrf_mlvt-1.35758e-09*fs_flagrf_mlvt'
+WVTH0      = '4.664221e-08+dwvthprf_mlvt+1.06815e-08*ff_flagrf_mlvt+8.54522e-09*sf_flagrf_mlvt-8.54522e-09*fs_flagrf_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthprf_mlvt-1.05213e-15*ff_flagrf_mlvt-8.41702e-16*sf_flagrf_mlvt+8.41702e-16*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2prf_mlvt'  LK2        = '7.0199448e-010+dlk2prf_mlvt'
+WK2        = '-6.399827e-009+dwk2prf_mlvt'
+PK2        = '4.8438224e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitprf_mlvt'
+WCIT       = '9.515692e-10+dwcitprf_mlvt'
+PCIT       = '-1.3394136e-16+dpcitprf_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flagrf_mlvt-0.0117287*sf_flagrf_mlvt+0.0117287*fs_flagrf_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffprf_mlvt+1.4441e-09*ff_flagrf_mlvt+1.15528e-09*sf_flagrf_mlvt-1.15528e-09*fs_flagrf_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffprf_mlvt+1.49541e-08*ff_flagrf_mlvt+1.19633e-08*sf_flagrf_mlvt-1.19633e-08*fs_flagrf_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffprf_mlvt-1.47298e-15*ff_flagrf_mlvt-1.17838e-15*sf_flagrf_mlvt+1.17838e-15*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.97289*ff_flagrf_mlvt+0.275652*sf_flagrf_mlvt-0.275652*fs_flagrf_mlvt'
+ETA0       = '0.07520113+deta0prf_mlvt'
+LETA0      = '6.9316746e-09+dleta0prf_mlvt'
+WETA0      = '3.5484332e-08+dweta0prf_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf_mlvt+0.000837767*ff_flagrf_mlvt+0.000670213*sf_flagrf_mlvt-0.000670213*fs_flagrf_mlvt'
+LU0        = '1.337909e-011+dlu0prf_mlvt-8.25198e-11*ff_flagrf_mlvt-6.60158e-11*sf_flagrf_mlvt+6.60158e-11*fs_flagrf_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatprf_mlvt-4188.83*ff_flagrf_mlvt-3351.07*sf_flagrf_mlvt+3351.07*fs_flagrf_mlvt'
+LVSAT      = '-0.0022357018+dlvsatprf_mlvt+0.000412599*ff_flagrf_mlvt+0.000330079*sf_flagrf_mlvt-0.000330079*fs_flagrf_mlvt'
+WVSAT      = '-0.029812142+dwvsatprf_mlvt+0.00427261*ff_flagrf_mlvt+0.00341809*sf_flagrf_mlvt-0.00341809*fs_flagrf_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatprf_mlvt-4.20851e-10*ff_flagrf_mlvt-3.36681e-10*sf_flagrf_mlvt+3.36681e-10*fs_flagrf_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmprf_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf_mlvt'
+LAT        = '-0.0064077479+dlatprf_mlvt'
+WAT        = '-0.095092602+dwatprf_mlvt'
+PAT        = '7.7470449e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt-8.54522e-10*ff_flagrf_mlvt-6.83618e-10*sf_flagrf_mlvt+6.83618e-10*fs_flagrf_mlvt'
+PU0        = '0+dpu0prf_mlvt+8.41702e-17*ff_flagrf_mlvt+6.73361e-17*sf_flagrf_mlvt-6.73361e-17*fs_flagrf_mlvt'
+LNFACTOR   = '0+dlnfactorprf_mlvt-9.58294e-08*ff_flagrf_mlvt-2.71517e-08*sf_flagrf_mlvt+2.71517e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-8.54523e-07*ff_flagrf_mlvt-1.70904e-07*sf_flagrf_mlvt+1.70904e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+8.41701e-14*ff_flagrf_mlvt+1.6834e-14*sf_flagrf_mlvt-1.6834e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf_mlvt_nw


.subckt nmos_rf_mlvt_6t D G S B NG PG lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parn1rf_mlvt  temp2=parn2rf_mlvt
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_mlvt='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_mlvt='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_mlvt='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_mlvt='0.00216908*geo_fac*toxnrf_mlvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1603.5*lr*scale/nr/(wr*scale)+2.575)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.084e05/(lr*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(lr*scale*1e6)+0.4837'

.param fn_dice='noiseflagnrf_mlvt_mc*par1fn_mc+noiseflagnrf_mlvt_mc_mis*par2fnrf_mlvt_mc'
.param c1fnrf_mlvt=8.00E+41           c2fnrf_mlvt=5.00E+22           c3fnrf_mlvt=1.00E+7 
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.555*log(((wr*scale*lr*scale*nr)/(12.7E-6*1E-6*1))**0.5)))'
.param noianrf_mlvt='c1fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'
.param noibnrf_mlvt='c2fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'
.param noicnrf_mlvt='c3fnrf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_mlvt    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_mlvt  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V mlvt-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_mlvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthnrf_mlvt+vthmisnrf_mlvt)'  LVTH0      = '-2.6209825e-009+dlvthnrf_mlvt'
+WVTH0      = '6.8814839e-010+dwvthnrf_mlvt'
+PVTH0      = '-5.3326435e-017+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '0.0071010498+dk2nrf_mlvt' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitnrf_mlvt'
+WCIT       = '-2.634146e-010+dwcitnrf_mlvt'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffnrf_mlvt'
+WVOFF      = '-2.7301032e-008+dwvoffnrf_mlvt'
+PVOFF      = '3.8940424e-015+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt'    ETA0       = '0.10402516+deta0nrf_mlvt' LETA0      = '-1.6784547e-010+dleta0nrf_mlvt'
+WETA0      = '-3.0136772e-008+dweta0nrf_mlvt'
+PETA0      = '1.6875216e-015+dpeta0nrf_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0nrf_mlvt'  LU0        = '6.0443544e-011+dlu0nrf_mlvt'
+WU0        = '-3.4587047e-010+dwu0nrf_mlvt'
+PU0        = '-1.2567478e-016+dpu0nrf_mlvt'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatnrf_mlvt'  LVSAT      = '-0.00073522225+dlvsatnrf_mlvt'
+WVSAT      = '0.013868259+dwvsatnrf_mlvt'
+PVSAT      = '-1.6704557e-009+dpvsatnrf_mlvt'
+A0         = 0.71811517          LA0        = '-2.3073092e-007+dla0nrf_mlvt'
+WA0        = 4.6955716e-007      PA0        = -7.5179779e-014     AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2nrf_mlvt'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf_mlvt'
+RDW        = '65+drdswnrf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxnrf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_mlvt'
+CGDO       = 'cgonrf_mlvt'              CGBO       = 0                   CGDL       = 'cglnrf_mlvt'
+CGSL       = 'cglnrf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt'
+WNFACTOR   = '0+dwnfactornrf_mlvt'      PNFACTOR   = '0+dpnfactornrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+WMIN       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44338471+(dvthnrf_mlvt+vthmisnrf_mlvt)'
+LVTH0      = '-2.6624817e-09+dlvthnrf_mlvt'
+WVTH0      = '-1.6551106e-08+dwvthnrf_mlvt'
+PVTH0      = '1.597862e-15+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '0.0013060071+dk2nrf_mlvt' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0020197491
+LCIT       = '4.0216548e-10+dlcitnrf_mlvt'
+WCIT       = '5.152138e-10+dwcitnrf_mlvt'
+PCIT       = -9.614958e-17
+VOFF       = -0.16044316
+LVOFF      = '-1.8820754e-09+dlvoffnrf_mlvt'
+WVOFF      = '3.5572622e-08+dwvoffnrf_mlvt'
+PVOFF      = '-2.1280553e-15+dpvoffnrf_mlvt'
+NFACTOR    = '0.60878657+dnfactornrf_mlvt+0.207839*ss_flagrf_mlvt'
+ETA0       = '-0.013762419+deta0nrf_mlvt+0.00706067*ff_flagrf_mlvt+0.0141213*ss_flagrf_mlvt'
+LETA0      = '1.1113958e-08+dleta0nrf_mlvt-6.76274e-10*ff_flagrf_mlvt-1.35255e-09*ss_flagrf_mlvt'
+WETA0      = '1.5891949e-08+dweta0nrf_mlvt-7.20189e-09*ff_flagrf_mlvt-1.44038e-08*ss_flagrf_mlvt'
+PETA0      = '-2.7211461e-15+dpeta0nrf_mlvt+6.89799e-16*ff_flagrf_mlvt+1.3796e-15*ss_flagrf_mlvt'
+ETAB       = -0.11384089
+LETAB      = 2.9069217e-09
+WETAB      = -3.5257548e-08
+PETAB      = 1.3049602e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0nrf_mlvt'   LU0        = '4.5926676e-011+dlu0nrf_mlvt'
+WU0        = '-4.2433976e-009+dwu0nrf_mlvt'
+PU0        = '2.4763426e-016+dpu0nrf_mlvt'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024
+UB         = 1.7538672e-18
+LUB        = -6.6974505e-28
+WUB        = -3.4899719e-25
+PUB        = 8.0187736e-33
+UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '90298.236+dvsatnrf_mlvt+72.6857*ff_flagrf_mlvt'
+LVSAT      = '0.00017603274+dlvsatnrf_mlvt-6.96186e-06*ff_flagrf_mlvt'
+WVSAT      = '-0.0018572123+dwvsatnrf_mlvt-0.000728311*ff_flagrf_mlvt'
+PVSAT      = '-1.6425802e-10+dpvsatnrf_mlvt+6.97579e-11*ff_flagrf_mlvt'
+A0         = 1.6696481           LA0        = '-3.2186969e-007+dla0nrf_mlvt'
+WA0        = -2.4506944e-006     PA0        = 2.0452483e-013      AGS        = 3.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'
+CGBO       = 0                   CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'
+CLC        = 0			CLE        = 0.6                 CF         = 'cfnrf_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.12701693
+LKT2       = 6.0452217e-09
+WKT2       = 3.7762002e-08
+PKT2       = -3.2025688e-15
+UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '1.3525474e-08+dlnfactornrf_mlvt-1.99069e-08*ss_flagrf_mlvt'
+WNFACTOR   = '1.440377e-07+dwnfactornrf_mlvt-2.11996e-07*ss_flagrf_mlvt'
+PNFACTOR   = '-1.3795983e-14+dpnfactornrf_mlvt+2.0305e-14*ss_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthnrf_mlvt+vthmisnrf_mlvt)'  LVTH0      = '-2.4452732e-009+dlvthnrf_mlvt'
+WVTH0      = '-2.656096e-009+dwvthnrf_mlvt'
+PVTH0      = '-2.3254991e-016+dpvthnrf_mlvt'
+K1         = 0.31994             K2         = '-0.0077298678+dk2nrf_mlvt'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitnrf_mlvt'
+WCIT       = '4.0796102e-010+dwcitnrf_mlvt'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffnrf_mlvt'
+WVOFF      = '-1.6424805e-008+dwvoffnrf_mlvt'
+PVOFF      = '8.6103596e-016+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt'    ETA0       = '0.044118879+deta0nrf_mlvt'
+LETA0      = '3.7906852e-009+dleta0nrf_mlvt'
+WETA0      = '3.0967637e-008+dweta0nrf_mlvt'
+PETA0      = '-2.3501797e-015+dpeta0nrf_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0nrf_mlvt'  LU0        = '-6.7466293e-010+dlu0nrf_mlvt'
+WU0        = '-7.6703892e-009+dwu0nrf_mlvt'
+PU0        = '6.2413382e-016+dpu0nrf_mlvt'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatnrf_mlvt'  LVSAT      = '-0.0010680136+dlvsatnrf_mlvt'
+WVSAT      = '0.0069449685+dwvsatnrf_mlvt'
+PVSAT      = '-1.3310085e-009+dpvsatnrf_mlvt'
+A0         = 2.0693451           LA0        = '-7.0903035e-007+dla0nrf_mlvt'
+WA0        = -9.0869732e-007     PA0        = 4.1268564e-013      AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'              CGBO       = 0
+CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 0
+CJD        = 0			MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt'      WNFACTOR   = '0+dwnfactornrf_mlvt'      PNFACTOR   = '0+dpnfactornrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_mlvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999948e-008-(dxlnrf_mlvt+dlmisnrf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_mlvt+dwmisnrf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = 0			PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxnrf_mlvt+toxmisnrf_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxlnrf_mlvt+dlmisnrf_mlvt)'       XW         = '2.0e-08+(dxwnrf_mlvt+dwmisnrf_mlvt)'      DLC        = '-5.415E-09+ddlcnrf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44977917+(dvthnrf_mlvt+vthmisnrf_mlvt)-0.00994084*ff_flagrf_mlvt'
+LVTH0      = '-2.7852085e-09+dlvthnrf_mlvt+9.52137e-10*ff_flagrf_mlvt'
+WVTH0      = '-2.3073464e-08+dwvthnrf_mlvt+1.01397e-08*ff_flagrf_mlvt'
+PVTH0      = '1.7230434e-15+dpvthnrf_mlvt-9.7118e-16*ff_flagrf_mlvt'
+K1         = 0.31994             K2         = '-0.014947392+dk2nrf_mlvt' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitnrf_mlvt'
+WCIT       = '-4.2348127e-010+dwcitnrf_mlvt'
+PCIT       = 6.2821635e-017
+VOFF       = -0.11890298
+LVOFF      = '-3.9086059e-09+dlvoffnrf_mlvt'
+WVOFF      = '-6.798364e-09+dwvoffnrf_mlvt'
+PVOFF      = '-6.09942e-17+dpvoffnrf_mlvt'
+NFACTOR    = '0.75+dnfactornrf_mlvt+0.745563*ff_flagrf_mlvt-0.745563*ss_flagrf_mlvt'
+ETA0       = '-0.051871703+deta0nrf_mlvt+0.0294899*ff_flagrf_mlvt-0.0393199*ss_flagrf_mlvt'
+LETA0      = '1.2984759e-008+dleta0nrf_mlvt-2.82456e-09*ff_flagrf_mlvt+3.76608e-09*ss_flagrf_mlvt'
+WETA0      = '5.4763418e-008+dweta0nrf_mlvt-3.00797e-08*ff_flagrf_mlvt+4.01063e-08*ss_flagrf_mlvt'
+PETA0      = '-4.6293634e-015+dpeta0nrf_mlvt+2.88105e-15*ff_flagrf_mlvt-3.8414e-15*ss_flagrf_mlvt'
+ETAB       = -0.18617972
+LETAB      = 6.908976e-09
+WETAB      = 3.8528064e-08
+PETAB      = -2.7771351e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0nrf_mlvt'  LU0        = '1.4350807e-010+dlu0nrf_mlvt'
+WU0        = '-2.7003787e-009+dwu0nrf_mlvt'
+PU0        = '1.4810125e-016+dpu0nrf_mlvt'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023
+UB         = 6.5255326e-19
+LUB        = 8.6437068e-26
+WUB        = 7.7434308e-25
+PUB        = -8.0830175e-32
+UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatnrf_mlvt-5278.06*ff_flagrf_mlvt+3931.99*ss_flagrf_mlvt'
+LVSAT      = '-0.00026235326+dlvsatnrf_mlvt+0.000505535*ff_flagrf_mlvt-0.000376608*ss_flagrf_mlvt'
+WVSAT      = '-0.0099049722+dwvsatnrf_mlvt+0.00472945*ff_flagrf_mlvt-0.00401063*ss_flagrf_mlvt'
+PVSAT      = '2.8289571e-010+dpvsatnrf_mlvt-4.52989e-10*ff_flagrf_mlvt+3.8414e-10*ss_flagrf_mlvt'
+A0         = -8.937762           LA0        = '3.4524137e-007+dla0nrf_mlvt'
+WA0        = 8.3688639e-006      PA0        = -4.7592845e-013     AGS        = 6.4966895
+LAGS       = 1.5356668e-007      WAGS       = -3.162e-006         PAGS       = -1.6753592e-027
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2nrf_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_mlvt'         RDW        = '65+drdswnrf_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxnrf_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_mlvt'              CGDO       = 'cgonrf_mlvt'              CGBO       = 0
+CGDL       = 'cglnrf_mlvt'              CGSL       = 'cglnrf_mlvt'              CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0
+KT2        = -0.080271035
+LKT2       = 1.5876912e-09
+WKT2       = -9.918812e-09
+PKT2       = 1.3441123e-15
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianrf_mlvt'
+NOIB       = 'noibnrf_mlvt'
+NOIC       = 'noicnrf_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 0			CJD        = 0			MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 0			CJSWD      = 0			MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 0			CJSWGD     = 0			MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_mlvt-7.14103e-08*ff_flagrf_mlvt+7.14103e-08*ss_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactornrf_mlvt-7.60474e-07*ff_flagrf_mlvt+7.60474e-07*ss_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactornrf_mlvt+7.28385e-14*ff_flagrf_mlvt-7.28385e-14*ss_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswnrf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.005                   TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0005                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 0.0004                  FCS    = 0			   )

.MODEL ndio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 2.01e-07                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 4.17e-13                CJ     = 'cjnrf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgnrf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.52                    TLEVC  = 1
+CTA    = 0.0007                  CTP    = 0.0015                  
+TCV    = -0.90E-03               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.8                     PB     = 1
+IK     = 1E20                    TPB    = 0.002                   TREF   = 25
+TPHP   = 2.4e-05                 FCS    = 0			   )

.MODEL PWDNW_nrf_mlvt D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_mlvt'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_mlvt'
+ N      = '1.02*n_d_dnw_nrf_mlvt'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_mlvt)'  CJ     = '7.31E-04*cj_d_dnw_nrf_mlvt'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_mlvt'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_mlvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_mlvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_mlvt'
+ N      = '1.02*n_d_dnw_nrf_mlvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_mlvt)'  CJ     = '1.15E-04*cj_d_dnw_nrf_mlvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_mlvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_mlvt_6t

.subckt pmos_rf_mlvt_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parp1rf_mlvt  temp2=parp2rf_mlvt
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_mlvt='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_mlvt = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_mlvt = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_mlvt='0.00253346*geo_fac*toxprf_mlvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mlvt_mc*par1fn_mc+noiseflagprf_mlvt_mc_mis*par2fprf_mlvt_mc'
.param c1fprf_mlvt=9.50E+41           c2fprf_mlvt=1.55E+24           c3fprf_mlvt=1.00E+10
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_mlvt='c1fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noibprf_mlvt='c2fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noicprf_mlvt='c3fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_mlvt  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_mlvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '3.2178643e-009+dlvthprf_mlvt'
+WVTH0      = '1.3206912e-008+dwvthprf_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2prf_mlvt'  LK2        = '7.5980421e-010+dlk2prf_mlvt'
+WK2        = '-8.0262273e-009+dwk2prf_mlvt'
+PK2        = '1.0831329e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf_mlvt'
+WCIT       = '-9.439202e-010+dwcitprf_mlvt'
+PCIT       = '7.5195034e-017+dpcitprf_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffprf_mlvt'
+PVOFF      = '1.283818e-015+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.15306049+deta0prf_mlvt' LETA0      = '-4.6449316e-013+dleta0prf_mlvt'
+WETA0      = '-4.8996634e-009+dweta0prf_mlvt'
+PETA0      = '1.2028151e-018+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf_mlvt'  LU0        = '1.3663252e-012+dlu0prf_mlvt'
+WU0        = '8.2210644e-011+dwu0prf_mlvt'
+PU0        = '-1.3690578e-017+dpu0prf_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf_mlvt'  LVSAT      = '0.0017671522+dlvsatprf_mlvt'
+WVSAT      = '0.0019549554+dwvsatprf_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatprf_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf_mlvt'
+LAT        = '-0.036846346+dlatprf_mlvt'
+WAT        = '-0.32267684+dwatprf_mlvt'
+PAT        = '3.5967105e-08+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt'      PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+(dvthprf_mlvt+vthmisprf_mlvt)-0.00675618*ff_flagrf_mlvt-0.00540495*sf_flagrf_mlvt+0.00540495*fs_flagrf_mlvt'
+LVTH0      = '-2.750318e-09+dlvthprf_mlvt+6.65482e-10*ff_flagrf_mlvt+5.32386e-10*sf_flagrf_mlvt-5.32386e-10*fs_flagrf_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthprf_mlvt-1.6e-15*ff_flagrf_mlvt+2.7e-15*sf_flagrf_mlvt-2.7e-15*fs_flagrf_mlvt'
+PVTH0      = '1.7447113e-15+dpvthprf_mlvt+4.7e-22*ff_flagrf_mlvt+1.7e-22*sf_flagrf_mlvt-1.7e-22*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2prf_mlvt'   LK2        = '1.0154813e-010+dlk2prf_mlvt'
+WK2        = '-1.8062006e-008+dwk2prf_mlvt'
+PK2        = '1.0968375e-015+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitprf_mlvt'
+WCIT       = '9.334878e-11+dwcitprf_mlvt'
+PCIT       = '-2.6975657e-17+dpcitprf_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flagrf_mlvt-0.00601751*sf_flagrf_mlvt+0.00601751*fs_flagrf_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffprf_mlvt+7.40903e-10*ff_flagrf_mlvt+5.92723e-10*sf_flagrf_mlvt-5.92723e-10*fs_flagrf_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffprf_mlvt+7.67232e-09*ff_flagrf_mlvt+6.13786e-09*sf_flagrf_mlvt-6.13786e-09*fs_flagrf_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffprf_mlvt-7.55721e-16*ff_flagrf_mlvt-6.04577e-16*sf_flagrf_mlvt+6.04577e-16*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.36078*ff_flagrf_mlvt+0.288624*sf_flagrf_mlvt-0.288624*fs_flagrf_mlvt'
+ETA0       = '0.14001953+deta0prf_mlvt'
+LETA0      = '1.2840682e-09+dleta0prf_mlvt'
+WETA0      = '-3.0630437e-08+dweta0prf_mlvt'
+PETA0      = '2.5356774e-15+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf_mlvt-0.000346007*ss_flagrf_mlvt'
+LU0        = '4.0694732e-012+dlu0prf_mlvt+3.40816e-11*ss_flagrf_mlvt'
+WU0        = '-1.5318415e-010+dwu0prf_mlvt+3.52927e-10*ss_flagrf_mlvt'
+PU0        = '9.495809e-018+dpu0prf_mlvt-3.47632e-17*ss_flagrf_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatprf_mlvt'
+LVSAT      = '-0.0010658424+dlvsatprf_mlvt'
+WVSAT      = '-0.0081360267+dwvsatprf_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatprf_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flagrf_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmprf_mlvt+4.44542e-08*ss_flagrf_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flagrf_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmprf_mlvt-4.53433e-14*ss_flagrf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf_mlvt'
+LAT        = '0.0065683527+dlatprf_mlvt'
+WAT        = '0.09819304+dwatprf_mlvt'
+PAT        = '-5.4885776e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt-3.55368e-08*ff_flagrf_mlvt-2.84294e-08*sf_flagrf_mlvt+2.84294e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-2.3017e-07*ff_flagrf_mlvt-1.84136e-07*sf_flagrf_mlvt+1.84136e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+2.26717e-14*ff_flagrf_mlvt+1.81374e-14*sf_flagrf_mlvt-1.81374e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '1.8657789e-009+dlvthprf_mlvt'
+WVTH0      = '2.5644645e-010+dwvthprf_mlvt'
+PVTH0      = '4.9032594e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2prf_mlvt'  LK2        = '8.7204533e-010+dlk2prf_mlvt'
+WK2        = '-1.4195742e-009+dwk2prf_mlvt'
+PK2        = '-6.1726576e-018+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf_mlvt'
+WCIT       = '1.6122937e-009+dwcitprf_mlvt'
+PCIT       = '-1.9902291e-016+dpcitprf_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffprf_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.14756059+deta0prf_mlvt' LETA0      = '-1.9572049e-010+dleta0prf_mlvt'
+WETA0      = '7.102273e-010+dweta0prf_mlvt'
+PETA0      = '2.0036393e-016+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf_mlvt'  LU0        = '-1.2055811e-011+dlu0prf_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf_mlvt'  LVSAT      = '0.0033816548+dlvsatprf_mlvt'
+WVSAT      = '0.0091118432+dwvsatprf_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatprf_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf_mlvt'
+LAT        = '-0.010714171+dlatprf_mlvt'
+WAT        = '-0.11098338+dwatprf_mlvt'
+PAT        = '9.3122869e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt'
+PU0        = '0+dpu0prf_mlvt'           LNFACTOR   = '0+dlnfactorprf_mlvt'      WNFACTOR   = '0+dwnfactorprf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+(dvthprf_mlvt+vthmisprf_mlvt)-0.0172283*ff_flagrf_mlvt-0.0137826*sf_flagrf_mlvt+0.0137826*fs_flagrf_mlvt'
+LVTH0      = '2.958878e-09+dlvthprf_mlvt+1.69698e-09*ff_flagrf_mlvt+1.35758e-09*sf_flagrf_mlvt-1.35758e-09*fs_flagrf_mlvt'
+WVTH0      = '4.664221e-08+dwvthprf_mlvt+1.06815e-08*ff_flagrf_mlvt+8.54522e-09*sf_flagrf_mlvt-8.54522e-09*fs_flagrf_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthprf_mlvt-1.05213e-15*ff_flagrf_mlvt-8.41702e-16*sf_flagrf_mlvt+8.41702e-16*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2prf_mlvt'  LK2        = '7.0199448e-010+dlk2prf_mlvt'
+WK2        = '-6.399827e-009+dwk2prf_mlvt'
+PK2        = '4.8438224e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitprf_mlvt'
+WCIT       = '9.515692e-10+dwcitprf_mlvt'
+PCIT       = '-1.3394136e-16+dpcitprf_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flagrf_mlvt-0.0117287*sf_flagrf_mlvt+0.0117287*fs_flagrf_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffprf_mlvt+1.4441e-09*ff_flagrf_mlvt+1.15528e-09*sf_flagrf_mlvt-1.15528e-09*fs_flagrf_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffprf_mlvt+1.49541e-08*ff_flagrf_mlvt+1.19633e-08*sf_flagrf_mlvt-1.19633e-08*fs_flagrf_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffprf_mlvt-1.47298e-15*ff_flagrf_mlvt-1.17838e-15*sf_flagrf_mlvt+1.17838e-15*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.97289*ff_flagrf_mlvt+0.275652*sf_flagrf_mlvt-0.275652*fs_flagrf_mlvt'
+ETA0       = '0.07520113+deta0prf_mlvt'
+LETA0      = '6.9316746e-09+dleta0prf_mlvt'
+WETA0      = '3.5484332e-08+dweta0prf_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf_mlvt+0.000837767*ff_flagrf_mlvt+0.000670213*sf_flagrf_mlvt-0.000670213*fs_flagrf_mlvt'
+LU0        = '1.337909e-011+dlu0prf_mlvt-8.25198e-11*ff_flagrf_mlvt-6.60158e-11*sf_flagrf_mlvt+6.60158e-11*fs_flagrf_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatprf_mlvt-4188.83*ff_flagrf_mlvt-3351.07*sf_flagrf_mlvt+3351.07*fs_flagrf_mlvt'
+LVSAT      = '-0.0022357018+dlvsatprf_mlvt+0.000412599*ff_flagrf_mlvt+0.000330079*sf_flagrf_mlvt-0.000330079*fs_flagrf_mlvt'
+WVSAT      = '-0.029812142+dwvsatprf_mlvt+0.00427261*ff_flagrf_mlvt+0.00341809*sf_flagrf_mlvt-0.00341809*fs_flagrf_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatprf_mlvt-4.20851e-10*ff_flagrf_mlvt-3.36681e-10*sf_flagrf_mlvt+3.36681e-10*fs_flagrf_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmprf_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf_mlvt'
+LAT        = '-0.0064077479+dlatprf_mlvt'
+WAT        = '-0.095092602+dwatprf_mlvt'
+PAT        = '7.7470449e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt-8.54522e-10*ff_flagrf_mlvt-6.83618e-10*sf_flagrf_mlvt+6.83618e-10*fs_flagrf_mlvt'
+PU0        = '0+dpu0prf_mlvt+8.41702e-17*ff_flagrf_mlvt+6.73361e-17*sf_flagrf_mlvt-6.73361e-17*fs_flagrf_mlvt'
+LNFACTOR   = '0+dlnfactorprf_mlvt-9.58294e-08*ff_flagrf_mlvt-2.71517e-08*sf_flagrf_mlvt+2.71517e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-8.54523e-07*ff_flagrf_mlvt-1.70904e-07*sf_flagrf_mlvt+1.70904e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+8.41701e-14*ff_flagrf_mlvt+1.6834e-14*sf_flagrf_mlvt-1.6834e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf_mlvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_mlvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_mlvt'
+ N      = '1.02*n_d_dnw_prf_mlvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_mlvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_mlvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_mlvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_mlvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_mlvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_mlvt'
+ N      = '1.02*n_d_prf_mlvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_mlvt)'  CJ     = '1.37E-04*cj_d_prf_mlvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_mlvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_mlvt_5t

.subckt pmos_rf_mlvt_nw_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_mlvt'
.param
+temp1=parp1rf_mlvt  temp2=parp2rf_mlvt
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2.0e-08'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_mlvt='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_mlvt = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_mlvt = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_mlvt='0.00253346*geo_fac*toxprf_mlvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1916.8*lr*scale/nr/(wr*scale)+0.4689)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.773e05/(lr*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(lr*scale*1e6)+0.4706'

.param fn_dice='noiseflagprf_mlvt_mc*par1fn_mc+noiseflagprf_mlvt_mc_mis*par2fprf_mlvt_mc'
.param c1fprf_mlvt=9.50E+41           c2fprf_mlvt=1.55E+24           c3fprf_mlvt=1.00E+10
.param arearatio='sigma_factor_flicker_rf_mlvt*(log(3.873)-min(0,0.5*log(((wr*scale*lr*scale*nr)/(10.3E-6*1E-6*1))**0.5)))'
.param noiaprf_mlvt='c1fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noibprf_mlvt='c2fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'
.param noicprf_mlvt='c3fprf_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_mlvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_mlvt  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_mlvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_mlvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_mlvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_mlvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_mlvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_mlvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '3.2178643e-009+dlvthprf_mlvt'
+WVTH0      = '1.3206912e-008+dwvthprf_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2prf_mlvt'  LK2        = '7.5980421e-010+dlk2prf_mlvt'
+WK2        = '-8.0262273e-009+dwk2prf_mlvt'
+PK2        = '1.0831329e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitprf_mlvt'
+WCIT       = '-9.439202e-010+dwcitprf_mlvt'
+PCIT       = '7.5195034e-017+dpcitprf_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffprf_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffprf_mlvt'
+PVOFF      = '1.283818e-015+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.15306049+deta0prf_mlvt' LETA0      = '-4.6449316e-013+dleta0prf_mlvt'
+WETA0      = '-4.8996634e-009+dweta0prf_mlvt'
+PETA0      = '1.2028151e-018+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0prf_mlvt'  LU0        = '1.3663252e-012+dlu0prf_mlvt'
+WU0        = '8.2210644e-011+dwu0prf_mlvt'
+PU0        = '-1.3690578e-017+dpu0prf_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatprf_mlvt'  LVSAT      = '0.0017671522+dlvsatprf_mlvt'
+WVSAT      = '0.0019549554+dwvsatprf_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatprf_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmprf_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2prf_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datprf_mlvt'
+LAT        = '-0.036846346+dlatprf_mlvt'
+WAT        = '-0.32267684+dwatprf_mlvt'
+PAT        = '3.5967105e-08+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt'      PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+(dvthprf_mlvt+vthmisprf_mlvt)-0.00675618*ff_flagrf_mlvt-0.00540495*sf_flagrf_mlvt+0.00540495*fs_flagrf_mlvt'
+LVTH0      = '-2.750318e-09+dlvthprf_mlvt+6.65482e-10*ff_flagrf_mlvt+5.32386e-10*sf_flagrf_mlvt-5.32386e-10*fs_flagrf_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthprf_mlvt-1.6e-15*ff_flagrf_mlvt+2.7e-15*sf_flagrf_mlvt-2.7e-15*fs_flagrf_mlvt'
+PVTH0      = '1.7447113e-15+dpvthprf_mlvt+4.7e-22*ff_flagrf_mlvt+1.7e-22*sf_flagrf_mlvt-1.7e-22*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2prf_mlvt'   LK2        = '1.0154813e-010+dlk2prf_mlvt'
+WK2        = '-1.8062006e-008+dwk2prf_mlvt'
+PK2        = '1.0968375e-015+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitprf_mlvt'
+WCIT       = '9.334878e-11+dwcitprf_mlvt'
+PCIT       = '-2.6975657e-17+dpcitprf_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flagrf_mlvt-0.00601751*sf_flagrf_mlvt+0.00601751*fs_flagrf_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffprf_mlvt+7.40903e-10*ff_flagrf_mlvt+5.92723e-10*sf_flagrf_mlvt-5.92723e-10*fs_flagrf_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffprf_mlvt+7.67232e-09*ff_flagrf_mlvt+6.13786e-09*sf_flagrf_mlvt-6.13786e-09*fs_flagrf_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffprf_mlvt-7.55721e-16*ff_flagrf_mlvt-6.04577e-16*sf_flagrf_mlvt+6.04577e-16*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.36078*ff_flagrf_mlvt+0.288624*sf_flagrf_mlvt-0.288624*fs_flagrf_mlvt'
+ETA0       = '0.14001953+deta0prf_mlvt'
+LETA0      = '1.2840682e-09+dleta0prf_mlvt'
+WETA0      = '-3.0630437e-08+dweta0prf_mlvt'
+PETA0      = '2.5356774e-15+dpeta0prf_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0prf_mlvt-0.000346007*ss_flagrf_mlvt'
+LU0        = '4.0694732e-012+dlu0prf_mlvt+3.40816e-11*ss_flagrf_mlvt'
+WU0        = '-1.5318415e-010+dwu0prf_mlvt+3.52927e-10*ss_flagrf_mlvt'
+PU0        = '9.495809e-018+dpu0prf_mlvt-3.47632e-17*ss_flagrf_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatprf_mlvt'
+LVSAT      = '-0.0010658424+dlvsatprf_mlvt'
+WVSAT      = '-0.0081360267+dwvsatprf_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatprf_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flagrf_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmprf_mlvt+4.44542e-08*ss_flagrf_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flagrf_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmprf_mlvt-4.53433e-14*ss_flagrf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2prf_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datprf_mlvt'
+LAT        = '0.0065683527+dlatprf_mlvt'
+WAT        = '0.09819304+dwatprf_mlvt'
+PAT        = '-5.4885776e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_mlvt-3.55368e-08*ff_flagrf_mlvt-2.84294e-08*sf_flagrf_mlvt+2.84294e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-2.3017e-07*ff_flagrf_mlvt-1.84136e-07*sf_flagrf_mlvt+1.84136e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+2.26717e-14*ff_flagrf_mlvt+1.81374e-14*sf_flagrf_mlvt-1.81374e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthprf_mlvt+vthmisprf_mlvt)' LVTH0      = '1.8657789e-009+dlvthprf_mlvt'
+WVTH0      = '2.5644645e-010+dwvthprf_mlvt'
+PVTH0      = '4.9032594e-016+dpvthprf_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2prf_mlvt'  LK2        = '8.7204533e-010+dlk2prf_mlvt'
+WK2        = '-1.4195742e-009+dwk2prf_mlvt'
+PK2        = '-6.1726576e-018+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitprf_mlvt'
+WCIT       = '1.6122937e-009+dwcitprf_mlvt'
+PCIT       = '-1.9902291e-016+dpcitprf_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffprf_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffprf_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffprf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt'     ETA0       = '0.14756059+deta0prf_mlvt' LETA0      = '-1.9572049e-010+dleta0prf_mlvt'
+WETA0      = '7.102273e-010+dweta0prf_mlvt'
+PETA0      = '2.0036393e-016+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0prf_mlvt'  LU0        = '-1.2055811e-011+dlu0prf_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatprf_mlvt'  LVSAT      = '0.0033816548+dlvsatprf_mlvt'
+WVSAT      = '0.0091118432+dwvsatprf_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatprf_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmprf_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2prf_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datprf_mlvt'
+LAT        = '-0.010714171+dlatprf_mlvt'
+WAT        = '-0.11098338+dwatprf_mlvt'
+PAT        = '9.3122869e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt'
+PU0        = '0+dpu0prf_mlvt'           LNFACTOR   = '0+dlnfactorprf_mlvt'      WNFACTOR   = '0+dwnfactorprf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_mlvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_mlvt+dlmisprf_mlvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_mlvt+dwmisprf_mlvt)'       
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_mlvt+toxmisprf_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_mlvt+dlmisprf_mlvt)'        XW         = '2.0e-08+(dxwprf_mlvt+dwmisprf_mlvt)'      DLC        = '-6.55e-09+ddlcprf_mlvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+(dvthprf_mlvt+vthmisprf_mlvt)-0.0172283*ff_flagrf_mlvt-0.0137826*sf_flagrf_mlvt+0.0137826*fs_flagrf_mlvt'
+LVTH0      = '2.958878e-09+dlvthprf_mlvt+1.69698e-09*ff_flagrf_mlvt+1.35758e-09*sf_flagrf_mlvt-1.35758e-09*fs_flagrf_mlvt'
+WVTH0      = '4.664221e-08+dwvthprf_mlvt+1.06815e-08*ff_flagrf_mlvt+8.54522e-09*sf_flagrf_mlvt-8.54522e-09*fs_flagrf_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthprf_mlvt-1.05213e-15*ff_flagrf_mlvt-8.41702e-16*sf_flagrf_mlvt+8.41702e-16*fs_flagrf_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2prf_mlvt'  LK2        = '7.0199448e-010+dlk2prf_mlvt'
+WK2        = '-6.399827e-009+dwk2prf_mlvt'
+PK2        = '4.8438224e-016+dpk2prf_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitprf_mlvt'
+WCIT       = '9.515692e-10+dwcitprf_mlvt'
+PCIT       = '-1.3394136e-16+dpcitprf_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flagrf_mlvt-0.0117287*sf_flagrf_mlvt+0.0117287*fs_flagrf_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffprf_mlvt+1.4441e-09*ff_flagrf_mlvt+1.15528e-09*sf_flagrf_mlvt-1.15528e-09*fs_flagrf_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffprf_mlvt+1.49541e-08*ff_flagrf_mlvt+1.19633e-08*sf_flagrf_mlvt-1.19633e-08*fs_flagrf_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffprf_mlvt-1.47298e-15*ff_flagrf_mlvt-1.17838e-15*sf_flagrf_mlvt+1.17838e-15*fs_flagrf_mlvt'
+NFACTOR    = '0.7+dnfactorprf_mlvt+0.97289*ff_flagrf_mlvt+0.275652*sf_flagrf_mlvt-0.275652*fs_flagrf_mlvt'
+ETA0       = '0.07520113+deta0prf_mlvt'
+LETA0      = '6.9316746e-09+dleta0prf_mlvt'
+WETA0      = '3.5484332e-08+dweta0prf_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0prf_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0prf_mlvt+0.000837767*ff_flagrf_mlvt+0.000670213*sf_flagrf_mlvt-0.000670213*fs_flagrf_mlvt'
+LU0        = '1.337909e-011+dlu0prf_mlvt-8.25198e-11*ff_flagrf_mlvt-6.60158e-11*sf_flagrf_mlvt+6.60158e-11*fs_flagrf_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatprf_mlvt-4188.83*ff_flagrf_mlvt-3351.07*sf_flagrf_mlvt+3351.07*fs_flagrf_mlvt'
+LVSAT      = '-0.0022357018+dlvsatprf_mlvt+0.000412599*ff_flagrf_mlvt+0.000330079*sf_flagrf_mlvt-0.000330079*fs_flagrf_mlvt'
+WVSAT      = '-0.029812142+dwvsatprf_mlvt+0.00427261*ff_flagrf_mlvt+0.00341809*sf_flagrf_mlvt-0.00341809*fs_flagrf_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatprf_mlvt-4.20851e-10*ff_flagrf_mlvt-3.36681e-10*sf_flagrf_mlvt+3.36681e-10*fs_flagrf_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmprf_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmprf_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2prf_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswprf_mlvt'
+RDW        = '75+drdswprf_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxprf_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_mlvt'
+CGDO       = 'cgoprf_mlvt'              CGBO       = 0                   CGDL       = 'cglprf_mlvt'
+CGSL       = 'cglprf_mlvt'              CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datprf_mlvt'
+LAT        = '-0.0064077479+dlatprf_mlvt'
+WAT        = '-0.095092602+dwatprf_mlvt'
+PAT        = '7.7470449e-09+dpatprf_mlvt'
+NOIA       = 'noiaprf_mlvt'
+NOIB       = 'noibprf_mlvt'
+NOIC       = 'noicprf_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 0			CJD        = 0
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0prf_mlvt-8.54522e-10*ff_flagrf_mlvt-6.83618e-10*sf_flagrf_mlvt+6.83618e-10*fs_flagrf_mlvt'
+PU0        = '0+dpu0prf_mlvt+8.41702e-17*ff_flagrf_mlvt+6.73361e-17*sf_flagrf_mlvt-6.73361e-17*fs_flagrf_mlvt'
+LNFACTOR   = '0+dlnfactorprf_mlvt-9.58294e-08*ff_flagrf_mlvt-2.71517e-08*sf_flagrf_mlvt+2.71517e-08*fs_flagrf_mlvt'
+WNFACTOR   = '0+dwnfactorprf_mlvt-8.54523e-07*ff_flagrf_mlvt-1.70904e-07*sf_flagrf_mlvt+1.70904e-07*fs_flagrf_mlvt'
+PNFACTOR   = '0+dpnfactorprf_mlvt+8.41701e-14*ff_flagrf_mlvt+1.6834e-14*sf_flagrf_mlvt-1.6834e-14*fs_flagrf_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_mlvt_f D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.062                   TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.0002                  
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL pdio_rf_mlvt_g D (						   LEVEL  = 3
+IS     = 1.82e-07                IKR    = 1E10
+N      = 1                       BV     = 10                      IBV    = 0.03
+JSW    = 2.71e-13                CJ     = 'cjprf_mlvt'            PJ     = 7.2E-4
+MJ     = 0.4                     FC     = 0                       CJSW   = 'cjswgprf_mlvt'
+AREA   = 3.08E-8                 MJSW   = 0.95                    TLEVC  = 1
+CTA    = 0.00105                 CTP    = 0.00132                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.75                    PB     = 1
+IK     = 1E20                    TPB    = 0.003                   TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf_mlvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_mlvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_mlvt'
+ N      = '1.02*n_d_dnw_prf_mlvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_mlvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_mlvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_mlvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_mlvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_mlvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_mlvt'
+ N      = '1.02*n_d_prf_mlvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_mlvt)'  CJ     = '1.37E-04*cj_d_prf_mlvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_mlvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_mlvt_nw_5t


.ENDL RF_MOS_mlvt




**************************************************************************************************
*
* 1.2V CORE lvt MOS MODEL
*
*
*
*              .lib RF_MOS_lvt
*
*              Model name            nr               lr (um)           wr (um)
*                                low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_lvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_lvt        1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_lvt_nw     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              nmos_rf_lvt_6t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_lvt_5t     1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*              pmos_rf_lvt_nw_5t  1     32         0.06    0.24     0.6    6.0
*            -------------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************


***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+A1rf_lvt='par1*4.9161*3/2.1'
+A2rf_lvt='par2*4.0383*3/2.1'
+A3rf_lvt='par3*3.5526*3/2.1'
+A4rf_lvt='par4*2.0284*3/2.1'
+A5rf_lvt='par5*0.88801*3/2.1'
+toxnrf_lvt       ='2.6e-09+(6.8083e-012)*A1rf_lvt+(2.4563e-012)*A2rf_lvt+(-1.1379e-011)*A3rf_lvt+(-5.8103e-012)*A4rf_lvt+(1.0545e-012)*A5rf_lvt'
+dxlnrf_lvt       ='0+(4.7435e-010)*A1rf_lvt+(2.1417e-010)*A2rf_lvt+(-1.2376e-009)*A3rf_lvt+(-6.1477e-010)*A4rf_lvt+(1.1334e-010)*A5rf_lvt'
+dxwnrf_lvt       ='0+(-9.0939e-010)*A1rf_lvt+(7.7991e-010)*A2rf_lvt+(2.1156e-009)*A3rf_lvt+(1.0165e-009)*A4rf_lvt+(-1.6813e-010)*A5rf_lvt'
+dvthnrf_lvt      ='0+(0.0041068)*A1rf_lvt+(-0.0028236)*A2rf_lvt+(0.0014907)*A3rf_lvt+(0.00056075)*A4rf_lvt+(-0.00019114)*A5rf_lvt'
+dlvthnrf_lvt     ='0+(2.0652e-010)*A1rf_lvt+(-1.3342e-010)*A2rf_lvt+(6.7549e-011)*A3rf_lvt+(4.421e-011)*A4rf_lvt+(-1.4339e-011)*A5rf_lvt'
+dwvthnrf_lvt     ='0+(4.1068e-010)*A1rf_lvt+(-2.8236e-010)*A2rf_lvt+(1.4907e-010)*A3rf_lvt+(5.6075e-011)*A4rf_lvt+(-1.9114e-011)*A5rf_lvt'
+dpvthnrf_lvt     ='0+(3.2462e-017)*A1rf_lvt+(-2.7674e-017)*A2rf_lvt+(1.6414e-017)*A3rf_lvt+(-5.575e-018)*A4rf_lvt+(1.4437e-018)*A5rf_lvt'
+cjnrf_lvt        ='1.185e-03+(1.1361e-005)*A1rf_lvt+(-7.806e-006)*A2rf_lvt+(4.1202e-006)*A3rf_lvt+(1.5494e-006)*A4rf_lvt+(-5.2835e-007)*A5rf_lvt'
+cjswnrf_lvt      ='9.400e-11+(9.0193e-013)*A1rf_lvt+(-6.1904e-013)*A2rf_lvt+(3.2645e-013)*A3rf_lvt+(1.2515e-013)*A4rf_lvt+(-4.2569e-014)*A5rf_lvt'
+cjswgnrf_lvt     ='1.600e-10+(1.5332e-012)*A1rf_lvt+(-1.0541e-012)*A2rf_lvt+(5.5651e-013)*A3rf_lvt+(2.0935e-013)*A4rf_lvt+(-7.136e-014)*A5rf_lvt'
+cgonrf_lvt       ='8.918e-11+(-6.3461e-013)*A1rf_lvt+(-2.289e-013)*A2rf_lvt+(1.0601e-012)*A3rf_lvt+(5.4255e-013)*A4rf_lvt+(-9.8583e-014)*A5rf_lvt'
+cglnrf_lvt       ='2.295e-11+(-1.6308e-013)*A1rf_lvt+(-5.8869e-014)*A2rf_lvt+(2.73e-013)*A3rf_lvt+(1.3814e-013)*A4rf_lvt+(-2.4948e-014)*A5rf_lvt'
+cfnrf_lvt        ='1.200000e-010+(-8.5357e-013)*A1rf_lvt+(-3.0795e-013)*A2rf_lvt+(1.4266e-012)*A3rf_lvt+(7.2845e-013)*A4rf_lvt+(-1.322e-013)*A5rf_lvt+5.4e-11'
+dlvoffnrf_lvt    ='0+(3.1284e-011)*A1rf_lvt+(-4.2931e-011)*A2rf_lvt+(2.9881e-011)*A3rf_lvt+(-3.5758e-011)*A4rf_lvt+(1.0362e-011)*A5rf_lvt'
+dpvoffnrf_lvt    ='0+(-3.1284e-018)*A1rf_lvt+(4.2931e-018)*A2rf_lvt+(-2.9881e-018)*A3rf_lvt+(3.5758e-018)*A4rf_lvt+(-1.0362e-018)*A5rf_lvt'
+ntoxnrf_lvt      ='1+(-0.05686)*A1rf_lvt+(-0.019224)*A2rf_lvt+(0.083196)*A3rf_lvt+(0.022902)*A4rf_lvt+(-0.0021051)*A5rf_lvt'
+du0nrf_lvt       ='0+(3.0085e-006)*A1rf_lvt+(-2.2452e-005)*A2rf_lvt+(-2.7072e-006)*A3rf_lvt+(-6.5707e-007)*A4rf_lvt+(-2.6423e-007)*A5rf_lvt'
+dlu0nrf_lvt      ='0+(-1.2034e-012)*A1rf_lvt+(8.9807e-012)*A2rf_lvt+(1.0829e-012)*A3rf_lvt+(2.6283e-013)*A4rf_lvt+(1.0569e-013)*A5rf_lvt'
+dpu0nrf_lvt      ='0+(7.4285e-020)*A1rf_lvt+(-5.6172e-019)*A2rf_lvt+(-5.519e-020)*A3rf_lvt+(-1.1173e-019)*A4rf_lvt+(-3.8519e-019)*A5rf_lvt'
+deta0nrf_lvt     ='0+(0.0023463)*A1rf_lvt+(-0.0032198)*A2rf_lvt+(0.002241)*A3rf_lvt+(-0.0026818)*A4rf_lvt+(0.00077716)*A5rf_lvt'
+dleta0nrf_lvt    ='0+(-3.7557e-010)*A1rf_lvt+(2.5665e-010)*A2rf_lvt+(-1.0521e-010)*A3rf_lvt+(-1.2378e-010)*A4rf_lvt+(-6.2248e-011)*A5rf_lvt'
+dpeta0nrf_lvt    ='0+(-1.1737e-017)*A1rf_lvt+(-2.6417e-018)*A2rf_lvt+(5.0026e-018)*A3rf_lvt+(-2.1617e-017)*A4rf_lvt+(6.4553e-018)*A5rf_lvt'
+dweta0nrf_lvt    ='0+(-4.6926e-010)*A1rf_lvt+(6.4397e-010)*A2rf_lvt+(-4.4821e-010)*A3rf_lvt+(5.3637e-010)*A4rf_lvt+(-1.5543e-010)*A5rf_lvt'
+dlvsatnrf_lvt    ='0+(3.0313e-005)*A1rf_lvt+(-1.8164e-005)*A2rf_lvt+(8.6871e-006)*A3rf_lvt+(9.1426e-006)*A4rf_lvt+(-2.8881e-006)*A5rf_lvt'
+dpvsatnrf_lvt    ='0+(-1.9558e-012)*A1rf_lvt+(8.0911e-013)*A2rf_lvt+(-2.4676e-013)*A3rf_lvt+(-1.2678e-012)*A4rf_lvt+(3.8648e-013)*A5rf_lvt'
+dlk2nrf_lvt      ='0+(4.1068e-011)*A1rf_lvt+(-2.8236e-011)*A2rf_lvt+(1.4907e-011)*A3rf_lvt+(5.6075e-012)*A4rf_lvt+(-1.9114e-012)*A5rf_lvt'
+dwk2nrf_lvt      ='0+(6.8447e-011)*A1rf_lvt+(-4.706e-011)*A2rf_lvt+(2.4844e-011)*A3rf_lvt+(9.3458e-012)*A4rf_lvt+(-3.1857e-012)*A5rf_lvt'
+ss_flagrf_lvt    ='0+(0.058683)*A1rf_lvt+(0.013208)*A2rf_lvt+(-0.025013)*A3rf_lvt+(0.10809)*A4rf_lvt+(-0.032277)*A5rf_lvt'
+ff_flagrf_lvt    ='max(-0.5,0+(-0.056423)*A1rf_lvt+(-0.011104)*A2rf_lvt+(-0.01055)*A3rf_lvt+(0.12234)*A4rf_lvt+(-0.034156)*A5rf_lvt)'
+sf_flagrf_lvt    ='max(-0.3,0+(0.0088222)*A1rf_lvt+(-0.07043)*A2rf_lvt+(-0.00065409)*A3rf_lvt+(-0.061618)*A4rf_lvt+(-0.23744)*A5rf_lvt)'
+fs_flagrf_lvt    ='0+(-0.0099807)*A1rf_lvt+(0.069892)*A2rf_lvt+(0.016266)*A3rf_lvt+(-0.057511)*A4rf_lvt+(-0.23579)*A5rf_lvt'
+toxprf_lvt       ='2.8e-09+(6.8083e-012)*A1rf_lvt+(2.4563e-012)*A2rf_lvt+(-1.1379e-011)*A3rf_lvt+(-5.8103e-012)*A4rf_lvt+(1.0545e-012)*A5rf_lvt'
+dxlprf_lvt       ='0+(4.7435e-010)*A1rf_lvt+(2.1417e-010)*A2rf_lvt+(-1.2376e-009)*A3rf_lvt+(-6.1477e-010)*A4rf_lvt+(1.1334e-010)*A5rf_lvt'
+dxwprf_lvt       ='0+(-6.0854e-010)*A1rf_lvt+(-1.4653e-009)*A2rf_lvt+(1.8448e-009)*A3rf_lvt+(9.5077e-010)*A4rf_lvt+(-1.9455e-010)*A5rf_lvt'
+dvthprf_lvt      ='0+(-0.0028838)*A1rf_lvt+(-0.0035207)*A2rf_lvt+(-0.0020725)*A3rf_lvt+(-0.00068208)*A4rf_lvt+(0.00010069)*A5rf_lvt'
+dlvthprf_lvt     ='0+(-1.9226e-010)*A1rf_lvt+(-1.9828e-010)*A2rf_lvt+(-1.5301e-010)*A3rf_lvt+(-4.249e-011)*A4rf_lvt+(-1.9731e-010)*A5rf_lvt'
+dwvthprf_lvt     ='0+(-3.7383e-010)*A1rf_lvt+(-4.5639e-010)*A2rf_lvt+(-2.6866e-010)*A3rf_lvt+(-8.8418e-011)*A4rf_lvt+(1.3052e-011)*A5rf_lvt'
+dpvthprf_lvt     ='0+(-1.5493e-017)*A1rf_lvt+(-2.4759e-017)*A2rf_lvt+(-1.7853e-017)*A3rf_lvt+(5.7562e-018)*A4rf_lvt+(-2.4818e-018)*A5rf_lvt'
+cjprf_lvt        ='1.068e-03+(7.9957e-006)*A1rf_lvt+(9.7512e-006)*A2rf_lvt+(5.732e-006)*A3rf_lvt+(1.9219e-006)*A4rf_lvt+(-2.8858e-007)*A5rf_lvt'
+cjswprf_lvt      ='7.600e-11+(5.6822e-013)*A1rf_lvt+(6.9371e-013)*A2rf_lvt+(4.0837e-013)*A3rf_lvt+(1.344e-013)*A4rf_lvt+(-1.9839e-014)*A5rf_lvt'
+cjswgprf_lvt     ='1.500e-10+(1.1215e-012)*A1rf_lvt+(1.3692e-012)*A2rf_lvt+(8.0598e-013)*A3rf_lvt+(2.6525e-013)*A4rf_lvt+(-3.9155e-014)*A5rf_lvt'
+cgoprf_lvt       ='7.490e-11+(-5.3243e-013)*A1rf_lvt+(-1.9214e-013)*A2rf_lvt+(8.9041e-013)*A3rf_lvt+(4.5463e-013)*A4rf_lvt+(-8.2509e-014)*A5rf_lvt'
+cglprf_lvt       ='6.169e-11+(-4.3844e-013)*A1rf_lvt+(-1.5824e-013)*A2rf_lvt+(7.3354e-013)*A3rf_lvt+(3.7329e-013)*A4rf_lvt+(-6.7623e-014)*A5rf_lvt'
+du0prf_lvt       ='0+(-6.3168e-006)*A1rf_lvt+(-4.9302e-007)*A2rf_lvt+(-8.8237e-006)*A3rf_lvt+(8.6109e-006)*A4rf_lvt+(-2.7226e-006)*A5rf_lvt'
+dlu0prf_lvt      ='0+(1.7957e-012)*A1rf_lvt+(1.8416e-012)*A2rf_lvt+(3.0266e-012)*A3rf_lvt+(-2.7062e-012)*A4rf_lvt+(8.9106e-013)*A5rf_lvt'
+dpu0prf_lvt      ='0+(1.6078e-020)*A1rf_lvt+(1.1451e-019)*A2rf_lvt+(6.3899e-020)*A3rf_lvt+(-8.7421e-020)*A4rf_lvt+(-1.7436e-019)*A5rf_lvt'
+deta0prf_lvt     ='0+(0.00094014)*A1rf_lvt+(-0.0070161)*A2rf_lvt+(-0.00084599)*A3rf_lvt+(-0.00020534)*A4rf_lvt+(-8.2573e-005)*A5rf_lvt'
+dweta0prf_lvt    ='0+(-5.8683e-010)*A1rf_lvt+(-1.3208e-010)*A2rf_lvt+(2.5013e-010)*A3rf_lvt+(-1.0809e-009)*A4rf_lvt+(3.2277e-010)*A5rf_lvt'
+ntoxprf_lvt      ='1+(-0.084214)*A1rf_lvt+(-0.026401)*A2rf_lvt+(0.10422)*A3rf_lvt+(-0.007214)*A4rf_lvt+(0.0076397)*A5rf_lvt'
+dlk2prf_lvt      ='0+(5.0703e-011)*A1rf_lvt+(3.2683e-011)*A2rf_lvt+(2.8457e-012)*A3rf_lvt+(5.9096e-011)*A4rf_lvt+(-1.6884e-011)*A5rf_lvt'
+dwk2prf_lvt      ='0+(4.2723e-011)*A1rf_lvt+(5.2159e-011)*A2rf_lvt+(3.0704e-011)*A3rf_lvt+(1.0105e-011)*A4rf_lvt+(-1.4916e-012)*A5rf_lvt'
+dlcitprf_lvt     ='0+(-2.9342e-012)*A1rf_lvt+(-6.6041e-013)*A2rf_lvt+(1.2506e-012)*A3rf_lvt+(-5.4043e-012)*A4rf_lvt+(1.6138e-012)*A5rf_lvt'
+cfprf_lvt        ='1.200000e-010+(-8.5357e-013)*A1rf_lvt+(-3.0795e-013)*A2rf_lvt+(1.4266e-012)*A3rf_lvt+(7.2845e-013)*A4rf_lvt+(-1.322e-013)*A5rf_lvt+5.6e-11'
+dlvoffprf_lvt    ='0+(3.3688e-011)*A1rf_lvt+(8.2032e-011)*A2rf_lvt+(7.1241e-011)*A3rf_lvt+(-5.7977e-011)*A4rf_lvt+(1.9983e-011)*A5rf_lvt'
+dpvoffprf_lvt    ='0+(-5.8683e-019)*A1rf_lvt+(-1.3208e-019)*A2rf_lvt+(2.5013e-019)*A3rf_lvt+(-1.0809e-018)*A4rf_lvt+(3.2277e-019)*A5rf_lvt'
+dnfactorprf_lvt  ='max(0,0+(-0.025267)*A1rf_lvt+(-0.0019721)*A2rf_lvt+(-0.035295)*A3rf_lvt+(0.034444)*A4rf_lvt+(-0.010891)*A5rf_lvt)'
+dagsprf_lvt      ='0+(0.0024063)*A1rf_lvt+(0.0058594)*A2rf_lvt+(0.0050887)*A3rf_lvt+(-0.0041412)*A4rf_lvt+(0.0014274)*A5rf_lvt'
+dvsatprf_lvt     ='max(-10000,0+(630.29)*A1rf_lvt+(886.36)*A2rf_lvt+(587.35)*A3rf_lvt+(-39.337)*A4rf_lvt+(38.45)*A5rf_lvt)'
+ddlcnrf_lvt      =8.441e-09
+drdswnrf_lvt     =0
+dcitnrf_lvt      =0
+dlcitnrf_lvt     =0
+dwcitnrf_lvt     =0
+dpcitnrf_lvt     =0
+dvoffnrf_lvt     =0
+dwvoffnrf_lvt    =0
+dnfactornrf_lvt  =0
+dwnfactornrf_lvt =0
+dlnfactornrf_lvt =0
+dpnfactornrf_lvt =0
+dwu0nrf_lvt      =0
+duanrf_lvt       =0
+dluanrf_lvt      =0
+dwuanrf_lvt      =0
+dpuanrf_lvt      =0
+dubnrf_lvt       =0
+dlubnrf_lvt      =0
+dwubnrf_lvt      =0
+dpubnrf_lvt      =0
+dua1nrf_lvt      =0
+dlua1nrf_lvt     =0
+dwua1nrf_lvt     =0
+dpua1nrf_lvt     =0
+dub1nrf_lvt      =0
+dlub1nrf_lvt     =0
+dwub1nrf_lvt     =0
+dpub1nrf_lvt     =0
+dkt1nrf_lvt      =0
+dlkt1nrf_lvt     =0
+dwkt1nrf_lvt     =0
+dpkt1nrf_lvt     =0
+dcdscdnrf_lvt    =0
+dk2nrf_lvt       =0
+dvsatnrf_lvt     =0
+dwvsatnrf_lvt    =0
+dpk2nrf_lvt      =0
+tt_flagrf_lvt    =0
+ddlcprf_lvt      =1.054e-08
+dwu0prf_lvt      =0
+duaprf_lvt       =0
+dluaprf_lvt      =0
+dwuaprf_lvt      =0
+dpuaprf_lvt      =0
+dubprf_lvt       =0
+dlubprf_lvt      =0
+dwubprf_lvt      =0
+dpubprf_lvt      =0
+dub1prf_lvt      =0
+dlub1prf_lvt     =0
+dwub1prf_lvt     =0
+dpub1prf_lvt     =0
+dua1prf_lvt      =0
+dlua1prf_lvt     =0
+dwua1prf_lvt     =0
+dpua1prf_lvt     =0
+datprf_lvt       =0
+dlatprf_lvt      =0
+dwatprf_lvt      =0
+dpatprf_lvt      =0
+duteprf_lvt      =0
+dluteprf_lvt     =0
+dwuteprf_lvt     =0
+dputeprf_lvt     =0
+dpclmprf_lvt     =0
+dlpclmprf_lvt    =0
+dwpclmprf_lvt    =0
+dppclmprf_lvt    =0
+dleta0prf_lvt    =0
+dpeta0prf_lvt    =0
+dk2prf_lvt       =0
+dpk2prf_lvt      =0
+dcitprf_lvt      =0
+dwcitprf_lvt     =0
+dpcitprf_lvt     =0
+dvoffprf_lvt     =0
+dwvoffprf_lvt    =0
+dlnfactorprf_lvt =0
+dwnfactorprf_lvt =0
+dpnfactorprf_lvt =0
+da0prf_lvt       =0
+dla0prf_lvt      =0
+dwa0prf_lvt      =0
+dpa0prf_lvt      =0
+dlagsprf_lvt     =0
+dwagsprf_lvt     =0
+dpagsprf_lvt     =0
+dlvsatprf_lvt    =0
+dwvsatprf_lvt    =0
+dpvsatprf_lvt    =0
+dpdiblc2prf_lvt  =0
+dlpdiblc2prf_lvt =0
+dwpdiblc2prf_lvt =0
+dppdiblc2prf_lvt =0
+is_d_dnw_nrf_lvt= 1         x_jsw_d_dnw_nrf_lvt= 0         n_d_dnw_nrf_lvt= 1         rs_d_dnw_nrf_lvt= 1
+cj_d_dnw_nrf_lvt= 1          cjsw_d_dnw_nrf_lvt= 1
+is_d_dnw_prf_lvt= 1         x_jsw_d_dnw_prf_lvt= 0         n_d_dnw_prf_lvt= 1         rs_d_dnw_prf_lvt= 1
+cj_d_dnw_prf_lvt= 1          cjsw_d_dnw_prf_lvt= 1
+is_d_prf_lvt= 1                 x_jsw_d_prf_lvt= 0             n_d_prf_lvt= 1             rs_d_prf_lvt= 1
+cj_d_prf_lvt= 1                  cjsw_d_prf_lvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL mc_RFMOS_lvt







***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+toxnrf_lvt       = 2.6e-09       dxlnrf_lvt       = 0             dxwnrf_lvt       = 0
+dvthnrf_lvt      = 0             dlvthnrf_lvt     = 0             dwvthnrf_lvt     = 0
+dpvthnrf_lvt     = 0             cjnrf_lvt        = 1.185E-03     cjswnrf_lvt      = 9.400E-11
+cjswgnrf_lvt     = 1.600E-10
+cgonrf_lvt       = 8.918E-11
+cglnrf_lvt       = 2.295E-11
+ddlcnrf_lvt      = 8.441E-09
+cfnrf_lvt        = '1.20e-10 + 5.4e-11' drdswnrf_lvt     = 0
+dcitnrf_lvt      = 0             dlcitnrf_lvt     = 0             dwcitnrf_lvt     = 0
+dpcitnrf_lvt     = 0             dvoffnrf_lvt     = 0             dlvoffnrf_lvt    = 0
+dwvoffnrf_lvt    = 0             dpvoffnrf_lvt    = 0             ntoxnrf_lvt      = 1
+dnfactornrf_lvt  = 0             dwnfactornrf_lvt = 0             dlnfactornrf_lvt = 0
+dpnfactornrf_lvt = 0             du0nrf_lvt       = 0             dlu0nrf_lvt      = 0
+dwu0nrf_lvt      = 0             dpu0nrf_lvt      = 0             duanrf_lvt       = 0
+dluanrf_lvt      = 0             dwuanrf_lvt      = 0             dpuanrf_lvt      = 0
+dubnrf_lvt       = 0             dlubnrf_lvt      = 0             dwubnrf_lvt      = 0
+dpubnrf_lvt      = 0             dua1nrf_lvt      = 0             dlua1nrf_lvt     = 0
+dwua1nrf_lvt     = 0             dpua1nrf_lvt     = 0             dub1nrf_lvt      = 0
+dlub1nrf_lvt     = 0             dwub1nrf_lvt     = 0             dpub1nrf_lvt     = 0
+dkt1nrf_lvt      = 0             dlkt1nrf_lvt     = 0             dwkt1nrf_lvt     = 0
+dpkt1nrf_lvt     = 0             deta0nrf_lvt     = 0             dleta0nrf_lvt    = 0
+dpeta0nrf_lvt    = 0             dweta0nrf_lvt    = 0             dcdscdnrf_lvt    = 0
+dk2nrf_lvt       = 0             dvsatnrf_lvt     = 0             dlvsatnrf_lvt    = 0
+dwvsatnrf_lvt    = 0             dpvsatnrf_lvt    = 0             dlk2nrf_lvt      = 0
+dwk2nrf_lvt      = 0             dpk2nrf_lvt      = 0
+tt_flagrf_lvt    = 0             ss_flagrf_lvt    = 0             ff_flagrf_lvt    = 0
+sf_flagrf_lvt    = 0             fs_flagrf_lvt    = 0
+toxprf_lvt       = 2.8e-09       dxlprf_lvt       = 0             dxwprf_lvt       = 0
+dvthprf_lvt      = 0             dlvthprf_lvt     = 0             dwvthprf_lvt     = 0
+dpvthprf_lvt     = 0             cjprf_lvt        = 1.068E-03     cjswprf_lvt      = 7.600E-11
+cjswgprf_lvt     = 1.500E-10
+cgoprf_lvt       = 7.490E-11
+cglprf_lvt       = 6.169E-11
+ddlcprf_lvt      = 1.054E-08
+du0prf_lvt       = 0             dlu0prf_lvt      = 0
+dwu0prf_lvt      = 0             dpu0prf_lvt      = 0             duaprf_lvt       = 0
+dluaprf_lvt      = 0             dwuaprf_lvt      = 0             dpuaprf_lvt      = 0
+dubprf_lvt       = 0             dlubprf_lvt      = 0             dwubprf_lvt      = 0
+dpubprf_lvt      = 0             dub1prf_lvt      = 0             dlub1prf_lvt     = 0
+dwub1prf_lvt     = 0             dpub1prf_lvt     = 0             dua1prf_lvt      = 0
+dlua1prf_lvt     = 0             dwua1prf_lvt     = 0             dpua1prf_lvt     = 0
+datprf_lvt       = 0             dlatprf_lvt      = 0             dwatprf_lvt      = 0
+dpatprf_lvt      = 0             duteprf_lvt      = 0             dluteprf_lvt     = 0
+dwuteprf_lvt     = 0             dputeprf_lvt     = 0             dpclmprf_lvt     = 0
+dlpclmprf_lvt    = 0             dwpclmprf_lvt    = 0             dppclmprf_lvt    = 0
+deta0prf_lvt     = 0             dleta0prf_lvt    = 0             dweta0prf_lvt    = 0
+dpeta0prf_lvt    = 0             ntoxprf_lvt      = 1             dk2prf_lvt       = 0
+dlk2prf_lvt      = 0             dwk2prf_lvt      = 0             dpk2prf_lvt      = 0
+dcitprf_lvt      = 0             dlcitprf_lvt     = 0             dwcitprf_lvt     = 0
+dpcitprf_lvt     = 0             cfprf_lvt        = '1.200E-10 + 5.6e-11' dvoffprf_lvt     = 0
+dlvoffprf_lvt    = 0             dwvoffprf_lvt    = 0             dpvoffprf_lvt    = 0
+dnfactorprf_lvt  = 0             dlnfactorprf_lvt = 0             dwnfactorprf_lvt = 0
+dpnfactorprf_lvt = 0             da0prf_lvt       = 0             dla0prf_lvt      = 0
+dwa0prf_lvt      = 0             dpa0prf_lvt      = 0             dagsprf_lvt      = 0
+dlagsprf_lvt     = 0             dwagsprf_lvt     = 0             dpagsprf_lvt     = 0
+dvsatprf_lvt     = 0             dlvsatprf_lvt    = 0             dwvsatprf_lvt    = 0
+dpvsatprf_lvt    = 0             dpdiblc2prf_lvt  = 0             dlpdiblc2prf_lvt = 0
+dwpdiblc2prf_lvt = 0             dppdiblc2prf_lvt = 0
+is_d_dnw_nrf_lvt= 1         x_jsw_d_dnw_nrf_lvt= 0         n_d_dnw_nrf_lvt= 1         rs_d_dnw_nrf_lvt= 1
+cj_d_dnw_nrf_lvt= 1          cjsw_d_dnw_nrf_lvt= 1
+is_d_dnw_prf_lvt= 1         x_jsw_d_dnw_prf_lvt= 0         n_d_dnw_prf_lvt= 1         rs_d_dnw_prf_lvt= 1
+cj_d_dnw_prf_lvt= 1          cjsw_d_dnw_prf_lvt= 1
+is_d_prf_lvt= 1                 x_jsw_d_prf_lvt= 0             n_d_prf_lvt= 1             rs_d_prf_lvt= 1
+cj_d_prf_lvt= 1                  cjsw_d_prf_lvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL TT_RFMOS_lvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+toxnrf_lvt       = 2.667e-09     dxlnrf_lvt       = 5e-09         dxwnrf_lvt       = -8e-09
+dvthnrf_lvt      = 0.03          dlvthnrf_lvt     = 1.6e-09      dwvthnrf_lvt     = 3e-09
+dpvthnrf_lvt     = 1.8e-16       cjnrf_lvt        = 1.268E-03     cjswnrf_lvt      = 1.006E-10
+cjswgnrf_lvt     = 1.712E-10     cgonrf_lvt       = 8.294E-11     cglnrf_lvt       = 2.134E-11
+ddlcnrf_lvt      = 8.441E-09     cfnrf_lvt        = '1.116e-10 + 5.4e-11' drdswnrf_lvt     = 0
+dcitnrf_lvt      = 0             dlcitnrf_lvt     = 0             dwcitnrf_lvt     = 0
+dpcitnrf_lvt     = 0             dvoffnrf_lvt     = 0             dlvoffnrf_lvt    = 0e-11
+dwvoffnrf_lvt    = 0             dpvoffnrf_lvt    = -0e-17        ntoxnrf_lvt      = 0.372
+dnfactornrf_lvt  = 0             dwnfactornrf_lvt = 0             dlnfactornrf_lvt = 0
+dpnfactornrf_lvt = 0             du0nrf_lvt       = 0             dlu0nrf_lvt      = 0
+dwu0nrf_lvt      = 0             dpu0nrf_lvt      = 0             duanrf_lvt       = 0
+dluanrf_lvt      = 0             dwuanrf_lvt      = 0             dpuanrf_lvt      = 0
+dubnrf_lvt       = 0             dlubnrf_lvt      = 0             dwubnrf_lvt      = 0
+dpubnrf_lvt      = 0             dua1nrf_lvt      = 0             dlua1nrf_lvt     = 0
+dwua1nrf_lvt     = 0             dpua1nrf_lvt     = 0             dub1nrf_lvt      = 0
+dlub1nrf_lvt     = 0             dwub1nrf_lvt     = 0             dpub1nrf_lvt     = 0
+dkt1nrf_lvt      = 0             dlkt1nrf_lvt     = 0             dwkt1nrf_lvt     = 0
+dpkt1nrf_lvt     = 0             deta0nrf_lvt     = 0             dleta0nrf_lvt    = -3.0e-09
+dpeta0nrf_lvt    = -0.2e-15       dweta0nrf_lvt    = 0             dcdscdnrf_lvt    = 0
+dk2nrf_lvt       = 0             dvsatnrf_lvt     = 0             dlvsatnrf_lvt    = 2.5e-04
+dwvsatnrf_lvt    = 0             dpvsatnrf_lvt    = -2.0e-11      dlk2nrf_lvt      = 3e-10
+dwk2nrf_lvt      = 5e-10         dpk2nrf_lvt      = 0
+tt_flagrf_lvt    = 0             ss_flagrf_lvt    = 1             ff_flagrf_lvt    = 0
+sf_flagrf_lvt    = 0             fs_flagrf_lvt    = 0
+toxprf_lvt       = 2.867e-09     dxlprf_lvt       = 5e-09         dxwprf_lvt       = -8e-09
+dvthprf_lvt      = -0.027         dlvthprf_lvt     = -1.5e-09      dwvthprf_lvt     = -3.5e-09
+dpvthprf_lvt     = -1e-16        cjprf_lvt        = 1.143E-03     cjswprf_lvt      = 8.132E-11
+cjswgprf_lvt     = 1.605E-10     cgoprf_lvt       = 6.966E-11     cglprf_lvt       = 5.737E-11
+ddlcprf_lvt      = 1.054E-08     du0prf_lvt       = -0.0000       dlu0prf_lvt      = 0e-11
+dwu0prf_lvt      = 0e-10         dpu0prf_lvt      = 0e-19         duaprf_lvt       = 0
+dluaprf_lvt      = 0             dwuaprf_lvt      = 0             dpuaprf_lvt      = 0
+dubprf_lvt       = 0             dlubprf_lvt      = 0e-27             dwubprf_lvt      = 0e-27
+dpubprf_lvt      = 0             dub1prf_lvt      = 0             dlub1prf_lvt     = 0
+dwub1prf_lvt     = 0             dpub1prf_lvt     = 0             dua1prf_lvt      = 0
+dlua1prf_lvt     = 0             dwua1prf_lvt     = 0             dpua1prf_lvt     = 0
+datprf_lvt       = 0             dlatprf_lvt      = 0             dwatprf_lvt      = 0
+dpatprf_lvt      = 0             duteprf_lvt      = 0             dluteprf_lvt     = 0
+dwuteprf_lvt     = 0             dputeprf_lvt     = 0             dpclmprf_lvt     = 0
+dlpclmprf_lvt    = 0             dwpclmprf_lvt    = 0             dppclmprf_lvt    = 0
+deta0prf_lvt     = 0             dleta0prf_lvt    = 0e-9             dweta0prf_lvt    = -1e-08
+dpeta0prf_lvt    = 0             ntoxprf_lvt      = -0.04         dk2prf_lvt       = 0
+dlk2prf_lvt      = 0.7e-9         dwk2prf_lvt      = 4e-10         dpk2prf_lvt      = 0
+dcitprf_lvt      = 0             dlcitprf_lvt     = -5e-11             dwcitprf_lvt     = 0
+dpcitprf_lvt     = 0             cfprf_lvt        = '1.116E-10 + 5.6e-11' dvoffprf_lvt     = 0
+dlvoffprf_lvt    = -0e-10      dwvoffprf_lvt    = 0             dpvoffprf_lvt    = -1e-17
+dnfactorprf_lvt  = 0             dlnfactorprf_lvt = -0e-8             dwnfactorprf_lvt = 0
+dpnfactorprf_lvt = 0             da0prf_lvt       = 0             dla0prf_lvt      = 0
+dwa0prf_lvt      = 0             dpa0prf_lvt      = 0             dagsprf_lvt      = 0
+dlagsprf_lvt     = 0             dwagsprf_lvt     = 0             dpagsprf_lvt     = 0e20
+dvsatprf_lvt     = 5000             dlvsatprf_lvt    = 0             dwvsatprf_lvt    = 0
+dpvsatprf_lvt    = 0             dpdiblc2prf_lvt  = 0             dlpdiblc2prf_lvt = 0
+dwpdiblc2prf_lvt = 0             dppdiblc2prf_lvt = 0
+is_d_dnw_nrf_lvt= 0.7         x_jsw_d_dnw_nrf_lvt= -1         n_d_dnw_nrf_lvt= 0.9975         rs_d_dnw_nrf_lvt= 1.2
+cj_d_dnw_nrf_lvt= 1.07          cjsw_d_dnw_nrf_lvt= 1.07
+is_d_dnw_prf_lvt= 0.7         x_jsw_d_dnw_prf_lvt= -1         n_d_dnw_prf_lvt= 0.9975         rs_d_dnw_prf_lvt= 1.2
+cj_d_dnw_prf_lvt= 1.07          cjsw_d_dnw_prf_lvt=  1.07
+is_d_prf_lvt= 0.7                 x_jsw_d_prf_lvt= -1             n_d_prf_lvt= 0.9975             rs_d_prf_lvt= 1.2
+cj_d_prf_lvt= 1.07                  cjsw_d_prf_lvt=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL SS_RFMOS_lvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+toxnrf_lvt       = 2.533e-09     dxlnrf_lvt       = -5e-09        dxwnrf_lvt       = 8e-09
+dvthnrf_lvt      = -0.03         dlvthnrf_lvt     = -14.4e-10      dwvthnrf_lvt     = -3e-09
+dpvthnrf_lvt     = -2.8e-16      cjnrf_lvt        = 1.102E-03     cjswnrf_lvt      = 8.742E-11
+cjswgnrf_lvt     = 1.488E-10     cgonrf_lvt       = 9.543E-11     cglnrf_lvt       = 2.455E-11
+ddlcnrf_lvt      = 8.441E-09     cfnrf_lvt        = '1.284e-10 + 5.4e-11' drdswnrf_lvt     = 0
+dcitnrf_lvt      = 0             dlcitnrf_lvt     = 0             dwcitnrf_lvt     = 0
+dpcitnrf_lvt     = 0             dvoffnrf_lvt     = 0             dlvoffnrf_lvt    = -0.4e-09
+dwvoffnrf_lvt    = 0             dpvoffnrf_lvt    = 0.4e-16       ntoxnrf_lvt      = 1.466
+dnfactornrf_lvt  = 0             dwnfactornrf_lvt = 0             dlnfactornrf_lvt = 0
+dpnfactornrf_lvt = 0             du0nrf_lvt       = 0             dlu0nrf_lvt      = 0
+dwu0nrf_lvt      = 0             dpu0nrf_lvt      = 0             duanrf_lvt       = 0
+dluanrf_lvt      = 0             dwuanrf_lvt      = 0             dpuanrf_lvt      = 0
+dubnrf_lvt       = 0             dlubnrf_lvt      = 0             dwubnrf_lvt      = 0
+dpubnrf_lvt      = 0             dua1nrf_lvt      = 0             dlua1nrf_lvt     = 0
+dwua1nrf_lvt     = 0             dpua1nrf_lvt     = 0             dub1nrf_lvt      = 0
+dlub1nrf_lvt     = 0             dwub1nrf_lvt     = 0             dpub1nrf_lvt     = 0
+dkt1nrf_lvt      = 0             dlkt1nrf_lvt     = 0             dwkt1nrf_lvt     = 0
+dpkt1nrf_lvt     = 0             deta0nrf_lvt     = -0.03         dleta0nrf_lvt    = 2.5e-09
+dpeta0nrf_lvt    = -0.0e-15      dweta0nrf_lvt    = 0.6e-08       dcdscdnrf_lvt    = 0
+dk2nrf_lvt       = 0             dvsatnrf_lvt     = 0             dlvsatnrf_lvt    = -2.0e-04
+dwvsatnrf_lvt    = 0             dpvsatnrf_lvt    = 1.0e-11       dlk2nrf_lvt      = -3e-10
+dwk2nrf_lvt      = -5e-10        dpk2nrf_lvt      = 0
+tt_flagrf_lvt    = 0             ss_flagrf_lvt    = 0             ff_flagrf_lvt    = 1
+sf_flagrf_lvt    = 0             fs_flagrf_lvt    = 0
+toxprf_lvt       = 2.733e-09     dxlprf_lvt       = -5e-09        dxwprf_lvt       = 8e-09
+dvthprf_lvt      = 0.027          dlvthprf_lvt     = 2e-09         dwvthprf_lvt     = 3.5e-09
+dpvthprf_lvt     = 2e-16         cjprf_lvt        = 9.933E-04     cjswprf_lvt      = 7.068E-11
+cjswgprf_lvt     = 1.395E-10     cgoprf_lvt       = 8.014E-11     cglprf_lvt       = 6.600E-11
+ddlcprf_lvt      = 1.054E-08     du0prf_lvt       = 0.0001        dlu0prf_lvt      = -3.2e-11
+dwu0prf_lvt      = -0e-10        dpu0prf_lvt      = -0.5e-18        duaprf_lvt       = 0
+dluaprf_lvt      = 0e-18             dwuaprf_lvt      = 0             dpuaprf_lvt      = 0
+dubprf_lvt       = 0             dlubprf_lvt      = -0e-27             dwubprf_lvt      = 0
+dpubprf_lvt      = 0             dub1prf_lvt      = 0             dlub1prf_lvt     = 0
+dwub1prf_lvt     = 0             dpub1prf_lvt     = 0             dua1prf_lvt      = 0
+dlua1prf_lvt     = 0             dwua1prf_lvt     = 0             dpua1prf_lvt     = 0
+datprf_lvt       = 0             dlatprf_lvt      = 0             dwatprf_lvt      = 0
+dpatprf_lvt      = 0             duteprf_lvt      = 0             dluteprf_lvt     = 0
+dwuteprf_lvt     = 0             dputeprf_lvt     = 0             dpclmprf_lvt     = 0
+dlpclmprf_lvt    = 0             dwpclmprf_lvt    = 0             dppclmprf_lvt    = 0
+deta0prf_lvt     = 0             dleta0prf_lvt    = 0e-9             dweta0prf_lvt    = 0e-08
+dpeta0prf_lvt    = 0             ntoxprf_lvt      = 1.54          dk2prf_lvt       = 0
+dlk2prf_lvt      = -0.2e-9        dwk2prf_lvt      = -4e-10        dpk2prf_lvt      = 0
+dcitprf_lvt      = 0e-4             dlcitprf_lvt     = 0e-11             dwcitprf_lvt     = 0
+dpcitprf_lvt     = 0             cfprf_lvt        = '1.284E-10 + 5.6e-11' dvoffprf_lvt     = 0
+dlvoffprf_lvt    = -7e-10       dwvoffprf_lvt    = 0             dpvoffprf_lvt    = -0e-17
+dnfactorprf_lvt  = 0.4             dlnfactorprf_lvt = 0e-8             dwnfactorprf_lvt = 0
+dpnfactorprf_lvt = 0             da0prf_lvt       = 0             dla0prf_lvt      = 0
+dwa0prf_lvt      = 0             dpa0prf_lvt      = 0             dagsprf_lvt      = -0.05
+dlagsprf_lvt     = 0             dwagsprf_lvt     = 0             dpagsprf_lvt     = -0e20
+dvsatprf_lvt     = -7000             dlvsatprf_lvt    = 0             dwvsatprf_lvt    = 0
+dpvsatprf_lvt    = 0             dpdiblc2prf_lvt  = 0             dlpdiblc2prf_lvt = 0
+dwpdiblc2prf_lvt = 0             dppdiblc2prf_lvt = 0
+is_d_dnw_nrf_lvt= 1.3         x_jsw_d_dnw_nrf_lvt= 1         n_d_dnw_nrf_lvt= 1.0025         rs_d_dnw_nrf_lvt= 0.8
+cj_d_dnw_nrf_lvt= 0.93          cjsw_d_dnw_nrf_lvt= 0.93
+is_d_dnw_prf_lvt= 1.3         x_jsw_d_dnw_prf_lvt= 1         n_d_dnw_prf_lvt= 1.0025         rs_d_dnw_prf_lvt= 0.8
+cj_d_dnw_prf_lvt= 0.93          cjsw_d_dnw_prf_lvt=  0.93
+is_d_prf_lvt= 1.3                 x_jsw_d_prf_lvt= 1             n_d_prf_lvt= 1.0025             rs_d_prf_lvt= 0.8
+cj_d_prf_lvt= 0.93                  cjsw_d_prf_lvt=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL FF_RFMOS_lvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+A1Nrf_lvt=0.8 A1Prf_lvt=-0.8 A2Nrf_lvt=0 A2Prf_lvt=0 A3Nrf_lvt=-1 A3Prf_lvt=1 A4NPrf_lvt=0
+toxnrf_lvt = '2.6e-09 + 6.7000e-011*A4NPrf_lvt'    dxlnrf_lvt = '5e-009*A2Nrf_lvt'                    dxwnrf_lvt = '8e-009*A3Nrf_lvt'
+dvthnrf_lvt = '0.03*A1Nrf_lvt'                     dlvthnrf_lvt = '14.4e-010*A1Nrf_lvt'               dwvthnrf_lvt = '3e-009*A1Nrf_lvt'
+dpvthnrf_lvt = '2.8e-016*A1Nrf_lvt'                cjnrf_lvt = '1.185E-03 * (1+0.070*A1Nrf_lvt)'      cjswnrf_lvt = '9.400E-11 * (1+0.070*A1Nrf_lvt)'
+cjswgnrf_lvt = '1.600E-10 * (1+0.070*A1Nrf_lvt)'   cgonrf_lvt = '8.918E-11 * (1-0.070*A4NPrf_lvt)'    cglnrf_lvt = '2.295E-11 * (1-0.070*A4NPrf_lvt)'
+ddlcnrf_lvt = 8.441E-09
+cfnrf_lvt = '1.20e-10*(1-0.070*A4NPrf_lvt)+5.4e-11'
+drdswnrf_lvt = 0                                 dcitnrf_lvt = 0                                  dlcitnrf_lvt = 0
+dwcitnrf_lvt = 0                                 dpcitnrf_lvt = 0                                 dvoffnrf_lvt = 0
+dlvoffnrf_lvt = '0.4e-09*A1Nrf_lvt'                dwvoffnrf_lvt = 0                                dpvoffnrf_lvt = '-0.4e-16*A1Nrf_lvt'
+ntoxnrf_lvt = '1 + -4.6600e-001*A4NPrf_lvt'        dnfactornrf_lvt = 0                              dwnfactornrf_lvt = 0
+dlnfactornrf_lvt = 0                             dpnfactornrf_lvt = 0                             du0nrf_lvt = '2.0e-4*A1Nrf_lvt'
+dlu0nrf_lvt = '-0.8e-10*A1Nrf_lvt'                 dwu0nrf_lvt = 0                                  dpu0nrf_lvt = '6.0e-18*A1Nrf_lvt'
+duanrf_lvt = 0                                   dluanrf_lvt = 0                                  dwuanrf_lvt = 0
+dpuanrf_lvt = 0                                  dubnrf_lvt = 0                                   dlubnrf_lvt = 0
+dwubnrf_lvt = 0                                  dpubnrf_lvt = 0                                  dua1nrf_lvt = 0
+dlua1nrf_lvt = 0                                 dwua1nrf_lvt = 0                                 dpua1nrf_lvt = 0
+dub1nrf_lvt = 0                                  dlub1nrf_lvt = 0                                 dwub1nrf_lvt = 0
+dpub1nrf_lvt = 0                                 dkt1nrf_lvt = 0                                  dlkt1nrf_lvt = 0
+dwkt1nrf_lvt = 0                                 dpkt1nrf_lvt = 0                                 deta0nrf_lvt = '0.03*A1Nrf_lvt'
+dleta0nrf_lvt = '-2.5e-09*A1Nrf_lvt'               dpeta0nrf_lvt = '0.0e-15*A1Nrf_lvt'                dweta0nrf_lvt = '-0.6e-08*A1Nrf_lvt'
+dcdscdnrf_lvt = 0                                dk2nrf_lvt = 0                                   dvsatnrf_lvt = 0
+dlvsatnrf_lvt = '2.0e-04*A1Nrf_lvt'                dwvsatnrf_lvt = 0                                dpvsatnrf_lvt = '-1.0e-11*A1Nrf_lvt'
+dlk2nrf_lvt = '3e-010*A1Nrf_lvt'                   dwk2nrf_lvt = '5e-010*A1Nrf_lvt'                   dpk2nrf_lvt = 0
+tt_flagrf_lvt    = 0                             ss_flagrf_lvt    = 0                             ff_flagrf_lvt    = 0
+sf_flagrf_lvt    = 1                             fs_flagrf_lvt    = 0
+toxprf_lvt = '2.8e-09 + 6.7000e-11*A4NPrf_lvt'     dxlprf_lvt = '5e-09*A2Prf_lvt'                     dxwprf_lvt = '8e-09*A3Prf_lvt'
+dvthprf_lvt = '-0.027*A1Prf_lvt'                   dlvthprf_lvt = '-2e-09*A1Prf_lvt'                  dwvthprf_lvt = '-3.5e-09*A1Prf_lvt'
+dpvthprf_lvt = '-2e-16*A1Prf_lvt'                  cjprf_lvt = '1.068E-03 * (1+0.070*A1Prf_lvt)'      cjswprf_lvt = '7.600E-11 * (1+0.070*A1Prf_lvt)'
+cjswgprf_lvt = '1.500E-10 * (1+0.070*A1Prf_lvt)'   cgoprf_lvt = '7.490E-11 * (1-0.070*A4NPrf_lvt)'    cglprf_lvt = '6.169E-11 * (1-0.070*A4NPrf_lvt)'
+ddlcprf_lvt = 1.054E-08                          du0prf_lvt = '0.0000*A1Prf_lvt'                   dlu0prf_lvt = '1.5e-11*A1Prf_lvt'
+dwu0prf_lvt = '0*A1Prf_lvt'                        dpu0prf_lvt = '5e-19*A1Prf_lvt'                    duaprf_lvt = 0
+dluaprf_lvt = '0*A1Prf_lvt'                        dwuaprf_lvt = 0                                  dpuaprf_lvt = 0
+dubprf_lvt = 0                                   dlubprf_lvt = '0*A1Prf_lvt'                        dwubprf_lvt = 0
+dpubprf_lvt = 0                                  dub1prf_lvt = 0                                  dlub1prf_lvt = 0
+dwub1prf_lvt = 0                                 dpub1prf_lvt = 0                                 dua1prf_lvt = 0
+dlua1prf_lvt = 0                                 dwua1prf_lvt = 0                                 dpua1prf_lvt = 0
+datprf_lvt = 0                                   dlatprf_lvt = 0                                  dwatprf_lvt = 0
+dpatprf_lvt = 0                                  duteprf_lvt = 0                                  dluteprf_lvt = 0
+dwuteprf_lvt = 0                                 dputeprf_lvt = 0                                 dpclmprf_lvt = 0
+dlpclmprf_lvt = 0                                dwpclmprf_lvt = 0                                dppclmprf_lvt = 0
+deta0prf_lvt = 0.05                                 dleta0prf_lvt = '0*A1Prf_lvt'                      dweta0prf_lvt = '0*A1Prf_lvt'
+dpeta0prf_lvt = 0                                ntoxprf_lvt = '1 + -5.4000e-01*A4NPrf_lvt'         dk2prf_lvt = 0
+dlk2prf_lvt = '2e-10*A1Prf_lvt'                    dwk2prf_lvt = '4e-10*A1Prf_lvt'                    dpk2prf_lvt = 0
+dcitprf_lvt = '0*A1Prf_lvt'                        dlcitprf_lvt = '0*A1Prf_lvt'                       dwcitprf_lvt = 0
+dpcitprf_lvt = 0
+cfprf_lvt = '1.200E-10*(1-0.070*A4NPrf_lvt)+5.6e-11'
+dvoffprf_lvt = 0                                 dlvoffprf_lvt = '7e-10*A1Prf_lvt'                  dwvoffprf_lvt = 0
+dpvoffprf_lvt = '0*A1Prf_lvt'                      dnfactorprf_lvt = '-0.0*A1Prf_lvt'                 dlnfactorprf_lvt = '0*A1Prf_lvt'
+dwnfactorprf_lvt = 0                             dpnfactorprf_lvt = 0                             da0prf_lvt = 0
+dla0prf_lvt = 0                                  dwa0prf_lvt = 0                                  dpa0prf_lvt = 0
+dagsprf_lvt = '0.05*A1Prf_lvt'                     dlagsprf_lvt = 0                                 dwagsprf_lvt = 0
+dpagsprf_lvt = '0*A1Prf_lvt'                       dvsatprf_lvt = '7000*A1Prf_lvt'                    dlvsatprf_lvt = 0
+dwvsatprf_lvt = 0                                dpvsatprf_lvt = 0                                dpdiblc2prf_lvt = 0
+dlpdiblc2prf_lvt = 0                             dwpdiblc2prf_lvt = 0                             dppdiblc2prf_lvt = 0
+is_d_dnw_nrf_lvt= 1         x_jsw_d_dnw_nrf_lvt= 0         n_d_dnw_nrf_lvt= 1         rs_d_dnw_nrf_lvt= 1
+cj_d_dnw_nrf_lvt= 1          cjsw_d_dnw_nrf_lvt= 1
+is_d_dnw_prf_lvt= 1         x_jsw_d_dnw_prf_lvt= 0         n_d_dnw_prf_lvt= 1         rs_d_dnw_prf_lvt= 1
+cj_d_dnw_prf_lvt= 1          cjsw_d_dnw_prf_lvt= 1
+is_d_prf_lvt= 1                 x_jsw_d_prf_lvt= 0             n_d_prf_lvt= 1             rs_d_prf_lvt= 1
+cj_d_prf_lvt= 1                  cjsw_d_prf_lvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL SF_RFMOS_lvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_lvt
.lib 'crn65lp_v1d5.l' noiseflagrf_lvt
.param
+parn1rf_lvt=AGAUSS(0,1,1)
+parn2rf_lvt=AGAUSS(0,1,1)
+parp1rf_lvt=AGAUSS(0,1,1)
+parp2rf_lvt=AGAUSS(0,1,1)
+A1Nrf_lvt=-0.8 A1Prf_lvt=0.8 A2Nrf_lvt=0 A2Prf_lvt=0 A3Nrf_lvt=1 A3Prf_lvt=-1 A4NPrf_lvt=0
+toxnrf_lvt = '2.6e-09 + 6.7000e-011*A4NPrf_lvt'    dxlnrf_lvt = '5e-009*A2Nrf_lvt'                    dxwnrf_lvt = '8e-009*A3Nrf_lvt'
+dvthnrf_lvt = '0.03*A1Nrf_lvt'                     dlvthnrf_lvt = '14.4e-010*A1Nrf_lvt'               dwvthnrf_lvt = '3e-009*A1Nrf_lvt'
+dpvthnrf_lvt = '2.8e-016*A1Nrf_lvt'                cjnrf_lvt = '1.185E-03 * (1+0.070*A1Nrf_lvt)'      cjswnrf_lvt = '9.400E-11 * (1+0.070*A1Nrf_lvt)'
+cjswgnrf_lvt = '1.600E-10 * (1+0.070*A1Nrf_lvt)'   cgonrf_lvt = '8.918E-11 * (1-0.070*A4NPrf_lvt)'    cglnrf_lvt = '2.295E-11 * (1-0.070*A4NPrf_lvt)'
+ddlcnrf_lvt = 8.441E-09
+cfnrf_lvt = '1.20e-10*(1-0.070*A4NPrf_lvt)+5.4e-11'
+drdswnrf_lvt = 0                                 dcitnrf_lvt = 0                                  dlcitnrf_lvt = 0
+dwcitnrf_lvt = 0                                 dpcitnrf_lvt = 0                                 dvoffnrf_lvt = 0
+dlvoffnrf_lvt = '0.4e-09*A1Nrf_lvt'                dwvoffnrf_lvt = 0                                dpvoffnrf_lvt = '-0.4e-16*A1Nrf_lvt'
+ntoxnrf_lvt = '1 + -4.6600e-001*A4NPrf_lvt'        dnfactornrf_lvt = 0                              dwnfactornrf_lvt = 0
+dlnfactornrf_lvt = 0                             dpnfactornrf_lvt = 0                             du0nrf_lvt = '2.0e-4*A1Nrf_lvt'
+dlu0nrf_lvt = '-0.8e-10*A1Nrf_lvt'                 dwu0nrf_lvt = 0                                  dpu0nrf_lvt = '4.0e-18*A1Nrf_lvt'
+duanrf_lvt = 0                                   dluanrf_lvt = 0                                  dwuanrf_lvt = 0
+dpuanrf_lvt = 0                                  dubnrf_lvt = 0                                   dlubnrf_lvt = 0
+dwubnrf_lvt = 0                                  dpubnrf_lvt = 0                                  dua1nrf_lvt = 0
+dlua1nrf_lvt = 0                                 dwua1nrf_lvt = 0                                 dpua1nrf_lvt = 0
+dub1nrf_lvt = 0                                  dlub1nrf_lvt = 0                                 dwub1nrf_lvt = 0
+dpub1nrf_lvt = 0                                 dkt1nrf_lvt = 0                                  dlkt1nrf_lvt = 0
+dwkt1nrf_lvt = 0                                 dpkt1nrf_lvt = 0                                 deta0nrf_lvt = '0.03*A1Nrf_lvt'
+dleta0nrf_lvt = '-3.0e-09*A1Nrf_lvt'               dpeta0nrf_lvt = '0.0e-15*A1Nrf_lvt'                dweta0nrf_lvt = '-0.6e-08*A1Nrf_lvt'
+dcdscdnrf_lvt = 0                                dk2nrf_lvt = 0                                   dvsatnrf_lvt = 0
+dlvsatnrf_lvt = '2.0e-04*A1Nrf_lvt'                dwvsatnrf_lvt = 0                                dpvsatnrf_lvt = '-1.0e-11*A1Nrf_lvt'
+dlk2nrf_lvt = '3e-010*A1Nrf_lvt'                   dwk2nrf_lvt = '5e-010*A1Nrf_lvt'                   dpk2nrf_lvt = 0
+tt_flagrf_lvt    = 0                             ss_flagrf_lvt    = 0                             ff_flagrf_lvt    = 0
+sf_flagrf_lvt    = 0                             fs_flagrf_lvt    = 1
+toxprf_lvt = '2.8e-09 + 6.7000e-11*A4NPrf_lvt'     dxlprf_lvt = '5e-09*A2Prf_lvt'                     dxwprf_lvt = '8e-09*A3Prf_lvt'
+dvthprf_lvt = '-0.027*A1Prf_lvt'                   dlvthprf_lvt = '-1e-09*A1Prf_lvt'                  dwvthprf_lvt = '-3.5e-09*A1Prf_lvt'
+dpvthprf_lvt = '-2e-16*A1Prf_lvt'                  cjprf_lvt = '1.068E-03 * (1+0.070*A1Prf_lvt)'      cjswprf_lvt = '7.600E-11 * (1+0.070*A1Prf_lvt)'
+cjswgprf_lvt = '1.500E-10 * (1+0.070*A1Prf_lvt)'   cgoprf_lvt = '7.490E-11 * (1-0.070*A4NPrf_lvt)'    cglprf_lvt = '6.169E-11 * (1-0.070*A4NPrf_lvt)'
+ddlcprf_lvt = 1.054E-08                          du0prf_lvt = '0.0000*A1Prf_lvt'                   dlu0prf_lvt = '1.5e-11*A1Prf_lvt'
+dwu0prf_lvt = '0*A1Prf_lvt'                        dpu0prf_lvt = '1.5e-18*A1Prf_lvt'                    duaprf_lvt = 0
+dluaprf_lvt = '0*A1Prf_lvt'                        dwuaprf_lvt = 0                                  dpuaprf_lvt = 0
+dubprf_lvt = 0                                   dlubprf_lvt = '0*A1Prf_lvt'                        dwubprf_lvt = 0
+dpubprf_lvt = 0                                  dub1prf_lvt = 0                                  dlub1prf_lvt = 0
+dwub1prf_lvt = 0                                 dpub1prf_lvt = 0                                 dua1prf_lvt = 0
+dlua1prf_lvt = 0                                 dwua1prf_lvt = 0                                 dpua1prf_lvt = 0
+datprf_lvt = 0                                   dlatprf_lvt = 0                                  dwatprf_lvt = 0
+dpatprf_lvt = 0                                  duteprf_lvt = 0                                  dluteprf_lvt = 0
+dwuteprf_lvt = 0                                 dputeprf_lvt = 0                                 dpclmprf_lvt = 0
+dlpclmprf_lvt = 0                                dwpclmprf_lvt = 0                                dppclmprf_lvt = 0
+deta0prf_lvt = -0.05                                 dleta0prf_lvt = '0*A1Prf_lvt'                      dweta0prf_lvt = '0*A1Prf_lvt'
+dpeta0prf_lvt = 0                                ntoxprf_lvt = '1 + -5.4000e-01*A4NPrf_lvt'         dk2prf_lvt = 0
+dlk2prf_lvt = '2e-10*A1Prf_lvt'                    dwk2prf_lvt = '4e-10*A1Prf_lvt'                    dpk2prf_lvt = 0
+dcitprf_lvt = '0*A1Prf_lvt'                        dlcitprf_lvt = '0*A1Prf_lvt'                       dwcitprf_lvt = 0
+dpcitprf_lvt = 0
+cfprf_lvt = '1.200E-10*(1-0.070*A4NPrf_lvt)+5.6e-11'
+dvoffprf_lvt = 0                                 dlvoffprf_lvt = '7e-10*A1Prf_lvt'                  dwvoffprf_lvt = 0
+dpvoffprf_lvt = '0*A1Prf_lvt'                      dnfactorprf_lvt = '-0.0*A1Prf_lvt'                 dlnfactorprf_lvt = '0*A1Prf_lvt'
+dwnfactorprf_lvt = 0                             dpnfactorprf_lvt = 0                             da0prf_lvt = 0
+dla0prf_lvt = 0                                  dwa0prf_lvt = 0                                  dpa0prf_lvt = 0
+dagsprf_lvt = '0.05*A1Prf_lvt'                     dlagsprf_lvt = 0                                 dwagsprf_lvt = 0
+dpagsprf_lvt = '0*A1Prf_lvt'                       dvsatprf_lvt = '7000*A1Prf_lvt'                    dlvsatprf_lvt = 0
+dwvsatprf_lvt = 0                                dpvsatprf_lvt = 0                                dpdiblc2prf_lvt = 0
+dlpdiblc2prf_lvt = 0                             dwpdiblc2prf_lvt = 0                             dppdiblc2prf_lvt = 0
+is_d_dnw_nrf_lvt= 1         x_jsw_d_dnw_nrf_lvt= 0         n_d_dnw_nrf_lvt= 1         rs_d_dnw_nrf_lvt= 1
+cj_d_dnw_nrf_lvt= 1          cjsw_d_dnw_nrf_lvt= 1
+is_d_dnw_prf_lvt= 1         x_jsw_d_dnw_prf_lvt= 0         n_d_dnw_prf_lvt= 1         rs_d_dnw_prf_lvt= 1
+cj_d_dnw_prf_lvt= 1          cjsw_d_dnw_prf_lvt= 1
+is_d_prf_lvt= 1                 x_jsw_d_prf_lvt= 0             n_d_prf_lvt= 1             rs_d_prf_lvt= 1
+cj_d_prf_lvt= 1                  cjsw_d_prf_lvt= 1
.lib 'crn65lp_v1d5.l' RF_MOS_lvt
.ENDL FS_RFMOS_lvt



.LIB RF_MOS_lvt

.subckt nmos_rf_lvt D G S B lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parn1rf_lvt  temp2=parn2rf_lvt
+fac1='0.498419*temp1*sigma+0.866936*temp2*sigma'
+fac2='0.498419*temp1*sigma-0.866936*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_lvt='(0.00386541332-0/(lef*1e6)+0.00000403525807/(lef*lef*1e12)+0.00000587615/(wef*wef*1e12)-0.0002168162130245*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_lvt='0.00177811*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_lvt='-0.00177811*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_lvt='0.00177811*geo_fac*toxnrf_lvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1533*lr*scale/nr/(wr*scale)+2.215)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.349e05/(lr*scale*1e6)+1.651e07'
.param rnoiax='0.0184/(lr*scale*1e6)+0.4433'

.param fn_dice='noiseflagnrf_lvt_mc*par1fn_mc+noiseflagnrf_lvt_mc_mis*par2fnrf_lvt_mc'
.param c1fnrf_lvt=7.05E+41           c2fnrf_lvt=1.00E+23           c3fnrf_lvt=1.00E+7       
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.35*log(((wr*scale*lr*scale*nr)/(15.2E-6*1E-6*1))**0.5)))'
.param noianrf_lvt='c1fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'
.param noibnrf_lvt='c2fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'
.param noicnrf_lvt='c3fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_lvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28615208+(dvthnrf_lvt+vthmisnrf_lvt)'
+LVTH0      = '-4.9983609e-009+dlvthnrf_lvt'
+WVTH0      = '8.4242078e-009+dwvthnrf_lvt'
+PVTH0      = '8.3105172e-018+dpvthnrf_lvt'
+K1         = 0.217               K2         = '0.027871333+dk2nrf_lvt'
+LK2        = '-4.0423516e-009+dlk2nrf_lvt'
+WK2        = '-6.7154904e-009+dwk2nrf_lvt'
+PK2        = '1.4392454e-015+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '0.00018742511+dcitnrf_lvt'
+LCIT       = '3.0832369e-011+dlcitnrf_lvt'
+WCIT       = '-1.0498717e-009+dwcitnrf_lvt'
+PCIT       = '1.8757092e-016+dpcitnrf_lvt'
+VOFF       = '-0.10966747+dvoffnrf_lvt'
+LVOFF      = '-3.4577165e-009+dlvoffnrf_lvt'
+WVOFF      = '-2.4677729e-008+dwvoffnrf_lvt'
+PVOFF      = '2.7504967e-015+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt'   ETA0       = '0.48915055+deta0nrf_lvt'
+LETA0      = '8.164015e-013+dleta0nrf_lvt'
+WETA0      = '-3.2518884e-007+dweta0nrf_lvt'
+PETA0      = '-3.586356e-019+dpeta0nrf_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.016001195+du0nrf_lvt'
+LU0        = '-1.0640471e-010+dlu0nrf_lvt'
+WU0        = '-2.3370167e-010+dwu0nrf_lvt'
+PU0        = '-2.0820372e-016+dpu0nrf_lvt'
+UA         = '-1.9487815e-009+duanrf_lvt'
+LUA        = '9.7958842e-018+dluanrf_lvt'
+WUA        = '4.9434163e-017+dwuanrf_lvt'
+PUA        = '-7.127695e-024+dpuanrf_lvt'
+UB         = '2.4060267e-018+dubnrf_lvt'
+LUB        = '-2.8382073e-026+dlubnrf_lvt'
+WUB        = '-4.3713318e-026+dwubnrf_lvt'
+PUB        = '-1.7322291e-032+dpubnrf_lvt'
+UC         = 7.6073046e-011      LUC        = -4.6675362e-018     WUC        = -4.3439813e-017
+PUC        = 2.9598691e-024      VSAT       = '103154.99+dvsatnrf_lvt'
+LVSAT      = '-0.00071927513+dlvsatnrf_lvt'
+WVSAT      = '0.00032910066+dwvsatnrf_lvt'
+PVSAT      = '-7.5028368e-011+dpvsatnrf_lvt'
+A0         = 4.9425076           LA0        = -8.0762088e-007     WA0        = -5.2656106e-007
+PA0        = 1.2004539e-013      AGS        = -2.8687863          LAGS       = 9.4523235e-007
+WAGS       = 3.9167033e-007      PAGS       = -3.7514184e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.067891169        LKETA      = 9.527125e-009       WKETA      = 1.7919753e-008
+PKETA      = -2.9617448e-015     DWG        = 0                   DWB        = 0
+PCLM       = 0.99881327          LPCLM      = -5.7657191e-008     WPCLM      = 4.7741724e-008
+PPCLM      = -1.5380816e-015     PDIBLC1    = 0                   PDIBLC2    = -0.0030506425
+LPDIBLC2   = 2.69563e-009        WPDIBLC2   = -2.6653099e-009     PPDIBLC2   = 1.1254255e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf_lvt'
+RDW        = '65+drdswnrf_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxnrf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_lvt'
+CGDO       = 'cgonrf_lvt'          CGBO       = 0                   CGDL       = 'cglnrf_lvt'
+CGSL       = 'cglnrf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.0012247098        LTVOFF     = -4.0437533e-011
+WTVOFF     = -8.5203632e-010     PTVOFF     = 6.4411854e-017      KT1        = '-0.22886246+dkt1nrf_lvt'
+LKT1       = '-2.9759694e-009+dlkt1nrf_lvt'
+WKT1       = '-1.5659777e-008+dwkt1nrf_lvt'
+PKT1       = '1.5829485e-015+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.075879437        LKT2       = 2.7043071e-009
+WKT2       = -4.2088909e-009     PKT2       = -1.2004539e-016     UTE        = -1.0844779
+LUTE       = 8.0912946e-009      WUTE       = 8.6167473e-008      PUTE       = -8.2531205e-015
+UA1        = '1.5080138e-009+dua1nrf_lvt'
+LUA1       = '-5.391282e-017+dlua1nrf_lvt'
+WUA1       = '-7.8827717e-017+dwua1nrf_lvt'
+PUA1       = '7.6153794e-024+dpua1nrf_lvt'
+UB1        = '-1.0938144e-018+dub1nrf_lvt'
+LUB1       = '4.8968935e-026+dlub1nrf_lvt'
+WUB1       = '2.5217669e-026+dwub1nrf_lvt'
+PUB1       = '-5.550805e-032+dpub1nrf_lvt'
+UC1        = 1.0838036e-010      LUC1       = -6.0210332e-018     WUC1       = -6.1438819e-017
+PUC1       = 8.9583872e-024      PRT        = 0                   AT         = 8000.1333
+WAT        = 0.022643864
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt'  WNFACTOR   = '0+dwnfactornrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+WMIN       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.23439418+(dvthnrf_lvt+vthmisnrf_lvt)+0.000545158*ff_flagrf_lvt-0.000545158*ss_flagrf_lvt'
+LVTH0      = '-4.0988817e-011+dlvthnrf_lvt-5.22149e-11*ff_flagrf_lvt+5.22149e-11*ss_flagrf_lvt'
+WVTH0      = '1.260777e-009+dwvthnrf_lvt-5.46248e-09*ff_flagrf_lvt+5.46248e-09*ss_flagrf_lvt'
+PVTH0      = '6.9442391e-016+dpvthnrf_lvt+5.23193e-16*ff_flagrf_lvt-5.23193e-16*ss_flagrf_lvt'
+K1         = 0.217               K2         = '-0.030127783+dk2nrf_lvt'
+LK2        = '1.5128037e-009+dlk2nrf_lvt'
+WK2        = '5.8489997e-009+dwk2nrf_lvt'
+PK2        = '2.3581857e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '-0.0025254154+dcitnrf_lvt'
+LCIT       = '2.9066824e-010+dlcitnrf_lvt'
+WCIT       = '4.0039237e-009+dwcitnrf_lvt'
+PCIT       = '-2.964816e-016+dpcitnrf_lvt'
+VOFF       = '-0.099451744+dvoffnrf_lvt'
+LVOFF      = '-4.436179e-009+dlvoffnrf_lvt'
+WVOFF      = '9.4170876e-009+dwvoffnrf_lvt'
+PVOFF      = '-5.1510487e-016+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt-0.357025*ss_flagrf_lvt'
+ETA0       = '0.48409488+deta0nrf_lvt-0.00181719*ff_flagrf_lvt'
+LETA0      = '4.8504901e-010+dleta0nrf_lvt+1.7405e-10*ff_flagrf_lvt'
+WETA0      = '-8.1020112e-007+dweta0nrf_lvt+1.82083e-08*ff_flagrf_lvt'
+PETA0      = '4.6454117e-014+dpeta0nrf_lvt-1.74398e-15*ff_flagrf_lvt'
+ETAB       = -0.018461361
+Petab    = 8.719881e-16
+Letab    = 1.4487063e-09
+WETAB      = -3.1068909e-08
+UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010669839+du0nrf_lvt'
+LU0        = '4.0423259e-010+dlu0nrf_lvt'
+WU0        = '-1.5698813e-009+dwu0nrf_lvt'
+PU0        = '-8.0224433e-017+dpu0nrf_lvt'
+UA         = '-2.4269058e-009+duanrf_lvt'
+LUA        = '5.5590629e-017+dluanrf_lvt'
+WUA        = '-2.9161008e-016+dwuanrf_lvt'
+PUA        = '2.5537523e-023+dpuanrf_lvt'
+UB         = '2.2307279e-018+dubnrf_lvt'
+LUB        = '-1.1591957e-026+dlubnrf_lvt'
+WUB        = '4.6418333e-025+dwubnrf_lvt'
+PUB        = '-6.5968632e-032+dpubnrf_lvt'
+UC         = 6.6545728e-11
+LUC        = -3.7549892e-18
+WUC        = -1.945144e-18
+PUC        = -1.0144903e-24
+VSAT       = '99160.041+dvsatnrf_lvt+1071.07*ss_flagrf_lvt'
+LVSAT      = '-0.00033663866+dlvsatnrf_lvt-0.000102587*ss_flagrf_lvt'
+WVSAT      = '0.0061008173+dwvsatnrf_lvt-0.0010925*ss_flagrf_lvt'
+PVSAT      = '-6.2784339e-010+dpvsatnrf_lvt+1.04639e-10*ss_flagrf_lvt'
+A0         = -2.4893169          LA0        = -9.5800729e-008     WA0        = 7.1278269e-008
+PA0        = 6.2784339e-014      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = 0.0036497472        LKETA      = 2.6749361e-009
+WKETA      = -7.1360839e-008     PKETA      = 5.5895502e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.38255683          LPCLM      = 1.3678505e-009
+WPCLM      = 4.6250034e-008      PPCLM      = -1.3952075e-015     PDIBLC1    = 0
+PDIBLC2    = 0.030053261         LPDIBLC2   = -4.7506186e-010     WPDIBLC2   = 2.3651594e-008
+PPDIBLC2   = -1.3952075e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0016506047
+LTVOFF     = -8.1229742e-011     WTVOFF     = -2.164082e-009      PTVOFF     = 1.9007959e-016
+KT1        = '-0.19451937+dkt1nrf_lvt'
+LKT1       = '-6.2653157e-09+dlkt1nrf_lvt'
+WKT1       = '-1.1213008e-07+dwkt1nrf_lvt'
+PKT1       = '1.0822839e-14+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.044506216        LKT2       = -3.0061996e-010
+WKT2       = -7.0281664e-009     PKT2       = 1.4998481e-016      UTE        = 0.66554152
+LUTE       = -1.5952557e-007     WUTE       = -1.6988524e-006     PUTE       = 1.6271608e-013
+UA1        = '3.4887539e-009+dua1nrf_lvt'
+LUA1       = '-2.436281e-016+dlua1nrf_lvt'
+WUA1       = '-1.7757392e-015+dwua1nrf_lvt'
+PUA1       = '1.7014556e-022+dpua1nrf_lvt'
+UB1        = '-9.5527444e-019+dub1nrf_lvt'
+LUB1       = '3.5699574e-026+dlub1nrf_lvt'
+WUB1       = '-1.5640491e-024+dwub1nrf_lvt'
+PUB1       = '9.6711924e-032+dpub1nrf_lvt'
+UC1        = -4.3940601e-11
+LUC1       = 8.5681829e-18
+WUC1       = 9.6239901e-17
+PUC1       = -6.144046e-24
+PRT        = 0                   AT         = -40423.746
+LAT        = 0.0046380392        WAT        = 0.072036221         PAT        = -4.7307999e-009
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0
+CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0
+CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0
+CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt+3.41956e-08*ss_flagrf_lvt'
+WNFACTOR   = '0+dwnfactornrf_lvt+3.64165e-07*ss_flagrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt-3.48795e-14*ss_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30139764+(dvthnrf_lvt+vthmisnrf_lvt)'
+LVTH0      = '-5.9798022e-009+dlvthnrf_lvt'
+WVTH0      = '-7.126262e-009+dwvthnrf_lvt'
+PVTH0      = '1.0093807e-015+dpvthnrf_lvt'
+K1         = 0.217               K2         = '0.022481655+dk2nrf_lvt'
+LK2        = '-3.1848829e-009+dlk2nrf_lvt'
+WK2        = '-1.2180193e-009+dwk2nrf_lvt'
+PK2        = '5.6462745e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '-0.0012641596+dcitnrf_lvt'
+LCIT       = '2.4032731e-010+dlcitnrf_lvt'
+WCIT       = '4.3074477e-010+dwcitnrf_lvt'
+PCIT       = '-2.6113916e-017+dpcitnrf_lvt'
+VOFF       = '-0.1452694+dvoffnrf_lvt'
+LVOFF      = '1.8390894e-010+dlvoffnrf_lvt'
+WVOFF      = '1.1636233e-008+dwvoffnrf_lvt'
+PVOFF      = '-9.6396125e-016+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt'   ETA0       = '0.1243618+deta0nrf_lvt'
+LETA0      = '1.1852348e-012+dleta0nrf_lvt'
+WETA0      = '4.6895683e-008+dweta0nrf_lvt'
+PETA0      = '-7.3484559e-019+dpeta0nrf_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017962484+du0nrf_lvt'
+LU0        = '-3.540492e-010+dlu0nrf_lvt'
+WU0        = '-2.2342161e-009+dwu0nrf_lvt'
+PU0        = '4.4393657e-017+dpu0nrf_lvt'
+UA         = '-1.8908752e-009+duanrf_lvt'
+LUA        = '1.1256568e-017+dluanrf_lvt'
+WUA        = '-9.6302274e-018+dwuanrf_lvt'
+PUA        = '-8.6175922e-024+dpuanrf_lvt'
+UB         = '2.5042067e-018+dubnrf_lvt'
+LUB        = '-6.1909735e-026+dlubnrf_lvt'
+WUB        = '-1.4385689e-025+dwubnrf_lvt'
+PUB        = '1.6875925e-032+dpubnrf_lvt'
+UC         = 1.7203086e-011      LUC        = 5.9990981e-019      WUC        = 1.6607546e-017
+PUC        = -2.4129258e-024     VSAT       = '98536.493+dvsatnrf_lvt'
+LVSAT      = '0.00033365028+dlvsatnrf_lvt'
+WVSAT      = '0.0050399697+dwvsatnrf_lvt'
+PVSAT      = '-1.1490123e-009+dpvsatnrf_lvt'
+A0         = 4.7238631           LA0        = -7.577743e-007      WA0        = -3.0354363e-007
+PA0        = 6.9201876e-014      AGS        = -2.4847958          LAGS       = 9.0845374e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.038058485        LKETA      = 6.5978517e-009
+WKETA      = -1.2509585e-008     PKETA      = 2.6113916e-017      DWG        = 0
+DWB        = 0                   PCLM       = 1.2105486           LPCLM      = -8.9733757e-008
+WPCLM      = -1.6822835e-007     PPCLM      = 3.1180015e-014      PDIBLC1    = 0
+PDIBLC2    = -0.0237901          LPDIBLC2   = 6.1646019e-009      WPDIBLC2   = 1.8488936e-008
+PPDIBLC2   = -2.4129258e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00034240366
+LTVOFF     = 6.833389e-011       WTVOFF     = 4.7915972e-011      PTVOFF     = -4.6534998e-017
+KT1        = '-0.26987595+dkt1nrf_lvt'
+LKT1       = '7.5090358e-009+dlkt1nrf_lvt'
+WKT1       = '2.6173983e-008+dwkt1nrf_lvt'
+PKT1       = '-9.1117568e-015+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.10692445         LKT2       = 5.9071791e-009
+WKT2       = 2.7457026e-008      PKT2       = -3.3869749e-015     UTE        = -1
+UA1        = '1.5826054e-009+dua1nrf_lvt'
+LUA1       = '-5.1387925e-017+dlua1nrf_lvt'
+WUA1       = '-1.5491114e-016+dwua1nrf_lvt'
+PUA1       = '5.0399857e-024+dpua1nrf_lvt'
+UB1        = '-9.7987827e-019+dub1nrf_lvt'
+LUB1       = '-6.116809e-026+dlub1nrf_lvt'
+WUB1       = '-9.0997215e-026+dwub1nrf_lvt'
+PUB1       = '5.6831715e-032+dpub1nrf_lvt'
+UC1        = 4.047626e-011       LUC1       = 9.7330908e-018      WUC1       = 7.8233597e-018
+PUC1       = -7.1108192e-024     PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt'  WNFACTOR   = '0+dwnfactornrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.25840312+(dvthnrf_lvt+vthmisnrf_lvt)-0.012266*ff_flagrf_lvt+0.012266*ss_flagrf_lvt'
+LVTH0      = '-1.8617867e-009+dlvthnrf_lvt+1.17483e-09*ff_flagrf_lvt-1.17483e-09*ss_flagrf_lvt'
+WVTH0      = '-2.3228341e-008+dwvthnrf_lvt+7.60495e-09*ff_flagrf_lvt-7.60495e-09*ss_flagrf_lvt'
+PVTH0      = '2.5516377e-015+dpvthnrf_lvt-7.28397e-16*ff_flagrf_lvt+7.28397e-16*ss_flagrf_lvt'
+K1         = 0.217               K2         = '-0.025394525+dk2nrf_lvt'
+LK2        = '1.4006976e-009+dlk2nrf_lvt'
+WK2        = '1.0210766e-009+dwk2nrf_lvt'
+PK2        = '3.5016685e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '2.3457461e-006+dcitnrf_lvt'
+LCIT       = '1.1902142e-010+dlcitnrf_lvt'
+WCIT       = '1.4256073e-009+dwcitnrf_lvt'
+PCIT       = '-1.2140185e-016+dpcitnrf_lvt'
+VOFF       = '-0.1240989+dvoffnrf_lvt'
+LVOFF      = '-1.8438017e-009+dlvoffnrf_lvt'
+WVOFF      = '3.4557183e-008+dwvoffnrf_lvt'
+PVOFF      = '-3.1593298e-015+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt-0.0994111*ss_flagrf_lvt'
+ETA0       = '-0.5294399+deta0nrf_lvt+0.0408868*ff_flagrf_lvt'
+LETA0      = '6.2622312e-008+dleta0nrf_lvt-3.91611e-09*ff_flagrf_lvt'
+WETA0      = '2.2360436e-007+dweta0nrf_lvt-2.53498e-08*ff_flagrf_lvt'
+PETA0      = '-1.6925892e-014+dpeta0nrf_lvt+2.42799e-15*ff_flagrf_lvt'
+ETAB       = 0.039736442
+LETAB      = -2.4572377e-09
+WETAB      = -9.0430667e-08
+PETAB      = 4.856051e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0082323123+du0nrf_lvt'
+LU0        = '5.7790661e-010+dlu0nrf_lvt'
+WU0        = '9.1639556e-010+dwu0nrf_lvt'
+PU0        = '-2.5737193e-016+dpu0nrf_lvt'
+UA         = '-3.0749301e-009+duanrf_lvt'
+LUA        = '1.2466534e-016+dluanrf_lvt'
+WUA        = '3.6937472e-016+dwuanrf_lvt'
+PUA        = '-4.4918686e-023+dpuanrf_lvt'
+UB         = '3.1425635e-018+dubnrf_lvt'
+LUB        = '-1.2305155e-025+dlubnrf_lvt'
+WUB        = '-4.6588894e-025+dwubnrf_lvt'
+PUB        = '4.7720155e-032+dpubnrf_lvt'
+UC         = 8.9822988e-11
+LUC        = -6.3555719e-18
+WUC        = -2.5687948e-17
+PUC        = 1.6381041e-24
+VSAT       = '120396.91+dvsatnrf_lvt-2485.28*ff_flagrf_lvt'
+LVSAT      = '-0.0017601405+dlvsatnrf_lvt+0.000238038*ff_flagrf_lvt'
+WVSAT      = '-0.01556079+dwvsatnrf_lvt+0.00253498*ff_flagrf_lvt'
+PVSAT      = '8.2412849e-010+dpvsatnrf_lvt-2.42799e-10*ff_flagrf_lvt'
+A0         = -3.488793           LA0        = 2.88339e-008        WA0        = 1.0907439e-006
+PA0        = -6.4342982e-014     AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0461879          LKETA      = 7.3764872e-009
+WKETA      = -2.0526438e-008     PKETA      = 7.9396812e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.17475972          LPCLM      = 9.4741054e-009
+WPCLM      = 2.5820308e-007      PPCLM      = -9.6635875e-015     PDIBLC1    = 0
+PDIBLC2    = 0.052953647         LPDIBLC2   = -1.1859141e-009     WPDIBLC2   = 2.9320051e-010
+PPDIBLC2   = -6.7013823e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0014296083
+LTVOFF     = -3.5798573e-011     WTVOFF     = -1.9386657e-009     PTVOFF     = 1.4373979e-016
+KT1        = '-0.12546444+dkt1nrf_lvt'
+LKT1       = '-6.3226983e-009+dlkt1nrf_lvt'
+WKT1       = '-1.8256611e-007+dwkt1nrf_lvt'
+PKT1       = '1.088137e-014+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.03619065         LKT2       = -8.6770458e-010
+WKT2       = -1.5510044e-008     PKT2       = 7.2841112e-016      UTE        = -1
+UA1        = '2.032528e-009+dua1nrf_lvt'
+LUA1       = '-9.448151e-017+dlua1nrf_lvt'
+WUA1       = '-2.9038879e-016+dwua1nrf_lvt'
+PUA1       = '1.8016035e-023+dpua1nrf_lvt'
+UB1        = '-3.5815882e-018+dub1nrf_lvt'
+LUB1       = '1.8802369e-025+dlub1nrf_lvt'
+WUB1       = '1.1147909e-024+dwub1nrf_lvt'
+PUB1       = '-5.8658669e-032+dpub1nrf_lvt'
+UC1        = 1.6779532e-10
+LUC1       = -2.461659e-18
+WUC1       = -1.1973073e-16
+PUC1       = 5.106393e-24
+PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt+9.52153e-09*ss_flagrf_lvt'
+WNFACTOR   = '0+dwnfactornrf_lvt+1.01399e-07*ss_flagrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt-9.71196e-15*ss_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.7e-07                 IKR    = 1E10
+N      = 1                       BV     = 9.3                     IBV    = 0.03
+JSW    = 2.8e-13                 CJ     = 'cjnrf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.08                    TLEVC  = 1
+CTA    = 0.00073                 CTP    = 0.0003                  
+TCV    = -8.00E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.001                   FCS    = 0			   )

.MODEL ndio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.7e-07                 IKR    = 1E10
+N      = 1                       BV     = 9.3                     IBV    = 0.03
+JSW    = 2.8e-13                 CJ     = 'cjnrf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.75                    TLEVC  = 1
+CTA    = 0.00073                 CTP    = 0.0015                  
+TCV    = -8.00E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 0.7
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.ends nmos_rf_lvt

.subckt pmos_rf_lvt D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parp1rf_lvt  temp2=parp2rf_lvt
+fac1='0.870389*temp1*sigma+0.492365*temp2*sigma'
+fac2='0.870389*temp1*sigma-0.492365*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_lvt='(0.004252047-0.00028546287615/(lef*1e6)+0.0000152025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)+0.000032802452198*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_lvt = '0.00181396*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_lvt = '-0.00181396*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_lvt='0.00181396*geo_fac*toxprf_lvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1843.3*lr*scale/nr/(wr*scale)+0.4389)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.205e06/(lr*scale*1e6)+3.273e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4814'

.param fn_dice='noiseflagprf_lvt_mc*par1fn_mc+noiseflagprf_lvt_mc_mis*par2fprf_lvt_mc'    
.param c1fprf_lvt=5.00E+42           c2fprf_lvt=1.55E+24           c3fprf_lvt=1.00E+10    
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(2.3E-6*1E-6*1))**0.5)))'
.param noiaprf_lvt='c1fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noibprf_lvt='c2fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noicprf_lvt='c3fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_lvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '1.2831097e-009+dlvthprf_lvt'
+WVTH0      = '-1.3596429e-008+dwvthprf_lvt'
+PVTH0      = '4.6838072e-016+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2prf_lvt'
+LK2        = '4.6584946e-010+dlk2prf_lvt'
+WK2        = '-2.5582468e-009+dwk2prf_lvt'
+PK2        = '4.6843351e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitprf_lvt'
+LCIT       = '3.0389251e-010+dlcitprf_lvt'
+WCIT       = '1.5758347e-009+dwcitprf_lvt'
+PCIT       = '-1.8542906e-016+dpcitprf_lvt'
+VOFF       = '-0.076341704+dvoffprf_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffprf_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffprf_lvt'
+PVOFF      = '3.2068922e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.2908066+deta0prf_lvt'
+LETA0      = '-2.3078942e-013+dleta0prf_lvt'
+WETA0      = '1.9302674e-007+dweta0prf_lvt'
+PETA0      = '5.8675625e-019+dpeta0prf_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0prf_lvt-5.66666e-06*ff_flagrf_lvt+8.48339e-06*ss_flagrf_lvt-4.53333e-06*sf_flagrf_lvt+4.53333e-06*fs_flagrf_lvt'
+LU0        = '-1.9519503e-010+dlu0prf_lvt+5e-20*ff_flagrf_lvt-1.95194e-12*ss_flagrf_lvt+2.4e-19*sf_flagrf_lvt-2.4e-19*fs_flagrf_lvt'
+WU0        = '1.9415438e-009+dwu0prf_lvt+5.678e-11*ff_flagrf_lvt-8.50036e-11*ss_flagrf_lvt+4.5424e-11*sf_flagrf_lvt-4.5424e-11*fs_flagrf_lvt'
+PU0        = '-3.9117084e-017+dpu0prf_lvt-1e-24*ff_flagrf_lvt+1.95585e-17*ss_flagrf_lvt+3.2e-24*sf_flagrf_lvt-3.2e-24*fs_flagrf_lvt'
+UA         = '-6.2902859e-010+duaprf_lvt'
+LUA        = '-2.4675637e-017+dluaprf_lvt'
+WUA        = '3.9281125e-016+dwuaprf_lvt'
+PUA        = '-1.9206488e-023+dpuaprf_lvt'
+UB         = '1.9421977e-018+dubprf_lvt'
+LUB        = '-2.4060497e-026+dlubprf_lvt'
+WUB        = '-4.483143e-025+dwubprf_lvt'
+PUB        = '3.8556285e-032+dpubprf_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatprf_lvt'  A0         = '5.3771092+da0prf_lvt'
+LA0        = '-9.4373925e-007+dla0prf_lvt'
+WA0        = '-1.9768385e-006+dwa0prf_lvt'
+PA0        = '3.9606047e-013+dpa0prf_lvt'
+AGS        = '9.1959311+dagsprf_lvt'
+LAGS       = '-5.1830021e-007+dlagsprf_lvt'
+WAGS       = '1.247831e-006+dwagsprf_lvt'
+PAGS       = '-1.5646833e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmprf_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+duteprf_lvt'
+LUTE       = '-2.8693669e-009+dluteprf_lvt'
+WUTE       = '-2.918889e-007+dwuteprf_lvt'
+PUTE       = '2.8751056e-014+dputeprf_lvt'
+UA1        = '1.3742656e-009+dua1prf_lvt'
+LUA1       = '2.3165574e-017+dlua1prf_lvt'
+WUA1       = '1.292132e-016+dwua1prf_lvt'
+PUA1       = '-4.7319897e-023+dpua1prf_lvt'
+UB1        = '-1.8019021e-018+dub1prf_lvt'
+LUB1       = '3.1767874e-026+dlub1prf_lvt'
+WUB1       = '-8.8236177e-026+dwub1prf_lvt'
+PUB1       = '-1.1654575e-032+dpub1prf_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datprf_lvt'
+LAT        = '-0.010013792+dlatprf_lvt'
+WAT        = '-0.0024820485+dwatprf_lvt'
+PAT        = '2.4448177e-010+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmprf_lvt'     PPCLM      = '0+dppclmprf_lvt'     LNFACTOR   = '0+dlnfactorprf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'  LVSAT      = '0+dlvsatprf_lvt'
+WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+(dvthprf_lvt+vthmisprf_lvt)-0.0126208*ff_flagrf_lvt+0.0275506*ss_flagrf_lvt-0.00555994*sf_flagrf_lvt+0.00555994*fs_flagrf_lvt'
+LVTH0      = '-1.5409072e-009+dlvthprf_lvt+1.24315e-09*ff_flagrf_lvt-2.71373e-09*ss_flagrf_lvt+5.47654e-10*sf_flagrf_lvt-5.47654e-10*fs_flagrf_lvt'
+WVTH0      = '-9.5700168e-009+dwvthprf_lvt-9.64051e-09*ff_flagrf_lvt-3.85616e-09*ss_flagrf_lvt-1.23398e-08*sf_flagrf_lvt+1.23398e-08*fs_flagrf_lvt'
+PVTH0      = '7.1779158e-017+dpvthprf_lvt+9.49589e-16*ff_flagrf_lvt+3.79834e-16*ss_flagrf_lvt+1.21547e-15*sf_flagrf_lvt-1.21547e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2prf_lvt'
+LK2        = '2.3040232e-009+dlk2prf_lvt'
+WK2        = '5.5823676e-010+dwk2prf_lvt'
+PK2        = '1.6145988e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.5104142e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '6.1284302e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-9.0574373e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.081864514+dvoffprf_lvt-0.0481515*ff_flagrf_lvt+0.0567087*ss_flagrf_lvt-0.0356506*sf_flagrf_lvt+0.0354005*fs_flagrf_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffprf_lvt+4.7429e-09*ff_flagrf_lvt-5.58579e-09*ss_flagrf_lvt+3.51158e-09*sf_flagrf_lvt-3.48694e-09*fs_flagrf_lvt'
+WVOFF      = '1.4496007e-008+dwvoffprf_lvt+2.31371e-08*ff_flagrf_lvt-5.78429e-08*ss_flagrf_lvt+1.69672e-08*sf_flagrf_lvt-1.44607e-08*fs_flagrf_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffprf_lvt-2.27901e-15*ff_flagrf_lvt+5.69751e-15*ss_flagrf_lvt-1.67127e-15*sf_flagrf_lvt+1.42438e-15*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.0769699*ff_flagrf_lvt-0.756116*ss_flagrf_lvt+0.061576*sf_flagrf_lvt-0.061576*fs_flagrf_lvt'
+ETA0       = '-0.13126921+deta0prf_lvt+0.0945146*ff_flagrf_lvt-0.0945146*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LETA0      = '4.1574237e-008+dleta0prf_lvt-9.30966e-09*ff_flagrf_lvt+9.30966e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WETA0      = '5.1059346e-007+dweta0prf_lvt-9.64048e-08*ff_flagrf_lvt+9.64048e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PETA0      = '-3.1279736e-014+dpeta0prf_lvt+9.49585e-15*ff_flagrf_lvt-9.49585e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0prf_lvt+0.000206454*ff_flagrf_lvt-0.00127681*ss_flagrf_lvt+8.95511e-05*sf_flagrf_lvt-1.39395e-05*fs_flagrf_lvt'
+LU0        = '2.1404963e-010+dlu0prf_lvt-2.08938e-11*ff_flagrf_lvt+1.24649e-10*ss_flagrf_lvt-9.26729e-12*sf_flagrf_lvt+1.81956e-12*fs_flagrf_lvt'
+WU0        = '1.1009666e-009+dwu0prf_lvt-3.67401e-10*ff_flagrf_lvt+8.848e-10*ss_flagrf_lvt-2.16797e-10*sf_flagrf_lvt+1.39673e-10*fs_flagrf_lvt'
+PU0        = '4.3679771e-017+dpu0prf_lvt+4.17817e-17*ff_flagrf_lvt-7.59665e-17*ss_flagrf_lvt+2.58287e-17*sf_flagrf_lvt-1.8232e-17*fs_flagrf_lvt'
+UA         = '-1.3371304e-009+duaprf_lvt'
+LUA        = '4.5072393e-017+dluaprf_lvt'
+WUA        = '-9.5951684e-019+dwuaprf_lvt'
+PUA        = '1.9579932e-023+dpuaprf_lvt'
+UB         = '1.6937477e-018+dubprf_lvt'
+LUB        = '4.118249e-028+dlubprf_lvt'
+WUB        = '2.3165923e-025+dwubprf_lvt'
+PUB        = '-2.8421107e-032+dpubprf_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatprf_lvt-192.425*ff_flagrf_lvt+5478.45*ss_flagrf_lvt-153.94*sf_flagrf_lvt+153.94*fs_flagrf_lvt'
+LVSAT      = '0.00071788404+dlvsatprf_lvt+1.89538e-05*ff_flagrf_lvt-0.000539625*ss_flagrf_lvt+1.5163e-05*sf_flagrf_lvt-1.5163e-05*fs_flagrf_lvt'
+WVSAT      = '0.02063004+dwvsatprf_lvt+0.0019281*ff_flagrf_lvt-0.00385619*ss_flagrf_lvt+0.00154248*sf_flagrf_lvt-0.00154248*fs_flagrf_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatprf_lvt-1.89917e-10*ff_flagrf_lvt+3.79834e-10*ss_flagrf_lvt-1.51934e-10*sf_flagrf_lvt+1.51934e-10*fs_flagrf_lvt'
+A0         = '-14.929677+da0prf_lvt'
+LA0        = '1.0564791e-006+dla0prf_lvt'
+WA0        = '7.4425951e-006+dwa0prf_lvt'
+PA0        = '-5.3175373e-013+dpa0prf_lvt'
+AGS        = '-4.6385162+dagsprf_lvt'
+LAGS       = '8.4439285e-007+dlagsprf_lvt'
+WAGS       = '1.8052297e-006+dwagsprf_lvt'
+PAGS       = '-2.1137211e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmprf_lvt'
+LPCLM      = '-5.758458e-008+dlpclmprf_lvt'
+WPCLM      = '9.6402055e-008+dwpclmprf_lvt'
+PPCLM      = '-9.4956024e-015+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2prf_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+duteprf_lvt'
+UA1        = '2.2956478e-009+dua1prf_lvt'
+LUA1       = '-6.7590577e-017+dlua1prf_lvt'
+WUA1       = '-1.1115199e-015+dwua1prf_lvt'
+PUA1       = '7.4892317e-023+dpua1prf_lvt'
+UB1        = '-1.2411257e-018+dub1prf_lvt'
+LUB1       = '-2.3468592e-026+dlub1prf_lvt'
+WUB1       = '-5.8862958e-025+dwub1prf_lvt'
+PUB1       = '3.7634175e-032+dpub1prf_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-7.58152e-09*ff_flagrf_lvt+7.44773e-08*ss_flagrf_lvt-6.06521e-09*sf_flagrf_lvt+6.06521e-09*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-7.71239e-07*ff_flagrf_lvt+7.71239e-07*ss_flagrf_lvt-6.16991e-07*sf_flagrf_lvt+6.16991e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.59668e-14*ff_flagrf_lvt-7.59668e-14*ss_flagrf_lvt+6.07734e-14*sf_flagrf_lvt-6.07734e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '2.6146736e-011+dlvthprf_lvt'
+WVTH0      = '-1.6058274e-008+dwvthprf_lvt'
+PVTH0      = '1.7504829e-015+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2prf_lvt'
+LK2        = '5.5945104e-010+dlk2prf_lvt'
+WK2        = '-1.5266232e-009+dwk2prf_lvt'
+PK2        = '3.729599e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitprf_lvt'
+LCIT       = '-4.9918717e-012+dlcitprf_lvt'
+WCIT       = '-1.6353193e-009+dwcitprf_lvt'
+PCIT       = '1.2963301e-016+dpcitprf_lvt'
+VOFF       = '-0.082218583+dvoffprf_lvt'
+LVOFF      = '-4.857209e-009+dlvoffprf_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffprf_lvt'
+PVOFF      = '2.6897322e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.72801286+deta0prf_lvt'
+LETA0      = '1.4122934e-012+dleta0prf_lvt'
+WETA0      = '-2.5292365e-007+dweta0prf_lvt'
+PETA0      = '-1.0891883e-018+dpeta0prf_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0prf_lvt+0.0001275*ff_flagrf_lvt-0.000190876*ss_flagrf_lvt+0.000102*sf_flagrf_lvt-0.000102*fs_flagrf_lvt'
+LU0        = '-2.7091922e-010+dlu0prf_lvt+4.6e-17*ff_flagrf_lvt+4.39187e-11*ss_flagrf_lvt-2.3e-17*sf_flagrf_lvt+2.3e-17*fs_flagrf_lvt'
+WU0        = '-1.9016192e-009+dwu0prf_lvt-7.90503e-11*ff_flagrf_lvt+1.18343e-10*ss_flagrf_lvt-6.32397e-11*sf_flagrf_lvt+6.32397e-11*fs_flagrf_lvt'
+PU0        = '3.8121589e-017+dpu0prf_lvt+5e-24*ff_flagrf_lvt-2.72296e-17*ss_flagrf_lvt-3.6e-23*sf_flagrf_lvt+3.6e-23*fs_flagrf_lvt'
+UA         = '4.0037736e-010+duaprf_lvt'
+LUA        = '-5.25554e-017+dluaprf_lvt'
+WUA        = '-6.5718282e-016+dwuaprf_lvt'
+PUA        = '9.2308705e-024+dpuaprf_lvt'
+UB         = '1.3125234e-018+dubprf_lvt'
+LUB        = '6.503691e-027+dlubprf_lvt'
+WUB        = '1.9395346e-025+dwubprf_lvt'
+PUB        = '7.3808134e-033+dpubprf_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatprf_lvt'  A0         = '4.8804857+da0prf_lvt'
+LA0        = '-7.8903284e-007+dla0prf_lvt'
+WA0        = '-1.4702825e-006+dwa0prf_lvt'
+PA0        = '2.3825993e-013+dpa0prf_lvt'
+AGS        = '13.322597+dagsprf_lvt'
+LAGS       = '-1.0187458e-006+dlagsprf_lvt'
+WAGS       = '-2.9613684e-006+dwagsprf_lvt'
+PAGS       = '3.5398618e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmprf_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmprf_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmprf_lvt'
+PPCLM      = '-1.3614853e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2prf_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+duteprf_lvt'
+LUTE       = '9.5674269e-009+dluteprf_lvt'
+WUTE       = '-1.6310179e-007+dwuteprf_lvt'
+PUTE       = '1.6065527e-014+dputeprf_lvt'
+UA1        = '2.0289308e-009+dua1prf_lvt'
+LUA1       = '-7.6235902e-017+dlua1prf_lvt'
+WUA1       = '-5.385453e-016+dwua1prf_lvt'
+PUA1       = '5.4069609e-023+dpua1prf_lvt'
+UB1        = '-2.1814336e-018+dub1prf_lvt'
+LUB1       = '5.2100107e-026+dlub1prf_lvt'
+WUB1       = '2.9888601e-025+dwub1prf_lvt'
+PUB1       = '-3.2393453e-032+dpub1prf_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datprf_lvt'
+LAT        = '-0.017286299+dlatprf_lvt'
+WAT        = '-0.077791263+dwatprf_lvt'
+PAT        = '7.6624394e-009+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_lvt'  WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'
+LVSAT      = '0+dlvsatprf_lvt'     WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+(dvthprf_lvt+vthmisprf_lvt)+0.00687633*ff_flagrf_lvt+0.0106116*ss_flagrf_lvt+0.0055011*sf_flagrf_lvt-0.0055011*fs_flagrf_lvt'
+LVTH0      = '-1.3621188e-010+dlvthprf_lvt-6.77323e-10*ff_flagrf_lvt-1.04524e-09*ss_flagrf_lvt-5.41853e-10*sf_flagrf_lvt+5.41853e-10*fs_flagrf_lvt'
+WVTH0      = '1.5530487e-008+dwvthprf_lvt-2.95276e-08*ff_flagrf_lvt+1.34216e-08*ss_flagrf_lvt-2.36221e-08*sf_flagrf_lvt+2.36221e-08*fs_flagrf_lvt'
+PVTH0      = '-1.3610101e-015+dpvthprf_lvt+2.90846e-15*ff_flagrf_lvt-1.32203e-15*ss_flagrf_lvt+2.32676e-15*sf_flagrf_lvt-2.32676e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2prf_lvt'
+LK2        = '2.4320462e-009+dlk2prf_lvt'
+WK2        = '1.9463059e-009+dwk2prf_lvt'
+PK2        = '3.0876379e-017+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.099571e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '1.7484688e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-4.8668363e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.078139928+dvoffprf_lvt-0.00704616*ff_flagrf_lvt-0.0210535*ss_flagrf_lvt-0.00217331*sf_flagrf_lvt+0.0120124*fs_flagrf_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffprf_lvt+6.94039e-10*ff_flagrf_lvt+2.07377e-09*ss_flagrf_lvt+2.14071e-10*sf_flagrf_lvt-1.18321e-09*fs_flagrf_lvt'
+WVOFF      = '1.0696929e-008+dwvoffprf_lvt-1.87903e-08*ff_flagrf_lvt+2.14746e-08*ss_flagrf_lvt-1.71796e-08*sf_flagrf_lvt+9.39513e-09*fs_flagrf_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffprf_lvt+1.85084e-15*ff_flagrf_lvt-2.11524e-15*ss_flagrf_lvt+1.6922e-15*sf_flagrf_lvt-9.25416e-16*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.110365*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0882879*sf_flagrf_lvt+0.70122*fs_flagrf_lvt'
+ETA0       = '0.90417384+deta0prf_lvt-0.00394754*ff_flagrf_lvt-0.0263169*ss_flagrf_lvt+0.0*sf_flagrf_lvt-0.0184218*fs_flagrf_lvt'
+LETA0      = '-1.7350444e-008+dleta0prf_lvt+3.88831e-10*ff_flagrf_lvt+2.59221e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.81455e-09*fs_flagrf_lvt'
+WETA0      = '-5.4555845e-007+dweta0prf_lvt+4.02649e-09*ff_flagrf_lvt+2.68433e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.87903e-08*fs_flagrf_lvt'
+PETA0      = '2.8823439e-014+dpeta0prf_lvt-3.96608e-16*ff_flagrf_lvt-2.64405e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt-1.85084e-15*fs_flagrf_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0prf_lvt-0.000313096*ff_flagrf_lvt+0.000193026*ss_flagrf_lvt-0.000250477*sf_flagrf_lvt+0.000234687*fs_flagrf_lvt'
+LU0        = '2.8823786e-010+dlu0prf_lvt+4.33987e-11*ff_flagrf_lvt+6.10414e-12*ss_flagrf_lvt+3.47189e-11*sf_flagrf_lvt-3.31636e-11*fs_flagrf_lvt'
+WU0        = '-1.1898039e-009+dwu0prf_lvt+1.6254e-10*ff_flagrf_lvt-6.14436e-10*ss_flagrf_lvt+1.30031e-10*sf_flagrf_lvt-1.13925e-10*fs_flagrf_lvt'
+PU0        = '-3.199222e-017+dpu0prf_lvt-2.37964e-17*ff_flagrf_lvt+4.49488e-17*ss_flagrf_lvt-1.90372e-17*sf_flagrf_lvt+1.74507e-17*fs_flagrf_lvt'
+UA         = '-7.9459861e-010+duaprf_lvt'
+LUA        = '6.5149733e-017+dluaprf_lvt'
+WUA        = '-5.5434195e-016+dwuaprf_lvt'
+PUA        = '-8.9895493e-025+dpuaprf_lvt'
+UB         = '1.6575544e-018+dubprf_lvt'
+LUB        = '-2.7481865e-026+dlubprf_lvt'
+WUB        = '2.6857637e-025+dwubprf_lvt'
+PUB        = '3.0456064e-035+dpubprf_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatprf_lvt-2249.67*ff_flagrf_lvt+17488*ss_flagrf_lvt-1799.74*sf_flagrf_lvt+1799.74*fs_flagrf_lvt'
+LVSAT      = '-0.0018446019+dlvsatprf_lvt+0.000221592*ff_flagrf_lvt-0.00172256*ss_flagrf_lvt+0.000177274*sf_flagrf_lvt-0.000177274*fs_flagrf_lvt'
+WVSAT      = '-0.0059053474+dwvsatprf_lvt+0.00402649*ff_flagrf_lvt-0.016106*ss_flagrf_lvt+0.00322119*sf_flagrf_lvt-0.00322119*fs_flagrf_lvt'
+PVSAT      = '5.8167672e-010+dpvsatprf_lvt-3.96609e-10*ff_flagrf_lvt+1.58643e-09*ss_flagrf_lvt-3.17287e-10*sf_flagrf_lvt+3.17287e-10*fs_flagrf_lvt'
+A0         = '-10.141985+da0prf_lvt'
+LA0        = '6.9068048e-007+dla0prf_lvt'
+WA0        = '2.5591493e-006+dwa0prf_lvt'
+PA0        = '-1.5863911e-013+dpa0prf_lvt'
+AGS        = '-8.9308661+dagsprf_lvt'
+LAGS       = '1.1732203e-006+dlagsprf_lvt'
+WAGS       = '6.1834266e-006+dwagsprf_lvt'
+PAGS       = '-5.4677612e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmprf_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmprf_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmprf_lvt'
+PPCLM      = '1.3219926e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flagrf_lvt-0.0210535*sf_flagrf_lvt+0.0210535*fs_flagrf_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flagrf_lvt+2.07377e-09*sf_flagrf_lvt-2.07377e-09*fs_flagrf_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flagrf_lvt+2.14746e-08*sf_flagrf_lvt-2.14746e-08*fs_flagrf_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flagrf_lvt-2.11524e-15*sf_flagrf_lvt+2.11524e-15*fs_flagrf_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+duteprf_lvt'
+UA1        = '1.22313e-009+dua1prf_lvt'
+LUA1       = '3.1354809e-018+dlua1prf_lvt'
+WUA1       = '-1.7551692e-017+dwua1prf_lvt'
+PUA1       = '2.7517381e-024+dpua1prf_lvt'
+UB1        = '-1.6557558e-018+dub1prf_lvt'
+LUB1       = '3.2084074e-028+dlub1prf_lvt'
+WUB1       = '-1.6570695e-025+dwub1prf_lvt'
+PUB1       = '1.3368954e-032+dpub1prf_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-1.08707e-08*ff_flagrf_lvt+0.0*ss_flagrf_lvt-8.69675e-09*sf_flagrf_lvt-6.90695e-08*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-8.05299e-07*ff_flagrf_lvt+0.0*ss_flagrf_lvt-6.44238e-07*sf_flagrf_lvt-1.6106e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.93218e-14*ff_flagrf_lvt+0.0*ss_flagrf_lvt+6.34573e-14*sf_flagrf_lvt+1.58643e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.06                    TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.00022                 
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.9                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.003                   FCS    = 0			   )

.MODEL pdio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.9                     TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.003                   
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf_lvt

.subckt pmos_rf_lvt_nw D G S B lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parp1rf_lvt  temp2=parp2rf_lvt
+fac1='0.870389*temp1*sigma+0.492365*temp2*sigma'
+fac2='0.870389*temp1*sigma-0.492365*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_lvt='(0.004252047-0.00028546287615/(lef*1e6)+0.0000152025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)+0.000032802452198*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_lvt = '0.00181396*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_lvt = '-0.00181396*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_lvt='0.00181396*geo_fac*toxprf_lvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1843.3*lr*scale/nr/(wr*scale)+0.4389)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.205e06/(lr*scale*1e6)+3.273e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4814'

.param fn_dice='noiseflagprf_lvt_mc*par1fn_mc+noiseflagprf_lvt_mc_mis*par2fprf_lvt_mc'    
.param c1fprf_lvt=5.00E+42           c2fprf_lvt=1.55E+24           c3fprf_lvt=1.00E+10    
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(2.3E-6*1E-6*1))**0.5)))'
.param noiaprf_lvt='c1fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noibprf_lvt='c2fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noicprf_lvt='c3fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_lvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '1.2831097e-009+dlvthprf_lvt'
+WVTH0      = '-1.3596429e-008+dwvthprf_lvt'
+PVTH0      = '4.6838072e-016+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2prf_lvt'
+LK2        = '4.6584946e-010+dlk2prf_lvt'
+WK2        = '-2.5582468e-009+dwk2prf_lvt'
+PK2        = '4.6843351e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitprf_lvt'
+LCIT       = '3.0389251e-010+dlcitprf_lvt'
+WCIT       = '1.5758347e-009+dwcitprf_lvt'
+PCIT       = '-1.8542906e-016+dpcitprf_lvt'
+VOFF       = '-0.076341704+dvoffprf_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffprf_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffprf_lvt'
+PVOFF      = '3.2068922e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.2908066+deta0prf_lvt'
+LETA0      = '-2.3078942e-013+dleta0prf_lvt'
+WETA0      = '1.9302674e-007+dweta0prf_lvt'
+PETA0      = '5.8675625e-019+dpeta0prf_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0prf_lvt-5.66666e-06*ff_flagrf_lvt+8.48339e-06*ss_flagrf_lvt-4.53333e-06*sf_flagrf_lvt+4.53333e-06*fs_flagrf_lvt'
+LU0        = '-1.9519503e-010+dlu0prf_lvt+5e-20*ff_flagrf_lvt-1.95194e-12*ss_flagrf_lvt+2.4e-19*sf_flagrf_lvt-2.4e-19*fs_flagrf_lvt'
+WU0        = '1.9415438e-009+dwu0prf_lvt+5.678e-11*ff_flagrf_lvt-8.50036e-11*ss_flagrf_lvt+4.5424e-11*sf_flagrf_lvt-4.5424e-11*fs_flagrf_lvt'
+PU0        = '-3.9117084e-017+dpu0prf_lvt-1e-24*ff_flagrf_lvt+1.95585e-17*ss_flagrf_lvt+3.2e-24*sf_flagrf_lvt-3.2e-24*fs_flagrf_lvt'
+UA         = '-6.2902859e-010+duaprf_lvt'
+LUA        = '-2.4675637e-017+dluaprf_lvt'
+WUA        = '3.9281125e-016+dwuaprf_lvt'
+PUA        = '-1.9206488e-023+dpuaprf_lvt'
+UB         = '1.9421977e-018+dubprf_lvt'
+LUB        = '-2.4060497e-026+dlubprf_lvt'
+WUB        = '-4.483143e-025+dwubprf_lvt'
+PUB        = '3.8556285e-032+dpubprf_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatprf_lvt'  A0         = '5.3771092+da0prf_lvt'
+LA0        = '-9.4373925e-007+dla0prf_lvt'
+WA0        = '-1.9768385e-006+dwa0prf_lvt'
+PA0        = '3.9606047e-013+dpa0prf_lvt'
+AGS        = '9.1959311+dagsprf_lvt'
+LAGS       = '-5.1830021e-007+dlagsprf_lvt'
+WAGS       = '1.247831e-006+dwagsprf_lvt'
+PAGS       = '-1.5646833e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmprf_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+duteprf_lvt'
+LUTE       = '-2.8693669e-009+dluteprf_lvt'
+WUTE       = '-2.918889e-007+dwuteprf_lvt'
+PUTE       = '2.8751056e-014+dputeprf_lvt'
+UA1        = '1.3742656e-009+dua1prf_lvt'
+LUA1       = '2.3165574e-017+dlua1prf_lvt'
+WUA1       = '1.292132e-016+dwua1prf_lvt'
+PUA1       = '-4.7319897e-023+dpua1prf_lvt'
+UB1        = '-1.8019021e-018+dub1prf_lvt'
+LUB1       = '3.1767874e-026+dlub1prf_lvt'
+WUB1       = '-8.8236177e-026+dwub1prf_lvt'
+PUB1       = '-1.1654575e-032+dpub1prf_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datprf_lvt'
+LAT        = '-0.010013792+dlatprf_lvt'
+WAT        = '-0.0024820485+dwatprf_lvt'
+PAT        = '2.4448177e-010+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmprf_lvt'     PPCLM      = '0+dppclmprf_lvt'     LNFACTOR   = '0+dlnfactorprf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'  LVSAT      = '0+dlvsatprf_lvt'
+WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+(dvthprf_lvt+vthmisprf_lvt)-0.0126208*ff_flagrf_lvt+0.0275506*ss_flagrf_lvt-0.00555994*sf_flagrf_lvt+0.00555994*fs_flagrf_lvt'
+LVTH0      = '-1.5409072e-009+dlvthprf_lvt+1.24315e-09*ff_flagrf_lvt-2.71373e-09*ss_flagrf_lvt+5.47654e-10*sf_flagrf_lvt-5.47654e-10*fs_flagrf_lvt'
+WVTH0      = '-9.5700168e-009+dwvthprf_lvt-9.64051e-09*ff_flagrf_lvt-3.85616e-09*ss_flagrf_lvt-1.23398e-08*sf_flagrf_lvt+1.23398e-08*fs_flagrf_lvt'
+PVTH0      = '7.1779158e-017+dpvthprf_lvt+9.49589e-16*ff_flagrf_lvt+3.79834e-16*ss_flagrf_lvt+1.21547e-15*sf_flagrf_lvt-1.21547e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2prf_lvt'
+LK2        = '2.3040232e-009+dlk2prf_lvt'
+WK2        = '5.5823676e-010+dwk2prf_lvt'
+PK2        = '1.6145988e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.5104142e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '6.1284302e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-9.0574373e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.081864514+dvoffprf_lvt-0.0481515*ff_flagrf_lvt+0.0567087*ss_flagrf_lvt-0.0356506*sf_flagrf_lvt+0.0354005*fs_flagrf_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffprf_lvt+4.7429e-09*ff_flagrf_lvt-5.58579e-09*ss_flagrf_lvt+3.51158e-09*sf_flagrf_lvt-3.48694e-09*fs_flagrf_lvt'
+WVOFF      = '1.4496007e-008+dwvoffprf_lvt+2.31371e-08*ff_flagrf_lvt-5.78429e-08*ss_flagrf_lvt+1.69672e-08*sf_flagrf_lvt-1.44607e-08*fs_flagrf_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffprf_lvt-2.27901e-15*ff_flagrf_lvt+5.69751e-15*ss_flagrf_lvt-1.67127e-15*sf_flagrf_lvt+1.42438e-15*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.0769699*ff_flagrf_lvt-0.756116*ss_flagrf_lvt+0.061576*sf_flagrf_lvt-0.061576*fs_flagrf_lvt'
+ETA0       = '-0.13126921+deta0prf_lvt+0.0945146*ff_flagrf_lvt-0.0945146*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LETA0      = '4.1574237e-008+dleta0prf_lvt-9.30966e-09*ff_flagrf_lvt+9.30966e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WETA0      = '5.1059346e-007+dweta0prf_lvt-9.64048e-08*ff_flagrf_lvt+9.64048e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PETA0      = '-3.1279736e-014+dpeta0prf_lvt+9.49585e-15*ff_flagrf_lvt-9.49585e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0prf_lvt+0.000206454*ff_flagrf_lvt-0.00127681*ss_flagrf_lvt+8.95511e-05*sf_flagrf_lvt-1.39395e-05*fs_flagrf_lvt'
+LU0        = '2.1404963e-010+dlu0prf_lvt-2.08938e-11*ff_flagrf_lvt+1.24649e-10*ss_flagrf_lvt-9.26729e-12*sf_flagrf_lvt+1.81956e-12*fs_flagrf_lvt'
+WU0        = '1.1009666e-009+dwu0prf_lvt-3.67401e-10*ff_flagrf_lvt+8.848e-10*ss_flagrf_lvt-2.16797e-10*sf_flagrf_lvt+1.39673e-10*fs_flagrf_lvt'
+PU0        = '4.3679771e-017+dpu0prf_lvt+4.17817e-17*ff_flagrf_lvt-7.59665e-17*ss_flagrf_lvt+2.58287e-17*sf_flagrf_lvt-1.8232e-17*fs_flagrf_lvt'
+UA         = '-1.3371304e-009+duaprf_lvt'
+LUA        = '4.5072393e-017+dluaprf_lvt'
+WUA        = '-9.5951684e-019+dwuaprf_lvt'
+PUA        = '1.9579932e-023+dpuaprf_lvt'
+UB         = '1.6937477e-018+dubprf_lvt'
+LUB        = '4.118249e-028+dlubprf_lvt'
+WUB        = '2.3165923e-025+dwubprf_lvt'
+PUB        = '-2.8421107e-032+dpubprf_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatprf_lvt-192.425*ff_flagrf_lvt+5478.45*ss_flagrf_lvt-153.94*sf_flagrf_lvt+153.94*fs_flagrf_lvt'
+LVSAT      = '0.00071788404+dlvsatprf_lvt+1.89538e-05*ff_flagrf_lvt-0.000539625*ss_flagrf_lvt+1.5163e-05*sf_flagrf_lvt-1.5163e-05*fs_flagrf_lvt'
+WVSAT      = '0.02063004+dwvsatprf_lvt+0.0019281*ff_flagrf_lvt-0.00385619*ss_flagrf_lvt+0.00154248*sf_flagrf_lvt-0.00154248*fs_flagrf_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatprf_lvt-1.89917e-10*ff_flagrf_lvt+3.79834e-10*ss_flagrf_lvt-1.51934e-10*sf_flagrf_lvt+1.51934e-10*fs_flagrf_lvt'
+A0         = '-14.929677+da0prf_lvt'
+LA0        = '1.0564791e-006+dla0prf_lvt'
+WA0        = '7.4425951e-006+dwa0prf_lvt'
+PA0        = '-5.3175373e-013+dpa0prf_lvt'
+AGS        = '-4.6385162+dagsprf_lvt'
+LAGS       = '8.4439285e-007+dlagsprf_lvt'
+WAGS       = '1.8052297e-006+dwagsprf_lvt'
+PAGS       = '-2.1137211e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmprf_lvt'
+LPCLM      = '-5.758458e-008+dlpclmprf_lvt'
+WPCLM      = '9.6402055e-008+dwpclmprf_lvt'
+PPCLM      = '-9.4956024e-015+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2prf_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+duteprf_lvt'
+UA1        = '2.2956478e-009+dua1prf_lvt'
+LUA1       = '-6.7590577e-017+dlua1prf_lvt'
+WUA1       = '-1.1115199e-015+dwua1prf_lvt'
+PUA1       = '7.4892317e-023+dpua1prf_lvt'
+UB1        = '-1.2411257e-018+dub1prf_lvt'
+LUB1       = '-2.3468592e-026+dlub1prf_lvt'
+WUB1       = '-5.8862958e-025+dwub1prf_lvt'
+PUB1       = '3.7634175e-032+dpub1prf_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-7.58152e-09*ff_flagrf_lvt+7.44773e-08*ss_flagrf_lvt-6.06521e-09*sf_flagrf_lvt+6.06521e-09*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-7.71239e-07*ff_flagrf_lvt+7.71239e-07*ss_flagrf_lvt-6.16991e-07*sf_flagrf_lvt+6.16991e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.59668e-14*ff_flagrf_lvt-7.59668e-14*ss_flagrf_lvt+6.07734e-14*sf_flagrf_lvt-6.07734e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '2.6146736e-011+dlvthprf_lvt'
+WVTH0      = '-1.6058274e-008+dwvthprf_lvt'
+PVTH0      = '1.7504829e-015+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2prf_lvt'
+LK2        = '5.5945104e-010+dlk2prf_lvt'
+WK2        = '-1.5266232e-009+dwk2prf_lvt'
+PK2        = '3.729599e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitprf_lvt'
+LCIT       = '-4.9918717e-012+dlcitprf_lvt'
+WCIT       = '-1.6353193e-009+dwcitprf_lvt'
+PCIT       = '1.2963301e-016+dpcitprf_lvt'
+VOFF       = '-0.082218583+dvoffprf_lvt'
+LVOFF      = '-4.857209e-009+dlvoffprf_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffprf_lvt'
+PVOFF      = '2.6897322e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.72801286+deta0prf_lvt'
+LETA0      = '1.4122934e-012+dleta0prf_lvt'
+WETA0      = '-2.5292365e-007+dweta0prf_lvt'
+PETA0      = '-1.0891883e-018+dpeta0prf_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0prf_lvt+0.0001275*ff_flagrf_lvt-0.000190876*ss_flagrf_lvt+0.000102*sf_flagrf_lvt-0.000102*fs_flagrf_lvt'
+LU0        = '-2.7091922e-010+dlu0prf_lvt+4.6e-17*ff_flagrf_lvt+4.39187e-11*ss_flagrf_lvt-2.3e-17*sf_flagrf_lvt+2.3e-17*fs_flagrf_lvt'
+WU0        = '-1.9016192e-009+dwu0prf_lvt-7.90503e-11*ff_flagrf_lvt+1.18343e-10*ss_flagrf_lvt-6.32397e-11*sf_flagrf_lvt+6.32397e-11*fs_flagrf_lvt'
+PU0        = '3.8121589e-017+dpu0prf_lvt+5e-24*ff_flagrf_lvt-2.72296e-17*ss_flagrf_lvt-3.6e-23*sf_flagrf_lvt+3.6e-23*fs_flagrf_lvt'
+UA         = '4.0037736e-010+duaprf_lvt'
+LUA        = '-5.25554e-017+dluaprf_lvt'
+WUA        = '-6.5718282e-016+dwuaprf_lvt'
+PUA        = '9.2308705e-024+dpuaprf_lvt'
+UB         = '1.3125234e-018+dubprf_lvt'
+LUB        = '6.503691e-027+dlubprf_lvt'
+WUB        = '1.9395346e-025+dwubprf_lvt'
+PUB        = '7.3808134e-033+dpubprf_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatprf_lvt'  A0         = '4.8804857+da0prf_lvt'
+LA0        = '-7.8903284e-007+dla0prf_lvt'
+WA0        = '-1.4702825e-006+dwa0prf_lvt'
+PA0        = '2.3825993e-013+dpa0prf_lvt'
+AGS        = '13.322597+dagsprf_lvt'
+LAGS       = '-1.0187458e-006+dlagsprf_lvt'
+WAGS       = '-2.9613684e-006+dwagsprf_lvt'
+PAGS       = '3.5398618e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmprf_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmprf_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmprf_lvt'
+PPCLM      = '-1.3614853e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2prf_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+duteprf_lvt'
+LUTE       = '9.5674269e-009+dluteprf_lvt'
+WUTE       = '-1.6310179e-007+dwuteprf_lvt'
+PUTE       = '1.6065527e-014+dputeprf_lvt'
+UA1        = '2.0289308e-009+dua1prf_lvt'
+LUA1       = '-7.6235902e-017+dlua1prf_lvt'
+WUA1       = '-5.385453e-016+dwua1prf_lvt'
+PUA1       = '5.4069609e-023+dpua1prf_lvt'
+UB1        = '-2.1814336e-018+dub1prf_lvt'
+LUB1       = '5.2100107e-026+dlub1prf_lvt'
+WUB1       = '2.9888601e-025+dwub1prf_lvt'
+PUB1       = '-3.2393453e-032+dpub1prf_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datprf_lvt'
+LAT        = '-0.017286299+dlatprf_lvt'
+WAT        = '-0.077791263+dwatprf_lvt'
+PAT        = '7.6624394e-009+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_lvt'  WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'
+LVSAT      = '0+dlvsatprf_lvt'     WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+(dvthprf_lvt+vthmisprf_lvt)+0.00687633*ff_flagrf_lvt+0.0106116*ss_flagrf_lvt+0.0055011*sf_flagrf_lvt-0.0055011*fs_flagrf_lvt'
+LVTH0      = '-1.3621188e-010+dlvthprf_lvt-6.77323e-10*ff_flagrf_lvt-1.04524e-09*ss_flagrf_lvt-5.41853e-10*sf_flagrf_lvt+5.41853e-10*fs_flagrf_lvt'
+WVTH0      = '1.5530487e-008+dwvthprf_lvt-2.95276e-08*ff_flagrf_lvt+1.34216e-08*ss_flagrf_lvt-2.36221e-08*sf_flagrf_lvt+2.36221e-08*fs_flagrf_lvt'
+PVTH0      = '-1.3610101e-015+dpvthprf_lvt+2.90846e-15*ff_flagrf_lvt-1.32203e-15*ss_flagrf_lvt+2.32676e-15*sf_flagrf_lvt-2.32676e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2prf_lvt'
+LK2        = '2.4320462e-009+dlk2prf_lvt'
+WK2        = '1.9463059e-009+dwk2prf_lvt'
+PK2        = '3.0876379e-017+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.099571e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '1.7484688e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-4.8668363e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.078139928+dvoffprf_lvt-0.00704616*ff_flagrf_lvt-0.0210535*ss_flagrf_lvt-0.00217331*sf_flagrf_lvt+0.0120124*fs_flagrf_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffprf_lvt+6.94039e-10*ff_flagrf_lvt+2.07377e-09*ss_flagrf_lvt+2.14071e-10*sf_flagrf_lvt-1.18321e-09*fs_flagrf_lvt'
+WVOFF      = '1.0696929e-008+dwvoffprf_lvt-1.87903e-08*ff_flagrf_lvt+2.14746e-08*ss_flagrf_lvt-1.71796e-08*sf_flagrf_lvt+9.39513e-09*fs_flagrf_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffprf_lvt+1.85084e-15*ff_flagrf_lvt-2.11524e-15*ss_flagrf_lvt+1.6922e-15*sf_flagrf_lvt-9.25416e-16*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.110365*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0882879*sf_flagrf_lvt+0.70122*fs_flagrf_lvt'
+ETA0       = '0.90417384+deta0prf_lvt-0.00394754*ff_flagrf_lvt-0.0263169*ss_flagrf_lvt+0.0*sf_flagrf_lvt-0.0184218*fs_flagrf_lvt'
+LETA0      = '-1.7350444e-008+dleta0prf_lvt+3.88831e-10*ff_flagrf_lvt+2.59221e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.81455e-09*fs_flagrf_lvt'
+WETA0      = '-5.4555845e-007+dweta0prf_lvt+4.02649e-09*ff_flagrf_lvt+2.68433e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.87903e-08*fs_flagrf_lvt'
+PETA0      = '2.8823439e-014+dpeta0prf_lvt-3.96608e-16*ff_flagrf_lvt-2.64405e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt-1.85084e-15*fs_flagrf_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0prf_lvt-0.000313096*ff_flagrf_lvt+0.000193026*ss_flagrf_lvt-0.000250477*sf_flagrf_lvt+0.000234687*fs_flagrf_lvt'
+LU0        = '2.8823786e-010+dlu0prf_lvt+4.33987e-11*ff_flagrf_lvt+6.10414e-12*ss_flagrf_lvt+3.47189e-11*sf_flagrf_lvt-3.31636e-11*fs_flagrf_lvt'
+WU0        = '-1.1898039e-009+dwu0prf_lvt+1.6254e-10*ff_flagrf_lvt-6.14436e-10*ss_flagrf_lvt+1.30031e-10*sf_flagrf_lvt-1.13925e-10*fs_flagrf_lvt'
+PU0        = '-3.199222e-017+dpu0prf_lvt-2.37964e-17*ff_flagrf_lvt+4.49488e-17*ss_flagrf_lvt-1.90372e-17*sf_flagrf_lvt+1.74507e-17*fs_flagrf_lvt'
+UA         = '-7.9459861e-010+duaprf_lvt'
+LUA        = '6.5149733e-017+dluaprf_lvt'
+WUA        = '-5.5434195e-016+dwuaprf_lvt'
+PUA        = '-8.9895493e-025+dpuaprf_lvt'
+UB         = '1.6575544e-018+dubprf_lvt'
+LUB        = '-2.7481865e-026+dlubprf_lvt'
+WUB        = '2.6857637e-025+dwubprf_lvt'
+PUB        = '3.0456064e-035+dpubprf_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatprf_lvt-2249.67*ff_flagrf_lvt+17488*ss_flagrf_lvt-1799.74*sf_flagrf_lvt+1799.74*fs_flagrf_lvt'
+LVSAT      = '-0.0018446019+dlvsatprf_lvt+0.000221592*ff_flagrf_lvt-0.00172256*ss_flagrf_lvt+0.000177274*sf_flagrf_lvt-0.000177274*fs_flagrf_lvt'
+WVSAT      = '-0.0059053474+dwvsatprf_lvt+0.00402649*ff_flagrf_lvt-0.016106*ss_flagrf_lvt+0.00322119*sf_flagrf_lvt-0.00322119*fs_flagrf_lvt'
+PVSAT      = '5.8167672e-010+dpvsatprf_lvt-3.96609e-10*ff_flagrf_lvt+1.58643e-09*ss_flagrf_lvt-3.17287e-10*sf_flagrf_lvt+3.17287e-10*fs_flagrf_lvt'
+A0         = '-10.141985+da0prf_lvt'
+LA0        = '6.9068048e-007+dla0prf_lvt'
+WA0        = '2.5591493e-006+dwa0prf_lvt'
+PA0        = '-1.5863911e-013+dpa0prf_lvt'
+AGS        = '-8.9308661+dagsprf_lvt'
+LAGS       = '1.1732203e-006+dlagsprf_lvt'
+WAGS       = '6.1834266e-006+dwagsprf_lvt'
+PAGS       = '-5.4677612e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmprf_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmprf_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmprf_lvt'
+PPCLM      = '1.3219926e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flagrf_lvt-0.0210535*sf_flagrf_lvt+0.0210535*fs_flagrf_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flagrf_lvt+2.07377e-09*sf_flagrf_lvt-2.07377e-09*fs_flagrf_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flagrf_lvt+2.14746e-08*sf_flagrf_lvt-2.14746e-08*fs_flagrf_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flagrf_lvt-2.11524e-15*sf_flagrf_lvt+2.11524e-15*fs_flagrf_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+duteprf_lvt'
+UA1        = '1.22313e-009+dua1prf_lvt'
+LUA1       = '3.1354809e-018+dlua1prf_lvt'
+WUA1       = '-1.7551692e-017+dwua1prf_lvt'
+PUA1       = '2.7517381e-024+dpua1prf_lvt'
+UB1        = '-1.6557558e-018+dub1prf_lvt'
+LUB1       = '3.2084074e-028+dlub1prf_lvt'
+WUB1       = '-1.6570695e-025+dwub1prf_lvt'
+PUB1       = '1.3368954e-032+dpub1prf_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-1.08707e-08*ff_flagrf_lvt+0.0*ss_flagrf_lvt-8.69675e-09*sf_flagrf_lvt-6.90695e-08*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-8.05299e-07*ff_flagrf_lvt+0.0*ss_flagrf_lvt-6.44238e-07*sf_flagrf_lvt-1.6106e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.93218e-14*ff_flagrf_lvt+0.0*ss_flagrf_lvt+6.34573e-14*sf_flagrf_lvt+1.58643e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.06                    TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.00022                 
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.9                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.003                   FCS    = 0			   )

.MODEL pdio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.9                     TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.003                   
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.ends pmos_rf_lvt_nw


.subckt nmos_rf_lvt_6t D G S B NG PG lr=0.06E-6 wr=1E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parn1rf_lvt  temp2=parn2rf_lvt
+fac1='0.498419*temp1*sigma+0.866936*temp2*sigma'
+fac2='0.498419*temp1*sigma-0.866936*temp2*sigma'
.param  lef='lr*scale-1e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_lvt='(0.00386541332-0/(lef*1e6)+0.00000403525807/(lef*lef*1e12)+0.00000587615/(wef*wef*1e12)-0.0002168162130245*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_lvt='0.00177811*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_lvt='-0.00177811*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_lvt='0.00177811*geo_fac*toxnrf_lvt*fac2*mismatchflag' 
**********************
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1533*lr*scale/nr/(wr*scale)+2.215)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.349e05/(lr*scale*1e6)+1.651e07'
.param rnoiax='0.0184/(lr*scale*1e6)+0.4433'

.param fn_dice='noiseflagnrf_lvt_mc*par1fn_mc+noiseflagnrf_lvt_mc_mis*par2fnrf_lvt_mc'
.param c1fnrf_lvt=7.05E+41           c2fnrf_lvt=1.00E+23           c3fnrf_lvt=1.00E+7       
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.35*log(((wr*scale*lr*scale*nr)/(15.2E-6*1E-6*1))**0.5)))'
.param noianrf_lvt='c1fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'
.param noibnrf_lvt='c2fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'
.param noicnrf_lvt='c3fnrf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_lvt    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_lvt  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************


**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx    
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx
M0 DI GI SI BI nch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_lvt.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28615208+(dvthnrf_lvt+vthmisnrf_lvt)'
+LVTH0      = '-4.9983609e-009+dlvthnrf_lvt'
+WVTH0      = '8.4242078e-009+dwvthnrf_lvt'
+PVTH0      = '8.3105172e-018+dpvthnrf_lvt'
+K1         = 0.217               K2         = '0.027871333+dk2nrf_lvt'
+LK2        = '-4.0423516e-009+dlk2nrf_lvt'
+WK2        = '-6.7154904e-009+dwk2nrf_lvt'
+PK2        = '1.4392454e-015+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '0.00018742511+dcitnrf_lvt'
+LCIT       = '3.0832369e-011+dlcitnrf_lvt'
+WCIT       = '-1.0498717e-009+dwcitnrf_lvt'
+PCIT       = '1.8757092e-016+dpcitnrf_lvt'
+VOFF       = '-0.10966747+dvoffnrf_lvt'
+LVOFF      = '-3.4577165e-009+dlvoffnrf_lvt'
+WVOFF      = '-2.4677729e-008+dwvoffnrf_lvt'
+PVOFF      = '2.7504967e-015+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt'   ETA0       = '0.48915055+deta0nrf_lvt'
+LETA0      = '8.164015e-013+dleta0nrf_lvt'
+WETA0      = '-3.2518884e-007+dweta0nrf_lvt'
+PETA0      = '-3.586356e-019+dpeta0nrf_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.016001195+du0nrf_lvt'
+LU0        = '-1.0640471e-010+dlu0nrf_lvt'
+WU0        = '-2.3370167e-010+dwu0nrf_lvt'
+PU0        = '-2.0820372e-016+dpu0nrf_lvt'
+UA         = '-1.9487815e-009+duanrf_lvt'
+LUA        = '9.7958842e-018+dluanrf_lvt'
+WUA        = '4.9434163e-017+dwuanrf_lvt'
+PUA        = '-7.127695e-024+dpuanrf_lvt'
+UB         = '2.4060267e-018+dubnrf_lvt'
+LUB        = '-2.8382073e-026+dlubnrf_lvt'
+WUB        = '-4.3713318e-026+dwubnrf_lvt'
+PUB        = '-1.7322291e-032+dpubnrf_lvt'
+UC         = 7.6073046e-011      LUC        = -4.6675362e-018     WUC        = -4.3439813e-017
+PUC        = 2.9598691e-024      VSAT       = '103154.99+dvsatnrf_lvt'
+LVSAT      = '-0.00071927513+dlvsatnrf_lvt'
+WVSAT      = '0.00032910066+dwvsatnrf_lvt'
+PVSAT      = '-7.5028368e-011+dpvsatnrf_lvt'
+A0         = 4.9425076           LA0        = -8.0762088e-007     WA0        = -5.2656106e-007
+PA0        = 1.2004539e-013      AGS        = -2.8687863          LAGS       = 9.4523235e-007
+WAGS       = 3.9167033e-007      PAGS       = -3.7514184e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.067891169        LKETA      = 9.527125e-009       WKETA      = 1.7919753e-008
+PKETA      = -2.9617448e-015     DWG        = 0                   DWB        = 0
+PCLM       = 0.99881327          LPCLM      = -5.7657191e-008     WPCLM      = 4.7741724e-008
+PPCLM      = -1.5380816e-015     PDIBLC1    = 0                   PDIBLC2    = -0.0030506425
+LPDIBLC2   = 2.69563e-009        WPDIBLC2   = -2.6653099e-009     PPDIBLC2   = 1.1254255e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswnrf_lvt'
+RDW        = '65+drdswnrf_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxnrf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgonrf_lvt'
+CGDO       = 'cgonrf_lvt'          CGBO       = 0                   CGDL       = 'cglnrf_lvt'
+CGSL       = 'cglnrf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.0012247098        LTVOFF     = -4.0437533e-011
+WTVOFF     = -8.5203632e-010     PTVOFF     = 6.4411854e-017      KT1        = '-0.22886246+dkt1nrf_lvt'
+LKT1       = '-2.9759694e-009+dlkt1nrf_lvt'
+WKT1       = '-1.5659777e-008+dwkt1nrf_lvt'
+PKT1       = '1.5829485e-015+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.075879437        LKT2       = 2.7043071e-009
+WKT2       = -4.2088909e-009     PKT2       = -1.2004539e-016     UTE        = -1.0844779
+LUTE       = 8.0912946e-009      WUTE       = 8.6167473e-008      PUTE       = -8.2531205e-015
+UA1        = '1.5080138e-009+dua1nrf_lvt'
+LUA1       = '-5.391282e-017+dlua1nrf_lvt'
+WUA1       = '-7.8827717e-017+dwua1nrf_lvt'
+PUA1       = '7.6153794e-024+dpua1nrf_lvt'
+UB1        = '-1.0938144e-018+dub1nrf_lvt'
+LUB1       = '4.8968935e-026+dlub1nrf_lvt'
+WUB1       = '2.5217669e-026+dwub1nrf_lvt'
+PUB1       = '-5.550805e-032+dpub1nrf_lvt'
+UC1        = 1.0838036e-010      LUC1       = -6.0210332e-018     WUC1       = -6.1438819e-017
+PUC1       = 8.9583872e-024      PRT        = 0                   AT         = 8000.1333
+WAT        = 0.022643864
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt'  WNFACTOR   = '0+dwnfactornrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+WMIN       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.23439418+(dvthnrf_lvt+vthmisnrf_lvt)+0.000545158*ff_flagrf_lvt-0.000545158*ss_flagrf_lvt'
+LVTH0      = '-4.0988817e-011+dlvthnrf_lvt-5.22149e-11*ff_flagrf_lvt+5.22149e-11*ss_flagrf_lvt'
+WVTH0      = '1.260777e-009+dwvthnrf_lvt-5.46248e-09*ff_flagrf_lvt+5.46248e-09*ss_flagrf_lvt'
+PVTH0      = '6.9442391e-016+dpvthnrf_lvt+5.23193e-16*ff_flagrf_lvt-5.23193e-16*ss_flagrf_lvt'
+K1         = 0.217               K2         = '-0.030127783+dk2nrf_lvt'
+LK2        = '1.5128037e-009+dlk2nrf_lvt'
+WK2        = '5.8489997e-009+dwk2nrf_lvt'
+PK2        = '2.3581857e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '-0.0025254154+dcitnrf_lvt'
+LCIT       = '2.9066824e-010+dlcitnrf_lvt'
+WCIT       = '4.0039237e-009+dwcitnrf_lvt'
+PCIT       = '-2.964816e-016+dpcitnrf_lvt'
+VOFF       = '-0.099451744+dvoffnrf_lvt'
+LVOFF      = '-4.436179e-009+dlvoffnrf_lvt'
+WVOFF      = '9.4170876e-009+dwvoffnrf_lvt'
+PVOFF      = '-5.1510487e-016+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt-0.357025*ss_flagrf_lvt'
+ETA0       = '0.48409488+deta0nrf_lvt-0.00181719*ff_flagrf_lvt'
+LETA0      = '4.8504901e-010+dleta0nrf_lvt+1.7405e-10*ff_flagrf_lvt'
+WETA0      = '-8.1020112e-007+dweta0nrf_lvt+1.82083e-08*ff_flagrf_lvt'
+PETA0      = '4.6454117e-014+dpeta0nrf_lvt-1.74398e-15*ff_flagrf_lvt'
+ETAB       = -0.018461361
+Petab    = 8.719881e-16
+Letab    = 1.4487063e-09
+WETAB      = -3.1068909e-08
+UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010669839+du0nrf_lvt'
+LU0        = '4.0423259e-010+dlu0nrf_lvt'
+WU0        = '-1.5698813e-009+dwu0nrf_lvt'
+PU0        = '-8.0224433e-017+dpu0nrf_lvt'
+UA         = '-2.4269058e-009+duanrf_lvt'
+LUA        = '5.5590629e-017+dluanrf_lvt'
+WUA        = '-2.9161008e-016+dwuanrf_lvt'
+PUA        = '2.5537523e-023+dpuanrf_lvt'
+UB         = '2.2307279e-018+dubnrf_lvt'
+LUB        = '-1.1591957e-026+dlubnrf_lvt'
+WUB        = '4.6418333e-025+dwubnrf_lvt'
+PUB        = '-6.5968632e-032+dpubnrf_lvt'
+UC         = 6.6545728e-11
+LUC        = -3.7549892e-18
+WUC        = -1.945144e-18
+PUC        = -1.0144903e-24
+VSAT       = '99160.041+dvsatnrf_lvt+1071.07*ss_flagrf_lvt'
+LVSAT      = '-0.00033663866+dlvsatnrf_lvt-0.000102587*ss_flagrf_lvt'
+WVSAT      = '0.0061008173+dwvsatnrf_lvt-0.0010925*ss_flagrf_lvt'
+PVSAT      = '-6.2784339e-010+dpvsatnrf_lvt+1.04639e-10*ss_flagrf_lvt'
+A0         = -2.4893169          LA0        = -9.5800729e-008     WA0        = 7.1278269e-008
+PA0        = 6.2784339e-014      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = 0.0036497472        LKETA      = 2.6749361e-009
+WKETA      = -7.1360839e-008     PKETA      = 5.5895502e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.38255683          LPCLM      = 1.3678505e-009
+WPCLM      = 4.6250034e-008      PPCLM      = -1.3952075e-015     PDIBLC1    = 0
+PDIBLC2    = 0.030053261         LPDIBLC2   = -4.7506186e-010     WPDIBLC2   = 2.3651594e-008
+PPDIBLC2   = -1.3952075e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0016506047
+LTVOFF     = -8.1229742e-011     WTVOFF     = -2.164082e-009      PTVOFF     = 1.9007959e-016
+KT1        = '-0.19451937+dkt1nrf_lvt'
+LKT1       = '-6.2653157e-09+dlkt1nrf_lvt'
+WKT1       = '-1.1213008e-07+dwkt1nrf_lvt'
+PKT1       = '1.0822839e-14+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.044506216        LKT2       = -3.0061996e-010
+WKT2       = -7.0281664e-009     PKT2       = 1.4998481e-016      UTE        = 0.66554152
+LUTE       = -1.5952557e-007     WUTE       = -1.6988524e-006     PUTE       = 1.6271608e-013
+UA1        = '3.4887539e-009+dua1nrf_lvt'
+LUA1       = '-2.436281e-016+dlua1nrf_lvt'
+WUA1       = '-1.7757392e-015+dwua1nrf_lvt'
+PUA1       = '1.7014556e-022+dpua1nrf_lvt'
+UB1        = '-9.5527444e-019+dub1nrf_lvt'
+LUB1       = '3.5699574e-026+dlub1nrf_lvt'
+WUB1       = '-1.5640491e-024+dwub1nrf_lvt'
+PUB1       = '9.6711924e-032+dpub1nrf_lvt'
+UC1        = -4.3940601e-11
+LUC1       = 8.5681829e-18
+WUC1       = 9.6239901e-17
+PUC1       = -6.144046e-24
+PRT        = 0                   AT         = -40423.746
+LAT        = 0.0046380392        WAT        = 0.072036221         PAT        = -4.7307999e-009
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0
+CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0
+CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0
+CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt+3.41956e-08*ss_flagrf_lvt'
+WNFACTOR   = '0+dwnfactornrf_lvt+3.64165e-07*ss_flagrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt-3.48795e-14*ss_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.3 NMOS	(	LEVEL      = 54                  
+LMIN       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30139764+(dvthnrf_lvt+vthmisnrf_lvt)'
+LVTH0      = '-5.9798022e-009+dlvthnrf_lvt'
+WVTH0      = '-7.126262e-009+dwvthnrf_lvt'
+PVTH0      = '1.0093807e-015+dpvthnrf_lvt'
+K1         = 0.217               K2         = '0.022481655+dk2nrf_lvt'
+LK2        = '-3.1848829e-009+dlk2nrf_lvt'
+WK2        = '-1.2180193e-009+dwk2nrf_lvt'
+PK2        = '5.6462745e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '-0.0012641596+dcitnrf_lvt'
+LCIT       = '2.4032731e-010+dlcitnrf_lvt'
+WCIT       = '4.3074477e-010+dwcitnrf_lvt'
+PCIT       = '-2.6113916e-017+dpcitnrf_lvt'
+VOFF       = '-0.1452694+dvoffnrf_lvt'
+LVOFF      = '1.8390894e-010+dlvoffnrf_lvt'
+WVOFF      = '1.1636233e-008+dwvoffnrf_lvt'
+PVOFF      = '-9.6396125e-016+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt'   ETA0       = '0.1243618+deta0nrf_lvt'
+LETA0      = '1.1852348e-012+dleta0nrf_lvt'
+WETA0      = '4.6895683e-008+dweta0nrf_lvt'
+PETA0      = '-7.3484559e-019+dpeta0nrf_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017962484+du0nrf_lvt'
+LU0        = '-3.540492e-010+dlu0nrf_lvt'
+WU0        = '-2.2342161e-009+dwu0nrf_lvt'
+PU0        = '4.4393657e-017+dpu0nrf_lvt'
+UA         = '-1.8908752e-009+duanrf_lvt'
+LUA        = '1.1256568e-017+dluanrf_lvt'
+WUA        = '-9.6302274e-018+dwuanrf_lvt'
+PUA        = '-8.6175922e-024+dpuanrf_lvt'
+UB         = '2.5042067e-018+dubnrf_lvt'
+LUB        = '-6.1909735e-026+dlubnrf_lvt'
+WUB        = '-1.4385689e-025+dwubnrf_lvt'
+PUB        = '1.6875925e-032+dpubnrf_lvt'
+UC         = 1.7203086e-011      LUC        = 5.9990981e-019      WUC        = 1.6607546e-017
+PUC        = -2.4129258e-024     VSAT       = '98536.493+dvsatnrf_lvt'
+LVSAT      = '0.00033365028+dlvsatnrf_lvt'
+WVSAT      = '0.0050399697+dwvsatnrf_lvt'
+PVSAT      = '-1.1490123e-009+dpvsatnrf_lvt'
+A0         = 4.7238631           LA0        = -7.577743e-007      WA0        = -3.0354363e-007
+PA0        = 6.9201876e-014      AGS        = -2.4847958          LAGS       = 9.0845374e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.038058485        LKETA      = 6.5978517e-009
+WKETA      = -1.2509585e-008     PKETA      = 2.6113916e-017      DWG        = 0
+DWB        = 0                   PCLM       = 1.2105486           LPCLM      = -8.9733757e-008
+WPCLM      = -1.6822835e-007     PPCLM      = 3.1180015e-014      PDIBLC1    = 0
+PDIBLC2    = -0.0237901          LPDIBLC2   = 6.1646019e-009      WPDIBLC2   = 1.8488936e-008
+PPDIBLC2   = -2.4129258e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00034240366
+LTVOFF     = 6.833389e-011       WTVOFF     = 4.7915972e-011      PTVOFF     = -4.6534998e-017
+KT1        = '-0.26987595+dkt1nrf_lvt'
+LKT1       = '7.5090358e-009+dlkt1nrf_lvt'
+WKT1       = '2.6173983e-008+dwkt1nrf_lvt'
+PKT1       = '-9.1117568e-015+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.10692445         LKT2       = 5.9071791e-009
+WKT2       = 2.7457026e-008      PKT2       = -3.3869749e-015     UTE        = -1
+UA1        = '1.5826054e-009+dua1nrf_lvt'
+LUA1       = '-5.1387925e-017+dlua1nrf_lvt'
+WUA1       = '-1.5491114e-016+dwua1nrf_lvt'
+PUA1       = '5.0399857e-024+dpua1nrf_lvt'
+UB1        = '-9.7987827e-019+dub1nrf_lvt'
+LUB1       = '-6.116809e-026+dlub1nrf_lvt'
+WUB1       = '-9.0997215e-026+dwub1nrf_lvt'
+PUB1       = '5.6831715e-032+dpub1nrf_lvt'
+UC1        = 4.047626e-011       LUC1       = 9.7330908e-018      WUC1       = 7.8233597e-018
+PUC1       = -7.1108192e-024     PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt'  WNFACTOR   = '0+dwnfactornrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_lvt.4 NMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.99984e-008-(dxlnrf_lvt+dlmisnrf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwnrf_lvt+dwmisnrf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_lvt+toxmisnrf_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxlnrf_lvt+dlmisnrf_lvt)'   XW         = '2e-08+(dxwnrf_lvt+dwmisnrf_lvt)'
+DLC        = '-5.415E-09+ddlcnrf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.25840312+(dvthnrf_lvt+vthmisnrf_lvt)-0.012266*ff_flagrf_lvt+0.012266*ss_flagrf_lvt'
+LVTH0      = '-1.8617867e-009+dlvthnrf_lvt+1.17483e-09*ff_flagrf_lvt-1.17483e-09*ss_flagrf_lvt'
+WVTH0      = '-2.3228341e-008+dwvthnrf_lvt+7.60495e-09*ff_flagrf_lvt-7.60495e-09*ss_flagrf_lvt'
+PVTH0      = '2.5516377e-015+dpvthnrf_lvt-7.28397e-16*ff_flagrf_lvt+7.28397e-16*ss_flagrf_lvt'
+K1         = 0.217               K2         = '-0.025394525+dk2nrf_lvt'
+LK2        = '1.4006976e-009+dlk2nrf_lvt'
+WK2        = '1.0210766e-009+dwk2nrf_lvt'
+PK2        = '3.5016685e-016+dpk2nrf_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdnrf_lvt'     CIT        = '2.3457461e-006+dcitnrf_lvt'
+LCIT       = '1.1902142e-010+dlcitnrf_lvt'
+WCIT       = '1.4256073e-009+dwcitnrf_lvt'
+PCIT       = '-1.2140185e-016+dpcitnrf_lvt'
+VOFF       = '-0.1240989+dvoffnrf_lvt'
+LVOFF      = '-1.8438017e-009+dlvoffnrf_lvt'
+WVOFF      = '3.4557183e-008+dwvoffnrf_lvt'
+PVOFF      = '-3.1593298e-015+dpvoffnrf_lvt'
+NFACTOR    = '1+dnfactornrf_lvt-0.0994111*ss_flagrf_lvt'
+ETA0       = '-0.5294399+deta0nrf_lvt+0.0408868*ff_flagrf_lvt'
+LETA0      = '6.2622312e-008+dleta0nrf_lvt-3.91611e-09*ff_flagrf_lvt'
+WETA0      = '2.2360436e-007+dweta0nrf_lvt-2.53498e-08*ff_flagrf_lvt'
+PETA0      = '-1.6925892e-014+dpeta0nrf_lvt+2.42799e-15*ff_flagrf_lvt'
+ETAB       = 0.039736442
+LETAB      = -2.4572377e-09
+WETAB      = -9.0430667e-08
+PETAB      = 4.856051e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0082323123+du0nrf_lvt'
+LU0        = '5.7790661e-010+dlu0nrf_lvt'
+WU0        = '9.1639556e-010+dwu0nrf_lvt'
+PU0        = '-2.5737193e-016+dpu0nrf_lvt'
+UA         = '-3.0749301e-009+duanrf_lvt'
+LUA        = '1.2466534e-016+dluanrf_lvt'
+WUA        = '3.6937472e-016+dwuanrf_lvt'
+PUA        = '-4.4918686e-023+dpuanrf_lvt'
+UB         = '3.1425635e-018+dubnrf_lvt'
+LUB        = '-1.2305155e-025+dlubnrf_lvt'
+WUB        = '-4.6588894e-025+dwubnrf_lvt'
+PUB        = '4.7720155e-032+dpubnrf_lvt'
+UC         = 8.9822988e-11
+LUC        = -6.3555719e-18
+WUC        = -2.5687948e-17
+PUC        = 1.6381041e-24
+VSAT       = '120396.91+dvsatnrf_lvt-2485.28*ff_flagrf_lvt'
+LVSAT      = '-0.0017601405+dlvsatnrf_lvt+0.000238038*ff_flagrf_lvt'
+WVSAT      = '-0.01556079+dwvsatnrf_lvt+0.00253498*ff_flagrf_lvt'
+PVSAT      = '8.2412849e-010+dpvsatnrf_lvt-2.42799e-10*ff_flagrf_lvt'
+A0         = -3.488793           LA0        = 2.88339e-008        WA0        = 1.0907439e-006
+PA0        = -6.4342982e-014     AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0461879          LKETA      = 7.3764872e-009
+WKETA      = -2.0526438e-008     PKETA      = 7.9396812e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.17475972          LPCLM      = 9.4741054e-009
+WPCLM      = 2.5820308e-007      PPCLM      = -9.6635875e-015     PDIBLC1    = 0
+PDIBLC2    = 0.052953647         LPDIBLC2   = -1.1859141e-009     WPDIBLC2   = 2.9320051e-010
+PPDIBLC2   = -6.7013823e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswnrf_lvt'     RDW        = '65+drdswnrf_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxnrf_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_lvt'          CGDO       = 'cgonrf_lvt'          CGBO       = 0
+CGDL       = 'cglnrf_lvt'          CGSL       = 'cglnrf_lvt'          CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0014296083
+LTVOFF     = -3.5798573e-011     WTVOFF     = -1.9386657e-009     PTVOFF     = 1.4373979e-016
+KT1        = '-0.12546444+dkt1nrf_lvt'
+LKT1       = '-6.3226983e-009+dlkt1nrf_lvt'
+WKT1       = '-1.8256611e-007+dwkt1nrf_lvt'
+PKT1       = '1.088137e-014+dpkt1nrf_lvt'
+KT1L       = 0                   KT2        = -0.03619065         LKT2       = -8.6770458e-010
+WKT2       = -1.5510044e-008     PKT2       = 7.2841112e-016      UTE        = -1
+UA1        = '2.032528e-009+dua1nrf_lvt'
+LUA1       = '-9.448151e-017+dlua1nrf_lvt'
+WUA1       = '-2.9038879e-016+dwua1nrf_lvt'
+PUA1       = '1.8016035e-023+dpua1nrf_lvt'
+UB1        = '-3.5815882e-018+dub1nrf_lvt'
+LUB1       = '1.8802369e-025+dlub1nrf_lvt'
+WUB1       = '1.1147909e-024+dwub1nrf_lvt'
+PUB1       = '-5.8658669e-032+dpub1nrf_lvt'
+UC1        = 1.6779532e-10
+LUC1       = -2.461659e-18
+WUC1       = -1.1973073e-16
+PUC1       = 5.106393e-24
+PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianrf_lvt'
+NOIB       = 'noibnrf_lvt'
+NOIC       = 'noicnrf_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 0			CJD        = 0
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactornrf_lvt+9.52153e-09*ss_flagrf_lvt'
+WNFACTOR   = '0+dwnfactornrf_lvt+1.01399e-07*ss_flagrf_lvt'
+PNFACTOR   = '0+dpnfactornrf_lvt-9.71196e-15*ss_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.7e-07                 IKR    = 1E10
+N      = 1                       BV     = 9.3                     IBV    = 0.03
+JSW    = 2.8e-13                 CJ     = 'cjnrf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.08                    TLEVC  = 1
+CTA    = 0.00073                 CTP    = 0.0003                  
+TCV    = -8.00E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.001                   FCS    = 0			   )

.MODEL ndio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.7e-07                 IKR    = 1E10
+N      = 1                       BV     = 9.3                     IBV    = 0.03
+JSW    = 2.8e-13                 CJ     = 'cjnrf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.75                    TLEVC  = 1
+CTA    = 0.00073                 CTP    = 0.0015                  
+TCV    = -8.00E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 1                       PB     = 0.7
+IK     = 1E20                    TPB    = 0.0015                  TREF   = 25
+TPHP   = 0.002                   FCS    = 0			   )

.MODEL PWDNW_nrf_lvt D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_lvt'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_lvt'
+ N      = '1.02*n_d_dnw_nrf_lvt'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_lvt)'  CJ     = '7.31E-04*cj_d_dnw_nrf_lvt'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_lvt'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_lvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_lvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_lvt'
+ N      = '1.02*n_d_dnw_nrf_lvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_lvt)'  CJ     = '1.15E-04*cj_d_dnw_nrf_lvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_lvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )
.ends nmos_rf_lvt_6t

.subckt pmos_rf_lvt_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parp1rf_lvt  temp2=parp2rf_lvt
+fac1='0.870389*temp1*sigma+0.492365*temp2*sigma'
+fac2='0.870389*temp1*sigma-0.492365*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_lvt='(0.004252047-0.00028546287615/(lef*1e6)+0.0000152025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)+0.000032802452198*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_lvt = '0.00181396*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_lvt = '-0.00181396*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_lvt='0.00181396*geo_fac*toxprf_lvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1843.3*lr*scale/nr/(wr*scale)+0.4389)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.205e06/(lr*scale*1e6)+3.273e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4814'

.param fn_dice='noiseflagprf_lvt_mc*par1fn_mc+noiseflagprf_lvt_mc_mis*par2fprf_lvt_mc'    
.param c1fprf_lvt=5.00E+42           c2fprf_lvt=1.55E+24           c3fprf_lvt=1.00E+10    
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(2.3E-6*1E-6*1))**0.5)))'
.param noiaprf_lvt='c1fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noibprf_lvt='c2fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noicprf_lvt='c3fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_lvt  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************


**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx    
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_lvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '1.2831097e-009+dlvthprf_lvt'
+WVTH0      = '-1.3596429e-008+dwvthprf_lvt'
+PVTH0      = '4.6838072e-016+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2prf_lvt'
+LK2        = '4.6584946e-010+dlk2prf_lvt'
+WK2        = '-2.5582468e-009+dwk2prf_lvt'
+PK2        = '4.6843351e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitprf_lvt'
+LCIT       = '3.0389251e-010+dlcitprf_lvt'
+WCIT       = '1.5758347e-009+dwcitprf_lvt'
+PCIT       = '-1.8542906e-016+dpcitprf_lvt'
+VOFF       = '-0.076341704+dvoffprf_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffprf_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffprf_lvt'
+PVOFF      = '3.2068922e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.2908066+deta0prf_lvt'
+LETA0      = '-2.3078942e-013+dleta0prf_lvt'
+WETA0      = '1.9302674e-007+dweta0prf_lvt'
+PETA0      = '5.8675625e-019+dpeta0prf_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0prf_lvt-5.66666e-06*ff_flagrf_lvt+8.48339e-06*ss_flagrf_lvt-4.53333e-06*sf_flagrf_lvt+4.53333e-06*fs_flagrf_lvt'
+LU0        = '-1.9519503e-010+dlu0prf_lvt+5e-20*ff_flagrf_lvt-1.95194e-12*ss_flagrf_lvt+2.4e-19*sf_flagrf_lvt-2.4e-19*fs_flagrf_lvt'
+WU0        = '1.9415438e-009+dwu0prf_lvt+5.678e-11*ff_flagrf_lvt-8.50036e-11*ss_flagrf_lvt+4.5424e-11*sf_flagrf_lvt-4.5424e-11*fs_flagrf_lvt'
+PU0        = '-3.9117084e-017+dpu0prf_lvt-1e-24*ff_flagrf_lvt+1.95585e-17*ss_flagrf_lvt+3.2e-24*sf_flagrf_lvt-3.2e-24*fs_flagrf_lvt'
+UA         = '-6.2902859e-010+duaprf_lvt'
+LUA        = '-2.4675637e-017+dluaprf_lvt'
+WUA        = '3.9281125e-016+dwuaprf_lvt'
+PUA        = '-1.9206488e-023+dpuaprf_lvt'
+UB         = '1.9421977e-018+dubprf_lvt'
+LUB        = '-2.4060497e-026+dlubprf_lvt'
+WUB        = '-4.483143e-025+dwubprf_lvt'
+PUB        = '3.8556285e-032+dpubprf_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatprf_lvt'  A0         = '5.3771092+da0prf_lvt'
+LA0        = '-9.4373925e-007+dla0prf_lvt'
+WA0        = '-1.9768385e-006+dwa0prf_lvt'
+PA0        = '3.9606047e-013+dpa0prf_lvt'
+AGS        = '9.1959311+dagsprf_lvt'
+LAGS       = '-5.1830021e-007+dlagsprf_lvt'
+WAGS       = '1.247831e-006+dwagsprf_lvt'
+PAGS       = '-1.5646833e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmprf_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+duteprf_lvt'
+LUTE       = '-2.8693669e-009+dluteprf_lvt'
+WUTE       = '-2.918889e-007+dwuteprf_lvt'
+PUTE       = '2.8751056e-014+dputeprf_lvt'
+UA1        = '1.3742656e-009+dua1prf_lvt'
+LUA1       = '2.3165574e-017+dlua1prf_lvt'
+WUA1       = '1.292132e-016+dwua1prf_lvt'
+PUA1       = '-4.7319897e-023+dpua1prf_lvt'
+UB1        = '-1.8019021e-018+dub1prf_lvt'
+LUB1       = '3.1767874e-026+dlub1prf_lvt'
+WUB1       = '-8.8236177e-026+dwub1prf_lvt'
+PUB1       = '-1.1654575e-032+dpub1prf_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datprf_lvt'
+LAT        = '-0.010013792+dlatprf_lvt'
+WAT        = '-0.0024820485+dwatprf_lvt'
+PAT        = '2.4448177e-010+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmprf_lvt'     PPCLM      = '0+dppclmprf_lvt'     LNFACTOR   = '0+dlnfactorprf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'  LVSAT      = '0+dlvsatprf_lvt'
+WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+(dvthprf_lvt+vthmisprf_lvt)-0.0126208*ff_flagrf_lvt+0.0275506*ss_flagrf_lvt-0.00555994*sf_flagrf_lvt+0.00555994*fs_flagrf_lvt'
+LVTH0      = '-1.5409072e-009+dlvthprf_lvt+1.24315e-09*ff_flagrf_lvt-2.71373e-09*ss_flagrf_lvt+5.47654e-10*sf_flagrf_lvt-5.47654e-10*fs_flagrf_lvt'
+WVTH0      = '-9.5700168e-009+dwvthprf_lvt-9.64051e-09*ff_flagrf_lvt-3.85616e-09*ss_flagrf_lvt-1.23398e-08*sf_flagrf_lvt+1.23398e-08*fs_flagrf_lvt'
+PVTH0      = '7.1779158e-017+dpvthprf_lvt+9.49589e-16*ff_flagrf_lvt+3.79834e-16*ss_flagrf_lvt+1.21547e-15*sf_flagrf_lvt-1.21547e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2prf_lvt'
+LK2        = '2.3040232e-009+dlk2prf_lvt'
+WK2        = '5.5823676e-010+dwk2prf_lvt'
+PK2        = '1.6145988e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.5104142e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '6.1284302e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-9.0574373e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.081864514+dvoffprf_lvt-0.0481515*ff_flagrf_lvt+0.0567087*ss_flagrf_lvt-0.0356506*sf_flagrf_lvt+0.0354005*fs_flagrf_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffprf_lvt+4.7429e-09*ff_flagrf_lvt-5.58579e-09*ss_flagrf_lvt+3.51158e-09*sf_flagrf_lvt-3.48694e-09*fs_flagrf_lvt'
+WVOFF      = '1.4496007e-008+dwvoffprf_lvt+2.31371e-08*ff_flagrf_lvt-5.78429e-08*ss_flagrf_lvt+1.69672e-08*sf_flagrf_lvt-1.44607e-08*fs_flagrf_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffprf_lvt-2.27901e-15*ff_flagrf_lvt+5.69751e-15*ss_flagrf_lvt-1.67127e-15*sf_flagrf_lvt+1.42438e-15*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.0769699*ff_flagrf_lvt-0.756116*ss_flagrf_lvt+0.061576*sf_flagrf_lvt-0.061576*fs_flagrf_lvt'
+ETA0       = '-0.13126921+deta0prf_lvt+0.0945146*ff_flagrf_lvt-0.0945146*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LETA0      = '4.1574237e-008+dleta0prf_lvt-9.30966e-09*ff_flagrf_lvt+9.30966e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WETA0      = '5.1059346e-007+dweta0prf_lvt-9.64048e-08*ff_flagrf_lvt+9.64048e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PETA0      = '-3.1279736e-014+dpeta0prf_lvt+9.49585e-15*ff_flagrf_lvt-9.49585e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0prf_lvt+0.000206454*ff_flagrf_lvt-0.00127681*ss_flagrf_lvt+8.95511e-05*sf_flagrf_lvt-1.39395e-05*fs_flagrf_lvt'
+LU0        = '2.1404963e-010+dlu0prf_lvt-2.08938e-11*ff_flagrf_lvt+1.24649e-10*ss_flagrf_lvt-9.26729e-12*sf_flagrf_lvt+1.81956e-12*fs_flagrf_lvt'
+WU0        = '1.1009666e-009+dwu0prf_lvt-3.67401e-10*ff_flagrf_lvt+8.848e-10*ss_flagrf_lvt-2.16797e-10*sf_flagrf_lvt+1.39673e-10*fs_flagrf_lvt'
+PU0        = '4.3679771e-017+dpu0prf_lvt+4.17817e-17*ff_flagrf_lvt-7.59665e-17*ss_flagrf_lvt+2.58287e-17*sf_flagrf_lvt-1.8232e-17*fs_flagrf_lvt'
+UA         = '-1.3371304e-009+duaprf_lvt'
+LUA        = '4.5072393e-017+dluaprf_lvt'
+WUA        = '-9.5951684e-019+dwuaprf_lvt'
+PUA        = '1.9579932e-023+dpuaprf_lvt'
+UB         = '1.6937477e-018+dubprf_lvt'
+LUB        = '4.118249e-028+dlubprf_lvt'
+WUB        = '2.3165923e-025+dwubprf_lvt'
+PUB        = '-2.8421107e-032+dpubprf_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatprf_lvt-192.425*ff_flagrf_lvt+5478.45*ss_flagrf_lvt-153.94*sf_flagrf_lvt+153.94*fs_flagrf_lvt'
+LVSAT      = '0.00071788404+dlvsatprf_lvt+1.89538e-05*ff_flagrf_lvt-0.000539625*ss_flagrf_lvt+1.5163e-05*sf_flagrf_lvt-1.5163e-05*fs_flagrf_lvt'
+WVSAT      = '0.02063004+dwvsatprf_lvt+0.0019281*ff_flagrf_lvt-0.00385619*ss_flagrf_lvt+0.00154248*sf_flagrf_lvt-0.00154248*fs_flagrf_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatprf_lvt-1.89917e-10*ff_flagrf_lvt+3.79834e-10*ss_flagrf_lvt-1.51934e-10*sf_flagrf_lvt+1.51934e-10*fs_flagrf_lvt'
+A0         = '-14.929677+da0prf_lvt'
+LA0        = '1.0564791e-006+dla0prf_lvt'
+WA0        = '7.4425951e-006+dwa0prf_lvt'
+PA0        = '-5.3175373e-013+dpa0prf_lvt'
+AGS        = '-4.6385162+dagsprf_lvt'
+LAGS       = '8.4439285e-007+dlagsprf_lvt'
+WAGS       = '1.8052297e-006+dwagsprf_lvt'
+PAGS       = '-2.1137211e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmprf_lvt'
+LPCLM      = '-5.758458e-008+dlpclmprf_lvt'
+WPCLM      = '9.6402055e-008+dwpclmprf_lvt'
+PPCLM      = '-9.4956024e-015+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2prf_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+duteprf_lvt'
+UA1        = '2.2956478e-009+dua1prf_lvt'
+LUA1       = '-6.7590577e-017+dlua1prf_lvt'
+WUA1       = '-1.1115199e-015+dwua1prf_lvt'
+PUA1       = '7.4892317e-023+dpua1prf_lvt'
+UB1        = '-1.2411257e-018+dub1prf_lvt'
+LUB1       = '-2.3468592e-026+dlub1prf_lvt'
+WUB1       = '-5.8862958e-025+dwub1prf_lvt'
+PUB1       = '3.7634175e-032+dpub1prf_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-7.58152e-09*ff_flagrf_lvt+7.44773e-08*ss_flagrf_lvt-6.06521e-09*sf_flagrf_lvt+6.06521e-09*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-7.71239e-07*ff_flagrf_lvt+7.71239e-07*ss_flagrf_lvt-6.16991e-07*sf_flagrf_lvt+6.16991e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.59668e-14*ff_flagrf_lvt-7.59668e-14*ss_flagrf_lvt+6.07734e-14*sf_flagrf_lvt-6.07734e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '2.6146736e-011+dlvthprf_lvt'
+WVTH0      = '-1.6058274e-008+dwvthprf_lvt'
+PVTH0      = '1.7504829e-015+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2prf_lvt'
+LK2        = '5.5945104e-010+dlk2prf_lvt'
+WK2        = '-1.5266232e-009+dwk2prf_lvt'
+PK2        = '3.729599e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitprf_lvt'
+LCIT       = '-4.9918717e-012+dlcitprf_lvt'
+WCIT       = '-1.6353193e-009+dwcitprf_lvt'
+PCIT       = '1.2963301e-016+dpcitprf_lvt'
+VOFF       = '-0.082218583+dvoffprf_lvt'
+LVOFF      = '-4.857209e-009+dlvoffprf_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffprf_lvt'
+PVOFF      = '2.6897322e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.72801286+deta0prf_lvt'
+LETA0      = '1.4122934e-012+dleta0prf_lvt'
+WETA0      = '-2.5292365e-007+dweta0prf_lvt'
+PETA0      = '-1.0891883e-018+dpeta0prf_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0prf_lvt+0.0001275*ff_flagrf_lvt-0.000190876*ss_flagrf_lvt+0.000102*sf_flagrf_lvt-0.000102*fs_flagrf_lvt'
+LU0        = '-2.7091922e-010+dlu0prf_lvt+4.6e-17*ff_flagrf_lvt+4.39187e-11*ss_flagrf_lvt-2.3e-17*sf_flagrf_lvt+2.3e-17*fs_flagrf_lvt'
+WU0        = '-1.9016192e-009+dwu0prf_lvt-7.90503e-11*ff_flagrf_lvt+1.18343e-10*ss_flagrf_lvt-6.32397e-11*sf_flagrf_lvt+6.32397e-11*fs_flagrf_lvt'
+PU0        = '3.8121589e-017+dpu0prf_lvt+5e-24*ff_flagrf_lvt-2.72296e-17*ss_flagrf_lvt-3.6e-23*sf_flagrf_lvt+3.6e-23*fs_flagrf_lvt'
+UA         = '4.0037736e-010+duaprf_lvt'
+LUA        = '-5.25554e-017+dluaprf_lvt'
+WUA        = '-6.5718282e-016+dwuaprf_lvt'
+PUA        = '9.2308705e-024+dpuaprf_lvt'
+UB         = '1.3125234e-018+dubprf_lvt'
+LUB        = '6.503691e-027+dlubprf_lvt'
+WUB        = '1.9395346e-025+dwubprf_lvt'
+PUB        = '7.3808134e-033+dpubprf_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatprf_lvt'  A0         = '4.8804857+da0prf_lvt'
+LA0        = '-7.8903284e-007+dla0prf_lvt'
+WA0        = '-1.4702825e-006+dwa0prf_lvt'
+PA0        = '2.3825993e-013+dpa0prf_lvt'
+AGS        = '13.322597+dagsprf_lvt'
+LAGS       = '-1.0187458e-006+dlagsprf_lvt'
+WAGS       = '-2.9613684e-006+dwagsprf_lvt'
+PAGS       = '3.5398618e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmprf_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmprf_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmprf_lvt'
+PPCLM      = '-1.3614853e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2prf_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+duteprf_lvt'
+LUTE       = '9.5674269e-009+dluteprf_lvt'
+WUTE       = '-1.6310179e-007+dwuteprf_lvt'
+PUTE       = '1.6065527e-014+dputeprf_lvt'
+UA1        = '2.0289308e-009+dua1prf_lvt'
+LUA1       = '-7.6235902e-017+dlua1prf_lvt'
+WUA1       = '-5.385453e-016+dwua1prf_lvt'
+PUA1       = '5.4069609e-023+dpua1prf_lvt'
+UB1        = '-2.1814336e-018+dub1prf_lvt'
+LUB1       = '5.2100107e-026+dlub1prf_lvt'
+WUB1       = '2.9888601e-025+dwub1prf_lvt'
+PUB1       = '-3.2393453e-032+dpub1prf_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datprf_lvt'
+LAT        = '-0.017286299+dlatprf_lvt'
+WAT        = '-0.077791263+dwatprf_lvt'
+PAT        = '7.6624394e-009+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_lvt'  WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'
+LVSAT      = '0+dlvsatprf_lvt'     WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+(dvthprf_lvt+vthmisprf_lvt)+0.00687633*ff_flagrf_lvt+0.0106116*ss_flagrf_lvt+0.0055011*sf_flagrf_lvt-0.0055011*fs_flagrf_lvt'
+LVTH0      = '-1.3621188e-010+dlvthprf_lvt-6.77323e-10*ff_flagrf_lvt-1.04524e-09*ss_flagrf_lvt-5.41853e-10*sf_flagrf_lvt+5.41853e-10*fs_flagrf_lvt'
+WVTH0      = '1.5530487e-008+dwvthprf_lvt-2.95276e-08*ff_flagrf_lvt+1.34216e-08*ss_flagrf_lvt-2.36221e-08*sf_flagrf_lvt+2.36221e-08*fs_flagrf_lvt'
+PVTH0      = '-1.3610101e-015+dpvthprf_lvt+2.90846e-15*ff_flagrf_lvt-1.32203e-15*ss_flagrf_lvt+2.32676e-15*sf_flagrf_lvt-2.32676e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2prf_lvt'
+LK2        = '2.4320462e-009+dlk2prf_lvt'
+WK2        = '1.9463059e-009+dwk2prf_lvt'
+PK2        = '3.0876379e-017+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.099571e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '1.7484688e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-4.8668363e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.078139928+dvoffprf_lvt-0.00704616*ff_flagrf_lvt-0.0210535*ss_flagrf_lvt-0.00217331*sf_flagrf_lvt+0.0120124*fs_flagrf_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffprf_lvt+6.94039e-10*ff_flagrf_lvt+2.07377e-09*ss_flagrf_lvt+2.14071e-10*sf_flagrf_lvt-1.18321e-09*fs_flagrf_lvt'
+WVOFF      = '1.0696929e-008+dwvoffprf_lvt-1.87903e-08*ff_flagrf_lvt+2.14746e-08*ss_flagrf_lvt-1.71796e-08*sf_flagrf_lvt+9.39513e-09*fs_flagrf_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffprf_lvt+1.85084e-15*ff_flagrf_lvt-2.11524e-15*ss_flagrf_lvt+1.6922e-15*sf_flagrf_lvt-9.25416e-16*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.110365*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0882879*sf_flagrf_lvt+0.70122*fs_flagrf_lvt'
+ETA0       = '0.90417384+deta0prf_lvt-0.00394754*ff_flagrf_lvt-0.0263169*ss_flagrf_lvt+0.0*sf_flagrf_lvt-0.0184218*fs_flagrf_lvt'
+LETA0      = '-1.7350444e-008+dleta0prf_lvt+3.88831e-10*ff_flagrf_lvt+2.59221e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.81455e-09*fs_flagrf_lvt'
+WETA0      = '-5.4555845e-007+dweta0prf_lvt+4.02649e-09*ff_flagrf_lvt+2.68433e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.87903e-08*fs_flagrf_lvt'
+PETA0      = '2.8823439e-014+dpeta0prf_lvt-3.96608e-16*ff_flagrf_lvt-2.64405e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt-1.85084e-15*fs_flagrf_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0prf_lvt-0.000313096*ff_flagrf_lvt+0.000193026*ss_flagrf_lvt-0.000250477*sf_flagrf_lvt+0.000234687*fs_flagrf_lvt'
+LU0        = '2.8823786e-010+dlu0prf_lvt+4.33987e-11*ff_flagrf_lvt+6.10414e-12*ss_flagrf_lvt+3.47189e-11*sf_flagrf_lvt-3.31636e-11*fs_flagrf_lvt'
+WU0        = '-1.1898039e-009+dwu0prf_lvt+1.6254e-10*ff_flagrf_lvt-6.14436e-10*ss_flagrf_lvt+1.30031e-10*sf_flagrf_lvt-1.13925e-10*fs_flagrf_lvt'
+PU0        = '-3.199222e-017+dpu0prf_lvt-2.37964e-17*ff_flagrf_lvt+4.49488e-17*ss_flagrf_lvt-1.90372e-17*sf_flagrf_lvt+1.74507e-17*fs_flagrf_lvt'
+UA         = '-7.9459861e-010+duaprf_lvt'
+LUA        = '6.5149733e-017+dluaprf_lvt'
+WUA        = '-5.5434195e-016+dwuaprf_lvt'
+PUA        = '-8.9895493e-025+dpuaprf_lvt'
+UB         = '1.6575544e-018+dubprf_lvt'
+LUB        = '-2.7481865e-026+dlubprf_lvt'
+WUB        = '2.6857637e-025+dwubprf_lvt'
+PUB        = '3.0456064e-035+dpubprf_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatprf_lvt-2249.67*ff_flagrf_lvt+17488*ss_flagrf_lvt-1799.74*sf_flagrf_lvt+1799.74*fs_flagrf_lvt'
+LVSAT      = '-0.0018446019+dlvsatprf_lvt+0.000221592*ff_flagrf_lvt-0.00172256*ss_flagrf_lvt+0.000177274*sf_flagrf_lvt-0.000177274*fs_flagrf_lvt'
+WVSAT      = '-0.0059053474+dwvsatprf_lvt+0.00402649*ff_flagrf_lvt-0.016106*ss_flagrf_lvt+0.00322119*sf_flagrf_lvt-0.00322119*fs_flagrf_lvt'
+PVSAT      = '5.8167672e-010+dpvsatprf_lvt-3.96609e-10*ff_flagrf_lvt+1.58643e-09*ss_flagrf_lvt-3.17287e-10*sf_flagrf_lvt+3.17287e-10*fs_flagrf_lvt'
+A0         = '-10.141985+da0prf_lvt'
+LA0        = '6.9068048e-007+dla0prf_lvt'
+WA0        = '2.5591493e-006+dwa0prf_lvt'
+PA0        = '-1.5863911e-013+dpa0prf_lvt'
+AGS        = '-8.9308661+dagsprf_lvt'
+LAGS       = '1.1732203e-006+dlagsprf_lvt'
+WAGS       = '6.1834266e-006+dwagsprf_lvt'
+PAGS       = '-5.4677612e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmprf_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmprf_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmprf_lvt'
+PPCLM      = '1.3219926e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flagrf_lvt-0.0210535*sf_flagrf_lvt+0.0210535*fs_flagrf_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flagrf_lvt+2.07377e-09*sf_flagrf_lvt-2.07377e-09*fs_flagrf_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flagrf_lvt+2.14746e-08*sf_flagrf_lvt-2.14746e-08*fs_flagrf_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flagrf_lvt-2.11524e-15*sf_flagrf_lvt+2.11524e-15*fs_flagrf_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+duteprf_lvt'
+UA1        = '1.22313e-009+dua1prf_lvt'
+LUA1       = '3.1354809e-018+dlua1prf_lvt'
+WUA1       = '-1.7551692e-017+dwua1prf_lvt'
+PUA1       = '2.7517381e-024+dpua1prf_lvt'
+UB1        = '-1.6557558e-018+dub1prf_lvt'
+LUB1       = '3.2084074e-028+dlub1prf_lvt'
+WUB1       = '-1.6570695e-025+dwub1prf_lvt'
+PUB1       = '1.3368954e-032+dpub1prf_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-1.08707e-08*ff_flagrf_lvt+0.0*ss_flagrf_lvt-8.69675e-09*sf_flagrf_lvt-6.90695e-08*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-8.05299e-07*ff_flagrf_lvt+0.0*ss_flagrf_lvt-6.44238e-07*sf_flagrf_lvt-1.6106e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.93218e-14*ff_flagrf_lvt+0.0*ss_flagrf_lvt+6.34573e-14*sf_flagrf_lvt+1.58643e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.06                    TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.00022                 
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.9                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.003                   FCS    = 0			   )

.MODEL pdio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.9                     TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.003                   
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf_lvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_lvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_lvt'
+ N      = '1.02*n_d_dnw_prf_lvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_lvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_lvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_lvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_lvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_lvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_lvt'
+ N      = '1.02*n_d_prf_lvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_lvt)'  CJ     = '1.37E-04*cj_d_prf_lvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_lvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_lvt_5t

.subckt pmos_rf_lvt_nw_5t D G S B PG lr=0.06E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.45u/scale' sd='0.24u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_lvt'
.param
+temp1=parp1rf_lvt  temp2=parp2rf_lvt
+fac1='0.870389*temp1*sigma+0.492365*temp2*sigma'
+fac2='0.870389*temp1*sigma-0.492365*temp2*sigma'
.param  lef='lr*scale+2e-09'
+       wef='wr*scale+2e-08'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_lvt='(0.004252047-0.00028546287615/(lef*1e6)+0.0000152025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)+0.000032802452198*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisprf_lvt = '0.00181396*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_lvt = '-0.00181396*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_lvt='0.00181396*geo_fac*toxprf_lvt*fac2*mismatchflag' 
.param Lspace=0.24u
.param Ledge=0.45u
.param Ledgeeff=0.24u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+1843.3*lr*scale/nr/(wr*scale)+0.4389)'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='1.205e06/(lr*scale*1e6)+3.273e07'
.param rnoiax='0.0152/(lr*scale*1e6)+0.4814'

.param fn_dice='noiseflagprf_lvt_mc*par1fn_mc+noiseflagprf_lvt_mc_mis*par2fprf_lvt_mc'    
.param c1fprf_lvt=5.00E+42           c2fprf_lvt=1.55E+24           c3fprf_lvt=1.00E+10    
.param arearatio='sigma_factor_flicker_rf_lvt*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(2.3E-6*1E-6*1))**0.5)))'
.param noiaprf_lvt='c1fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noibprf_lvt='c2fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'
.param noicprf_lvt='c3fprf_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_lvt)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_lvt  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************



**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_lvt_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_lvt_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_lvt_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_lvt_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_lvt L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_lvt.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '1.2831097e-009+dlvthprf_lvt'
+WVTH0      = '-1.3596429e-008+dwvthprf_lvt'
+PVTH0      = '4.6838072e-016+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2prf_lvt'
+LK2        = '4.6584946e-010+dlk2prf_lvt'
+WK2        = '-2.5582468e-009+dwk2prf_lvt'
+PK2        = '4.6843351e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitprf_lvt'
+LCIT       = '3.0389251e-010+dlcitprf_lvt'
+WCIT       = '1.5758347e-009+dwcitprf_lvt'
+PCIT       = '-1.8542906e-016+dpcitprf_lvt'
+VOFF       = '-0.076341704+dvoffprf_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffprf_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffprf_lvt'
+PVOFF      = '3.2068922e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.2908066+deta0prf_lvt'
+LETA0      = '-2.3078942e-013+dleta0prf_lvt'
+WETA0      = '1.9302674e-007+dweta0prf_lvt'
+PETA0      = '5.8675625e-019+dpeta0prf_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0prf_lvt-5.66666e-06*ff_flagrf_lvt+8.48339e-06*ss_flagrf_lvt-4.53333e-06*sf_flagrf_lvt+4.53333e-06*fs_flagrf_lvt'
+LU0        = '-1.9519503e-010+dlu0prf_lvt+5e-20*ff_flagrf_lvt-1.95194e-12*ss_flagrf_lvt+2.4e-19*sf_flagrf_lvt-2.4e-19*fs_flagrf_lvt'
+WU0        = '1.9415438e-009+dwu0prf_lvt+5.678e-11*ff_flagrf_lvt-8.50036e-11*ss_flagrf_lvt+4.5424e-11*sf_flagrf_lvt-4.5424e-11*fs_flagrf_lvt'
+PU0        = '-3.9117084e-017+dpu0prf_lvt-1e-24*ff_flagrf_lvt+1.95585e-17*ss_flagrf_lvt+3.2e-24*sf_flagrf_lvt-3.2e-24*fs_flagrf_lvt'
+UA         = '-6.2902859e-010+duaprf_lvt'
+LUA        = '-2.4675637e-017+dluaprf_lvt'
+WUA        = '3.9281125e-016+dwuaprf_lvt'
+PUA        = '-1.9206488e-023+dpuaprf_lvt'
+UB         = '1.9421977e-018+dubprf_lvt'
+LUB        = '-2.4060497e-026+dlubprf_lvt'
+WUB        = '-4.483143e-025+dwubprf_lvt'
+PUB        = '3.8556285e-032+dpubprf_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatprf_lvt'  A0         = '5.3771092+da0prf_lvt'
+LA0        = '-9.4373925e-007+dla0prf_lvt'
+WA0        = '-1.9768385e-006+dwa0prf_lvt'
+PA0        = '3.9606047e-013+dpa0prf_lvt'
+AGS        = '9.1959311+dagsprf_lvt'
+LAGS       = '-5.1830021e-007+dlagsprf_lvt'
+WAGS       = '1.247831e-006+dwagsprf_lvt'
+PAGS       = '-1.5646833e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmprf_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+duteprf_lvt'
+LUTE       = '-2.8693669e-009+dluteprf_lvt'
+WUTE       = '-2.918889e-007+dwuteprf_lvt'
+PUTE       = '2.8751056e-014+dputeprf_lvt'
+UA1        = '1.3742656e-009+dua1prf_lvt'
+LUA1       = '2.3165574e-017+dlua1prf_lvt'
+WUA1       = '1.292132e-016+dwua1prf_lvt'
+PUA1       = '-4.7319897e-023+dpua1prf_lvt'
+UB1        = '-1.8019021e-018+dub1prf_lvt'
+LUB1       = '3.1767874e-026+dlub1prf_lvt'
+WUB1       = '-8.8236177e-026+dwub1prf_lvt'
+PUB1       = '-1.1654575e-032+dpub1prf_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datprf_lvt'
+LAT        = '-0.010013792+dlatprf_lvt'
+WAT        = '-0.0024820485+dwatprf_lvt'
+PAT        = '2.4448177e-010+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmprf_lvt'     PPCLM      = '0+dppclmprf_lvt'     LNFACTOR   = '0+dlnfactorprf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'  LVSAT      = '0+dlvsatprf_lvt'
+WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+WMAX       = 6.01e-006			
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+(dvthprf_lvt+vthmisprf_lvt)-0.0126208*ff_flagrf_lvt+0.0275506*ss_flagrf_lvt-0.00555994*sf_flagrf_lvt+0.00555994*fs_flagrf_lvt'
+LVTH0      = '-1.5409072e-009+dlvthprf_lvt+1.24315e-09*ff_flagrf_lvt-2.71373e-09*ss_flagrf_lvt+5.47654e-10*sf_flagrf_lvt-5.47654e-10*fs_flagrf_lvt'
+WVTH0      = '-9.5700168e-009+dwvthprf_lvt-9.64051e-09*ff_flagrf_lvt-3.85616e-09*ss_flagrf_lvt-1.23398e-08*sf_flagrf_lvt+1.23398e-08*fs_flagrf_lvt'
+PVTH0      = '7.1779158e-017+dpvthprf_lvt+9.49589e-16*ff_flagrf_lvt+3.79834e-16*ss_flagrf_lvt+1.21547e-15*sf_flagrf_lvt-1.21547e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2prf_lvt'
+LK2        = '2.3040232e-009+dlk2prf_lvt'
+WK2        = '5.5823676e-010+dwk2prf_lvt'
+PK2        = '1.6145988e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.5104142e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '6.1284302e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-9.0574373e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.081864514+dvoffprf_lvt-0.0481515*ff_flagrf_lvt+0.0567087*ss_flagrf_lvt-0.0356506*sf_flagrf_lvt+0.0354005*fs_flagrf_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffprf_lvt+4.7429e-09*ff_flagrf_lvt-5.58579e-09*ss_flagrf_lvt+3.51158e-09*sf_flagrf_lvt-3.48694e-09*fs_flagrf_lvt'
+WVOFF      = '1.4496007e-008+dwvoffprf_lvt+2.31371e-08*ff_flagrf_lvt-5.78429e-08*ss_flagrf_lvt+1.69672e-08*sf_flagrf_lvt-1.44607e-08*fs_flagrf_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffprf_lvt-2.27901e-15*ff_flagrf_lvt+5.69751e-15*ss_flagrf_lvt-1.67127e-15*sf_flagrf_lvt+1.42438e-15*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.0769699*ff_flagrf_lvt-0.756116*ss_flagrf_lvt+0.061576*sf_flagrf_lvt-0.061576*fs_flagrf_lvt'
+ETA0       = '-0.13126921+deta0prf_lvt+0.0945146*ff_flagrf_lvt-0.0945146*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LETA0      = '4.1574237e-008+dleta0prf_lvt-9.30966e-09*ff_flagrf_lvt+9.30966e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WETA0      = '5.1059346e-007+dweta0prf_lvt-9.64048e-08*ff_flagrf_lvt+9.64048e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PETA0      = '-3.1279736e-014+dpeta0prf_lvt+9.49585e-15*ff_flagrf_lvt-9.49585e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0prf_lvt+0.000206454*ff_flagrf_lvt-0.00127681*ss_flagrf_lvt+8.95511e-05*sf_flagrf_lvt-1.39395e-05*fs_flagrf_lvt'
+LU0        = '2.1404963e-010+dlu0prf_lvt-2.08938e-11*ff_flagrf_lvt+1.24649e-10*ss_flagrf_lvt-9.26729e-12*sf_flagrf_lvt+1.81956e-12*fs_flagrf_lvt'
+WU0        = '1.1009666e-009+dwu0prf_lvt-3.67401e-10*ff_flagrf_lvt+8.848e-10*ss_flagrf_lvt-2.16797e-10*sf_flagrf_lvt+1.39673e-10*fs_flagrf_lvt'
+PU0        = '4.3679771e-017+dpu0prf_lvt+4.17817e-17*ff_flagrf_lvt-7.59665e-17*ss_flagrf_lvt+2.58287e-17*sf_flagrf_lvt-1.8232e-17*fs_flagrf_lvt'
+UA         = '-1.3371304e-009+duaprf_lvt'
+LUA        = '4.5072393e-017+dluaprf_lvt'
+WUA        = '-9.5951684e-019+dwuaprf_lvt'
+PUA        = '1.9579932e-023+dpuaprf_lvt'
+UB         = '1.6937477e-018+dubprf_lvt'
+LUB        = '4.118249e-028+dlubprf_lvt'
+WUB        = '2.3165923e-025+dwubprf_lvt'
+PUB        = '-2.8421107e-032+dpubprf_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatprf_lvt-192.425*ff_flagrf_lvt+5478.45*ss_flagrf_lvt-153.94*sf_flagrf_lvt+153.94*fs_flagrf_lvt'
+LVSAT      = '0.00071788404+dlvsatprf_lvt+1.89538e-05*ff_flagrf_lvt-0.000539625*ss_flagrf_lvt+1.5163e-05*sf_flagrf_lvt-1.5163e-05*fs_flagrf_lvt'
+WVSAT      = '0.02063004+dwvsatprf_lvt+0.0019281*ff_flagrf_lvt-0.00385619*ss_flagrf_lvt+0.00154248*sf_flagrf_lvt-0.00154248*fs_flagrf_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatprf_lvt-1.89917e-10*ff_flagrf_lvt+3.79834e-10*ss_flagrf_lvt-1.51934e-10*sf_flagrf_lvt+1.51934e-10*fs_flagrf_lvt'
+A0         = '-14.929677+da0prf_lvt'
+LA0        = '1.0564791e-006+dla0prf_lvt'
+WA0        = '7.4425951e-006+dwa0prf_lvt'
+PA0        = '-5.3175373e-013+dpa0prf_lvt'
+AGS        = '-4.6385162+dagsprf_lvt'
+LAGS       = '8.4439285e-007+dlagsprf_lvt'
+WAGS       = '1.8052297e-006+dwagsprf_lvt'
+PAGS       = '-2.1137211e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmprf_lvt'
+LPCLM      = '-5.758458e-008+dlpclmprf_lvt'
+WPCLM      = '9.6402055e-008+dwpclmprf_lvt'
+PPCLM      = '-9.4956024e-015+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2prf_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+duteprf_lvt'
+UA1        = '2.2956478e-009+dua1prf_lvt'
+LUA1       = '-6.7590577e-017+dlua1prf_lvt'
+WUA1       = '-1.1115199e-015+dwua1prf_lvt'
+PUA1       = '7.4892317e-023+dpua1prf_lvt'
+UB1        = '-1.2411257e-018+dub1prf_lvt'
+LUB1       = '-2.3468592e-026+dlub1prf_lvt'
+WUB1       = '-5.8862958e-025+dwub1prf_lvt'
+PUB1       = '3.7634175e-032+dpub1prf_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-7.58152e-09*ff_flagrf_lvt+7.44773e-08*ss_flagrf_lvt-6.06521e-09*sf_flagrf_lvt+6.06521e-09*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-7.71239e-07*ff_flagrf_lvt+7.71239e-07*ss_flagrf_lvt-6.16991e-07*sf_flagrf_lvt+6.16991e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.59668e-14*ff_flagrf_lvt-7.59668e-14*ss_flagrf_lvt+6.07734e-14*sf_flagrf_lvt-6.07734e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.3 PMOS	(	LEVEL      = 54                  
+LMIN       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+LMAX       = 2.401e-007
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+(dvthprf_lvt+vthmisprf_lvt)'
+LVTH0      = '2.6146736e-011+dlvthprf_lvt'
+WVTH0      = '-1.6058274e-008+dwvthprf_lvt'
+PVTH0      = '1.7504829e-015+dpvthprf_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2prf_lvt'
+LK2        = '5.5945104e-010+dlk2prf_lvt'
+WK2        = '-1.5266232e-009+dwk2prf_lvt'
+PK2        = '3.729599e-016+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitprf_lvt'
+LCIT       = '-4.9918717e-012+dlcitprf_lvt'
+WCIT       = '-1.6353193e-009+dwcitprf_lvt'
+PCIT       = '1.2963301e-016+dpcitprf_lvt'
+VOFF       = '-0.082218583+dvoffprf_lvt'
+LVOFF      = '-4.857209e-009+dlvoffprf_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffprf_lvt'
+PVOFF      = '2.6897322e-015+dpvoffprf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt' ETA0       = '0.72801286+deta0prf_lvt'
+LETA0      = '1.4122934e-012+dleta0prf_lvt'
+WETA0      = '-2.5292365e-007+dweta0prf_lvt'
+PETA0      = '-1.0891883e-018+dpeta0prf_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0prf_lvt+0.0001275*ff_flagrf_lvt-0.000190876*ss_flagrf_lvt+0.000102*sf_flagrf_lvt-0.000102*fs_flagrf_lvt'
+LU0        = '-2.7091922e-010+dlu0prf_lvt+4.6e-17*ff_flagrf_lvt+4.39187e-11*ss_flagrf_lvt-2.3e-17*sf_flagrf_lvt+2.3e-17*fs_flagrf_lvt'
+WU0        = '-1.9016192e-009+dwu0prf_lvt-7.90503e-11*ff_flagrf_lvt+1.18343e-10*ss_flagrf_lvt-6.32397e-11*sf_flagrf_lvt+6.32397e-11*fs_flagrf_lvt'
+PU0        = '3.8121589e-017+dpu0prf_lvt+5e-24*ff_flagrf_lvt-2.72296e-17*ss_flagrf_lvt-3.6e-23*sf_flagrf_lvt+3.6e-23*fs_flagrf_lvt'
+UA         = '4.0037736e-010+duaprf_lvt'
+LUA        = '-5.25554e-017+dluaprf_lvt'
+WUA        = '-6.5718282e-016+dwuaprf_lvt'
+PUA        = '9.2308705e-024+dpuaprf_lvt'
+UB         = '1.3125234e-018+dubprf_lvt'
+LUB        = '6.503691e-027+dlubprf_lvt'
+WUB        = '1.9395346e-025+dwubprf_lvt'
+PUB        = '7.3808134e-033+dpubprf_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatprf_lvt'  A0         = '4.8804857+da0prf_lvt'
+LA0        = '-7.8903284e-007+dla0prf_lvt'
+WA0        = '-1.4702825e-006+dwa0prf_lvt'
+PA0        = '2.3825993e-013+dpa0prf_lvt'
+AGS        = '13.322597+dagsprf_lvt'
+LAGS       = '-1.0187458e-006+dlagsprf_lvt'
+WAGS       = '-2.9613684e-006+dwagsprf_lvt'
+PAGS       = '3.5398618e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmprf_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmprf_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmprf_lvt'
+PPCLM      = '-1.3614853e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2prf_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+duteprf_lvt'
+LUTE       = '9.5674269e-009+dluteprf_lvt'
+WUTE       = '-1.6310179e-007+dwuteprf_lvt'
+PUTE       = '1.6065527e-014+dputeprf_lvt'
+UA1        = '2.0289308e-009+dua1prf_lvt'
+LUA1       = '-7.6235902e-017+dlua1prf_lvt'
+WUA1       = '-5.385453e-016+dwua1prf_lvt'
+PUA1       = '5.4069609e-023+dpua1prf_lvt'
+UB1        = '-2.1814336e-018+dub1prf_lvt'
+LUB1       = '5.2100107e-026+dlub1prf_lvt'
+WUB1       = '2.9888601e-025+dwub1prf_lvt'
+PUB1       = '-3.2393453e-032+dpub1prf_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datprf_lvt'
+LAT        = '-0.017286299+dlatprf_lvt'
+WAT        = '-0.077791263+dwatprf_lvt'
+PAT        = '7.6624394e-009+dpatprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_lvt'  WNFACTOR   = '0+dwnfactorprf_lvt'  PNFACTOR   = '0+dpnfactorprf_lvt'
+LVSAT      = '0+dlvsatprf_lvt'     WVSAT      = '0+dwvsatprf_lvt'     PVSAT      = '0+dpvsatprf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_lvt.4 PMOS	(	LEVEL      = 54                  
+LMIN       = 6e-008
+LMAX       = '9.999946e-008-(dxlprf_lvt+dlmisprf_lvt)'
+WMIN       = 0.6e-006			
+WMAX       = '1e-006-(dxwprf_lvt+dwmisprf_lvt)'   
+VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxprf_lvt+toxmisprf_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlprf_lvt+dlmisprf_lvt)'    XW         = '2e-08+(dxwprf_lvt+dwmisprf_lvt)'    DLC        = '-6.55e-09+ddlcprf_lvt'
+DWC        = 0                   XPART      = 0			TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+(dvthprf_lvt+vthmisprf_lvt)+0.00687633*ff_flagrf_lvt+0.0106116*ss_flagrf_lvt+0.0055011*sf_flagrf_lvt-0.0055011*fs_flagrf_lvt'
+LVTH0      = '-1.3621188e-010+dlvthprf_lvt-6.77323e-10*ff_flagrf_lvt-1.04524e-09*ss_flagrf_lvt-5.41853e-10*sf_flagrf_lvt+5.41853e-10*fs_flagrf_lvt'
+WVTH0      = '1.5530487e-008+dwvthprf_lvt-2.95276e-08*ff_flagrf_lvt+1.34216e-08*ss_flagrf_lvt-2.36221e-08*sf_flagrf_lvt+2.36221e-08*fs_flagrf_lvt'
+PVTH0      = '-1.3610101e-015+dpvthprf_lvt+2.90846e-15*ff_flagrf_lvt-1.32203e-15*ss_flagrf_lvt+2.32676e-15*sf_flagrf_lvt-2.32676e-15*fs_flagrf_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2prf_lvt'
+LK2        = '2.4320462e-009+dlk2prf_lvt'
+WK2        = '1.9463059e-009+dwk2prf_lvt'
+PK2        = '3.0876379e-017+dpk2prf_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+LCIT       = '4.099571e-010+dlcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+WCIT       = '1.7484688e-010+dwcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+PCIT       = '-4.8668363e-017+dpcitprf_lvt+0.0*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0*sf_flagrf_lvt+0.0*fs_flagrf_lvt'
+VOFF       = '-0.078139928+dvoffprf_lvt-0.00704616*ff_flagrf_lvt-0.0210535*ss_flagrf_lvt-0.00217331*sf_flagrf_lvt+0.0120124*fs_flagrf_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffprf_lvt+6.94039e-10*ff_flagrf_lvt+2.07377e-09*ss_flagrf_lvt+2.14071e-10*sf_flagrf_lvt-1.18321e-09*fs_flagrf_lvt'
+WVOFF      = '1.0696929e-008+dwvoffprf_lvt-1.87903e-08*ff_flagrf_lvt+2.14746e-08*ss_flagrf_lvt-1.71796e-08*sf_flagrf_lvt+9.39513e-09*fs_flagrf_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffprf_lvt+1.85084e-15*ff_flagrf_lvt-2.11524e-15*ss_flagrf_lvt+1.6922e-15*sf_flagrf_lvt-9.25416e-16*fs_flagrf_lvt'
+NFACTOR    = '0.6+dnfactorprf_lvt+0.110365*ff_flagrf_lvt+0.0*ss_flagrf_lvt+0.0882879*sf_flagrf_lvt+0.70122*fs_flagrf_lvt'
+ETA0       = '0.90417384+deta0prf_lvt-0.00394754*ff_flagrf_lvt-0.0263169*ss_flagrf_lvt+0.0*sf_flagrf_lvt-0.0184218*fs_flagrf_lvt'
+LETA0      = '-1.7350444e-008+dleta0prf_lvt+3.88831e-10*ff_flagrf_lvt+2.59221e-09*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.81455e-09*fs_flagrf_lvt'
+WETA0      = '-5.4555845e-007+dweta0prf_lvt+4.02649e-09*ff_flagrf_lvt+2.68433e-08*ss_flagrf_lvt+0.0*sf_flagrf_lvt+1.87903e-08*fs_flagrf_lvt'
+PETA0      = '2.8823439e-014+dpeta0prf_lvt-3.96608e-16*ff_flagrf_lvt-2.64405e-15*ss_flagrf_lvt+0.0*sf_flagrf_lvt-1.85084e-15*fs_flagrf_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0prf_lvt-0.000313096*ff_flagrf_lvt+0.000193026*ss_flagrf_lvt-0.000250477*sf_flagrf_lvt+0.000234687*fs_flagrf_lvt'
+LU0        = '2.8823786e-010+dlu0prf_lvt+4.33987e-11*ff_flagrf_lvt+6.10414e-12*ss_flagrf_lvt+3.47189e-11*sf_flagrf_lvt-3.31636e-11*fs_flagrf_lvt'
+WU0        = '-1.1898039e-009+dwu0prf_lvt+1.6254e-10*ff_flagrf_lvt-6.14436e-10*ss_flagrf_lvt+1.30031e-10*sf_flagrf_lvt-1.13925e-10*fs_flagrf_lvt'
+PU0        = '-3.199222e-017+dpu0prf_lvt-2.37964e-17*ff_flagrf_lvt+4.49488e-17*ss_flagrf_lvt-1.90372e-17*sf_flagrf_lvt+1.74507e-17*fs_flagrf_lvt'
+UA         = '-7.9459861e-010+duaprf_lvt'
+LUA        = '6.5149733e-017+dluaprf_lvt'
+WUA        = '-5.5434195e-016+dwuaprf_lvt'
+PUA        = '-8.9895493e-025+dpuaprf_lvt'
+UB         = '1.6575544e-018+dubprf_lvt'
+LUB        = '-2.7481865e-026+dlubprf_lvt'
+WUB        = '2.6857637e-025+dwubprf_lvt'
+PUB        = '3.0456064e-035+dpubprf_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatprf_lvt-2249.67*ff_flagrf_lvt+17488*ss_flagrf_lvt-1799.74*sf_flagrf_lvt+1799.74*fs_flagrf_lvt'
+LVSAT      = '-0.0018446019+dlvsatprf_lvt+0.000221592*ff_flagrf_lvt-0.00172256*ss_flagrf_lvt+0.000177274*sf_flagrf_lvt-0.000177274*fs_flagrf_lvt'
+WVSAT      = '-0.0059053474+dwvsatprf_lvt+0.00402649*ff_flagrf_lvt-0.016106*ss_flagrf_lvt+0.00322119*sf_flagrf_lvt-0.00322119*fs_flagrf_lvt'
+PVSAT      = '5.8167672e-010+dpvsatprf_lvt-3.96609e-10*ff_flagrf_lvt+1.58643e-09*ss_flagrf_lvt-3.17287e-10*sf_flagrf_lvt+3.17287e-10*fs_flagrf_lvt'
+A0         = '-10.141985+da0prf_lvt'
+LA0        = '6.9068048e-007+dla0prf_lvt'
+WA0        = '2.5591493e-006+dwa0prf_lvt'
+PA0        = '-1.5863911e-013+dpa0prf_lvt'
+AGS        = '-8.9308661+dagsprf_lvt'
+LAGS       = '1.1732203e-006+dlagsprf_lvt'
+WAGS       = '6.1834266e-006+dwagsprf_lvt'
+PAGS       = '-5.4677612e-013+dpagsprf_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmprf_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmprf_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmprf_lvt'
+PPCLM      = '1.3219926e-014+dppclmprf_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2prf_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2prf_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2prf_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2prf_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxprf_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgoprf_lvt'
+CGDO       = 'cgoprf_lvt'          CGBO       = 0                   CGDL       = 'cglprf_lvt'
+CGSL       = 'cglprf_lvt'          CLC        = 0			CLE        = 0.6
+CF         = 'cfprf_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flagrf_lvt-0.0210535*sf_flagrf_lvt+0.0210535*fs_flagrf_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flagrf_lvt+2.07377e-09*sf_flagrf_lvt-2.07377e-09*fs_flagrf_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flagrf_lvt+2.14746e-08*sf_flagrf_lvt-2.14746e-08*fs_flagrf_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flagrf_lvt-2.11524e-15*sf_flagrf_lvt+2.11524e-15*fs_flagrf_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+duteprf_lvt'
+UA1        = '1.22313e-009+dua1prf_lvt'
+LUA1       = '3.1354809e-018+dlua1prf_lvt'
+WUA1       = '-1.7551692e-017+dwua1prf_lvt'
+PUA1       = '2.7517381e-024+dpua1prf_lvt'
+UB1        = '-1.6557558e-018+dub1prf_lvt'
+LUB1       = '3.2084074e-028+dlub1prf_lvt'
+WUB1       = '-1.6570695e-025+dwub1prf_lvt'
+PUB1       = '1.3368954e-032+dpub1prf_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datprf_lvt'
+NOIA       = 'noiaprf_lvt'
+NOIB       = 'noibprf_lvt'
+NOIC       = 'noicprf_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dluteprf_lvt'      WUTE       = '0+dwuteprf_lvt'      PUTE       = '0+dputeprf_lvt'
+LAT        = '0+dlatprf_lvt'       WAT        = '0+dwatprf_lvt'       PAT        = '0+dpatprf_lvt'
+LNFACTOR   = '0+dlnfactorprf_lvt-1.08707e-08*ff_flagrf_lvt+0.0*ss_flagrf_lvt-8.69675e-09*sf_flagrf_lvt-6.90695e-08*fs_flagrf_lvt'
+WNFACTOR   = '0+dwnfactorprf_lvt-8.05299e-07*ff_flagrf_lvt+0.0*ss_flagrf_lvt-6.44238e-07*sf_flagrf_lvt-1.6106e-07*fs_flagrf_lvt'
+PNFACTOR   = '0+dpnfactorprf_lvt+7.93218e-14*ff_flagrf_lvt+0.0*ss_flagrf_lvt+6.34573e-14*sf_flagrf_lvt+1.58643e-14*fs_flagrf_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_lvt_f D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.06                    TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.00022                 
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.9                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.003                   FCS    = 0			   )

.MODEL pdio_rf_lvt_g D (						   LEVEL  = 3
+IS     = 1.15e-07                IKR    = 1E10
+N      = 1                       BV     = 9.6                     IBV    = 0.03
+JSW    = 1.7e-13                 CJ     = 'cjprf_lvt'             PJ     = 8.4E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_lvt'
+AREA   = 3.92e-8                 MJSW   = 0.9                     TLEVC  = 1
+CTA    = 0.00091                 CTP    = 0.003                   
+TCV    = -8.0E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 0.0017                  TREF   = 25
+TPHP   = 0.0005                  FCS    = 0			   )

.MODEL DNWPSUB_prf_lvt D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_lvt'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_lvt'
+ N      = '1.02*n_d_dnw_prf_lvt'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_lvt)'  CJ     = '1.15E-04*cj_d_dnw_prf_lvt' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_lvt'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_lvt D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_lvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_lvt'
+ N      = '1.02*n_d_prf_lvt'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_lvt)'  CJ     = '1.37E-04*cj_d_prf_lvt'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_lvt'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_lvt_nw_5t
.ENDL RF_MOS_lvt






**************************************************************************************************
*
* 1.8V IO MOS MODEL
*
*
*
*              .lib RF_MOS_18
*
*              Model name           nr               lr (um)           wr (um)
*                               low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_18        1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_18        1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_18_nw     1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*              nmos_rf_18_6t     1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_18_5t     1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_18_nw_5t  1     32         0.26    0.38     1.0    10.0
*            -------------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************

***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+A1rf_18='par6*4.8844*3/2.2'
+A2rf_18='par7*3.6211*3/2.2'
+A3rf_18='par8*3.1765*3/2.2'
+A4rf_18='par9*1.3928*3/2.2'
+toxnrf_18        ='5.6e-09+(-2.9051e-011)*A1rf_18+(1.0524e-011)*A2rf_18+(-6.11e-011)*A3rf_18+(1.9574e-011)*A4rf_18'
+dxlnrf_18        ='0+(-8.7742e-010)*A1rf_18+(4.0539e-010)*A2rf_18+(-2.9313e-009)*A3rf_18+(7.5636e-010)*A4rf_18'
+dxwnrf_18        ='0+(1.2502e-009)*A1rf_18+(1.4002e-009)*A2rf_18+(3.7127e-009)*A3rf_18+(-9.9453e-010)*A4rf_18'
+cjnrf_18         ='1.1950e-03+(-1.1483e-005)*A1rf_18+(-8.9571e-006)*A2rf_18+(4.3258e-006)*A3rf_18+(3.3359e-006)*A4rf_18'
+cjswnrf_18       ='1.6500e-10+(-1.5855e-012)*A1rf_18+(-1.2368e-012)*A2rf_18+(5.9728e-013)*A3rf_18+(4.6052e-013)*A4rf_18'
+cjswgnrf_18      ='2.0800e-10+(-1.9987e-012)*A1rf_18+(-1.5591e-012)*A2rf_18+(7.5294e-013)*A3rf_18+(5.8053e-013)*A4rf_18'
+cgonrf_18        ='9.95494e-11+(6.7482e-013)*A1rf_18+(-2.4444e-013)*A2rf_18+(1.4192e-012)*A3rf_18+(-4.5469e-013)*A4rf_18'
+cglnrf_18        ='2.67995e-10+(1.8167e-012)*A1rf_18+(-6.5807e-013)*A2rf_18+(3.8207e-012)*A3rf_18+(-1.224e-012)*A4rf_18'
+dvthnrf_18       ='0+(-0.0019918)*A1rf_18+(-0.003373)*A2rf_18+(0.00046738)*A3rf_18+(0.00060958)*A4rf_18'
+dlvthnrf_18      ='0+(-4.0919e-010)*A1rf_18+(-4.1802e-010)*A2rf_18+(1.4887e-010)*A3rf_18+(1.5429e-010)*A4rf_18'
+dwvthnrf_18      ='0+(-1.3431e-010)*A1rf_18+(-1.3975e-010)*A2rf_18+(5.0205e-011)*A3rf_18+(5.6487e-011)*A4rf_18'
+dpvthnrf_18      ='0+(-2.983e-016)*A1rf_18+(-3.235e-016)*A2rf_18+(1.1844e-016)*A3rf_18+(1.5571e-016)*A4rf_18'
+dcitnrf_18       ='0+(-1.2806e-005)*A1rf_18+(-1.4097e-005)*A2rf_18+(5.1948e-006)*A3rf_18+(7.1655e-006)*A4rf_18'
+dlcitnrf_18      ='0+(-2.9669e-012)*A1rf_18+(-4.4006e-012)*A2rf_18+(1.8026e-012)*A3rf_18+(4.2731e-012)*A4rf_18'
+dwu0nrf_18       ='0+(1.4056e-011)*A1rf_18+(1.3852e-011)*A2rf_18+(-4.8461e-012)*A3rf_18+(-4.132e-012)*A4rf_18'
+dpu0nrf_18       ='0+(1.0153e-017)*A1rf_18+(6.3139e-018)*A2rf_18+(-1.5511e-018)*A3rf_18+(5.5177e-018)*A4rf_18'
+da0nrf_18        ='0+(-0.0062062)*A1rf_18+(0.00093485)*A2rf_18+(0.0032361)*A3rf_18+(0.0017039)*A4rf_18'
+dla0nrf_18       ='0+(-1.2412e-009)*A1rf_18+(1.8697e-010)*A2rf_18+(6.4721e-010)*A3rf_18+(3.4078e-010)*A4rf_18'
+dlvsatnrf_18     ='0+(-8.6887e-005)*A1rf_18+(1.3088e-005)*A2rf_18+(4.5305e-005)*A3rf_18+(2.3855e-005)*A4rf_18'
+dpvsatnrf_18     ='0+(-3.125e-012)*A1rf_18+(6.1228e-013)*A2rf_18+(-8.7195e-013)*A3rf_18+(-7.5837e-012)*A4rf_18'
+dpclmnrf_18      ='max(-0.18,0+(0.014056)*A1rf_18+(0.013852)*A2rf_18+(-0.0048461)*A3rf_18+(-0.004132)*A4rf_18)'
+dppclmnrf_18     ='0+(7.5001e-016)*A1rf_18+(-1.4695e-016)*A2rf_18+(2.0927e-016)*A3rf_18+(1.8201e-015)*A4rf_18'
+dleta0nrf_18     ='0+(3.9835e-010)*A1rf_18+(1.7105e-010)*A2rf_18+(-2.0374e-011)*A3rf_18+(3.9304e-010)*A4rf_18'
+dpeta0nrf_18     ='0+(5.7782e-016)*A1rf_18+(7.171e-016)*A2rf_18+(-2.7718e-016)*A3rf_18+(-5.0995e-016)*A4rf_18'
+dk2nrf_18        ='0+(-0.00098395)*A1rf_18+(-0.00096966)*A2rf_18+(0.00033922)*A3rf_18+(0.00028924)*A4rf_18'
+dlk2nrf_18       ='0+(-9.8395e-011)*A1rf_18+(-9.6966e-011)*A2rf_18+(3.3922e-011)*A3rf_18+(2.8924e-011)*A4rf_18'
+cfnrf_18         ='9.000000e-011+(6.1008e-013)*A1rf_18+(-2.2099e-013)*A2rf_18+(1.2831e-012)*A3rf_18+(-4.1105e-013)*A4rf_18+2.4e-11'
+toxprf_18        ='5.9e-09+(-2.9051e-011)*A1rf_18+(1.0524e-011)*A2rf_18+(-6.11e-011)*A3rf_18+(1.9574e-011)*A4rf_18'
+dxlprf_18        ='0+(-8.7742e-010)*A1rf_18+(4.0539e-010)*A2rf_18+(-2.9313e-009)*A3rf_18+(7.5636e-010)*A4rf_18'
+dxwprf_18        ='max(-3.1e-8,0+(8.5562e-010)*A1rf_18+(-2.3731e-009)*A2rf_18+(3.3224e-009)*A3rf_18+(-8.2073e-010)*A4rf_18)'
+cjprf_18         ='0.001111+(-8.6302e-006)*A1rf_18+(1.1236e-005)*A2rf_18+(6.0451e-006)*A3rf_18+(2.2003e-006)*A4rf_18'
+cjswprf_18       ='9.7000e-11+(-7.535e-013)*A1rf_18+(9.8097e-013)*A2rf_18+(5.2778e-013)*A3rf_18+(1.9205e-013)*A4rf_18'
+cjswgprf_18      ='1.6800e-10+(-1.305e-012)*A1rf_18+(1.699e-012)*A2rf_18+(9.141e-013)*A3rf_18+(3.3263e-013)*A4rf_18'
+cgoprf_18        ='1.19935e-10+(8.1294e-013)*A1rf_18+(-2.9449e-013)*A2rf_18+(1.7099e-012)*A3rf_18+(-5.4775e-013)*A4rf_18'
+cglprf_18        ='2.49822e-10+(1.6935e-012)*A1rf_18+(-6.1344e-013)*A2rf_18+(3.5616e-012)*A3rf_18+(-1.141e-012)*A4rf_18'
+dvthprf_18       ='0+(0.0012355)*A1rf_18+(-0.0038591)*A2rf_18+(-0.0012154)*A3rf_18+(-0.00027645)*A4rf_18'
+dlvthprf_18      ='0+(1.3028e-010)*A1rf_18+(-2.5775e-010)*A2rf_18+(-1.3019e-010)*A3rf_18+(-1.1609e-010)*A4rf_18'
+dwvthprf_18      ='0+(1.0768e-010)*A1rf_18+(-1.7592e-010)*A2rf_18+(-8.0982e-011)*A3rf_18+(-2.6836e-011)*A4rf_18'
+dpvthprf_18      ='0+(3.7968e-016)*A1rf_18+(-6.4722e-016)*A2rf_18+(-3.0486e-016)*A3rf_18+(-1.448e-016)*A4rf_18'
+du0prf_18        ='0+(-4.9737e-006)*A1rf_18+(8.0582e-007)*A2rf_18+(1.5929e-006)*A3rf_18+(-2.0111e-006)*A4rf_18'
+dpu0prf_18       ='0+(-3.125e-019)*A1rf_18+(6.1228e-020)*A2rf_18+(-8.7195e-020)*A3rf_18+(-7.5837e-019)*A4rf_18'
+dlvsatprf_18     ='0+(6.2501e-006)*A1rf_18+(-1.2246e-006)*A2rf_18+(1.7439e-006)*A3rf_18+(1.5167e-005)*A4rf_18'
+dpvsatprf_18     ='0+(-7.086e-011)*A1rf_18+(1.0677e-010)*A2rf_18+(4.6845e-011)*A3rf_18+(9.3422e-013)*A4rf_18'
+dla0prf_18       ='0+(-7.2592e-009)*A1rf_18+(9.1632e-009)*A2rf_18+(3.5259e-009)*A3rf_18+(-3.2084e-009)*A4rf_18'
+dpa0prf_18       ='0+(-4.5183e-016)*A1rf_18+(1.6367e-015)*A2rf_18+(9.8421e-016)*A3rf_18+(1.7851e-015)*A4rf_18'
+dagsprf_18       ='0+(-4.5183e-005)*A1rf_18+(0.00016367)*A2rf_18+(9.8421e-005)*A3rf_18+(0.00017851)*A4rf_18'
+dpeta0prf_18     ='0+(3.8555e-016)*A1rf_18+(-5.4e-016)*A2rf_18+(-2.2551e-016)*A3rf_18+(7.1166e-017)*A4rf_18'
+dlk2prf_18       ='0+(-7.5379e-011)*A1rf_18+(1.2314e-010)*A2rf_18+(5.6687e-011)*A3rf_18+(1.8785e-011)*A4rf_18'
+cfprf_18         ='9.000000e-011+(6.1008e-013)*A1rf_18+(-2.2099e-013)*A2rf_18+(1.2831e-012)*A3rf_18+(-4.1105e-013)*A4rf_18+2.4e-11'
+dlcnrf_18        =6.03005e-08
+dwcitnrf_18      =0
+dpcitnrf_18      =0
+du0nrf_18        =0
+dlu0nrf_18       =0
+dwa0nrf_18       =0
+dpa0nrf_18       =0
+dagsnrf_18       =0
+dlagsnrf_18      =0
+dwagsnrf_18      =0
+dpagsnrf_18      =0
+dvsatnrf_18      =0
+dwvsatnrf_18     =0
+dlpclmnrf_18     =0
+dwpclmnrf_18     =0
+deta0nrf_18      =0
+dweta0nrf_18     =0
+dwk2nrf_18       =0
+dpk2nrf_18       =0
+dlcprf_18        =6.40638e-08
+dlu0prf_18       =0
+dwu0prf_18       =0
+dnfactorprf_18   =0
+dlnfactorprf_18  =0
+dwnfactorprf_18  =0
+dpnfactorprf_18  =0
+dvoffprf_18      =0
+dlvoffprf_18     =0
+dwvoffprf_18     =0
+dpvoffprf_18     =0
+dcitprf_18       =0
+dlcitprf_18      =0
+dwcitprf_18      =0
+dpcitprf_18      =0
+dvsatprf_18      =0
+dwvsatprf_18     =0
+da0prf_18        =0
+dwa0prf_18       =0
+dlagsprf_18      =0
+dwagsprf_18      =0
+dpagsprf_18      =0
+dpclmprf_18      =0
+dlpclmprf_18     =0
+dwpclmprf_18     =0
+dppclmprf_18     =0
+deta0prf_18      =0
+dleta0prf_18     =0
+dweta0prf_18     =0
+dk2prf_18        =0
+dwk2prf_18       =0
+dpk2prf_18       =0
+is_d_dnw_nrf_18= 1         x_jsw_d_dnw_nrf_18= 0         n_d_dnw_nrf_18= 1         rs_d_dnw_nrf_18= 1
+cj_d_dnw_nrf_18= 1          cjsw_d_dnw_nrf_18= 1
+is_d_dnw_prf_18= 1         x_jsw_d_dnw_prf_18= 0         n_d_dnw_prf_18= 1         rs_d_dnw_prf_18= 1
+cj_d_dnw_prf_18= 1          cjsw_d_dnw_prf_18= 1
+is_d_prf_18= 1                 x_jsw_d_prf_18= 0             n_d_prf_18= 1             rs_d_prf_18= 1
+cj_d_prf_18= 1                  cjsw_d_prf_18= 1
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL mc_RFMOS_18








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+toxnrf_18        = 5.6e-09       dxlnrf_18        = 0             dxwnrf_18        = 0
+cjnrf_18         = 1.1950E-03    cjswnrf_18       = 1.6500E-10    cjswgnrf_18      = 2.0800E-10
+cgonrf_18        = 9.95494E-11   cglnrf_18        = 2.67995E-10   dlcnrf_18        = 6.03005E-08
+dvthnrf_18       = 0             dlvthnrf_18      = 0             dwvthnrf_18      = 0
+dpvthnrf_18      = 0             dcitnrf_18       = 0             dlcitnrf_18      = 0
+dwcitnrf_18      = 0             dpcitnrf_18      = 0             du0nrf_18        = 0
+dlu0nrf_18       = 0             dwu0nrf_18       = 0             dpu0nrf_18       = 0
+da0nrf_18        = 0             dla0nrf_18       = 0             dwa0nrf_18       = 0
+dpa0nrf_18       = 0             dagsnrf_18       = 0             dlagsnrf_18      = 0
+dwagsnrf_18      = 0             dpagsnrf_18      = 0             dvsatnrf_18      = 0
+dlvsatnrf_18     = 0             dwvsatnrf_18     = 0             dpvsatnrf_18     = 0
+dpclmnrf_18      = 0             dlpclmnrf_18     = 0             dwpclmnrf_18     = 0
+dppclmnrf_18     = 0             deta0nrf_18      = 0             dleta0nrf_18     = 0
+dweta0nrf_18     = 0             dpeta0nrf_18     = 0             dk2nrf_18        = 0
+dlk2nrf_18       = 0             dwk2nrf_18       = 0             dpk2nrf_18       = 0
+cfnrf_18         = '9e-11 + 2.4e-11'
+toxprf_18        = 5.9e-09       dxlprf_18        = 0             dxwprf_18        = 0
+cjprf_18         = 0.001111      cjswprf_18       = 9.7000E-11    cjswgprf_18      = 1.6800E-10
+cgoprf_18        = 1.19935E-10   cglprf_18        = 2.49822E-10   dlcprf_18        = 6.40638E-08
+dvthprf_18       = 0             dlvthprf_18      = 0             dwvthprf_18      = 0
+dpvthprf_18      = 0             du0prf_18        = 0             dlu0prf_18       = 0
+dwu0prf_18       = 0             dpu0prf_18       = 0             dnfactorprf_18   = 0
+dlnfactorprf_18  = 0             dwnfactorprf_18  = 0             dpnfactorprf_18  = 0
+dvoffprf_18      = 0             dlvoffprf_18     = 0             dwvoffprf_18     = 0
+dpvoffprf_18     = 0             dcitprf_18       = 0             dlcitprf_18      = 0
+dwcitprf_18      = 0             dpcitprf_18      = 0             dvsatprf_18      = 0
+dlvsatprf_18     = 0             dwvsatprf_18     = 0             dpvsatprf_18     = 0
+da0prf_18        = 0             dla0prf_18       = 0             dwa0prf_18       = 0
+dpa0prf_18       = 0             dagsprf_18       = 0             dlagsprf_18      = 0
+dwagsprf_18      = 0             dpagsprf_18      = 0             dpclmprf_18      = 0
+dlpclmprf_18     = 0             dwpclmprf_18     = 0             dppclmprf_18     = 0
+deta0prf_18      = 0             dleta0prf_18     = 0             dweta0prf_18     = 0
+dpeta0prf_18     = 0             dk2prf_18        = 0             dlk2prf_18       = 0
+dwk2prf_18       = 0             dpk2prf_18       = 0             cfprf_18         = '9e-11 + 2.4e-11'
+is_d_dnw_nrf_18= 1         x_jsw_d_dnw_nrf_18= 0         n_d_dnw_nrf_18= 1         rs_d_dnw_nrf_18= 1
+cj_d_dnw_nrf_18= 1          cjsw_d_dnw_nrf_18= 1
+is_d_dnw_prf_18= 1         x_jsw_d_dnw_prf_18= 0         n_d_dnw_prf_18= 1         rs_d_dnw_prf_18= 1
+cj_d_dnw_prf_18= 1          cjsw_d_dnw_prf_18= 1
+is_d_prf_18= 1                 x_jsw_d_prf_18= 0             n_d_prf_18= 1             rs_d_prf_18= 1
+cj_d_prf_18= 1                  cjsw_d_prf_18= 1
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL TT_RFMOS_18








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+toxnrf_18        = 5.9e-09       dxlnrf_18        = 1e-08         dxwnrf_18        = -1.2e-08
+cjnrf_18         = 0.00127865    cjswnrf_18       = 1.7655E-10    cjswgnrf_18      = 2.2256E-10
+cgonrf_18        = 9.25809E-11   cglnrf_18        = 2.49235E-10   dlcnrf_18        = 6.03005E-08
+dvthnrf_18       = 0.013         dlvthnrf_18      = 2.8e-9        dwvthnrf_18      = 0.9e-9
+dpvthnrf_18      = 1.9e-15       dcitnrf_18       = 0.8e-4        dlcitnrf_18      = 1e-11
+dwcitnrf_18      = 0             dpcitnrf_18      = 0             du0nrf_18        = 0
+dlu0nrf_18       = 0             dwu0nrf_18       = -1e-10        dpu0nrf_18       = -1e-16
+da0nrf_18        = 0.05          dla0nrf_18       = 1e-8          dwa0nrf_18       = 0
+dpa0nrf_18       = 0             dagsnrf_18       = 0             dlagsnrf_18      = 0
+dwagsnrf_18      = 0             dpagsnrf_18      = 0             dvsatnrf_18      = 0
+dlvsatnrf_18     = 7e-4          dwvsatnrf_18     = 0             dpvsatnrf_18     = 0.5e-10
+dpclmnrf_18      = -0.1          dlpclmnrf_18     = 0             dwpclmnrf_18     = 0
+dppclmnrf_18     = -1.2e-14      deta0nrf_18      = 0             dleta0nrf_18     = -4.5e-9
+dweta0nrf_18     = 0             dpeta0nrf_18     = -3e-15        dk2nrf_18        = 0.007
+dlk2nrf_18       = 7e-10         dwk2nrf_18       = 0             dpk2nrf_18       = 0
+cfnrf_18         = '8.37e-11 + 2.4e-11'
+toxprf_18        = 6.2e-09       dxlprf_18        = 1e-08         dxwprf_18        = -1.2e-08
+cjprf_18         = 0.00118877    cjswprf_18       = 1.0379E-10    cjswgprf_18      = 1.7976E-10
+cgoprf_18        = 1.11540E-10   cglprf_18        = 2.32334E-10   dlcprf_18        = 6.40638E-08
+dvthprf_18       = -0.013        dlvthprf_18      = -1e-9         dwvthprf_18      = -1e-9
+dpvthprf_18      = -3.4e-15      du0prf_18        = 0.5e-4        dlu0prf_18       = 0
+dwu0prf_18       = 0             dpu0prf_18       = 0.5e-17       dnfactorprf_18   = 0
+dlnfactorprf_18  = 0             dwnfactorprf_18  = 0             dpnfactorprf_18  = 0
+dvoffprf_18      = 0             dlvoffprf_18     = 0             dwvoffprf_18     = 0
+dpvoffprf_18     = 0             dcitprf_18       = 0             dlcitprf_18      = 0
+dwcitprf_18      = 0             dpcitprf_18      = 0             dvsatprf_18      = 0
+dlvsatprf_18     = -1e-4         dwvsatprf_18     = 0             dpvsatprf_18     = 7e-10
+da0prf_18        = 0             dla0prf_18       = 8e-8          dwa0prf_18       = 0
+dpa0prf_18       = 0             dagsprf_18       = 0             dlagsprf_18      = 0
+dwagsprf_18      = 0             dpagsprf_18      = 0             dpclmprf_18      = 0
+dlpclmprf_18     = 0             dwpclmprf_18     = 0             dppclmprf_18     = 0
+deta0prf_18      = 0             dleta0prf_18     = 0             dweta0prf_18     = 0
+dpeta0prf_18     = -4e-15        dk2prf_18        = 0             dlk2prf_18       = 7e-10
+dwk2prf_18       = 0             dpk2prf_18       = 0             cfprf_18         = '8.37e-11 + 2.4e-11'
+is_d_dnw_nrf_18= 0.7         x_jsw_d_dnw_nrf_18= -1         n_d_dnw_nrf_18= 0.9975         rs_d_dnw_nrf_18= 1.2
+cj_d_dnw_nrf_18= 1.07          cjsw_d_dnw_nrf_18= 1.07
+is_d_dnw_prf_18= 0.7         x_jsw_d_dnw_prf_18= -1         n_d_dnw_prf_18= 0.9975         rs_d_dnw_prf_18= 1.2
+cj_d_dnw_prf_18= 1.07          cjsw_d_dnw_prf_18=  1.07
+is_d_prf_18= 0.7                 x_jsw_d_prf_18= -1             n_d_prf_18= 0.9975             rs_d_prf_18= 1.2
+cj_d_prf_18= 1.07                  cjsw_d_prf_18=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL SS_RFMOS_18








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+toxnrf_18        = 5.3e-09       dxlnrf_18        = -1e-08        dxwnrf_18        = 1.2e-08
+cjnrf_18         = 0.00111135    cjswnrf_18       = 1.5345E-10    cjswgnrf_18      = 1.9344E-10
+cgonrf_18        = 1.06518E-10   cglnrf_18        = 2.86755E-10   dlcnrf_18        = 6.03005E-08
+dvthnrf_18       = -0.013        dlvthnrf_18      = -3.0e-9       dwvthnrf_18      = -1e-9
+dpvthnrf_18      = -2.3e-15      dcitnrf_18       = -1e-4         dlcitnrf_18      = -3e-11
+dwcitnrf_18      = 0             dpcitnrf_18      = 0             du0nrf_18        = 0
+dlu0nrf_18       = 0             dwu0nrf_18       = 1e-10         dpu0nrf_18       = 0.5e-16
+da0nrf_18        = -0.05         dla0nrf_18       = -1e-8         dwa0nrf_18       = 0
+dpa0nrf_18       = 0             dagsnrf_18       = 0             dlagsnrf_18      = 0
+dwagsnrf_18      = 0             dpagsnrf_18      = 0             dvsatnrf_18      = 0
+dlvsatnrf_18     = -7e-4         dwvsatnrf_18     = 0             dpvsatnrf_18     = 0
+dpclmnrf_18      = 0.1           dlpclmnrf_18     = 0             dwpclmnrf_18     = 0
+dppclmnrf_18     = 0             deta0nrf_18      = 0             dleta0nrf_18     = 1.5e-9
+dweta0nrf_18     = 0             dpeta0nrf_18     = 5e-15         dk2nrf_18        = -0.007
+dlk2nrf_18       = -7e-10        dwk2nrf_18       = 0             dpk2nrf_18       = 0
+cfnrf_18         = '9.63e-11 + 2.4e-11'
+toxprf_18        = 5.6e-09       dxlprf_18        = -1e-08        dxwprf_18        = 1.2e-08
+cjprf_18         = 0.00103323    cjswprf_18       = 9.0210E-11    cjswgprf_18      = 1.5624E-10
+cgoprf_18        = 1.28330E-10   cglprf_18        = 2.67310E-10   dlcprf_18        = 6.40638E-08
+dvthprf_18       = 0.013         dlvthprf_18      = 1.5e-9        dwvthprf_18      = 1e-9
+dpvthprf_18      = 3.7e-15       du0prf_18        = -0.3e-4       dlu0prf_18       = 0
+dwu0prf_18       = 0             dpu0prf_18       = 0             dnfactorprf_18   = 0
+dlnfactorprf_18  = 0             dwnfactorprf_18  = 0             dpnfactorprf_18  = 0
+dvoffprf_18      = 0             dlvoffprf_18     = 0             dwvoffprf_18     = 0
+dpvoffprf_18     = 0             dcitprf_18       = 0             dlcitprf_18      = 0
+dwcitprf_18      = 0             dpcitprf_18      = 0             dvsatprf_18      = 0
+dlvsatprf_18     = 0             dwvsatprf_18     = 0             dpvsatprf_18     = -6e-10
+da0prf_18        = 0             dla0prf_18       = -5e-8         dwa0prf_18       = 0
+dpa0prf_18       = -1e-14        dagsprf_18       = -0.001        dlagsprf_18      = 0
+dwagsprf_18      = 0             dpagsprf_18      = 0             dpclmprf_18      = 0
+dlpclmprf_18     = 0             dwpclmprf_18     = 0             dppclmprf_18     = 0
+deta0prf_18      = 0             dleta0prf_18     = 0             dweta0prf_18     = 0
+dpeta0prf_18     = 3e-15         dk2prf_18        = 0             dlk2prf_18       = -7e-10
+dwk2prf_18       = 0             dpk2prf_18       = 0             cfprf_18         = '9.63e-11 + 2.4e-11'
+is_d_dnw_nrf_18= 1.3         x_jsw_d_dnw_nrf_18= 1         n_d_dnw_nrf_18= 1.0025         rs_d_dnw_nrf_18= 0.8
+cj_d_dnw_nrf_18= 0.93          cjsw_d_dnw_nrf_18= 0.93
+is_d_dnw_prf_18= 1.3         x_jsw_d_dnw_prf_18= 1         n_d_dnw_prf_18= 1.0025         rs_d_dnw_prf_18= 0.8
+cj_d_dnw_prf_18= 0.93          cjsw_d_dnw_prf_18=  0.93
+is_d_prf_18= 1.3                 x_jsw_d_prf_18= 1             n_d_prf_18= 1.0025             rs_d_prf_18= 0.8
+cj_d_prf_18= 0.93                  cjsw_d_prf_18=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL FF_RFMOS_18








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+A1Nrf_18=1 A1Prf_18=-1 A2Nrf_18=0 A2Prf_18=0 A3Nrf_18=-1 A3Prf_18=1 A4NPrf_18=0
+toxnrf_18 = '5.6e-09 + 3.0000e-010*A4NPrf_18'     dxlnrf_18 = '1e-008*A2Nrf_18'                     dxwnrf_18 = '1.2e-008*A3Nrf_18'
+cjnrf_18 = '1.1950E-03 * (1+0.070*0.8)'      cjswnrf_18 = '1.6500E-10 * (1+0.070*0.8)'    cjswgnrf_18 = '2.0800E-10 * (1+0.070*0.8)'
+cgonrf_18 = '9.95494E-11 * (1-0.070*A4NPrf_18)'   cglnrf_18 = '2.67995E-10 * (1-0.070*A4NPrf_18)'   dlcnrf_18 = 6.03005E-08
+dvthnrf_18 = '0.023*A1Nrf_18'                     dlvthnrf_18 = '3e-009*A1Nrf_18'                   dwvthnrf_18 = '1e-009*A1Nrf_18'
+dpvthnrf_18 = '2.3e-015*A1Nrf_18'                 dcitnrf_18 = '0.0001*A1Nrf_18'                    dlcitnrf_18 = '3e-011*A1Nrf_18'
+dwcitnrf_18 = 0                                 dpcitnrf_18 = 0                                 du0nrf_18 = 0
+dlu0nrf_18 = 0                                  dwu0nrf_18 = '-1e-010*A1Nrf_18'                   dpu0nrf_18 = '-5e-017*A1Nrf_18'
+da0nrf_18 = '0.00*A1Nrf_18'                       dla0nrf_18 = '0e-008*A1Nrf_18'                    dwa0nrf_18 = 0
+dpa0nrf_18 = 0                                  dagsnrf_18 = 0                                  dlagsnrf_18 = 0
+dwagsnrf_18 = 0                                 dpagsnrf_18 = 0                                 dvsatnrf_18 = 0
+dlvsatnrf_18 = '0.0000*A1Nrf_18'                  dwvsatnrf_18 = 0                                dpvsatnrf_18 = 0
+dpclmnrf_18 = '-0.1*A1Nrf_18'                     dlpclmnrf_18 = 0                                dwpclmnrf_18 = 0
+dppclmnrf_18 = 0                                deta0nrf_18 = 0                                 dleta0nrf_18 = '-1.5e-009*A1Nrf_18'
+dweta0nrf_18 = 0                                dpeta0nrf_18 = '-5e-015*A1Nrf_18'                 dk2nrf_18 = '0.007*A1Nrf_18'
+dlk2nrf_18 = '7e-010*A1Nrf_18'                    dwk2nrf_18 = 0                                  dpk2nrf_18 = 0
+cfnrf_18 = '9e-11*(1-0.070*A4NPrf_18)+2.4e-11'
+toxprf_18 = '5.9e-09 + 3.0000e-010*A4NPrf_18'     dxlprf_18 = '1e-008*A2Prf_18'                     dxwprf_18 = '1.2e-008*A3Prf_18'
+cjprf_18 = '0.001111 * (1+0.070*-0.8)'        cjswprf_18 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgprf_18 = '1.6800E-10 * (1+0.070*-0.8)'
+cgoprf_18 = '1.19935E-10 * (1-0.070*A4NPrf_18)'   cglprf_18 = '2.49822E-10 * (1-0.070*A4NPrf_18)'   dlcprf_18 = 6.40638E-08
+dvthprf_18 = '-0.023*A1Prf_18'                    dlvthprf_18 = '-1.5e-009*A1Prf_18'                dwvthprf_18 = '-1e-009*A1Prf_18'
+dpvthprf_18 = '-3.7e-015*A1Prf_18'                du0prf_18 = '0e-005*A1Prf_18'                     dlu0prf_18 = 0
+dwu0prf_18 = 0                                  dpu0prf_18 = 0                                  dnfactorprf_18 = 0
+dlnfactorprf_18 = 0                             dwnfactorprf_18 = 0                             dpnfactorprf_18 = 0
+dvoffprf_18 = 0                                 dlvoffprf_18 = 0                                dwvoffprf_18 = 0
+dpvoffprf_18 = 0                                dcitprf_18 = 0                                  dlcitprf_18 = 0
+dwcitprf_18 = 0                                 dpcitprf_18 = 0                                 dvsatprf_18 = 0
+dlvsatprf_18 = 0                                dwvsatprf_18 = 0                                dpvsatprf_18 = '6e-010*A1Prf_18'
+da0prf_18 = 0                                   dla0prf_18 = '5e-008*A1Prf_18'                    dwa0prf_18 = 0
+dpa0prf_18 = '1e-014*A1Prf_18'                    dagsprf_18 = '0.001*A1Prf_18'                     dlagsprf_18 = 0
+dwagsprf_18 = 0                                 dpagsprf_18 = 0                                 dpclmprf_18 = 0
+dlpclmprf_18 = 0                                dwpclmprf_18 = 0                                dppclmprf_18 = 0
+deta0prf_18 = 0                                 dleta0prf_18 = 0                                dweta0prf_18 = 0
+dpeta0prf_18 = '-3e-015*A1Prf_18'                 dk2prf_18 = 0                                   dlk2prf_18 = '7e-010*A1Prf_18'
+dwk2prf_18 = 0                                  dpk2prf_18 = 0
+cfprf_18 = '9e-11*(1-0.070*A4NPrf_18)+2.4e-11'
+is_d_dnw_nrf_18= 1         x_jsw_d_dnw_nrf_18= 0         n_d_dnw_nrf_18= 1         rs_d_dnw_nrf_18= 1
+cj_d_dnw_nrf_18= 1          cjsw_d_dnw_nrf_18= 1
+is_d_dnw_prf_18= 1         x_jsw_d_dnw_prf_18= 0         n_d_dnw_prf_18= 1         rs_d_dnw_prf_18= 1
+cj_d_dnw_prf_18= 1          cjsw_d_dnw_prf_18= 1
+is_d_prf_18= 1                 x_jsw_d_prf_18= 0             n_d_prf_18= 1             rs_d_prf_18= 1
+cj_d_prf_18= 1                  cjsw_d_prf_18= 1
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL SF_RFMOS_18








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_18
.lib 'crn65lp_v1d5.l' noiseflagrf_18
.param
+parn1rf_18=AGAUSS(0,1,1)
+parn2rf_18=AGAUSS(0,1,1)
+parp1rf_18=AGAUSS(0,1,1)
+parp2rf_18=AGAUSS(0,1,1)
+A1Nrf_18=-1 A1Prf_18=1 A2Nrf_18=0 A2Prf_18=0 A3Nrf_18=1 A3Prf_18=-1 A4NPrf_18=0
+toxnrf_18 = '5.6e-09 + 3.0000e-010*A4NPrf_18'     dxlnrf_18 = '1e-008*A2Nrf_18'                     dxwnrf_18 = '1.2e-008*A3Nrf_18'
+cjnrf_18 = '1.1950E-03 * (1+0.070*-0.8)'      cjswnrf_18 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgnrf_18 = '2.0800E-10 * (1+0.070*-0.8)'
+cgonrf_18 = '9.95494E-11 * (1-0.070*A4NPrf_18)'   cglnrf_18 = '2.67995E-10 * (1-0.070*A4NPrf_18)'   dlcnrf_18 = 6.03005E-08
+dvthnrf_18 = '0.023*A1Nrf_18'                     dlvthnrf_18 = '3e-009*A1Nrf_18'                   dwvthnrf_18 = '1e-009*A1Nrf_18'
+dpvthnrf_18 = '2.3e-015*A1Nrf_18'                 dcitnrf_18 = '0.0001*A1Nrf_18'                    dlcitnrf_18 = '3e-011*A1Nrf_18'
+dwcitnrf_18 = 0                                 dpcitnrf_18 = 0                                 du0nrf_18 = 0
+dlu0nrf_18 = 0                                  dwu0nrf_18 = '-1e-010*A1Nrf_18'                   dpu0nrf_18 = '-5e-017*A1Nrf_18'
+da0nrf_18 = '0.00*A1Nrf_18'                       dla0nrf_18 = '0e-008*A1Nrf_18'                    dwa0nrf_18 = 0
+dpa0nrf_18 = 0                                  dagsnrf_18 = 0                                  dlagsnrf_18 = 0
+dwagsnrf_18 = 0                                 dpagsnrf_18 = 0                                 dvsatnrf_18 = 0
+dlvsatnrf_18 = '0.0000*A1Nrf_18'                  dwvsatnrf_18 = 0                                dpvsatnrf_18 = 0
+dpclmnrf_18 = '-0.1*A1Nrf_18'                     dlpclmnrf_18 = 0                                dwpclmnrf_18 = 0
+dppclmnrf_18 = 0                                deta0nrf_18 = 0                                 dleta0nrf_18 = '-1.5e-009*A1Nrf_18'
+dweta0nrf_18 = 0                                dpeta0nrf_18 = '-5e-015*A1Nrf_18'                 dk2nrf_18 = '0.007*A1Nrf_18'
+dlk2nrf_18 = '7e-010*A1Nrf_18'                    dwk2nrf_18 = 0                                  dpk2nrf_18 = 0
+cfnrf_18 = '9e-11*(1-0.070*A4NPrf_18)+2.4e-11'
+toxprf_18 = '5.9e-09 + 3.0000e-010*A4NPrf_18'     dxlprf_18 = '1e-008*A2Prf_18'                     dxwprf_18 = '1.2e-008*A3Prf_18'
+cjprf_18 = '0.001111 * (1+0.070*0.8)'        cjswprf_18 = '9.7000E-11 * (1+0.070*0.8)'    cjswgprf_18 = '1.6800E-10 * (1+0.070*0.8)'
+cgoprf_18 = '1.19935E-10 * (1-0.070*A4NPrf_18)'   cglprf_18 = '2.49822E-10 * (1-0.070*A4NPrf_18)'   dlcprf_18 = 6.40638E-08
+dvthprf_18 = '-0.023*A1Prf_18'                    dlvthprf_18 = '-1.5e-009*A1Prf_18'                dwvthprf_18 = '-1e-009*A1Prf_18'
+dpvthprf_18 = '-3.7e-015*A1Prf_18'                du0prf_18 = '0e-005*A1Prf_18'                     dlu0prf_18 = 0
+dwu0prf_18 = 0                                  dpu0prf_18 = 0                                  dnfactorprf_18 = 0
+dlnfactorprf_18 = 0                             dwnfactorprf_18 = 0                             dpnfactorprf_18 = 0
+dvoffprf_18 = 0                                 dlvoffprf_18 = 0                                dwvoffprf_18 = 0
+dpvoffprf_18 = 0                                dcitprf_18 = 0                                  dlcitprf_18 = 0
+dwcitprf_18 = 0                                 dpcitprf_18 = 0                                 dvsatprf_18 = 0
+dlvsatprf_18 = 0                                dwvsatprf_18 = 0                                dpvsatprf_18 = '6e-010*A1Prf_18'
+da0prf_18 = 0                                   dla0prf_18 = '5e-008*A1Prf_18'                    dwa0prf_18 = 0
+dpa0prf_18 = '1e-014*A1Prf_18'                    dagsprf_18 = '0.001*A1Prf_18'                     dlagsprf_18 = 0
+dwagsprf_18 = 0                                 dpagsprf_18 = 0                                 dpclmprf_18 = 0
+dlpclmprf_18 = 0                                dwpclmprf_18 = 0                                dppclmprf_18 = 0
+deta0prf_18 = 0                                 dleta0prf_18 = 0                                dweta0prf_18 = 0
+dpeta0prf_18 = '-3e-015*A1Prf_18'                 dk2prf_18 = 0                                   dlk2prf_18 = '7e-010*A1Prf_18'
+dwk2prf_18 = 0                                  dpk2prf_18 = 0
+cfprf_18 = '9e-11*(1-0.070*A4NPrf_18)+2.4e-11'
+is_d_dnw_nrf_18= 1         x_jsw_d_dnw_nrf_18= 0         n_d_dnw_nrf_18= 1         rs_d_dnw_nrf_18= 1
+cj_d_dnw_nrf_18= 1          cjsw_d_dnw_nrf_18= 1
+is_d_dnw_prf_18= 1         x_jsw_d_dnw_prf_18= 0         n_d_dnw_prf_18= 1         rs_d_dnw_prf_18= 1
+cj_d_dnw_prf_18= 1          cjsw_d_dnw_prf_18= 1
+is_d_prf_18= 1                 x_jsw_d_prf_18= 0             n_d_prf_18= 1             rs_d_prf_18= 1
+cj_d_prf_18= 1                  cjsw_d_prf_18= 1
.lib 'crn65lp_v1d5.l' RF_MOS_18
.ENDL FS_RFMOS_18


.LIB RF_MOS_18

.subckt nmos_rf_18 D G S B lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parn1rf_18  temp2=parn2rf_18
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_18='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_18='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_18='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_18='0.00275107*geo_fac*toxnrf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'


.param fn_dice='noiseflagnrf_18_mc*par1fn_mc+noiseflagnrf_18_mc_mis*par2fnrf_18_mc'
.param c1fnrf_18=8.00E+41           c2fnrf_18=5.55E+24           c3fnrf_18=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_18='c1fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'
.param noibnrf_18='c2fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'
.param noicnrf_18='c3fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_18 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   1.8V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************
.MODEL nch_rf_18.1 NMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_18+toxmisnrf_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_18+dlmisnrf_18)'  XW         = '7e-09+(dxwnrf_18+dwmisnrf_18)'
+DLC        = 'dlcnrf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55572846+(dvthnrf_18+vthmisnrf_18)'
+LVTH0      = '1.4037009e-008+dlvthnrf_18'
+WVTH0      = '-3.5642896e-008+dwvthnrf_18'
+PVTH0      = '8.6776455e-015+dpvthnrf_18'
+K1         = 0.71631             K2         = '-0.10872301+dk2nrf_18'
+LK2        = '1.644713e-008+dlk2nrf_18'
+WK2        = '-1.4598472e-008+dwk2nrf_18'
+PK2        = '5.4101782e-015+dpk2nrf_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010116733+dcitnrf_18'
+LCIT       = '-1.6792218e-011+dlcitnrf_18'
+WCIT       = '-2.5887286e-010+dwcitnrf_18'
+PCIT       = '2.4113842e-017+dpcitnrf_18'
+VOFF       = -0.074529266        LVOFF      = -1.2586685e-008     WVOFF      = -7.9767307e-008
+PVOFF      = 1.6854658e-014      NFACTOR    = 0.55                ETA0       = '0.51487061+deta0nrf_18'
+LETA0      = '2.9517528e-009+dleta0nrf_18'
+WETA0      = '2.0516592e-008+dweta0nrf_18'
+PETA0      = '2.5281986e-015+dpeta0nrf_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.045622847+du0nrf_18'
+LU0        = '-2.6499699e-009+dlu0nrf_18'
+WU0        = '7.7644596e-009+dwu0nrf_18'
+PU0        = '-1.894063e-015+dpu0nrf_18'
+UA         = -1.8818992e-010     LUA        = -3.3434682e-016     WUA        = 3.7870577e-016
+PUA        = -2.8619542e-023     UB         = 1.7929581e-018      LUB        = 4.7803414e-025
+WUB        = 6.1084645e-025      PUB        = -2.7351271e-031     UC         = 2.3992245e-010
+LUC        = -3.5871529e-017     WUC        = -4.7194646e-018     PUC        = -9.8716561e-024
+VSAT       = '108695.66+dvsatnrf_18'
+LVSAT      = '-0.0068736361+dlvsatnrf_18'
+WVSAT      = '-0.0068113387+dwvsatnrf_18'
+PVSAT      = '1.668778e-009+dpvsatnrf_18'
+A0         = '0.49116347+da0nrf_18'
+LA0        = '-2.9285861e-007+dla0nrf_18'
+WA0        = '-1.8201203e-007+dwa0nrf_18'
+PA0        = '1.0730242e-013+dpa0nrf_18'
+AGS        = '3.9145724+dagsnrf_18'
+LAGS       = '-6.0317099e-007+dlagsnrf_18'
+WAGS       = '2.2906159e-007+dwagsnrf_18'
+PAGS       = '-1.6779563e-013+dpagsnrf_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067214855        LKETA      = 1.9482929e-008
+WKETA      = 1.3823285e-010      PKETA      = 2.093482e-015       DWG        = 0
+DWB        = 0                   PCLM       = '-0.064254502+dpclmnrf_18'
+LPCLM      = '1.0014829e-007+dlpclmnrf_18'
+WPCLM      = '5.6765043e-007+dwpclmnrf_18'
+PPCLM      = '-1.5578042e-013+dppclmnrf_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015463108       LPDIBLC2   = 7.6691395e-010
+WPDIBLC2   = 4.6473857e-011      PPDIBLC2   = -2.1720814e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_18'           CGDO       = 'cgonrf_18'           CGBO       = 0
+CGDL       = 'cglnrf_18'           CGSL       = 'cglnrf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0010417601
+LTVOFF     = 2.060063e-010       WTVOFF     = 1.8782966e-009      PTVOFF     = -7.1173381e-016
+KT1        = -0.38578061         LKT1       = 3.676321e-008       WKT1       = 2.7053704e-007
+PKT1       = -7.3326104e-014     KT1L       = 0                   KT2        = -0.14373694
+LKT2       = 2.8827219e-008      WKT2       = 4.3187153e-008      PKT2       = -1.0838713e-014
+UTE        = -1.3246716          LUTE       = 7.9544531e-008      WUTE       = 3.2694426e-007
+PUTE       = -8.0101343e-014     UA1        = 3.3726047e-009      LUA1       = -2.7712562e-016
+WUA1       = 9.102561e-016       PUA1       = -2.2762132e-022     UB1        = -4.0327032e-018
+LUB1       = 3.8096885e-025      WUB1       = -1.9655098e-024     PUB1       = 5.9341745e-031
+UC1        = 9.7340458e-011      LUC1       = -7.4108568e-018     WUC1       = -1.7921285e-017
+PUC1       = -8.0935732e-024     PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_18'
+NOIB       = 'noibnrf_18'
+NOIC       = 'noicnrf_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_18'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_18'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends nmos_rf_18

.subckt pmos_rf_18 D G S B lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parp1rf_18  temp2=parp2rf_18
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_18='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_18='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_18='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_18='0.00197184*geo_fac*toxprf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_18_mc*par1fn_mc+noiseflagprf_18_mc_mis*par2fprf_18_mc'
.param c1fprf_18=2.40E+41           c2fprf_18=9.00E+21           c3fprf_18=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_18='c1fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noibprf_18='c2fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noicprf_18='c3fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_18 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf_18.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_18+toxmisprf_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_18+dlmisprf_18)'  XW         = '7e-09+(dxwprf_18+dwmisprf_18)'
+DLC        = 'dlcprf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+(dvthprf_18+vthmisprf_18)'
+LVTH0      = '-1.614965e-008+dlvthprf_18'
+WVTH0      = '2.1213121e-008+dwvthprf_18'
+PVTH0      = '-6.9254286e-015+dpvthprf_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2prf_18'
+LK2        = '-1.4264019e-008+dlk2prf_18'
+WK2        = '-3.6972506e-009+dwk2prf_18'
+PK2        = '2.2445064e-015+dpk2prf_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitprf_18'
+LCIT       = '4.9631869e-012+dlcitprf_18'
+WCIT       = '-1.465091e-010+dwcitprf_18'
+PCIT       = '7.0088675e-018+dpcitprf_18'
+VOFF       = '-0.013277558+dvoffprf_18'
+LVOFF      = '-1.0164244e-008+dlvoffprf_18'
+WVOFF      = '-1.7237725e-008+dwvoffprf_18'
+PVOFF      = '4.5524263e-015+dpvoffprf_18'
+NFACTOR    = '0.63002+dnfactorprf_18'
+ETA0       = '0.68737441+deta0prf_18'
+LETA0      = '-2.8295717e-008+dleta0prf_18'
+WETA0      = '-6.3076868e-007+dweta0prf_18'
+PETA0      = '1.504153e-013+dpeta0prf_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0prf_18'
+LU0        = '8.1401698e-010+dlu0prf_18'
+WU0        = '-2.1279835e-009+dwu0prf_18'
+PU0        = '9.5203784e-016+dpu0prf_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatprf_18'
+LVSAT      = '-0.012785126+dlvsatprf_18'
+WVSAT      = '-0.052549478+dwvsatprf_18'
+PVSAT      = '1.2874622e-008+dpvsatprf_18'
+A0         = '0.82373599+da0prf_18'
+LA0        = '-1.4726459e-008+dla0prf_18'
+WA0        = '9.0657005e-007+dwa0prf_18'
+PA0        = '-2.3198517e-013+dpa0prf_18'
+AGS        = '0.04584401+dagsprf_18'
+LAGS       = '2.9007199e-007+dlagsprf_18'
+WAGS       = '-1.1787255e-007+dwagsprf_18'
+PAGS       = '-2.2144684e-014+dpagsprf_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmprf_18'
+LPCLM      = '1.7897004e-007+dlpclmprf_18'
+WPCLM      = '9.0231296e-007+dwpclmprf_18'
+PPCLM      = '-1.9069126e-013+dppclmprf_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_18'           CGDO       = 'cgoprf_18'           CGBO       = 0
+CGDL       = 'cglprf_18'           CGSL       = 'cglprf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_18'
+NOIB       = 'noibprf_18'
+NOIC       = 'noicprf_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_18'
+WNFACTOR   = '0+dwnfactorprf_18'   PNFACTOR   = '0+dpnfactorprf_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_18


.subckt pmos_rf_18_nw D G S B lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parp1rf_18  temp2=parp2rf_18
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_18='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_18='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_18='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_18='0.00197184*geo_fac*toxprf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_18_mc*par1fn_mc+noiseflagprf_18_mc_mis*par2fprf_18_mc'
.param c1fprf_18=2.40E+41           c2fprf_18=9.00E+21           c3fprf_18=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_18='c1fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noibprf_18='c2fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noicprf_18='c3fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_18 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf_18.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_18+toxmisprf_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_18+dlmisprf_18)'  XW         = '7e-09+(dxwprf_18+dwmisprf_18)'
+DLC        = 'dlcprf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+(dvthprf_18+vthmisprf_18)'
+LVTH0      = '-1.614965e-008+dlvthprf_18'
+WVTH0      = '2.1213121e-008+dwvthprf_18'
+PVTH0      = '-6.9254286e-015+dpvthprf_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2prf_18'
+LK2        = '-1.4264019e-008+dlk2prf_18'
+WK2        = '-3.6972506e-009+dwk2prf_18'
+PK2        = '2.2445064e-015+dpk2prf_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitprf_18'
+LCIT       = '4.9631869e-012+dlcitprf_18'
+WCIT       = '-1.465091e-010+dwcitprf_18'
+PCIT       = '7.0088675e-018+dpcitprf_18'
+VOFF       = '-0.013277558+dvoffprf_18'
+LVOFF      = '-1.0164244e-008+dlvoffprf_18'
+WVOFF      = '-1.7237725e-008+dwvoffprf_18'
+PVOFF      = '4.5524263e-015+dpvoffprf_18'
+NFACTOR    = '0.63002+dnfactorprf_18'
+ETA0       = '0.68737441+deta0prf_18'
+LETA0      = '-2.8295717e-008+dleta0prf_18'
+WETA0      = '-6.3076868e-007+dweta0prf_18'
+PETA0      = '1.504153e-013+dpeta0prf_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0prf_18'
+LU0        = '8.1401698e-010+dlu0prf_18'
+WU0        = '-2.1279835e-009+dwu0prf_18'
+PU0        = '9.5203784e-016+dpu0prf_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatprf_18'
+LVSAT      = '-0.012785126+dlvsatprf_18'
+WVSAT      = '-0.052549478+dwvsatprf_18'
+PVSAT      = '1.2874622e-008+dpvsatprf_18'
+A0         = '0.82373599+da0prf_18'
+LA0        = '-1.4726459e-008+dla0prf_18'
+WA0        = '9.0657005e-007+dwa0prf_18'
+PA0        = '-2.3198517e-013+dpa0prf_18'
+AGS        = '0.04584401+dagsprf_18'
+LAGS       = '2.9007199e-007+dlagsprf_18'
+WAGS       = '-1.1787255e-007+dwagsprf_18'
+PAGS       = '-2.2144684e-014+dpagsprf_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmprf_18'
+LPCLM      = '1.7897004e-007+dlpclmprf_18'
+WPCLM      = '9.0231296e-007+dwpclmprf_18'
+PPCLM      = '-1.9069126e-013+dppclmprf_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_18'           CGDO       = 'cgoprf_18'           CGBO       = 0
+CGDL       = 'cglprf_18'           CGSL       = 'cglprf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_18'
+NOIB       = 'noibprf_18'
+NOIC       = 'noicprf_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_18'
+WNFACTOR   = '0+dwnfactorprf_18'   PNFACTOR   = '0+dpnfactorprf_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_18_nw


.subckt nmos_rf_18_6t D G S B NG PG lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parn1rf_18  temp2=parn2rf_18
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_18='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_18='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_18='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_18='0.00275107*geo_fac*toxnrf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'

.param fn_dice='noiseflagnrf_18_mc*par1fn_mc+noiseflagnrf_18_mc_mis*par2fnrf_18_mc'
.param c1fnrf_18=8.00E+41           c2fnrf_18=5.55E+24           c3fnrf_18=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_18='c1fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'
.param noibnrf_18='c2fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'
.param noicnrf_18='c3fnrf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_18    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_18  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_18 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   1.8V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************
.MODEL nch_rf_18.1 NMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_18+toxmisnrf_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_18+dlmisnrf_18)'  XW         = '7e-09+(dxwnrf_18+dwmisnrf_18)'
+DLC        = 'dlcnrf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55572846+(dvthnrf_18+vthmisnrf_18)'
+LVTH0      = '1.4037009e-008+dlvthnrf_18'
+WVTH0      = '-3.5642896e-008+dwvthnrf_18'
+PVTH0      = '8.6776455e-015+dpvthnrf_18'
+K1         = 0.71631             K2         = '-0.10872301+dk2nrf_18'
+LK2        = '1.644713e-008+dlk2nrf_18'
+WK2        = '-1.4598472e-008+dwk2nrf_18'
+PK2        = '5.4101782e-015+dpk2nrf_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010116733+dcitnrf_18'
+LCIT       = '-1.6792218e-011+dlcitnrf_18'
+WCIT       = '-2.5887286e-010+dwcitnrf_18'
+PCIT       = '2.4113842e-017+dpcitnrf_18'
+VOFF       = -0.074529266        LVOFF      = -1.2586685e-008     WVOFF      = -7.9767307e-008
+PVOFF      = 1.6854658e-014      NFACTOR    = 0.55                ETA0       = '0.51487061+deta0nrf_18'
+LETA0      = '2.9517528e-009+dleta0nrf_18'
+WETA0      = '2.0516592e-008+dweta0nrf_18'
+PETA0      = '2.5281986e-015+dpeta0nrf_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.045622847+du0nrf_18'
+LU0        = '-2.6499699e-009+dlu0nrf_18'
+WU0        = '7.7644596e-009+dwu0nrf_18'
+PU0        = '-1.894063e-015+dpu0nrf_18'
+UA         = -1.8818992e-010     LUA        = -3.3434682e-016     WUA        = 3.7870577e-016
+PUA        = -2.8619542e-023     UB         = 1.7929581e-018      LUB        = 4.7803414e-025
+WUB        = 6.1084645e-025      PUB        = -2.7351271e-031     UC         = 2.3992245e-010
+LUC        = -3.5871529e-017     WUC        = -4.7194646e-018     PUC        = -9.8716561e-024
+VSAT       = '108695.66+dvsatnrf_18'
+LVSAT      = '-0.0068736361+dlvsatnrf_18'
+WVSAT      = '-0.0068113387+dwvsatnrf_18'
+PVSAT      = '1.668778e-009+dpvsatnrf_18'
+A0         = '0.49116347+da0nrf_18'
+LA0        = '-2.9285861e-007+dla0nrf_18'
+WA0        = '-1.8201203e-007+dwa0nrf_18'
+PA0        = '1.0730242e-013+dpa0nrf_18'
+AGS        = '3.9145724+dagsnrf_18'
+LAGS       = '-6.0317099e-007+dlagsnrf_18'
+WAGS       = '2.2906159e-007+dwagsnrf_18'
+PAGS       = '-1.6779563e-013+dpagsnrf_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067214855        LKETA      = 1.9482929e-008
+WKETA      = 1.3823285e-010      PKETA      = 2.093482e-015       DWG        = 0
+DWB        = 0                   PCLM       = '-0.064254502+dpclmnrf_18'
+LPCLM      = '1.0014829e-007+dlpclmnrf_18'
+WPCLM      = '5.6765043e-007+dwpclmnrf_18'
+PPCLM      = '-1.5578042e-013+dppclmnrf_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015463108       LPDIBLC2   = 7.6691395e-010
+WPDIBLC2   = 4.6473857e-011      PPDIBLC2   = -2.1720814e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_18'           CGDO       = 'cgonrf_18'           CGBO       = 0
+CGDL       = 'cglnrf_18'           CGSL       = 'cglnrf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0010417601
+LTVOFF     = 2.060063e-010       WTVOFF     = 1.8782966e-009      PTVOFF     = -7.1173381e-016
+KT1        = -0.38578061         LKT1       = 3.676321e-008       WKT1       = 2.7053704e-007
+PKT1       = -7.3326104e-014     KT1L       = 0                   KT2        = -0.14373694
+LKT2       = 2.8827219e-008      WKT2       = 4.3187153e-008      PKT2       = -1.0838713e-014
+UTE        = -1.3246716          LUTE       = 7.9544531e-008      WUTE       = 3.2694426e-007
+PUTE       = -8.0101343e-014     UA1        = 3.3726047e-009      LUA1       = -2.7712562e-016
+WUA1       = 9.102561e-016       PUA1       = -2.2762132e-022     UB1        = -4.0327032e-018
+LUB1       = 3.8096885e-025      WUB1       = -1.9655098e-024     PUB1       = 5.9341745e-031
+UC1        = 9.7340458e-011      LUC1       = -7.4108568e-018     WUC1       = -1.7921285e-017
+PUC1       = -8.0935732e-024     PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_18'
+NOIB       = 'noibnrf_18'
+NOIC       = 'noicnrf_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 0
+CJD        = 0			MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 0
+CJSWD      = 0			MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 0
+CJSWGD     = 0			MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_18'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_18'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL PWDNW_nrf_18 D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_18'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_18'
+ N      = '1.02*n_d_dnw_nrf_18'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_18)'  CJ     = '7.31E-04*cj_d_dnw_nrf_18'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_18'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_18 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_18'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_18'
+ N      = '1.02*n_d_dnw_nrf_18'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_18)'  CJ     = '1.15E-04*cj_d_dnw_nrf_18' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_18'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_18_6t

.subckt pmos_rf_18_5t D G S B PG lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parp1rf_18  temp2=parp2rf_18
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_18='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_18='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_18='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_18='0.00197184*geo_fac*toxprf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_18_mc*par1fn_mc+noiseflagprf_18_mc_mis*par2fprf_18_mc'
.param c1fprf_18=2.40E+41           c2fprf_18=9.00E+21           c3fprf_18=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_18='c1fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noibprf_18='c2fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noicprf_18='c3fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'


*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_18  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_18 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf_18.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_18+toxmisprf_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_18+dlmisprf_18)'  XW         = '7e-09+(dxwprf_18+dwmisprf_18)'
+DLC        = 'dlcprf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+(dvthprf_18+vthmisprf_18)'
+LVTH0      = '-1.614965e-008+dlvthprf_18'
+WVTH0      = '2.1213121e-008+dwvthprf_18'
+PVTH0      = '-6.9254286e-015+dpvthprf_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2prf_18'
+LK2        = '-1.4264019e-008+dlk2prf_18'
+WK2        = '-3.6972506e-009+dwk2prf_18'
+PK2        = '2.2445064e-015+dpk2prf_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitprf_18'
+LCIT       = '4.9631869e-012+dlcitprf_18'
+WCIT       = '-1.465091e-010+dwcitprf_18'
+PCIT       = '7.0088675e-018+dpcitprf_18'
+VOFF       = '-0.013277558+dvoffprf_18'
+LVOFF      = '-1.0164244e-008+dlvoffprf_18'
+WVOFF      = '-1.7237725e-008+dwvoffprf_18'
+PVOFF      = '4.5524263e-015+dpvoffprf_18'
+NFACTOR    = '0.63002+dnfactorprf_18'
+ETA0       = '0.68737441+deta0prf_18'
+LETA0      = '-2.8295717e-008+dleta0prf_18'
+WETA0      = '-6.3076868e-007+dweta0prf_18'
+PETA0      = '1.504153e-013+dpeta0prf_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0prf_18'
+LU0        = '8.1401698e-010+dlu0prf_18'
+WU0        = '-2.1279835e-009+dwu0prf_18'
+PU0        = '9.5203784e-016+dpu0prf_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatprf_18'
+LVSAT      = '-0.012785126+dlvsatprf_18'
+WVSAT      = '-0.052549478+dwvsatprf_18'
+PVSAT      = '1.2874622e-008+dpvsatprf_18'
+A0         = '0.82373599+da0prf_18'
+LA0        = '-1.4726459e-008+dla0prf_18'
+WA0        = '9.0657005e-007+dwa0prf_18'
+PA0        = '-2.3198517e-013+dpa0prf_18'
+AGS        = '0.04584401+dagsprf_18'
+LAGS       = '2.9007199e-007+dlagsprf_18'
+WAGS       = '-1.1787255e-007+dwagsprf_18'
+PAGS       = '-2.2144684e-014+dpagsprf_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmprf_18'
+LPCLM      = '1.7897004e-007+dlpclmprf_18'
+WPCLM      = '9.0231296e-007+dwpclmprf_18'
+PPCLM      = '-1.9069126e-013+dppclmprf_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_18'           CGDO       = 'cgoprf_18'           CGBO       = 0
+CGDL       = 'cglprf_18'           CGSL       = 'cglprf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_18'
+NOIB       = 'noibprf_18'
+NOIC       = 'noicprf_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_18'
+WNFACTOR   = '0+dwnfactorprf_18'   PNFACTOR   = '0+dpnfactorprf_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )
.MODEL DNWPSUB_prf_18 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_18'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_18'
+ N      = '1.02*n_d_dnw_prf_18'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_18)'  CJ     = '1.15E-04*cj_d_dnw_prf_18' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_18'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_18 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_18'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_18'
+ N      = '1.02*n_d_prf_18'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_18)'  CJ     = '1.37E-04*cj_d_prf_18'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_18'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_18_5t


.subckt pmos_rf_18_nw_5t D G S B PG lr=0.26E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_18'
.param
+temp1=parp1rf_18  temp2=parp2rf_18
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_18='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_18='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_18='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_18='0.00197184*geo_fac*toxprf_18*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'
.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_18_mc*par1fn_mc+noiseflagprf_18_mc_mis*par2fprf_18_mc'
.param c1fprf_18=2.40E+41           c2fprf_18=9.00E+21           c3fprf_18=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_18*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_18='c1fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noibprf_18='c2fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'
.param noicprf_18='c3fprf_18*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_18)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_18  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_18_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_18_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_18_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_18_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_18 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc
.MODEL pch_rf_18.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 26e-008
+LMAX       = 3.801e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_18+toxmisprf_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_18+dlmisprf_18)'  XW         = '7e-09+(dxwprf_18+dwmisprf_18)'
+DLC        = 'dlcprf_18'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+(dvthprf_18+vthmisprf_18)'
+LVTH0      = '-1.614965e-008+dlvthprf_18'
+WVTH0      = '2.1213121e-008+dwvthprf_18'
+PVTH0      = '-6.9254286e-015+dpvthprf_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2prf_18'
+LK2        = '-1.4264019e-008+dlk2prf_18'
+WK2        = '-3.6972506e-009+dwk2prf_18'
+PK2        = '2.2445064e-015+dpk2prf_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitprf_18'
+LCIT       = '4.9631869e-012+dlcitprf_18'
+WCIT       = '-1.465091e-010+dwcitprf_18'
+PCIT       = '7.0088675e-018+dpcitprf_18'
+VOFF       = '-0.013277558+dvoffprf_18'
+LVOFF      = '-1.0164244e-008+dlvoffprf_18'
+WVOFF      = '-1.7237725e-008+dwvoffprf_18'
+PVOFF      = '4.5524263e-015+dpvoffprf_18'
+NFACTOR    = '0.63002+dnfactorprf_18'
+ETA0       = '0.68737441+deta0prf_18'
+LETA0      = '-2.8295717e-008+dleta0prf_18'
+WETA0      = '-6.3076868e-007+dweta0prf_18'
+PETA0      = '1.504153e-013+dpeta0prf_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0prf_18'
+LU0        = '8.1401698e-010+dlu0prf_18'
+WU0        = '-2.1279835e-009+dwu0prf_18'
+PU0        = '9.5203784e-016+dpu0prf_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatprf_18'
+LVSAT      = '-0.012785126+dlvsatprf_18'
+WVSAT      = '-0.052549478+dwvsatprf_18'
+PVSAT      = '1.2874622e-008+dpvsatprf_18'
+A0         = '0.82373599+da0prf_18'
+LA0        = '-1.4726459e-008+dla0prf_18'
+WA0        = '9.0657005e-007+dwa0prf_18'
+PA0        = '-2.3198517e-013+dpa0prf_18'
+AGS        = '0.04584401+dagsprf_18'
+LAGS       = '2.9007199e-007+dlagsprf_18'
+WAGS       = '-1.1787255e-007+dwagsprf_18'
+PAGS       = '-2.2144684e-014+dpagsprf_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmprf_18'
+LPCLM      = '1.7897004e-007+dlpclmprf_18'
+WPCLM      = '9.0231296e-007+dwpclmprf_18'
+PPCLM      = '-1.9069126e-013+dppclmprf_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_18'           CGDO       = 'cgoprf_18'           CGBO       = 0
+CGDL       = 'cglprf_18'           CGSL       = 'cglprf_18'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_18'
+NOIB       = 'noibprf_18'
+NOIC       = 'noicprf_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_18'
+WNFACTOR   = '0+dwnfactorprf_18'   PNFACTOR   = '0+dpnfactorprf_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_18_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_18_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_18'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_18'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL DNWPSUB_prf_18 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_18'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_18'
+ N      = '1.02*n_d_dnw_prf_18'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_18)'  CJ     = '1.15E-04*cj_d_dnw_prf_18' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_18'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_18 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_18'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_18'
+ N      = '1.02*n_d_prf_18'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_18)'  CJ     = '1.37E-04*cj_d_prf_18'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_18'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_18_nw_5t


.ENDL RF_MOS_18





**************************************************************************************************
*
* 2.5V IO MOS MODEL
*
*
*
*              .lib RF_MOS_25
*
*              Model name           nr               lr (um)           wr (um)
*                               low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_25        1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_25        1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_25_nw     1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*              nmos_rf_25_6t     1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_25_5t     1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_25_nw_5t  1     32         0.28    0.50     1.0    10.0
*            -------------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************

***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+A1rf_25='par6*4.8844*3/2.2'
+A2rf_25='par7*3.6211*3/2.2'
+A3rf_25='par8*3.1765*3/2.2'
+A4rf_25='par9*1.3928*3/2.2'
+toxnrf_25        ='5.6e-09+(-2.9051e-011)*A1rf_25+(1.0524e-011)*A2rf_25+(-6.11e-011)*A3rf_25+(1.9574e-011)*A4rf_25'
+dxlnrf_25        ='0+(-8.7742e-010)*A1rf_25+(4.0539e-010)*A2rf_25+(-2.9313e-009)*A3rf_25+(7.5636e-010)*A4rf_25'
+dxwnrf_25        ='0+(1.2502e-009)*A1rf_25+(1.4002e-009)*A2rf_25+(3.7127e-009)*A3rf_25+(-9.9453e-010)*A4rf_25'
+cjnrf_25         ='1.1950e-03+(-1.1483e-005)*A1rf_25+(-8.9571e-006)*A2rf_25+(4.3258e-006)*A3rf_25+(3.3359e-006)*A4rf_25'
+cjswnrf_25       ='1.6500e-10+(-1.5855e-012)*A1rf_25+(-1.2368e-012)*A2rf_25+(5.9728e-013)*A3rf_25+(4.6052e-013)*A4rf_25'
+cjswgnrf_25      ='2.0800e-10+(-1.9987e-012)*A1rf_25+(-1.5591e-012)*A2rf_25+(7.5294e-013)*A3rf_25+(5.8053e-013)*A4rf_25'
+cgonrf_25        ='9.95494e-11+(6.7482e-013)*A1rf_25+(-2.4444e-013)*A2rf_25+(1.4192e-012)*A3rf_25+(-4.5469e-013)*A4rf_25'
+cglnrf_25        ='2.67995e-10+(1.8167e-012)*A1rf_25+(-6.5807e-013)*A2rf_25+(3.8207e-012)*A3rf_25+(-1.224e-012)*A4rf_25'
+dvthnrf_25       ='0+(-0.0019918)*A1rf_25+(-0.003373)*A2rf_25+(0.00046738)*A3rf_25+(0.00060958)*A4rf_25'
+dlvthnrf_25      ='0+(-4.0919e-010)*A1rf_25+(-4.1802e-010)*A2rf_25+(1.4887e-010)*A3rf_25+(1.5429e-010)*A4rf_25'
+dwvthnrf_25      ='0+(-1.3431e-010)*A1rf_25+(-1.3975e-010)*A2rf_25+(5.0205e-011)*A3rf_25+(5.6487e-011)*A4rf_25'
+dpvthnrf_25      ='0+(-2.983e-016)*A1rf_25+(-3.235e-016)*A2rf_25+(1.1844e-016)*A3rf_25+(1.5571e-016)*A4rf_25'
+dcitnrf_25       ='0+(-1.2806e-005)*A1rf_25+(-1.4097e-005)*A2rf_25+(5.1948e-006)*A3rf_25+(7.1655e-006)*A4rf_25'
+dlcitnrf_25      ='0+(-2.9669e-012)*A1rf_25+(-4.4006e-012)*A2rf_25+(1.8026e-012)*A3rf_25+(4.2731e-012)*A4rf_25'
+dwu0nrf_25       ='0+(1.4056e-011)*A1rf_25+(1.3852e-011)*A2rf_25+(-4.8461e-012)*A3rf_25+(-4.132e-012)*A4rf_25'
+dpu0nrf_25       ='0+(1.0153e-017)*A1rf_25+(6.3139e-018)*A2rf_25+(-1.5511e-018)*A3rf_25+(5.5177e-018)*A4rf_25'
+da0nrf_25        ='0+(-0.0062062)*A1rf_25+(0.00093485)*A2rf_25+(0.0032361)*A3rf_25+(0.0017039)*A4rf_25'
+dla0nrf_25       ='0+(-1.2412e-009)*A1rf_25+(1.8697e-010)*A2rf_25+(6.4721e-010)*A3rf_25+(3.4078e-010)*A4rf_25'
+dlvsatnrf_25     ='0+(-8.6887e-005)*A1rf_25+(1.3088e-005)*A2rf_25+(4.5305e-005)*A3rf_25+(2.3855e-005)*A4rf_25'
+dpvsatnrf_25     ='0+(-3.125e-012)*A1rf_25+(6.1228e-013)*A2rf_25+(-8.7195e-013)*A3rf_25+(-7.5837e-012)*A4rf_25'
+dpclmnrf_25      ='max(-0.18,0+(0.014056)*A1rf_25+(0.013852)*A2rf_25+(-0.0048461)*A3rf_25+(-0.004132)*A4rf_25)'
+dppclmnrf_25     ='0+(7.5001e-016)*A1rf_25+(-1.4695e-016)*A2rf_25+(2.0927e-016)*A3rf_25+(1.8201e-015)*A4rf_25'
+dleta0nrf_25     ='0+(3.9835e-010)*A1rf_25+(1.7105e-010)*A2rf_25+(-2.0374e-011)*A3rf_25+(3.9304e-010)*A4rf_25'
+dpeta0nrf_25     ='0+(5.7782e-016)*A1rf_25+(7.171e-016)*A2rf_25+(-2.7718e-016)*A3rf_25+(-5.0995e-016)*A4rf_25'
+dk2nrf_25        ='0+(-0.00098395)*A1rf_25+(-0.00096966)*A2rf_25+(0.00033922)*A3rf_25+(0.00028924)*A4rf_25'
+dlk2nrf_25       ='0+(-9.8395e-011)*A1rf_25+(-9.6966e-011)*A2rf_25+(3.3922e-011)*A3rf_25+(2.8924e-011)*A4rf_25'
+cfnrf_25         ='9.000000e-011+(6.1008e-013)*A1rf_25+(-2.2099e-013)*A2rf_25+(1.2831e-012)*A3rf_25+(-4.1105e-013)*A4rf_25+2.4e-11'
+toxprf_25        ='5.9e-09+(-2.9051e-011)*A1rf_25+(1.0524e-011)*A2rf_25+(-6.11e-011)*A3rf_25+(1.9574e-011)*A4rf_25'
+dxlprf_25        ='0+(-8.7742e-010)*A1rf_25+(4.0539e-010)*A2rf_25+(-2.9313e-009)*A3rf_25+(7.5636e-010)*A4rf_25'
+dxwprf_25        ='max(-3.1e-8,0+(8.5562e-010)*A1rf_25+(-2.3731e-009)*A2rf_25+(3.3224e-009)*A3rf_25+(-8.2073e-010)*A4rf_25)'
+cjprf_25         ='0.001111+(-8.6302e-006)*A1rf_25+(1.1236e-005)*A2rf_25+(6.0451e-006)*A3rf_25+(2.2003e-006)*A4rf_25'
+cjswprf_25       ='9.7000e-11+(-7.535e-013)*A1rf_25+(9.8097e-013)*A2rf_25+(5.2778e-013)*A3rf_25+(1.9205e-013)*A4rf_25'
+cjswgprf_25      ='1.6800e-10+(-1.305e-012)*A1rf_25+(1.699e-012)*A2rf_25+(9.141e-013)*A3rf_25+(3.3263e-013)*A4rf_25'
+cgoprf_25        ='1.19935e-10+(8.1294e-013)*A1rf_25+(-2.9449e-013)*A2rf_25+(1.7099e-012)*A3rf_25+(-5.4775e-013)*A4rf_25'
+cglprf_25        ='2.49822e-10+(1.6935e-012)*A1rf_25+(-6.1344e-013)*A2rf_25+(3.5616e-012)*A3rf_25+(-1.141e-012)*A4rf_25'
+dvthprf_25       ='0+(0.0012355)*A1rf_25+(-0.0038591)*A2rf_25+(-0.0012154)*A3rf_25+(-0.00027645)*A4rf_25'
+dlvthprf_25      ='0+(1.3028e-010)*A1rf_25+(-2.5775e-010)*A2rf_25+(-1.3019e-010)*A3rf_25+(-1.1609e-010)*A4rf_25'
+dwvthprf_25      ='0+(1.0768e-010)*A1rf_25+(-1.7592e-010)*A2rf_25+(-8.0982e-011)*A3rf_25+(-2.6836e-011)*A4rf_25'
+dpvthprf_25      ='0+(3.7968e-016)*A1rf_25+(-6.4722e-016)*A2rf_25+(-3.0486e-016)*A3rf_25+(-1.448e-016)*A4rf_25'
+du0prf_25        ='0+(-4.9737e-006)*A1rf_25+(8.0582e-007)*A2rf_25+(1.5929e-006)*A3rf_25+(-2.0111e-006)*A4rf_25'
+dpu0prf_25       ='0+(-3.125e-019)*A1rf_25+(6.1228e-020)*A2rf_25+(-8.7195e-020)*A3rf_25+(-7.5837e-019)*A4rf_25'
+dlvsatprf_25     ='0+(6.2501e-006)*A1rf_25+(-1.2246e-006)*A2rf_25+(1.7439e-006)*A3rf_25+(1.5167e-005)*A4rf_25'
+dpvsatprf_25     ='0+(-7.086e-011)*A1rf_25+(1.0677e-010)*A2rf_25+(4.6845e-011)*A3rf_25+(9.3422e-013)*A4rf_25'
+dla0prf_25       ='0+(-7.2592e-009)*A1rf_25+(9.1632e-009)*A2rf_25+(3.5259e-009)*A3rf_25+(-3.2084e-009)*A4rf_25'
+dpa0prf_25       ='0+(-4.5183e-016)*A1rf_25+(1.6367e-015)*A2rf_25+(9.8421e-016)*A3rf_25+(1.7851e-015)*A4rf_25'
+dagsprf_25       ='0+(-4.5183e-005)*A1rf_25+(0.00016367)*A2rf_25+(9.8421e-005)*A3rf_25+(0.00017851)*A4rf_25'
+dpeta0prf_25     ='0+(3.8555e-016)*A1rf_25+(-5.4e-016)*A2rf_25+(-2.2551e-016)*A3rf_25+(7.1166e-017)*A4rf_25'
+dlk2prf_25       ='0+(-7.5379e-011)*A1rf_25+(1.2314e-010)*A2rf_25+(5.6687e-011)*A3rf_25+(1.8785e-011)*A4rf_25'
+cfprf_25         ='9.000000e-011+(6.1008e-013)*A1rf_25+(-2.2099e-013)*A2rf_25+(1.2831e-012)*A3rf_25+(-4.1105e-013)*A4rf_25+2.4e-11'
+dlcnrf_25        =6.03005e-08
+dwcitnrf_25      =0
+dpcitnrf_25      =0
+du0nrf_25        =0
+dlu0nrf_25       =0
+dwa0nrf_25       =0
+dpa0nrf_25       =0
+dagsnrf_25       =0
+dlagsnrf_25      =0
+dwagsnrf_25      =0
+dpagsnrf_25      =0
+dvsatnrf_25      =0
+dwvsatnrf_25     =0
+dlpclmnrf_25     =0
+dwpclmnrf_25     =0
+deta0nrf_25      =0
+dweta0nrf_25     =0
+dwk2nrf_25       =0
+dpk2nrf_25       =0
+dlcprf_25        =6.40638e-08
+dlu0prf_25       =0
+dwu0prf_25       =0
+dnfactorprf_25   =0
+dlnfactorprf_25  =0
+dwnfactorprf_25  =0
+dpnfactorprf_25  =0
+dvoffprf_25      =0
+dlvoffprf_25     =0
+dwvoffprf_25     =0
+dpvoffprf_25     =0
+dcitprf_25       =0
+dlcitprf_25      =0
+dwcitprf_25      =0
+dpcitprf_25      =0
+dvsatprf_25      =0
+dwvsatprf_25     =0
+da0prf_25        =0
+dwa0prf_25       =0
+dlagsprf_25      =0
+dwagsprf_25      =0
+dpagsprf_25      =0
+dpclmprf_25      =0
+dlpclmprf_25     =0
+dwpclmprf_25     =0
+dppclmprf_25     =0
+deta0prf_25      =0
+dleta0prf_25     =0
+dweta0prf_25     =0
+dk2prf_25        =0
+dwk2prf_25       =0
+dpk2prf_25       =0
+is_d_dnw_nrf_25= 1         x_jsw_d_dnw_nrf_25= 0         n_d_dnw_nrf_25= 1         rs_d_dnw_nrf_25= 1
+cj_d_dnw_nrf_25= 1          cjsw_d_dnw_nrf_25= 1
+is_d_dnw_prf_25= 1         x_jsw_d_dnw_prf_25= 0         n_d_dnw_prf_25= 1         rs_d_dnw_prf_25= 1
+cj_d_dnw_prf_25= 1          cjsw_d_dnw_prf_25= 1
+is_d_prf_25= 1                 x_jsw_d_prf_25= 0             n_d_prf_25= 1             rs_d_prf_25= 1
+cj_d_prf_25= 1                  cjsw_d_prf_25= 1
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL mc_RFMOS_25








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+toxnrf_25        = 5.6e-09       dxlnrf_25        = 0             dxwnrf_25        = 0
+cjnrf_25         = 1.1950E-03    cjswnrf_25       = 1.6500E-10    cjswgnrf_25      = 2.0800E-10
+cgonrf_25        = 9.95494E-11   cglnrf_25        = 2.67995E-10   dlcnrf_25        = 6.03005E-08
+dvthnrf_25       = 0             dlvthnrf_25      = 0             dwvthnrf_25      = 0
+dpvthnrf_25      = 0             dcitnrf_25       = 0             dlcitnrf_25      = 0
+dwcitnrf_25      = 0             dpcitnrf_25      = 0             du0nrf_25        = 0
+dlu0nrf_25       = 0             dwu0nrf_25       = 0             dpu0nrf_25       = 0
+da0nrf_25        = 0             dla0nrf_25       = 0             dwa0nrf_25       = 0
+dpa0nrf_25       = 0             dagsnrf_25       = 0             dlagsnrf_25      = 0
+dwagsnrf_25      = 0             dpagsnrf_25      = 0             dvsatnrf_25      = 0
+dlvsatnrf_25     = 0             dwvsatnrf_25     = 0             dpvsatnrf_25     = 0
+dpclmnrf_25      = 0             dlpclmnrf_25     = 0             dwpclmnrf_25     = 0
+dppclmnrf_25     = 0             deta0nrf_25      = 0             dleta0nrf_25     = 0
+dweta0nrf_25     = 0             dpeta0nrf_25     = 0             dk2nrf_25        = 0
+dlk2nrf_25       = 0             dwk2nrf_25       = 0             dpk2nrf_25       = 0
+cfnrf_25         = '9e-11 + 2.4e-11'
+toxprf_25        = 5.9e-09       dxlprf_25        = 0             dxwprf_25        = 0
+cjprf_25         = 0.001111      cjswprf_25       = 9.7000E-11    cjswgprf_25      = 1.6800E-10
+cgoprf_25        = 1.19935E-10   cglprf_25        = 2.49822E-10   dlcprf_25        = 6.40638E-08
+dvthprf_25       = 0             dlvthprf_25      = 0             dwvthprf_25      = 0
+dpvthprf_25      = 0             du0prf_25        = 0             dlu0prf_25       = 0
+dwu0prf_25       = 0             dpu0prf_25       = 0             dnfactorprf_25   = 0
+dlnfactorprf_25  = 0             dwnfactorprf_25  = 0             dpnfactorprf_25  = 0
+dvoffprf_25      = 0             dlvoffprf_25     = 0             dwvoffprf_25     = 0
+dpvoffprf_25     = 0             dcitprf_25       = 0             dlcitprf_25      = 0
+dwcitprf_25      = 0             dpcitprf_25      = 0             dvsatprf_25      = 0
+dlvsatprf_25     = 0             dwvsatprf_25     = 0             dpvsatprf_25     = 0
+da0prf_25        = 0             dla0prf_25       = 0             dwa0prf_25       = 0
+dpa0prf_25       = 0             dagsprf_25       = 0             dlagsprf_25      = 0
+dwagsprf_25      = 0             dpagsprf_25      = 0             dpclmprf_25      = 0
+dlpclmprf_25     = 0             dwpclmprf_25     = 0             dppclmprf_25     = 0
+deta0prf_25      = 0             dleta0prf_25     = 0             dweta0prf_25     = 0
+dpeta0prf_25     = 0             dk2prf_25        = 0             dlk2prf_25       = 0
+dwk2prf_25       = 0             dpk2prf_25       = 0             cfprf_25         = '9e-11 + 2.4e-11'
+is_d_dnw_nrf_25= 1         x_jsw_d_dnw_nrf_25= 0         n_d_dnw_nrf_25= 1         rs_d_dnw_nrf_25= 1
+cj_d_dnw_nrf_25= 1          cjsw_d_dnw_nrf_25= 1
+is_d_dnw_prf_25= 1         x_jsw_d_dnw_prf_25= 0         n_d_dnw_prf_25= 1         rs_d_dnw_prf_25= 1
+cj_d_dnw_prf_25= 1          cjsw_d_dnw_prf_25= 1
+is_d_prf_25= 1                 x_jsw_d_prf_25= 0             n_d_prf_25= 1             rs_d_prf_25= 1
+cj_d_prf_25= 1                  cjsw_d_prf_25= 1
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL TT_RFMOS_25








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+toxnrf_25        = 5.9e-09       dxlnrf_25        = 1e-08         dxwnrf_25        = -1.2e-08
+cjnrf_25         = 0.00127865    cjswnrf_25       = 1.7655E-10    cjswgnrf_25      = 2.2256E-10
+cgonrf_25        = 9.25809E-11   cglnrf_25        = 2.49235E-10   dlcnrf_25        = 6.03005E-08
+dvthnrf_25       = 0.013         dlvthnrf_25      = 2.8e-9        dwvthnrf_25      = 0.9e-9
+dpvthnrf_25      = 1.9e-15       dcitnrf_25       = 0.8e-4        dlcitnrf_25      = 1e-11
+dwcitnrf_25      = 0             dpcitnrf_25      = 0             du0nrf_25        = 0
+dlu0nrf_25       = 0             dwu0nrf_25       = -1e-10        dpu0nrf_25       = -1e-16
+da0nrf_25        = 0.05          dla0nrf_25       = 1e-8          dwa0nrf_25       = 0
+dpa0nrf_25       = 0             dagsnrf_25       = 0             dlagsnrf_25      = 0
+dwagsnrf_25      = 0             dpagsnrf_25      = 0             dvsatnrf_25      = 0
+dlvsatnrf_25     = 7e-4          dwvsatnrf_25     = 0             dpvsatnrf_25     = 0.5e-10
+dpclmnrf_25      = -0.1          dlpclmnrf_25     = 0             dwpclmnrf_25     = 0
+dppclmnrf_25     = -1.2e-14      deta0nrf_25      = 0             dleta0nrf_25     = -4.5e-9
+dweta0nrf_25     = 0             dpeta0nrf_25     = -3e-15        dk2nrf_25        = 0.007
+dlk2nrf_25       = 7e-10         dwk2nrf_25       = 0             dpk2nrf_25       = 0
+cfnrf_25         = '8.37e-11 + 2.4e-11'
+toxprf_25        = 6.2e-09       dxlprf_25        = 1e-08         dxwprf_25        = -1.2e-08
+cjprf_25         = 0.00118877    cjswprf_25       = 1.0379E-10    cjswgprf_25      = 1.7976E-10
+cgoprf_25        = 1.11540E-10   cglprf_25        = 2.32334E-10   dlcprf_25        = 6.40638E-08
+dvthprf_25       = -0.013        dlvthprf_25      = -1e-9         dwvthprf_25      = -1e-9
+dpvthprf_25      = -3.4e-15      du0prf_25        = 0.5e-4        dlu0prf_25       = 0
+dwu0prf_25       = 0             dpu0prf_25       = 0.5e-17       dnfactorprf_25   = 0
+dlnfactorprf_25  = 0             dwnfactorprf_25  = 0             dpnfactorprf_25  = 0
+dvoffprf_25      = 0             dlvoffprf_25     = 0             dwvoffprf_25     = 0
+dpvoffprf_25     = 0             dcitprf_25       = 0             dlcitprf_25      = 0
+dwcitprf_25      = 0             dpcitprf_25      = 0             dvsatprf_25      = 0
+dlvsatprf_25     = -1e-4         dwvsatprf_25     = 0             dpvsatprf_25     = 7e-10
+da0prf_25        = 0             dla0prf_25       = 8e-8          dwa0prf_25       = 0
+dpa0prf_25       = 0             dagsprf_25       = 0             dlagsprf_25      = 0
+dwagsprf_25      = 0             dpagsprf_25      = 0             dpclmprf_25      = 0
+dlpclmprf_25     = 0             dwpclmprf_25     = 0             dppclmprf_25     = 0
+deta0prf_25      = 0             dleta0prf_25     = 0             dweta0prf_25     = 0
+dpeta0prf_25     = -4e-15        dk2prf_25        = 0             dlk2prf_25       = 7e-10
+dwk2prf_25       = 0             dpk2prf_25       = 0             cfprf_25         = '8.37e-11 + 2.4e-11'
+is_d_dnw_nrf_25= 0.7         x_jsw_d_dnw_nrf_25= -1         n_d_dnw_nrf_25= 0.9975         rs_d_dnw_nrf_25= 1.2
+cj_d_dnw_nrf_25= 1.07          cjsw_d_dnw_nrf_25= 1.07
+is_d_dnw_prf_25= 0.7         x_jsw_d_dnw_prf_25= -1         n_d_dnw_prf_25= 0.9975         rs_d_dnw_prf_25= 1.2
+cj_d_dnw_prf_25= 1.07          cjsw_d_dnw_prf_25=  1.07
+is_d_prf_25= 0.7                 x_jsw_d_prf_25= -1             n_d_prf_25= 0.9975             rs_d_prf_25= 1.2
+cj_d_prf_25= 1.07                  cjsw_d_prf_25=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL SS_RFMOS_25








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+toxnrf_25        = 5.3e-09       dxlnrf_25        = -1e-08        dxwnrf_25        = 1.2e-08
+cjnrf_25         = 0.00111135    cjswnrf_25       = 1.5345E-10    cjswgnrf_25      = 1.9344E-10
+cgonrf_25        = 1.06518E-10   cglnrf_25        = 2.86755E-10   dlcnrf_25        = 6.03005E-08
+dvthnrf_25       = -0.013        dlvthnrf_25      = -3.0e-9       dwvthnrf_25      = -1e-9
+dpvthnrf_25      = -2.3e-15      dcitnrf_25       = -1e-4         dlcitnrf_25      = -3e-11
+dwcitnrf_25      = 0             dpcitnrf_25      = 0             du0nrf_25        = 0
+dlu0nrf_25       = 0             dwu0nrf_25       = 1e-10         dpu0nrf_25       = 0.5e-16
+da0nrf_25        = -0.05         dla0nrf_25       = -1e-8         dwa0nrf_25       = 0
+dpa0nrf_25       = 0             dagsnrf_25       = 0             dlagsnrf_25      = 0
+dwagsnrf_25      = 0             dpagsnrf_25      = 0             dvsatnrf_25      = 0
+dlvsatnrf_25     = -7e-4         dwvsatnrf_25     = 0             dpvsatnrf_25     = 0
+dpclmnrf_25      = 0.1           dlpclmnrf_25     = 0             dwpclmnrf_25     = 0
+dppclmnrf_25     = 0             deta0nrf_25      = 0             dleta0nrf_25     = 1.5e-9
+dweta0nrf_25     = 0             dpeta0nrf_25     = 5e-15         dk2nrf_25        = -0.007
+dlk2nrf_25       = -7e-10        dwk2nrf_25       = 0             dpk2nrf_25       = 0
+cfnrf_25         = '9.63e-11 + 2.4e-11'
+toxprf_25        = 5.6e-09       dxlprf_25        = -1e-08        dxwprf_25        = 1.2e-08
+cjprf_25         = 0.00103323    cjswprf_25       = 9.0210E-11    cjswgprf_25      = 1.5624E-10
+cgoprf_25        = 1.28330E-10   cglprf_25        = 2.67310E-10   dlcprf_25        = 6.40638E-08
+dvthprf_25       = 0.013         dlvthprf_25      = 1.5e-9        dwvthprf_25      = 1e-9
+dpvthprf_25      = 3.7e-15       du0prf_25        = -0.3e-4       dlu0prf_25       = 0
+dwu0prf_25       = 0             dpu0prf_25       = 0             dnfactorprf_25   = 0
+dlnfactorprf_25  = 0             dwnfactorprf_25  = 0             dpnfactorprf_25  = 0
+dvoffprf_25      = 0             dlvoffprf_25     = 0             dwvoffprf_25     = 0
+dpvoffprf_25     = 0             dcitprf_25       = 0             dlcitprf_25      = 0
+dwcitprf_25      = 0             dpcitprf_25      = 0             dvsatprf_25      = 0
+dlvsatprf_25     = 0             dwvsatprf_25     = 0             dpvsatprf_25     = -6e-10
+da0prf_25        = 0             dla0prf_25       = -5e-8         dwa0prf_25       = 0
+dpa0prf_25       = -1e-14        dagsprf_25       = -0.001        dlagsprf_25      = 0
+dwagsprf_25      = 0             dpagsprf_25      = 0             dpclmprf_25      = 0
+dlpclmprf_25     = 0             dwpclmprf_25     = 0             dppclmprf_25     = 0
+deta0prf_25      = 0             dleta0prf_25     = 0             dweta0prf_25     = 0
+dpeta0prf_25     = 3e-15         dk2prf_25        = 0             dlk2prf_25       = -7e-10
+dwk2prf_25       = 0             dpk2prf_25       = 0             cfprf_25         = '9.63e-11 + 2.4e-11'
+is_d_dnw_nrf_25= 1         x_jsw_d_dnw_nrf_25= 0         n_d_dnw_nrf_25= 1         rs_d_dnw_nrf_25= 1
+cj_d_dnw_nrf_25= 1          cjsw_d_dnw_nrf_25= 1
+is_d_dnw_prf_25= 1         x_jsw_d_dnw_prf_25= 0         n_d_dnw_prf_25= 1         rs_d_dnw_prf_25= 1
+cj_d_dnw_prf_25= 1          cjsw_d_dnw_prf_25= 1
+is_d_prf_25= 1                 x_jsw_d_prf_25= 0             n_d_prf_25= 1             rs_d_prf_25= 1
+cj_d_prf_25= 1                  cjsw_d_prf_25= 1
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL FF_RFMOS_25








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+A1Nrf_25=1 A1Prf_25=-1 A2Nrf_25=0 A2Prf_25=0 A3Nrf_25=-1 A3Prf_25=1 A4NPrf_25=0
+toxnrf_25 = '5.6e-09 + 3.0000e-010*A4NPrf_25'     dxlnrf_25 = '1e-008*A2Nrf_25'                     dxwnrf_25 = '1.2e-008*A3Nrf_25'
+cjnrf_25 = '1.1950E-03 * (1+0.070*0.8)'      cjswnrf_25 = '1.6500E-10 * (1+0.070*0.8)'    cjswgnrf_25 = '2.0800E-10 * (1+0.070*0.8)'
+cgonrf_25 = '9.95494E-11 * (1-0.070*A4NPrf_25)'   cglnrf_25 = '2.67995E-10 * (1-0.070*A4NPrf_25)'   dlcnrf_25 = 6.03005E-08
+dvthnrf_25 = '0.023*A1Nrf_25'                     dlvthnrf_25 = '3e-009*A1Nrf_25'                   dwvthnrf_25 = '1e-009*A1Nrf_25'
+dpvthnrf_25 = '2.3e-015*A1Nrf_25'                 dcitnrf_25 = '0.0001*A1Nrf_25'                    dlcitnrf_25 = '3e-011*A1Nrf_25'
+dwcitnrf_25 = 0                                 dpcitnrf_25 = 0                                 du0nrf_25 = 0
+dlu0nrf_25 = 0                                  dwu0nrf_25 = '-1e-010*A1Nrf_25'                   dpu0nrf_25 = '-5e-017*A1Nrf_25'
+da0nrf_25 = '0.00*A1Nrf_25'                       dla0nrf_25 = '0e-008*A1Nrf_25'                    dwa0nrf_25 = 0
+dpa0nrf_25 = 0                                  dagsnrf_25 = 0                                  dlagsnrf_25 = 0
+dwagsnrf_25 = 0                                 dpagsnrf_25 = 0                                 dvsatnrf_25 = 0
+dlvsatnrf_25 = '0.0000*A1Nrf_25'                  dwvsatnrf_25 = 0                                dpvsatnrf_25 = 0
+dpclmnrf_25 = '-0.1*A1Nrf_25'                     dlpclmnrf_25 = 0                                dwpclmnrf_25 = 0
+dppclmnrf_25 = 0                                deta0nrf_25 = 0                                 dleta0nrf_25 = '-1.5e-009*A1Nrf_25'
+dweta0nrf_25 = 0                                dpeta0nrf_25 = '-5e-015*A1Nrf_25'                 dk2nrf_25 = '0.007*A1Nrf_25'
+dlk2nrf_25 = '7e-010*A1Nrf_25'                    dwk2nrf_25 = 0                                  dpk2nrf_25 = 0
+cfnrf_25 = '9e-11*(1-0.070*A4NPrf_25)+2.4e-11'
+toxprf_25 = '5.9e-09 + 3.0000e-010*A4NPrf_25'     dxlprf_25 = '1e-008*A2Prf_25'                     dxwprf_25 = '1.2e-008*A3Prf_25'
+cjprf_25 = '0.001111 * (1+0.070*-0.8)'        cjswprf_25 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgprf_25 = '1.6800E-10 * (1+0.070*-0.8)'
+cgoprf_25 = '1.19935E-10 * (1-0.070*A4NPrf_25)'   cglprf_25 = '2.49822E-10 * (1-0.070*A4NPrf_25)'   dlcprf_25 = 6.40638E-08
+dvthprf_25 = '-0.023*A1Prf_25'                    dlvthprf_25 = '-1.5e-009*A1Prf_25'                dwvthprf_25 = '-1e-009*A1Prf_25'
+dpvthprf_25 = '-3.7e-015*A1Prf_25'                du0prf_25 = '0e-005*A1Prf_25'                     dlu0prf_25 = 0
+dwu0prf_25 = 0                                  dpu0prf_25 = 0                                  dnfactorprf_25 = 0
+dlnfactorprf_25 = 0                             dwnfactorprf_25 = 0                             dpnfactorprf_25 = 0
+dvoffprf_25 = 0                                 dlvoffprf_25 = 0                                dwvoffprf_25 = 0
+dpvoffprf_25 = 0                                dcitprf_25 = 0                                  dlcitprf_25 = 0
+dwcitprf_25 = 0                                 dpcitprf_25 = 0                                 dvsatprf_25 = 0
+dlvsatprf_25 = 0                                dwvsatprf_25 = 0                                dpvsatprf_25 = '6e-010*A1Prf_25'
+da0prf_25 = 0                                   dla0prf_25 = '5e-008*A1Prf_25'                    dwa0prf_25 = 0
+dpa0prf_25 = '1e-014*A1Prf_25'                    dagsprf_25 = '0.001*A1Prf_25'                     dlagsprf_25 = 0
+dwagsprf_25 = 0                                 dpagsprf_25 = 0                                 dpclmprf_25 = 0
+dlpclmprf_25 = 0                                dwpclmprf_25 = 0                                dppclmprf_25 = 0
+deta0prf_25 = 0                                 dleta0prf_25 = 0                                dweta0prf_25 = 0
+dpeta0prf_25 = '-3e-015*A1Prf_25'                 dk2prf_25 = 0                                   dlk2prf_25 = '7e-010*A1Prf_25'
+dwk2prf_25 = 0                                  dpk2prf_25 = 0
+cfprf_25 = '9e-11*(1-0.070*A4NPrf_25)+2.4e-11'
+is_d_dnw_nrf_25= 1         x_jsw_d_dnw_nrf_25= 0         n_d_dnw_nrf_25= 1         rs_d_dnw_nrf_25= 1
+cj_d_dnw_nrf_25= 1          cjsw_d_dnw_nrf_25= 1
+is_d_dnw_prf_25= 1         x_jsw_d_dnw_prf_25= 0         n_d_dnw_prf_25= 1         rs_d_dnw_prf_25= 1
+cj_d_dnw_prf_25= 1          cjsw_d_dnw_prf_25= 1
+is_d_prf_25= 1                 x_jsw_d_prf_25= 0             n_d_prf_25= 1             rs_d_prf_25= 1
+cj_d_prf_25= 1                  cjsw_d_prf_25= 1
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL SF_RFMOS_25








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_25
.lib 'crn65lp_v1d5.l' noiseflagrf_25
.param
+parn1rf_25=AGAUSS(0,1,1)
+parn2rf_25=AGAUSS(0,1,1)
+parp1rf_25=AGAUSS(0,1,1)
+parp2rf_25=AGAUSS(0,1,1)
+A1Nrf_25=-1 A1Prf_25=1 A2Nrf_25=0 A2Prf_25=0 A3Nrf_25=1 A3Prf_25=-1 A4NPrf_25=0
+toxnrf_25 = '5.6e-09 + 3.0000e-010*A4NPrf_25'     dxlnrf_25 = '1e-008*A2Nrf_25'                     dxwnrf_25 = '1.2e-008*A3Nrf_25'
+cjnrf_25 = '1.1950E-03 * (1+0.070*-0.8)'      cjswnrf_25 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgnrf_25 = '2.0800E-10 * (1+0.070*-0.8)'
+cgonrf_25 = '9.95494E-11 * (1-0.070*A4NPrf_25)'   cglnrf_25 = '2.67995E-10 * (1-0.070*A4NPrf_25)'   dlcnrf_25 = 6.03005E-08
+dvthnrf_25 = '0.023*A1Nrf_25'                     dlvthnrf_25 = '3e-009*A1Nrf_25'                   dwvthnrf_25 = '1e-009*A1Nrf_25'
+dpvthnrf_25 = '2.3e-015*A1Nrf_25'                 dcitnrf_25 = '0.0001*A1Nrf_25'                    dlcitnrf_25 = '3e-011*A1Nrf_25'
+dwcitnrf_25 = 0                                 dpcitnrf_25 = 0                                 du0nrf_25 = 0
+dlu0nrf_25 = 0                                  dwu0nrf_25 = '-1e-010*A1Nrf_25'                   dpu0nrf_25 = '-5e-017*A1Nrf_25'
+da0nrf_25 = '0.00*A1Nrf_25'                       dla0nrf_25 = '0e-008*A1Nrf_25'                    dwa0nrf_25 = 0
+dpa0nrf_25 = 0                                  dagsnrf_25 = 0                                  dlagsnrf_25 = 0
+dwagsnrf_25 = 0                                 dpagsnrf_25 = 0                                 dvsatnrf_25 = 0
+dlvsatnrf_25 = '0.0000*A1Nrf_25'                  dwvsatnrf_25 = 0                                dpvsatnrf_25 = 0
+dpclmnrf_25 = '-0.1*A1Nrf_25'                     dlpclmnrf_25 = 0                                dwpclmnrf_25 = 0
+dppclmnrf_25 = 0                                deta0nrf_25 = 0                                 dleta0nrf_25 = '-1.5e-009*A1Nrf_25'
+dweta0nrf_25 = 0                                dpeta0nrf_25 = '-5e-015*A1Nrf_25'                 dk2nrf_25 = '0.007*A1Nrf_25'
+dlk2nrf_25 = '7e-010*A1Nrf_25'                    dwk2nrf_25 = 0                                  dpk2nrf_25 = 0
+cfnrf_25 = '9e-11*(1-0.070*A4NPrf_25)+2.4e-11'
+toxprf_25 = '5.9e-09 + 3.0000e-010*A4NPrf_25'     dxlprf_25 = '1e-008*A2Prf_25'                     dxwprf_25 = '1.2e-008*A3Prf_25'
+cjprf_25 = '0.001111 * (1+0.070*0.8)'        cjswprf_25 = '9.7000E-11 * (1+0.070*0.8)'    cjswgprf_25 = '1.6800E-10 * (1+0.070*0.8)'
+cgoprf_25 = '1.19935E-10 * (1-0.070*A4NPrf_25)'   cglprf_25 = '2.49822E-10 * (1-0.070*A4NPrf_25)'   dlcprf_25 = 6.40638E-08
+dvthprf_25 = '-0.023*A1Prf_25'                    dlvthprf_25 = '-1.5e-009*A1Prf_25'                dwvthprf_25 = '-1e-009*A1Prf_25'
+dpvthprf_25 = '-3.7e-015*A1Prf_25'                du0prf_25 = '0e-005*A1Prf_25'                     dlu0prf_25 = 0
+dwu0prf_25 = 0                                  dpu0prf_25 = 0                                  dnfactorprf_25 = 0
+dlnfactorprf_25 = 0                             dwnfactorprf_25 = 0                             dpnfactorprf_25 = 0
+dvoffprf_25 = 0                                 dlvoffprf_25 = 0                                dwvoffprf_25 = 0
+dpvoffprf_25 = 0                                dcitprf_25 = 0                                  dlcitprf_25 = 0
+dwcitprf_25 = 0                                 dpcitprf_25 = 0                                 dvsatprf_25 = 0
+dlvsatprf_25 = 0                                dwvsatprf_25 = 0                                dpvsatprf_25 = '6e-010*A1Prf_25'
+da0prf_25 = 0                                   dla0prf_25 = '5e-008*A1Prf_25'                    dwa0prf_25 = 0
+dpa0prf_25 = '1e-014*A1Prf_25'                    dagsprf_25 = '0.001*A1Prf_25'                     dlagsprf_25 = 0
+dwagsprf_25 = 0                                 dpagsprf_25 = 0                                 dpclmprf_25 = 0
+dlpclmprf_25 = 0                                dwpclmprf_25 = 0                                dppclmprf_25 = 0
+deta0prf_25 = 0                                 dleta0prf_25 = 0                                dweta0prf_25 = 0
+dpeta0prf_25 = '-3e-015*A1Prf_25'                 dk2prf_25 = 0                                   dlk2prf_25 = '7e-010*A1Prf_25'
+dwk2prf_25 = 0                                  dpk2prf_25 = 0
+cfprf_25 = '9e-11*(1-0.070*A4NPrf_25)+2.4e-11'
+is_d_dnw_nrf_25= 1         x_jsw_d_dnw_nrf_25= 0         n_d_dnw_nrf_25= 1         rs_d_dnw_nrf_25= 1
+cj_d_dnw_nrf_25= 1          cjsw_d_dnw_nrf_25= 1
+is_d_dnw_prf_25= 1         x_jsw_d_dnw_prf_25= 0         n_d_dnw_prf_25= 1         rs_d_dnw_prf_25= 1
+cj_d_dnw_prf_25= 1          cjsw_d_dnw_prf_25= 1
+is_d_prf_25= 1                 x_jsw_d_prf_25= 0             n_d_prf_25= 1             rs_d_prf_25= 1
+cj_d_prf_25= 1                  cjsw_d_prf_25= 1
.lib 'crn65lp_v1d5.l' RF_MOS_25
.ENDL FS_RFMOS_25


.LIB RF_MOS_25

.subckt nmos_rf_25 D G S B lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parn1rf_25  temp2=parn2rf_25
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-0.015e-6'
+       wef='wr*scale+0.007e-6'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_25='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_25='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_25='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_25='0.00275107*geo_fac*toxnrf_25*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'

.param fn_dice='noiseflagnrf_25_mc*par1fn_mc+noiseflagnrf_25_mc_mis*par2fnrf_25_mc'
.param c1fnrf_25=8.00E+41           c2fnrf_25=5.55E+24           c3fnrf_25=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_25='c1fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'
.param noibnrf_25='c2fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'
.param noicnrf_25='c3fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_25 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   2.5V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_25.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlnrf_25+dlmisnrf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_25+toxmisnrf_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_25+dlmisnrf_25)'  XW         = '7e-09+(dxwnrf_25+dwmisnrf_25)'
+DLC        = 'dlcnrf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+(dvthnrf_25+vthmisnrf_25)'
+LVTH0      = '-3.3832116e-009+dlvthnrf_25'
+WVTH0      = '-3.6076185e-008+dwvthnrf_25'
+PVTH0      = '8.8357962e-015+dpvthnrf_25'
+K1         = 0.71631             K2         = '-0.061138887+dk2nrf_25'
+LK2        = '-9.2107413e-010+dlk2nrf_25'
+WK2        = '9.9093956e-009+dwk2nrf_25'
+PK2        = '-3.5351933e-015+dpk2nrf_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitnrf_25'
+LCIT       = '1.1765275e-010+dlcitnrf_25'
+WCIT       = '-8.1835785e-011+dwcitnrf_25'
+PCIT       = '-4.050469e-017+dpcitnrf_25'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0nrf_25'
+LETA0      = '-3.8911504e-009+dleta0nrf_25'
+WETA0      = '-7.9238321e-008+dweta0nrf_25'
+PETA0      = '3.8938742e-014+dpeta0nrf_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0nrf_25'
+LU0        = '-6.818911e-010+dlu0nrf_25'
+WU0        = '-1.6119779e-008+dwu0nrf_25'
+PU0        = '6.8236842e-015+dpu0nrf_25'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatnrf_25'
+LVSAT      = '0.00017484387+dlvsatnrf_25'
+WVSAT      = '0.002554252+dwvsatnrf_25'
+PVSAT      = '-1.7496626e-009+dpvsatnrf_25'
+A0         = '1.1807466+da0nrf_25' LA0        = '-5.4455646e-007+dla0nrf_25'
+WA0        = '-2.8630873e-007+dwa0nrf_25'
+PA0        = '1.4537072e-013+dpa0nrf_25'
+AGS        = '-2.065376+dagsnrf_25'
+LAGS       = '1.5795102e-006+dlagsnrf_25'
+WAGS       = '4.6705548e-007+dwagsnrf_25'
+PAGS       = '-2.546634e-013+dpagsnrf_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmnrf_25'
+LPCLM      = '-2.7249305e-008+dlpclmnrf_25'
+WPCLM      = '-1.6066245e-007+dwpclmnrf_25'
+PPCLM      = '1.1005378e-013+dppclmnrf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_25'           CGDO       = 'cgonrf_25'           CGBO       = 0
+CGDL       = 'cglnrf_25'           CGSL       = 'cglnrf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_25'
+NOIB       = 'noibnrf_25'
+NOIC       = 'noicnrf_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_25.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlnrf_25+dlmisnrf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_25+toxmisnrf_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_25+dlmisnrf_25)'  XW         = '7e-09+(dxwnrf_25+dwmisnrf_25)'
+DLC        = 'dlcnrf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58142898+(dvthnrf_25+vthmisnrf_25)'
+LVTH0      = '4.65632e-009+dlvthnrf_25'
+WVTH0      = '-4.3320114e-008+dwvthnrf_25'
+PVTH0      = '1.147983e-014+dpvthnrf_25'
+K1         = 0.71631             K2         = '-0.083157012+dk2nrf_25'
+LK2        = '7.1155415e-009+dlk2nrf_25'
+WK2        = '-3.6995758e-008+dwk2nrf_25'
+PK2        = '1.3585188e-014+dpk2nrf_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0016696855+dcitnrf_25'
+LCIT       = '-2.5696666e-010+dlcitnrf_25'
+WCIT       = '-7.0374751e-010+dwcitnrf_25'
+PCIT       = '1.8649309e-016+dpcitnrf_25'
+VOFF       = -0.088709128        LVOFF      = -7.4110351e-009     WVOFF      = -5.8039324e-008
+PVOFF      = 8.9239435e-015      NFACTOR    = 0.55                ETA0       = '0.33936373+deta0nrf_25'
+LETA0      = '6.7011766e-008+dleta0nrf_25'
+WETA0      = '3.3109936e-007+dweta0nrf_25'
+PETA0      = '-1.1083451e-013+dpeta0nrf_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.030175686+du0nrf_25'
+LU0        = '2.9882438e-009+dlu0nrf_25'
+WU0        = '1.3087791e-008+dwu0nrf_25'
+PU0        = '-3.8370791e-015+dpu0nrf_25'
+UA         = -1.228116e-009      LUA        = 4.5226192e-017      WUA        = 9.0114011e-016
+PUA        = -2.1930808e-022     UB         = 2.570298e-018       LUB        = 1.9430506e-025
+WUB        = 2.2437669e-025      PUB        = -1.3245125e-031     UC         = 3.0335865e-010
+LUC        = -5.9025742e-017     WUC        = -1.1594261e-016     PUC        = 3.0724791e-023
+VSAT       = '106277.56+dvsatnrf_25'
+LVSAT      = '-0.005991031+dlvsatnrf_25'
+WVSAT      = '-8.8174179e-005+dwvsatnrf_25'
+PVSAT      = '-7.8517707e-010+dpvsatnrf_25'
+A0         = '0.95451+da0nrf_25'   LA0        = '-4.6198009e-007+dla0nrf_25'
+WA0        = '7.0539343e-007+dwa0nrf_25'
+PA0        = '-2.1660057e-013+dpa0nrf_25'
+AGS        = '4.7706648+dagsnrf_25'
+LAGS       = '-9.1564472e-007+dlagsnrf_25'
+WAGS       = '2.6663872e-007+dwagsnrf_25'
+PAGS       = '-1.8151128e-013+dpagsnrf_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.098453102        LKETA      = 3.0884888e-008
+WKETA      = 3.5352247e-008      PKETA      = -1.0759633e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.26948005+dpclmnrf_25'
+LPCLM      = '-2.1664821e-008+dlpclmnrf_25'
+WPCLM      = '2.3185666e-007+dwpclmnrf_25'
+PPCLM      = '-3.3215697e-014+dppclmnrf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00043695717       LPDIBLC2   = 4.3021146e-011
+WPDIBLC2   = -4.2987236e-010     PPDIBLC2   = -4.3341774e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_25'           CGDO       = 'cgonrf_25'           CGBO       = 0
+CGDL       = 'cglnrf_25'           CGSL       = 'cglnrf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0027434372
+LTVOFF     = -4.1510587e-010     WTVOFF     = -2.6155541e-010     PTVOFF     = 6.9312182e-017
+KT1        = -0.39571654         LKT1       = 4.0389824e-008      WKT1       = 2.0375793e-007
+PKT1       = -4.8951729e-014     KT1L       = 0                   KT2        = -0.17137354
+LKT2       = 3.8914578e-008      WKT2       = 6.8443317e-008      PKT2       = -2.0057213e-014
+UTE        = -1.3896059          LUTE       = 1.0324556e-007      WUTE       = 3.9233311e-007
+PUTE       = -1.0396827e-013     UA1        = 3.3235151e-009      LUA1       = -2.5920789e-016
+WUA1       = 1.1939848e-015      PUA1       = -3.3118227e-022     UB1        = -4.1858919e-018
+LUB1       = 4.3688273e-025      WUB1       = -2.0030822e-024     PUB1       = 6.071314e-031
+UC1        = 1.5268558e-010      LUC1       = -2.7611828e-017     WUC1       = -1.1664744e-016
+PUC1       = 2.7941474e-023      PRT        = 0                   AT         = -33393.011
+LAT        = 0.011823449         WAT        = 0.0059342622        PAT        = -2.1660057e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_25'
+NOIB       = 'noibnrf_25'
+NOIC       = 'noicnrf_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_25'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_25'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends nmos_rf_25

.subckt pmos_rf_25 D G S B lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parp1rf_25  temp2=parp2rf_25
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef = 'lr*scale-1.5e-08'
+       wef = 'wr*scale+7e-09'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_25='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_25 = '0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_25 = '-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_25='0.00197184*geo_fac*toxprf_25*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_25_mc*par1fn_mc+noiseflagprf_25_mc_mis*par2fprf_25_mc'
.param c1fprf_25=2.40E+41           c2fprf_25=9.00E+21           c3fprf_25=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_25='c1fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noibprf_25='c2fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noicprf_25='c3fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'


**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_25 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_25.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlprf_25+dlmisprf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '2.5718197e-009+dlvthprf_25'
+WVTH0      = '-2.3646075e-008+dwvthprf_25'
+PVTH0      = '9.4481782e-015+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2prf_25'
+LK2        = '-8.9535871e-009+dlk2prf_25'
+WK2        = '-1.295933e-008+dwk2prf_25'
+PK2        = '5.6251653e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitprf_25'
+LCIT       = '4.6455294e-011+dlcitprf_25'
+WCIT       = '-4.1099174e-010+dwcitprf_25'
+PCIT       = '1.0354503e-016+dpcitprf_25'
+VOFF       = '-0.11299764+dvoffprf_25'
+LVOFF      = '2.6233584e-008+dlvoffprf_25'
+WVOFF      = '-1.4529495e-009+dwvoffprf_25'
+PVOFF      = '-1.2090169e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.56211263+deta0prf_25'
+LETA0      = '1.7424833e-008+dleta0prf_25'
+WETA0      = '2.6548126e-007+dweta0prf_25'
+PETA0      = '-1.7671593e-013+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0prf_25'
+LU0        = '5.5390148e-010+dlu0prf_25'
+WU0        = '2.4305632e-010+dwu0prf_25'
+PU0        = '8.66083e-017+dpu0prf_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatprf_25'
+LVSAT      = '0.013404813+dlvsatprf_25'
+WVSAT      = '0.019706054+dwvsatprf_25'
+PVSAT      = '-1.3498647e-008+dpvsatprf_25'
+A0         = '0.80514856+da0prf_25'
+LA0        = '-7.9420433e-009+dla0prf_25'
+WA0        = '-5.107694e-007+dwa0prf_25'
+PA0        = '2.8534373e-013+dpa0prf_25'
+AGS        = '0.15467694+dagsprf_25'
+LAGS       = '2.5034798e-007+dlagsprf_25'
+WAGS       = '7.1515032e-008+dwagsprf_25'
+PAGS       = '-9.1271151e-014+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmprf_25'
+LPCLM      = '-5.4009069e-008+dlpclmprf_25'
+WPCLM      = '-5.1456596e-007+dwpclmprf_25'
+PPCLM      = '3.2646955e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_25.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlprf_25+dlmisprf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '1.9165092e-008+dlvthprf_25'
+WVTH0      = '5.5647704e-008+dwvthprf_25'
+PVTH0      = '-1.9494051e-014+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2prf_25'
+LK2        = '-2.0061177e-008+dlk2prf_25'
+WK2        = '-2.0365156e-008+dwk2prf_25'
+PK2        = '8.3282919e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitprf_25'
+LCIT       = '-1.4937327e-010+dlcitprf_25'
+WCIT       = '-5.4181493e-010+dwcitprf_25'
+PCIT       = '1.512955e-016+dpcitprf_25'
+VOFF       = '-0.067282633+dvoffprf_25'
+LVOFF      = '9.5476086e-009+dlvoffprf_25'
+WVOFF      = '1.7241887e-008+dwvoffprf_25'
+PVOFF      = '-8.0326321e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.61679273+deta0prf_25'
+LETA0      = '-2.5334029e-009+dleta0prf_25'
+WETA0      = '-2.9608441e-007+dweta0prf_25'
+PETA0      = '2.8255544e-014+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0prf_25'
+LU0        = '5.7861787e-010+dlu0prf_25'
+WU0        = '-1.6886335e-009+dwu0prf_25'
+PU0        = '7.9167508e-016+dpu0prf_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatprf_25'
+LVSAT      = '-0.016594572+dlvsatprf_25'
+WVSAT      = '-0.063059374+dwvsatprf_25'
+PVSAT      = '1.6710734e-008+dpvsatprf_25'
+A0         = '0.51664235+da0prf_25'
+LA0        = '9.7362723e-008+dla0prf_25'
+WA0        = '2.1970184e-006+dwa0prf_25'
+PA0        = '-7.0299881e-013+dpa0prf_25'
+AGS        = '0.70207782+dagsprf_25'
+LAGS       = '5.0546654e-008+dlagsprf_25'
+WAGS       = '-4.6552383e-007+dwagsprf_25'
+PAGS       = '1.0474804e-013+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmprf_25'
+LPCLM      = '3.4876893e-007+dlpclmprf_25'
+WPCLM      = '7.447096e-007+dwpclmprf_25'
+PPCLM      = '-1.3316603e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_25


.subckt pmos_rf_25_nw D G S B lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parp1rf_25  temp2=parp2rf_25
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef = 'lr*scale-1.5e-08'
+       wef = 'wr*scale+7e-09'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_25='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_25 = '0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_25 = '-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_25='0.00197184*geo_fac*toxprf_25*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_25_mc*par1fn_mc+noiseflagprf_25_mc_mis*par2fprf_25_mc'
.param c1fprf_25=2.40E+41           c2fprf_25=9.00E+21           c3fprf_25=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_25='c1fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noibprf_25='c2fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noicprf_25='c3fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'


**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_25 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_25.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlprf_25+dlmisprf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '2.5718197e-009+dlvthprf_25'
+WVTH0      = '-2.3646075e-008+dwvthprf_25'
+PVTH0      = '9.4481782e-015+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2prf_25'
+LK2        = '-8.9535871e-009+dlk2prf_25'
+WK2        = '-1.295933e-008+dwk2prf_25'
+PK2        = '5.6251653e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitprf_25'
+LCIT       = '4.6455294e-011+dlcitprf_25'
+WCIT       = '-4.1099174e-010+dwcitprf_25'
+PCIT       = '1.0354503e-016+dpcitprf_25'
+VOFF       = '-0.11299764+dvoffprf_25'
+LVOFF      = '2.6233584e-008+dlvoffprf_25'
+WVOFF      = '-1.4529495e-009+dwvoffprf_25'
+PVOFF      = '-1.2090169e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.56211263+deta0prf_25'
+LETA0      = '1.7424833e-008+dleta0prf_25'
+WETA0      = '2.6548126e-007+dweta0prf_25'
+PETA0      = '-1.7671593e-013+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0prf_25'
+LU0        = '5.5390148e-010+dlu0prf_25'
+WU0        = '2.4305632e-010+dwu0prf_25'
+PU0        = '8.66083e-017+dpu0prf_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatprf_25'
+LVSAT      = '0.013404813+dlvsatprf_25'
+WVSAT      = '0.019706054+dwvsatprf_25'
+PVSAT      = '-1.3498647e-008+dpvsatprf_25'
+A0         = '0.80514856+da0prf_25'
+LA0        = '-7.9420433e-009+dla0prf_25'
+WA0        = '-5.107694e-007+dwa0prf_25'
+PA0        = '2.8534373e-013+dpa0prf_25'
+AGS        = '0.15467694+dagsprf_25'
+LAGS       = '2.5034798e-007+dlagsprf_25'
+WAGS       = '7.1515032e-008+dwagsprf_25'
+PAGS       = '-9.1271151e-014+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmprf_25'
+LPCLM      = '-5.4009069e-008+dlpclmprf_25'
+WPCLM      = '-5.1456596e-007+dwpclmprf_25'
+PPCLM      = '3.2646955e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_25.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlprf_25+dlmisprf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '1.9165092e-008+dlvthprf_25'
+WVTH0      = '5.5647704e-008+dwvthprf_25'
+PVTH0      = '-1.9494051e-014+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2prf_25'
+LK2        = '-2.0061177e-008+dlk2prf_25'
+WK2        = '-2.0365156e-008+dwk2prf_25'
+PK2        = '8.3282919e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitprf_25'
+LCIT       = '-1.4937327e-010+dlcitprf_25'
+WCIT       = '-5.4181493e-010+dwcitprf_25'
+PCIT       = '1.512955e-016+dpcitprf_25'
+VOFF       = '-0.067282633+dvoffprf_25'
+LVOFF      = '9.5476086e-009+dlvoffprf_25'
+WVOFF      = '1.7241887e-008+dwvoffprf_25'
+PVOFF      = '-8.0326321e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.61679273+deta0prf_25'
+LETA0      = '-2.5334029e-009+dleta0prf_25'
+WETA0      = '-2.9608441e-007+dweta0prf_25'
+PETA0      = '2.8255544e-014+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0prf_25'
+LU0        = '5.7861787e-010+dlu0prf_25'
+WU0        = '-1.6886335e-009+dwu0prf_25'
+PU0        = '7.9167508e-016+dpu0prf_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatprf_25'
+LVSAT      = '-0.016594572+dlvsatprf_25'
+WVSAT      = '-0.063059374+dwvsatprf_25'
+PVSAT      = '1.6710734e-008+dpvsatprf_25'
+A0         = '0.51664235+da0prf_25'
+LA0        = '9.7362723e-008+dla0prf_25'
+WA0        = '2.1970184e-006+dwa0prf_25'
+PA0        = '-7.0299881e-013+dpa0prf_25'
+AGS        = '0.70207782+dagsprf_25'
+LAGS       = '5.0546654e-008+dlagsprf_25'
+WAGS       = '-4.6552383e-007+dwagsprf_25'
+PAGS       = '1.0474804e-013+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmprf_25'
+LPCLM      = '3.4876893e-007+dlpclmprf_25'
+WPCLM      = '7.447096e-007+dwpclmprf_25'
+PPCLM      = '-1.3316603e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_25_nw

.subckt nmos_rf_25_6t D G S B NG PG lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parn1rf_25  temp2=parn2rf_25
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-0.015e-6'
+       wef='wr*scale+0.007e-6'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_25='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_25='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_25='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_25='0.00275107*geo_fac*toxnrf_25*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'

.param fn_dice='noiseflagnrf_25_mc*par1fn_mc+noiseflagnrf_25_mc_mis*par2fnrf_25_mc'
.param c1fnrf_25=8.00E+41           c2fnrf_25=5.55E+24           c3fnrf_25=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_25='c1fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'
.param noibnrf_25='c2fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'
.param noicnrf_25='c3fnrf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_25    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_25  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_25 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   2.5V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

.MODEL nch_rf_25.1 NMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlnrf_25+dlmisnrf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_25+toxmisnrf_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_25+dlmisnrf_25)'  XW         = '7e-09+(dxwnrf_25+dwmisnrf_25)'
+DLC        = 'dlcnrf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+(dvthnrf_25+vthmisnrf_25)'
+LVTH0      = '-3.3832116e-009+dlvthnrf_25'
+WVTH0      = '-3.6076185e-008+dwvthnrf_25'
+PVTH0      = '8.8357962e-015+dpvthnrf_25'
+K1         = 0.71631             K2         = '-0.061138887+dk2nrf_25'
+LK2        = '-9.2107413e-010+dlk2nrf_25'
+WK2        = '9.9093956e-009+dwk2nrf_25'
+PK2        = '-3.5351933e-015+dpk2nrf_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitnrf_25'
+LCIT       = '1.1765275e-010+dlcitnrf_25'
+WCIT       = '-8.1835785e-011+dwcitnrf_25'
+PCIT       = '-4.050469e-017+dpcitnrf_25'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0nrf_25'
+LETA0      = '-3.8911504e-009+dleta0nrf_25'
+WETA0      = '-7.9238321e-008+dweta0nrf_25'
+PETA0      = '3.8938742e-014+dpeta0nrf_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0nrf_25'
+LU0        = '-6.818911e-010+dlu0nrf_25'
+WU0        = '-1.6119779e-008+dwu0nrf_25'
+PU0        = '6.8236842e-015+dpu0nrf_25'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatnrf_25'
+LVSAT      = '0.00017484387+dlvsatnrf_25'
+WVSAT      = '0.002554252+dwvsatnrf_25'
+PVSAT      = '-1.7496626e-009+dpvsatnrf_25'
+A0         = '1.1807466+da0nrf_25' LA0        = '-5.4455646e-007+dla0nrf_25'
+WA0        = '-2.8630873e-007+dwa0nrf_25'
+PA0        = '1.4537072e-013+dpa0nrf_25'
+AGS        = '-2.065376+dagsnrf_25'
+LAGS       = '1.5795102e-006+dlagsnrf_25'
+WAGS       = '4.6705548e-007+dwagsnrf_25'
+PAGS       = '-2.546634e-013+dpagsnrf_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmnrf_25'
+LPCLM      = '-2.7249305e-008+dlpclmnrf_25'
+WPCLM      = '-1.6066245e-007+dwpclmnrf_25'
+PPCLM      = '1.1005378e-013+dppclmnrf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_25'           CGDO       = 'cgonrf_25'           CGBO       = 0
+CGDL       = 'cglnrf_25'           CGSL       = 'cglnrf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_25'
+NOIB       = 'noibnrf_25'
+NOIC       = 'noicnrf_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_rf_25.2 NMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlnrf_25+dlmisnrf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_25+toxmisnrf_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_25+dlmisnrf_25)'  XW         = '7e-09+(dxwnrf_25+dwmisnrf_25)'
+DLC        = 'dlcnrf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58142898+(dvthnrf_25+vthmisnrf_25)'
+LVTH0      = '4.65632e-009+dlvthnrf_25'
+WVTH0      = '-4.3320114e-008+dwvthnrf_25'
+PVTH0      = '1.147983e-014+dpvthnrf_25'
+K1         = 0.71631             K2         = '-0.083157012+dk2nrf_25'
+LK2        = '7.1155415e-009+dlk2nrf_25'
+WK2        = '-3.6995758e-008+dwk2nrf_25'
+PK2        = '1.3585188e-014+dpk2nrf_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0016696855+dcitnrf_25'
+LCIT       = '-2.5696666e-010+dlcitnrf_25'
+WCIT       = '-7.0374751e-010+dwcitnrf_25'
+PCIT       = '1.8649309e-016+dpcitnrf_25'
+VOFF       = -0.088709128        LVOFF      = -7.4110351e-009     WVOFF      = -5.8039324e-008
+PVOFF      = 8.9239435e-015      NFACTOR    = 0.55                ETA0       = '0.33936373+deta0nrf_25'
+LETA0      = '6.7011766e-008+dleta0nrf_25'
+WETA0      = '3.3109936e-007+dweta0nrf_25'
+PETA0      = '-1.1083451e-013+dpeta0nrf_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.030175686+du0nrf_25'
+LU0        = '2.9882438e-009+dlu0nrf_25'
+WU0        = '1.3087791e-008+dwu0nrf_25'
+PU0        = '-3.8370791e-015+dpu0nrf_25'
+UA         = -1.228116e-009      LUA        = 4.5226192e-017      WUA        = 9.0114011e-016
+PUA        = -2.1930808e-022     UB         = 2.570298e-018       LUB        = 1.9430506e-025
+WUB        = 2.2437669e-025      PUB        = -1.3245125e-031     UC         = 3.0335865e-010
+LUC        = -5.9025742e-017     WUC        = -1.1594261e-016     PUC        = 3.0724791e-023
+VSAT       = '106277.56+dvsatnrf_25'
+LVSAT      = '-0.005991031+dlvsatnrf_25'
+WVSAT      = '-8.8174179e-005+dwvsatnrf_25'
+PVSAT      = '-7.8517707e-010+dpvsatnrf_25'
+A0         = '0.95451+da0nrf_25'   LA0        = '-4.6198009e-007+dla0nrf_25'
+WA0        = '7.0539343e-007+dwa0nrf_25'
+PA0        = '-2.1660057e-013+dpa0nrf_25'
+AGS        = '4.7706648+dagsnrf_25'
+LAGS       = '-9.1564472e-007+dlagsnrf_25'
+WAGS       = '2.6663872e-007+dwagsnrf_25'
+PAGS       = '-1.8151128e-013+dpagsnrf_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.098453102        LKETA      = 3.0884888e-008
+WKETA      = 3.5352247e-008      PKETA      = -1.0759633e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.26948005+dpclmnrf_25'
+LPCLM      = '-2.1664821e-008+dlpclmnrf_25'
+WPCLM      = '2.3185666e-007+dwpclmnrf_25'
+PPCLM      = '-3.3215697e-014+dppclmnrf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00043695717       LPDIBLC2   = 4.3021146e-011
+WPDIBLC2   = -4.2987236e-010     PPDIBLC2   = -4.3341774e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_25'           CGDO       = 'cgonrf_25'           CGBO       = 0
+CGDL       = 'cglnrf_25'           CGSL       = 'cglnrf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0027434372
+LTVOFF     = -4.1510587e-010     WTVOFF     = -2.6155541e-010     PTVOFF     = 6.9312182e-017
+KT1        = -0.39571654         LKT1       = 4.0389824e-008      WKT1       = 2.0375793e-007
+PKT1       = -4.8951729e-014     KT1L       = 0                   KT2        = -0.17137354
+LKT2       = 3.8914578e-008      WKT2       = 6.8443317e-008      PKT2       = -2.0057213e-014
+UTE        = -1.3896059          LUTE       = 1.0324556e-007      WUTE       = 3.9233311e-007
+PUTE       = -1.0396827e-013     UA1        = 3.3235151e-009      LUA1       = -2.5920789e-016
+WUA1       = 1.1939848e-015      PUA1       = -3.3118227e-022     UB1        = -4.1858919e-018
+LUB1       = 4.3688273e-025      WUB1       = -2.0030822e-024     PUB1       = 6.071314e-031
+UC1        = 1.5268558e-010      LUC1       = -2.7611828e-017     WUC1       = -1.1664744e-016
+PUC1       = 2.7941474e-023      PRT        = 0                   AT         = -33393.011
+LAT        = 0.011823449         WAT        = 0.0059342622        PAT        = -2.1660057e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_25'
+NOIB       = 'noibnrf_25'
+NOIC       = 'noicnrf_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_25'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_25'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL PWDNW_nrf_25 D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_25'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_25'
+ N      = '1.02*n_d_dnw_nrf_25'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_25)'  CJ     = '7.31E-04*cj_d_dnw_nrf_25'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_25'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_25 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_25'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_25'
+ N      = '1.02*n_d_dnw_nrf_25'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_25)'  CJ     = '1.15E-04*cj_d_dnw_nrf_25' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_25'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_25_6t

.subckt pmos_rf_25_5t D G S B PG lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parp1rf_25  temp2=parp2rf_25
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef = 'lr*scale-1.5e-08'
+       wef = 'wr*scale+7e-09'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_25='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_25 = '0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_25 = '-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_25='0.00197184*geo_fac*toxprf_25*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_25_mc*par1fn_mc+noiseflagprf_25_mc_mis*par2fprf_25_mc'
.param c1fprf_25=2.40E+41           c2fprf_25=9.00E+21           c3fprf_25=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_25='c1fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noibprf_25='c2fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noicprf_25='c3fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'


*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_25  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_25 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_25.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlprf_25+dlmisprf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '2.5718197e-009+dlvthprf_25'
+WVTH0      = '-2.3646075e-008+dwvthprf_25'
+PVTH0      = '9.4481782e-015+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2prf_25'
+LK2        = '-8.9535871e-009+dlk2prf_25'
+WK2        = '-1.295933e-008+dwk2prf_25'
+PK2        = '5.6251653e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitprf_25'
+LCIT       = '4.6455294e-011+dlcitprf_25'
+WCIT       = '-4.1099174e-010+dwcitprf_25'
+PCIT       = '1.0354503e-016+dpcitprf_25'
+VOFF       = '-0.11299764+dvoffprf_25'
+LVOFF      = '2.6233584e-008+dlvoffprf_25'
+WVOFF      = '-1.4529495e-009+dwvoffprf_25'
+PVOFF      = '-1.2090169e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.56211263+deta0prf_25'
+LETA0      = '1.7424833e-008+dleta0prf_25'
+WETA0      = '2.6548126e-007+dweta0prf_25'
+PETA0      = '-1.7671593e-013+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0prf_25'
+LU0        = '5.5390148e-010+dlu0prf_25'
+WU0        = '2.4305632e-010+dwu0prf_25'
+PU0        = '8.66083e-017+dpu0prf_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatprf_25'
+LVSAT      = '0.013404813+dlvsatprf_25'
+WVSAT      = '0.019706054+dwvsatprf_25'
+PVSAT      = '-1.3498647e-008+dpvsatprf_25'
+A0         = '0.80514856+da0prf_25'
+LA0        = '-7.9420433e-009+dla0prf_25'
+WA0        = '-5.107694e-007+dwa0prf_25'
+PA0        = '2.8534373e-013+dpa0prf_25'
+AGS        = '0.15467694+dagsprf_25'
+LAGS       = '2.5034798e-007+dlagsprf_25'
+WAGS       = '7.1515032e-008+dwagsprf_25'
+PAGS       = '-9.1271151e-014+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmprf_25'
+LPCLM      = '-5.4009069e-008+dlpclmprf_25'
+WPCLM      = '-5.1456596e-007+dwpclmprf_25'
+PPCLM      = '3.2646955e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_25.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlprf_25+dlmisprf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '1.9165092e-008+dlvthprf_25'
+WVTH0      = '5.5647704e-008+dwvthprf_25'
+PVTH0      = '-1.9494051e-014+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2prf_25'
+LK2        = '-2.0061177e-008+dlk2prf_25'
+WK2        = '-2.0365156e-008+dwk2prf_25'
+PK2        = '8.3282919e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitprf_25'
+LCIT       = '-1.4937327e-010+dlcitprf_25'
+WCIT       = '-5.4181493e-010+dwcitprf_25'
+PCIT       = '1.512955e-016+dpcitprf_25'
+VOFF       = '-0.067282633+dvoffprf_25'
+LVOFF      = '9.5476086e-009+dlvoffprf_25'
+WVOFF      = '1.7241887e-008+dwvoffprf_25'
+PVOFF      = '-8.0326321e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.61679273+deta0prf_25'
+LETA0      = '-2.5334029e-009+dleta0prf_25'
+WETA0      = '-2.9608441e-007+dweta0prf_25'
+PETA0      = '2.8255544e-014+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0prf_25'
+LU0        = '5.7861787e-010+dlu0prf_25'
+WU0        = '-1.6886335e-009+dwu0prf_25'
+PU0        = '7.9167508e-016+dpu0prf_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatprf_25'
+LVSAT      = '-0.016594572+dlvsatprf_25'
+WVSAT      = '-0.063059374+dwvsatprf_25'
+PVSAT      = '1.6710734e-008+dpvsatprf_25'
+A0         = '0.51664235+da0prf_25'
+LA0        = '9.7362723e-008+dla0prf_25'
+WA0        = '2.1970184e-006+dwa0prf_25'
+PA0        = '-7.0299881e-013+dpa0prf_25'
+AGS        = '0.70207782+dagsprf_25'
+LAGS       = '5.0546654e-008+dlagsprf_25'
+WAGS       = '-4.6552383e-007+dwagsprf_25'
+PAGS       = '1.0474804e-013+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmprf_25'
+LPCLM      = '3.4876893e-007+dlpclmprf_25'
+WPCLM      = '7.447096e-007+dwpclmprf_25'
+PPCLM      = '-1.3316603e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL DNWPSUB_prf_25 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_25'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_25'
+ N      = '1.02*n_d_dnw_prf_25'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_25)'  CJ     = '1.15E-04*cj_d_dnw_prf_25' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_25'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_25 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_25'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_25'
+ N      = '1.02*n_d_prf_25'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_25)'  CJ     = '1.37E-04*cj_d_prf_25'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_25'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_25_5t

.subckt pmos_rf_25_nw_5t D G S B PG lr=0.28E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_25'
.param
+temp1=parp1rf_25  temp2=parp2rf_25
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef = 'lr*scale-1.5e-08'
+       wef = 'wr*scale+7e-09'
+       geo_fac  = '1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_25='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_25 = '0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_25 = '-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_25='0.00197184*geo_fac*toxprf_25*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'
.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_25_mc*par1fn_mc+noiseflagprf_25_mc_mis*par2fprf_25_mc'
.param c1fprf_25=2.40E+41           c2fprf_25=9.00E+21           c3fprf_25=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_25*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_25='c1fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noibprf_25='c2fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'
.param noicprf_25='c3fprf_25*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_25)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'


*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_25  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_25_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_25_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_25_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_25_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_25 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

.MODEL pch_rf_25.1 PMOS	(	LEVEL      = 54                  
+LMIN       = '3.8e-007-(dxlprf_25+dlmisprf_25)'
+LMAX       = 5.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '2.5718197e-009+dlvthprf_25'
+WVTH0      = '-2.3646075e-008+dwvthprf_25'
+PVTH0      = '9.4481782e-015+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2prf_25'
+LK2        = '-8.9535871e-009+dlk2prf_25'
+WK2        = '-1.295933e-008+dwk2prf_25'
+PK2        = '5.6251653e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitprf_25'
+LCIT       = '4.6455294e-011+dlcitprf_25'
+WCIT       = '-4.1099174e-010+dwcitprf_25'
+PCIT       = '1.0354503e-016+dpcitprf_25'
+VOFF       = '-0.11299764+dvoffprf_25'
+LVOFF      = '2.6233584e-008+dlvoffprf_25'
+WVOFF      = '-1.4529495e-009+dwvoffprf_25'
+PVOFF      = '-1.2090169e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.56211263+deta0prf_25'
+LETA0      = '1.7424833e-008+dleta0prf_25'
+WETA0      = '2.6548126e-007+dweta0prf_25'
+PETA0      = '-1.7671593e-013+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0prf_25'
+LU0        = '5.5390148e-010+dlu0prf_25'
+WU0        = '2.4305632e-010+dwu0prf_25'
+PU0        = '8.66083e-017+dpu0prf_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatprf_25'
+LVSAT      = '0.013404813+dlvsatprf_25'
+WVSAT      = '0.019706054+dwvsatprf_25'
+PVSAT      = '-1.3498647e-008+dpvsatprf_25'
+A0         = '0.80514856+da0prf_25'
+LA0        = '-7.9420433e-009+dla0prf_25'
+WA0        = '-5.107694e-007+dwa0prf_25'
+PA0        = '2.8534373e-013+dpa0prf_25'
+AGS        = '0.15467694+dagsprf_25'
+LAGS       = '2.5034798e-007+dlagsprf_25'
+WAGS       = '7.1515032e-008+dwagsprf_25'
+PAGS       = '-9.1271151e-014+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmprf_25'
+LPCLM      = '-5.4009069e-008+dlpclmprf_25'
+WPCLM      = '-5.1456596e-007+dwpclmprf_25'
+PPCLM      = '3.2646955e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pch_rf_25.2 PMOS	(	LEVEL      = 54                  
+LMIN       = 28e-008
+LMAX       = '3.8e-007-(dxlprf_25+dlmisprf_25)'  
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_25+toxmisprf_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_25+dlmisprf_25)'  XW         = '7e-09+(dxwprf_25+dwmisprf_25)'
+DLC        = 'dlcprf_25'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+(dvthprf_25+vthmisprf_25)'
+LVTH0      = '1.9165092e-008+dlvthprf_25'
+WVTH0      = '5.5647704e-008+dwvthprf_25'
+PVTH0      = '-1.9494051e-014+dpvthprf_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2prf_25'
+LK2        = '-2.0061177e-008+dlk2prf_25'
+WK2        = '-2.0365156e-008+dwk2prf_25'
+PK2        = '8.3282919e-015+dpk2prf_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitprf_25'
+LCIT       = '-1.4937327e-010+dlcitprf_25'
+WCIT       = '-5.4181493e-010+dwcitprf_25'
+PCIT       = '1.512955e-016+dpcitprf_25'
+VOFF       = '-0.067282633+dvoffprf_25'
+LVOFF      = '9.5476086e-009+dlvoffprf_25'
+WVOFF      = '1.7241887e-008+dwvoffprf_25'
+PVOFF      = '-8.0326321e-015+dpvoffprf_25'
+NFACTOR    = '0.63002+dnfactorprf_25'
+ETA0       = '0.61679273+deta0prf_25'
+LETA0      = '-2.5334029e-009+dleta0prf_25'
+WETA0      = '-2.9608441e-007+dweta0prf_25'
+PETA0      = '2.8255544e-014+dpeta0prf_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0prf_25'
+LU0        = '5.7861787e-010+dlu0prf_25'
+WU0        = '-1.6886335e-009+dwu0prf_25'
+PU0        = '7.9167508e-016+dpu0prf_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatprf_25'
+LVSAT      = '-0.016594572+dlvsatprf_25'
+WVSAT      = '-0.063059374+dwvsatprf_25'
+PVSAT      = '1.6710734e-008+dpvsatprf_25'
+A0         = '0.51664235+da0prf_25'
+LA0        = '9.7362723e-008+dla0prf_25'
+WA0        = '2.1970184e-006+dwa0prf_25'
+PA0        = '-7.0299881e-013+dpa0prf_25'
+AGS        = '0.70207782+dagsprf_25'
+LAGS       = '5.0546654e-008+dlagsprf_25'
+WAGS       = '-4.6552383e-007+dwagsprf_25'
+PAGS       = '1.0474804e-013+dpagsprf_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmprf_25'
+LPCLM      = '3.4876893e-007+dlpclmprf_25'
+WPCLM      = '7.447096e-007+dwpclmprf_25'
+PPCLM      = '-1.3316603e-013+dppclmprf_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_25'           CGDO       = 'cgoprf_25'           CGBO       = 0
+CGDL       = 'cglprf_25'           CGSL       = 'cglprf_25'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_25'
+NOIB       = 'noibprf_25'
+NOIC       = 'noicprf_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_25'
+WNFACTOR   = '0+dwnfactorprf_25'   PNFACTOR   = '0+dpnfactorprf_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )




.MODEL pdio_rf_25_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_25_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_25'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_25'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL DNWPSUB_prf_25 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_25'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_25'
+ N      = '1.02*n_d_dnw_prf_25'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_25)'  CJ     = '1.15E-04*cj_d_dnw_prf_25' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_25'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_25 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_25'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_25'
+ N      = '1.02*n_d_prf_25'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_25)'  CJ     = '1.37E-04*cj_d_prf_25'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_25'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_25_nw_5t

.ENDL RF_MOS_25






**************************************************************************************************
*
* 3.3V IO MOS MODEL
*
*
*
*              .lib RF_MOS_33
*
*              Model name           nr               lr (um)           wr (um)
*                               low   high        low     high     low    high
*            -------------------------------------------------------------------
*              nmos_rf_33        1     32         0.5    0.70     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_33        1     32         0.4    0.70     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_33_nw     1     32         0.4    0.70     1.0    10.0
*            -------------------------------------------------------------------
*              nmos_rf_33_6t     1     32         0.5    0.70     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_33_5t     1     32         0.4    0.70     1.0    10.0
*            -------------------------------------------------------------------
*              pmos_rf_33_nw_5t  1     32         0.4    0.70     1.0    10.0
*            -------------------------------------------------------------------
*            End Model
*            **nr: Finger number
*            **wr: Width per finger
*
**************************************************************************************************

***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+A1rf_33='par6*4.8844*3/2.2'
+A2rf_33='par7*3.6211*3/2.2'
+A3rf_33='par8*3.1765*3/2.2'
+A4rf_33='par9*1.3928*3/2.2'
+toxnrf_33        ='5.6e-09+(-2.9051e-011)*A1rf_33+(1.0524e-011)*A2rf_33+(-6.11e-011)*A3rf_33+(1.9574e-011)*A4rf_33'
+dxlnrf_33        ='0+(-8.7742e-010)*A1rf_33+(4.0539e-010)*A2rf_33+(-2.9313e-009)*A3rf_33+(7.5636e-010)*A4rf_33'
+dxwnrf_33        ='0+(1.2502e-009)*A1rf_33+(1.4002e-009)*A2rf_33+(3.7127e-009)*A3rf_33+(-9.9453e-010)*A4rf_33'
+cjnrf_33         ='1.1950e-03+(-1.1483e-005)*A1rf_33+(-8.9571e-006)*A2rf_33+(4.3258e-006)*A3rf_33+(3.3359e-006)*A4rf_33'
+cjswnrf_33       ='1.6500e-10+(-1.5855e-012)*A1rf_33+(-1.2368e-012)*A2rf_33+(5.9728e-013)*A3rf_33+(4.6052e-013)*A4rf_33'
+cjswgnrf_33      ='2.0800e-10+(-1.9987e-012)*A1rf_33+(-1.5591e-012)*A2rf_33+(7.5294e-013)*A3rf_33+(5.8053e-013)*A4rf_33'
+cgonrf_33        ='9.95494e-11+(6.7482e-013)*A1rf_33+(-2.4444e-013)*A2rf_33+(1.4192e-012)*A3rf_33+(-4.5469e-013)*A4rf_33'
+cglnrf_33        ='2.67995e-10+(1.8167e-012)*A1rf_33+(-6.5807e-013)*A2rf_33+(3.8207e-012)*A3rf_33+(-1.224e-012)*A4rf_33'
+dvthnrf_33       ='0+(-0.0019918)*A1rf_33+(-0.003373)*A2rf_33+(0.00046738)*A3rf_33+(0.00060958)*A4rf_33'
+dlvthnrf_33      ='0+(-4.0919e-010)*A1rf_33+(-4.1802e-010)*A2rf_33+(1.4887e-010)*A3rf_33+(1.5429e-010)*A4rf_33'
+dwvthnrf_33      ='0+(-1.3431e-010)*A1rf_33+(-1.3975e-010)*A2rf_33+(5.0205e-011)*A3rf_33+(5.6487e-011)*A4rf_33'
+dpvthnrf_33      ='0+(-2.983e-016)*A1rf_33+(-3.235e-016)*A2rf_33+(1.1844e-016)*A3rf_33+(1.5571e-016)*A4rf_33'
+dcitnrf_33       ='0+(-1.2806e-005)*A1rf_33+(-1.4097e-005)*A2rf_33+(5.1948e-006)*A3rf_33+(7.1655e-006)*A4rf_33'
+dlcitnrf_33      ='0+(-2.9669e-012)*A1rf_33+(-4.4006e-012)*A2rf_33+(1.8026e-012)*A3rf_33+(4.2731e-012)*A4rf_33'
+dwu0nrf_33       ='0+(1.4056e-011)*A1rf_33+(1.3852e-011)*A2rf_33+(-4.8461e-012)*A3rf_33+(-4.132e-012)*A4rf_33'
+dpu0nrf_33       ='0+(1.0153e-017)*A1rf_33+(6.3139e-018)*A2rf_33+(-1.5511e-018)*A3rf_33+(5.5177e-018)*A4rf_33'
+da0nrf_33        ='0+(-0.0062062)*A1rf_33+(0.00093485)*A2rf_33+(0.0032361)*A3rf_33+(0.0017039)*A4rf_33'
+dla0nrf_33       ='0+(-1.2412e-009)*A1rf_33+(1.8697e-010)*A2rf_33+(6.4721e-010)*A3rf_33+(3.4078e-010)*A4rf_33'
+dlvsatnrf_33     ='0+(-8.6887e-005)*A1rf_33+(1.3088e-005)*A2rf_33+(4.5305e-005)*A3rf_33+(2.3855e-005)*A4rf_33'
+dpvsatnrf_33     ='0+(-3.125e-012)*A1rf_33+(6.1228e-013)*A2rf_33+(-8.7195e-013)*A3rf_33+(-7.5837e-012)*A4rf_33'
+dpclmnrf_33      ='max(-0.18,0+(0.014056)*A1rf_33+(0.013852)*A2rf_33+(-0.0048461)*A3rf_33+(-0.004132)*A4rf_33)'
+dppclmnrf_33     ='0+(7.5001e-016)*A1rf_33+(-1.4695e-016)*A2rf_33+(2.0927e-016)*A3rf_33+(1.8201e-015)*A4rf_33'
+dleta0nrf_33     ='0+(3.9835e-010)*A1rf_33+(1.7105e-010)*A2rf_33+(-2.0374e-011)*A3rf_33+(3.9304e-010)*A4rf_33'
+dpeta0nrf_33     ='0+(5.7782e-016)*A1rf_33+(7.171e-016)*A2rf_33+(-2.7718e-016)*A3rf_33+(-5.0995e-016)*A4rf_33'
+dk2nrf_33        ='0+(-0.00098395)*A1rf_33+(-0.00096966)*A2rf_33+(0.00033922)*A3rf_33+(0.00028924)*A4rf_33'
+dlk2nrf_33       ='0+(-9.8395e-011)*A1rf_33+(-9.6966e-011)*A2rf_33+(3.3922e-011)*A3rf_33+(2.8924e-011)*A4rf_33'
+cfnrf_33         ='9.000000e-011+(6.1008e-013)*A1rf_33+(-2.2099e-013)*A2rf_33+(1.2831e-012)*A3rf_33+(-4.1105e-013)*A4rf_33+2.4e-11'
+toxprf_33        ='5.9e-09+(-2.9051e-011)*A1rf_33+(1.0524e-011)*A2rf_33+(-6.11e-011)*A3rf_33+(1.9574e-011)*A4rf_33'
+dxlprf_33        ='0+(-8.7742e-010)*A1rf_33+(4.0539e-010)*A2rf_33+(-2.9313e-009)*A3rf_33+(7.5636e-010)*A4rf_33'
+dxwprf_33        ='max(-3.1e-8,0+(8.5562e-010)*A1rf_33+(-2.3731e-009)*A2rf_33+(3.3224e-009)*A3rf_33+(-8.2073e-010)*A4rf_33)'
+cjprf_33         ='0.001111+(-8.6302e-006)*A1rf_33+(1.1236e-005)*A2rf_33+(6.0451e-006)*A3rf_33+(2.2003e-006)*A4rf_33'
+cjswprf_33       ='9.7000e-11+(-7.535e-013)*A1rf_33+(9.8097e-013)*A2rf_33+(5.2778e-013)*A3rf_33+(1.9205e-013)*A4rf_33'
+cjswgprf_33      ='1.6800e-10+(-1.305e-012)*A1rf_33+(1.699e-012)*A2rf_33+(9.141e-013)*A3rf_33+(3.3263e-013)*A4rf_33'
+cgoprf_33        ='1.19935e-10+(8.1294e-013)*A1rf_33+(-2.9449e-013)*A2rf_33+(1.7099e-012)*A3rf_33+(-5.4775e-013)*A4rf_33'
+cglprf_33        ='2.49822e-10+(1.6935e-012)*A1rf_33+(-6.1344e-013)*A2rf_33+(3.5616e-012)*A3rf_33+(-1.141e-012)*A4rf_33'
+dvthprf_33       ='0+(0.0012355)*A1rf_33+(-0.0038591)*A2rf_33+(-0.0012154)*A3rf_33+(-0.00027645)*A4rf_33'
+dlvthprf_33      ='0+(1.3028e-010)*A1rf_33+(-2.5775e-010)*A2rf_33+(-1.3019e-010)*A3rf_33+(-1.1609e-010)*A4rf_33'
+dwvthprf_33      ='0+(1.0768e-010)*A1rf_33+(-1.7592e-010)*A2rf_33+(-8.0982e-011)*A3rf_33+(-2.6836e-011)*A4rf_33'
+dpvthprf_33      ='0+(3.7968e-016)*A1rf_33+(-6.4722e-016)*A2rf_33+(-3.0486e-016)*A3rf_33+(-1.448e-016)*A4rf_33'
+du0prf_33        ='0+(-4.9737e-006)*A1rf_33+(8.0582e-007)*A2rf_33+(1.5929e-006)*A3rf_33+(-2.0111e-006)*A4rf_33'
+dpu0prf_33       ='0+(-3.125e-019)*A1rf_33+(6.1228e-020)*A2rf_33+(-8.7195e-020)*A3rf_33+(-7.5837e-019)*A4rf_33'
+dlvsatprf_33     ='0+(6.2501e-006)*A1rf_33+(-1.2246e-006)*A2rf_33+(1.7439e-006)*A3rf_33+(1.5167e-005)*A4rf_33'
+dpvsatprf_33     ='0+(-7.086e-011)*A1rf_33+(1.0677e-010)*A2rf_33+(4.6845e-011)*A3rf_33+(9.3422e-013)*A4rf_33'
+dla0prf_33       ='0+(-7.2592e-009)*A1rf_33+(9.1632e-009)*A2rf_33+(3.5259e-009)*A3rf_33+(-3.2084e-009)*A4rf_33'
+dpa0prf_33       ='0+(-4.5183e-016)*A1rf_33+(1.6367e-015)*A2rf_33+(9.8421e-016)*A3rf_33+(1.7851e-015)*A4rf_33'
+dagsprf_33       ='0+(-4.5183e-005)*A1rf_33+(0.00016367)*A2rf_33+(9.8421e-005)*A3rf_33+(0.00017851)*A4rf_33'
+dpeta0prf_33     ='0+(3.8555e-016)*A1rf_33+(-5.4e-016)*A2rf_33+(-2.2551e-016)*A3rf_33+(7.1166e-017)*A4rf_33'
+dlk2prf_33       ='0+(-7.5379e-011)*A1rf_33+(1.2314e-010)*A2rf_33+(5.6687e-011)*A3rf_33+(1.8785e-011)*A4rf_33'
+cfprf_33         ='9.000000e-011+(6.1008e-013)*A1rf_33+(-2.2099e-013)*A2rf_33+(1.2831e-012)*A3rf_33+(-4.1105e-013)*A4rf_33+2.4e-11'
+dlcnrf_33        =6.03005e-08
+dwcitnrf_33      =0
+dpcitnrf_33      =0
+du0nrf_33        =0
+dlu0nrf_33       =0
+dwa0nrf_33       =0
+dpa0nrf_33       =0
+dagsnrf_33       =0
+dlagsnrf_33      =0
+dwagsnrf_33      =0
+dpagsnrf_33      =0
+dvsatnrf_33      =0
+dwvsatnrf_33     =0
+dlpclmnrf_33     =0
+dwpclmnrf_33     =0
+deta0nrf_33      =0
+dweta0nrf_33     =0
+dwk2nrf_33       =0
+dpk2nrf_33       =0
+dlcprf_33        =6.40638e-08
+dlu0prf_33       =0
+dwu0prf_33       =0
+dnfactorprf_33   =0
+dlnfactorprf_33  =0
+dwnfactorprf_33  =0
+dpnfactorprf_33  =0
+dvoffprf_33      =0
+dlvoffprf_33     =0
+dwvoffprf_33     =0
+dpvoffprf_33     =0
+dcitprf_33       =0
+dlcitprf_33      =0
+dwcitprf_33      =0
+dpcitprf_33      =0
+dvsatprf_33      =0
+dwvsatprf_33     =0
+da0prf_33        =0
+dwa0prf_33       =0
+dlagsprf_33      =0
+dwagsprf_33      =0
+dpagsprf_33      =0
+dpclmprf_33      =0
+dlpclmprf_33     =0
+dwpclmprf_33     =0
+dppclmprf_33     =0
+deta0prf_33      =0
+dleta0prf_33     =0
+dweta0prf_33     =0
+dk2prf_33        =0
+dwk2prf_33       =0
+dpk2prf_33       =0
+is_d_dnw_nrf_33= 1         x_jsw_d_dnw_nrf_33= 0         n_d_dnw_nrf_33= 1         rs_d_dnw_nrf_33= 1
+cj_d_dnw_nrf_33= 1          cjsw_d_dnw_nrf_33= 1
+is_d_dnw_prf_33= 1         x_jsw_d_dnw_prf_33= 0         n_d_dnw_prf_33= 1         rs_d_dnw_prf_33= 1
+cj_d_dnw_prf_33= 1          cjsw_d_dnw_prf_33= 1
+is_d_prf_33= 1                 x_jsw_d_prf_33= 0             n_d_prf_33= 1             rs_d_prf_33= 1
+cj_d_prf_33= 1                  cjsw_d_prf_33= 1

.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL mc_RFMOS_33








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+toxnrf_33        = 5.6e-09       dxlnrf_33        = 0             dxwnrf_33        = 0
+cjnrf_33         = 1.1950E-03    cjswnrf_33       = 1.6500E-10    cjswgnrf_33      = 2.0800E-10
+cgonrf_33        = 9.95494E-11   cglnrf_33        = 2.67995E-10   dlcnrf_33        = 6.03005E-08
+dvthnrf_33       = 0             dlvthnrf_33      = 0             dwvthnrf_33      = 0
+dpvthnrf_33      = 0             dcitnrf_33       = 0             dlcitnrf_33      = 0
+dwcitnrf_33      = 0             dpcitnrf_33      = 0             du0nrf_33        = 0
+dlu0nrf_33       = 0             dwu0nrf_33       = 0             dpu0nrf_33       = 0
+da0nrf_33        = 0             dla0nrf_33       = 0             dwa0nrf_33       = 0
+dpa0nrf_33       = 0             dagsnrf_33       = 0             dlagsnrf_33      = 0
+dwagsnrf_33      = 0             dpagsnrf_33      = 0             dvsatnrf_33      = 0
+dlvsatnrf_33     = 0             dwvsatnrf_33     = 0             dpvsatnrf_33     = 0
+dpclmnrf_33      = 0             dlpclmnrf_33     = 0             dwpclmnrf_33     = 0
+dppclmnrf_33     = 0             deta0nrf_33      = 0             dleta0nrf_33     = 0
+dweta0nrf_33     = 0             dpeta0nrf_33     = 0             dk2nrf_33        = 0
+dlk2nrf_33       = 0             dwk2nrf_33       = 0             dpk2nrf_33       = 0
+cfnrf_33         = '9e-11 + 2.4e-11'
+toxprf_33        = 5.9e-09       dxlprf_33        = 0             dxwprf_33        = 0
+cjprf_33         = 0.001111      cjswprf_33       = 9.7000E-11    cjswgprf_33      = 1.6800E-10
+cgoprf_33        = 1.19935E-10   cglprf_33        = 2.49822E-10   dlcprf_33        = 6.40638E-08
+dvthprf_33       = 0             dlvthprf_33      = 0             dwvthprf_33      = 0
+dpvthprf_33      = 0             du0prf_33        = 0             dlu0prf_33       = 0
+dwu0prf_33       = 0             dpu0prf_33       = 0             dnfactorprf_33   = 0
+dlnfactorprf_33  = 0             dwnfactorprf_33  = 0             dpnfactorprf_33  = 0
+dvoffprf_33      = 0             dlvoffprf_33     = 0             dwvoffprf_33     = 0
+dpvoffprf_33     = 0             dcitprf_33       = 0             dlcitprf_33      = 0
+dwcitprf_33      = 0             dpcitprf_33      = 0             dvsatprf_33      = 0
+dlvsatprf_33     = 0             dwvsatprf_33     = 0             dpvsatprf_33     = 0
+da0prf_33        = 0             dla0prf_33       = 0             dwa0prf_33       = 0
+dpa0prf_33       = 0             dagsprf_33       = 0             dlagsprf_33      = 0
+dwagsprf_33      = 0             dpagsprf_33      = 0             dpclmprf_33      = 0
+dlpclmprf_33     = 0             dwpclmprf_33     = 0             dppclmprf_33     = 0
+deta0prf_33      = 0             dleta0prf_33     = 0             dweta0prf_33     = 0
+dpeta0prf_33     = 0             dk2prf_33        = 0             dlk2prf_33       = 0
+dwk2prf_33       = 0             dpk2prf_33       = 0             cfprf_33         = '9e-11 + 2.4e-11'
+is_d_dnw_nrf_33= 1         x_jsw_d_dnw_nrf_33= 0         n_d_dnw_nrf_33= 1         rs_d_dnw_nrf_33= 1
+cj_d_dnw_nrf_33= 1          cjsw_d_dnw_nrf_33= 1
+is_d_dnw_prf_33= 1         x_jsw_d_dnw_prf_33= 0         n_d_dnw_prf_33= 1         rs_d_dnw_prf_33= 1
+cj_d_dnw_prf_33= 1          cjsw_d_dnw_prf_33= 1
+is_d_prf_33= 1                 x_jsw_d_prf_33= 0             n_d_prf_33= 1             rs_d_prf_33= 1
+cj_d_prf_33= 1                  cjsw_d_prf_33= 1
.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL TT_RFMOS_33








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+toxnrf_33        = 5.9e-09       dxlnrf_33        = 1e-08         dxwnrf_33        = -1.2e-08
+cjnrf_33         = 0.00127865    cjswnrf_33       = 1.7655E-10    cjswgnrf_33      = 2.2256E-10
+cgonrf_33        = 9.25809E-11   cglnrf_33        = 2.49235E-10   dlcnrf_33        = 6.03005E-08
+dvthnrf_33       = 0.013         dlvthnrf_33      = 2.8e-9        dwvthnrf_33      = 0.9e-9
+dpvthnrf_33      = 1.9e-15       dcitnrf_33       = 0.8e-4        dlcitnrf_33      = 1e-11
+dwcitnrf_33      = 0             dpcitnrf_33      = 0             du0nrf_33        = 0
+dlu0nrf_33       = 0             dwu0nrf_33       = -1e-10        dpu0nrf_33       = -1e-16
+da0nrf_33        = 0.05          dla0nrf_33       = 1e-8          dwa0nrf_33       = 0
+dpa0nrf_33       = 0             dagsnrf_33       = 0             dlagsnrf_33      = 0
+dwagsnrf_33      = 0             dpagsnrf_33      = 0             dvsatnrf_33      = 0
+dlvsatnrf_33     = 7e-4          dwvsatnrf_33     = 0             dpvsatnrf_33     = 0.5e-10
+dpclmnrf_33      = -0.1          dlpclmnrf_33     = 0             dwpclmnrf_33     = 0
+dppclmnrf_33     = -1.2e-14      deta0nrf_33      = 0             dleta0nrf_33     = -4.5e-9
+dweta0nrf_33     = 0             dpeta0nrf_33     = -3e-15        dk2nrf_33        = 0.007
+dlk2nrf_33       = 7e-10         dwk2nrf_33       = 0             dpk2nrf_33       = 0
+cfnrf_33         = '8.37e-11 + 2.4e-11'
+toxprf_33        = 6.2e-09       dxlprf_33        = 1e-08         dxwprf_33        = -1.2e-08
+cjprf_33         = 0.00118877    cjswprf_33       = 1.0379E-10    cjswgprf_33      = 1.7976E-10
+cgoprf_33        = 1.11540E-10   cglprf_33        = 2.32334E-10   dlcprf_33        = 6.40638E-08
+dvthprf_33       = -0.013        dlvthprf_33      = -1e-9         dwvthprf_33      = -1e-9
+dpvthprf_33      = -3.4e-15      du0prf_33        = 0.5e-4        dlu0prf_33       = 0
+dwu0prf_33       = 0             dpu0prf_33       = 0.5e-17       dnfactorprf_33   = 0
+dlnfactorprf_33  = 0             dwnfactorprf_33  = 0             dpnfactorprf_33  = 0
+dvoffprf_33      = 0             dlvoffprf_33     = 0             dwvoffprf_33     = 0
+dpvoffprf_33     = 0             dcitprf_33       = 0             dlcitprf_33      = 0
+dwcitprf_33      = 0             dpcitprf_33      = 0             dvsatprf_33      = 0
+dlvsatprf_33     = -1e-4         dwvsatprf_33     = 0             dpvsatprf_33     = 7e-10
+da0prf_33        = 0             dla0prf_33       = 8e-8          dwa0prf_33       = 0
+dpa0prf_33       = 0             dagsprf_33       = 0             dlagsprf_33      = 0
+dwagsprf_33      = 0             dpagsprf_33      = 0             dpclmprf_33      = 0
+dlpclmprf_33     = 0             dwpclmprf_33     = 0             dppclmprf_33     = 0
+deta0prf_33      = 0             dleta0prf_33     = 0             dweta0prf_33     = 0
+dpeta0prf_33     = -4e-15        dk2prf_33        = 0             dlk2prf_33       = 7e-10
+dwk2prf_33       = 0             dpk2prf_33       = 0             cfprf_33         = '8.37e-11 + 2.4e-11'
+is_d_dnw_nrf_33= 0.7         x_jsw_d_dnw_nrf_33= -1         n_d_dnw_nrf_33= 0.9975         rs_d_dnw_nrf_33= 1.2
+cj_d_dnw_nrf_33= 1.07          cjsw_d_dnw_nrf_33= 1.07
+is_d_dnw_prf_33= 0.7         x_jsw_d_dnw_prf_33= -1         n_d_dnw_prf_33= 0.9975         rs_d_dnw_prf_33= 1.2
+cj_d_dnw_prf_33= 1.07          cjsw_d_dnw_prf_33=  1.07
+is_d_prf_33= 0.7                 x_jsw_d_prf_33= -1             n_d_prf_33= 0.9975             rs_d_prf_33= 1.2
+cj_d_prf_33= 1.07                  cjsw_d_prf_33=  1.07
.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL SS_RFMOS_33








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+toxnrf_33        = 5.3e-09       dxlnrf_33        = -1e-08        dxwnrf_33        = 1.2e-08
+cjnrf_33         = 0.00111135    cjswnrf_33       = 1.5345E-10    cjswgnrf_33      = 1.9344E-10
+cgonrf_33        = 1.06518E-10   cglnrf_33        = 2.86755E-10   dlcnrf_33        = 6.03005E-08
+dvthnrf_33       = -0.013        dlvthnrf_33      = -3.0e-9       dwvthnrf_33      = -1e-9
+dpvthnrf_33      = -2.3e-15      dcitnrf_33       = -1e-4         dlcitnrf_33      = -3e-11
+dwcitnrf_33      = 0             dpcitnrf_33      = 0             du0nrf_33        = 0
+dlu0nrf_33       = 0             dwu0nrf_33       = 1e-10         dpu0nrf_33       = 0.5e-16
+da0nrf_33        = -0.05         dla0nrf_33       = -1e-8         dwa0nrf_33       = 0
+dpa0nrf_33       = 0             dagsnrf_33       = 0             dlagsnrf_33      = 0
+dwagsnrf_33      = 0             dpagsnrf_33      = 0             dvsatnrf_33      = 0
+dlvsatnrf_33     = -7e-4         dwvsatnrf_33     = 0             dpvsatnrf_33     = 0
+dpclmnrf_33      = 0.1           dlpclmnrf_33     = 0             dwpclmnrf_33     = 0
+dppclmnrf_33     = 0             deta0nrf_33      = 0             dleta0nrf_33     = 1.5e-9
+dweta0nrf_33     = 0             dpeta0nrf_33     = 5e-15         dk2nrf_33        = -0.007
+dlk2nrf_33       = -7e-10        dwk2nrf_33       = 0             dpk2nrf_33       = 0
+cfnrf_33         = '9.63e-11 + 2.4e-11'
+toxprf_33        = 5.6e-09       dxlprf_33        = -1e-08        dxwprf_33        = 1.2e-08
+cjprf_33         = 0.00103323    cjswprf_33       = 9.0210E-11    cjswgprf_33      = 1.5624E-10
+cgoprf_33        = 1.28330E-10   cglprf_33        = 2.67310E-10   dlcprf_33        = 6.40638E-08
+dvthprf_33       = 0.013         dlvthprf_33      = 1.5e-9        dwvthprf_33      = 1e-9
+dpvthprf_33      = 3.7e-15       du0prf_33        = -0.3e-4       dlu0prf_33       = 0
+dwu0prf_33       = 0             dpu0prf_33       = 0             dnfactorprf_33   = 0
+dlnfactorprf_33  = 0             dwnfactorprf_33  = 0             dpnfactorprf_33  = 0
+dvoffprf_33      = 0             dlvoffprf_33     = 0             dwvoffprf_33     = 0
+dpvoffprf_33     = 0             dcitprf_33       = 0             dlcitprf_33      = 0
+dwcitprf_33      = 0             dpcitprf_33      = 0             dvsatprf_33      = 0
+dlvsatprf_33     = 0             dwvsatprf_33     = 0             dpvsatprf_33     = -6e-10
+da0prf_33        = 0             dla0prf_33       = -5e-8         dwa0prf_33       = 0
+dpa0prf_33       = -1e-14        dagsprf_33       = -0.001        dlagsprf_33      = 0
+dwagsprf_33      = 0             dpagsprf_33      = 0             dpclmprf_33      = 0
+dlpclmprf_33     = 0             dwpclmprf_33     = 0             dppclmprf_33     = 0
+deta0prf_33      = 0             dleta0prf_33     = 0             dweta0prf_33     = 0
+dpeta0prf_33     = 3e-15         dk2prf_33        = 0             dlk2prf_33       = -7e-10
+dwk2prf_33       = 0             dpk2prf_33       = 0             cfprf_33         = '9.63e-11 + 2.4e-11'
+is_d_dnw_nrf_33= 1.3         x_jsw_d_dnw_nrf_33= 1         n_d_dnw_nrf_33= 1.0025         rs_d_dnw_nrf_33= 0.8
+cj_d_dnw_nrf_33= 0.93          cjsw_d_dnw_nrf_33= 0.93
+is_d_dnw_prf_33= 1.3         x_jsw_d_dnw_prf_33= 1         n_d_dnw_prf_33= 1.0025         rs_d_dnw_prf_33= 0.8
+cj_d_dnw_prf_33= 0.93          cjsw_d_dnw_prf_33=  0.93
+is_d_prf_33= 1.3                 x_jsw_d_prf_33= 1             n_d_prf_33= 1.0025             rs_d_prf_33= 0.8
+cj_d_prf_33= 0.93                  cjsw_d_prf_33=  0.93
.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL FF_RFMOS_33








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+A1Nrf_33=1 A1Prf_33=-1 A2Nrf_33=0 A2Prf_33=0 A3Nrf_33=-1 A3Prf_33=1 A4NPrf_33=0
+toxnrf_33 = '5.6e-09 + 3.0000e-010*A4NPrf_33'     dxlnrf_33 = '1e-008*A2Nrf_33'                     dxwnrf_33 = '1.2e-008*A3Nrf_33'
+cjnrf_33 = '1.1950E-03 * (1+0.070*0.8)'      cjswnrf_33 = '1.6500E-10 * (1+0.070*0.8)'    cjswgnrf_33 = '2.0800E-10 * (1+0.070*0.8)'
+cgonrf_33 = '9.95494E-11 * (1-0.070*A4NPrf_33)'   cglnrf_33 = '2.67995E-10 * (1-0.070*A4NPrf_33)'   dlcnrf_33 = 6.03005E-08
+dvthnrf_33 = '0.023*A1Nrf_33'                     dlvthnrf_33 = '3e-009*A1Nrf_33'                   dwvthnrf_33 = '1e-009*A1Nrf_33'
+dpvthnrf_33 = '2.3e-015*A1Nrf_33'                 dcitnrf_33 = '0.0001*A1Nrf_33'                    dlcitnrf_33 = '3e-011*A1Nrf_33'
+dwcitnrf_33 = 0                                 dpcitnrf_33 = 0                                 du0nrf_33 = 0
+dlu0nrf_33 = 0                                  dwu0nrf_33 = '-1e-010*A1Nrf_33'                   dpu0nrf_33 = '-5e-017*A1Nrf_33'
+da0nrf_33 = '0.00*A1Nrf_33'                       dla0nrf_33 = '0e-008*A1Nrf_33'                    dwa0nrf_33 = 0
+dpa0nrf_33 = 0                                  dagsnrf_33 = 0                                  dlagsnrf_33 = 0
+dwagsnrf_33 = 0                                 dpagsnrf_33 = 0                                 dvsatnrf_33 = 0
+dlvsatnrf_33 = '0.0000*A1Nrf_33'                  dwvsatnrf_33 = 0                                dpvsatnrf_33 = 0
+dpclmnrf_33 = '-0.1*A1Nrf_33'                     dlpclmnrf_33 = 0                                dwpclmnrf_33 = 0
+dppclmnrf_33 = 0                                deta0nrf_33 = 0                                 dleta0nrf_33 = '-1.5e-009*A1Nrf_33'
+dweta0nrf_33 = 0                                dpeta0nrf_33 = '-5e-015*A1Nrf_33'                 dk2nrf_33 = '0.007*A1Nrf_33'
+dlk2nrf_33 = '7e-010*A1Nrf_33'                    dwk2nrf_33 = 0                                  dpk2nrf_33 = 0
+cfnrf_33 = '9e-11*(1-0.070*A4NPrf_33)+2.4e-11'
+toxprf_33 = '5.9e-09 + 3.0000e-010*A4NPrf_33'     dxlprf_33 = '1e-008*A2Prf_33'                     dxwprf_33 = '1.2e-008*A3Prf_33'
+cjprf_33 = '0.001111 * (1+0.070*-0.8)'        cjswprf_33 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgprf_33 = '1.6800E-10 * (1+0.070*-0.8)'
+cgoprf_33 = '1.19935E-10 * (1-0.070*A4NPrf_33)'   cglprf_33 = '2.49822E-10 * (1-0.070*A4NPrf_33)'   dlcprf_33 = 6.40638E-08
+dvthprf_33 = '-0.023*A1Prf_33'                    dlvthprf_33 = '-1.5e-009*A1Prf_33'                dwvthprf_33 = '-1e-009*A1Prf_33'
+dpvthprf_33 = '-3.7e-015*A1Prf_33'                du0prf_33 = '0e-005*A1Prf_33'                     dlu0prf_33 = 0
+dwu0prf_33 = 0                                  dpu0prf_33 = 0                                  dnfactorprf_33 = 0
+dlnfactorprf_33 = 0                             dwnfactorprf_33 = 0                             dpnfactorprf_33 = 0
+dvoffprf_33 = 0                                 dlvoffprf_33 = 0                                dwvoffprf_33 = 0
+dpvoffprf_33 = 0                                dcitprf_33 = 0                                  dlcitprf_33 = 0
+dwcitprf_33 = 0                                 dpcitprf_33 = 0                                 dvsatprf_33 = 0
+dlvsatprf_33 = 0                                dwvsatprf_33 = 0                                dpvsatprf_33 = '6e-010*A1Prf_33'
+da0prf_33 = 0                                   dla0prf_33 = '5e-008*A1Prf_33'                    dwa0prf_33 = 0
+dpa0prf_33 = '1e-014*A1Prf_33'                    dagsprf_33 = '0.001*A1Prf_33'                     dlagsprf_33 = 0
+dwagsprf_33 = 0                                 dpagsprf_33 = 0                                 dpclmprf_33 = 0
+dlpclmprf_33 = 0                                dwpclmprf_33 = 0                                dppclmprf_33 = 0
+deta0prf_33 = 0                                 dleta0prf_33 = 0                                dweta0prf_33 = 0
+dpeta0prf_33 = '-3e-015*A1Prf_33'                 dk2prf_33 = 0                                   dlk2prf_33 = '7e-010*A1Prf_33'
+dwk2prf_33 = 0                                  dpk2prf_33 = 0
+cfprf_33 = '9e-11*(1-0.070*A4NPrf_33)+2.4e-11'
+is_d_dnw_nrf_33= 1         x_jsw_d_dnw_nrf_33= 0         n_d_dnw_nrf_33= 1         rs_d_dnw_nrf_33= 1
+cj_d_dnw_nrf_33= 1          cjsw_d_dnw_nrf_33= 1
+is_d_dnw_prf_33= 1         x_jsw_d_dnw_prf_33= 0         n_d_dnw_prf_33= 1         rs_d_dnw_prf_33= 1
+cj_d_dnw_prf_33= 1          cjsw_d_dnw_prf_33= 1
+is_d_prf_33= 1                 x_jsw_d_prf_33= 0             n_d_prf_33= 1             rs_d_prf_33= 1
+cj_d_prf_33= 1                  cjsw_d_prf_33= 1
.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL SF_RFMOS_33








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_RFMOS_33
.lib 'crn65lp_v1d5.l' noiseflagrf_33
.param
+parn1rf_33=AGAUSS(0,1,1)
+parn2rf_33=AGAUSS(0,1,1)
+parp1rf_33=AGAUSS(0,1,1)
+parp2rf_33=AGAUSS(0,1,1)
+A1Nrf_33=-1 A1Prf_33=1 A2Nrf_33=0 A2Prf_33=0 A3Nrf_33=1 A3Prf_33=-1 A4NPrf_33=0
+toxnrf_33 = '5.6e-09 + 3.0000e-010*A4NPrf_33'     dxlnrf_33 = '1e-008*A2Nrf_33'                     dxwnrf_33 = '1.2e-008*A3Nrf_33'
+cjnrf_33 = '1.1950E-03 * (1+0.070*-0.8)'      cjswnrf_33 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgnrf_33 = '2.0800E-10 * (1+0.070*-0.8)'
+cgonrf_33 = '9.95494E-11 * (1-0.070*A4NPrf_33)'   cglnrf_33 = '2.67995E-10 * (1-0.070*A4NPrf_33)'   dlcnrf_33 = 6.03005E-08
+dvthnrf_33 = '0.023*A1Nrf_33'                     dlvthnrf_33 = '3e-009*A1Nrf_33'                   dwvthnrf_33 = '1e-009*A1Nrf_33'
+dpvthnrf_33 = '2.3e-015*A1Nrf_33'                 dcitnrf_33 = '0.0001*A1Nrf_33'                    dlcitnrf_33 = '3e-011*A1Nrf_33'
+dwcitnrf_33 = 0                                 dpcitnrf_33 = 0                                 du0nrf_33 = 0
+dlu0nrf_33 = 0                                  dwu0nrf_33 = '-1e-010*A1Nrf_33'                   dpu0nrf_33 = '-5e-017*A1Nrf_33'
+da0nrf_33 = '0.00*A1Nrf_33'                       dla0nrf_33 = '0e-008*A1Nrf_33'                    dwa0nrf_33 = 0
+dpa0nrf_33 = 0                                  dagsnrf_33 = 0                                  dlagsnrf_33 = 0
+dwagsnrf_33 = 0                                 dpagsnrf_33 = 0                                 dvsatnrf_33 = 0
+dlvsatnrf_33 = '0.0000*A1Nrf_33'                  dwvsatnrf_33 = 0                                dpvsatnrf_33 = 0
+dpclmnrf_33 = '-0.1*A1Nrf_33'                     dlpclmnrf_33 = 0                                dwpclmnrf_33 = 0
+dppclmnrf_33 = 0                                deta0nrf_33 = 0                                 dleta0nrf_33 = '-1.5e-009*A1Nrf_33'
+dweta0nrf_33 = 0                                dpeta0nrf_33 = '-5e-015*A1Nrf_33'                 dk2nrf_33 = '0.007*A1Nrf_33'
+dlk2nrf_33 = '7e-010*A1Nrf_33'                    dwk2nrf_33 = 0                                  dpk2nrf_33 = 0
+cfnrf_33 = '9e-11*(1-0.070*A4NPrf_33)+2.4e-11'
+toxprf_33 = '5.9e-09 + 3.0000e-010*A4NPrf_33'     dxlprf_33 = '1e-008*A2Prf_33'                     dxwprf_33 = '1.2e-008*A3Prf_33'
+cjprf_33 = '0.001111 * (1+0.070*0.8)'        cjswprf_33 = '9.7000E-11 * (1+0.070*0.8)'    cjswgprf_33 = '1.6800E-10 * (1+0.070*0.8)'
+cgoprf_33 = '1.19935E-10 * (1-0.070*A4NPrf_33)'   cglprf_33 = '2.49822E-10 * (1-0.070*A4NPrf_33)'   dlcprf_33 = 6.40638E-08
+dvthprf_33 = '-0.023*A1Prf_33'                    dlvthprf_33 = '-1.5e-009*A1Prf_33'                dwvthprf_33 = '-1e-009*A1Prf_33'
+dpvthprf_33 = '-3.7e-015*A1Prf_33'                du0prf_33 = '0e-005*A1Prf_33'                     dlu0prf_33 = 0
+dwu0prf_33 = 0                                  dpu0prf_33 = 0                                  dnfactorprf_33 = 0
+dlnfactorprf_33 = 0                             dwnfactorprf_33 = 0                             dpnfactorprf_33 = 0
+dvoffprf_33 = 0                                 dlvoffprf_33 = 0                                dwvoffprf_33 = 0
+dpvoffprf_33 = 0                                dcitprf_33 = 0                                  dlcitprf_33 = 0
+dwcitprf_33 = 0                                 dpcitprf_33 = 0                                 dvsatprf_33 = 0
+dlvsatprf_33 = 0                                dwvsatprf_33 = 0                                dpvsatprf_33 = '6e-010*A1Prf_33'
+da0prf_33 = 0                                   dla0prf_33 = '5e-008*A1Prf_33'                    dwa0prf_33 = 0
+dpa0prf_33 = '1e-014*A1Prf_33'                    dagsprf_33 = '0.001*A1Prf_33'                     dlagsprf_33 = 0
+dwagsprf_33 = 0                                 dpagsprf_33 = 0                                 dpclmprf_33 = 0
+dlpclmprf_33 = 0                                dwpclmprf_33 = 0                                dppclmprf_33 = 0
+deta0prf_33 = 0                                 dleta0prf_33 = 0                                dweta0prf_33 = 0
+dpeta0prf_33 = '-3e-015*A1Prf_33'                 dk2prf_33 = 0                                   dlk2prf_33 = '7e-010*A1Prf_33'
+dwk2prf_33 = 0                                  dpk2prf_33 = 0
+cfprf_33 = '9e-11*(1-0.070*A4NPrf_33)+2.4e-11'
+is_d_dnw_nrf_33= 1         x_jsw_d_dnw_nrf_33= 0         n_d_dnw_nrf_33= 1         rs_d_dnw_nrf_33= 1
+cj_d_dnw_nrf_33= 1          cjsw_d_dnw_nrf_33= 1
+is_d_dnw_prf_33= 1         x_jsw_d_dnw_prf_33= 0         n_d_dnw_prf_33= 1         rs_d_dnw_prf_33= 1
+cj_d_dnw_prf_33= 1          cjsw_d_dnw_prf_33= 1
+is_d_prf_33= 1                 x_jsw_d_prf_33= 0             n_d_prf_33= 1             rs_d_prf_33= 1
+cj_d_prf_33= 1                  cjsw_d_prf_33= 1
.lib 'crn65lp_v1d5.l' RF_MOS_33
.ENDL FS_RFMOS_33


.LIB RF_MOS_33

.subckt nmos_rf_33 D G S B lr=0.50E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parn1rf_33  temp2=parn2rf_33
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_33='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_33='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_33='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_33='0.00275107*geo_fac*toxnrf_33*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'

.param fn_dice='noiseflagnrf_33_mc*par1fn_mc+noiseflagnrf_33_mc_mis*par2fnrf_33_mc'
.param c1fnrf_33=8.00E+41           c2fnrf_33=5.55E+24           c3fnrf_33=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_33='c1fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'
.param noibnrf_33='c2fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'
.param noicnrf_33='c3fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_33 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   3.3V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************


.MODEL nch_rf_33.1 NMOS	(	LEVEL      = 54                  
+LMIN       = 50e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_33+toxmisnrf_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_33+dlmisnrf_33)'  XW         = '7e-09+(dxwnrf_33+dwmisnrf_33)'
+DLC        = 'dlcnrf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.61260823+(dvthnrf_33+vthmisnrf_33)'
+LVTH0      = '-9.6531111e-009+dlvthnrf_33'
+WVTH0      = '-2.3448733e-008+dwvthnrf_33'
+PVTH0      = '1.8599153e-016+dpvthnrf_33'
+K1         = 0.71631             K2         = '-0.061361997+dk2nrf_33'
+LK2        = '-7.6824392e-010+dlk2nrf_33'
+WK2        = '-8.2035576e-010+dwk2nrf_33'
+PK2        = '3.8146864e-015+dpk2nrf_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00056199471+dcitnrf_33'
+LCIT       = '1.7336809e-010+dlcitnrf_33'
+WCIT       = '1.8415807e-011+dwcitnrf_33'
+PCIT       = '-1.0917703e-016+dpcitnrf_33'
+VOFF       = -0.13952383         LVOFF      = 8.0391584e-009      WVOFF      = 2.0307493e-008
+PVOFF      = -1.4953719e-014     NFACTOR    = 0.55                ETA0       = '0.54212048+deta0nrf_33'
+LETA0      = '-9.7151486e-009+dleta0nrf_33'
+WETA0      = '-3.667542e-008+dweta0nrf_33'
+PETA0      = '9.7831547e-015+dpeta0nrf_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039864876+du0nrf_33'
+LU0        = '-4.3119852e-010+dlu0nrf_33'
+WU0        = '-1.2457472e-008+dwu0nrf_33'
+PU0        = '4.3150036e-015+dpu0nrf_33'
+UA         = -5.7018434e-010     LUA        = -1.846368e-016      WUA        = -6.4595592e-016
+PUA        = 2.8294892e-022      UB         = 2.795246e-018       LUB        = 1.5343922e-025
+WUB        = -6.2253769e-026     PUB        = -8.9275936e-032     UC         = 1.6565338e-010
+LUC        = 1.1841976e-020      WUC        = -6.764611e-017      PUC        = 9.5227665e-024
+VSAT       = '89640+dvsatnrf_33'   A0         = '0.2429578+da0nrf_33' LA0        = '9.7828886e-008+dla0nrf_33'
+WA0        = '-5.9209381e-008+dwa0nrf_33'
+PA0        = '-1.0192336e-014+dpa0nrf_33'
+AGS        = '0.82120683+dagsnrf_33'
+LAGS       = '-3.9779908e-007+dlagsnrf_33'
+WAGS       = '3.2633961e-007+dwagsnrf_33'
+PAGS       = '-1.5827303e-013+dpagsnrf_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033517974        LKETA      = 1.1409345e-009
+WKETA      = -3.1787491e-008     PKETA      = 2.0831052e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.018151516+dpclmnrf_33'
+LPCLM      = '1.8025879e-007+dlpclmnrf_33'
+WPCLM      = '1.7377311e-008+dwpclmnrf_33'
+PPCLM      = '-1.1903458e-014+dppclmnrf_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0049521331        LPDIBLC2   = -1.6797111e-009
+WPDIBLC2   = -2.7152049e-010     PPDIBLC2   = 1.8599153e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_33'           CGDO       = 'cgonrf_33'           CGBO       = 0
+CGDL       = 'cglnrf_33'           CGSL       = 'cglnrf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00095938099
+LTVOFF     = 3.0676272e-010      WTVOFF     = 1.1990289e-009      PTVOFF     = -8.0906317e-016
+KT1        = -0.29378102         LKT1       = 5.2365858e-009      WKT1       = -4.5321528e-008
+PKT1       = 3.4036451e-014      KT1L       = 0                   KT2        = -0.054709833
+LKT2       = -3.7708737e-009     WKT2       = -4.3597233e-009     PKT2       = 5.4867502e-015
+UTE        = -1.4961476          LUTE       = 1.7430185e-007      WUTE       = -2.0741926e-007
+PUTE       = 1.6739238e-013      UA1        = 2.1614356e-009      LUA1       = 3.4817481e-016
+WUA1       = -1.5587711e-015     PUA1       = 6.8649475e-022      UB1        = -3.0099966e-018
+LUB1       = -1.2751846e-025     WUB1       = 9.1600655e-025      PUB1       = -2.6652587e-031
+UC1        = -1.0154792e-010     LUC1       = 8.2052595e-017      WUC1       = 6.6820968e-017
+PUC1       = -5.2125987e-023     PRT        = 0                   AT         = 17838.697
+LAT        = -0.0086517678       WAT        = 0.029908206         PAT        = -1.450548e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_33'
+NOIB       = 'noibnrf_33'
+NOIC       = 'noicnrf_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatnrf_33'
+WVSAT      = '0+dwvsatnrf_33'      PVSAT      = '0+dpvsatnrf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_33'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_33'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends nmos_rf_33

.subckt pmos_rf_33 D G S B lr=0.40E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parp1rf_33  temp2=parp2rf_33
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_33='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_33='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_33='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_33='0.00197184*geo_fac*toxprf_33*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_33_mc*par1fn_mc+noiseflagprf_33_mc_mis*par2fprf_33_mc'
.param c1fprf_33=2.40E+41           c2fprf_33=9.00E+21           c3fprf_33=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_33='c1fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noibprf_33='c2fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noicprf_33='c3fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_33 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc


.MODEL pch_rf_33.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 40e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_33+toxmisprf_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_33+dlmisprf_33)'  XW         = '7e-09+(dxwprf_33+dwmisprf_33)'
+DLC        = 'dlcprf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+(dvthprf_33+vthmisprf_33)'
+LVTH0      = '2.5702433e-008+dlvthprf_33'
+WVTH0      = '-1.6627131e-009+dwvthprf_33'
+PVTH0      = '-5.610425e-015+dpvthprf_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2prf_33'
+LK2        = '7.9535455e-010+dlk2prf_33'
+WK2        = '-6.2274297e-009+dwk2prf_33'
+PK2        = '1.0138136e-015+dpk2prf_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitprf_33'
+LCIT       = '6.8571721e-011+dlcitprf_33'
+WCIT       = '-4.6654535e-010+dwcitprf_33'
+PCIT       = '1.4159925e-016+dpcitprf_33'
+VOFF       = '-0.14042777+dvoffprf_33'
+LVOFF      = '4.5023226e-008+dlvoffprf_33'
+WVOFF      = '1.3401393e-008+dwvoffprf_33'
+PVOFF      = '-1.1384241e-014+dpvoffprf_33'
+NFACTOR    = '0.63002+dnfactorprf_33'
+ETA0       = '0.93976958+deta0prf_33'
+LETA0      = '-2.4127017e-007+dleta0prf_33'
+WETA0      = '1.9042077e-007+dweta0prf_33'
+PETA0      = '-1.2529949e-013+dpeta0prf_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0prf_33'
+LU0        = '-4.3228825e-010+dlu0prf_33'
+WU0        = '-8.0877649e-010+dwu0prf_33'
+PU0        = '8.0711378e-016+dpu0prf_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatprf_33'  A0         = '0.37683406+da0prf_33'
+LA0        = '2.8545338e-007+dla0prf_33'
+WA0        = '-4.2106763e-008+dwa0prf_33'
+PA0        = '-3.5690177e-014+dpa0prf_33'
+AGS        = '0.30127989+dagsprf_33'
+LAGS       = '1.4992495e-007+dlagsprf_33'
+WAGS       = '5.5740077e-008+dwagsprf_33'
+PAGS       = '-8.0465306e-014+dpagsprf_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmprf_33'
+LPCLM      = '2.5263178e-007+dlpclmprf_33'
+WPCLM      = '-2.6616416e-007+dwpclmprf_33'
+PPCLM      = '1.5631432e-013+dppclmprf_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_33'           CGDO       = 'cgoprf_33'           CGBO       = 0
+CGDL       = 'cglprf_33'           CGSL       = 'cglprf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_33'
+NOIB       = 'noibprf_33'
+NOIC       = 'noicprf_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_33'
+WNFACTOR   = '0+dwnfactorprf_33'   PNFACTOR   = '0+dpnfactorprf_33'   LVSAT      = '0+dlvsatprf_33'
+WVSAT      = '0+dwvsatprf_33'      PVSAT      = '0+dpvsatprf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pdio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_33

.subckt pmos_rf_33_nw D G S B lr=0.40E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parp1rf_33  temp2=parp2rf_33
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_33='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_33='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_33='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_33='0.00197184*geo_fac*toxprf_33*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_33_mc*par1fn_mc+noiseflagprf_33_mc_mis*par2fprf_33_mc'
.param c1fprf_33=2.40E+41           c2fprf_33=9.00E+21           c3fprf_33=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_33='c1fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noibprf_33='c2fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noicprf_33='c3fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw'
.param rwdiop='2*(Wrw+Lrw)'
.param dnwdioa='Wdnw*Ldnw'
.param dnwdiop='2*(Wdnw+Ldnw)'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbod+rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/rwdioa+rshdnwsti*(1-Aodact/rwdioa)'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/rwdiop'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  BI  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_33 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc


.MODEL pch_rf_33.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 40e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_33+toxmisprf_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_33+dlmisprf_33)'  XW         = '7e-09+(dxwprf_33+dwmisprf_33)'
+DLC        = 'dlcprf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+(dvthprf_33+vthmisprf_33)'
+LVTH0      = '2.5702433e-008+dlvthprf_33'
+WVTH0      = '-1.6627131e-009+dwvthprf_33'
+PVTH0      = '-5.610425e-015+dpvthprf_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2prf_33'
+LK2        = '7.9535455e-010+dlk2prf_33'
+WK2        = '-6.2274297e-009+dwk2prf_33'
+PK2        = '1.0138136e-015+dpk2prf_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitprf_33'
+LCIT       = '6.8571721e-011+dlcitprf_33'
+WCIT       = '-4.6654535e-010+dwcitprf_33'
+PCIT       = '1.4159925e-016+dpcitprf_33'
+VOFF       = '-0.14042777+dvoffprf_33'
+LVOFF      = '4.5023226e-008+dlvoffprf_33'
+WVOFF      = '1.3401393e-008+dwvoffprf_33'
+PVOFF      = '-1.1384241e-014+dpvoffprf_33'
+NFACTOR    = '0.63002+dnfactorprf_33'
+ETA0       = '0.93976958+deta0prf_33'
+LETA0      = '-2.4127017e-007+dleta0prf_33'
+WETA0      = '1.9042077e-007+dweta0prf_33'
+PETA0      = '-1.2529949e-013+dpeta0prf_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0prf_33'
+LU0        = '-4.3228825e-010+dlu0prf_33'
+WU0        = '-8.0877649e-010+dwu0prf_33'
+PU0        = '8.0711378e-016+dpu0prf_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatprf_33'  A0         = '0.37683406+da0prf_33'
+LA0        = '2.8545338e-007+dla0prf_33'
+WA0        = '-4.2106763e-008+dwa0prf_33'
+PA0        = '-3.5690177e-014+dpa0prf_33'
+AGS        = '0.30127989+dagsprf_33'
+LAGS       = '1.4992495e-007+dlagsprf_33'
+WAGS       = '5.5740077e-008+dwagsprf_33'
+PAGS       = '-8.0465306e-014+dpagsprf_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmprf_33'
+LPCLM      = '2.5263178e-007+dlpclmprf_33'
+WPCLM      = '-2.6616416e-007+dwpclmprf_33'
+PPCLM      = '1.5631432e-013+dppclmprf_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_33'           CGDO       = 'cgoprf_33'           CGBO       = 0
+CGDL       = 'cglprf_33'           CGSL       = 'cglprf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_33'
+NOIB       = 'noibprf_33'
+NOIC       = 'noicprf_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_33'
+WNFACTOR   = '0+dwnfactorprf_33'   PNFACTOR   = '0+dpnfactorprf_33'   LVSAT      = '0+dlvsatprf_33'
+WVSAT      = '0+dwvsatprf_33'      PVSAT      = '0+dpvsatprf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pdio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.ends pmos_rf_33_nw


.subckt nmos_rf_33_6t D G S B NG PG lr=0.50E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parn1rf_33  temp2=parn2rf_33
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisnrf_33='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisnrf_33='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisnrf_33='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisnrf_33='0.00275107*geo_fac*toxnrf_33*fac2*mismatchflag' 
**********************
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=835
.param Rsti=1200
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+298.4*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.37+9.74/(wr*scale*1e6)+30.88/nr+121.23/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='6.365e4/(lr*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(lr*scale*1e6)+0.5356'

.param fn_dice='noiseflagnrf_33_mc*par1fn_mc+noiseflagnrf_33_mc_mis*par2fnrf_33_mc'
.param c1fnrf_33=8.00E+41           c2fnrf_33=5.55E+24           c3fnrf_33=7.75E+6     
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noianrf_33='c1fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'
.param noibnrf_33='c2fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'
.param noicnrf_33='c3fnrf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagnrf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=600
.param rendgr=900
.param rendod=300
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

**********************************************************
Dpwdnw   B2  BN    PWDNW_nrf_33    AREA=rwdioa  PJ=rwdiop
Ddnwpsub BP  BN    DNWPSUB_nrf_33  AREA=dnwdioa PJ=dnwdiop 
Rng      BN  NG    R=rdnwx   
Rpsuba   BP  PG    R=rpsubax  
Rbod     BI  B2  R=rbod

***********************************************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SB  SI  ndio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DB  DI  ndio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SB  SI  ndio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DB  DI  ndio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI nch_rf_33 L=lr W=wr m=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc

**********************************************************************************************
*                                                                                            *
*                                   3.3V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************


.MODEL nch_rf_33.1 NMOS	(	LEVEL      = 54                  
+LMIN       = 50e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxnrf_33+toxmisnrf_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlnrf_33+dlmisnrf_33)'  XW         = '7e-09+(dxwnrf_33+dwmisnrf_33)'
+DLC        = 'dlcnrf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.61260823+(dvthnrf_33+vthmisnrf_33)'
+LVTH0      = '-9.6531111e-009+dlvthnrf_33'
+WVTH0      = '-2.3448733e-008+dwvthnrf_33'
+PVTH0      = '1.8599153e-016+dpvthnrf_33'
+K1         = 0.71631             K2         = '-0.061361997+dk2nrf_33'
+LK2        = '-7.6824392e-010+dlk2nrf_33'
+WK2        = '-8.2035576e-010+dwk2nrf_33'
+PK2        = '3.8146864e-015+dpk2nrf_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00056199471+dcitnrf_33'
+LCIT       = '1.7336809e-010+dlcitnrf_33'
+WCIT       = '1.8415807e-011+dwcitnrf_33'
+PCIT       = '-1.0917703e-016+dpcitnrf_33'
+VOFF       = -0.13952383         LVOFF      = 8.0391584e-009      WVOFF      = 2.0307493e-008
+PVOFF      = -1.4953719e-014     NFACTOR    = 0.55                ETA0       = '0.54212048+deta0nrf_33'
+LETA0      = '-9.7151486e-009+dleta0nrf_33'
+WETA0      = '-3.667542e-008+dweta0nrf_33'
+PETA0      = '9.7831547e-015+dpeta0nrf_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039864876+du0nrf_33'
+LU0        = '-4.3119852e-010+dlu0nrf_33'
+WU0        = '-1.2457472e-008+dwu0nrf_33'
+PU0        = '4.3150036e-015+dpu0nrf_33'
+UA         = -5.7018434e-010     LUA        = -1.846368e-016      WUA        = -6.4595592e-016
+PUA        = 2.8294892e-022      UB         = 2.795246e-018       LUB        = 1.5343922e-025
+WUB        = -6.2253769e-026     PUB        = -8.9275936e-032     UC         = 1.6565338e-010
+LUC        = 1.1841976e-020      WUC        = -6.764611e-017      PUC        = 9.5227665e-024
+VSAT       = '89640+dvsatnrf_33'   A0         = '0.2429578+da0nrf_33' LA0        = '9.7828886e-008+dla0nrf_33'
+WA0        = '-5.9209381e-008+dwa0nrf_33'
+PA0        = '-1.0192336e-014+dpa0nrf_33'
+AGS        = '0.82120683+dagsnrf_33'
+LAGS       = '-3.9779908e-007+dlagsnrf_33'
+WAGS       = '3.2633961e-007+dwagsnrf_33'
+PAGS       = '-1.5827303e-013+dpagsnrf_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033517974        LKETA      = 1.1409345e-009
+WKETA      = -3.1787491e-008     PKETA      = 2.0831052e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.018151516+dpclmnrf_33'
+LPCLM      = '1.8025879e-007+dlpclmnrf_33'
+WPCLM      = '1.7377311e-008+dwpclmnrf_33'
+PPCLM      = '-1.1903458e-014+dppclmnrf_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0049521331        LPDIBLC2   = -1.6797111e-009
+WPDIBLC2   = -2.7152049e-010     PPDIBLC2   = 1.8599153e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgonrf_33'           CGDO       = 'cgonrf_33'           CGBO       = 0
+CGDL       = 'cglnrf_33'           CGSL       = 'cglnrf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfnrf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00095938099
+LTVOFF     = 3.0676272e-010      WTVOFF     = 1.1990289e-009      PTVOFF     = -8.0906317e-016
+KT1        = -0.29378102         LKT1       = 5.2365858e-009      WKT1       = -4.5321528e-008
+PKT1       = 3.4036451e-014      KT1L       = 0                   KT2        = -0.054709833
+LKT2       = -3.7708737e-009     WKT2       = -4.3597233e-009     PKT2       = 5.4867502e-015
+UTE        = -1.4961476          LUTE       = 1.7430185e-007      WUTE       = -2.0741926e-007
+PUTE       = 1.6739238e-013      UA1        = 2.1614356e-009      LUA1       = 3.4817481e-016
+WUA1       = -1.5587711e-015     PUA1       = 6.8649475e-022      UB1        = -3.0099966e-018
+LUB1       = -1.2751846e-025     WUB1       = 9.1600655e-025      PUB1       = -2.6652587e-031
+UC1        = -1.0154792e-010     LUC1       = 8.2052595e-017      WUC1       = 6.6820968e-017
+PUC1       = -5.2125987e-023     PRT        = 0                   AT         = 17838.697
+LAT        = -0.0086517678       WAT        = 0.029908206         PAT        = -1.450548e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianrf_33'
+NOIB       = 'noibnrf_33'
+NOIC       = 'noicnrf_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatnrf_33'
+WVSAT      = '0+dwvsatnrf_33'      PVSAT      = '0+dpvsatnrf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL ndio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswnrf_33'
+AREA   = 3.08e-8                 MJSW   = 0.12                    TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 3.52e-4                 
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.48                    PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.1e-3                  FCS    = 0			   )

.MODEL ndio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.399e-7                IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 5e-14                   CJ     = 'cjnrf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgnrf_33'
+AREA   = 3.08e-8                 MJSW   = 0.3                     TLEVC  = 1
+CTA    = 8.62e-4                 CTP    = 1e-3                    
+TCV    = -8.80E-04               TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.6                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.7e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL PWDNW_nrf_33 D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw_nrf_33'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw_nrf_33'
+ N      = '1.02*n_d_dnw_nrf_33'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw_nrf_33)'  CJ     = '7.31E-04*cj_d_dnw_nrf_33'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw_nrf_33'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

.MODEL DNWPSUB_nrf_33 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_nrf_33'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_nrf_33'
+ N      = '1.02*n_d_dnw_nrf_33'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_nrf_33)'  CJ     = '1.15E-04*cj_d_dnw_nrf_33' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_nrf_33'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.ends nmos_rf_33_6t

.subckt pmos_rf_33_5t D G S B PG lr=0.40E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parp1rf_33  temp2=parp2rf_33
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_33='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_33='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_33='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_33='0.00197184*geo_fac*toxprf_33*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_33_mc*par1fn_mc+noiseflagprf_33_mc_mis*par2fprf_33_mc'
.param c1fprf_33=2.40E+41           c2fprf_33=9.00E+21           c3fprf_33=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_33='c1fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noibprf_33='c2fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noicprf_33='c3fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use**********
Ddnwpsub BP  B2    DNWPSUB_prf_33  AREA=dnwdioa PJ=dnwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
*********************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_33 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc


.MODEL pch_rf_33.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 40e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_33+toxmisprf_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_33+dlmisprf_33)'  XW         = '7e-09+(dxwprf_33+dwmisprf_33)'
+DLC        = 'dlcprf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+(dvthprf_33+vthmisprf_33)'
+LVTH0      = '2.5702433e-008+dlvthprf_33'
+WVTH0      = '-1.6627131e-009+dwvthprf_33'
+PVTH0      = '-5.610425e-015+dpvthprf_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2prf_33'
+LK2        = '7.9535455e-010+dlk2prf_33'
+WK2        = '-6.2274297e-009+dwk2prf_33'
+PK2        = '1.0138136e-015+dpk2prf_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitprf_33'
+LCIT       = '6.8571721e-011+dlcitprf_33'
+WCIT       = '-4.6654535e-010+dwcitprf_33'
+PCIT       = '1.4159925e-016+dpcitprf_33'
+VOFF       = '-0.14042777+dvoffprf_33'
+LVOFF      = '4.5023226e-008+dlvoffprf_33'
+WVOFF      = '1.3401393e-008+dwvoffprf_33'
+PVOFF      = '-1.1384241e-014+dpvoffprf_33'
+NFACTOR    = '0.63002+dnfactorprf_33'
+ETA0       = '0.93976958+deta0prf_33'
+LETA0      = '-2.4127017e-007+dleta0prf_33'
+WETA0      = '1.9042077e-007+dweta0prf_33'
+PETA0      = '-1.2529949e-013+dpeta0prf_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0prf_33'
+LU0        = '-4.3228825e-010+dlu0prf_33'
+WU0        = '-8.0877649e-010+dwu0prf_33'
+PU0        = '8.0711378e-016+dpu0prf_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatprf_33'  A0         = '0.37683406+da0prf_33'
+LA0        = '2.8545338e-007+dla0prf_33'
+WA0        = '-4.2106763e-008+dwa0prf_33'
+PA0        = '-3.5690177e-014+dpa0prf_33'
+AGS        = '0.30127989+dagsprf_33'
+LAGS       = '1.4992495e-007+dlagsprf_33'
+WAGS       = '5.5740077e-008+dwagsprf_33'
+PAGS       = '-8.0465306e-014+dpagsprf_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmprf_33'
+LPCLM      = '2.5263178e-007+dlpclmprf_33'
+WPCLM      = '-2.6616416e-007+dwpclmprf_33'
+PPCLM      = '1.5631432e-013+dppclmprf_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_33'           CGDO       = 'cgoprf_33'           CGBO       = 0
+CGDL       = 'cglprf_33'           CGSL       = 'cglprf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_33'
+NOIB       = 'noibprf_33'
+NOIC       = 'noicprf_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_33'
+WNFACTOR   = '0+dwnfactorprf_33'   PNFACTOR   = '0+dpnfactorprf_33'   LVSAT      = '0+dlvsatprf_33'
+WVSAT      = '0+dwvsatprf_33'      PVSAT      = '0+dpvsatprf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pdio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL DNWPSUB_prf_33 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_33'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_33'
+ N      = '1.02*n_d_dnw_prf_33'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_33)'  CJ     = '1.15E-04*cj_d_dnw_prf_33' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_33'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_33 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_33'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_33'
+ N      = '1.02*n_d_prf_33'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_33)'  CJ     = '1.37E-04*cj_d_prf_33'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_33'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_33_5t

.subckt pmos_rf_33_nw_5t D G S B PG lr=0.40E-6 wr=1.0E-6 nr=4 mismatchflag=0 sigma=1 rbflag=1 sa='0.73u/scale' sd='0.31u/scale' sca=0 scb=0 scc=0 scale='scale_mos_rf_33'
.param
+temp1=parp1rf_33  temp2=parp2rf_33
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='lr*scale-1.5e-08'
+       wef='wr*scale+7e-09'
+       geo_fac ='1/sqrt(nr*lef*wef*1e12)'
+       vthmisprf_33='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisprf_33='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisprf_33='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisprf_33='0.00197184*geo_fac*toxprf_33*fac2*mismatchflag' 
.param Lspace=0.31u
.param Ledge=0.73u
.param Ledgeeff=0.31u
.param Lsti=0.5u
.param Wsti=1.0u
.param Rod=315
.param Rsti=554
.param Ns='int(nr/2+1)'
.param Nd='int((nr+1)/2)'
.param Nodd='(nr-int(nr/2)*2)'
.param dummyflag=1
.param SLeff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param SReff='Ledge+dummyflag*(Ledgeeff-Ledge)'
.param LdioS='(Ns-2)*Lspace+SLeff+SReff+Nodd*(Lspace-SLeff)'
.param LdioD='(Ns-1)*Lspace+Nodd*SLeff'
.param Lod='nr*(lr*scale+Lspace)+2*Ledge-Lspace'
.param sdiofa='(wr*scale*LdioS)/scale/scale'
.param sdiofp='(2*LdioS+(2-Nodd)*wr*scale*(1-dummyflag))/scale'
.param ddiofa='(wr*scale*LdioD)/scale/scale'
.param ddiofp='(2*LdioD+Nodd*wr*scale*(1-dummyflag))/scale'
.param sdiogp='(wr*scale*nr+(2-Nodd)*wr*scale*dummyflag)/scale'
.param ddiogp='(wr*scale*nr+Nodd*wr*scale*dummyflag)/scale'

.param sax='1/(log((Ledge+lr*scale/2+nr*(lr*scale+Lspace))*(Ledge+lr*scale/2+(nr-1)*(lr*scale+Lspace))/(Ledge+Lspace+3*lr*scale/2)/(Ledge+lr*scale/2))/(2*nr*(lr*scale+Lspace))+1/(nr*(Ledge+lr*scale/2)))-lr*scale/2'

.param rgx='((1.333*(wr*scale*1e6+0.54)/(lr*scale*1e6-0.003)+61.5*lr*scale*1e6+8.53)/nr+nr*(0.00150*wr*scale*1e6+0.02906)+0.11307*wr*scale*1e6+0.916*lr*scale*1e6+325.8*lr*scale/nr/(wr*scale))'
.param rsx='(0.0337*(lr*scale+Lspace)*1e6*(2*Ns+1/Ns-3) +4.056/Ns + 1.68)/(wr*scale*1e6)'
.param rdx='0.01*(lr*scale+Lspace)*1e6*(Nd+2/Nd) + 0.2687*(wr*scale*1e6+1.41)/Nd + 0.201/(0.2+(Nd-1)*(lr*scale+Lspace)*1e6)'
.param rdbx='1.63+6.46/(wr*scale*1e6)+15.36/nr+61.74/(wr*scale*1e6*nr)'
.param cgsx='(0.52*nr*(lr*scale+Lspace)*1e6/(0.022*wr*scale*1e6+1.26)+0.27*wr*scale*1e6+0.1)*1e-15'
.param cgdx='(0.15*nr*(lr*scale+Lspace)*1e6+0.05*nr+0.1)*1e-15'
.param cdsx='(0.1+0.0455*nr*wr*scale/(lr*scale+Lspace)+1.6*nr*(lr*scale+Lspace)/(wr*scale+9.8e-6))*1e-15'
.param tnoiax='2.295e6/(lr*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(lr*scale*1e6)+0.5496'

.param fn_dice='noiseflagprf_33_mc*par1fn_mc+noiseflagprf_33_mc_mis*par2fprf_33_mc'
.param c1fprf_33=2.40E+41           c2fprf_33=9.00E+21           c3fprf_33=2.00E+09   
.param arearatio='sigma_factor_flicker_rf_33*(log(3.873)-min(0,0.36*log(((wr*scale*lr*scale*nr)/(28E-6*1E-6*1))**0.5)))'
.param noiaprf_33='c1fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noibprf_33='c2fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'
.param noicprf_33='c3fprf_33*2.718**((fn_dice+(1-fn_dice)*noiseflagprf_33)*arearatio)'

**************subc use*********************
.param Sobn=1.0u Sobe=0.5u Sobs=1.0u Sobw=0.5u
.param Sbnn=0.32u Sbne=0.32u Sbns=0.32u Sbnw=0.32u
.param Tsub=100u
.param backgndflag=1
.param wpeflag=1
**********************

****** rsh value subc use *****
.param rshsti=250
.param rendgr=300
.param rendod=150
.param rshdnwod=600
.param rshdnwsti=500
.param renddnwgr=400
.param rshpsub=7000
.param Wgr=0.21u
.param Sgr=0.16u
.param Wnwgr=1.4u
.param Wnwdnw=0.4u
.param Wwpe=0.62u
.param Wrw='Sobn+Sbnn+(wr*scale)+Sobs+Sbns+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Lrw='Sobw+Sbnw+Lod+Sobe+Sbne+(Wgr-Sgr+Wwpe*(wpeflag-1))*2'
.param Wdnw='Wrw+Wnwdnw*2'
.param Ldnw='Lrw+Wnwdnw*2'
.param Wpsubtmp='Wrw+Wnwgr*2'
.param Lpsubtmp='Lrw+Wnwgr*2'
.param rwdioa='Wrw*Lrw/scale/scale'
.param rwdiop='2*(Wrw+Lrw)/scale'
.param dnwdioa='Wdnw*Ldnw/scale/scale'
.param dnwdiop='2*(Wdnw+Ldnw)/scale'
.param Podact='2*(wr*scale+Lod)'
.param Aodact='wr*scale*Lod'
.param Dsub='Tsub*1e6'
.param Wpsub='Wpsubtmp*1e6'
.param Lpsub='Lpsubtmp*1e6'
.param rbstin='pwr(log(1+pwr(1.38749*Sobn/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstie='pwr(log(1+pwr(1.38749*Sobe/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param rbstis='pwr(log(1+pwr(1.38749*Sobs/Lod,1/0.917430)),0.917430)/1.38749'
.param rbstiw='pwr(log(1+pwr(1.38749*Sobw/(wr*scale), 1/0.917430)),0.917430)/1.38749'
.param ybstix='1/rbstin+1/rbstie+1/rbstis+1/rbstiw'
.param rbstinw='63.9641*pwr(Sobn/Sobw,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstine='63.9641*pwr(Sobn/Sobe,1.71537)+1.31666*pwr(Sobn/Lod,0.602897)+0.328170'
.param rbstien='63.9641*pwr(Sobe/Sobn,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbsties='63.9641*pwr(Sobe/Sobs,1.71537)+1.31666*pwr(Sobe/(wr*scale), 0.602897)+0.328170'
.param rbstise='63.9641*pwr(Sobs/Sobe,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstisw='63.9641*pwr(Sobs/Sobw,1.71537)+1.31666*pwr(Sobs/Lod,0.602897)+0.328170'
.param rbstiws='63.9641*pwr(Sobw/Sobs,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param rbstiwn='63.9641*pwr(Sobw/Sobn,1.71537)+1.31666*pwr(Sobw/(wr*scale), 0.602897)+0.328170'
.param ybstixy='1/rbstinw+1/rbstine+1/rbstien+1/rbsties+1/rbstise+1/rbstisw+1/rbstiws+1/rbstiwn'
.param rbsti='rshsti/(ybstix+ybstixy)'
.param rbod='1e-6*rendod/Podact'
.param rbk='1e-6*rendgr/Podact'
.param rbx='1e-5+rbflag*(rbsti+rbk-rdbx/2)'
.param rshdnw='rshdnwod*Aodact/(rwdioa*scale*scale)+rshdnwsti*(1-Aodact/(rwdioa*scale*scale))'
.param rdnw='rshdnw/(4.45415+12*(Wrw/Lrw+Lrw/Wrw))'
.param rngx='1e-6*renddnwgr/(rwdiop*scale)'
.param rdnwx='rdnw+rngx'
.param rpsubad='pwr(Dsub/2.01999,0.337008)'
.param rpsubaw='pwr(Wpsub,0.240418)*(pwr(Wpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rpsubal='pwr(Lpsub,0.240418)*(pwr(Lpsub,0.814439)/pwr(Dsub,1.22410)+1.01317)'
.param rshpsubaw='pwr(pwr(rpsubaw,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rshpsubal='pwr(pwr(rpsubal,-4.67208)+backgndflag*pwr(rpsubad,-4.67208),-1/4.67208)'
.param rpsubax='rshpsub/(56.90831/(rshpsubaw/Wpsub+rshpsubal/Lpsub)+12*(rshpsubaw-rshpsubal)*(Wpsub-Lpsub)/rshpsubaw/rshpsubal)'
.param rshpsubbw='pwr(Dsub,0.446593)/Lpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Wpsub,5.32511)),1.18759)'
.param rshpsubbl='pwr(Dsub,0.446593)/Wpsub/pwr(99.7363,1.18759)*pwr(log(1+99.7363*pwr(Dsub/Lpsub,5.32511)),1.18759)'
.param rpsubbx='rshpsub/(1/rshpsubbw+1/rshpsubbl)'

*******subc use*************************************
Dnwpsub BP  B2    NWDIO_prf_33  AREA=rwdioa PJ=rwdiop
Rpsuba   BP  PG  R=rpsubax  
Rbod     B2  BI    R=rbod
****************************************************
**********************
RG  G GI   R=rgx
RS  S SI   R=rsx
RD  D DI   R=rdx
**********************
CGS_M GI SI C=cgsx
CGD_M GI DI C=cgdx
CDS_M DI SI C=cdsx
***** Diodes  ****************
DSS  SI  SB  pdio_rf_33_f AREA=sdiofa PJ=sdiofp
DDD  DI  DB  pdio_rf_33_f AREA=ddiofa PJ=ddiofp 
DSG  SI  SB  pdio_rf_33_g AREA=1E-30  PJ=sdiogp  
DDG  DI  DB  pdio_rf_33_g AREA=1E-30  PJ=ddiogp
*****************************************************************************
RB    B  B2  R=rbx   
Rdb  DB  BI  R=rdbx  
Rsb  SB  BI  R=rdbx

M0 DI GI SI BI pch_rf_33 L=lr W=wr M=nr AD=0 AS=0 PD=0 PS=0 SA='sax/scale' SB='sax/scale' SCA=sca SCB=scb SCC=scc


.MODEL pch_rf_33.1 PMOS	(	LEVEL      = 54                  
+LMIN       = 40e-008
+LMAX       = 7.01e-007			
+WMIN       = 1e-006			
+WMAX       = 10.01e-006
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = 0
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxprf_33+toxmisprf_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlprf_33+dlmisprf_33)'  XW         = '7e-09+(dxwprf_33+dwmisprf_33)'
+DLC        = 'dlcprf_33'           DWC        = 0                   XPART      = 0
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+(dvthprf_33+vthmisprf_33)'
+LVTH0      = '2.5702433e-008+dlvthprf_33'
+WVTH0      = '-1.6627131e-009+dwvthprf_33'
+PVTH0      = '-5.610425e-015+dpvthprf_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2prf_33'
+LK2        = '7.9535455e-010+dlk2prf_33'
+WK2        = '-6.2274297e-009+dwk2prf_33'
+PK2        = '1.0138136e-015+dpk2prf_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitprf_33'
+LCIT       = '6.8571721e-011+dlcitprf_33'
+WCIT       = '-4.6654535e-010+dwcitprf_33'
+PCIT       = '1.4159925e-016+dpcitprf_33'
+VOFF       = '-0.14042777+dvoffprf_33'
+LVOFF      = '4.5023226e-008+dlvoffprf_33'
+WVOFF      = '1.3401393e-008+dwvoffprf_33'
+PVOFF      = '-1.1384241e-014+dpvoffprf_33'
+NFACTOR    = '0.63002+dnfactorprf_33'
+ETA0       = '0.93976958+deta0prf_33'
+LETA0      = '-2.4127017e-007+dleta0prf_33'
+WETA0      = '1.9042077e-007+dweta0prf_33'
+PETA0      = '-1.2529949e-013+dpeta0prf_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0prf_33'
+LU0        = '-4.3228825e-010+dlu0prf_33'
+WU0        = '-8.0877649e-010+dwu0prf_33'
+PU0        = '8.0711378e-016+dpu0prf_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatprf_33'  A0         = '0.37683406+da0prf_33'
+LA0        = '2.8545338e-007+dla0prf_33'
+WA0        = '-4.2106763e-008+dwa0prf_33'
+PA0        = '-3.5690177e-014+dpa0prf_33'
+AGS        = '0.30127989+dagsprf_33'
+LAGS       = '1.4992495e-007+dlagsprf_33'
+WAGS       = '5.5740077e-008+dwagsprf_33'
+PAGS       = '-8.0465306e-014+dpagsprf_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmprf_33'
+LPCLM      = '2.5263178e-007+dlpclmprf_33'
+WPCLM      = '-2.6616416e-007+dwpclmprf_33'
+PPCLM      = '1.5631432e-013+dppclmprf_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgoprf_33'           CGDO       = 'cgoprf_33'           CGBO       = 0
+CGDL       = 'cglprf_33'           CGSL       = 'cglprf_33'           CLC        = 0
+CLE        = 0.6                 CF         = 'cfprf_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiaprf_33'
+NOIB       = 'noibprf_33'
+NOIC       = 'noicprf_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 0			CJD        = 0
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 0			CJSWD      = 0
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 0			CJSWGD     = 0
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorprf_33'
+WNFACTOR   = '0+dwnfactorprf_33'   PNFACTOR   = '0+dpnfactorprf_33'   LVSAT      = '0+dlvsatprf_33'
+WVSAT      = '0+dwvsatprf_33'      PVSAT      = '0+dpvsatprf_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pdio_rf_33_f D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.082                   TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 3.16e-4                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.5e-3                  FCS    = 0			   )

.MODEL pdio_rf_33_g D (						   LEVEL  = 3
+IS     = 1.13e-7                 IKR    = 1E10
+N      = 1                       BV     = 9                       IBV    = 0.03
+JSW    = 1e-14                   CJ     = 'cjprf_33'              PJ     = 7.2E-4
+MJ     = 0.31                    FC     = 0                       CJSW   = 'cjswgprf_33'
+AREA   = 3.08e-8                 MJSW   = 0.35                    TLEVC  = 1
+CTA    = 8.78e-4                 CTP    = 1.13e-3                 
+TCV    = -8.5E-04                TLEV   = 1                       XTI    = 3
+EG     = 1.17                    PHP    = 0.5                     PB     = 0.7
+IK     = 1E20                    TPB    = 1.6e-3                  TREF   = 25
+TPHP   = 1.4e-3                  FCS    = 0			   )

.MODEL DNWPSUB_prf_33 D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw_prf_33'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw_prf_33'
+ N      = '1.02*n_d_dnw_prf_33'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw_prf_33)'  CJ     = '1.15E-04*cj_d_dnw_prf_33' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw_prf_33'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )

.MODEL NWDIO_prf_33 D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d_prf_33'   IKR    = 1E10               RS     = '1.0E-10*rs_d_prf_33'
+ N      = '1.02*n_d_prf_33'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d_prf_33)'  CJ     = '1.37E-04*cj_d_prf_33'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d_prf_33'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ends pmos_rf_33_nw_5t


.ENDL RF_MOS_33


**************************************************************************************************
*     MIM CAPACITOR MODEL :
*
*     HF model:
*          1.0fF MiM_Cap w/i underground metal for 1PXM 4<=X<=9
*          1.5fF MiM_Cap w/i underground metal for 1PXM 4<=X<=9
*          2.0fF MiM_Cap w/i underground metal for 1PXM 4<=X<=9
*
*     ## library files:
*
*     1. The MIM capacitors with underground metal are modeled with sub-circuit 'mimcap_um_sin_rf'
*        a. mimflag=1  for 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2  for 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3  for 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     2. The MIM capacitors without underground metal are modeled with sub-circuit 'mimcap_woum_sin_rf'
*        a. mimflag=1  for 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2  for 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3  for 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     3. The UTM direct contact MIM capacitors with underground metal are modeled with sub-circuit 'mimcap_um_sin_udc_rf'
*        a. mimflag=1  for 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2  for 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3  for 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     4. The UTM direct contact MIM capacitors without underground metal are modeled with sub-circuit 'mimcap_woum_sin_udc_rf'
*        a. mimflag=1  for 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2  for 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3  for 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*
*
*     Model name            	lt(um)            wt(um)
*                           	low    high       low    high
*     -------------------------------------------------------------
*     mimcap_um_sin_rf       	4     100         4     100
*     mimcap_woum_sin_rf     	4     100         4     100
*     mimcap_um_sin_udc_rf      4     100         4     100
*     mimcap_woum_sin_udc_rf    4     100         4     100
*     ------------------------------------------------------------
*     End Model
*            **lt: length dimension of top metal (CTM)
*            **wt: width dimension of top metal (CTM)
*            **lay: the number of metal layer under MIM, ex. for MIM is between M7 and M8, lay=7
*            **lt >= wt
*            **MIM is between Mz and Mx      
*
**************************************************************************************************

.LIB scale_option_rfmim
.param scale_rfmim=1
.ENDL scale_option_rfmim


.LIB MC_RFMIM
.lib 'crn65lp_v1d5.l' scale_option_rfmim

.param
+ par_rfmim=AGAUSS(0,1,1)
+ A1_rfmim='par1_mim*1.0000e+000' 
+ l_mimfac        = 1.0
+ cmim_mimfac     = '1.0000e+000+(1.0000e-001)*A1_rfmim'
+ cmim2p0_mimfac  = '1.0000e+000+(1.5000e-001)*A1_rfmim'
+ cm7_mimfac      = 1.0
+ rctm_mimfac     = 1.0
+ cm5_mimfac      = 1.0
+ rsub_mimfac     = 1.0
+ csub_mimfac     = 1.0
.lib 'crn65lp_v1d5.l' RF_MIM
.ENDL MC_RFMIM


********************************************************
*********        MIM Corner Parameters       ***********
********************************************************
.LIB TT_RFMIM
.lib 'crn65lp_v1d5.l' scale_option_rfmim

.param
+ par_rfmim=AGAUSS(0,1,1)
+ l_mimfac        = 1.0
+ cmim_mimfac     = 1.0
+ cmim2p0_mimfac  = 1.0
+ cm7_mimfac      = 1.0
+ rctm_mimfac     = 1.0
+ cm5_mimfac      = 1.0
+ rsub_mimfac     = 1.0
+ csub_mimfac     = 1.0
.lib 'crn65lp_v1d5.l' RF_MIM
.ENDL TT_RFMIM



.LIB FF_RFMIM
.lib 'crn65lp_v1d5.l' scale_option_rfmim

.param
+ par_rfmim=AGAUSS(0,1,1)
+ l_mimfac        = 0.9762
+ cmim_mimfac     = 0.9
+ cmim2p0_mimfac  = 0.85
+ cm7_mimfac      = 0.926
+ rctm_mimfac     = 0.9
+ cm5_mimfac      = 0.931
+ rsub_mimfac     = 0.8
+ csub_mimfac     = 1.25
.lib 'crn65lp_v1d5.l' RF_MIM
.ENDL FF_RFMIM



.LIB SS_RFMIM
.lib 'crn65lp_v1d5.l' scale_option_rfmim

.param
+ par_rfmim=AGAUSS(0,1,1)
+ l_mimfac        = 1.0235
+ cmim_mimfac     = 1.1
+ cmim2p0_mimfac  = 1.15
+ cm7_mimfac      = 1.08
+ rctm_mimfac     = 1.1
+ cm5_mimfac      = 1.074
+ rsub_mimfac     = 1.2
+ csub_mimfac     = 0.833
.lib 'crn65lp_v1d5.l' RF_MIM
.ENDL SS_RFMIM




.LIB RF_MIM

.subckt mimcap_um_sin_rf top bottom um lt=10u wt=10u scale='scale_rfmim' mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt((lt*scale)*(wt*scale)*1e12)'
.param factmis='mis*geo_fac*par_rfmim'
.param ltop_para ='((0.24*((wt*scale)*1e6)*(log(((wt*scale)*1e6)/((lt*scale)*1e6+0.08))+1.19+0.022*((lt*scale)*1e6+0.08)/((wt*scale)*1e6))/1+1.5)/3+3.6)*1e-12'
.param lbot_cbm ='((0.24*((wt*scale)*1e6+3.52)*(log(((wt*scale)*1e6+3.52)/(((lt*scale)*1e6+3.52)+0.2))+1.19+0.022*(((lt*scale)*1e6+3.52)+0.2)/((wt*scale)*1e6+3.52))/1+1.5)/3+3.6)*1e-12'
.param lbot_lead ='((0.606+0.24*(((lt*scale)*1e6+3.52)/2)*(log((((lt*scale)*1e6+3.52)/2)/(1+0.9))+1.19+0.022*(1+0.9)/(((lt*scale)*1e6+3.52)/2))/1+1.5)/2+3.6)*1e-12'
.param lbot_para ='(lbot_cbm+lbot_lead)'
.param via_v ='int(((lt*scale)*1e6/2-1.196)/(0.91)+1)'
.param res_v ='(via_v-1)*(2*via_v-1)/(6*via_v)*0.007902299+23.975/via_v'
.param via_h ='int(((wt*scale)*1e6-3.24)/(2.69)+1)'
.param rtop_para ='(0.067902542+(via_h-1)*(2*via_h-1)/(6*via_h)*0.010063559+res_v/2/via_h+0.25)'
.param r1 ='((lt*scale)*1e6+0.2)/2/((wt*scale)*1e6+0.2)*0.3/3'
.param r3 ='((wt*scale)*1e6+0.2)/2/((lt*scale)*1e6+0.2)*0.3/3'
.param rcbm ='(1/(2/r1+2/r3))'
.param via_left ='int(((((wt*scale)*1e6+3.52)-0.83+(((lt*scale)*1e6+3.52)/2-2.85))-0.76)/(0.91)+1)'
.param res_left ='0.003012048+(via_left-1)*(2*via_left-1)/(6*via_left)*0.008283133+0.615/via_left'
.param via_vert ='int(((((lt*scale)*1e6+3.52)/2-2.85)-0.76)/(0.91)+1)'
.param res_vert ='0.003012048+(via_vert-1)*(2*via_vert-1)/(6*via_vert)*0.008283133+0.615/via_vert'
.param res_cbm ='1/(1/res_left+1/res_vert)'
.param res_lead ='(2/1.66+((lt*scale)*1e6+3.52)/2/1.66)*0.025'
.param res_upper ='res_cbm+res_lead'
.param rbot_para ='(res_upper/2+rcbm+0.25 )'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param mim_d='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.193)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.193)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.193))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmim_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmim2p0_mimfac))'
*
.param cmim_para ='(1+factmis)*((((wt*scale)+mim_a)*((lt*scale)+mim_a)*1e12*mim_b)+2*(((wt*scale)+mim_a)+((lt*scale)+mim_a))*1e6*mim_c+mim_d)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='(((lt*scale)*1e6+3.52)*((wt*scale)*1e6+3.52)*0.0525+0.04382+((lt*scale)*1e6+3.52)*0.0066)*1e-15'
*
ltop top n1 'ltop_para*l_mimfac'
rtop n1 n2 'rtop_para*(0.003*(temper-25)+1)*rctm_mimfac' 
cmim n2 n3 'cmim_para*(1+v(n2,n3)*vcc1+(abs(v(n2,n3))**2)*vcc2)*cmim_corner'
rbot n3 n4 'rbot_para*(0.003*(temper-25)+1)*rctm_mimfac' 
lbot n4 bottom 'lbot_para*l_mimfac'
cox n3 um 'cox_para*cm7_mimfac'
*
.ends mimcap_um_sin_rf
*
.subckt mimcap_woum_sin_rf top bottom gnode lt=10u wt=10u lay=9 scale='scale_rfmim' mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt((lt*scale)*(wt*scale)*1e12)'
.param factmis='mis*geo_fac*par_rfmim'
.param ltop_para ='((0.24*((wt*scale)*1e6)*(log(((wt*scale)*1e6)/((lt*scale)*1e6+0.08))+1.19+0.022*((lt*scale)*1e6+0.08)/((wt*scale)*1e6))/1+1.5)/3+3.6)*1e-12'
.param lbot_cbm ='((0.24*((wt*scale)*1e6+3.52)*(log(((wt*scale)*1e6+3.52)/(((lt*scale)*1e6+3.52)+0.2))+1.19+0.022*(((lt*scale)*1e6+3.52)+0.2)/((wt*scale)*1e6+3.52))/1+1.5)/3+3.6)*1e-12'
.param lbot_lead ='((0.606+0.24*(((lt*scale)*1e6+3.52)/2)*(log((((lt*scale)*1e6+3.52)/2)/(1+0.9))+1.19+0.022*(1+0.9)/(((lt*scale)*1e6+3.52)/2))/1+1.5)/2+3.6)*1e-12'
.param lbot_para ='(lbot_cbm+lbot_lead)'
.param via_v ='int(((lt*scale)*1e6/2-1.196)/(0.91)+1)'
.param res_v ='(via_v-1)*(2*via_v-1)/(6*via_v)*0.007902299+23.975/via_v'
.param via_h ='int(((wt*scale)*1e6-3.24)/(2.69)+1)'
.param rtop_para ='(0.067902542+(via_h-1)*(2*via_h-1)/(6*via_h)*0.010063559+res_v/2/via_h+0.25)'
.param r1 ='((lt*scale)*1e6+0.2)/2/((wt*scale)*1e6+0.2)*0.3/3'
.param r3 ='((wt*scale)*1e6+0.2)/2/((lt*scale)*1e6+0.2)*0.3/3'
.param rcbm ='(1/(2/r1+2/r3))'
.param via_left ='int(((((wt*scale)*1e6+3.52)-0.83+(((lt*scale)*1e6+3.52)/2-2.85))-0.76)/(0.91)+1)'
.param res_left ='0.003012048+(via_left-1)*(2*via_left-1)/(6*via_left)*0.008283133+0.615/via_left'
.param via_vert ='int(((((lt*scale)*1e6+3.52)/2-2.85)-0.76)/(0.91)+1)'
.param res_vert ='0.003012048+(via_vert-1)*(2*via_vert-1)/(6*via_vert)*0.008283133+0.615/via_vert'
.param res_cbm ='1/(1/res_left+1/res_vert)'
.param res_lead ='(2/1.66+((lt*scale)*1e6+3.52)/2/1.66)*0.025'
.param res_upper ='res_cbm+res_lead'
.param rbot_para ='(res_upper/2+rcbm+0.25)'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param mim_d='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.193)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.193)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.193))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmim_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmim2p0_mimfac))'
*
.param cmim_para ='(1+factmis)*((((wt*scale)+mim_a)*((lt*scale)+mim_a)*1e12*mim_b)+2*(((wt*scale)+mim_a)+((lt*scale)+mim_a))*1e6*mim_c+mim_d)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='(((lt*scale)*1e6+3.52)*((wt*scale)*1e6+3.52)*0.0105357+0.04382+((lt*scale)*1e6+3.52)*0.0066)*1e-15'
.param rsub_para ='(1/(2/(((lt*scale)*1e6+3.52)/2/((wt*scale)*1e6+3.52)*1100/3)+2/(((wt*scale)*1e6+3.52)/2/((lt*scale)*1e6+3.52)*1100/3)))*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
.param csub_para ='(312/rsub_para)*1e-15'
*
ltop top n1 'ltop_para*l_mimfac'
rtop n1 n2 'rtop_para*(0.003*(temper-25)+1)*rctm_mimfac' 
cmim n2 n3 'cmim_para*(1+v(n2,n3)*vcc1+(abs(v(n2,n3))**2)*vcc2)*cmim_corner'
rbot n3 n4 'rbot_para*(0.003*(temper-25)+1)*rctm_mimfac' 
lbot n4 bottom 'lbot_para*l_mimfac'
cox n3 n5 'cox_para*((1/(4.35717+(1.42106)*(lay-2)))/0.0872414)*cm5_mimfac'
csub n5 gnode 'csub_para*csub_mimfac'
rsub n5 gnode 'rsub_para*rsub_mimfac'
*
.ends mimcap_woum_sin_rf

.subckt mimcap_um_sin_udc_rf top bottom um lt=10u wt=10u scale='scale_rfmim' mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt((lt*scale)*(wt*scale)*1e12)'
.param factmis='mis*geo_fac*par_rfmim'
.param ltop_para ='((0.24*((wt*scale)*1e6)*(log(((wt*scale)*1e6)/((lt*scale)*1e6+0.08))+1.19+0.022*((lt*scale)*1e6+0.08)/((wt*scale)*1e6))/1+1.5)/3+3.6)*1e-12'
.param lbot_cbm ='((0.24*((wt*scale)*1e6+7.84)*(log(((wt*scale)*1e6+7.84)/(((lt*scale)*1e6+7.84)+0.2))+1.19+0.022*(((lt*scale)*1e6+7.84)+0.2)/((wt*scale)*1e6+7.84))/1)/3)*1e-12'
.param lbot_lead ='((0.606+0.24*(((lt*scale)*1e6+7.84)/2)*(log((((lt*scale)*1e6+7.84)/2)/(2+3.4))+1.19+0.022*(2+3.4)/(((lt*scale)*1e6+7.84)/2))/1)/2)*1e-12'
.param lbot ='(lbot_cbm+lbot_lead)*1e12'
.param lbot_para ='9.05445538528849*lbot**0.590075891297729*1e-12-(1.18350020828306*((lt*scale)/(wt*scale))-1)*1e-12'
.param via_v ='int(((lt*scale)*1e6/2-0.7)/(0.9)+1)'
.param res_v ='(via_v-1)*(2*via_v-1)/(6*via_v)*0.0009712230216+23.975/via_v'
.param via_h ='int(((wt*scale)*1e6-3.075)/(5.385)+1)'
.param rtop ='(0.0170868644+(via_h-1)*(2*via_h-1)/(6*via_h)*0.0055190678+res_v/2/via_h)'
.param rtop_para ='1.06872158*rtop**0.697186362'
.param r1 ='((lt*scale)*1e6+3.72)/2/((wt*scale)*1e6+3.72)*0.26/3'
.param r3 ='((wt*scale)*1e6+3.72)/2/((lt*scale)*1e6+3.72)*0.26/3'
.param rcbm ='(1/(2/r1+2/r3))'
.param via_left ='int(((((wt*scale)*1e6+7.84)-1.03+(((lt*scale)*1e6+7.84)/2-4.21))-1.16)/(0.9)+1)'
.param res_left ='0.0009708737864/2+(via_left-1)*(2*via_left-1)/(6*via_left)*0.0013106796+0.615/via_left'
.param via_vert ='int(((((lt*scale)*1e6+7.84)/2-4.21)-1.16)/(0.9)+1)'
.param res_vert ='0.0009708737864/2+(via_vert-1)*(2*via_vert-1)/(6*via_vert)*0.0013106796+0.615/via_vert'
.param res_cbm ='1/(1/res_left+1/res_vert)'
.param res_lead ='(2/2.06+((lt*scale)*1e6+7.84)/2/2)*0.005'
.param res_upper ='res_cbm+res_lead'
.param rbot_para ='(res_upper/2+rcbm+0.25 )'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param mim_d='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.199)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.199)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.199))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmim_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmim2p0_mimfac))'
*
.param cmim_para ='(1+factmis)*((((wt*scale)+mim_a)*((lt*scale)+mim_a)*1e12*mim_b)+2*(((wt*scale)+mim_a)+((lt*scale)+mim_a))*1e6*mim_c+mim_d)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='(((lt*scale)*1e6+7.84)*((wt*scale)*1e6+7.84)*0.0525+0.04382+((lt*scale)*1e6+7.84)*0.0066)*1e-15'
*
ltop top n1 'ltop_para*l_mimfac'
rtop n1 n2 'rtop_para*(0.003*(temper-25)+1)*rctm_mimfac' 
cmim n2 n3 'cmim_para*(1+v(n2,n3)*vcc1+(abs(v(n2,n3))**2)*vcc2)*cmim_corner'
rbot n3 n4 'rbot_para*(0.003*(temper-25)+1)*rctm_mimfac' 
lbot n4 bottom 'lbot_para*l_mimfac'
cox n3 um 'cox_para*cm7_mimfac'
*
.ends mimcap_um_sin_udc_rf
*
.subckt mimcap_woum_sin_udc_rf top bottom gnode lt=10u wt=10u lay=9 scale='scale_rfmim' mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt((lt*scale)*(wt*scale)*1e12)'
.param factmis='mis*geo_fac*par_rfmim'
.param ltop_para ='((0.24*((wt*scale)*1e6)*(log(((wt*scale)*1e6)/((lt*scale)*1e6+0.08))+1.19+0.022*((lt*scale)*1e6+0.08)/((wt*scale)*1e6))/1+1.5)/3+3.6)*1e-12'
.param lbot_cbm ='((0.24*((wt*scale)*1e6+7.84)*(log(((wt*scale)*1e6+7.84)/(((lt*scale)*1e6+7.84)+0.2))+1.19+0.022*(((lt*scale)*1e6+7.84)+0.2)/((wt*scale)*1e6+7.84))/1)/3)*1e-12'
.param lbot_lead ='((0.606+0.24*(((lt*scale)*1e6+7.84)/2)*(log((((lt*scale)*1e6+7.84)/2)/(2+3.4))+1.19+0.022*(2+3.4)/(((lt*scale)*1e6+7.84)/2))/1)/2)*1e-12'
.param lbot ='(lbot_cbm+lbot_lead)*1e12'
.param lbot_para ='9.05445538528849*lbot**0.590075891297729*1e-12-(1.18350020828306*((lt*scale)/(wt*scale))-1)*1e-12'
.param via_v ='int(((lt*scale)*1e6/2-0.7)/(0.9)+1)'
.param res_v ='(via_v-1)*(2*via_v-1)/(6*via_v)*0.0009712230216+23.975/via_v'
.param via_h ='int(((wt*scale)*1e6-3.075)/(5.385)+1)'
.param rtop ='(0.0170868644+(via_h-1)*(2*via_h-1)/(6*via_h)*0.0055190678+res_v/2/via_h)'
.param rtop_para ='1.06872158*rtop**0.697186362'
.param r1 ='((lt*scale)*1e6+3.72)/2/((wt*scale)*1e6+3.72)*0.26/3'
.param r3 ='((wt*scale)*1e6+3.72)/2/((lt*scale)*1e6+3.72)*0.26/3'
.param rcbm ='(1/(2/r1+2/r3))'
.param via_left ='int(((((wt*scale)*1e6+7.84)-1.03+(((lt*scale)*1e6+7.84)/2-4.21))-1.16)/(0.9)+1)'
.param res_left ='0.0009708737864/2+(via_left-1)*(2*via_left-1)/(6*via_left)*0.0013106796+0.615/via_left'
.param via_vert ='int(((((lt*scale)*1e6+7.84)/2-4.21)-1.16)/(0.9)+1)'
.param res_vert ='0.0009708737864/2+(via_vert-1)*(2*via_vert-1)/(6*via_vert)*0.0013106796+0.615/via_vert'
.param res_cbm ='1/(1/res_left+1/res_vert)'
.param res_lead ='(2/2.06+((lt*scale)*1e6+7.84)/2/2)*0.005'
.param res_upper ='res_cbm+res_lead'
.param rbot_para ='(res_upper/2+rcbm+0.25 )'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param mim_d='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.199)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.199)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.199))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmim_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmim_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmim2p0_mimfac))'
*
.param cmim_para ='(1+factmis)*((((wt*scale)+mim_a)*((lt*scale)+mim_a)*1e12*mim_b)+2*(((wt*scale)+mim_a)+((lt*scale)+mim_a))*1e6*mim_c+mim_d)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='(((lt*scale)*1e6+7.84)*((wt*scale)*1e6+7.84)*0.0105357+0.04382+((lt*scale)*1e6+7.84)*0.0066)*1e-15'
.param rsub_para ='(1/(2/(((lt*scale)*1e6+7.84)/2/((wt*scale)*1e6+7.84)*1100/3)+2/(((wt*scale)*1e6+7.84)/2/((lt*scale)*1e6+7.84)*1100/3)))*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
.param csub_para ='(312/rsub_para)*1e-15'
*
ltop top n1 'ltop_para*l_mimfac'
rtop n1 n2 'rtop_para*(0.003*(temper-25)+1)*rctm_mimfac' 
cmim n2 n3 'cmim_para*(1+v(n2,n3)*vcc1+(abs(v(n2,n3))**2)*vcc2)*cmim_corner'
rbot n3 n4 'rbot_para*(0.003*(temper-25)+1)*rctm_mimfac' 
lbot n4 bottom 'lbot_para*l_mimfac'
cox n3 n5 'cox_para*((1/(4.35717+(1.42106)*(lay-2)))/0.0872414)*cm5_mimfac'
csub n5 gnode 'csub_para*csub_mimfac'
rsub n5 gnode 'rsub_para*rsub_mimfac'
*
.ends mimcap_woum_sin_udc_rf

*
.ENDL RF_MIM
*

***************************************************************************************************
*    HSPICE LEVEL 49:
*
*      ## library files: 
*      models are applied in: 
*      spiral_std_mu_z, spiral_sym_mu_z, spiral_sym_ct_mu_z -- from 1P5M to 1P9M. UTM(34K) is used for the core inductor.
*      spiral_std_mza_a, spiral_sym_mza_a, spiral_sym_ct_mza_a, spiral_std_mu_a, spiral_sym_mu_a, spiral_sym_ct_mu_a-- from 1P3M to 1P8M, Mz and ALRDL or Mu and ALRDL are used for the core inductor.
*
*     The Inductors are modeled with sub-circuit 'spiral_std_xxx' and 'spiral_sym_xxx' and 'spiral_sym_ct_xxx', xxx represents the process of inductor, described above. 
*      mu_z represents M1 + (lay-3)*Mx + Mz + Mu
*      mza_a represents M1 + (lay-2)*Mx + Mz + ALRDL, mu_a is the same with mza_a
*
*      .subckt spiral_std_mu_z    : Standard model with space=2~4um(w=3um~30um) for Inductance varies with turn(1/4 turn increments) and radius
*      .subckt spiral_sym_mu_z    : Symmetric model with space=2~4um(w=3um~30um) for Inductance varies with turn(integral turn increments) and radius
*      .subckt spiral_sym_ct_mu_z : Center-tap model with space=2~4um(w=3um~30um) for Inductance varies with turn(integral turn increments) and radius
*      .subckt spiral_std_mza_a   : Standard model with space=2~4um(w=7.5um~30um) for Inductance varies with turn(1/4 turn increments) and radius
*      .subckt spiral_sym_mza_a   : Symmetric model with space=2~4um(w=7.5um~30um) for Inductance varies with turn(integral turn increments) and radius
*      .subckt spiral_sym_ct_mza_a: Center-tap model with space=2~4um(w=7.5um~30um) for Inductance varies with turn(integral turn increments) and radius
*      .subckt spiral_std_mu_a   : Standard model with space=2~4um(w=6.2um~30um) for Inductance varies with turn(1/4 turn increments) and radius
*      .subckt spiral_sym_mu_a   : Symmetric model with space=2~4um(w=6.2um~30um) for Inductance varies with turn(integral turn increments) and radius
*      .subckt spiral_sym_ct_mu_a: Center-tap model with space=2~4um(w=6.2um~30um) for Inductance varies with turn(integral turn increments) and radius
*
*     Parameter 'gdis' is the distance between core inductor and the guard-ring. Please note that the coupling with other devices should be taken cared by designer, especially 
*     gdis = 10u. This coupling with other devices isn't counted in this model.
*
*	Inductor model:
*         Model name           w(um)        s(um)        rad(um)        gdis(um)        turns           lay            
*                           low    high	   low    high   low    high    low    high    low    high     low    high    
*     --------------------------------------------------------------------------------------------------------------
*	spiral_std_mza_a       7.5  30     2	  4      15    90       10     50	0.5    5.5      3      8
*	spiral_sym_mza_a       7.5  30     2	  4      15    90       10     50	1      6        3      8
*	spiral_sym_ct_mza_a    7.5  30     2	  4      15    90       10     50	1      6        3      8	
*     --------------------------------------------------------------------------------------------------------------
*	spiral_std_mu_z       3   30     2	  4      15    90       10     50	0.5    5.5      5      9
*	spiral_sym_mu_z       3   30     2	  4      15    90       10     50	1       6       5      9
*	spiral_sym_ct_mu_z    3   30     2	  4      15    90       10     50	1       6       5      9	
*    ---------------------------------------------------------------------------------------------------------------
*	spiral_std_mu_a       6.2  30     2	  4      15    90       10     50	0.5    5.5      3      8
*	spiral_sym_mu_a       6.2  30     2	  4      15    90       10     50	 1      6       3      8
*	spiral_sym_ct_mu_a    6.2  30     2	  4      15    90       10     50	 1      6       3      8	
*    ---------------------------------------------------------------------------------------------------------------
*	End Model
*      * when width is larger than 20um, radius is limited within 20um~90um
*      ** center-tapped inductor can only be used in differetial model.
*
***************************************************************************************************

********************************************************
************* Inductor Corner Parameters ***************
********************************************************

.lib mc_rfind
.lib 'crn65lp_v1d5.l' scale_option_ind
.param
+par1_ind=AGAUSS(0,1,3) par2_ind=AGAUSS(0,1,3) 
+A1_ind='par1_ind*3.2247e+000' 
+A2_ind='par2_ind*13.5124e-001' 
+c12_indfac      = '1.0000e+000+(2.5902e-002)*A1_ind+(-5.0969e-003)*A2_ind'
+rm9_indfac      = '1.0000e+000+(1.7386e-002)*A1_ind+(-8.6270e-002)*A2_ind'
+l_indfac        = '1.0000e+000+(8.9341e-003)*A1_ind+(3.5548e-003)*A2_ind'
+cm9_indfac      = '1.0000e+000+(3.0163e-002)*A1_ind+(1.4193e-002)*A2_ind'
+csub_indfac     = '1.0000e+000+(-7.6416e-002)*A1_ind+(-1.9505e-002)*A2_ind'
+rsub_indfac     = '1.0000e+000+(7.0010e-002)*A1_ind+(2.5602e-003)*A2_ind'
.lib 'crn65lp_v1d5.l' RF_IND
.endl mc_rfind


.LIB TT_RFIND
.lib 'crn65lp_v1d5.l' scale_option_ind
.param
+ c12_indfac=1.0
+ rm9_indfac=1.0
+ l_indfac=1.0
+ cm9_indfac=1.0
+ csub_indfac=1.0
+ rsub_indfac=1.0
.lib 'crn65lp_v1d5.l' RF_IND
.ENDL TT_RFIND



.LIB FF_RFIND
.lib 'crn65lp_v1d5.l' scale_option_ind
.param
+ c12_indfac=0.926
+ rm9_indfac=0.9
+ l_indfac=0.9762
+ cm9_indfac=0.913
+ csub_indfac=1.25
+ rsub_indfac=0.8
.lib 'crn65lp_v1d5.l' RF_IND
.ENDL FF_RFIND



.LIB SS_RFIND
.lib 'crn65lp_v1d5.l' scale_option_ind
.param
+ c12_indfac=1.081
+ rm9_indfac=1.1
+ l_indfac=1.0235
+ cm9_indfac=1.07
+ csub_indfac=0.8333
+ rsub_indfac=1.2
.lib 'crn65lp_v1d5.l' RF_IND
.ENDL SS_RFIND

.LIB scale_option_ind
.param scale_ind=1 
.ENDL scale_option_ind



.LIB RF_IND
.subckt spiral_std_mu_a top bottom gnode rad=6e-05 w=9e-06 nr=0.5 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-50)' spacing_='0.5*(spacing/1e-06*scale-3)'
.param T99='(1-abs(sgn(nr-(0.5))))'
.param T100='(min(sgn(rad_-(0.3335))+1,1))'
.param T101='(min(sgn(w_-(0.4002))+1,1))'
.param T102='(min(sgn(w_-(0.3998))+1,1))'
.param T103='(min(sgn(w_-(0.667))+1,1))'
.param T104='(min(sgn(w_-(0.666333))+1,1))'
.param T105='(min(sgn(rad_-(0.333167))+1,1))'
.param T106='(min(sgn(rad_-(0.500167))+1,1))'
.param T107='(min(sgn(rad_-(0.499833))+1,1))'
.param T108='(min(sgn(rad_-(0.666833))+1,1))'
.param T109='(min(sgn(rad_-(0.6665))+1,1))'
.param T110='(min(sgn(rad_-(0.8335))+1,1))'
.param T111='(min(sgn(rad_-(0.833167))+1,1))'
.param T112='(1-abs(sgn(nr-(0.75))))'
.param T113='(1-abs(sgn(nr-(1.25))))'
.param T114='(1-abs(sgn(nr-(1.5))))'
.param T115='(1-abs(sgn(nr-(1.75))))'
.param T116='(1-abs(sgn(nr-(1))))'
.param T117='(1-abs(sgn(nr-(2.25))))'
.param T118='(1-abs(sgn(nr-(2.5))))'
.param T119='(1-abs(sgn(nr-(2.75))))'
.param T120='(1-abs(sgn(nr-(2))))'
.param T121='(1-abs(sgn(nr-(3.25))))'
.param T122='(1-abs(sgn(nr-(3.5))))'
.param T123='(1-abs(sgn(nr-(3.75))))'
.param T124='(1-abs(sgn(nr-(3))))'
.param T125='(1-abs(sgn(nr-(4.25))))'
.param T126='(1-abs(sgn(nr-(4.5))))'
.param T127='(1-abs(sgn(nr-(4.75))))'
.param T128='(1-abs(sgn(nr-(4))))'
.param T129='(1-abs(sgn(nr-(5.25))))'
.param T130='(1-abs(sgn(nr-(5.5))))'
.param T131='(1-abs(sgn(nr-(5))))'
.param S0='T99*(1-T100)*(1-T101)'
.param noS0='(1-S0)'
.param S1='T99*T102*(1-T100)*(1-T103)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T99*T104*(1-T100)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T99*(1-T101)*T105*(1-T106)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T99*T105*T102*(1-T106)*(1-T103)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T99*T105*T104*(1-T106)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T99*(1-T101)*T107*(1-T108)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T99*T107*T102*(1-T108)*(1-T103)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T99*T107*T104*(1-T108)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T99*(1-T101)*T109*(1-T110)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T99*T109*T102*(1-T110)*(1-T103)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T99*T109*T104*(1-T110)*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T99*(1-T101)*T111*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T99*T111*T102*(1-T103)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T99*T111*T104*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T112*(1-T100)*(1-T101)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T112*T102*(1-T100)*(1-T103)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T112*T104*(1-T100)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T112*(1-T101)*T105*(1-T106)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T112*T105*T102*(1-T106)*(1-T103)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T112*T105*T104*(1-T106)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T112*(1-T101)*T107*(1-T108)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T112*T107*T102*(1-T108)*(1-T103)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T112*T107*T104*(1-T108)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T112*(1-T101)*T109*(1-T110)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T112*T109*T102*(1-T110)*(1-T103)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T112*T109*T104*(1-T110)*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T112*(1-T101)*T111*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T112*T111*T102*(1-T103)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T112*T111*T104*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T113*(1-T100)*(1-T101)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T113*T102*(1-T100)*(1-T103)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T113*T104*(1-T100)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T113*(1-T101)*T105*(1-T106)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T113*T105*T102*(1-T106)*(1-T103)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T113*T105*T104*(1-T106)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T113*(1-T101)*T107*(1-T108)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T113*T107*T102*(1-T108)*(1-T103)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T113*T107*T104*(1-T108)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T113*(1-T101)*T109*(1-T110)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T113*T109*T102*(1-T110)*(1-T103)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T113*T109*T104*(1-T110)*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T113*(1-T101)*T111*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T113*T111*T102*(1-T103)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T113*T111*T104*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T114*(1-T100)*(1-T101)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T114*T102*(1-T100)*(1-T103)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T114*T104*(1-T100)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T114*(1-T101)*T105*(1-T106)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T114*T105*T102*(1-T106)*(1-T103)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T114*T105*T104*(1-T106)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T114*(1-T101)*T107*(1-T108)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T114*T107*T102*(1-T108)*(1-T103)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T114*T107*T104*(1-T108)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T114*(1-T101)*T109*(1-T110)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T114*T109*T102*(1-T110)*(1-T103)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T114*T109*T104*(1-T110)*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T114*(1-T101)*T111*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T114*T111*T102*(1-T103)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T114*T111*T104*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T115*(1-T100)*(1-T101)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T115*T102*(1-T100)*(1-T103)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T115*T104*(1-T100)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T115*(1-T101)*T105*(1-T106)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T115*T105*T102*(1-T106)*(1-T103)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T115*T105*T104*(1-T106)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T115*(1-T101)*T107*(1-T108)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T115*T107*T102*(1-T108)*(1-T103)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T115*T107*T104*(1-T108)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T115*(1-T101)*T109*(1-T110)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T115*T109*T102*(1-T110)*(1-T103)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T115*T109*T104*(1-T110)*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T115*(1-T101)*T111*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T115*T111*T102*(1-T103)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T115*T111*T104*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T116*(1-T100)*(1-T101)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T116*T102*(1-T100)*(1-T103)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T116*T104*(1-T100)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T116*(1-T101)*T105*(1-T106)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T116*T105*T102*(1-T106)*(1-T103)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T116*T105*T104*(1-T106)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T116*(1-T101)*T107*(1-T108)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T116*T107*T102*(1-T108)*(1-T103)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T116*T107*T104*(1-T108)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T116*(1-T101)*T109*(1-T110)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T116*T109*T102*(1-T110)*(1-T103)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T116*T109*T104*(1-T110)*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T116*(1-T101)*T111*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T116*T111*T102*(1-T103)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T116*T111*T104*noS88'
.param noS89='(1-S89)*noS88'
.param S90='T117*(1-T100)*(1-T101)*noS89'
.param noS90='(1-S90)*noS89'
.param S91='T117*T102*(1-T100)*(1-T103)*noS90'
.param noS91='(1-S91)*noS90'
.param S92='T117*T104*(1-T100)*noS91'
.param noS92='(1-S92)*noS91'
.param S93='T117*(1-T101)*T105*(1-T106)*noS92'
.param noS93='(1-S93)*noS92'
.param S94='T117*T105*T102*(1-T106)*(1-T103)*noS93'
.param noS94='(1-S94)*noS93'
.param S95='T117*T105*T104*(1-T106)*noS94'
.param noS95='(1-S95)*noS94'
.param S96='T117*(1-T101)*T107*(1-T108)*noS95'
.param noS96='(1-S96)*noS95'
.param S97='T117*T107*T102*(1-T108)*(1-T103)*noS96'
.param noS97='(1-S97)*noS96'
.param S98='T117*T107*T104*(1-T108)*noS97'
.param noS98='(1-S98)*noS97'
.param S99='T117*(1-T101)*T109*(1-T110)*noS98'
.param noS99='(1-S99)*noS98'
.param S100='T117*T109*T102*(1-T110)*(1-T103)*noS99'
.param noS100='(1-S100)*noS99'
.param S101='T117*T109*T104*(1-T110)*noS100'
.param noS101='(1-S101)*noS100'
.param S102='T117*(1-T101)*T111*noS101'
.param noS102='(1-S102)*noS101'
.param S103='T117*T111*T102*(1-T103)*noS102'
.param noS103='(1-S103)*noS102'
.param S104='T117*T111*T104*noS103'
.param noS104='(1-S104)*noS103'
.param S105='T118*(1-T100)*(1-T101)*noS104'
.param noS105='(1-S105)*noS104'
.param S106='T118*T102*(1-T100)*(1-T103)*noS105'
.param noS106='(1-S106)*noS105'
.param S107='T118*T104*(1-T100)*noS106'
.param noS107='(1-S107)*noS106'
.param S108='T118*(1-T101)*T105*(1-T106)*noS107'
.param noS108='(1-S108)*noS107'
.param S109='T118*T105*T102*(1-T106)*(1-T103)*noS108'
.param noS109='(1-S109)*noS108'
.param S110='T118*T105*T104*(1-T106)*noS109'
.param noS110='(1-S110)*noS109'
.param S111='T118*(1-T101)*T107*(1-T108)*noS110'
.param noS111='(1-S111)*noS110'
.param S112='T118*T107*T102*(1-T108)*(1-T103)*noS111'
.param noS112='(1-S112)*noS111'
.param S113='T118*T107*T104*(1-T108)*noS112'
.param noS113='(1-S113)*noS112'
.param S114='T118*(1-T101)*T109*(1-T110)*noS113'
.param noS114='(1-S114)*noS113'
.param S115='T118*T109*T102*(1-T110)*(1-T103)*noS114'
.param noS115='(1-S115)*noS114'
.param S116='T118*T109*T104*(1-T110)*noS115'
.param noS116='(1-S116)*noS115'
.param S117='T118*(1-T101)*T111*noS116'
.param noS117='(1-S117)*noS116'
.param S118='T118*T111*T102*(1-T103)*noS117'
.param noS118='(1-S118)*noS117'
.param S119='T118*T111*T104*noS118'
.param noS119='(1-S119)*noS118'
.param S120='T119*(1-T100)*(1-T101)*noS119'
.param noS120='(1-S120)*noS119'
.param S121='T119*T102*(1-T100)*(1-T103)*noS120'
.param noS121='(1-S121)*noS120'
.param S122='T119*T104*(1-T100)*noS121'
.param noS122='(1-S122)*noS121'
.param S123='T119*(1-T101)*T105*(1-T106)*noS122'
.param noS123='(1-S123)*noS122'
.param S124='T119*T105*T102*(1-T106)*(1-T103)*noS123'
.param noS124='(1-S124)*noS123'
.param S125='T119*T105*T104*(1-T106)*noS124'
.param noS125='(1-S125)*noS124'
.param S126='T119*(1-T101)*T107*(1-T108)*noS125'
.param noS126='(1-S126)*noS125'
.param S127='T119*T107*T102*(1-T108)*(1-T103)*noS126'
.param noS127='(1-S127)*noS126'
.param S128='T119*T107*T104*(1-T108)*noS127'
.param noS128='(1-S128)*noS127'
.param S129='T119*(1-T101)*T109*(1-T110)*noS128'
.param noS129='(1-S129)*noS128'
.param S130='T119*T109*T102*(1-T110)*(1-T103)*noS129'
.param noS130='(1-S130)*noS129'
.param S131='T119*T109*T104*(1-T110)*noS130'
.param noS131='(1-S131)*noS130'
.param S132='T119*(1-T101)*T111*noS131'
.param noS132='(1-S132)*noS131'
.param S133='T119*T111*T102*(1-T103)*noS132'
.param noS133='(1-S133)*noS132'
.param S134='T119*T111*T104*noS133'
.param noS134='(1-S134)*noS133'
.param S135='T120*(1-T100)*(1-T101)*noS134'
.param noS135='(1-S135)*noS134'
.param S136='T120*T102*(1-T100)*(1-T103)*noS135'
.param noS136='(1-S136)*noS135'
.param S137='T120*T104*(1-T100)*noS136'
.param noS137='(1-S137)*noS136'
.param S138='T120*(1-T101)*T105*(1-T106)*noS137'
.param noS138='(1-S138)*noS137'
.param S139='T120*T105*T102*(1-T106)*(1-T103)*noS138'
.param noS139='(1-S139)*noS138'
.param S140='T120*T105*T104*(1-T106)*noS139'
.param noS140='(1-S140)*noS139'
.param S141='T120*(1-T101)*T107*(1-T108)*noS140'
.param noS141='(1-S141)*noS140'
.param S142='T120*T107*T102*(1-T108)*(1-T103)*noS141'
.param noS142='(1-S142)*noS141'
.param S143='T120*T107*T104*(1-T108)*noS142'
.param noS143='(1-S143)*noS142'
.param S144='T120*(1-T101)*T109*(1-T110)*noS143'
.param noS144='(1-S144)*noS143'
.param S145='T120*T109*T102*(1-T110)*(1-T103)*noS144'
.param noS145='(1-S145)*noS144'
.param S146='T120*T109*T104*(1-T110)*noS145'
.param noS146='(1-S146)*noS145'
.param S147='T120*(1-T101)*T111*noS146'
.param noS147='(1-S147)*noS146'
.param S148='T120*T111*T102*(1-T103)*noS147'
.param noS148='(1-S148)*noS147'
.param S149='T120*T111*T104*noS148'
.param noS149='(1-S149)*noS148'
.param S150='T121*(1-T100)*(1-T101)*noS149'
.param noS150='(1-S150)*noS149'
.param S151='T121*T102*(1-T100)*(1-T103)*noS150'
.param noS151='(1-S151)*noS150'
.param S152='T121*T104*(1-T100)*noS151'
.param noS152='(1-S152)*noS151'
.param S153='T121*(1-T101)*T105*(1-T106)*noS152'
.param noS153='(1-S153)*noS152'
.param S154='T121*T105*T102*(1-T106)*(1-T103)*noS153'
.param noS154='(1-S154)*noS153'
.param S155='T121*T105*T104*(1-T106)*noS154'
.param noS155='(1-S155)*noS154'
.param S156='T121*(1-T101)*T107*(1-T108)*noS155'
.param noS156='(1-S156)*noS155'
.param S157='T121*T107*T102*(1-T108)*(1-T103)*noS156'
.param noS157='(1-S157)*noS156'
.param S158='T121*T107*T104*(1-T108)*noS157'
.param noS158='(1-S158)*noS157'
.param S159='T121*(1-T101)*T109*(1-T110)*noS158'
.param noS159='(1-S159)*noS158'
.param S160='T121*T109*T102*(1-T110)*(1-T103)*noS159'
.param noS160='(1-S160)*noS159'
.param S161='T121*T109*T104*(1-T110)*noS160'
.param noS161='(1-S161)*noS160'
.param S162='T121*(1-T101)*T111*noS161'
.param noS162='(1-S162)*noS161'
.param S163='T121*T111*T102*(1-T103)*noS162'
.param noS163='(1-S163)*noS162'
.param S164='T121*T111*T104*noS163'
.param noS164='(1-S164)*noS163'
.param S165='T122*(1-T100)*(1-T101)*noS164'
.param noS165='(1-S165)*noS164'
.param S166='T122*T102*(1-T100)*(1-T103)*noS165'
.param noS166='(1-S166)*noS165'
.param S167='T122*T104*(1-T100)*noS166'
.param noS167='(1-S167)*noS166'
.param S168='T122*(1-T101)*T105*(1-T106)*noS167'
.param noS168='(1-S168)*noS167'
.param S169='T122*T105*T102*(1-T106)*(1-T103)*noS168'
.param noS169='(1-S169)*noS168'
.param S170='T122*T105*T104*(1-T106)*noS169'
.param noS170='(1-S170)*noS169'
.param S171='T122*(1-T101)*T107*(1-T108)*noS170'
.param noS171='(1-S171)*noS170'
.param S172='T122*T107*T102*(1-T108)*(1-T103)*noS171'
.param noS172='(1-S172)*noS171'
.param S173='T122*T107*T104*(1-T108)*noS172'
.param noS173='(1-S173)*noS172'
.param S174='T122*(1-T101)*T109*(1-T110)*noS173'
.param noS174='(1-S174)*noS173'
.param S175='T122*T109*T102*(1-T110)*(1-T103)*noS174'
.param noS175='(1-S175)*noS174'
.param S176='T122*T109*T104*(1-T110)*noS175'
.param noS176='(1-S176)*noS175'
.param S177='T122*(1-T101)*T111*noS176'
.param noS177='(1-S177)*noS176'
.param S178='T122*T111*T102*(1-T103)*noS177'
.param noS178='(1-S178)*noS177'
.param S179='T122*T111*T104*noS178'
.param noS179='(1-S179)*noS178'
.param S180='T123*(1-T100)*(1-T101)*noS179'
.param noS180='(1-S180)*noS179'
.param S181='T123*T102*(1-T100)*(1-T103)*noS180'
.param noS181='(1-S181)*noS180'
.param S182='T123*T104*(1-T100)*noS181'
.param noS182='(1-S182)*noS181'
.param S183='T123*(1-T101)*T105*(1-T106)*noS182'
.param noS183='(1-S183)*noS182'
.param S184='T123*T105*T102*(1-T106)*(1-T103)*noS183'
.param noS184='(1-S184)*noS183'
.param S185='T123*T105*T104*(1-T106)*noS184'
.param noS185='(1-S185)*noS184'
.param S186='T123*(1-T101)*T107*(1-T108)*noS185'
.param noS186='(1-S186)*noS185'
.param S187='T123*T107*T102*(1-T108)*(1-T103)*noS186'
.param noS187='(1-S187)*noS186'
.param S188='T123*T107*T104*(1-T108)*noS187'
.param noS188='(1-S188)*noS187'
.param S189='T123*(1-T101)*T109*(1-T110)*noS188'
.param noS189='(1-S189)*noS188'
.param S190='T123*T109*T102*(1-T110)*(1-T103)*noS189'
.param noS190='(1-S190)*noS189'
.param S191='T123*T109*T104*(1-T110)*noS190'
.param noS191='(1-S191)*noS190'
.param S192='T123*(1-T101)*T111*noS191'
.param noS192='(1-S192)*noS191'
.param S193='T123*T111*T102*(1-T103)*noS192'
.param noS193='(1-S193)*noS192'
.param S194='T123*T111*T104*noS193'
.param noS194='(1-S194)*noS193'
.param S195='T124*(1-T100)*(1-T101)*noS194'
.param noS195='(1-S195)*noS194'
.param S196='T124*T102*(1-T100)*(1-T103)*noS195'
.param noS196='(1-S196)*noS195'
.param S197='T124*T104*(1-T100)*noS196'
.param noS197='(1-S197)*noS196'
.param S198='T124*(1-T101)*T105*(1-T106)*noS197'
.param noS198='(1-S198)*noS197'
.param S199='T124*T105*T102*(1-T106)*(1-T103)*noS198'
.param noS199='(1-S199)*noS198'
.param S200='T124*T105*T104*(1-T106)*noS199'
.param noS200='(1-S200)*noS199'
.param S201='T124*(1-T101)*T107*(1-T108)*noS200'
.param noS201='(1-S201)*noS200'
.param S202='T124*T107*T102*(1-T108)*(1-T103)*noS201'
.param noS202='(1-S202)*noS201'
.param S203='T124*T107*T104*(1-T108)*noS202'
.param noS203='(1-S203)*noS202'
.param S204='T124*(1-T101)*T109*(1-T110)*noS203'
.param noS204='(1-S204)*noS203'
.param S205='T124*T109*T102*(1-T110)*(1-T103)*noS204'
.param noS205='(1-S205)*noS204'
.param S206='T124*T109*T104*(1-T110)*noS205'
.param noS206='(1-S206)*noS205'
.param S207='T124*(1-T101)*T111*noS206'
.param noS207='(1-S207)*noS206'
.param S208='T124*T111*T102*(1-T103)*noS207'
.param noS208='(1-S208)*noS207'
.param S209='T124*T111*T104*noS208'
.param noS209='(1-S209)*noS208'
.param S210='T125*(1-T100)*(1-T101)*noS209'
.param noS210='(1-S210)*noS209'
.param S211='T125*T102*(1-T100)*(1-T103)*noS210'
.param noS211='(1-S211)*noS210'
.param S212='T125*T104*(1-T100)*noS211'
.param noS212='(1-S212)*noS211'
.param S213='T125*(1-T101)*T105*(1-T106)*noS212'
.param noS213='(1-S213)*noS212'
.param S214='T125*T105*T102*(1-T106)*(1-T103)*noS213'
.param noS214='(1-S214)*noS213'
.param S215='T125*T105*T104*(1-T106)*noS214'
.param noS215='(1-S215)*noS214'
.param S216='T125*(1-T101)*T107*(1-T108)*noS215'
.param noS216='(1-S216)*noS215'
.param S217='T125*T107*T102*(1-T108)*(1-T103)*noS216'
.param noS217='(1-S217)*noS216'
.param S218='T125*T107*T104*(1-T108)*noS217'
.param noS218='(1-S218)*noS217'
.param S219='T125*(1-T101)*T109*(1-T110)*noS218'
.param noS219='(1-S219)*noS218'
.param S220='T125*T109*T102*(1-T110)*(1-T103)*noS219'
.param noS220='(1-S220)*noS219'
.param S221='T125*T109*T104*(1-T110)*noS220'
.param noS221='(1-S221)*noS220'
.param S222='T125*(1-T101)*T111*noS221'
.param noS222='(1-S222)*noS221'
.param S223='T125*T111*T102*(1-T103)*noS222'
.param noS223='(1-S223)*noS222'
.param S224='T125*T111*T104*noS223'
.param noS224='(1-S224)*noS223'
.param S225='T126*(1-T100)*(1-T101)*noS224'
.param noS225='(1-S225)*noS224'
.param S226='T126*T102*(1-T100)*(1-T103)*noS225'
.param noS226='(1-S226)*noS225'
.param S227='T126*T104*(1-T100)*noS226'
.param noS227='(1-S227)*noS226'
.param S228='T126*(1-T101)*T105*(1-T106)*noS227'
.param noS228='(1-S228)*noS227'
.param S229='T126*T105*T102*(1-T106)*(1-T103)*noS228'
.param noS229='(1-S229)*noS228'
.param S230='T126*T105*T104*(1-T106)*noS229'
.param noS230='(1-S230)*noS229'
.param S231='T126*(1-T101)*T107*(1-T108)*noS230'
.param noS231='(1-S231)*noS230'
.param S232='T126*T107*T102*(1-T108)*(1-T103)*noS231'
.param noS232='(1-S232)*noS231'
.param S233='T126*T107*T104*(1-T108)*noS232'
.param noS233='(1-S233)*noS232'
.param S234='T126*(1-T101)*T109*(1-T110)*noS233'
.param noS234='(1-S234)*noS233'
.param S235='T126*T109*T102*(1-T110)*(1-T103)*noS234'
.param noS235='(1-S235)*noS234'
.param S236='T126*T109*T104*(1-T110)*noS235'
.param noS236='(1-S236)*noS235'
.param S237='T126*(1-T101)*T111*noS236'
.param noS237='(1-S237)*noS236'
.param S238='T126*T111*T102*(1-T103)*noS237'
.param noS238='(1-S238)*noS237'
.param S239='T126*T111*T104*noS238'
.param noS239='(1-S239)*noS238'
.param S240='T127*(1-T100)*(1-T101)*noS239'
.param noS240='(1-S240)*noS239'
.param S241='T127*T102*(1-T100)*(1-T103)*noS240'
.param noS241='(1-S241)*noS240'
.param S242='T127*T104*(1-T100)*noS241'
.param noS242='(1-S242)*noS241'
.param S243='T127*(1-T101)*T105*(1-T106)*noS242'
.param noS243='(1-S243)*noS242'
.param S244='T127*T105*T102*(1-T106)*(1-T103)*noS243'
.param noS244='(1-S244)*noS243'
.param S245='T127*T105*T104*(1-T106)*noS244'
.param noS245='(1-S245)*noS244'
.param S246='T127*(1-T101)*T107*(1-T108)*noS245'
.param noS246='(1-S246)*noS245'
.param S247='T127*T107*T102*(1-T108)*(1-T103)*noS246'
.param noS247='(1-S247)*noS246'
.param S248='T127*T107*T104*(1-T108)*noS247'
.param noS248='(1-S248)*noS247'
.param S249='T127*(1-T101)*T109*(1-T110)*noS248'
.param noS249='(1-S249)*noS248'
.param S250='T127*T109*T102*(1-T110)*(1-T103)*noS249'
.param noS250='(1-S250)*noS249'
.param S251='T127*T109*T104*(1-T110)*noS250'
.param noS251='(1-S251)*noS250'
.param S252='T127*(1-T101)*T111*noS251'
.param noS252='(1-S252)*noS251'
.param S253='T127*T111*T102*(1-T103)*noS252'
.param noS253='(1-S253)*noS252'
.param S254='T127*T111*T104*noS253'
.param noS254='(1-S254)*noS253'
.param S255='T128*(1-T100)*(1-T101)*noS254'
.param noS255='(1-S255)*noS254'
.param S256='T128*T102*(1-T100)*(1-T103)*noS255'
.param noS256='(1-S256)*noS255'
.param S257='T128*T104*(1-T100)*noS256'
.param noS257='(1-S257)*noS256'
.param S258='T128*(1-T101)*T105*(1-T106)*noS257'
.param noS258='(1-S258)*noS257'
.param S259='T128*T105*T102*(1-T106)*(1-T103)*noS258'
.param noS259='(1-S259)*noS258'
.param S260='T128*T105*T104*(1-T106)*noS259'
.param noS260='(1-S260)*noS259'
.param S261='T128*(1-T101)*T107*(1-T108)*noS260'
.param noS261='(1-S261)*noS260'
.param S262='T128*T107*T102*(1-T108)*(1-T103)*noS261'
.param noS262='(1-S262)*noS261'
.param S263='T128*T107*T104*(1-T108)*noS262'
.param noS263='(1-S263)*noS262'
.param S264='T128*(1-T101)*T109*(1-T110)*noS263'
.param noS264='(1-S264)*noS263'
.param S265='T128*T109*T102*(1-T110)*(1-T103)*noS264'
.param noS265='(1-S265)*noS264'
.param S266='T128*T109*T104*(1-T110)*noS265'
.param noS266='(1-S266)*noS265'
.param S267='T128*(1-T101)*T111*noS266'
.param noS267='(1-S267)*noS266'
.param S268='T128*T111*T102*(1-T103)*noS267'
.param noS268='(1-S268)*noS267'
.param S269='T128*T111*T104*noS268'
.param noS269='(1-S269)*noS268'
.param S270='T129*(1-T100)*(1-T101)*noS269'
.param noS270='(1-S270)*noS269'
.param S271='T129*T102*(1-T100)*(1-T103)*noS270'
.param noS271='(1-S271)*noS270'
.param S272='T129*T104*(1-T100)*noS271'
.param noS272='(1-S272)*noS271'
.param S273='T129*(1-T101)*T105*(1-T106)*noS272'
.param noS273='(1-S273)*noS272'
.param S274='T129*T105*T102*(1-T106)*(1-T103)*noS273'
.param noS274='(1-S274)*noS273'
.param S275='T129*T105*T104*(1-T106)*noS274'
.param noS275='(1-S275)*noS274'
.param S276='T129*(1-T101)*T107*(1-T108)*noS275'
.param noS276='(1-S276)*noS275'
.param S277='T129*T107*T102*(1-T108)*(1-T103)*noS276'
.param noS277='(1-S277)*noS276'
.param S278='T129*T107*T104*(1-T108)*noS277'
.param noS278='(1-S278)*noS277'
.param S279='T129*(1-T101)*T109*(1-T110)*noS278'
.param noS279='(1-S279)*noS278'
.param S280='T129*T109*T102*(1-T110)*(1-T103)*noS279'
.param noS280='(1-S280)*noS279'
.param S281='T129*T109*T104*(1-T110)*noS280'
.param noS281='(1-S281)*noS280'
.param S282='T129*(1-T101)*T111*noS281'
.param noS282='(1-S282)*noS281'
.param S283='T129*T111*T102*(1-T103)*noS282'
.param noS283='(1-S283)*noS282'
.param S284='T129*T111*T104*noS283'
.param noS284='(1-S284)*noS283'
.param S285='T130*(1-T100)*(1-T101)*noS284'
.param noS285='(1-S285)*noS284'
.param S286='T130*T102*(1-T100)*(1-T103)*noS285'
.param noS286='(1-S286)*noS285'
.param S287='T130*T104*(1-T100)*noS286'
.param noS287='(1-S287)*noS286'
.param S288='T130*(1-T101)*T105*(1-T106)*noS287'
.param noS288='(1-S288)*noS287'
.param S289='T130*T105*T102*(1-T106)*(1-T103)*noS288'
.param noS289='(1-S289)*noS288'
.param S290='T130*T105*T104*(1-T106)*noS289'
.param noS290='(1-S290)*noS289'
.param S291='T130*(1-T101)*T107*(1-T108)*noS290'
.param noS291='(1-S291)*noS290'
.param S292='T130*T107*T102*(1-T108)*(1-T103)*noS291'
.param noS292='(1-S292)*noS291'
.param S293='T130*T107*T104*(1-T108)*noS292'
.param noS293='(1-S293)*noS292'
.param S294='T130*(1-T101)*T109*(1-T110)*noS293'
.param noS294='(1-S294)*noS293'
.param S295='T130*T109*T102*(1-T110)*(1-T103)*noS294'
.param noS295='(1-S295)*noS294'
.param S296='T130*T109*T104*(1-T110)*noS295'
.param noS296='(1-S296)*noS295'
.param S297='T130*(1-T101)*T111*noS296'
.param noS297='(1-S297)*noS296'
.param S298='T130*T111*T102*(1-T103)*noS297'
.param noS298='(1-S298)*noS297'
.param S299='T130*T111*T104*noS298'
.param noS299='(1-S299)*noS298'
.param S300='T131*(1-T100)*(1-T101)*noS299'
.param noS300='(1-S300)*noS299'
.param S301='T131*T102*(1-T100)*(1-T103)*noS300'
.param noS301='(1-S301)*noS300'
.param S302='T131*T104*(1-T100)*noS301'
.param noS302='(1-S302)*noS301'
.param S303='T131*(1-T101)*T105*(1-T106)*noS302'
.param noS303='(1-S303)*noS302'
.param S304='T131*T105*T102*(1-T106)*(1-T103)*noS303'
.param noS304='(1-S304)*noS303'
.param S305='T131*T105*T104*(1-T106)*noS304'
.param noS305='(1-S305)*noS304'
.param S306='T131*(1-T101)*T107*(1-T108)*noS305'
.param noS306='(1-S306)*noS305'
.param S307='T131*T107*T102*(1-T108)*(1-T103)*noS306'
.param noS307='(1-S307)*noS306'
.param S308='T131*T107*T104*(1-T108)*noS307'
.param noS308='(1-S308)*noS307'
.param S309='T131*(1-T101)*T109*(1-T110)*noS308'
.param noS309='(1-S309)*noS308'
.param S310='T131*T109*T102*(1-T110)*(1-T103)*noS309'
.param noS310='(1-S310)*noS309'
.param S311='T131*T109*T104*(1-T110)*noS310'
.param noS311='(1-S311)*noS310'
.param S312='T131*(1-T101)*T111*noS311'
.param noS312='(1-S312)*noS311'
.param S313='T131*T111*T102*(1-T103)*noS312'
.param noS313='(1-S313)*noS312'
.param S314='T131*T111*T104*noS313'
.param noS314='(1-S314)*noS313'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V0_part3='V0_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.108916e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V0_part5='V0_part4+(-1.181866e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V0_part6='V0_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V0_part7='V0_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V0_part8='V0_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V0_part9='V0_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V0_part10='V0_part9+1.226898e+00*S90+(-1.256106e+01)*S91+(-3.703451e+01)*S92+0.000000e+00*S93+(-1.572631e+01)*S94+(-6.176543e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+(-1.801416e+01)*S98+0.000000e+00*S99'
.param V0_part11='V0_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-3.052887e+01)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V0_part12='V0_part11+(-1.505261e+01)*S110+0.000000e+00*S111+0.000000e+00*S112+(-1.865053e+01)*S113+(-4.834815e+00)*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V0_part13='V0_part12+0.000000e+00*S120+0.000000e+00*S121+(-1.282536e+01)*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V0_part14='V0_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+(-2.647107e+00)*S137+5.942116e+00*S138+0.000000e+00*S139'
.param V0_part15='V0_part14+0.000000e+00*S140+9.250888e-02*S141+0.000000e+00*S142+(-5.095201e-01)*S143+(-3.941929e+00)*S144+1.064139e+00*S145+8.679540e+00*S146+2.383291e-01*S147+(-3.023739e+00)*S148+0.000000e+00*S149'
.param V0_part16='V0_part15+0.000000e+00*S150+(-1.248231e+01)*S151+(-2.739607e+01)*S152+0.000000e+00*S153+0.000000e+00*S154+(-7.824160e+00)*S155+(-1.588864e+01)*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V0_part17='V0_part16+0.000000e+00*S160+0.000000e+00*S161+(-4.912402e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-9.553180e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V0_part18='V0_part17+(-2.333938e+00)*S170+0.000000e+00*S171+0.000000e+00*S172+(-3.860532e+00)*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V0_part19='V0_part18+0.000000e+00*S180+0.000000e+00*S181+(-1.396968e+01)*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V0_part20='V0_part19+(-3.276418e+00)*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+7.541203e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V0_part21='V0_part20+8.629045e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V0_part22='V0_part21+0.000000e+00*S210+(-5.407967e+00)*S211+(-1.401950e+01)*S212+(-9.442491e+00)*S213+0.000000e+00*S214+(-1.462462e+00)*S215+0.000000e+00*S216+(-1.412681e+01)*S217+0.000000e+00*S218+(-4.131990e+00)*S219'
.param V0_part23='V0_part22+0.000000e+00*S220+(-7.591427e+01)*S221+0.000000e+00*S222+(-4.762692e+01)*S223+(-8.201480e+01)*S224+(-5.919867e+00)*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V0_part24='V0_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V0_part25='V0_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+(-5.616194e+00)*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V0_part26='V0_part25+0.000000e+00*S250+(-1.049657e+01)*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+7.126416e+00*S255+0.000000e+00*S256+1.483965e+01*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V0_part27='V0_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V0_part28='V0_part27+0.000000e+00*S270+0.000000e+00*S271+(-1.491259e+01)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V0_part29='V0_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-9.146745e+00)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V0_part30='V0_part29+(-9.962961e+00)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+9.876415e+00*S296+0.000000e+00*S297+0.000000e+00*S298+(-2.546400e+01)*S299'
.param V0_part31='V0_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-6.229643e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+(-5.801712e+00)*S308+0.000000e+00*S309'
.param V0='V0_part31+0.000000e+00*S310+(-1.096357e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V1_part3='V1_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+3.056622e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V1_part5='V1_part4+1.082349e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V1_part6='V1_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V1_part7='V1_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V1_part8='V1_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V1_part9='V1_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V1_part10='V1_part9+3.306641e+00*S90+1.662237e+01*S91+3.392124e+01*S92+0.000000e+00*S93+9.805916e+00*S94+(-6.500412e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+(-4.272869e+00)*S98+0.000000e+00*S99'
.param V1_part11='V1_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+4.140117e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V1_part12='V1_part11+5.341025e+00*S110+0.000000e+00*S111+0.000000e+00*S112+1.260374e+01*S113+1.423610e+01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V1_part13='V1_part12+0.000000e+00*S120+0.000000e+00*S121+7.497403e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V1_part14='V1_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+9.519799e+00*S137+5.620626e-01*S138+0.000000e+00*S139'
.param V1_part15='V1_part14+0.000000e+00*S140+1.716659e+01*S141+0.000000e+00*S142+6.736680e+00*S143+1.678823e+01*S144+8.217968e+00*S145+(-7.224380e+00)*S146+1.587487e+01*S147+1.161404e+01*S148+0.000000e+00*S149'
.param V1_part16='V1_part15+0.000000e+00*S150+6.625961e+00*S151+(-6.631390e+00)*S152+0.000000e+00*S153+0.000000e+00*S154+(-2.878314e+01)*S155+2.527969e+01*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V1_part17='V1_part16+0.000000e+00*S160+0.000000e+00*S161+1.150943e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-1.212292e+01)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V1_part18='V1_part17+(-2.678808e+01)*S170+0.000000e+00*S171+0.000000e+00*S172+(-1.427059e-01)*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V1_part19='V1_part18+0.000000e+00*S180+0.000000e+00*S181+(-1.056350e+01)*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V1_part20='V1_part19+9.630549e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-2.477235e+00)*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V1_part21='V1_part20+(-1.627073e+01)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V1_part22='V1_part21+0.000000e+00*S210+(-1.152968e+01)*S211+(-1.946572e+01)*S212+2.670834e+01*S213+0.000000e+00*S214+(-2.202719e+01)*S215+0.000000e+00*S216+4.328408e+00*S217+0.000000e+00*S218+7.779266e+00*S219'
.param V1_part23='V1_part22+0.000000e+00*S220+4.241968e+01*S221+0.000000e+00*S222+3.798580e+01*S223+5.057290e+01*S224+1.890558e+01*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V1_part24='V1_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V1_part25='V1_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+2.496053e+01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V1_part26='V1_part25+0.000000e+00*S250+9.584875e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+(-4.694296e+00)*S255+0.000000e+00*S256+(-3.406677e+01)*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V1_part27='V1_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V1_part28='V1_part27+0.000000e+00*S270+0.000000e+00*S271+(-1.578849e+01)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V1_part29='V1_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-1.970112e+01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V1_part30='V1_part29+7.834892e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+4.330119e+00*S296+0.000000e+00*S297+0.000000e+00*S298+1.311848e+01*S299'
.param V1_part31='V1_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+6.574964e+00*S305+0.000000e+00*S306+0.000000e+00*S307+8.068435e+00*S308+0.000000e+00*S309'
.param V1='V1_part31+0.000000e+00*S310+1.921649e+01*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V2_part3='V2_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+1.374505e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V2_part5='V2_part4+2.180150e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V2_part6='V2_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V2_part7='V2_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V2_part8='V2_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V2_part9='V2_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V2_part10='V2_part9+6.261503e+00*S90+3.012887e+01*S91+6.459702e+01*S92+0.000000e+00*S93+4.056594e+01*S94+4.550263e+01*S95+0.000000e+00*S96+0.000000e+00*S97+5.447208e+01*S98+0.000000e+00*S99'
.param V2_part11='V2_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+4.141664e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V2_part12='V2_part11+3.079918e+01*S110+0.000000e+00*S111+0.000000e+00*S112+3.651351e+01*S113+1.459431e+01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V2_part13='V2_part12+0.000000e+00*S120+0.000000e+00*S121+2.351344e+01*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V2_part14='V2_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+1.699759e+01*S137+3.456444e+00*S138+0.000000e+00*S139'
.param V2_part15='V2_part14+0.000000e+00*S140+1.634289e+01*S141+0.000000e+00*S142+1.722628e+01*S143+1.475594e+01*S144+1.569291e+01*S145+1.203193e+01*S146+6.163251e+00*S147+1.986489e+01*S148+0.000000e+00*S149'
.param V2_part16='V2_part15+0.000000e+00*S150+4.465272e+01*S151+7.467578e+01*S152+0.000000e+00*S153+0.000000e+00*S154+5.716666e+01*S155+2.769760e+01*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V2_part17='V2_part16+0.000000e+00*S160+0.000000e+00*S161+1.958268e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+3.597509e+01*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V2_part18='V2_part17+3.179751e+01*S170+0.000000e+00*S171+0.000000e+00*S172+2.174346e+01*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V2_part19='V2_part18+0.000000e+00*S180+0.000000e+00*S181+5.000272e+01*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V2_part20='V2_part19+4.240589e+01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+1.278321e+01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V2_part21='V2_part20+1.412471e+01*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V2_part22='V2_part21+0.000000e+00*S210+3.513086e+01*S211+6.325061e+01*S212+4.913860e+01*S213+0.000000e+00*S214+4.534196e+01*S215+0.000000e+00*S216+6.037447e+01*S217+0.000000e+00*S218+4.392987e+01*S219'
.param V2_part23='V2_part22+0.000000e+00*S220+1.388300e+02*S221+0.000000e+00*S222+9.240883e+01*S223+1.590107e+02*S224+1.467083e+01*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V2_part24='V2_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V2_part25='V2_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+1.098691e+01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V2_part26='V2_part25+0.000000e+00*S250+3.873417e+01*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+6.549656e+00*S255+0.000000e+00*S256+1.224224e+01*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V2_part27='V2_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V2_part28='V2_part27+0.000000e+00*S270+0.000000e+00*S271+6.245889e+01*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V2_part29='V2_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+4.599366e+01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V2_part30='V2_part29+3.669204e+01*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+1.158799e+01*S296+0.000000e+00*S297+0.000000e+00*S298+8.664775e+01*S299'
.param V2_part31='V2_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+3.104926e+01*S305+0.000000e+00*S306+0.000000e+00*S307+3.840010e+01*S308+0.000000e+00*S309'
.param V2='V2_part31+0.000000e+00*S310+3.865008e+01*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V3_part3='V3_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-2.610310e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V3_part5='V3_part4+(-3.781833e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V3_part6='V3_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V3_part7='V3_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V3_part8='V3_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V3_part9='V3_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V3_part10='V3_part9+(-3.615870e-01)*S90+(-2.169090e+00)*S91+(-1.587849e+00)*S92+0.000000e+00*S93+(-7.169019e-02)*S94+(-8.172455e-01)*S95+0.000000e+00*S96+0.000000e+00*S97+(-5.609973e+00)*S98+0.000000e+00*S99'
.param V3_part11='V3_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-6.555828e-01)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V3_part12='V3_part11+(-1.809646e+00)*S110+0.000000e+00*S111+0.000000e+00*S112+(-4.096103e+00)*S113+3.868275e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V3_part13='V3_part12+0.000000e+00*S120+0.000000e+00*S121+(-2.324586e+00)*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V3_part14='V3_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+3.483875e+00*S137+7.763475e-01*S138+0.000000e+00*S139'
.param V3_part15='V3_part14+0.000000e+00*S140+(-1.178551e-01)*S141+0.000000e+00*S142+3.259948e+00*S143+(-1.931363e+00)*S144+(-3.951683e+00)*S145+1.067303e+00*S146+8.185457e+00*S147+6.810049e+00*S148+0.000000e+00*S149'
.param V3_part16='V3_part15+0.000000e+00*S150+4.684711e-01*S151+(-3.603457e+00)*S152+0.000000e+00*S153+0.000000e+00*S154+(-6.128663e+00)*S155+1.663097e-01*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V3_part17='V3_part16+0.000000e+00*S160+0.000000e+00*S161+(-3.323682e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-3.437113e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V3_part18='V3_part17+(-3.798814e+00)*S170+0.000000e+00*S171+0.000000e+00*S172+1.686418e-01*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V3_part19='V3_part18+0.000000e+00*S180+0.000000e+00*S181+6.717566e-01*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V3_part20='V3_part19+8.557578e-01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-1.902355e+00)*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V3_part21='V3_part20+(-1.735898e-01)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V3_part22='V3_part21+0.000000e+00*S210+(-2.795057e+00)*S211+(-6.110828e+00)*S212+8.589967e-01*S213+0.000000e+00*S214+(-1.262794e+00)*S215+0.000000e+00*S216+1.370805e+00*S217+0.000000e+00*S218+3.271604e+00*S219'
.param V3_part23='V3_part22+0.000000e+00*S220+8.618359e+00*S221+0.000000e+00*S222+9.220940e+00*S223+7.628281e+00*S224+(-3.008870e+00)*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V3_part24='V3_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V3_part25='V3_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+3.420695e-01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V3_part26='V3_part25+0.000000e+00*S250+6.300682e-01*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+3.689486e+00*S255+0.000000e+00*S256+4.787302e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V3_part27='V3_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V3_part28='V3_part27+0.000000e+00*S270+0.000000e+00*S271+2.729166e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V3_part29='V3_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-4.663399e+00)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V3_part30='V3_part29+(-1.517264e+00)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+4.099943e+00*S296+0.000000e+00*S297+0.000000e+00*S298+7.523358e+00*S299'
.param V3_part31='V3_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+5.451720e+00*S305+0.000000e+00*S306+0.000000e+00*S307+4.753079e+00*S308+0.000000e+00*S309'
.param V3='V3_part31+0.000000e+00*S310+4.789158e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V4_part3='V4_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-2.668443e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V4_part5='V4_part4+(-3.113462e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V4_part6='V4_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V4_part7='V4_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V4_part8='V4_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V4_part9='V4_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V4_part10='V4_part9+(-3.848090e+00)*S90+(-4.473558e+00)*S91+(-5.310073e+00)*S92+0.000000e+00*S93+(-5.701289e+00)*S94+(-6.211592e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+(-7.651356e+00)*S98+0.000000e+00*S99'
.param V4_part11='V4_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-4.819624e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V4_part12='V4_part11+(-7.431436e+00)*S110+0.000000e+00*S111+0.000000e+00*S112+(-7.604054e+00)*S113+(-6.192471e+00)*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V4_part13='V4_part12+0.000000e+00*S120+0.000000e+00*S121+(-6.271901e+00)*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V4_part14='V4_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+(-8.289953e+00)*S137+(-7.552502e+00)*S138+0.000000e+00*S139'
.param V4_part15='V4_part14+0.000000e+00*S140+(-7.800729e+00)*S141+0.000000e+00*S142+(-1.150714e+01)*S143+(-9.420632e+00)*S144+(-9.906856e+00)*S145+(-1.165761e+01)*S146+(-1.062888e+01)*S147+(-1.176723e+01)*S148+0.000000e+00*S149'
.param V4_part16='V4_part15+0.000000e+00*S150+(-5.816619e+00)*S151+(-6.474372e+00)*S152+0.000000e+00*S153+0.000000e+00*S154+(-9.295461e+00)*S155+(-6.541446e+00)*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V4_part17='V4_part16+0.000000e+00*S160+0.000000e+00*S161+(-8.180186e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-9.152750e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V4_part18='V4_part17+(-1.032053e+01)*S170+0.000000e+00*S171+0.000000e+00*S172+(-1.008608e+01)*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V4_part19='V4_part18+0.000000e+00*S180+0.000000e+00*S181+(-9.177446e+00)*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V4_part20='V4_part19+(-6.382319e+00)*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-9.450774e+00)*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V4_part21='V4_part20+(-1.124062e+01)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V4_part22='V4_part21+0.000000e+00*S210+(-6.554163e+00)*S211+(-8.236370e+00)*S212+(-2.834907e+00)*S213+0.000000e+00*S214+(-1.059220e+01)*S215+0.000000e+00*S216+(-5.950605e+00)*S217+0.000000e+00*S218+(-5.833425e+00)*S219'
.param V4_part23='V4_part22+0.000000e+00*S220+(-5.752611e+00)*S221+0.000000e+00*S222+(-4.775837e+00)*S223+(-5.808714e+00)*S224+(-1.868137e+00)*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V4_part24='V4_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V4_part25='V4_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+(-5.094065e+00)*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V4_part26='V4_part25+0.000000e+00*S250+(-9.274552e+00)*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+(-6.095197e+00)*S255+0.000000e+00*S256+(-1.239408e+01)*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V4_part27='V4_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V4_part28='V4_part27+0.000000e+00*S270+0.000000e+00*S271+(-8.742988e+00)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V4_part29='V4_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-1.713349e+01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V4_part30='V4_part29+(-1.457877e+01)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+(-1.279180e+01)*S296+0.000000e+00*S297+0.000000e+00*S298+(-1.033482e+01)*S299'
.param V4_part31='V4_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-1.022218e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+(-1.203360e+01)*S308+0.000000e+00*S309'
.param V4='V4_part31+0.000000e+00*S310+(-1.215702e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V5_part1='7.062732e-01*S0+4.341108e+00*S1+2.778481e+00*S2+(-2.059452e-02)*S3+7.257870e+00*S4+(-1.734334e-02)*S5+(-3.213715e-02)*S6+(-2.627717e-02)*S7+5.675578e-01*S8+4.789290e+01*S9'
.param V5_part2='V5_part1+(-4.175174e-02)*S10+4.529292e-01*S11+5.063005e+01*S12+9.733914e-01*S13+2.306098e+00*S14+1.877268e+00*S15+1.125096e+00*S16+1.153703e+00*S17+6.925435e-01*S18+5.435733e+00*S19'
.param V5_part3='V5_part2+1.163770e+00*S20+7.618266e+00*S21+(-3.042713e-02)*S22+1.573779e+00*S23+8.080485e+00*S24+(-4.540321e-02)*S25+3.885215e+00*S26+1.553267e+01*S27+(-5.887223e-02)*S28+(-4.501368e-02)*S29'
.param V5_part4='V5_part3+2.619247e+00*S30+(-2.590724e-02)*S31+1.037140e+00*S32+3.498631e+00*S33+3.760453e+00*S34+1.478319e+00*S35+6.250240e+00*S36+(-9.539491e-02)*S37+3.064967e+00*S38+1.048979e+01*S39'
.param V5_part5='V5_part4+(-1.015559e-01)*S40+(-1.990442e-02)*S41+1.110481e+01*S42+3.136484e+01*S43+(-3.440973e-02)*S44+4.819218e-02*S45+(-5.107956e-02)*S46+1.295252e+00*S47+3.645298e+00*S48+3.029870e+00*S49'
.param V5_part6='V5_part5+1.232954e+00*S50+1.467379e-03*S51+6.347137e+00*S52+2.580951e+00*S53+1.069511e+01*S54+1.180160e+01*S55+4.128844e+00*S56+1.580512e+01*S57+6.771850e+00*S58+3.413089e+00*S59'
.param V5_part7='V5_part6+3.222189e+00*S60+(-3.945252e-02)*S61+7.086488e-02*S62+5.547977e+00*S63+(-7.860120e-02)*S64+3.877053e-02*S65+1.234909e+01*S66+(-1.186687e-01)*S67+(-5.712906e-03)*S68+(-1.684999e-01)*S69'
.param V5_part8='V5_part7+(-1.632082e-01)*S70+(-2.678485e-02)*S71+(-1.460351e-01)*S72+1.393003e+00*S73+2.007929e+00*S74+(-4.011877e-03)*S75+1.740382e+00*S76+1.831883e-02*S77+(-1.955318e+00)*S78+4.833614e+00*S79'
.param V5_part9='V5_part8+1.521831e+00*S80+2.190337e-01*S81+2.818939e+00*S82+2.391489e+00*S83+5.984940e+00*S84+(-5.089152e-02)*S85+5.136078e+00*S86+7.678366e+00*S87+9.867043e+00*S88+(-3.581825e-02)*S89'
.param V5_part10='V5_part9+2.773184e+00*S90+(-9.915206e-03)*S91+1.875252e+00*S92+5.811997e+00*S93+(-9.458445e-02)*S94+2.378430e+00*S95+(-1.831836e-02)*S96+4.511869e-01*S97+4.986971e-01*S98+1.659096e+01*S99'
.param V5_part11='V5_part10+6.818872e+00*S100+4.201109e+00*S101+1.658434e+01*S102+7.430245e+00*S103+6.924732e+00*S104+2.056170e+00*S105+(-1.946592e-02)*S106+5.539371e-02*S107+5.843292e+00*S108+(-1.156668e-01)*S109'
.param V5_part12='V5_part11+7.328483e-01*S110+8.668454e+00*S111+3.348241e+00*S112+8.996313e-01*S113+3.372303e-01*S114+5.633542e+00*S115+1.706450e+00*S116+1.536956e+01*S117+4.584586e+00*S118+(-2.984657e-02)*S119'
.param V5_part13='V5_part12+3.759012e+00*S120+2.741009e+00*S121+6.408967e-01*S122+6.224860e+00*S123+4.033021e+00*S124+5.757225e-01*S125+8.953674e+00*S126+3.212688e-01*S127+6.005591e-01*S128+1.112842e+01*S129'
.param V5_part14='V5_part13+1.531460e-01*S130+6.922054e-01*S131+(-3.173640e-01)*S132+6.484188e+00*S133+9.250577e-01*S134+2.758500e+00*S135+(-2.646645e-02)*S136+3.556038e-01*S137+5.012734e+00*S138+3.732753e+00*S139'
.param V5_part15='V5_part14+2.558300e-02*S140+8.088070e+00*S141+5.697091e-01*S142+5.081301e+01*S143+1.117162e+01*S144+6.226558e+00*S145+2.990971e+00*S146+(-1.764301e-01)*S147+(-2.254246e-01)*S148+(-7.222578e-02)*S149'
.param V5_part16='V5_part15+2.524560e+00*S150+2.052265e-01*S151+3.683543e-01*S152+4.797213e+00*S153+(-2.883317e-02)*S154+1.203452e-01*S155+(-1.921657e-01)*S156+(-1.334159e-01)*S157+2.079990e-01*S158+8.462516e+00*S159'
.param V5_part17='V5_part16+1.489144e+00*S160+1.087874e+00*S161+(-4.342021e-01)*S162+(-1.287661e-01)*S163+6.909943e-01*S164+1.129300e-01*S165+4.104558e-02*S166+4.314886e-02*S167+(-1.016063e-01)*S168+(-8.753270e+00)*S169'
.param V5_part18='V5_part17+1.810858e+01*S170+7.073992e+00*S171+1.327936e+00*S172+3.129748e+00*S173+9.735166e+00*S174+1.328490e+00*S175+(-2.398847e+01)*S176+(-4.982312e-01)*S177+1.605305e+00*S178+(-1.212589e-01)*S179'
.param V5_part19='V5_part18+2.483231e+00*S180+5.467517e-02*S181+1.927841e-01*S182+4.635970e-02*S183+(-3.933472e-02)*S184+6.650976e+00*S185+8.762999e+00*S186+(-1.606681e-01)*S187+1.423454e-01*S188+1.166062e+01*S189'
.param V5_part20='V5_part19+2.203145e+01*S190+9.048764e-02*S191+8.341868e+00*S192+(-2.256029e-01)*S193+(-3.043816e-01)*S194+2.217559e+00*S195+3.209065e+00*S196+2.802901e-01*S197+1.068914e-02*S198+1.917629e+00*S199'
.param V5_part21='V5_part20+1.884068e-01*S200+8.334350e+00*S201+5.364678e-02*S202+1.216254e-01*S203+9.973548e+00*S204+(-1.358893e-01)*S205+2.211892e-02*S206+(-3.584269e-01)*S207+2.629627e+01*S208+1.920234e-01*S209'
.param V5_part22='V5_part21+1.797937e-01*S210+(-1.823981e+00)*S211+2.510366e+01*S212+2.274511e+00*S213+(-9.037614e+00)*S214+2.140792e+01*S215+7.426938e+00*S216+5.240977e+00*S217+2.948560e+01*S218+7.743023e+00*S219'
.param V5_part23='V5_part22+2.255650e+01*S220+4.036532e-01*S221+(-2.947112e-01)*S222+7.638546e-02*S223+4.138441e-01*S224+1.684861e-01*S225+9.265571e-02*S226+5.184360e-01*S227+(-2.648157e+00)*S228+2.077185e-01*S229'
.param V5_part24='V5_part23+4.745257e-01*S230+7.742881e+00*S231+(-9.716694e-02)*S232+3.136542e-02*S233+8.210707e+00*S234+5.731386e-01*S235+8.065622e-02*S236+(-8.637589e-01)*S237+(-1.887606e-01)*S238+9.629524e-02*S239'
.param V5_part25='V5_part24+2.188273e+00*S240+3.241321e-02*S241+3.793505e-01*S242+2.294205e+00*S243+5.110777e-01*S244+5.384666e-01*S245+(-3.113639e-01)*S246+7.219136e-01*S247+6.045871e-01*S248+3.756897e-01*S249'
.param V5_part26='V5_part25+2.475153e-01*S250+4.565191e-01*S251+(-8.404452e-01)*S252+(-7.622563e-02)*S253+3.881186e-01*S254+(-2.108524e+02)*S255+(-6.428461e+00)*S256+1.243421e-01*S257+1.729968e+00*S258+(-3.206950e-02)*S259'
.param V5_part27='V5_part26+6.332762e-02*S260+(-2.631846e-01)*S261+(-7.326773e-02)*S262+(-1.829951e-02)*S263+(-2.715048e-01)*S264+(-1.587713e-01)*S265+3.808534e-02*S266+1.238132e+01*S267+(-1.479853e-01)*S268+6.602153e-03*S269'
.param V5_part28='V5_part27+1.327608e+00*S270+1.428587e-01*S271+9.623681e-01*S272+1.861674e-01*S273+8.987023e-02*S274+4.840256e-01*S275+(-3.370655e-01)*S276+6.517717e-02*S277+3.575319e-01*S278+2.231519e-01*S279'
.param V5_part29='V5_part28+(-1.745439e-01)*S280+2.903660e-01*S281+(-1.302557e-01)*S282+3.169110e+01*S283+5.251282e-01*S284+5.215622e+00*S285+6.987071e-01*S286+4.165019e-01*S287+2.445481e+00*S288+(-2.768089e-01)*S289'
.param V5_part30='V5_part29+3.701623e-01*S290+(-4.525162e-01)*S291+1.277795e-01*S292+1.212513e+00*S293+4.560866e+00*S294+2.052664e+00*S295+3.911154e-01*S296+4.602359e+00*S297+5.845568e+00*S298+6.558848e-01*S299'
.param V5_part31='V5_part30+1.497276e+00*S300+1.270076e-01*S301+2.050248e-01*S302+2.486805e+00*S303+9.083290e-02*S304+5.282083e-01*S305+3.885263e+00*S306+1.091027e-01*S307+7.307988e-01*S308+4.835641e+00*S309'
.param V5='V5_part31+2.992180e+00*S310+6.193831e-01*S311+5.618523e+00*S312+3.513506e+00*S313+5.583103e-01*S314'
.param V6_part1='1.386027e+00*S0+2.558270e+00*S1+9.485447e-01*S2+9.318909e-02*S3+1.191023e+00*S4+4.701451e-02*S5+8.889796e-02*S6+6.174581e-02*S7+(-1.972179e-01)*S8+(-1.292533e+01)*S9'
.param V6_part2='V6_part1+7.123690e-02*S10+(-1.782741e-01)*S11+(-1.088172e+01)*S12+(-3.967063e-01)*S13+(-2.397041e+00)*S14+1.692057e+00*S15+1.600955e-01*S16+(-5.748278e-02)*S17+1.755210e+01*S18+(-1.365996e+00)*S19'
.param V6_part3='V6_part2+(-5.948615e-01)*S20+(-2.014665e+00)*S21+8.584872e-02*S22+(-6.891488e-01)*S23+(-2.674848e+00)*S24+8.985160e-02*S25+(-1.919789e+00)*S26+(-3.056745e+00)*S27+9.256077e-02*S28+6.829230e-02*S29'
.param V6_part4='V6_part3+(-1.042574e+00)*S30+6.233071e-02*S31+(-1.525070e+00)*S32+(-3.617445e+00)*S33+(-4.595878e+00)*S34+(-1.817879e+00)*S35+(-5.636129e+00)*S36+1.529161e-01*S37+(-2.346216e+00)*S38+(-8.293768e+00)*S39'
.param V6_part5='V6_part4+1.335739e-01*S40+1.187806e-01*S41+(-7.515150e+00)*S42+(-2.054194e+01)*S43+1.129658e-01*S44+4.719747e-01*S45+2.640031e-01*S46+(-1.390873e+00)*S47+(-4.428971e+00)*S48+(-3.352995e+00)*S49'
.param V6_part6='V6_part5+(-1.527476e+00)*S50+3.126130e-01*S51+(-3.991781e+00)*S52+(-3.015376e+00)*S53+(-8.388324e+00)*S54+(-1.159345e+01)*S55+(-4.516388e+00)*S56+(-1.111293e+01)*S57+(-6.003702e+00)*S58+(-2.715699e+00)*S59'
.param V6_part7='V6_part6+(-4.888564e+00)*S60+2.698825e-01*S61+1.837995e-01*S62+(-6.651309e+00)*S63+2.402764e-01*S64+1.809091e-01*S65+(-1.017196e+01)*S66+2.370081e-01*S67+1.740190e-01*S68+5.318751e-01*S69'
.param V6_part8='V6_part7+2.194060e-01*S70+1.431213e-01*S71+3.844684e-01*S72+(-1.045980e+00)*S73+3.180121e+00*S74+2.157763e-01*S75+1.795126e+01*S76+8.701981e-02*S77+2.530543e+01*S78+9.287035e+00*S79'
.param V6_part9='V6_part8+2.848395e+01*S80+2.986779e+01*S81+(-2.319506e+00)*S82+(-1.924751e+00)*S83+(-3.974705e+00)*S84+1.224562e-01*S85+(-3.782533e+00)*S86+(-4.371658e+00)*S87+(-6.024985e+00)*S88+8.410745e-02*S89'
.param V6_part10='V6_part9+(-4.107839e+00)*S90+4.421167e-01*S91+(-3.100442e+00)*S92+(-7.160340e+00)*S93+2.894868e-01*S94+(-3.552545e+00)*S95+4.575290e-01*S96+(-7.233982e-02)*S97+(-4.828081e-02)*S98+(-1.669376e+01)*S99'
.param V6_part11='V6_part10+(-6.148153e+00)*S100+(-3.086941e+00)*S101+(-1.299748e+01)*S102+(-5.674849e+00)*S103+(-4.288099e+00)*S104+(-3.042793e+00)*S105+4.967119e-01*S106+3.168570e-01*S107+(-7.858609e+00)*S108+2.945527e-01*S109'
.param V6_part12='V6_part11+(-2.411077e-01)*S110+(-1.086153e+01)*S111+(-3.312587e+00)*S112+(-1.917724e-01)*S113+4.098529e-01*S114+(-4.516313e+00)*S115+(-7.233787e-01)*S116+(-1.122861e+01)*S117+(-3.296409e+00)*S118+1.490050e-01*S119'
.param V6_part13='V6_part12+(-6.158029e+00)*S120+(-3.760747e+00)*S121+(-1.763968e-01)*S122+(-8.418700e+00)*S123+(-4.706895e+00)*S124+1.049066e-01*S125+(-1.026149e+01)*S126+(-9.940529e-02)*S127+1.456121e-01*S128+(-9.582674e+00)*S129'
.param V6_part14='V6_part13+(-4.350563e-02)*S130+8.860596e-02*S131+5.853281e-01*S132+(-4.329157e+00)*S133+(-9.172754e-02)*S134+(-4.732478e+00)*S135+4.279048e-01*S136+(-2.074773e-03)*S137+(-6.291660e+00)*S138+(-5.158330e+00)*S139'
.param V6_part15='V6_part14+2.884887e-01*S140+(-8.097861e+00)*S141+(-2.872389e-01)*S142+(-5.212752e+01)*S143+(-1.013206e+01)*S144+(-6.024605e+00)*S145+(-2.536799e+00)*S146+4.027275e-01*S147+2.054737e-01*S148+1.766216e-01*S149'
.param V6_part16='V6_part15+(-3.375708e+00)*S150+(-5.823791e-02)*S151+6.119710e-01*S152+(-6.264834e+00)*S153+1.172048e-01*S154+2.142674e-01*S155+8.099991e-01*S156+5.173915e-01*S157+5.848745e-01*S158+(-6.472688e+00)*S159'
.param V6_part17='V6_part16+(-5.935424e+00)*S160+(-5.379241e-02)*S161+7.576759e-01*S162+3.797102e-01*S163+3.054404e-01*S164+7.993576e-01*S165+1.955522e-01*S166+1.660783e-01*S167+9.015599e-01*S168+1.325389e+01*S169'
.param V6_part18='V6_part17+(-6.674599e+00)*S170+(-7.024051e+00)*S171+(-6.509075e+00)*S172+(-1.586263e+00)*S173+(-7.093265e+00)*S174+(-7.847409e+00)*S175+(-1.848495e+01)*S176+8.822791e-01*S177+(-8.283125e+00)*S178+7.575712e-01*S179'
.param V6_part19='V6_part18+(-1.799503e+00)*S180+1.341914e-01*S181+2.815415e-01*S182+4.697142e-01*S183+1.813725e-01*S184+(-6.015158e+00)*S185+(-8.401997e+00)*S186+2.274848e-01*S187+1.614563e-01*S188+(-7.360928e+00)*S189'
.param V6_part20='V6_part19+(-1.251039e+01)*S190+1.827267e-01*S191+(-4.785584e+00)*S192+5.545981e-01*S193+1.215305e-01*S194+(-2.663649e+00)*S195+(-2.013543e+00)*S196+4.934178e-01*S197+5.920118e-01*S198+(-1.708549e+00)*S199'
.param V6_part21='V6_part20+4.193647e-01*S200+(-9.088362e+00)*S201+2.682228e-02*S202+4.355067e-01*S203+(-8.115238e+00)*S204+1.116910e-01*S205+4.545271e-01*S206+6.627232e-01*S207+(-1.406201e+01)*S208+3.544207e-02*S209'
.param V6_part22='V6_part21+5.804957e-01*S210+2.833512e+00*S211+(-2.218894e+00)*S212+(-2.367959e+00)*S213+2.424568e+01*S214+(-5.155888e+00)*S215+(-6.075799e+00)*S216+(-5.617451e+00)*S217+(-9.572055e-01)*S218+(-5.667720e+00)*S219'
.param V6_part23='V6_part22+(-1.059298e+01)*S220+8.124130e-01*S221+1.523492e+00*S222+1.147280e+00*S223+8.440137e-01*S224+6.159497e-01*S225+2.665490e-01*S226+7.574435e-01*S227+5.978054e+00*S228+7.404429e-01*S229'
.param V6_part24='V6_part23+8.808389e-01*S230+(-7.204773e+00)*S231+3.614219e-01*S232+5.089315e-01*S233+(-4.932625e+00)*S234+(-7.073621e+00)*S235+3.277142e-01*S236+1.225905e+00*S237+7.514996e-01*S238+3.119402e-01*S239'
.param V6_part25='V6_part24+6.254886e-01*S240+4.476665e-01*S241+2.085608e-01*S242+(-2.927344e+00)*S243+7.111711e-01*S244+8.520241e-01*S245+1.346831e+00*S246+(-9.154216e+00)*S247+8.774174e-01*S248+1.501289e-01*S249'
.param V6_part26='V6_part25+(-7.807751e+00)*S250+9.105091e-01*S251+1.399089e+00*S252+2.946240e-01*S253+7.018544e-01*S254+5.569856e+02*S255+1.232782e+01*S256+2.021283e-01*S257+3.110532e-01*S258+1.225319e-01*S259'
.param V6_part27='V6_part26+1.936311e-01*S260+1.244812e+00*S261+5.911307e-01*S262+1.011806e-01*S263+8.029475e-01*S264+5.605714e-01*S265+2.660254e-01*S266+(-6.443837e+00)*S267+2.565440e-01*S268+2.634528e-01*S269'
.param V6_part28='V6_part27+6.112346e-02*S270+1.804633e-01*S271+5.855571e-01*S272+9.199528e-01*S273+3.259588e-01*S274+5.239804e-02*S275+1.851997e+00*S276+3.234751e-01*S277+3.761915e-01*S278+2.210872e+00*S279'
.param V6_part29='V6_part28+(-1.742714e+00)*S280+4.343228e-01*S281+2.069098e+00*S282+(-1.333896e+01)*S283+6.594313e-01*S284+1.246410e+01*S285+6.135014e-01*S286+1.150481e-01*S287+(-2.896713e+00)*S288+(-1.177850e+00)*S289'
.param V6_part30='V6_part29+2.935005e-01*S290+2.091069e+00*S291+3.701576e-01*S292+1.042954e+00*S293+(-4.394890e+00)*S294+(-2.701637e+00)*S295+3.899111e-01*S296+1.828682e+00*S297+(-1.412365e+01)*S298+8.449336e-01*S299'
.param V6_part31='V6_part30+7.483986e-02*S300+9.410877e-02*S301+3.196875e-01*S302+(-2.561882e+00)*S303+(-8.500289e-01)*S304+7.846090e-01*S305+(-4.503671e+00)*S306+3.246631e-01*S307+1.046920e+00*S308+(-4.112274e+00)*S309'
.param V6='V6_part31+(-1.044859e+01)*S310+9.466697e-01*S311+(-4.163766e+00)*S312+(-1.143127e+01)*S313+7.877033e-01*S314'
.param V7_part1='1.840137e-01*S0+9.811830e-01*S1+4.069760e-01*S2+1.786644e-02*S3+1.835847e+00*S4+2.320756e-02*S5+2.211937e-02*S6+2.480626e-02*S7+4.187590e-01*S8+6.484989e+00*S9'
.param V7_part2='V7_part1+3.205375e-02*S10+2.892171e-01*S11+8.555144e+00*S12+2.811751e-01*S13+5.516889e-01*S14+7.363470e-02*S15+1.441826e-01*S16+1.982285e-01*S17+4.940835e-01*S18+5.848544e-01*S19'
.param V7_part3='V7_part2+1.713202e-01*S20+3.957861e-01*S21+3.282577e-02*S22+7.991972e-02*S23+4.805537e-01*S24+4.020076e-02*S25+6.615858e-01*S26+4.353252e-01*S27+4.650042e-02*S28+5.297911e-02*S29'
.param V7_part4='V7_part3+9.912829e-02*S30+7.398407e-02*S31+3.879711e-01*S32+3.096479e-01*S33+9.571847e-01*S34+4.676825e-01*S35+5.401203e-01*S36+1.005859e-01*S37+7.067567e-01*S38+1.038176e+00*S39'
.param V7_part5='V7_part4+1.099919e-01*S40+6.725684e-02*S41+1.083695e+00*S42+4.590811e+00*S43+8.209500e-02*S44+2.792514e-02*S45+8.238297e-02*S46+3.013173e-01*S47+4.122779e-01*S48+9.656440e-01*S49'
.param V7_part6='V7_part5+4.594719e-01*S50+4.983444e-02*S51+1.039700e+00*S52+1.336399e+00*S53+1.180815e+00*S54+2.946709e+00*S55+2.363246e+00*S56+1.888691e+00*S57+2.181158e+00*S58+1.261485e+00*S59'
.param V7_part7='V7_part6+2.882683e-01*S60+8.745241e-02*S61+3.276815e-02*S62+4.686281e-01*S63+1.069065e-01*S64+4.873269e-02*S65+1.159289e+00*S66+1.255180e-01*S67+7.779889e-02*S68+8.057638e-02*S69'
.param V7_part8='V7_part7+1.532403e-01*S70+9.828213e-02*S71+9.247860e-02*S72+6.181192e-01*S73+(-7.097578e-01)*S74+1.881451e-02*S75+3.709176e-01*S76+1.945522e-02*S77+1.447658e+00*S78+1.771006e+00*S79'
.param V7_part9='V7_part8+1.625553e+00*S80+2.494754e+00*S81+3.982790e-01*S82+4.729839e-01*S83+4.453903e-01*S84+5.057296e-02*S85+8.363190e-01*S86+5.484065e-01*S87+1.094175e+00*S88+6.121580e-02*S89'
.param V7_part10='V7_part9+3.417102e-01*S90+9.188227e-02*S91+6.337031e-01*S92+8.441569e-01*S93+1.392627e-01*S94+1.309414e+00*S95+7.214497e-02*S96+4.109258e-01*S97+1.502068e-01*S98+3.019175e+00*S99'
.param V7_part11='V7_part10+1.834716e+00*S100+7.965297e-01*S101+2.835656e+00*S102+2.052636e+00*S103+8.629216e-01*S104+4.463219e-01*S105+1.051582e-01*S106+1.508964e-01*S107+1.154706e+00*S108+1.588390e-01*S109'
.param V7_part12='V7_part11+6.747727e-02*S110+2.036059e+00*S111+1.017233e+00*S112+5.347032e-02*S113+5.193681e-01*S114+1.317059e+00*S115+2.137569e-01*S116+2.364229e+00*S117+1.789525e+00*S118+1.659749e-01*S119'
.param V7_part13='V7_part12+4.727633e-01*S120+4.581909e-01*S121+3.014755e-02*S122+1.035059e+00*S123+8.099452e-01*S124+8.723673e-03*S125+1.711443e+00*S126+4.372797e-01*S127+4.532723e-02*S128+1.658647e+00*S129'
.param V7_part14='V7_part13+5.181134e-01*S130+1.066150e-01*S131+1.521893e-01*S132+1.591872e+00*S133+2.615322e-01*S134+2.369186e-01*S135+8.112977e-02*S136+4.520148e-02*S137+4.039520e-01*S138+8.792102e-01*S139'
.param V7_part15='V7_part14+8.052212e-02*S140+8.348073e-01*S141+4.264990e-01*S142+1.961938e+01*S143+1.453275e+00*S144+1.458855e+00*S145+8.746418e-01*S146+1.071300e-01*S147+1.954660e-01*S148+1.340253e-01*S149'
.param V7_part16='V7_part15+4.433668e-01*S150+2.095149e-01*S151+(-1.026277e-01)*S152+1.164607e+00*S153+1.756230e-01*S154+8.078002e-02*S155+1.214892e-01*S156+1.591077e-01*S157+(-4.910803e-02)*S158+1.523688e+00*S159'
.param V7_part17='V7_part16+4.296558e+00*S160+(-2.211778e-02)*S161+1.838896e-01*S162+1.818709e-01*S163+(-4.649384e-02)*S164+7.204276e-02*S165+1.423577e-01*S166+4.495634e-01*S167+1.037826e-01*S168+3.332636e+01*S169'
.param V7_part18='V7_part17+5.105860e+00*S170+1.290863e+00*S171+3.704635e+00*S172+9.614543e+00*S173+1.054076e+00*S174+5.977342e+00*S175+5.848844e+01*S176+1.965925e-01*S177+6.731293e+00*S178+(-1.007473e-02)*S179'
.param V7_part19='V7_part18+4.172623e-01*S180+1.518412e-01*S181+5.608858e-02*S182+1.110977e-01*S183+1.973101e-01*S184+(-1.259337e+00)*S185+1.300949e+00*S186+2.491722e-01*S187+1.067940e-01*S188+1.374703e+00*S189'
.param V7_part20='V7_part19+(-1.209211e+00)*S190+1.492053e-01*S191+1.582320e+00*S192+2.052333e-01*S193+1.139600e+00*S194+3.296781e-01*S195+2.017307e+00*S196+(-6.402964e-02)*S197+8.894764e-02*S198+7.385871e-01*S199'
.param V7_part21='V7_part20+(-1.403324e-02)*S200+1.344980e+00*S201+3.896756e-01*S202+1.142939e-02*S203+1.728504e+00*S204+2.445419e-01*S205+5.966532e-02*S206+1.673246e-01*S207+(-2.029475e+00)*S208+4.323011e-01*S209'
.param V7_part22='V7_part21+8.396049e-02*S210+2.885885e+00*S211+3.304916e+00*S212+8.010406e-01*S213+3.232203e+01*S214+6.548215e+00*S215+1.518120e+00*S216+2.445901e+00*S217+6.911645e+00*S218+1.647031e+00*S219'
.param V7_part23='V7_part22+(-2.387043e+00)*S220+(-1.419901e-01)*S221+1.971962e-01*S222+2.555443e-01*S223+(-1.396342e-01)*S224+9.156806e-02*S225+1.649347e-01*S226+(-1.575542e-01)*S227+9.484406e-01*S228+9.751470e-02*S229'
.param V7_part24='V7_part23+(-2.148725e-01)*S230+1.607820e+00*S231+2.518888e-01*S232+4.150046e-01*S233+1.357087e+00*S234+6.292813e+00*S235+2.024422e-01*S236+3.777490e-01*S237+1.924884e-01*S238+1.893338e-01*S239'
.param V7_part25='V7_part24+1.248700e+00*S240+1.795218e-01*S241+(-2.763879e-03)*S242+1.136753e+00*S243+3.453587e-02*S244+(-2.129272e-01)*S245+1.965147e-01*S246+6.348330e+00*S247+(-1.934147e-01)*S248+1.237417e+00*S249'
.param V7_part26='V7_part25+7.561939e+00*S250+(-1.508399e-01)*S251+2.852230e-01*S252+3.215282e-01*S253+(-8.316902e-02)*S254+1.134656e+02*S255+1.649978e+01*S256+1.923553e-01*S257+3.427742e-01*S258+2.195067e-01*S259'
.param V7_part27='V7_part26+2.374632e-01*S260+1.431060e-01*S261+1.687170e-01*S262+5.814000e-01*S263+1.750802e-01*S264+2.118896e-01*S265+2.021501e-01*S266+2.088265e+00*S267+3.054115e-01*S268+2.246531e-01*S269'
.param V7_part28='V7_part27+6.195267e-01*S270+2.316811e-01*S271+(-2.822220e-01)*S272+1.421312e-01*S273+2.333462e-01*S274+6.251161e-01*S275+1.853453e-01*S276+2.828255e-01*S277+4.577290e-01*S278+2.219464e-01*S279'
.param V7_part29='V7_part28+2.964036e+00*S280+4.101321e-01*S281+3.340490e-01*S282+(-2.158022e+00)*S283+(-2.475514e-02)*S284+2.476568e+00*S285+7.170472e-03*S286+4.827104e-01*S287+1.162580e+00*S288+1.767482e+00*S289'
.param V7_part30='V7_part29+4.921035e-01*S290+2.062410e-01*S291+2.718241e-01*S292+(-3.015134e-01)*S293+1.641302e+00*S294+2.107925e+00*S295+5.132208e-01*S296+2.276827e+00*S297+9.521309e+00*S298+1.822624e-01*S299'
.param V7_part31='V7_part30+4.957841e-01*S300+2.293877e-01*S301+2.280112e-01*S302+1.238922e+00*S303+1.088382e+00*S304+(-1.974316e-01)*S305+1.511479e+00*S306+2.726796e-01*S307+(-2.606425e-01)*S308+1.392264e+00*S309'
.param V7='V7_part31+7.366306e+00*S310+(-1.740229e-01)*S311+1.601617e+00*S312+9.230192e+00*S313+(-6.824550e-02)*S314'
.param V8_part1='6.179301e-01*S0+1.567896e+00*S1+5.707648e-01*S2+2.102052e-02*S3+1.603528e+00*S4+1.165909e-02*S5+1.992223e-02*S6+1.374755e-02*S7+1.031175e-01*S8+1.816443e+01*S9'
.param V8_part2='V8_part1+1.309678e-02*S10+1.233379e-01*S11+2.020149e+01*S12+2.290843e-01*S13+(-5.967458e+00)*S14+1.326953e+00*S15+5.513101e-01*S16+3.646323e-01*S17+(-1.589177e+01)*S18+1.037092e+00*S19'
.param V8_part3='V8_part2+2.867675e-01*S20+1.524372e+00*S21+1.397652e-02*S22+4.254297e-01*S23+1.291337e+00*S24+1.348005e-02*S25+2.077776e-01*S26+4.008575e+00*S27+1.358402e-02*S28+9.574193e-03*S29'
.param V8_part4='V8_part3+1.373851e+00*S30+(-1.534521e-03)*S31+2.242357e-01*S32+8.690647e-01*S33+4.354875e-01*S34+2.279990e-01*S35+1.125097e+00*S36+6.495924e-04*S37+5.327270e-01*S38+1.301170e+00*S39'
.param V8_part5='V8_part4+1.119837e-03*S40+(-4.638698e-03)*S41+7.378167e-01*S42+3.888404e+00*S43+(-6.721747e-03)*S44+1.575573e-03*S45+3.593403e-03*S46+3.546995e-01*S47+6.951293e-01*S48+7.678202e-01*S49'
.param V8_part6='V8_part5+9.754808e-02*S50+1.376439e-03*S51+1.147465e+00*S52+2.668133e-01*S53+1.710025e+00*S54+1.461735e-01*S55+5.070504e-02*S56+1.986961e+00*S57+2.095559e-01*S58+1.750133e-01*S59'
.param V8_part7='V8_part6+8.350537e-01*S60+2.205387e-03*S61+(-3.198397e-05)*S62+1.080479e+00*S63+3.992492e-03*S64+(-4.451915e-04)*S65+2.414782e+00*S66+(-4.584805e-03)*S67+(-7.899987e-03)*S68+3.191493e-04*S69'
.param V8_part8='V8_part7+7.336753e-05*S70+(-1.643278e-02)*S71+(-6.345488e-03)*S72+2.912367e-01*S73+2.143652e+00*S74+2.167453e-02*S75+(-1.785074e+01)*S76+9.586915e-03*S77+(-2.550571e+01)*S78+(-2.613144e+01)*S79'
.param V8_part9='V8_part8+(-2.291171e+01)*S80+(-3.219939e+01)*S81+6.422855e-01*S82+5.246066e-01*S83+1.261613e+00*S84+1.271223e-02*S85+4.642572e-01*S86+1.280578e+00*S87+9.024490e-01*S88+9.927196e-03*S89'
.param V8_part10='V8_part9+6.690737e-01*S90+(-1.209225e-02)*S91+1.556110e-01*S92+1.583641e+00*S93+(-2.009550e-02)*S94+3.268418e-01*S95+(-1.121303e-02)*S96+2.438890e-01*S97+9.408483e-02*S98+2.307754e+00*S99'
.param V8_part11='V8_part10+9.988927e-01*S100+3.636448e-01*S101+1.985804e+00*S102+1.163835e+00*S103+4.366271e-01*S104+6.597368e-01*S105+(-2.835025e-02)*S106+(-3.619280e-02)*S107+1.627539e+00*S108+(-2.508297e-02)*S109'
.param V8_part12='V8_part11+6.785898e-02*S110+1.860680e+00*S111+5.071923e-01*S112+1.301160e-01*S113+3.799618e-01*S114+6.329364e-01*S115+2.924284e-01*S116+3.275109e+00*S117+1.282349e+00*S118+(-6.334551e-02)*S119'
.param V8_part13='V8_part12+4.888124e-01*S120+1.014366e-02*S121+5.712021e-02*S122+1.105441e+00*S123+3.248065e-02*S124+6.824406e-02*S125+1.231954e+00*S126+2.379475e-01*S127+9.179023e-02*S128+1.385016e+00*S129'
.param V8_part14='V8_part13+2.281443e-01*S130+1.385656e-01*S131+(-2.907663e-02)*S132+1.051570e+00*S133+1.933657e-01*S134+8.013274e-01*S135+(-3.904780e-03)*S136+1.008608e-01*S137+9.098487e-01*S138+1.042995e+00*S139'
.param V8_part15='V8_part14+(-3.320895e-02)*S140+1.656589e+00*S141+3.680878e-01*S142+(-1.204350e+00)*S143+1.615712e+00*S144+3.088946e-01*S145+3.390532e-01*S146+(-6.916684e-03)*S147+(-1.773946e-02)*S148+(-2.485912e-02)*S149'
.param V8_part16='V8_part15+3.825430e-01*S150+1.662991e-02*S151+1.144246e-02*S152+9.578720e-01*S153+2.063056e-05*S154+6.846390e-03*S155+(-3.293450e-02)*S156+1.294395e-02*S157+6.028190e-03*S158+1.851600e+00*S159'
.param V8_part17='V8_part16+3.977815e-02*S160+1.175096e-01*S161+(-2.777695e-02)*S162+1.858259e-02*S163+1.367984e-01*S164+2.423602e-03*S165+(-6.788087e-04)*S166+(-5.604274e-02)*S167+(-3.001216e-02)*S168+2.837435e+00*S169'
.param V8_part18='V8_part17+(-9.645892e-01)*S170+1.575426e+00*S171+4.467119e-02*S172+(-2.693622e-01)*S173+2.036745e+00*S174+(-1.750331e-01)*S175+9.460604e-01*S176+(-3.346675e-02)*S177+(-3.310751e-01)*S178+3.659602e-02*S179'
.param V8_part19='V8_part18+1.556548e-01*S180+3.166081e-03*S181+9.590314e-03*S182+1.489052e-02*S183+(-4.946093e-04)*S184+(-4.338358e-01)*S185+2.020436e+00*S186+(-6.403213e-03)*S187+3.242958e-03*S188+3.312860e+00*S189'
.param V8_part20='V8_part19+(-3.292741e-01)*S190+4.989155e-03*S191+2.432280e+00*S192+3.548543e-02*S193+(-3.418814e-02)*S194+5.643437e-01*S195+(-1.448811e-01)*S196+1.262648e-02*S197+2.335778e-02*S198+(-6.169469e-02)*S199'
.param V8_part21='V8_part20+1.394365e-02*S200+1.466059e+00*S201+1.318584e-01*S202+2.220881e-02*S203+1.926291e+00*S204+1.748947e-02*S205+1.135625e-02*S206+(-3.207627e-02)*S207+(-5.409434e-01)*S208+(-2.203195e-02)*S209'
.param V8_part22='V8_part21+1.033080e-02*S210+1.884960e-02*S211+(-9.673368e-01)*S212+5.217149e-01*S213+1.946339e+00*S214+(-1.131694e+00)*S215+2.351391e+00*S216+1.405020e+00*S217+(-1.830257e+00)*S218+2.316499e+00*S219'
.param V8_part23='V8_part22+(-5.735624e-01)*S220+1.882827e-02*S221+9.010892e-02*S222+8.827851e-02*S223+3.560269e-02*S224+9.355115e-03*S225+2.439736e-03*S226+3.902140e-03*S227+1.409881e-01*S228+1.723141e-02*S229'
.param V8_part24='V8_part23+3.723915e-03*S230+2.070338e+00*S231+(-1.061747e-02)*S232+6.015754e-03*S233+2.576795e+00*S234+4.835309e-02*S235+3.146827e-03*S236+(-5.257691e-02)*S237+8.462973e-03*S238+2.565214e-03*S239'
.param V8_part25='V8_part24+(-1.390523e-01)*S240+7.957808e-03*S241+(-5.629681e-03)*S242+2.091114e-02*S243+2.628554e-03*S244+2.137837e-02*S245+3.010246e-02*S246+(-6.906392e-02)*S247+3.840295e-03*S248+6.272966e-01*S249'
.param V8_part26='V8_part25+(-1.423928e-01)*S250+5.890695e-03*S251+(-5.861793e-02)*S252+1.099787e-02*S253+4.065309e-04*S254+1.353761e+01*S255+6.507684e-01*S256+1.329125e-02*S257+4.231102e-01*S258+1.852188e-04*S259'
.param V8_part27='V8_part26+1.015304e-02*S260+5.305788e-02*S261+1.515085e-02*S262+(-4.822043e-03)*S263+2.388940e-02*S264+3.797917e-02*S265+1.140744e-02*S266+3.712144e+00*S267+1.543657e-02*S268+1.483028e-03*S269'
.param V8_part28='V8_part27+(-2.883094e-02)*S270+(-6.136159e-03)*S271+(-3.373041e-02)*S272+3.247031e-02*S273+3.776702e-03*S274+(-1.864589e-02)*S275+5.033822e-02*S276+7.783554e-03*S277+(-1.536517e-02)*S278+1.894611e-01*S279'
.param V8_part29='V8_part28+2.323339e-01*S280+(-7.887852e-04)*S281+2.194363e-01*S282+(-7.538029e-01)*S283+4.168396e-03*S284+(-3.777823e-01)*S285+(-8.961680e-05)*S286+(-8.778695e-03)*S287+(-3.011068e-01)*S288+8.748523e-02*S289'
.param V8_part30='V8_part29+1.356644e-02*S290+3.730807e-02*S291+9.765718e-03*S292+(-1.311170e-03)*S293+(-2.840426e-02)*S294+1.491378e-01*S295+4.133493e-02*S296+2.962936e-01*S297+(-6.077903e-01)*S298+(-6.917044e-02)*S299'
.param V8_part31='V8_part30+1.250155e-01*S300+1.620994e-02*S301+1.603177e-03*S302+8.355728e-02*S303+8.124265e-02*S304+1.082406e-02*S305+(-2.230941e-02)*S306+1.642051e-02*S307+2.038639e-02*S308+(-3.770372e-02)*S309'
.param V8='V8_part31+1.536003e-01*S310+1.851643e-02*S311+2.458934e-01*S312+1.424513e-01*S313+(-5.405107e-03)*S314'
.param V9_part1='(-2.641304e-03)*S0+4.293293e-02*S1+1.713900e-02*S2+(-4.748096e-06)*S3+3.125768e-02*S4+9.203231e-05*S5+(-4.908196e-06)*S6+1.793187e-05*S7+(-3.282211e-03)*S8+(-4.007806e-01)*S9'
.param V9_part2='V9_part1+5.013761e-05*S10+1.333649e-03*S11+(-5.636132e-01)*S12+(-4.666809e-03)*S13+(-1.748986e-02)*S14+4.976275e-03*S15+1.654056e-03*S16+(-8.439706e-03)*S17+1.814510e-02*S18+(-1.338642e-03)*S19'
.param V9_part3='V9_part2+(-2.330221e-03)*S20+(-7.608651e-03)*S21+2.356253e-04*S22+(-1.364540e-03)*S23+3.064993e-03*S24+2.504540e-04*S25+2.056542e-03*S26+2.468159e-02*S27+2.475447e-04*S28+1.718286e-04*S29'
.param V9_part4='V9_part3+(-1.500820e-02)*S30+2.185081e-03*S31+(-2.007616e-02)*S32+(-2.192147e-02)*S33+(-8.605052e-03)*S34+(-2.004609e-02)*S35+(-1.215605e-02)*S36+2.332384e-03*S37+(-1.724915e-02)*S38+1.587269e-02*S39'
.param V9_part5='V9_part4+2.155946e-03*S40+9.813530e-04*S41+4.457487e-02*S42+6.429240e-01*S43+9.384563e-04*S44+3.578729e-03*S45+3.102508e-03*S46+(-5.155823e-02)*S47+(-7.504633e-02)*S48+7.933934e-02*S49'
.param V9_part6='V9_part5+(-3.664706e-02)*S50+(-1.072838e-03)*S51+1.511646e-01*S52+(-2.315023e-02)*S53+2.559519e-01*S54+1.973724e-01*S55+6.692072e-02*S56+3.214539e-02*S57+2.069246e-01*S58+(-2.815316e-02)*S59'
.param V9_part7='V9_part6+(-6.530070e-02)*S60+2.153866e-03*S61+2.139982e-05*S62+(-5.289693e-02)*S63+2.399725e-04*S64+1.431921e-04*S65+2.943228e-01*S66+2.393659e-03*S67+2.487753e-03*S68+2.165145e-03*S69'
.param V9_part8='V9_part7+2.552054e-03*S70+(-5.137030e-04)*S71+(-8.779708e-03)*S72+(-1.831638e-02)*S73+1.270640e-01*S74+(-7.825295e-04)*S75+7.463136e-04*S76+(-3.048765e-04)*S77+3.084696e-04*S78+(-5.084078e-03)*S79'
.param V9_part9='V9_part8+1.287738e+00*S80+(-1.977528e-01)*S81+(-2.093097e-01)*S82+(-1.833470e-01)*S83+(-2.540582e-01)*S84+(-4.919601e-04)*S85+(-2.601635e-01)*S86+(-2.501168e-01)*S87+(-3.261382e-01)*S88+(-9.308477e-04)*S89'
.param V9_part10='V9_part9+(-1.858380e-01)*S90+8.933472e-03*S91+(-2.102960e-01)*S92+(-1.584643e-01)*S93+3.229794e-03*S94+(-1.899710e-01)*S95+(-3.953940e-03)*S96+(-1.096729e-02)*S97+(-2.910110e-02)*S98+2.695992e-01*S99'
.param V9_part11='V9_part10+2.082865e-01*S100+(-1.429949e-01)*S101+2.246075e-01*S102+2.688517e-01*S103+(-3.585748e-01)*S104+(-2.924035e-01)*S105+9.528945e-03*S106+2.374789e-02*S107+(-3.142129e-01)*S108+(-3.150175e-03)*S109'
.param V9_part12='V9_part11+(-4.523227e-02)*S110+(-1.160499e-01)*S111+(-4.332426e-02)*S112+(-5.254530e-02)*S113+(-9.671696e-02)*S114+(-1.657069e-01)*S115+(-7.517480e-02)*S116+1.024773e-01*S117+(-6.630574e-02)*S118+(-7.645390e-03)*S119'
.param V9_part13='V9_part12+(-3.311219e-01)*S120+(-2.405798e-01)*S121+(-6.021693e-02)*S122+(-3.186263e-01)*S123+(-1.498981e-01)*S124+(-4.002117e-02)*S125+(-4.365723e-01)*S126+(-2.839716e-02)*S127+(-5.242524e-02)*S128+(-2.215725e-01)*S129'
.param V9_part14='V9_part13+1.414615e-02*S130+(-5.573473e-02)*S131+7.456165e-04*S132+(-1.332292e-02)*S133+(-7.302718e-02)*S134+(-2.130335e-01)*S135+4.818765e-03*S136+(-3.915023e-02)*S137+(-2.141055e-01)*S138+(-1.545905e-01)*S139'
.param V9_part15='V9_part14+1.202179e-03*S140+(-2.198034e-01)*S141+(-4.297507e-02)*S142+(-3.089697e+00)*S143+(-1.852376e-01)*S144+(-1.351814e-01)*S145+(-1.221422e-01)*S146+(-1.271611e-03)*S147+(-3.265580e-03)*S148+(-8.842224e-03)*S149'
.param V9_part16='V9_part15+(-3.696392e-01)*S150+1.520018e-02*S151+2.723005e-02*S152+(-3.687072e-01)*S153+1.326514e-02*S154+6.133813e-03*S155+3.024452e-02*S156+(-3.650501e-03)*S157+1.436293e-02*S158+(-4.672283e-01)*S159'
.param V9_part17='V9_part16+3.730700e-01*S160+(-4.106502e-02)*S161+2.880808e-02*S162+(-1.489409e-02)*S163+(-4.606160e-02)*S164+1.388045e-02*S165+(-1.170675e-02)*S166+(-3.934619e-02)*S167+1.354699e-02*S168+3.552792e+00*S169'
.param V9_part18='V9_part17+(-1.309235e+00)*S170+(-4.999109e-01)*S171+2.900604e-01*S172+(-4.874754e-01)*S173+(-1.517100e-01)*S174+3.120785e-01*S175+(-3.093299e+00)*S176+3.058563e-02*S177+1.907874e-01*S178+5.983722e-03*S179'
.param V9_part19='V9_part18+(-3.786274e-01)*S180+1.606209e-02*S181+9.149959e-03*S182+1.596189e-02*S183+1.023728e-02*S184+(-4.604461e-01)*S185+(-4.511274e-01)*S186+2.719347e-03*S187+1.320948e-03*S188+(-4.264018e-01)*S189'
.param V9_part20='V9_part19+(-8.847299e-01)*S190+7.883852e-03*S191+(-4.211322e-01)*S192+1.772376e-02*S193+6.279023e-02*S194+(-3.078206e-01)*S195+(-1.953688e-01)*S196+9.440735e-03*S197+1.594483e-03*S198+(-7.663235e-02)*S199'
.param V9_part21='V9_part20+6.739372e-03*S200+(-2.772306e-01)*S201+(-5.399413e-03)*S202+6.836019e-04*S203+(-7.674573e-01)*S204+(-7.283087e-04)*S205+2.330262e-03*S206+2.828213e-03*S207+(-3.410843e-01)*S208+5.590201e-01*S209'
.param V9_part22='V9_part21+1.160668e-02*S210+(-8.445037e-01)*S211+(-1.313869e+00)*S212+(-1.339332e-01)*S213+5.176447e+00*S214+(-1.434443e+00)*S215+(-7.224997e-01)*S216+(-2.788348e-01)*S217+(-4.989702e-01)*S218+(-5.061970e-01)*S219'
.param V9_part23='V9_part22+(-1.106362e+00)*S220+6.453441e-02*S221+1.594825e-01*S222+9.141770e-02*S223+6.954778e-02*S224+2.594555e-02*S225+(-9.362138e-03)*S226+3.410332e-02*S227+2.378425e-01*S228+1.221735e-02*S229'
.param V9_part24='V9_part23+7.392724e-02*S230+(-6.222235e-01)*S231+2.925739e-02*S232+2.596545e-02*S233+(-5.792986e-01)*S234+1.862677e-01*S235+1.259147e-02*S236+3.562268e-02*S237+3.073415e-02*S238+1.160390e-02*S239'
.param V9_part25='V9_part24+(-1.780452e-01)*S240+4.164665e-03*S241+(-5.933330e-03)*S242+5.585192e-01*S243+1.633553e-02*S244+5.138901e-02*S245+3.320709e-02*S246+(-3.151249e-02)*S247+8.348549e-02*S248+1.582369e-01*S249'
.param V9_part26='V9_part25+3.321967e-02*S250+9.565974e-02*S251+7.038634e-02*S252+3.200243e-02*S253+7.116010e-02*S254+(-3.667140e+01)*S255+(-5.592178e+00)*S256+(-3.815259e-03)*S257+(-4.699976e-02)*S258+1.791381e-02*S259'
.param V9_part27='V9_part26+(-7.607776e-03)*S260+1.001837e-02*S261+5.925783e-03*S262+1.767934e-02*S263+3.958271e-02*S264+2.062225e-02*S265+6.657383e-03*S266+(-1.063631e+00)*S267+1.917128e-02*S268+8.886152e-03*S269'
.param V9_part28='V9_part27+2.645914e-01*S270+5.621209e-02*S271+1.084705e-01*S272+9.922152e-02*S273+4.705813e-02*S274+(-1.269785e-01)*S275+4.903825e-02*S276+4.528469e-02*S277+(-8.764367e-02)*S278+4.352525e-01*S279'
.param V9_part29='V9_part28+3.381802e-01*S280+(-7.341900e-02)*S281+4.661803e-01*S282+(-1.348573e+00)*S283+8.884508e-02*S284+2.771508e-01*S285+3.575397e-02*S286+(-7.170642e-02)*S287+8.194923e-01*S288+1.644310e-01*S289'
.param V9_part30='V9_part29+(-4.209904e-02)*S290+4.727819e-02*S291+4.956193e-02*S292+2.061107e-01*S293+1.443657e+00*S294+4.786868e-01*S295+(-7.995777e-02)*S296+2.108563e+00*S297+1.734004e-01*S298+6.081392e-02*S299'
.param V9_part31='V9_part30+1.647465e-01*S300+3.927975e-02*S301+1.341047e-02*S302+5.033572e-01*S303+1.451869e-01*S304+4.382596e-02*S305+1.049223e+00*S306+2.899257e-02*S307+1.353899e-01*S308+8.376311e-01*S309'
.param V9='V9_part31+1.210219e-01*S310+1.237850e-01*S311+1.500426e+00*S312+4.315446e-01*S313+1.110641e-01*S314'
.param V10_part1='6.340126e-02*S0+1.712921e-01*S1+9.945567e-02*S2+4.985461e-02*S3+2.883441e-01*S4+4.340563e-02*S5+5.118890e-02*S6+4.829997e-02*S7+5.967183e-02*S8+1.519073e+00*S9'
.param V10_part2='V10_part1+4.977996e-02*S10+5.371816e-02*S11+1.826905e+00*S12+6.535892e-02*S13+1.072791e-01*S14+5.341548e-02*S15+4.524102e-02*S16+4.406159e-02*S17+1.320338e-01*S18+1.249219e-01*S19'
.param V10_part3='V10_part2+4.487138e-02*S20+1.573881e-01*S21+4.128869e-02*S22+4.795012e-02*S23+1.637346e-01*S24+4.151356e-02*S25+8.828068e-02*S26+2.348401e-01*S27+4.131179e-02*S28+4.033567e-02*S29'
.param V10_part4='V10_part3+5.726742e-02*S30+3.826253e-02*S31+4.783536e-02*S32+8.432949e-02*S33+1.120984e-01*S34+4.919992e-02*S35+1.230425e-01*S36+3.900313e-02*S37+8.991303e-02*S38+2.191397e-01*S39'
.param V10_part5='V10_part4+4.326841e-02*S40+3.318611e-02*S41+2.229273e-01*S42+7.346349e-01*S43+4.000103e-02*S44+5.256663e-02*S45+5.191432e-02*S46+6.890083e-02*S47+1.145370e-01*S48+1.401143e-01*S49'
.param V10_part6='V10_part5+6.583795e-02*S50+4.627727e-02*S51+1.996756e-01*S52+1.372675e-01*S53+2.991703e-01*S54+4.170110e-01*S55+2.076541e-01*S56+4.391221e-01*S57+2.823538e-01*S58+2.012707e-01*S59'
.param V10_part7='V10_part6+7.941780e-02*S60+4.609097e-02*S61+4.145522e-02*S62+1.129315e-01*S63+3.932230e-02*S64+3.845150e-02*S65+2.750840e-01*S66+4.366845e-02*S67+3.908875e-02*S68+1.824646e-02*S69'
.param V10_part8='V10_part7+3.514282e-02*S70+3.096510e-02*S71+2.288016e-02*S72+4.804147e-02*S73+1.315710e-02*S74+8.001832e-03*S75+(-9.198090e-03)*S76+7.345141e-03*S77+5.037749e-02*S78+2.729488e-02*S79'
.param V10_part9='V10_part8+(-1.035831e-01)*S80+9.872747e-02*S81+5.415903e-02*S82+4.835805e-02*S83+1.046788e-01*S84+6.407101e-03*S85+1.078615e-01*S86+1.280168e-01*S87+2.019079e-01*S88+1.118937e-02*S89'
.param V10_part10='V10_part9+8.133200e-02*S90+5.278122e-02*S91+7.634362e-02*S92+1.861011e-01*S93+4.532777e-02*S94+9.172772e-02*S95+2.043732e-02*S96+3.568127e-02*S97+4.122137e-02*S98+7.376265e-01*S99'
.param V10_part11='V10_part10+4.643776e-01*S100+2.250393e-01*S101+9.365939e-01*S102+6.378678e-01*S103+4.242980e-01*S104+1.054460e-01*S105+6.073682e-02*S106+7.045293e-02*S107+2.751479e-01*S108+4.498110e-02*S109'
.param V10_part12='V10_part11+5.530890e-02*S110+5.735596e-01*S111+2.311882e-01*S112+5.553478e-02*S113+7.303999e-02*S114+4.079171e-01*S115+9.410425e-02*S116+1.253234e+00*S117+7.210169e-01*S118+(-1.359857e-02)*S119'
.param V10_part13='V10_part12+1.007259e-01*S120+5.744579e-02*S121+5.613980e-02*S122+2.300312e-01*S123+6.373002e-02*S124+4.570256e-02*S125+4.613702e-01*S126+5.113907e-02*S127+3.877977e-02*S128+7.004252e-01*S129'
.param V10_part14='V10_part13+6.236244e-02*S130+4.110036e-02*S131+(-4.366931e-02)*S132+4.967858e-01*S133+7.876931e-02*S134+4.581132e-02*S135+1.545581e-02*S136+8.203637e-03*S137+8.617045e-02*S138+1.033640e-01*S139'
.param V10_part15='V10_part14+5.426005e-03*S140+1.807005e-01*S141+7.861736e-03*S142+1.095332e+00*S143+3.230768e-01*S144+1.799012e-01*S145+1.624705e-01*S146+(-4.010515e-02)*S147+(-2.869710e-02)*S148+(-5.056248e-03)*S149'
.param V10_part16='V10_part15+1.009340e-01*S150+5.948598e-02*S151+1.361456e-01*S152+2.911146e-01*S153+1.600019e-02*S154+8.987279e-02*S155+(-1.562917e-02)*S156+7.907730e-05*S157+1.427991e-01*S158+6.582763e-01*S159'
.param V10_part17='V10_part16+1.629840e+00*S160+5.898729e-02*S161+(-7.722130e-02)*S162+(-2.651551e-02)*S163+8.174733e-02*S164+3.983768e-02*S165+7.668306e-02*S166+2.394956e-01*S167+1.281995e-02*S168+3.856325e+00*S169'
.param V10_part18='V10_part17+(-1.350846e+00)*S170+7.489538e-01*S171+1.394913e+00*S172+2.764240e-01*S173+7.942479e-01*S174+2.085525e+00*S175+2.924163e+01*S176+(-7.208308e-02)*S177+2.329888e+00*S178+2.273675e-01*S179'
.param V10_part19='V10_part18+8.524877e-02*S180+6.933584e-02*S181+1.232247e-01*S182+1.615225e-02*S183+2.843657e-02*S184+(-3.783238e-01)*S185+6.693729e-01*S186+(-1.215711e-04)*S187+1.093121e-01*S188+8.670348e-01*S189'
.param V10_part20='V10_part19+(-3.437361e-01)*S190+8.769585e-02*S191+7.315842e-01*S192+(-5.472804e-02)*S193+5.048418e-01*S194+4.802088e-02*S195+5.461643e-02*S196+8.582106e-02*S197+(-4.201482e-02)*S198+(-2.960127e-02)*S199'
.param V10_part21='V10_part20+8.484505e-02*S200+5.398168e-01*S201+1.918765e-03*S202+1.008981e-01*S203+6.840632e-01*S204+(-7.730999e-02)*S205+8.340443e-02*S206+(-9.323251e-02)*S207+(-9.924235e-02)*S208+(-2.438376e-01)*S209'
.param V10_part22='V10_part21+5.034705e-02*S210+4.948995e-01*S211+(-5.790651e-01)*S212+2.493573e-01*S213+5.152764e+00*S214+(-1.502312e+00)*S215+6.476342e-01*S216+9.764952e-01*S217+(-2.852956e+00)*S218+7.854209e-01*S219'
.param V10_part23='V10_part22+(-5.708152e-01)*S220+2.337648e-01*S221+1.378052e-02*S222+1.003339e-01*S223+2.170837e-01*S224+6.905256e-02*S225+1.165900e-01*S226+3.262157e-01*S227+6.165541e-02*S228+5.245340e-02*S229'
.param V10_part24='V10_part23+3.703308e-01*S230+8.742082e-01*S231+3.601913e-02*S232+4.089882e-01*S233+6.564497e-01*S234+2.270791e+00*S235+1.177563e-01*S236+(-3.079379e-02)*S237+(-1.517316e-03)*S238+1.410571e-01*S239'
.param V10_part25='V10_part24+1.786023e-01*S240+1.294973e-01*S241+2.113411e-01*S242+3.068258e-01*S243+1.061476e-02*S244+3.711112e-01*S245+(-5.388311e-02)*S246+2.171365e+00*S247+2.713884e-01*S248+1.736555e-01*S249'
.param V10_part26='V10_part25+2.803471e+00*S250+2.944063e-01*S251+(-1.584334e-01)*S252+(-4.988338e-02)*S253+3.391782e-01*S254+2.477991e+00*S255+1.861140e+00*S256+2.013483e-02*S257+3.651959e-02*S258+(-2.359968e-02)*S259'
.param V10_part27='V10_part26+7.965480e-03*S260+(-9.668107e-02)*S261+(-1.161078e-02)*S262+2.064923e-01*S263+(-2.136038e-02)*S264+(-5.886530e-02)*S265+2.372415e-02*S266+9.492767e-01*S267+(-9.821450e-02)*S268+2.924445e-02*S269'
.param V10_part28='V10_part27+1.999496e-01*S270+1.419033e-01*S271+3.490121e-01*S272+8.288575e-02*S273+1.002690e-01*S274+1.235639e+00*S275+(-6.943478e-02)*S276+6.050327e-02*S277+8.786309e-01*S278+7.324358e-02*S279'
.param V10_part29='V10_part28+7.563394e-01*S280+7.456979e-01*S281+1.918422e-02*S282+(-6.678535e-01)*S283+2.837869e-01*S284+4.181769e-01*S285+1.515173e-01*S286+9.250513e-01*S287+3.532432e-01*S288+2.839748e-01*S289'
.param V10_part30='V10_part29+7.928135e-01*S290+(-6.080702e-02)*S291+1.108057e-01*S292+2.962292e-01*S293+5.089406e-01*S294+7.310559e-01*S295+5.325979e-01*S296+7.331972e-01*S297+4.141103e+00*S298+2.020589e-01*S299'
.param V10_part31='V10_part30+1.269140e-01*S300+7.966076e-02*S301+6.148700e-02*S302+2.859926e-01*S303+9.246766e-02*S304+4.127746e-01*S305+4.174447e-01*S306+2.038242e-02*S307+2.618476e-01*S308+4.376447e-01*S309'
.param V10='V10_part31+3.276536e+00*S310+2.464824e-01*S311+4.891702e-01*S312+4.620183e+00*S313+2.122279e-01*S314'
.param V11_part1='1.119848e-01*S0+1.550722e-01*S1+1.109320e-01*S2+1.166911e-01*S3+1.538041e-01*S4+8.948029e-02*S5+1.231611e-01*S6+1.087921e-01*S7+8.823239e-02*S8+1.469037e-01*S9'
.param V11_part2='V11_part1+1.172574e-01*S10+9.447386e-02*S11+1.734121e-01*S12+1.081928e-01*S13+4.888368e-02*S14+1.349182e-01*S15+1.228490e-01*S16+1.117443e-01*S17+4.946002e-01*S18+1.203294e-01*S19'
.param V11_part3='V11_part2+1.181811e-01*S20+1.343934e-01*S21+1.610420e-01*S22+1.282182e-01*S23+1.397285e-01*S24+1.724610e-01*S25+1.287794e-01*S26+1.320649e-01*S27+1.808624e-01*S28+1.634201e-01*S29'
.param V11_part4='V11_part3+2.667660e-01*S30+2.904271e-01*S31+2.374854e-01*S32+2.957291e-01*S33+2.602933e-01*S34+2.673389e-01*S35+3.161812e-01*S36+3.500121e-01*S37+2.635035e-01*S38+3.159312e-01*S39'
.param V11_part5='V11_part4+3.652823e-01*S40+3.338031e-01*S41+3.610299e-01*S42+2.244389e-01*S43+3.453663e-01*S44+4.547430e-01*S45+4.130488e-01*S46+3.138925e-01*S47+4.136264e-01*S48+3.582043e-01*S49'
.param V11_part6='V11_part5+3.712330e-01*S50+5.379930e-01*S51+3.660736e-01*S52+3.648704e-01*S53+4.378693e-01*S54+4.008391e-01*S55+3.928837e-01*S56+4.587306e-01*S57+4.584882e-01*S58+4.143199e-01*S59'
.param V11_part7='V11_part6+4.838968e-01*S60+5.245341e-01*S61+4.851387e-01*S62+5.352542e-01*S63+5.840509e-01*S64+5.254185e-01*S65+5.232462e-01*S66+6.191841e-01*S67+5.690220e-01*S68+7.495087e-01*S69'
.param V11_part8='V11_part7+6.634411e-01*S70+6.089570e-01*S71+7.657735e-01*S72+6.536976e-01*S73+7.446365e-01*S74+2.196603e-01*S75+1.104090e+00*S76+1.766006e-01*S77+1.132644e+00*S78+1.207825e+00*S79'
.param V11_part9='V11_part8+1.561367e+00*S80+1.607865e+00*S81+1.790340e-01*S82+1.654766e-01*S83+1.946867e-01*S84+2.399509e-01*S85+1.558328e-01*S86+2.080207e-01*S87+1.675327e-01*S88+2.239614e-01*S89'
.param V11_part10='V11_part9+7.616437e-01*S90+8.247511e-01*S91+6.655845e-01*S92+7.799702e-01*S93+8.964681e-01*S94+7.375353e-01*S95+1.064442e+00*S96+9.009499e-01*S97+8.275771e-01*S98+7.483224e-01*S99'
.param V11_part11='V11_part10+7.497099e-01*S100+7.842369e-01*S101+7.772424e-01*S102+7.527121e-01*S103+7.943843e-01*S104+9.235910e-01*S105+1.007416e+00*S106+1.009207e+00*S107+9.186660e-01*S108+1.108010e+00*S109'
.param V11_part12='V11_part11+9.385227e-01*S110+8.662038e-01*S111+1.006425e+00*S112+1.009066e+00*S113+1.281778e+00*S114+9.905190e-01*S115+1.040396e+00*S116+8.201050e-01*S117+9.269311e-01*S118+1.329897e+00*S119'
.param V11_part13='V11_part12+1.126891e+00*S120+1.072474e+00*S121+1.007739e+00*S122+1.148962e+00*S123+1.240133e+00*S124+1.112688e+00*S125+1.173277e+00*S126+1.289141e+00*S127+1.185065e+00*S128+1.195613e+00*S129'
.param V11_part14='V11_part13+1.352547e+00*S130+1.252638e+00*S131+1.701904e+00*S132+1.222805e+00*S133+1.297392e+00*S134+6.056521e-01*S135+6.715687e-01*S136+5.665689e-01*S137+6.686970e-01*S138+5.741742e-01*S139'
.param V11_part15='V11_part14+6.831499e-01*S140+6.631974e-01*S141+7.159790e-01*S142+4.733651e+00*S143+6.755884e-01*S144+6.803540e-01*S145+6.220934e-01*S146+9.476081e-01*S147+8.777184e-01*S148+8.057659e-01*S149'
.param V11_part16='V11_part15+1.501076e+00*S150+1.465492e+00*S151+1.279534e+00*S152+1.563505e+00*S153+1.728249e+00*S154+1.530212e+00*S155+2.059163e+00*S156+1.935082e+00*S157+1.517105e+00*S158+1.645582e+00*S159'
.param V11_part17='V11_part16+1.084385e+00*S160+1.663871e+00*S161+2.285584e+00*S162+2.114695e+00*S163+1.723080e+00*S164+1.972125e+00*S165+1.826088e+00*S166+2.030075e+00*S167+2.174175e+00*S168+1.639687e+01*S169'
.param V11_part18='V11_part17+8.714063e+00*S170+1.686605e+00*S171+1.199445e+00*S172+4.434026e+00*S173+1.846499e+00*S174+1.236412e+00*S175+5.765694e+00*S176+2.600337e+00*S177+1.241604e+00*S178+1.908013e+00*S179'
.param V11_part19='V11_part18+2.055994e+00*S180+1.979387e+00*S181+1.799488e+00*S182+2.363149e+00*S183+2.211284e+00*S184+2.173053e+00*S185+2.009294e+00*S186+2.347972e+00*S187+2.143239e+00*S188+2.122868e+00*S189'
.param V11_part20='V11_part19+1.827956e+00*S190+2.261843e+00*S191+2.328534e+00*S192+2.699071e+00*S193+2.456544e+00*S194+1.312567e+00*S195+1.866422e+00*S196+1.103081e+00*S197+1.650901e+00*S198+1.608722e+00*S199'
.param V11_part21='V11_part20+1.228393e+00*S200+1.251154e+00*S201+1.495788e+00*S202+1.298245e+00*S203+1.350210e+00*S204+1.690321e+00*S205+1.403231e+00*S206+1.954767e+00*S207+8.784822e-01*S208+1.588612e+00*S209'
.param V11_part22='V11_part21+2.709654e+00*S210+5.507861e+00*S211+1.259782e+01*S212+2.681916e+00*S213+1.744430e+01*S214+1.095365e+01*S215+2.631856e+00*S216+2.318519e+00*S217+1.351557e+01*S218+2.750285e+00*S219'
.param V11_part23='V11_part22+2.378131e+00*S220+2.633989e+00*S221+3.421924e+00*S222+3.012734e+00*S223+2.767804e+00*S224+2.997160e+00*S225+2.875443e+00*S226+2.315319e+00*S227+4.581377e+00*S228+3.312218e+00*S229'
.param V11_part24='V11_part23+2.487564e+00*S230+2.848568e+00*S231+3.260764e+00*S232+3.361056e+00*S233+3.212934e+00*S234+2.393009e+00*S235+3.018430e+00*S236+4.079517e+00*S237+3.673233e+00*S238+3.166609e+00*S239'
.param V11_part25='V11_part24+3.522145e+00*S240+2.949776e+00*S241+2.833554e+00*S242+3.317471e+00*S243+3.719425e+00*S244+2.799617e+00*S245+4.092613e+00*S246+2.334764e+00*S247+3.057580e+00*S248+3.896508e+00*S249'
.param V11_part26='V11_part25+2.520362e+00*S250+3.208707e+00*S251+4.462132e+00*S252+3.941967e+00*S253+3.348055e+00*S254+1.178042e+02*S255+1.606982e+01*S256+1.989473e+00*S257+2.605929e+00*S258+2.496565e+00*S259'
.param V11_part27='V11_part26+2.158538e+00*S260+2.950616e+00*S261+2.710169e+00*S262+2.784219e+00*S263+2.944353e+00*S264+2.840973e+00*S265+2.443435e+00*S266+2.533475e+00*S267+2.905361e+00*S268+2.550042e+00*S269'
.param V11_part28='V11_part27+3.759320e+00*S270+3.598071e+00*S271+3.233060e+00*S272+4.217708e+00*S273+3.976559e+00*S274+3.729655e+00*S275+4.850770e+00*S276+4.210049e+00*S277+4.154112e+00*S278+4.746023e+00*S279'
.param V11_part29='V11_part28+4.123416e+00*S280+4.349351e+00*S281+4.953291e+00*S282+3.487272e+00*S283+4.083389e+00*S284+5.913659e+00*S285+4.473124e+00*S286+4.078515e+00*S287+4.342315e+00*S288+4.133171e+00*S289'
.param V11_part30='V11_part29+4.329554e+00*S290+5.290175e+00*S291+4.552742e+00*S292+4.062126e+00*S293+4.815733e+00*S294+4.442121e+00*S295+5.049918e+00*S296+5.500104e+00*S297+3.128522e+00*S298+4.480591e+00*S299'
.param V11_part31='V11_part30+3.464711e+00*S300+3.286209e+00*S301+2.984381e+00*S302+3.681024e+00*S303+3.523396e+00*S304+3.053876e+00*S305+3.803719e+00*S306+3.821131e+00*S307+3.343423e+00*S308+4.035432e+00*S309'
.param V11='V11_part31+2.466893e+00*S310+3.540744e+00*S311+4.226647e+00*S312+2.314404e+00*S313+3.712761e+00*S314'
.param V12_part1='(-2.151592e-02)*S0+(-1.881430e-02)*S1+5.431320e-03*S2+(-2.912097e-02)*S3+(-3.147487e-02)*S4+(-9.482459e-04)*S5+(-4.356699e-02)*S6+(-2.020193e-02)*S7+(-3.237317e-03)*S8+(-4.022898e-01)*S9'
.param V12_part2='V12_part1+(-3.015786e-02)*S10+(-8.110808e-03)*S11+(-5.244339e-01)*S12+(-2.839594e-02)*S13+(-2.004111e-02)*S14+(-1.216265e-02)*S15+2.022127e-03*S16+7.999101e-03*S17+(-3.125810e-02)*S18+(-1.072945e-02)*S19'
.param V12_part3='V12_part2+2.901924e-03*S20+(-4.813038e-02)*S21+(-2.457568e-02)*S22+(-3.985283e-03)*S23+(-5.192215e-02)*S24+(-3.593612e-02)*S25+(-2.502764e-03)*S26+(-6.868166e-02)*S27+(-4.840619e-02)*S28+(-2.402821e-02)*S29'
.param V12_part4='V12_part3+(-9.497085e-03)*S30+7.648552e-03*S31+2.217361e-02*S32+(-2.990525e-02)*S33+1.185932e-02*S34+2.092877e-02*S35+(-4.122134e-02)*S36+(-3.397492e-02)*S37+1.655998e-02*S38+(-3.131010e-02)*S39'
.param V12_part5='V12_part4+(-6.297455e-02)*S40+(-1.610839e-02)*S41+(-1.160738e-02)*S42+1.271123e-01*S43+(-3.755331e-02)*S44+6.725216e-03*S45+2.732376e-02*S46+4.177825e-02*S47+(-2.730338e-02)*S48+2.099945e-02*S49'
.param V12_part6='V12_part5+4.112733e-02*S50+(-1.050753e-01)*S51+2.940825e-03*S52+4.510656e-02*S53+(-7.602335e-02)*S54+1.291361e-01*S55+7.350258e-02*S56+(-2.601551e-02)*S57+1.007552e-01*S58+3.100376e-02*S59'
.param V12_part7='V12_part6+2.202000e-02*S60+3.830503e-02*S61+5.682223e-02*S62+(-6.122920e-03)*S63+9.535446e-03*S64+4.100578e-02*S65+(-5.865408e-04)*S66+(-3.388421e-02)*S67+1.536262e-02*S68+(-1.753188e-01)*S69'
.param V12_part8='V12_part7+(-7.016458e-02)*S70+(-7.649346e-03)*S71+(-2.732583e-01)*S72+(-6.628810e-02)*S73+(-1.550514e-02)*S74+(-6.854880e-03)*S75+1.182493e-01*S76+1.238799e-02*S77+6.050424e-03*S78+1.429006e-01*S79'
.param V12_part9='V12_part8+2.387858e-01*S80+6.954018e-02*S81+(-9.464946e-03)*S82+4.802707e-03*S83+(-5.056985e-02)*S84+(-3.561918e-02)*S85+8.528947e-03*S86+(-5.181048e-02)*S87+2.668467e-03*S88+(-2.464897e-02)*S89'
.param V12_part10='V12_part9+7.202230e-02*S90+9.384579e-02*S91+1.135772e-01*S92+1.775545e-02*S93+5.417526e-02*S94+1.212606e-01*S95+(-1.018803e-01)*S96+4.076440e-03*S97+4.397920e-02*S98+2.626927e-01*S99'
.param V12_part11='V12_part10+9.198758e-02*S100+6.478689e-02*S101+3.512690e-01*S102+4.465070e-02*S103+7.024656e-02*S104+9.221237e-02*S105+1.601293e-01*S106+1.806453e-01*S107+4.739243e-02*S108+1.126177e-01*S109'
.param V12_part12='V12_part11+1.133213e-01*S110+7.105476e-02*S111+1.203317e-01*S112+8.486453e-02*S113+(-2.472310e-01)*S114+2.668302e-01*S115+4.695512e-02*S116+(-1.829502e-01)*S117+(-1.242291e-01)*S118+2.054166e-02*S119'
.param V12_part13='V12_part12+1.935006e-01*S120+2.530749e-01*S121+1.740643e-01*S122+1.330463e-01*S123+3.219624e-01*S124+1.457312e-01*S125+2.158313e-01*S126+2.497305e-02*S127+1.178576e-01*S128+1.524547e-01*S129'
.param V12_part14='V12_part13+(-7.334982e-02)*S130+7.945477e-02*S131+(-3.417126e-01)*S132+5.047220e-02*S133+3.843621e-02*S134+2.971878e-02*S135+6.483673e-02*S136+6.713129e-02*S137+1.142912e-02*S138+4.101341e-02*S139'
.param V12_part15='V12_part14+7.029966e-02*S140+(-1.564496e-02)*S141+1.313419e-03*S142+6.748550e-01*S143+3.386932e-02*S144+2.182031e-01*S145+5.257619e-02*S146+(-2.398992e-01)*S147+(-1.027821e-01)*S148+(-3.083626e-02)*S149'
.param V12_part16='V12_part15+2.917441e-01*S150+2.753130e-01*S151+2.561010e-01*S152+2.274169e-01*S153+2.948576e-01*S154+2.823336e-01*S155+8.280411e-02*S156+2.051944e-01*S157+1.604146e-01*S158+(-1.589216e-01)*S159'
.param V12_part17='V12_part16+(-1.228860e+00)*S160+1.457997e-01*S161+(-3.164231e-01)*S162+(-5.551089e-02)*S163+4.166299e-02*S164+5.431056e-01*S165+4.651956e-01*S166+4.345068e-01*S167+3.923638e-01*S168+(-3.505612e+00)*S169'
.param V12_part18='V12_part17+3.141722e+00*S170+(-1.935291e-01)*S171+(-9.020093e-01)*S172+9.584275e-01*S173+(-4.256997e-01)*S174+(-1.638568e+00)*S175+(-2.281671e+01)*S176+(-3.353589e-01)*S177+(-1.931371e+00)*S178+6.627250e-02*S179'
.param V12_part19='V12_part18+4.696522e-01*S180+5.394049e-01*S181+5.270505e-01*S182+3.868913e-01*S183+4.868676e-01*S184+2.297574e+00*S185+(-6.699352e-02)*S186+4.158260e-01*S187+3.945262e-01*S188+(-2.981799e-01)*S189'
.param V12_part20='V12_part19+3.392527e+00*S190+3.247309e-01*S191+(-5.147290e-01)*S192+1.020963e-01*S193+6.863623e-02*S194+1.872324e-01*S195+3.291367e-01*S196+2.017153e-01*S197+2.193791e-01*S198+2.803495e-01*S199'
.param V12_part21='V12_part20+1.681965e-01*S200+7.495426e-02*S201+6.343689e-02*S202+1.179405e-01*S203+1.162383e-01*S204+9.152943e-02*S205+6.631650e-02*S206+(-3.393600e-01)*S207+2.793198e+00*S208+8.691516e-02*S209'
.param V12_part22='V12_part21+8.914264e-01*S210+9.280218e-01*S211+4.124427e+00*S212+1.713846e-01*S213+(-3.651299e+00)*S214+4.513173e+00*S215+(-9.976529e-03)*S216+4.867161e-02*S217+5.492322e+00*S218+(-3.290176e-01)*S219'
.param V12_part23='V12_part22+3.734919e+00*S220+3.494664e-01*S221+(-6.422265e-01)*S222+5.942205e-02*S223+2.408056e-01*S224+1.067287e+00*S225+1.032650e+00*S226+7.402697e-01*S227+5.857723e-01*S228+9.576394e-01*S229'
.param V12_part24='V12_part23+6.463684e-01*S230+(-1.614385e-01)*S231+7.370697e-01*S232+7.543913e-01*S233+(-2.969965e-01)*S234+(-1.620069e+00)*S235+7.085056e-01*S236+(-3.142060e-01)*S237+4.569294e-01*S238+5.525915e-01*S239'
.param V12_part25='V12_part24+8.583964e-01*S240+1.167964e+00*S241+1.091752e+00*S242+2.844401e-01*S243+1.288557e+00*S244+7.867141e-01*S245+7.368940e-01*S246+(-1.226431e+00)*S247+7.149094e-01*S248+(-3.486545e-01)*S249'
.param V12_part26='V12_part25+(-2.017769e+00)*S250+5.912945e-01*S251+(-9.255174e-02)*S252+4.433557e-01*S253+4.381540e-01*S254+(-1.314631e+01)*S255+8.020117e-01*S256+6.906972e-01*S257+2.389539e-01*S258+6.209970e-01*S259'
.param V12_part27='V12_part26+6.510549e-01*S260+4.332678e-01*S261+4.766584e-01*S262+5.057893e-01*S263+(-8.770033e-02)*S264+3.546502e-01*S265+4.691237e-01*S266+(-2.101769e-01)*S267+1.680181e-01*S268+3.652921e-01*S269'
.param V12_part28='V12_part27+1.013165e+00*S270+1.466580e+00*S271+1.227849e+00*S272+1.062719e+00*S273+1.381038e+00*S274+1.022577e+00*S275+1.158799e+00*S276+1.148113e+00*S277+1.041953e+00*S278+(-1.060506e-01)*S279'
.param V12_part29='V12_part28+(-9.861508e-02)*S280+9.344942e-01*S281+(-5.197300e-01)*S282+6.099166e+00*S283+7.726847e-01*S284+1.456085e+00*S285+2.163921e+00*S286+1.679421e+00*S287+7.316909e-01*S288+1.134737e+00*S289'
.param V12_part30='V12_part29+1.670265e+00*S290+1.379091e+00*S291+1.313361e+00*S292+1.226561e+00*S293+(-2.863070e-01)*S294+2.398440e-01*S295+1.404859e+00*S296+(-1.498582e+00)*S297+(-2.671518e+00)*S298+9.762208e-01*S299'
.param V12_part31='V12_part30+8.781888e-01*S300+1.272457e+00*S301+1.351018e+00*S302+3.768467e-01*S303+8.980629e-01*S304+9.316638e-01*S305+(-6.541950e-02)*S306+9.002664e-01*S307+8.548406e-01*S308+(-4.137722e-01)*S309'
.param V12='V12_part31+(-2.047492e+00)*S310+7.303822e-01*S311+(-9.724700e-01)*S312+(-3.291707e+00)*S313+6.204507e-01*S314'
.param V13_part1='5.130667e-02*S0+1.153645e-01*S1+7.238603e-02*S2+3.905319e-02*S3+1.874484e-01*S4+3.339922e-02*S5+3.892089e-02*S6+3.592167e-02*S7+4.628436e-02*S8+9.301392e-01*S9'
.param V13_part2='V13_part1+3.687747e-02*S10+4.269519e-02*S11+1.112712e+00*S12+5.216851e-02*S13+(-4.062020e-02)*S14+4.885175e-02*S15+4.298169e-02*S16+4.204330e-02*S17+1.104213e-01*S18+9.686683e-02*S19'
.param V13_part3='V13_part2+4.153680e-02*S20+1.214693e-01*S21+3.073116e-02*S22+4.403220e-02*S23+1.303170e-01*S24+3.198246e-02*S25+8.101803e-02*S26+1.735805e-01*S27+3.227506e-02*S28+3.007914e-02*S29'
.param V13_part4='V13_part3+4.767877e-02*S30+2.998514e-02*S31+4.430386e-02*S32+7.264493e-02*S33+9.227792e-02*S34+5.275188e-02*S35+1.084298e-01*S36+3.457362e-02*S37+7.982831e-02*S38+1.742514e-01*S39'
.param V13_part5='V13_part4+3.513070e-02*S40+3.206647e-02*S41+2.116875e-01*S42+5.281707e-01*S43+3.351472e-02*S44+3.962511e-02*S45+3.702038e-02*S46+5.013823e-02*S47+8.599143e-02*S48+9.713371e-02*S49'
.param V13_part6='V13_part5+5.911723e-02*S50+3.878656e-02*S51+1.356340e-01*S52+1.014331e-01*S53+2.047290e-01*S54+3.012603e-01*S55+1.720214e-01*S56+3.205914e-01*S57+2.426654e-01*S58+1.528492e-01*S59'
.param V13_part7='V13_part6+6.917118e-02*S60+3.239060e-02*S61+3.021522e-02*S62+1.027567e-01*S63+3.340604e-02*S64+3.019477e-02*S65+2.114981e-01*S66+3.637211e-02*S67+3.436527e-02*S68+3.655493e-02*S69'
.param V13_part8='V13_part7+3.870736e-02*S70+3.608718e-02*S71+3.239431e-02*S72+8.773816e-02*S73+6.136181e-02*S74+1.301441e-02*S75+(-9.700328e-03)*S76+1.108858e-02*S77+4.136574e-02*S78+7.436077e-02*S79'
.param V13_part9='V13_part8+1.118518e-01*S80+3.171833e-01*S81+4.853553e-02*S82+4.400742e-02*S83+8.305461e-02*S84+1.267709e-02*S85+8.136331e-02*S86+1.078942e-01*S87+1.483297e-01*S88+1.299137e-02*S89'
.param V13_part10='V13_part9+7.014276e-02*S90+3.667543e-02*S91+6.253174e-02*S92+1.346932e-01*S93+4.040173e-02*S94+9.828797e-02*S95+3.890657e-02*S96+5.695258e-02*S97+4.570239e-02*S98+4.758435e-01*S99'
.param V13_part11='V13_part10+2.833269e-01*S100+1.675978e-01*S101+6.063328e-01*S102+3.513456e-01*S103+2.750663e-01*S104+7.382320e-02*S105+4.253293e-02*S106+4.432673e-02*S107+1.680733e-01*S108+4.643333e-02*S109'
.param V13_part12='V13_part11+4.651998e-02*S110+3.128334e-01*S111+1.640590e-01*S112+5.902499e-02*S113+9.621334e-02*S114+2.688171e-01*S115+8.700039e-02*S116+5.787184e-01*S117+3.036981e-01*S118+6.630903e-02*S119'
.param V13_part13='V13_part12+9.098429e-02*S120+7.033267e-02*S121+3.409371e-02*S122+1.753693e-01*S123+1.166679e-01*S124+3.634687e-02*S125+3.181376e-01*S126+5.600374e-02*S127+4.450385e-02*S128+4.389101e-01*S129'
.param V13_part14='V13_part13+5.161179e-02*S130+6.090863e-02*S131+4.033423e-02*S132+3.126575e-01*S133+9.187245e-02*S134+3.932304e-02*S135+1.580940e-02*S136+9.537655e-03*S137+8.713022e-02*S138+7.571967e-02*S139'
.param V13_part15='V13_part14+1.760651e-02*S140+1.437586e-01*S141+3.585579e-02*S142+8.990929e-01*S143+2.374887e-01*S144+1.933110e-01*S145+1.121534e-01*S146+1.734117e-02*S147+2.387631e-02*S148+2.624841e-02*S149'
.param V13_part16='V13_part15+7.745007e-02*S150+3.529907e-02*S151+3.269898e-02*S152+1.921548e-01*S153+3.692651e-02*S154+3.528520e-02*S155+3.782468e-02*S156+3.045471e-02*S157+3.603131e-02*S158+3.396738e-01*S159'
.param V13_part17='V13_part16+6.225923e-02*S160+5.598754e-02*S161+3.648966e-02*S162+1.865702e-02*S163+4.607166e-02*S164+4.290894e-02*S165+3.977968e-02*S166+5.530402e-02*S167+4.350845e-02*S168+8.542954e-01*S169'
.param V13_part18='V13_part17+3.577976e-01*S170+2.766502e-01*S171+6.080694e-02*S172+1.692604e-01*S173+3.170904e-01*S174+5.038714e-02*S175+7.212517e-01*S176+3.610881e-02*S177+3.149157e-02*S178+3.700648e-02*S179'
.param V13_part19='V13_part18+7.527847e-02*S180+3.489077e-02*S181+3.424456e-02*S182+3.192762e-02*S183+3.699761e-02*S184+2.647486e-03*S185+3.040902e-01*S186+3.845239e-02*S187+3.590866e-02*S188+4.144776e-01*S189'
.param V13_part20='V13_part19+2.502153e-01*S190+3.632491e-02*S191+3.593549e-01*S192+3.137679e-02*S193+3.643221e-02*S194+4.268018e-02*S195+3.114388e-02*S196+1.127353e-02*S197+1.402236e-02*S198+3.279502e-02*S199'
.param V13_part21='V13_part20+1.238768e-02*S200+2.786959e-01*S201+1.929449e-02*S202+1.303597e-02*S203+3.894361e-01*S204+1.425989e-02*S205+1.705617e-02*S206+1.534448e-02*S207+8.169467e-02*S208+1.818488e-02*S209'
.param V13_part22='V13_part21+3.430928e-02*S210+6.641842e-02*S211+3.711645e-01*S212+9.915015e-02*S213+7.335189e-01*S214+3.333862e-01*S215+3.128259e-01*S216+2.860534e-01*S217+4.556105e-01*S218+3.472286e-01*S219'
.param V13_part23='V13_part22+1.005512e-01*S220+4.779511e-02*S221+5.807476e-02*S222+6.776377e-02*S223+5.265766e-02*S224+4.101336e-02*S225+4.206107e-02*S226+4.226672e-02*S227+5.573025e-02*S228+4.083665e-02*S229'
.param V13_part24='V13_part23+4.479750e-02*S230+3.039301e-01*S231+4.993827e-02*S232+5.824156e-02*S233+3.242895e-01*S234+9.621414e-02*S235+4.742650e-02*S236+2.220429e-02*S237+2.099048e-02*S238+4.889135e-02*S239'
.param V13_part25='V13_part24+5.775234e-02*S240+3.561954e-02*S241+4.155516e-02*S242+6.636153e-02*S243+3.147042e-02*S244+3.660921e-02*S245+3.170342e-02*S246+5.257103e-02*S247+4.683795e-02*S248+1.165198e-01*S249'
.param V13_part26='V13_part25+4.715436e-02*S250+5.078404e-02*S251+2.093323e-02*S252+4.129631e-02*S253+5.134708e-02*S254+1.889643e+00*S255+2.547339e-01*S256+1.357418e-02*S257+5.398348e-02*S258+1.697423e-02*S259'
.param V13_part27='V13_part26+1.649450e-02*S260+9.515474e-03*S261+1.081638e-02*S262+3.309713e-02*S263+1.423456e-02*S264+8.678718e-03*S265+1.521304e-02*S266+4.869002e-01*S267+1.173638e-02*S268+1.974124e-02*S269'
.param V13_part28='V13_part27+5.138950e-02*S270+4.001463e-02*S271+5.425828e-02*S272+3.940208e-02*S273+3.842461e-02*S274+1.574136e-02*S275+3.165886e-02*S276+4.146006e-02*S277+2.667412e-02*S278+6.608662e-02*S279'
.param V13_part29='V13_part28+9.672687e-02*S280+2.786146e-02*S281+7.181038e-02*S282+1.596307e-01*S283+5.940632e-02*S284+7.089500e-02*S285+4.174110e-02*S286+6.410145e-02*S287+6.150594e-02*S288+6.802267e-02*S289'
.param V13_part30='V13_part29+5.542157e-02*S290+3.467805e-02*S291+4.919931e-02*S292+5.919093e-02*S293+9.819012e-02*S294+1.040821e-01*S295+8.337656e-02*S296+1.788299e-01*S297+2.675124e-02*S298+7.778855e-02*S299'
.param V13_part31='V13_part30+3.038434e-02*S300+1.692706e-02*S301+1.749612e-02*S302+4.543784e-02*S303+3.201136e-02*S304+1.704919e-02*S305+4.239805e-02*S306+2.140512e-02*S307+2.463973e-02*S308+6.498742e-02*S309'
.param V13='V13_part31+8.773483e-02*S310+2.697695e-02*S311+7.591294e-02*S312+7.850745e-02*S313+4.048205e-02*S314'
.param V14_part1='3.331412e-05*S0+1.497482e-04*S1+9.176668e-06*S2+6.091010e-06*S3+2.190512e-04*S4+5.380949e-06*S5+6.880759e-07*S6+(-7.095314e-06)*S7+5.520882e-05*S8+(-5.478587e-03)*S9'
.param V14_part2='V14_part1+2.322954e-05*S10+5.698265e-05*S11+(-7.873327e-03)*S12+8.629021e-06*S13+(-1.899959e-04)*S14+3.157036e-04*S15+2.797932e-04*S16+2.401449e-04*S17+5.603899e-04*S18+1.708409e-04*S19'
.param V14_part3='V14_part2+2.831574e-04*S20+1.653050e-04*S21+4.468278e-04*S22+3.105954e-04*S23+2.061449e-04*S24+4.785308e-04*S25+2.399775e-04*S26+1.163507e-04*S27+5.080408e-04*S28+4.598059e-04*S29'
.param V14_part4='V14_part3+2.017359e-03*S30+2.361425e-03*S31+2.139132e-03*S32+1.725964e-03*S33+2.642696e-03*S34+1.899226e-03*S35+1.311317e-03*S36+1.918311e-03*S37+6.022267e-04*S38+8.602910e-04*S39'
.param V14_part5='V14_part4+1.703389e-03*S40+2.886053e-04*S41+(-1.214842e-03)*S42+(-3.586607e-03)*S43+1.442216e-04*S44+3.317253e-03*S45+3.020780e-03*S46+2.512791e-03*S47+1.805619e-03*S48+2.576672e-03*S49'
.param V14_part6='V14_part5+1.606792e-03*S50+(-7.741431e-04)*S51+5.017249e-04*S52+(-5.315522e-04)*S53+(-2.476018e-03)*S54+(-1.371246e-03)*S55+(-6.456722e-03)*S56+(-4.797359e-03)*S57+(-4.543718e-04)*S58+(-3.876664e-03)*S59'
.param V14_part7='V14_part6+3.708906e-03*S60+4.078205e-03*S61+4.077147e-03*S62+1.836010e-03*S63+1.859377e-03*S64+1.966744e-03*S65+(-1.716076e-03)*S66+2.555706e-03*S67+2.437032e-03*S68+(-6.402694e-04)*S69'
.param V14_part8='V14_part7+1.678589e-03*S70+1.420628e-03*S71+(-6.424643e-03)*S72+(-8.211631e-03)*S73+2.759354e-03*S74+3.372479e-03*S75+3.368753e-02*S76+2.650125e-03*S77+2.949612e-02*S78+3.541629e-02*S79'
.param V14_part9='V14_part8+5.534794e-02*S80+3.858376e-02*S81+8.532644e-04*S82+5.718508e-04*S83+6.374220e-05*S84+1.913967e-03*S85+(-1.235921e-03)*S86+2.553918e-04*S87+(-2.048602e-03)*S88+9.475554e-04*S89'
.param V14_part10='V14_part9+9.441905e-03*S90+1.101053e-02*S91+1.139800e-02*S92+3.583361e-03*S93+8.700283e-03*S94+7.407953e-03*S95+3.158900e-04*S96+4.531780e-03*S97+1.046941e-02*S98+6.617690e-03*S99'
.param V14_part11='V14_part10+1.966757e-03*S100+5.530257e-03*S101+6.580430e-03*S102+3.126231e-03*S103+1.210842e-02*S104+8.776940e-03*S105+1.038420e-02*S106+1.798128e-02*S107+1.416298e-03*S108+8.800448e-03*S109'
.param V14_part12='V14_part11+1.671566e-02*S110+5.417502e-03*S111+4.530553e-03*S112+1.415942e-02*S113+(-4.770143e-04)*S114+3.730188e-03*S115+5.980592e-03*S116+(-8.037121e-03)*S117+(-7.642992e-04)*S118+7.785245e-03*S119'
.param V14_part13='V14_part12+1.389242e-02*S120+2.117045e-02*S121+2.413613e-02*S122+4.786179e-03*S123+1.511350e-02*S124+1.869279e-02*S125+5.706064e-03*S126+8.432147e-03*S127+1.590236e-02*S128+(-6.514261e-03)*S129'
.param V14_part14='V14_part13+3.072349e-03*S130+1.127811e-02*S131+(-1.151827e-02)*S132+2.747203e-03*S133+4.895334e-03*S134+5.415230e-03*S135+5.878745e-03*S136+1.059853e-02*S137+5.066497e-03*S138+5.249790e-03*S139'
.param V14_part15='V14_part14+5.033435e-03*S140+6.389760e-03*S141+1.757046e-03*S142+2.159249e-01*S143+4.221008e-03*S144+9.781417e-03*S145+4.389955e-03*S146+(-3.384406e-03)*S147+1.426274e-03*S148+(-6.346476e-03)*S149'
.param V14_part16='V14_part15+2.326068e-02*S150+3.099231e-02*S151+2.674340e-02*S152+1.053026e-02*S153+1.779388e-02*S154+2.577856e-02*S155+6.023241e-03*S156+1.009351e-02*S157+1.972062e-02*S158+1.119148e-02*S159'
.param V14_part17='V14_part16+6.250066e-02*S160+2.469202e-02*S161+(-1.635345e-02)*S162+(-6.745647e-03)*S163+1.572440e-02*S164+3.358550e-02*S165+3.742428e-02*S166+3.564390e-02*S167+1.950760e-02*S168+1.073170e+00*S169'
.param V14_part18='V14_part17+5.757074e-01*S170+2.366827e-02*S171+7.655902e-02*S172+3.083553e-01*S173+4.885495e-03*S174+6.968817e-02*S175+2.266205e-02*S176+(-2.079202e-02)*S177+4.643869e-02*S178+7.019040e-03*S179'
.param V14_part19='V14_part18+3.997534e-02*S180+3.468626e-02*S181+4.098820e-02*S182+2.038292e-02*S183+2.843261e-02*S184+4.400914e-02*S185+9.053360e-03*S186+1.789954e-02*S187+2.886531e-02*S188+(-4.697756e-03)*S189'
.param V14_part20='V14_part19+2.057096e-02*S190+2.563662e-02*S191+1.863845e-02*S192+(-2.484096e-03)*S193+4.040652e-02*S194+2.116678e-02*S195+7.267187e-02*S196+2.342622e-02*S197+1.461434e-02*S198+4.907540e-02*S199'
.param V14_part21='V14_part20+2.029506e-02*S200+5.654208e-03*S201+1.246922e-02*S202+1.140687e-02*S203+1.683864e-02*S204+(-1.097927e-03)*S205+1.489187e-02*S206+(-1.284720e-02)*S207+(-4.438370e-02)*S208+(-6.327145e-01)*S209'
.param V14_part22='V14_part21+5.348589e-02*S210+(-3.332370e-02)*S211+1.078865e+00*S212+6.136429e-02*S213+1.706149e+00*S214+9.486272e-01*S215+2.682904e-02*S216+5.429412e-02*S217+1.160961e+00*S218+1.454068e-02*S219'
.param V14_part23='V14_part22+(-3.098879e-02)*S220+4.285456e-02*S221+(-8.199965e-03)*S222+3.380112e-02*S223+4.239192e-02*S224+6.274608e-02*S225+7.453745e-02*S226+6.301847e-02*S227+4.035346e-02*S228+4.729507e-02*S229'
.param V14_part24='V14_part23+4.334600e-02*S230+5.499880e-02*S231+3.905461e-02*S232+9.506591e-02*S233+9.070094e-03*S234+1.135716e-01*S235+5.077414e-02*S236+(-2.950380e-02)*S237+(-2.219169e-04)*S238+4.270755e-02*S239'
.param V14_part25='V14_part24+1.507236e-01*S240+7.959308e-02*S241+9.090950e-02*S242+1.299358e-01*S243+5.359700e-02*S244+6.469465e-02*S245+2.749919e-02*S246+1.060092e-01*S247+6.399496e-02*S248+4.897222e-02*S249'
.param V14_part26='V14_part25+1.048288e-01*S250+5.648660e-02*S251+(-1.974274e-02)*S252+1.639057e-02*S253+4.206712e-02*S254+(-2.803505e+00)*S255+(-6.766883e-01)*S256+5.383177e-02*S257+4.145857e-02*S258+3.067981e-02*S259'
.param V14_part27='V14_part26+4.406271e-02*S260+1.046799e-02*S261+2.339684e-02*S262+9.230096e-02*S263+(-7.332048e-03)*S264+1.076851e-02*S265+3.512797e-02*S266+(-2.217317e-02)*S267+3.354789e-03*S268+2.789563e-02*S269'
.param V14_part28='V14_part27+1.395689e-01*S270+9.138983e-02*S271+9.510095e-02*S272+6.759790e-02*S273+7.881686e-02*S274+3.158780e-02*S275+3.675447e-02*S276+6.987678e-02*S277+3.220092e-02*S278+4.257805e-02*S279'
.param V14_part29='V14_part28+1.402759e-01*S280+2.505816e-02*S281+1.766407e-02*S282+(-3.959162e-02)*S283+6.270084e-02*S284+3.379552e-01*S285+1.126123e-01*S286+1.073368e-01*S287+1.943305e-01*S288+1.489298e-01*S289'
.param V14_part30='V14_part29+1.135981e-01*S290+4.633625e-02*S291+7.899190e-02*S292+1.162607e-01*S293+1.655754e-01*S294+1.712161e-01*S295+9.992189e-02*S296+2.275370e-01*S297+1.446677e-01*S298+1.154799e-01*S299'
.param V14_part31='V14_part30+1.149102e-01*S300+7.724238e-02*S301+9.286356e-02*S302+1.482735e-01*S303+9.843110e-02*S304+7.461707e-02*S305+1.675280e-01*S306+3.404097e-02*S307+7.355586e-02*S308+1.458583e-01*S309'
.param V14='V14_part31+1.386456e-01*S310+6.904518e-02*S311+1.369173e-01*S312+1.861083e-01*S313+5.346532e-02*S314'
.param V15_part1='2.983419e-03*S0+3.612270e-03*S1+4.602333e-03*S2+1.632783e+01*S3+(-1.760570e-02)*S4+5.820539e+00*S5+1.469211e+01*S6+8.547732e+00*S7+(-2.843560e-02)*S8+(-7.149520e-02)*S9'
.param V15_part2='V15_part1+1.779905e+00*S10+(-4.692382e-02)*S11+(-9.320530e-02)*S12+(-8.876714e-02)*S13+(-4.951067e-02)*S14+(-1.596797e-03)*S15+7.761004e-03*S16+1.268002e-02*S17+(-3.731418e-02)*S18+(-1.998315e-02)*S19'
.param V15_part3='V15_part2+(-1.071702e-02)*S20+(-7.902277e-02)*S21+9.480940e+00*S22+(-3.343177e-02)*S23+(-1.254659e-01)*S24+9.333344e+00*S25+(-4.606306e-02)*S26+(-1.494471e-01)*S27+9.512996e+00*S28+5.291383e+00*S29'
.param V15_part4='V15_part3+1.428567e-01*S30+4.681752e+00*S31+8.456941e-02*S32+2.451497e-02*S33+(-1.384403e-01)*S34+3.432797e-02*S35+(-1.206305e-02)*S36+1.400354e+01*S37+1.109057e-03*S38+(-6.837968e-02)*S39'
.param V15_part5='V15_part4+4.598152e+01*S40+8.663230e+00*S41+(-1.539665e-01)*S42+(-2.309362e-01)*S43+1.320601e+01*S44+3.722054e+00*S45+1.805795e+00*S46+9.795171e-02*S47+3.877803e-03*S48+(-1.604372e-01)*S49'
.param V15_part6='V15_part5+3.107695e-02*S50+2.297042e+01*S51+(-2.040984e-01)*S52+(-1.820049e-02)*S53+(-1.381931e-01)*S54+(-2.465159e-01)*S55+(-5.852235e-02)*S56+(-2.027845e-01)*S57+(-3.209722e-01)*S58+(-8.621312e-02)*S59'
.param V15_part7='V15_part6+1.377014e-01*S60+3.732238e+00*S61+3.539534e+00*S62+2.999359e-02*S63+7.458921e+00*S64+5.155017e+00*S65+(-2.758739e-02)*S66+7.819977e+00*S67+5.830446e+00*S68+7.388779e+00*S69'
.param V15_part8='V15_part7+6.770417e+00*S70+7.714339e+00*S71+2.836642e+01*S72+(-6.080416e-01)*S73+(-3.651930e-02)*S74+3.879319e+00*S75+5.948164e-02*S76+2.509082e+00*S77+3.955433e-03*S78+3.606553e-02*S79'
.param V15_part9='V15_part8+4.471916e-02*S80+(-5.174150e-02)*S81+(-5.390162e-02)*S82+(-7.918318e-03)*S83+(-1.656362e-01)*S84+8.143305e+00*S85+(-2.865023e-02)*S86+(-2.198274e-01)*S87+(-1.060705e-01)*S88+8.710630e+00*S89'
.param V15_part10='V15_part9+1.565879e-01*S90+3.918976e+00*S91+1.883429e-01*S92+4.680227e-02*S93+7.643699e+00*S94+8.428823e-02*S95+2.424323e+01*S96+(-4.131734e-01)*S97+(-5.945770e-02)*S98+(-2.011268e-01)*S99'
.param V15_part11='V15_part10+(-3.569734e-01)*S100+2.918127e-02*S101+(-3.652189e-01)*S102+(-4.094375e-01)*S103+(-7.136226e-03)*S104+1.605778e-01*S105+3.023822e+00*S106+1.268336e+00*S107+1.487918e-02*S108+6.987428e+00*S109'
.param V15_part12='V15_part11+6.262466e-02*S110+(-2.074592e-01)*S111+(-3.760264e-01)*S112+(-9.136267e-02)*S113+(-6.613200e-01)*S114+(-4.548570e-01)*S115+(-5.170000e-02)*S116+(-5.751004e-01)*S117+(-5.259146e-01)*S118+2.921876e+00*S119'
.param V15_part13='V15_part12+1.912040e-01*S120+(-3.399225e-02)*S121+1.769346e-01*S122+1.605013e-02*S123+(-1.790676e-01)*S124+2.427430e-04*S125+(-2.388670e-01)*S126+(-5.267159e-01)*S127+7.265763e-03*S128+(-4.542933e-01)*S129'
.param V15_part14='V15_part13+(-6.105467e-01)*S130+(-1.277289e-01)*S131+2.869420e+01*S132+(-5.533608e-01)*S133+(-2.845656e-01)*S134+7.796887e-02*S135+3.405721e+00*S136+2.096022e-03*S137+(-2.526542e-02)*S138+(-1.657828e-01)*S139'
.param V15_part15='V15_part14+1.269755e+00*S140+(-9.880981e-02)*S141+(-4.363038e-01)*S142+1.987106e-01*S143+(-2.050993e-01)*S144+(-3.983697e-01)*S145+(-9.320537e-02)*S146+2.403018e+01*S147+1.536727e+01*S148+6.002189e+00*S149'
.param V15_part16='V15_part15+5.405106e-02*S150+4.534040e-02*S151+(-7.739171e-01)*S152+(-1.333381e-01)*S153+(-5.507945e+01)*S154+(-8.442802e+01)*S155+1.328916e+01*S156+3.041535e+00*S157+1.011317e+00*S158+(-6.826184e-01)*S159'
.param V15_part17='V15_part16+(-3.390261e-01)*S160+(-2.137389e-01)*S161+2.575873e+01*S162+7.093396e+00*S163+(-5.721301e-01)*S164+4.820757e+00*S165+8.494954e+00*S166+1.184657e+00*S167+9.289111e+00*S168+(-2.945865e-02)*S169'
.param V15_part18='V15_part17+2.352513e-01*S170+(-4.855261e-01)*S171+(-2.321198e-01)*S172+8.638876e-02*S173+(-8.991533e-01)*S174+(-3.121829e-01)*S175+2.798325e-01*S176+2.145961e+01*S177+(-3.676232e-01)*S178+1.056158e-01*S179'
.param V15_part19='V15_part18+1.857044e-01*S180+(-1.254035e+01)*S181+(-1.402104e+02)*S182+3.935035e+03*S183+(-5.646097e+02)*S184+2.265261e-01*S185+(-5.794856e-01)*S186+(-8.329267e+02)*S187+(-9.135790e+01)*S188+(-8.237353e-01)*S189'
.param V15_part20='V15_part19+(-2.907230e-01)*S190+(-2.200539e+02)*S191+(-1.257392e+00)*S192+5.933075e+00*S193+4.499554e-01*S194+9.702954e-02*S195+7.898155e-02*S196+(-1.196162e+00)*S197+4.995594e+00*S198+(-2.021699e-01)*S199'
.param V15_part21='V15_part20+8.594138e-02*S200+(-4.081818e-01)*S201+(-4.906258e-01)*S202+1.417826e+00*S203+(-5.386008e-01)*S204+(-1.531620e+03)*S205+9.593860e-01*S206+2.510387e+01*S207+(-3.875233e-01)*S208+(-3.586573e-01)*S209'
.param V15_part22='V15_part21+3.479574e+00*S210+1.619606e-01*S211+4.840561e-01*S212+(-2.462397e-01)*S213+5.617459e-02*S214+4.037255e-01*S215+(-5.907735e-01)*S216+(-1.290101e-01)*S217+4.108637e-01*S218+(-1.044811e+00)*S219'
.param V15_part23='V15_part22+(-3.645328e-01)*S220+1.417124e-02*S221+(-4.620483e+00)*S222+7.380506e-02*S223+5.195926e-02*S224+(-1.307880e+00)*S225+1.415758e+01*S226+(-5.311490e+00)*S227+7.358498e-01*S228+7.217955e-01*S229'
.param V15_part24='V15_part23+8.247447e-01*S230+(-7.686471e-01)*S231+(-1.000000e+04)*S232+1.819016e+00*S233+(-1.098847e+00)*S234+(-2.625732e-01)*S235+2.811742e+01*S236+3.864325e+00*S237+(-2.275056e+00)*S238+4.738800e+01*S239'
.param V15_part25='V15_part24+3.533317e-01*S240+1.010459e+01*S241+1.605435e+02*S242+(-1.590738e-01)*S243+(-5.097296e-01)*S244+2.677633e-01*S245+6.744192e+00*S246+(-1.131900e-01)*S247+3.182853e-01*S248+(-4.602546e-01)*S249'
.param V15_part26='V15_part25+(-1.990923e-01)*S250+5.531254e-01*S251+2.050320e+01*S252+(-8.541716e+01)*S253+(-5.956471e-01)*S254+4.212350e-01*S255+1.274878e-01*S256+9.393056e+00*S257+(-3.511349e-01)*S258+(-3.857340e+02)*S259'
.param V15_part27='V15_part26+1.363237e+01*S260+3.080868e+00*S261+1.573588e+00*S262+1.350945e+00*S263+(-6.240376e+03)*S264+1.790710e+00*S265+2.546829e+01*S266+(-1.105143e+00)*S267+(-6.675089e+02)*S268+3.206312e+01*S269'
.param V15_part28='V15_part27+4.545885e-01*S270+(-5.732687e+00)*S271+(-1.555798e-01)*S272+(-6.600180e+00)*S273+(-7.799903e+00)*S274+1.866608e+00*S275+5.882568e+00*S276+(-1.102514e+01)*S277+2.195953e+00*S278+(-2.782261e+00)*S279'
.param V15_part29='V15_part28+2.409889e-02*S280+2.421862e+00*S281+(-3.118237e+00)*S282+(-5.946288e-01)*S283+2.933081e-01*S284+4.481112e-01*S285+1.376035e-01*S286+2.553364e+00*S287+(-1.362269e-01)*S288+1.073091e+00*S289'
.param V15_part30='V15_part29+2.326641e+00*S290+6.944915e+00*S291+(-1.075393e+01)*S292+8.204222e-01*S293+(-1.529989e+00)*S294+(-3.679957e-01)*S295+1.865749e+00*S296+(-7.243789e-01)*S297+(-5.260532e-01)*S298+5.532800e-01*S299'
.param V15_part31='V15_part30+3.371327e-01*S300+(-4.301786e+00)*S301+1.049671e+01*S302+(-4.809645e-02)*S303+1.119547e+00*S304+(-1.692806e+00)*S305+(-6.399063e-01)*S306+(-8.512943e+00)*S307+6.317234e-01*S308+(-1.347748e+00)*S309'
.param V15='V15_part31+(-2.405852e-01)*S310+4.718785e-01*S311+(-1.976382e+00)*S312+(-4.531700e-01)*S313+2.542618e-01*S314'
.param V16_part1='1.832473e-01*S0+1.090944e-01*S1+7.649246e-02*S2+2.286507e+00*S3+1.129783e-01*S4+(-6.445284e-01)*S5+(-5.980824e-01)*S6+(-4.917140e-01)*S7+8.816334e-02*S8+1.549667e-01*S9'
.param V16_part2='V16_part1+(-9.934478e-01)*S10+9.378450e-02*S11+1.561899e-01*S12+1.356812e-01*S13+9.318585e-02*S14+2.872658e-01*S15+1.725145e-01*S16+1.137590e-01*S17+2.427922e-01*S18+1.619341e-01*S19'
.param V16_part3='V16_part2+1.228733e-01*S20+2.590514e-01*S21+(-4.146893e+00)*S22+1.291247e-01*S23+2.612648e-01*S24+(-4.322085e+00)*S25+1.192709e-01*S26+2.470316e-01*S27+(-3.625626e+00)*S28+(-2.436908e+00)*S29'
.param V16_part4='V16_part3+6.859252e-01*S30+3.357554e+01*S31+2.261057e-01*S32+6.701222e-01*S33+3.015084e-01*S34+2.720022e-01*S35+5.494689e-01*S36+(-8.320869e+00)*S37+2.456498e-01*S38+5.101552e-01*S39'
.param V16_part5='V16_part4+(-3.236697e+01)*S40+(-7.424129e+00)*S41+5.195755e-01*S42+2.638420e-01*S43+(-9.523010e+00)*S44+(-5.657352e+00)*S45+(-4.306777e+00)*S46+3.182636e-01*S47+7.888031e-01*S48+4.059637e-01*S49'
.param V16_part6='V16_part5+3.385928e-01*S50+(-5.091650e+00)*S51+3.907538e-01*S52+2.819480e-01*S53+6.643883e-01*S54+3.230375e-01*S55+2.308010e-01*S56+6.020878e-01*S57+2.834248e-01*S58+2.268780e-01*S59'
.param V16_part7='V16_part6+9.247112e-01*S60+(-7.250355e+00)*S61+(-5.962157e+00)*S62+8.462817e-01*S63+(-1.004384e+01)*S64+(-6.680540e+00)*S65+7.074438e-01*S66+(-9.233473e+00)*S67+(-6.374725e+00)*S68+(-6.664830e+00)*S69'
.param V16_part8='V16_part7+(-7.883550e+00)*S70+(-7.356697e+00)*S71+(-1.571357e+01)*S72+5.719259e-01*S73+2.744562e-01*S74+(-5.796873e+00)*S75+8.308029e-02*S76+(-4.182157e+00)*S77+2.177778e-01*S78+1.051641e-01*S79'
.param V16_part9='V16_part8+9.583146e-02*S80+2.658147e-01*S81+2.372480e-01*S82+1.651932e-01*S83+3.591854e-01*S84+(-5.291615e+00)*S85+1.586363e-01*S86+3.614505e-01*S87+2.171059e-01*S88+(-4.837258e+00)*S89'
.param V16_part10='V16_part9+1.489735e+00*S90+(-7.377648e+00)*S91+4.629891e-01*S92+1.197041e+00*S93+(-1.095864e+01)*S94+5.318207e-01*S95+(-2.773661e+01)*S96+7.523086e-01*S97+4.964830e-01*S98+8.300252e-01*S99'
.param V16_part11='V16_part10+5.088169e-01*S100+3.755826e-01*S101+8.109925e-01*S102+4.636817e-01*S103+3.432273e-01*S104+1.717062e+00*S105+(-5.111713e+00)*S106+(-6.342208e-01)*S107+1.256424e+00*S108+(-8.983787e+00)*S109'
.param V16_part12='V16_part11+5.436092e-01*S110+1.081348e+00*S111+6.533466e-01*S112+5.168456e-01*S113+1.513424e+00*S114+5.024973e-01*S115+5.297874e-01*S116+1.043428e+00*S117+5.874582e-01*S118+(-1.069772e+00)*S119'
.param V16_part13='V16_part12+1.724156e+00*S120+7.425524e-01*S121+6.492376e-01*S122+1.340530e+00*S123+4.948514e-01*S124+5.053323e-01*S125+1.168630e+00*S126+1.028226e+00*S127+1.629431e-01*S128+1.110967e+00*S129'
.param V16_part14='V16_part13+1.035693e+00*S130+1.337932e-01*S131+(-1.900452e+01)*S132+6.687922e-01*S133+4.297177e-01*S134+1.462258e+00*S135+(-7.238266e+00)*S136+8.301616e-01*S137+1.111367e+00*S138+6.347716e-01*S139'
.param V16_part15='V16_part14+(-7.227341e-01)*S140+9.524762e-01*S141+7.402136e-01*S142+7.578549e-02*S143+8.318700e-01*S144+4.356988e-01*S145+3.778324e-01*S146+(-1.907959e+01)*S147+(-1.242134e+01)*S148+(-4.142799e+00)*S149'
.param V16_part16='V16_part15+2.339659e+00*S150+2.233318e+00*S151+(-4.872062e+00)*S152+1.661091e+00*S153+6.216675e+01*S154+(-3.043473e+01)*S155+(-1.285271e+01)*S156+(-1.310816e+01)*S157+(-4.876843e+00)*S158+1.637036e+00*S159'
.param V16_part17='V16_part16+9.102240e-01*S160+4.125509e-01*S161+(-1.694618e+01)*S162+(-1.546031e+01)*S163+5.287596e-01*S164+(-3.806499e+00)*S165+(-5.732257e+00)*S166+4.473631e-01*S167+(-1.189634e+01)*S168+3.847094e-01*S169'
.param V16_part18='V16_part17+(-1.581428e-02)*S170+1.769793e+00*S171+9.261076e-01*S172+2.281742e-01*S173+1.974429e+00*S174+1.036659e+00*S175+2.742334e-01*S176+(-1.364036e+01)*S177+1.035428e+00*S178+(-3.258249e+00)*S179'
.param V16_part19='V16_part18+2.022038e+00*S180+1.872801e+01*S181+1.204233e+01*S182+(-3.459082e+03)*S183+6.704372e+02*S184+2.504136e-01*S185+2.042449e+00*S186+1.186782e+02*S187+(-4.774153e+01)*S188+1.921466e+00*S189'
.param V16_part20='V16_part19+5.019082e-01*S190+(-3.818492e+01)*S191+2.071905e+00*S192+(-2.048578e+01)*S193+1.273781e+00*S194+2.316906e+00*S195+4.421402e-01*S196+(-6.605326e+00)*S197+(-5.880312e+00)*S198+5.428141e-01*S199'
.param V16_part21='V16_part20+(-1.023812e+01)*S200+1.460221e+00*S201+1.299836e+00*S202+(-8.834844e+00)*S203+1.294375e+00*S204+(-2.849084e+02)*S205+(-7.373912e+00)*S206+(-1.558063e+01)*S207+5.164825e-01*S208+2.507905e+00*S209'
.param V16_part22='V16_part21+1.300005e+01*S210+3.100613e-01*S211+(-2.362199e-01)*S212+2.823709e+00*S213+3.745810e-01*S214+(-8.038762e-04)*S215+2.376673e+00*S216+8.821335e-01*S217+9.110111e-02*S218+2.447371e+00*S219'
.param V16_part23='V16_part22+7.168541e-01*S220+3.157173e-02*S221+1.916714e+00*S222+2.025728e-01*S223+1.278999e-01*S224+5.295271e+01*S225+(-1.393855e+00)*S226+(-5.932757e+00)*S227+1.402152e+00*S228+(-5.490691e+00)*S229'
.param V16_part24='V16_part23+(-3.405800e+00)*S230+2.751470e+00*S231+9.694385e+03*S232+1.272589e+00*S233+2.598728e+00*S234+1.394443e+00*S235+(-4.937446e+00)*S236+3.709284e+00*S237+(-5.113563e+00)*S238+(-2.730887e+00)*S239'
.param V16_part25='V16_part24+1.844704e+00*S240+(-1.003984e+02)*S241+(-1.131451e+02)*S242+2.956530e+00*S243+(-8.622231e-01)*S244+(-3.614805e+00)*S245+(-4.959331e+00)*S246+1.451100e+00*S247+8.309653e-02*S248+2.501950e+00*S249'
.param V16_part26='V16_part25+1.370336e+00*S250+(-5.067382e-01)*S251+(-1.295210e+01)*S252+4.706228e+01*S253+(-3.584900e-01)*S254+9.823792e-01*S255+2.922854e-01*S256+(-7.662401e+00)*S257+2.345441e+00*S258+5.478347e+02*S259'
.param V16_part27='V16_part26+(-9.094436e+00)*S260+(-8.342463e+00)*S261+(-1.473403e+01)*S262+1.108142e+00*S263+5.230196e+02*S264+(-1.971217e+01)*S265+(-6.983446e+00)*S266+1.917953e+00*S267+1.819993e+01*S268+(-8.340857e+00)*S269'
.param V16_part28='V16_part27+3.147515e+00*S270+7.509707e+00*S271+(-7.396774e-01)*S272+2.850654e+01*S273+6.538751e+00*S274+2.249715e+00*S275+(-8.534944e+00)*S276+1.043481e+01*S277+2.083475e+00*S278+3.392890e+00*S279'
.param V16_part29='V16_part28+2.045739e+00*S280+2.189793e+00*S281+3.328827e+00*S282+1.081626e+00*S283+6.592623e-01*S284+1.943292e+00*S285+(-8.459918e-01)*S286+2.075344e+00*S287+3.655332e+00*S288+1.803429e+00*S289'
.param V16_part30='V16_part29+2.094983e+00*S290+(-8.710154e+00)*S291+1.366070e+01*S292+7.522005e-01*S293+3.990248e+00*S294+2.358746e+00*S295+1.524429e+00*S296+2.047628e+00*S297+1.930456e+00*S298+9.517986e-01*S299'
.param V16_part31='V16_part30+3.024045e+00*S300+6.539084e+00*S301+(-5.115502e+00)*S302+2.877844e+00*S303+1.921290e+00*S304+(-6.964648e+00)*S305+3.182703e+00*S306+1.270166e+01*S307+(-3.382998e-01)*S308+3.412497e+00*S309'
.param V16='V16_part31+1.540832e+00*S310+2.712781e-02*S311+3.521058e+00*S312+1.561432e+00*S313+6.091731e-01*S314'
.param V17_part1='2.620438e-02*S0+2.747999e-02*S1+2.935270e-02*S2+2.333155e+00*S3+3.758996e-02*S4+2.669498e+00*S5+2.439613e+00*S6+1.992380e+00*S7+5.332944e-02*S8+5.353943e-02*S9'
.param V17_part2='V17_part1+4.746071e-01*S10+6.720070e-02*S11+6.146624e-02*S12+7.109068e-02*S13+6.939794e-02*S14+3.333484e-02*S15+3.499386e-02*S16+3.679524e-02*S17+4.616957e-02*S18+4.903709e-02*S19'
.param V17_part3='V17_part2+5.396887e-02*S20+5.845310e-02*S21+9.250595e-01*S22+7.071734e-02*S23+7.308976e-02*S24+8.755625e-01*S25+8.216268e-02*S26+8.551972e-02*S27+5.399717e-01*S28+4.163665e-01*S29'
.param V17_part4='V17_part3+4.867872e-02*S30+4.256699e+00*S31+6.179201e-02*S32+7.127310e-02*S33+1.777775e-01*S34+8.336665e-02*S35+9.136771e-02*S36+2.950094e+00*S37+1.051367e-01*S38+1.096475e-01*S39'
.param V17_part5='V17_part4+6.244458e+00*S40+3.240566e+00*S41+1.315653e-01*S42+2.382777e-01*S43+4.007594e+00*S44+5.076529e-01*S45+1.017404e+00*S46+6.439664e-02*S47+8.229676e-02*S48+1.956270e-01*S49'
.param V17_part6='V17_part5+9.627455e-02*S50+4.835655e-01*S51+2.218601e-01*S52+1.340744e-01*S53+1.281259e-01*S54+2.523769e-01*S55+1.803279e-01*S56+1.550531e-01*S57+3.000344e-01*S58+1.958268e-01*S59'
.param V17_part7='V17_part6+6.002342e-02*S60+1.044599e+00*S61+7.132172e-01*S62+9.056541e-02*S63+1.586921e+00*S64+1.686323e+00*S65+1.167928e-01*S66+2.273625e+00*S67+1.896094e+00*S68+1.092906e+00*S69'
.param V17_part8='V17_part7+2.992790e+00*S70+2.450309e+00*S71+9.260889e-01*S72+4.047434e-01*S73+2.609534e-01*S74+3.355008e-01*S75+3.894173e-02*S76+7.443896e-01*S77+5.476402e-02*S78+5.746234e-02*S79'
.param V17_part9='V17_part8+5.473684e-02*S80+6.930036e-02*S81+8.052741e-02*S82+7.844544e-02*S83+9.328798e-02*S84+9.520078e-01*S85+9.480127e-02*S86+1.105246e-01*S87+1.134784e-01*S88+1.381087e+00*S89'
.param V17_part10='V17_part9+6.754444e-02*S90+1.045753e+00*S91+1.145356e-01*S92+9.974794e-02*S93+2.200376e+00*S94+1.450551e-01*S95+3.839974e+00*S96+4.046261e-01*S97+3.310676e-01*S98+1.957821e-01*S99'
.param V17_part11='V17_part10+3.523111e-01*S100+2.000510e-01*S101+2.451406e-01*S102+3.910016e-01*S103+2.274873e-01*S104+7.172651e-02*S105+9.600888e-01*S106+7.114472e-02*S107+1.169036e-01*S108+1.854201e+00*S109'
.param V17_part12='V17_part11+2.689348e-01*S110+1.815111e-01*S111+3.534694e-01*S112+3.560745e-01*S113+2.823887e-01*S114+4.285465e-01*S115+2.810471e-01*S116+2.767668e-01*S117+4.362575e-01*S118+9.259030e-01*S119'
.param V17_part13='V17_part12+8.051435e-02*S120+2.589232e-01*S121+3.161608e-01*S122+1.343594e-01*S123+3.462657e-01*S124+4.967864e-01*S125+2.066197e-01*S126+4.741487e-01*S127+5.760322e-01*S128+2.671651e-01*S129'
.param V17_part14='V17_part13+5.138939e-01*S130+6.670454e-01*S131+4.148630e+00*S132+4.691913e-01*S133+5.491896e-01*S134+6.626309e-02*S135+1.012534e+00*S136+2.839659e-01*S137+1.004443e-01*S138+2.249042e-01*S139'
.param V17_part15='V17_part14+4.560032e-01*S140+1.314435e-01*S141+3.548988e-01*S142+1.360548e-01*S143+1.735076e-01*S144+3.591777e-01*S145+2.178399e-01*S146+4.295034e+00*S147+3.524141e+00*S148+1.628413e+00*S149'
.param V17_part16='V17_part15+1.326933e-01*S150+4.595846e-01*S151+3.375752e+00*S152+1.884857e-01*S153+9.643534e+01*S154+1.348076e+02*S155+2.733730e+00*S156+6.952666e+00*S157+3.473236e+00*S158+3.092735e-01*S159'
.param V17_part17='V17_part16+3.657707e-01*S160+7.845934e-01*S161+3.927371e+00*S162+1.028835e+01*S163+1.098688e+00*S164+1.226577e+00*S165+4.990588e+00*S166+(-1.622123e-01)*S167+2.463225e+00*S168+3.409324e-01*S169'
.param V17_part18='V17_part17+3.204130e-01*S170+2.709822e-01*S171+3.506621e-01*S172+4.058420e-01*S173+3.405807e-01*S174+3.629148e-01*S175+2.021197e-01*S176+3.937179e+00*S177+3.794757e-01*S178+4.419749e+00*S179'
.param V17_part19='V17_part18+1.628109e-01*S180+2.969686e+01*S181+1.939863e+02*S182+(-8.292530e+01)*S183+6.302502e+02*S184+3.812902e-01*S185+2.904957e-01*S186+1.366105e+03*S187+1.683968e+02*S188+3.559958e-01*S189'
.param V17_part20='V17_part19+5.634992e-01*S190+3.409569e+02*S191+4.395905e-01*S192+1.528963e+01*S193+7.232854e-02*S194+9.711406e-02*S195+2.467508e-01*S196+4.717623e+00*S197+2.525571e+00*S198+3.853522e-01*S199'
.param V17_part21='V17_part20+6.195083e+00*S200+2.394650e-01*S201+5.728922e-01*S202+5.543638e+00*S203+2.933360e-01*S204+5.294947e+03*S205+6.953704e+00*S206+4.020997e+00*S207+5.118181e-01*S208+2.281897e-01*S209'
.param V17_part22='V17_part21+1.461306e+01*S210+3.623428e-01*S211+2.420139e-01*S212+2.482285e-01*S213+4.010600e-01*S214+3.323752e-01*S215+3.195177e-01*S216+4.554607e-01*S217+3.529338e-01*S218+4.077571e-01*S219'
.param V17_part23='V17_part22+6.457594e-01*S220+2.022585e+00*S221+2.630454e+00*S222+1.210816e+00*S223+1.845737e+00*S224+2.323026e+01*S225+6.003766e+00*S226+9.339605e+00*S227+2.220105e-01*S228+3.624882e+00*S229'
.param V17_part24='V17_part23+3.039898e+00*S230+3.418360e-01*S231+7.508407e+03*S232+(-2.910679e-01)*S233+4.396250e-01*S234+3.923864e-01*S235+(-9.271712e+00)*S236+8.094876e-01*S237+9.897703e+00*S238+(-1.123526e+01)*S239'
.param V17_part25='V17_part24+1.973279e-01*S240+5.692433e+01*S241+(-3.256778e+01)*S242+2.666394e-01*S243+2.292567e+00*S244+4.073227e+00*S245+2.230069e+00*S246+3.653336e-01*S247+1.896649e+00*S248+4.443050e-01*S249'
.param V17_part26='V17_part25+4.042671e-01*S250+2.263164e+00*S251+3.737226e+00*S252+3.397399e+02*S253+4.036058e+00*S254+1.367525e-01*S255+3.186603e-01*S256+(-2.593471e+00)*S257+3.060141e-01*S258+3.941366e+02*S259'
.param V17_part27='V17_part26+(-3.591662e+00)*S260+3.849106e+00*S261+1.022143e+01*S262+(-1.398889e-01)*S263+3.383699e+03*S264+1.574771e+01*S265+(-7.137633e+00)*S266+4.637493e-01*S267+9.969044e+03*S268+(-8.605418e+00)*S269'
.param V17_part28='V17_part27+2.195374e-01*S270+5.714727e+00*S271+2.575231e+00*S272+3.493662e+00*S273+3.579072e+01*S274+(-6.754460e-01)*S275+3.219803e+00*S276+1.491470e+01*S277+(-6.081260e-01)*S278+1.477314e+00*S279'
.param V17_part29='V17_part28+2.671343e-01*S280+(-5.464196e-01)*S281+1.625944e+00*S282+8.333825e-01*S283+2.777164e+00*S284+2.275985e-01*S285+2.110450e+00*S286+(-8.535063e-01)*S287+3.138174e-01*S288+4.668758e-02*S289'
.param V17_part30='V17_part29+(-6.193834e-01)*S290+2.842321e+00*S291+1.139353e+01*S292+9.014580e-01*S293+5.494132e-01*S294+4.466038e-01*S295+(-1.997611e-02)*S296+6.411087e-01*S297+4.905155e-01*S298+1.105751e+00*S299'
.param V17_part31='V17_part30+2.267251e-01*S300+4.852990e+00*S301+(-3.761889e+00)*S302+2.760730e-01*S303+8.963494e-04*S304+8.284666e+00*S305+3.727374e-01*S306+5.894292e+00*S307+1.739304e+00*S308+4.982381e-01*S309'
.param V17='V17_part31+4.072824e-01*S310+1.902526e+00*S311+6.033474e-01*S312+4.717541e-01*S313+2.027149e+00*S314'
.param V18_part1='4.737861e-02*S0+2.992495e-02*S1+2.203610e-02*S2+4.897422e+00*S3+2.662663e-02*S4+(-5.586188e-02)*S5+4.500040e+00*S6+1.549933e+00*S7+1.898856e-02*S8+3.832537e-02*S9'
.param V18_part2='V18_part1+3.711043e-01*S10+1.801750e-02*S11+4.012668e-02*S12+2.364691e-02*S13+2.536652e-02*S14+5.267235e-02*S15+3.129681e-02*S16+2.147359e-02*S17+4.384321e-02*S18+2.873813e-02*S19'
.param V18_part3='V18_part2+2.034018e-02*S20+4.387697e-02*S21+1.123839e+00*S22+1.954383e-02*S23+4.011855e-02*S24+7.208122e-01*S25+1.942898e-02*S26+4.132600e-02*S27+1.600945e+00*S28+9.642637e-01*S29'
.param V18_part4='V18_part3+5.011322e-03*S30+(-5.490686e+01)*S31+(-5.833301e-04)*S32+3.678805e-03*S33+8.024612e-03*S34+(-2.673613e-03)*S35+7.420547e-03*S36+7.920333e-01*S37+(-5.290897e-03)*S38+1.177048e-02*S39'
.param V18_part5='V18_part4+6.306399e+00*S40+9.204231e-01*S41+7.231260e-03*S42+(-4.385779e-03)*S43+7.135451e-01*S44+1.054455e+00*S45+8.072522e-01*S46+2.155974e-03*S47+(-5.726430e-05)*S48+6.776643e-03*S49'
.param V18_part6='V18_part5+(-9.721585e-03)*S50+8.049697e+00*S51+4.400950e-03*S52+(-1.473589e-02)*S53+1.029142e-02*S54+(-7.888471e-03)*S55+(-2.413899e-02)*S56+(-2.764820e-03)*S57+(-3.862641e-02)*S58+(-3.563127e-02)*S59'
.param V18_part7='V18_part6+8.477269e-03*S60+9.948159e-01*S61+5.779512e-01*S62+8.323307e-03*S63+9.311215e-01*S64+9.170994e-01*S65+1.558277e-02*S66+1.138465e+00*S67+5.653797e-01*S68+8.520772e-01*S69'
.param V18_part8='V18_part7+5.029851e-01*S70+3.150572e-01*S71+5.561512e+00*S72+(-9.648245e-02)*S73+(-2.361241e-02)*S74+1.366711e+00*S75+2.506805e-02*S76+7.496815e-01*S77+4.002920e-02*S78+2.475491e-02*S79'
.param V18_part9='V18_part8+2.335672e-02*S80+3.670210e-02*S81+2.600370e-02*S82+2.080754e-02*S83+3.817102e-02*S84+1.691704e+00*S85+2.113031e-02*S86+3.682391e-02*S87+2.633832e-02*S88+1.355822e+00*S89'
.param V18_part10='V18_part9+(-7.140854e-03)*S90+7.163175e-01*S91+(-3.908054e-02)*S92+(-1.629468e-02)*S93+5.871609e-01*S94+(-6.711432e-02)*S95+3.445432e+00*S96+(-2.303488e-01)*S97+(-1.932387e-01)*S98+(-4.109410e-02)*S99'
.param V18_part11='V18_part10+(-7.528941e-02)*S100+(-9.639409e-02)*S101+(-4.184966e-02)*S102+(-7.766702e-02)*S103+(-9.033748e-02)*S104+(-2.192248e-02)*S105+6.809565e-01*S106+6.729128e-02*S107+(-3.913719e-02)*S108+3.924221e-01*S109'
.param V18_part12='V18_part11+(-1.010059e-01)*S110+(-5.068321e-02)*S111+(-6.999035e-02)*S112+(-1.585252e-01)*S113+(-1.296258e-01)*S114+(-5.817355e-02)*S115+(-1.584834e-01)*S116+(-4.962422e-02)*S117+(-4.463444e-02)*S118+5.120209e-01*S119'
.param V18_part13='V18_part12+2.731091e-03*S120+(-2.843390e-02)*S121+(-1.299781e-01)*S122+(-2.906108e-02)*S123+(-3.511337e-02)*S124+(-2.673117e-01)*S125+(-3.580770e-02)*S126+(-2.645357e-01)*S127+(-2.626657e-01)*S128+(-4.372105e-02)*S129'
.param V18_part14='V18_part13+(-3.131705e-01)*S130+(-1.950236e-01)*S131+5.626068e+00*S132+(-9.403623e-02)*S133+(-1.076709e-01)*S134+(-2.292692e-03)*S135+1.086874e+00*S136+(-2.089060e-01)*S137+(-2.031006e-02)*S138+(-1.468950e-02)*S139'
.param V18_part15='V18_part14+3.209822e-01*S140+(-7.026975e-03)*S141+(-1.547881e-01)*S142+2.432982e-02*S143+(-7.903009e-03)*S144+(-3.390858e-02)*S145+(-3.483273e-02)*S146+3.912636e+00*S147+1.107041e+00*S148+7.085978e-01*S149'
.param V18_part16='V18_part15+(-3.649006e-02)*S150+(-6.339317e-02)*S151+(-3.738662e-01)*S152+(-4.871843e-02)*S153+(-7.269456e-01)*S154+2.412321e+00*S155+3.706194e+00*S156+1.280405e-02*S157+(-3.294300e-01)*S158+(-6.220496e-02)*S159'
.param V18_part17='V18_part16+2.215461e-02*S160+(-1.369617e-01)*S161+5.444142e+00*S162+(-7.132847e-02)*S163+(-1.932673e-01)*S164+(-5.300091e-02)*S165+(-9.588941e-02)*S166+(-1.769604e-02)*S167+2.281391e+00*S168+6.560624e-03*S169'
.param V18_part18='V18_part17+(-2.714518e-04)*S170+(-5.029562e-02)*S171+1.347019e-02*S172+1.346787e-02*S173+(-7.789030e-02)*S174+5.886349e-02*S175+1.034699e-02*S176+5.497886e+00*S177+8.402800e-02*S178+(-6.216992e-01)*S179'
.param V18_part19='V18_part18+(-7.914464e-03)*S180+(-1.819536e+00)*S181+3.562112e+00*S182+(-2.227673e+02)*S183+9.406415e+01*S184+1.517211e-02*S185+(-6.577088e-02)*S186+2.404895e+02*S187+2.171809e+00*S188+(-9.455123e-02)*S189'
.param V18_part20='V18_part19+(-6.414565e-02)*S190+6.038633e+00*S191+(-1.091253e-01)*S192+(-7.188155e-01)*S193+3.272283e-02*S194+(-7.801530e-02)*S195+2.862832e-02*S196+(-3.023967e-01)*S197+(-2.351837e-01)*S198+2.928608e-02*S199'
.param V18_part21='V18_part20+(-3.832088e-01)*S200+(-4.312392e-02)*S201+(-2.944569e-01)*S202+(-3.161623e-01)*S203+(-3.964204e-02)*S204+3.268806e+01*S205+(-2.578386e-03)*S206+6.575038e+00*S207+1.102540e-02*S208+8.999096e-03*S209'
.param V18_part22='V18_part21+(-2.966689e-01)*S210+3.892092e-03*S211+(-2.644933e-02)*S212+(-4.689458e-02)*S213+(-1.882444e-03)*S214+(-2.553764e-02)*S215+(-1.013035e-01)*S216+(-4.993449e-02)*S217+(-2.873200e-02)*S218+(-1.297335e-01)*S219'
.param V18_part23='V18_part22+(-3.239337e-03)*S220+(-1.299854e-01)*S221+(-2.295381e-01)*S222+(-5.821669e-02)*S223+(-1.816872e-01)*S224+(-1.657556e+00)*S225+(-3.447721e-01)*S226+(-3.584601e-02)*S227+5.225042e-02*S228+(-1.442364e-01)*S229'
.param V18_part24='V18_part23+(-9.094887e-02)*S230+(-6.747406e-02)*S231+1.981963e+03*S232+(-5.879476e-02)*S233+(-1.599521e-01)*S234+4.287270e-02*S235+(-1.875732e-01)*S236+1.185436e+00*S237+7.170461e-01*S238+(-5.738113e-01)*S239'
.param V18_part25='V18_part24+3.092107e-02*S240+3.349123e+00*S241+(-2.208897e+00)*S242+6.908079e-02*S243+9.905935e-02*S244+(-2.953075e-01)*S245+1.099913e-01*S246+2.775280e-02*S247+3.061376e-02*S248+(-1.360509e-01)*S249'
.param V18_part26='V18_part25+5.595113e-02*S250+(-1.778761e-02)*S251+4.783822e+00*S252+9.524717e-01*S253+(-6.160952e-02)*S254+4.541337e-02*S255+1.692498e-02*S256+(-3.914870e-01)*S257+(-1.218075e-01)*S258+3.081745e+01*S259'
.param V18_part27='V18_part26+(-4.317847e-01)*S260+(-5.358050e-01)*S261+3.183927e-01*S262+2.915634e-02*S263+6.896959e+02*S264+(-1.302873e+00)*S265+(-5.666594e-02)*S266+(-8.867922e-02)*S267+1.998502e+01*S268+(-2.400775e+00)*S269'
.param V18_part28='V18_part27+5.724807e-02*S270+(-2.758350e-02)*S271+3.553423e-02*S272+1.062980e+00*S273+1.848647e+00*S274+2.102045e-02*S275+(-2.293885e-01)*S276+(-6.854082e-01)*S277+2.004571e-02*S278+(-1.950663e-01)*S279'
.param V18_part29='V18_part28+9.961727e-03*S280+2.043179e-03*S281+(-2.623589e-01)*S282+1.108698e-02*S283+(-5.593848e-02)*S284+4.925588e-02*S285+2.581485e-02*S286+(-3.944094e-02)*S287+9.650528e-02*S288+(-1.658692e-02)*S289'
.param V18_part30='V18_part29+(-4.767970e-02)*S290+4.179402e-02*S291+2.882146e-01*S292+(-2.485446e-02)*S293+8.535708e-02*S294+2.461660e-02*S295+(-1.400511e-01)*S296+8.918600e-02*S297+5.975860e-02*S298+7.932888e-02*S299'
.param V18_part31='V18_part30+3.082466e-02*S300+(-1.660714e-01)*S301+(-2.685293e-01)*S302+6.875324e-02*S303+(-5.320057e-03)*S304+(-3.236150e-01)*S305+1.160607e-01*S306+(-1.734317e-01)*S307+(-1.375896e-02)*S308+5.524325e-02*S309'
.param V18='V18_part31+3.756324e-02*S310+(-5.728155e-02)*S311+5.093821e-02*S312+4.903425e-02*S313+9.342877e-02*S314'
.param V19_part1='(-3.318527e-05)*S0+7.824283e-05*S1+4.501292e-05*S2+2.601767e-02*S3+2.049062e-04*S4+1.358592e-01*S5+5.326680e-03*S6+1.435172e-03*S7+8.996181e-07*S8+3.134896e-04*S9'
.param V19_part2='V19_part1+2.664758e-03*S10+(-2.315345e-05)*S11+3.466445e-04*S12+(-2.029640e-05)*S13+(-3.355492e-05)*S14+6.708578e-04*S15+5.695196e-04*S16+2.702124e-04*S17+6.484252e-04*S18+4.889771e-04*S19'
.param V19_part3='V19_part2+3.755768e-04*S20+7.158134e-04*S21+(-5.058178e-03)*S22+3.438863e-04*S23+7.401087e-04*S24+6.024081e-03*S25+2.928708e-04*S26+6.003180e-04*S27+5.772684e-03*S28+7.700905e-04*S29'
.param V19_part4='V19_part3+7.480599e-03*S30+3.244420e-01*S31+5.593481e-03*S32+4.319258e-03*S33+3.730820e-03*S34+4.317614e-03*S35+1.279138e-03*S36+1.152256e-01*S37+2.942880e-03*S38+(-2.162598e-03)*S39'
.param V19_part5='V19_part4+3.275668e-01*S40+(-1.617347e-02)*S41+(-5.878691e-03)*S42+6.962108e-04*S43+7.221359e-02*S44+(-1.308160e-01)*S45+8.399992e-03*S46+5.421087e-03*S47+2.055182e-03*S48+4.405697e-03*S49'
.param V19_part6='V19_part5+2.769805e-03*S50+7.622446e-01*S51+2.045207e-04*S52+1.313514e-03*S53+(-8.313382e-04)*S54+4.683063e-04*S55+4.963079e-03*S56+(-6.223539e-03)*S57+(-7.864148e-03)*S58+(-7.299094e-03)*S59'
.param V19_part7='V19_part6+8.512012e-03*S60+(-1.108354e-01)*S61+(-1.938209e-01)*S62+7.173057e-05*S63+(-1.230076e-01)*S64+(-1.590463e-01)*S65+(-3.206773e-03)*S66+1.612639e-02*S67+(-1.499673e-02)*S68+(-1.025314e-01)*S69'
.param V19_part8='V19_part7+1.931947e-02*S70+(-2.805820e-01)*S71+9.048049e-01*S72+(-2.504280e-02)*S73+(-6.281394e-03)*S74+(-5.273394e-01)*S75+(-8.859811e-03)*S76+(-4.141587e-01)*S77+(-7.782705e-03)*S78+(-6.215242e-03)*S79'
.param V19_part9='V19_part8+(-3.771415e-03)*S80+(-5.206786e-03)*S81+(-1.300798e-03)*S82+(-1.227584e-03)*S83+(-1.315464e-03)*S84+(-3.393784e-01)*S85+(-1.577443e-03)*S86+(-6.384266e-04)*S87+(-2.206172e-03)*S88+(-2.663034e-01)*S89'
.param V19_part10='V19_part9+3.129012e-02*S90+(-2.746054e-01)*S91+1.770449e-02*S92+5.186529e-03*S93+(-2.897389e-01)*S94+1.174717e-02*S95+3.046167e-02*S96+(-4.792603e-03)*S97+2.729656e-02*S98+(-1.934075e-02)*S99'
.param V19_part11='V19_part10+(-1.199462e-02)*S100+(-1.587623e-02)*S101+(-2.994635e-02)*S102+(-1.212601e-02)*S103+(-9.042924e-03)*S104+2.835456e-02*S105+(-2.540713e-01)*S106+(-8.995145e-02)*S107+3.749432e-03*S108+(-2.032968e-01)*S109'
.param V19_part12='V19_part11+2.629869e-02*S110+(-1.929787e-02)*S111+(-9.919570e-03)*S112+2.906505e-02*S113+6.239914e-02*S114+(-1.303045e-02)*S115+8.901496e-03*S116+(-1.600436e-02)*S117+(-2.068508e-02)*S118+(-1.438180e-01)*S119'
.param V19_part13='V19_part12+2.836194e-02*S120+4.111450e-03*S121+5.994859e-02*S122+4.864116e-03*S123+(-7.745710e-03)*S124+(-9.918492e-03)*S125+(-1.443487e-02)*S126+3.165735e-02*S127+(-5.500098e-03)*S128+(-2.131757e-02)*S129'
.param V19_part14='V19_part13+(-1.203642e-02)*S130+(-1.209389e-02)*S131+(-5.672080e-01)*S132+5.848276e-03*S133+7.735896e-03*S134+1.562551e-02*S135+(-3.182609e-01)*S136+8.413514e-02*S137+1.073343e-02*S138+(-7.259791e-03)*S139'
.param V19_part15='V19_part14+(-1.010211e-01)*S140+2.101430e-03*S141+(-1.484556e-02)*S142+(-1.350114e-02)*S143+4.759250e-04*S144+(-2.256610e-03)*S145+3.085622e-03*S146+(-4.471720e-01)*S147+(-1.385282e-01)*S148+(-7.943212e-02)*S149'
.param V19_part16='V19_part15+7.566578e-02*S150+3.584195e-02*S151+(-4.276100e-01)*S152+2.672979e-02*S153+(-2.171830e+01)*S154+(-2.191857e+00)*S155+(-9.412546e-01)*S156+4.993507e-01*S157+(-4.811099e-01)*S158+5.138426e-02*S159'
.param V19_part17='V19_part16+(-4.875114e-03)*S160+3.971879e-02*S161+(-9.369255e-01)*S162+5.321263e-01*S163+7.435572e-02*S164+(-6.382893e-01)*S165+(-6.257671e-01)*S166+4.868383e-02*S167+(-6.673714e-01)*S168+(-8.991422e-04)*S169'
.param V19_part18='V19_part17+(-1.592847e-02)*S170+3.000440e-02*S171+5.469859e-03*S172+5.869213e-03*S173+5.372953e-02*S174+2.332853e-02*S175+(-3.385873e-03)*S176+(-7.202682e-01)*S177+1.847904e-02*S178+(-5.786629e-02)*S179'
.param V19_part19='V19_part18+6.859348e-02*S180+(-7.746557e+00)*S181+(-2.175603e+00)*S182+1.760165e+02*S183+(-2.901962e+01)*S184+(-2.136229e-02)*S185+7.048299e-02*S186+4.299056e+00*S187+(-6.049234e+00)*S188+6.139486e-02*S189'
.param V19_part20='V19_part19+5.459381e-03*S190+(-2.898174e+00)*S191+8.095006e-02*S192+6.319431e-01*S193+(-5.858706e-02)*S194+4.498294e-02*S195+(-3.055656e-02)*S196+(-1.853173e-01)*S197+(-8.726141e-01)*S198+(-1.368059e-02)*S199'
.param V19_part21='V19_part20+(-5.073996e-01)*S200+(-2.273137e-02)*S201+4.420479e-02*S202+(-8.688953e-01)*S203+(-1.672563e-02)*S204+(-7.439876e+01)*S205+(-2.610075e-01)*S206+(-1.388554e+00)*S207+1.127629e-02*S208+(-2.357953e+00)*S209'
.param V19_part22='V19_part21+7.350080e-01*S210+4.533584e-02*S211+(-3.466297e-02)*S212+1.493265e-01*S213+2.120403e-02*S214+(-1.452958e-02)*S215+1.318558e-01*S216+1.095753e-01*S217+(-1.154339e-02)*S218+1.573488e-01*S219'
.param V19_part23='V19_part22+4.927318e-02*S220+(-1.907382e-01)*S221+(-2.994281e-01)*S222+(-3.287080e-02)*S223+(-1.384196e-01)*S224+2.898297e+00*S225+(-8.211067e-01)*S226+(-5.241012e-01)*S227+1.527963e-01*S228+4.223750e-01*S229'
.param V19_part24='V19_part23+(-6.867223e-01)*S230+1.463263e-01*S231+7.391252e+02*S232+(-2.446296e-02)*S233+1.647496e-01*S234+7.324353e-02*S235+6.109351e-03*S236+2.065726e-01*S237+4.999314e-01*S238+1.632007e+00*S239'
.param V19_part25='V19_part24+5.906696e-02*S240+9.129525e+00*S241+3.554620e+00*S242+6.556552e-02*S243+3.119712e-01*S244+(-5.146109e-01)*S245+1.319557e+00*S246+7.528767e-02*S247+(-1.925830e-01)*S248+1.479614e-01*S249'
.param V19_part26='V19_part25+8.205605e-02*S250+(-3.444592e-01)*S251+(-5.559700e-01)*S252+(-6.794883e+00)*S253+(-5.460679e-01)*S254+8.537154e-02*S255+3.705284e-02*S256+(-8.190077e-01)*S257+5.446172e-02*S258+(-5.710428e+01)*S259'
.param V19_part27='V19_part26+(-1.160875e+00)*S260+1.075378e+00*S261+3.615763e-01*S262+(-1.000280e-01)*S263+(-2.687673e+01)*S264+3.735002e-02*S265+(-5.344020e-02)*S266+9.726537e-02*S267+(-8.949753e+01)*S268+(-4.842915e-01)*S269'
.param V19_part28='V19_part27+1.340960e-01*S270+(-1.084036e+00)*S271+(-4.224973e-01)*S272+1.490402e+00*S273+(-6.264508e+00)*S274+2.460307e-01*S275+1.549603e+00*S276+(-1.808953e+00)*S277+3.654352e-01*S278+(-3.803811e-01)*S279'
.param V19_part29='V19_part28+6.475961e-02*S280+4.997509e-01*S281+(-4.748542e-01)*S282+9.217338e-02*S283+(-4.649868e-01)*S284+1.195144e-01*S285+4.016356e-01*S286+2.653538e-01*S287+1.111930e-01*S288+8.212869e-02*S289'
.param V19_part30='V19_part29+2.228211e-01*S290+1.548572e+00*S291+(-1.147316e+00)*S292+(-1.952065e-01)*S293+2.000562e-02*S294+4.735972e-02*S295+2.522456e-01*S296+1.795625e-01*S297+1.025354e-01*S298+(-4.780655e-02)*S299'
.param V19_part31='V19_part30+9.965879e-02*S300+(-1.138200e+00)*S301+(-5.904407e-01)*S302+7.536747e-02*S303+4.942114e-02*S304+(-9.474093e-01)*S305+3.768207e-02*S306+(-3.772305e-01)*S307+(-3.132805e-01)*S308+2.646609e-02*S309'
.param V19='V19_part31+7.374595e-02*S310+(-2.791496e-01)*S311+(-2.961880e-02)*S312+7.851617e-02*S313+(-3.315926e-01)*S314'
.param V20_part1='1.049108e-01*S0+9.669856e-02*S1+9.063680e-02*S2+6.010074e-01*S3+1.003716e-01*S4+2.776271e-01*S5+5.793035e-01*S6+3.627040e-01*S7+9.861162e-02*S8+1.090243e-01*S9'
.param V20_part2='V20_part1+1.305293e-01*S10+1.011814e-01*S11+1.119899e-01*S12+1.060421e-01*S13+1.096112e-01*S14+8.900179e-02*S15+8.322957e-02*S16+7.865646e-02*S17+8.689341e-02*S18+8.600076e-02*S19'
.param V20_part3='V20_part2+8.257571e-02*S20+9.077859e-02*S21+2.246043e-01*S22+8.424608e-02*S23+9.087268e-02*S24+2.088455e-01*S25+8.446328e-02*S26+9.272850e-02*S27+1.971142e-01*S28+1.183347e-01*S29'
.param V20_part4='V20_part3+9.512546e-02*S30+1.543542e-01*S31+8.243194e-02*S32+8.928976e-02*S33+8.783700e-02*S34+6.996886e-02*S35+7.965275e-02*S36+4.637818e-01*S37+7.638127e-02*S38+7.549842e-02*S39'
.param V20_part5='V20_part4+1.096509e+00*S40+2.381523e-01*S41+6.747935e-02*S42+7.756181e-02*S43+2.826018e-01*S44+1.664133e-01*S45+1.476635e-01*S46+1.058088e-01*S47+9.818194e-02*S48+9.986448e-02*S49'
.param V20_part6='V20_part5+8.902814e-02*S50+4.329714e-01*S51+9.878907e-02*S52+8.601389e-02*S53+7.439053e-02*S54+7.954931e-02*S55+9.468091e-02*S56+6.729241e-02*S57+7.251093e-02*S58+7.248657e-02*S59'
.param V20_part7='V20_part6+8.889477e-02*S60+1.331315e-01*S61+1.077761e-01*S62+7.389667e-02*S63+1.921798e-01*S64+1.702271e-01*S65+6.838800e-02*S66+2.206870e-01*S67+1.820609e-01*S68+1.144562e-01*S69'
.param V20_part8='V20_part7+1.752703e-01*S70+2.866240e-01*S71+3.203015e-01*S72+7.152785e-03*S73+7.646646e-02*S74+7.366402e-02*S75+2.268851e-02*S76+6.141224e-02*S77+2.030238e-02*S78+2.217221e-02*S79'
.param V20_part9='V20_part8+2.511146e-02*S80+1.876568e-02*S81+2.669360e-02*S82+2.436521e-02*S83+2.189867e-02*S84+1.537834e-01*S85+2.030291e-02*S86+8.617191e-03*S87+1.693352e-02*S88+1.760420e-01*S89'
.param V20_part10='V20_part9+9.174305e-02*S90+1.548085e-01*S91+1.075049e-01*S92+6.936280e-02*S93+2.969999e-01*S94+3.577398e-02*S95+8.107276e-01*S96+5.180873e-02*S97+4.488415e-02*S98+(-1.006578e-02)*S99'
.param V20_part11='V20_part10+4.857170e-02*S100+7.883225e-02*S101+(-4.483410e-02)*S102+1.278139e-02*S103+7.770492e-02*S104+1.061818e-01*S105+1.662684e-01*S106+1.320093e-01*S107+7.329308e-02*S108+2.650045e-01*S109'
.param V20_part12='V20_part11+1.213403e-01*S110+2.739665e-02*S111+7.037851e-02*S112+9.996577e-02*S113+(-6.051515e-02)*S114+(-7.208015e-04)*S115+8.941136e-02*S116+(-6.701644e-02)*S117+1.352033e-02*S118+3.092410e-01*S119'
.param V20_part13='V20_part12+8.480146e-02*S120+1.051586e-01*S121+1.473084e-01*S122+4.966185e-02*S123+5.950860e-02*S124+1.351994e-01*S125+(-8.777647e-03)*S126+(-6.720268e-03)*S127+7.427257e-02*S128+(-6.197716e-02)*S129'
.param V20_part14='V20_part13+(-9.597546e-02)*S130+(-2.717618e-02)*S131+1.802275e+00*S132+(-2.526294e-02)*S133+(-6.371438e-02)*S134+2.069857e-02*S135+7.855425e-02*S136+2.233851e-02*S137+(-3.544199e-03)*S138+2.735825e-02*S139'
.param V20_part15='V20_part14+1.538672e-02*S140+(-2.196067e-02)*S141+1.302983e-03*S142+1.563721e-02*S143+(-5.463958e-02)*S144+(-3.440458e-02)*S145+(-6.703240e-03)*S146+1.083311e+00*S147+7.474174e-01*S148+3.214221e-01*S149'
.param V20_part16='V20_part15+7.962346e-02*S150+1.440621e-01*S151+1.534026e+00*S152+1.833061e-02*S153+(-1.160913e+00)*S154+3.585955e+01*S155+1.176249e+00*S156+2.189719e+00*S157+2.347156e+00*S158+(-1.012095e-01)*S159'
.param V20_part17='V20_part16+(-5.201023e-03)*S160+1.020953e-01*S161+2.426233e+00*S162+5.201079e+00*S163+5.442870e-01*S164+1.716097e-01*S165+2.661581e-01*S166+2.175997e-01*S167+7.913906e-01*S168+8.230132e-02*S169'
.param V20_part18='V20_part17+(-1.176819e-03)*S170+(-2.391734e-02)*S171+2.145812e-02*S172+(-9.855579e-02)*S173+(-8.066049e-02)*S174+2.875980e-03*S175+2.625513e-01*S176+1.946439e+00*S177+(-1.014474e-01)*S178+5.221711e+00*S179'
.param V20_part19='V20_part18+8.049769e-02*S180+2.934999e+00*S181+4.553193e+01*S182+(-1.160450e+02)*S183+5.706335e+01*S184+8.962601e-02*S185+(-6.103672e-02)*S186+2.876184e+02*S187+6.746307e+01*S188+(-8.751997e-02)*S189'
.param V20_part20='V20_part19+(-1.177156e-01)*S190+1.287317e+02*S191+(-2.022034e-01)*S192+6.514459e+00*S193+2.444132e-01*S194+1.962572e-02*S195+4.414344e-02*S196+1.699256e+00*S197+(-3.927537e-02)*S198+(-4.054280e-02)*S199'
.param V20_part21='V20_part20+2.706954e+00*S200+(-1.010393e-01)*S201+(-1.906294e-01)*S202+3.079650e+00*S203+(-1.365447e-01)*S204+(-8.602564e+01)*S205+3.423337e+00*S206+1.584692e+00*S207+(-1.456171e-01)*S208+(-9.871079e-02)*S209'
.param V20_part22='V20_part21+1.060303e+00*S210+1.687615e-01*S211+1.315433e-01*S212+(-3.887604e-03)*S213+9.116641e-02*S214+(-3.337777e-02)*S215+(-4.504471e-02)*S216+2.009987e-03*S217+(-3.289278e-02)*S218+(-1.555408e-01)*S219'
.param V20_part23='V20_part22+(-1.312879e-01)*S220+2.640446e+00*S221+7.219425e-01*S222+9.593758e-01*S223+2.457060e+00*S224+2.171146e+00*S225+4.387766e-01*S226+5.689423e+00*S227+1.424405e-01*S228+6.822793e-01*S229'
.param V20_part24='V20_part23+4.313788e+00*S230+(-3.106712e-02)*S231+1.169225e+03*S232+3.027394e-01*S233+(-1.498151e-01)*S234+(-5.251746e-02)*S235+(-2.046907e+00)*S236+1.899534e-01*S237+3.490522e+00*S238+(-2.872675e-01)*S239'
.param V20_part25='V20_part24+1.089027e-01*S240+2.094786e+01*S241+5.081083e+00*S242+1.161447e-03*S243+2.496177e-01*S244+4.717170e+00*S245+7.975608e-01*S246+4.548181e-02*S247+2.405242e+00*S248+(-3.474284e-01)*S249'
.param V20_part26='V20_part25+2.093128e-02*S250+2.902105e+00*S251+1.610252e+00*S252+1.551490e+01*S253+3.875627e+00*S254+4.234185e-02*S255+7.591782e-02*S256+(-9.721458e-01)*S257+(-7.697269e-02)*S258+8.752803e+00*S259'
.param V20_part27='V20_part26+(-1.361327e+00)*S260+8.306773e-01*S261+3.099428e+00*S262+1.286025e-01*S263+1.083530e+03*S264+5.110257e+00*S265+(-1.915028e+00)*S266+(-2.885265e-01)*S267+1.423759e+02*S268+(-2.032064e+00)*S269'
.param V20_part28='V20_part27+1.719336e-01*S270+1.415783e+00*S271+2.301288e+00*S272+1.646120e-02*S273+6.445830e+00*S274+7.043344e-01*S275+8.928866e-01*S276+1.177948e+00*S277+5.517593e-01*S278+5.482249e-01*S279'
.param V20_part29='V20_part28+(-4.328291e-02)*S280+4.519653e-01*S281+2.867821e-01*S282+(-2.755256e-01)*S283+3.083755e+00*S284+2.630212e-01*S285+4.313214e-01*S286+7.318252e-01*S287+6.172825e-02*S288+1.232537e-01*S289'
.param V20_part30='V20_part29+6.257707e-01*S290+8.798180e-01*S291+1.245117e+00*S292+1.675958e+00*S293+(-2.749038e-01)*S294+(-5.994969e-02)*S295+5.107839e-01*S296+(-1.478593e-01)*S297+(-1.811299e-01)*S298+9.897913e-01*S299'
.param V20_part31='V20_part30+6.998744e-02*S300+9.976370e-01*S301+(-1.395149e+00)*S302+(-5.100921e-02)*S303+(-9.524211e-02)*S304+7.728452e+00*S305+(-2.016853e-01)*S306+(-2.334112e-03)*S307+2.338157e+00*S308+(-3.058002e-01)*S309'
.param V20='V20_part31+(-7.984495e-02)*S310+2.317655e+00*S311+(-4.615486e-01)*S312+(-2.068215e-01)*S313+2.098806e+00*S314'
.param V21_part1='2.042269e-01*S0+1.763842e-01*S1+1.560215e-01*S2+2.668517e-01*S3+1.956097e-01*S4+2.010259e-01*S5+2.595097e-01*S6+2.172284e-01*S7+1.880046e-01*S8+2.502945e-01*S9'
.param V21_part2='V21_part1+1.989977e-01*S10+2.021951e-01*S11+2.577282e-01*S12+2.412666e-01*S13+2.057627e-01*S14+2.973159e-01*S15+2.624890e-01*S16+2.335027e-01*S17+3.306378e-01*S18+2.900736e-01*S19'
.param V21_part3='V21_part2+2.604631e-01*S20+3.592464e-01*S21+2.474745e-01*S22+2.874035e-01*S23+3.799331e-01*S24+2.677581e-01*S25+3.045332e-01*S26+3.875808e-01*S27+2.859833e-01*S28+2.826084e-01*S29'
.param V21_part4='V21_part3+6.317270e-01*S30+2.934682e+00*S31+5.308944e-01*S32+7.315744e-01*S33+6.438603e-01*S34+6.076201e-01*S35+7.929553e-01*S36+4.782501e-01*S37+6.283350e-01*S38+8.284832e-01*S39'
.param V21_part5='V21_part4+4.667358e-01*S40+5.401863e-01*S41+8.689602e-01*S42+7.623154e-01*S43+5.678607e-01*S44+7.354326e-01*S45+6.842896e-01*S46+7.297283e-01*S47+1.022104e+00*S48+9.019126e-01*S49'
.param V21_part6='V21_part5+8.410859e-01*S50+7.765510e-01*S51+9.643195e-01*S52+8.798089e-01*S53+1.161518e+00*S54+1.040071e+00*S55+9.314386e-01*S56+1.203522e+00*S57+1.090450e+00*S58+9.949163e-01*S59'
.param V21_part7='V21_part6+1.153529e+00*S60+9.071504e-01*S61+8.578083e-01*S62+1.296768e+00*S63+9.992782e-01*S64+9.047596e-01*S65+1.371749e+00*S66+1.119949e+00*S67+9.992551e-01*S68+1.340579e+00*S69'
.param V21_part8='V21_part7+1.257848e+00*S70+1.059305e+00*S71+1.308433e+00*S72+1.486421e+00*S73+1.187344e+00*S74+2.973198e-01*S75+3.664890e-01*S76+2.607457e-01*S77+4.467031e-01*S78+4.041599e-01*S79'
.param V21_part9='V21_part8+3.620615e-01*S80+4.810747e-01*S81+4.405064e-01*S82+4.037155e-01*S83+5.173025e-01*S84+3.712311e-01*S85+4.279679e-01*S86+5.497073e-01*S87+4.918391e-01*S88+3.540261e-01*S89'
.param V21_part10='V21_part9+1.778896e+00*S90+1.434227e+00*S91+1.495666e+00*S92+1.971338e+00*S93+1.516609e+00*S94+1.697608e+00*S95+1.566005e+00*S96+2.060989e+00*S97+2.021585e+00*S98+2.274708e+00*S99'
.param V21_part11='V21_part10+2.075640e+00*S100+1.894804e+00*S101+2.389520e+00*S102+2.196389e+00*S103+1.992767e+00*S104+2.149655e+00*S105+1.764995e+00*S106+1.685942e+00*S107+2.387753e+00*S108+1.941515e+00*S109'
.param V21_part12='V21_part11+2.246840e+00*S110+2.585680e+00*S111+2.419425e+00*S112+2.435555e+00*S113+2.871119e+00*S114+2.588680e+00*S115+2.432646e+00*S116+2.918277e+00*S117+2.668729e+00*S118+2.163073e+00*S119'
.param V21_part13='V21_part12+2.559487e+00*S120+2.338829e+00*S121+2.394898e+00*S122+2.822091e+00*S123+2.651963e+00*S124+2.678672e+00*S125+3.058538e+00*S126+3.125424e+00*S127+2.895018e+00*S128+3.273864e+00*S129'
.param V21_part14='V21_part13+3.363093e+00*S130+3.126964e+00*S131+2.417822e+00*S132+3.145175e+00*S133+3.222386e+00*S134+1.452060e+00*S135+1.143082e+00*S136+1.309437e+00*S137+1.608300e+00*S138+1.415057e+00*S139'
.param V21_part15='V21_part14+1.232013e+00*S140+1.707757e+00*S141+1.597625e+00*S142+1.401617e+00*S143+1.814465e+00*S144+1.664258e+00*S145+1.538974e+00*S146+1.307196e+00*S147+1.353616e+00*S148+1.332804e+00*S149'
.param V21_part16='V21_part15+3.398429e+00*S150+3.988225e+00*S151+2.238615e+00*S152+3.796068e+00*S153+7.952630e+01*S154+1.500090e+01*S155+2.999960e+00*S156+2.221558e+00*S157+2.652856e+00*S158+4.385379e+00*S159'
.param V21_part17='V21_part16+4.005468e+00*S160+4.235019e+00*S161+3.066646e+00*S162+1.653492e+00*S163+4.181910e+00*S164+3.806294e+00*S165+5.649153e+00*S166+3.122723e+00*S167+3.587213e+00*S168+3.970693e+00*S169'
.param V21_part18='V21_part17+3.921533e+00*S170+4.707684e+00*S171+4.389240e+00*S172+4.050551e+00*S173+5.030150e+00*S174+4.568754e+00*S175+3.980414e+00*S176+3.840061e+00*S177+4.812924e+00*S178+3.023279e+00*S179'
.param V21_part19='V21_part18+4.439519e+00*S180+2.578296e+01*S181+3.066124e+01*S182+1.787033e+02*S183+3.848322e+02*S184+3.892730e+00*S185+5.328016e+00*S186+4.952560e+02*S187+1.834628e+01*S188+5.591428e+00*S189'
.param V21_part20='V21_part19+5.237519e+00*S190+3.077135e+01*S191+5.898086e+00*S192+2.301524e+00*S193+4.462800e+00*S194+2.932704e+00*S195+2.680229e+00*S196+1.621102e+00*S197+3.619755e+00*S198+3.185395e+00*S199'
.param V21_part21='V21_part20+1.467640e+00*S200+3.534695e+00*S201+3.915823e+00*S202+1.610160e+00*S203+3.731920e+00*S204+2.454974e+03*S205+1.885717e+00*S206+2.826894e+00*S207+3.633201e+00*S208+3.179762e+00*S209'
.param V21_part22='V21_part21+1.323938e+01*S210+4.925438e+00*S211+5.143241e+00*S212+6.235367e+00*S213+5.609069e+00*S214+5.548690e+00*S215+6.572978e+00*S216+6.218600e+00*S217+5.781198e+00*S218+6.989679e+00*S219'
.param V21_part23='V21_part22+6.518349e+00*S220+5.691372e+00*S221+7.804205e+00*S222+6.522695e+00*S223+5.981863e+00*S224+2.355243e+01*S225+9.598673e+00*S226+3.860890e+00*S227+6.405007e+00*S228+5.558482e+00*S229'
.param V21_part24='V21_part23+4.521343e+00*S230+7.274251e+00*S231+3.792701e+03*S232+5.719145e+00*S233+7.767958e+00*S234+7.138523e+00*S235+7.652548e+00*S236+7.594242e+00*S237+5.963430e+00*S238+8.798832e+00*S239'
.param V21_part25='V21_part24+6.716554e+00*S240+8.315814e+00*S241+3.186086e+00*S242+7.548562e+00*S243+6.377102e+00*S244+5.081139e+00*S245+7.204419e+00*S246+7.372915e+00*S247+6.659759e+00*S248+8.747137e+00*S249'
.param V21_part26='V21_part25+7.710693e+00*S250+6.927115e+00*S251+7.335390e+00*S252+1.699436e+02*S253+7.259870e+00*S254+4.749691e+00*S255+4.454115e+00*S256+4.768405e+00*S257+5.650157e+00*S258+3.246264e+02*S259'
.param V21_part27='V21_part26+5.041963e+00*S260+4.832699e+00*S261+3.447750e+00*S262+4.600268e+00*S263+1.120576e+02*S264+2.991313e+00*S265+6.274767e+00*S266+6.499380e+00*S267+3.880486e+03*S268+6.233787e+00*S269'
.param V21_part28='V21_part27+8.204858e+00*S270+1.340826e+01*S271+8.261271e+00*S272+1.471594e+01*S273+3.159428e+01*S274+6.835910e+00*S275+8.339398e+00*S276+1.940027e+01*S277+7.424409e+00*S278+1.031364e+01*S279'
.param V21_part29='V21_part28+9.491007e+00*S280+7.869720e+00*S281+1.088021e+01*S282+9.752746e+00*S283+9.489548e+00*S284+8.573230e+00*S285+7.696883e+00*S286+6.972490e+00*S287+9.808568e+00*S288+9.482464e+00*S289'
.param V21_part30='V21_part29+7.606707e+00*S290+9.171157e+00*S291+1.875120e+01*S292+9.173763e+00*S293+1.116109e+01*S294+1.047391e+01*S295+8.563967e+00*S296+1.137668e+01*S297+1.056278e+01*S298+1.019580e+01*S299'
.param V21_part31='V21_part30+7.521335e+00*S300+1.241767e+01*S301+7.054424e+00*S302+8.212368e+00*S303+8.383677e+00*S304+4.799265e+00*S305+8.857394e+00*S306+1.356322e+01*S307+7.312127e+00*S308+9.378996e+00*S309'
.param V21='V21_part31+8.438908e+00*S310+7.817794e+00*S311+9.835848e+00*S312+8.811769e+00*S313+8.239847e+00*S314'
.param V22_part1='(-2.790184e-02)*S0+(-3.442821e-03)*S1+7.898986e-03*S2+(-1.869596e-01)*S3+(-2.062355e-02)*S4+5.355933e-03*S5+(-1.927024e-01)*S6+(-4.427078e-02)*S7+(-1.368981e-02)*S8+(-1.108996e-01)*S9'
.param V22_part2='V22_part1+(-4.372674e-02)*S10+(-2.654139e-02)*S11+(-1.398612e-01)*S12+(-7.746786e-02)*S13+(-4.021366e-02)*S14+(-2.665124e-02)*S15+1.775487e-03*S16+1.397049e-02*S17+(-6.007525e-02)*S18+(-2.098923e-02)*S19'
.param V22_part3='V22_part2+(-1.757262e-04)*S20+(-1.037594e-01)*S21+(-3.441777e-02)*S22+(-1.529934e-02)*S23+(-1.446655e-01)*S24+(-3.951222e-02)*S25+(-2.954660e-02)*S26+(-1.843631e-01)*S27+(-6.106698e-02)*S28+(-2.701935e-02)*S29'
.param V22_part4='V22_part3+(-3.855965e-02)*S30+4.066989e-01*S31+3.721790e-02*S32+(-1.043197e-01)*S33+(-2.683823e-02)*S34+2.248012e-02*S35+(-1.807500e-01)*S36+3.696149e-02*S37+(-8.876562e-03)*S38+(-2.521716e-01)*S39'
.param V22_part5='V22_part4+1.235461e-01*S40+5.057975e-02*S41+(-3.363107e-01)*S42+(-1.585782e-01)*S43+3.351843e-02*S44+6.056552e-03*S45+4.825073e-02*S46+7.724866e-02*S47+(-9.195776e-02)*S48+2.501503e-03*S49'
.param V22_part6='V22_part5+5.931891e-02*S50+(-1.259364e-01)*S51+(-5.875507e-02)*S52+2.526818e-02*S53+(-3.081094e-01)*S54+(-1.112137e-01)*S55+(-2.609200e-02)*S56+(-4.227127e-01)*S57+(-1.843722e-01)*S58+(-5.771548e-02)*S59'
.param V22_part7='V22_part6+3.785352e-02*S60+8.951760e-02*S61+1.206203e-01*S62+(-8.160522e-02)*S63+9.367206e-02*S64+1.088160e-01*S65+(-2.181010e-01)*S66+5.163441e-02*S67+9.863748e-02*S68+(-2.106779e-01)*S69'
.param V22_part8='V22_part7+9.981345e-02*S70+9.067194e-02*S71+(-3.365769e-01)*S72+(-2.264872e-01)*S73+(-7.114369e-02)*S74+(-1.331292e-02)*S75+1.258473e-02*S76+2.211505e-02*S77+(-5.211265e-02)*S78+(-1.186592e-02)*S79'
.param V22_part9='V22_part8+8.087230e-03*S80+(-9.806760e-02)*S81+(-4.364143e-02)*S82+(-7.637106e-03)*S83+(-1.600730e-01)*S84+(-2.693644e-02)*S85+(-2.367007e-02)*S86+(-2.038941e-01)*S87+(-9.771192e-02)*S88+(-3.448237e-03)*S89'
.param V22_part10='V22_part9+1.620920e-01*S90+1.856159e-01*S91+2.317778e-01*S92+(-1.245929e-02)*S93+2.727577e-01*S94+2.192388e-01*S95+2.421511e-01*S96+6.542038e-03*S97+1.237653e-01*S98+(-3.651223e-01)*S99'
.param V22_part11='V22_part10+(-1.304567e-01)*S100+2.188069e-02*S101+(-5.464748e-01)*S102+(-2.544752e-01)*S103+(-8.122823e-02)*S104+3.022222e-01*S105+2.784292e-01*S106+2.633298e-01*S107+8.909041e-02*S108+4.405847e-01*S109'
.param V22_part12='V22_part11+2.719847e-01*S110+(-7.697568e-02)*S111+8.021423e-02*S112+1.582013e-01*S113+(-1.368451e-01)*S114+(-2.071449e-02)*S115+4.551555e-02*S116+(-6.008330e-01)*S117+(-2.125061e-01)*S118+7.347846e-02*S119'
.param V22_part13='V22_part12+3.903802e-01*S120+4.342230e-01*S121+4.679221e-01*S122+1.674771e-01*S123+3.130004e-01*S124+3.651766e-01*S125+(-2.856792e-02)*S126+1.658863e-01*S127+2.869366e-01*S128+(-3.145677e-01)*S129'
.param V22_part14='V22_part13+9.985623e-04*S130+2.064375e-01*S131+(-1.570996e-01)*S132+(-2.256785e-01)*S133+1.012125e-01*S134+1.084256e-01*S135+1.175339e-01*S136+1.903343e-01*S137+(-3.242033e-02)*S138+5.403843e-02*S139'
.param V22_part15='V22_part14+1.095499e-01*S140+(-1.901355e-01)*S141+(-1.076741e-02)*S142+5.026652e-02*S143+(-3.341464e-01)*S144+(-9.230406e-02)*S145+1.305548e-02*S146+(-1.843290e-02)*S147+2.693967e-01*S148+5.252350e-02*S149'
.param V22_part16='V22_part15+8.534384e-01*S150+8.012616e-01*S151+(-8.139228e-03)*S152+5.588980e-01*S153+(-1.813315e+00)*S154+(-2.873901e+01)*S155+(-2.685449e-01)*S156+(-1.447210e+00)*S157+(-6.382208e-01)*S158+(-2.396934e-01)*S159'
.param V22_part17='V22_part16+1.983549e-01*S160+2.586991e-01*S161+(-7.125958e-01)*S162+(-3.994468e+00)*S163+(-1.800969e-01)*S164+8.552384e-01*S165+1.365858e+00*S166+7.208350e-01*S167+2.712223e-01*S168+7.772798e-01*S169'
.param V22_part18='V22_part17+9.456084e-01*S170+3.469971e-01*S171+6.336844e-01*S172+9.423006e-01*S173+(-2.306698e-01)*S174+3.117823e-01*S175+4.103195e-01*S176+(-1.104063e+00)*S177+6.527963e-02*S178+(-2.163381e+00)*S179'
.param V22_part19='V22_part18+1.327764e+00*S180+1.497039e+00*S181+(-3.481050e+01)*S182+8.943457e+02*S183+(-9.885019e+01)*S184+1.036170e+00*S185+4.356388e-01*S186+(-3.468393e+02)*S187+(-5.445090e+01)*S188+(-1.813194e-01)*S189'
.param V22_part20='V22_part19+4.845108e-01*S190+(-1.110056e+02)*S191+(-6.256365e-01)*S192+(-5.122388e+00)*S193+3.036556e-01*S194+5.958598e-01*S195+5.500860e-01*S196+(-3.799934e-01)*S197+5.857447e-01*S198+4.766781e-01*S199'
.param V22_part21='V22_part20+(-9.770763e-01)*S200+1.054287e-01*S201+3.613660e-01*S202+(-1.151061e+00)*S203+(-2.579002e-01)*S204+(-4.497039e+02)*S205+(-1.462899e+00)*S206+(-2.068896e-01)*S207+(-1.947379e-01)*S208+1.173018e-01*S209'
.param V22_part22='V22_part21+1.662422e+00*S210+1.535841e+00*S211+1.772343e+00*S212+1.562273e+00*S213+1.495655e+00*S214+1.731742e+00*S215+8.272581e-01*S216+1.203703e+00*S217+1.478693e+00*S218+2.698553e-01*S219'
.param V22_part23='V22_part22+8.912324e-01*S220+(-3.246935e-01)*S221+(-1.957107e+00)*S222+(-7.552219e-04)*S223+(-5.059743e-01)*S224+1.134504e+00*S225+3.273045e+00*S226+(-1.663720e+00)*S227+9.868585e-01*S228+7.364367e-01*S229'
.param V22_part24='V22_part23+(-2.561226e-01)*S230+1.160832e+00*S231+(-2.473987e+03)*S232+1.251547e+00*S233+3.791674e-01*S234+1.276955e+00*S235+1.068600e+01*S236+(-1.275630e+00)*S237+(-3.075916e+00)*S238+1.348140e+01*S239'
.param V22_part25='V22_part24+2.737953e+00*S240+5.190998e-01*S241+3.082654e+01*S242+2.223764e+00*S243+1.504905e+00*S244+(-2.355825e-01)*S245+(-2.607716e-01)*S246+1.951495e+00*S247+8.749054e-01*S248+1.016895e+00*S249'
.param V22_part26='V22_part25+1.495680e+00*S250+3.426629e-01*S251+(-1.222902e+00)*S252+(-4.802133e+01)*S253+(-5.822597e-01)*S254+1.290636e+00*S255+1.328201e+00*S256+4.618783e+00*S257+1.247936e+00*S258+(-4.821586e+01)*S259'
.param V22_part27='V22_part26+5.720886e+00*S260+(-7.392151e-01)*S261+(-2.088552e+00)*S262+8.199484e-01*S263+(-2.103134e+03)*S264+(-3.842077e+00)*S265+8.694114e+00*S266+(-5.448938e-01)*S267+(-3.049952e+02)*S268+1.031837e+01*S269'
.param V22_part28='V22_part27+3.773480e+00*S270+2.996377e+00*S271+2.417654e+00*S272+3.626057e+00*S273+2.110702e+00*S274+2.245224e+00*S275+2.489252e-02*S276+2.253170e+00*S277+2.027223e+00*S278+2.880608e-01*S279'
.param V22_part29='V22_part28+2.411000e+00*S280+1.766708e+00*S281+(-4.038761e-01)*S282+1.752316e+00*S283+6.768707e-01*S284+3.938242e+00*S285+2.881111e+00*S286+2.882184e+00*S287+3.578275e+00*S288+3.987518e+00*S289'
.param V22_part30='V22_part29+2.744985e+00*S290+4.049217e-01*S291+1.862292e+00*S292+2.705741e+00*S293+1.760423e+00*S294+2.775887e+00*S295+2.220067e+00*S296+2.419678e-01*S297+2.140011e+00*S298+2.713596e+00*S299'
.param V22_part31='V22_part30+3.245843e+00*S300+2.861315e+00*S301+7.474716e+00*S302+2.526863e+00*S303+2.955623e+00*S304+(-1.829483e+00)*S305+1.817073e+00*S306+1.619842e+00*S307+1.283289e+00*S308+9.499920e-01*S309'
.param V22='V22_part31+1.879068e+00*S310+9.905563e-01*S311+4.639861e-02*S312+1.471386e+00*S313+8.320301e-01*S314'
.param V23_part1='7.395785e-02*S0+6.751581e-02*S1+6.245766e-02*S2+3.622796e-01*S3+6.883048e-02*S4+1.824870e-01*S5+3.591952e-01*S6+2.351559e-01*S7+6.578577e-02*S8+7.600279e-02*S9'
.param V23_part2='V23_part1+9.430828e-02*S10+6.692590e-02*S11+7.617507e-02*S12+7.340725e-02*S13+6.871625e-02*S14+6.254927e-02*S15+5.806028e-02*S16+5.351815e-02*S17+6.270629e-02*S18+5.924355e-02*S19'
.param V23_part3='V23_part2+5.471838e-02*S20+6.689638e-02*S21+1.744645e-01*S22+5.677454e-02*S23+6.824128e-02*S24+1.764757e-01*S25+5.848769e-02*S26+6.589158e-02*S27+1.683166e-01*S28+1.128677e-01*S29'
.param V23_part4='V23_part3+5.967417e-02*S30+1.966421e-01*S31+5.866538e-02*S32+6.786623e-02*S33+6.533126e-02*S34+6.242501e-02*S35+7.028890e-02*S36+3.441533e-01*S37+6.034092e-02*S38+7.372248e-02*S39'
.param V23_part5='V23_part4+7.833301e-01*S40+2.198657e-01*S41+7.457983e-02*S42+7.004099e-02*S43+2.670551e-01*S44+1.174151e-01*S45+1.017110e-01*S46+6.777736e-02*S47+8.145512e-02*S48+7.372127e-02*S49'
.param V23_part6='V23_part5+7.455202e-02*S50+2.984583e-01*S51+7.874253e-02*S52+7.146115e-02*S53+8.444811e-02*S54+8.541388e-02*S55+8.036706e-02*S56+8.359945e-02*S57+8.157210e-02*S58+8.006794e-02*S59'
.param V23_part7='V23_part6+6.736294e-02*S60+1.157008e-01*S61+9.912132e-02*S62+6.991886e-02*S63+1.813092e-01*S64+1.458546e-01*S65+6.860250e-02*S66+2.289099e-01*S67+1.879389e-01*S68+1.544553e-01*S69'
.param V23_part8='V23_part7+2.538574e-01*S70+2.717672e-01*S71+3.561013e-01*S72+8.262415e-02*S73+7.019305e-02*S74+5.000110e-02*S75+1.968241e-02*S76+4.458403e-02*S77+1.988684e-02*S78+2.037161e-02*S79'
.param V23_part9='V23_part8+1.957428e-02*S80+2.256875e-02*S81+2.528935e-02*S82+2.357430e-02*S83+2.719477e-02*S84+1.326472e-01*S85+2.510363e-02*S86+2.695182e-02*S87+2.751978e-02*S88+1.479912e-01*S89'
.param V23_part10='V23_part9+7.323390e-02*S90+1.267948e-01*S91+7.354130e-02*S92+7.129486e-02*S93+2.545267e-01*S94+7.692418e-02*S95+5.815997e-01*S96+9.268651e-02*S97+8.891960e-02*S98+7.749763e-02*S99'
.param V23_part11='V23_part10+8.482192e-02*S100+8.925797e-02*S101+8.439467e-02*S102+8.845476e-02*S103+9.845041e-02*S104+8.433188e-02*S105+1.274638e-01*S106+7.714023e-02*S107+8.135912e-02*S108+2.458974e-01*S109'
.param V23_part12='V23_part11+9.515847e-02*S110+8.676640e-02*S111+9.369033e-02*S112+1.028200e-01*S113+1.002651e-01*S114+9.893753e-02*S115+9.867091e-02*S116+8.948641e-02*S117+8.083667e-02*S118+2.683785e-01*S119'
.param V23_part13='V23_part12+7.809875e-02*S120+7.843477e-02*S121+7.994972e-02*S122+7.925332e-02*S123+8.507533e-02*S124+8.800418e-02*S125+8.397670e-02*S126+8.091905e-02*S127+9.853296e-02*S128+8.936120e-02*S129'
.param V23_part14='V23_part13+5.210632e-02*S130+1.144287e-01*S131+1.036809e+00*S132+9.808965e-02*S133+1.243693e-01*S134+3.141797e-02*S135+6.984098e-02*S136+3.076391e-02*S137+3.546737e-02*S138+2.801659e-02*S139'
.param V23_part15='V23_part14+3.900678e-02*S140+2.859955e-02*S141+4.236003e-02*S142+2.501474e-02*S143+3.016710e-02*S144+4.393647e-02*S145+4.422402e-02*S146+6.865100e-01*S147+5.269467e-01*S148+2.484663e-01*S149'
.param V23_part16='V23_part15+8.279312e-02*S150+8.117406e-02*S151+4.471367e-02*S152+8.399700e-02*S153+1.769244e+00*S154+1.417448e+00*S155+5.433672e-01*S156+1.130921e-01*S157+6.704335e-02*S158+7.820914e-02*S159'
.param V23_part17='V23_part16+5.135159e-02*S160+8.071451e-02*S161+1.005693e+00*S162+1.036242e-01*S163+4.054688e-02*S164+1.351140e-01*S165+1.648205e-01*S166+8.226553e-02*S167+3.912287e-01*S168+7.795334e-02*S169'
.param V23_part18='V23_part17+9.298655e-02*S170+7.825897e-02*S171+6.745911e-02*S172+8.424693e-02*S173+7.776671e-02*S174+7.239999e-02*S175+7.983049e-02*S176+7.928925e-01*S177+7.226767e-02*S178+1.756651e-02*S179'
.param V23_part19='V23_part18+8.329715e-02*S180+3.735821e-01*S181+2.114299e+00*S182+(-2.291992e+00)*S183+2.512345e+01*S184+6.636097e-02*S185+7.583106e-02*S186+6.551209e+01*S187+1.702437e+00*S188+6.710678e-02*S189'
.param V23_part20='V23_part19+1.091785e-01*S190+2.871863e+00*S191+6.519711e-02*S192+6.956527e-02*S193+1.020283e-01*S194+3.552187e-02*S195+2.418822e-02*S196+2.056398e-02*S197+9.698373e-02*S198+3.455673e-02*S199'
.param V23_part21='V23_part20+2.543615e-02*S200+4.110687e-02*S201+1.123076e-02*S202+4.925474e-02*S203+4.329435e-02*S204+4.632453e+00*S205+7.569080e-02*S206+8.834266e-01*S207+3.765150e-02*S208+3.753961e-02*S209'
.param V23_part22='V23_part21+3.275321e-01*S210+7.443442e-02*S211+9.524938e-02*S212+6.973211e-02*S213+7.330272e-02*S214+1.005737e-01*S215+6.995905e-02*S216+6.671016e-02*S217+1.051253e-01*S218+6.239801e-02*S219'
.param V23_part23='V23_part22+8.743201e-02*S220+4.393668e-02*S221+5.184013e-02*S222+4.688210e-02*S223+3.472892e-02*S224+5.676882e-01*S225+2.086236e-01*S226+7.935183e-02*S227+8.830865e-02*S228+1.102906e-01*S229'
.param V23_part24='V23_part23+5.193528e-02*S230+7.060959e-02*S231+5.413022e+02*S232+1.112711e-01*S233+6.428246e-02*S234+6.806959e-02*S235+1.609304e-01*S236+2.696631e-01*S237+2.835603e-01*S238+6.471823e-02*S239'
.param V23_part25='V23_part24+7.028643e-02*S240+1.104431e+00*S241+7.342868e-01*S242+6.900939e-02*S243+1.008064e-01*S244+(-1.137142e-02)*S245+1.614756e-01*S246+5.955850e-02*S247+7.578262e-02*S248+5.426208e-02*S249'
.param V23_part26='V23_part25+5.039337e-02*S250+7.574608e-02*S251+6.628819e-01*S252+(-4.303472e-03)*S253+8.892785e-02*S254+2.326831e-02*S255+2.829717e-02*S256+7.545897e-03*S257+3.591706e-02*S258+9.117811e+00*S259'
.param V23_part27='V23_part26+9.495646e-03*S260+4.724389e-02*S261+7.880777e-02*S262+4.918358e-02*S263+9.049660e+01*S264+(-8.769592e-02)*S265+3.522787e-02*S266+2.052193e-02*S267+(-1.237677e+01)*S268+(-1.927081e-01)*S269'
.param V23_part28='V23_part27+7.245313e-02*S270+1.007448e-01*S271+1.602657e-01*S272+1.290905e-01*S273+2.905973e-01*S274+9.586508e-02*S275+1.557579e-01*S276+(-1.593503e-01)*S277+1.123606e-01*S278+(-2.022356e-03)*S279'
.param V23_part29='V23_part28+1.243803e-02*S280+1.311506e-01*S281+(-3.200969e-02)*S282+8.720300e-02*S283+4.038100e-02*S284+8.048154e-02*S285+1.121680e-01*S286+1.085664e-01*S287+8.099953e-02*S288+6.924234e-02*S289'
.param V23_part30='V23_part29+1.155282e-01*S290+1.712457e-01*S291+1.418514e-01*S292+8.339566e-02*S293+6.831096e-02*S294+5.404200e-02*S295+1.445121e-01*S296+6.710767e-02*S297+7.024450e-02*S298+1.601464e-01*S299'
.param V23_part31='V23_part30+2.658974e-02*S300+4.210508e-02*S301+7.710108e-03*S302+2.002187e-02*S303+2.137160e-02*S304+(-4.854978e-02)*S305+6.609413e-03*S306+(-1.489907e-02)*S307+9.474143e-03*S308+2.008799e-02*S309'
.param V23='V23_part31+1.587759e-02*S310+2.495357e-02*S311+(-7.081804e-05)*S312+(-2.363360e-03)*S313+4.605795e-02*S314'
.param V24_part1='1.581104e-05*S0+1.449955e-05*S1+(-1.735567e-05)*S2+(-4.105043e-05)*S3+1.498647e-05*S4+7.588607e-04*S5+1.714357e-04*S6+2.899632e-04*S7+5.238931e-06*S8+(-1.456336e-05)*S9'
.param V24_part2='V24_part1+9.708962e-05*S10+9.406117e-06*S11+(-2.121651e-05)*S12+1.504297e-06*S13+2.664980e-05*S14+8.127342e-04*S15+7.251787e-04*S16+6.641429e-04*S17+9.363995e-04*S18+8.098767e-04*S19'
.param V24_part3='V24_part2+7.627119e-04*S20+9.838125e-04*S21+3.562742e-04*S22+8.020636e-04*S23+1.052820e-03*S24+4.946848e-04*S25+8.229144e-04*S26+1.025318e-03*S27+5.481283e-04*S28+7.355734e-04*S29'
.param V24_part4='V24_part3+4.571828e-03*S30+2.781131e-02*S31+4.926766e-03*S32+3.336208e-03*S33+3.671700e-03*S34+4.214456e-03*S35+1.310467e-03*S36+3.801776e-03*S37+1.976338e-03*S38+(-6.787084e-04)*S39'
.param V24_part5='V24_part4+8.726204e-03*S40+1.809664e-04*S41+(-3.888827e-03)*S42+(-1.949405e-03)*S43+2.488799e-04*S44+5.484141e-03*S45+6.361053e-03*S46+6.410266e-03*S47+3.197125e-03*S48+3.825470e-03*S49'
.param V24_part6='V24_part5+3.814461e-03*S50+5.453558e-05*S51+2.365227e-04*S52+2.476814e-04*S53+(-3.389351e-03)*S54+2.224538e-04*S55+1.821256e-03*S56+(-4.209725e-03)*S57+(-9.066627e-03)*S58+(-8.901596e-03)*S59'
.param V24_part7='V24_part6+8.006208e-03*S60+8.199750e-03*S61+7.617013e-03*S62+3.366438e-03*S63+4.159444e-03*S64+2.876995e-03*S65+(-3.804559e-03)*S66+3.317199e-04*S67+5.569240e-04*S68+(-4.213179e-03)*S69'
.param V24_part8='V24_part7+(-1.731876e-03)*S70+8.680343e-03*S71+(-1.870056e-02)*S72+(-1.238409e-02)*S73+3.675308e-03*S74+3.042837e-03*S75+6.133713e-03*S76+2.542624e-03*S77+5.996819e-03*S78+5.210899e-03*S79'
.param V24_part9='V24_part8+4.673482e-03*S80+5.198266e-03*S81+4.205362e-03*S82+3.879707e-03*S83+4.047419e-03*S84+8.616544e-04*S85+3.345433e-03*S86+4.969855e-03*S87+3.035743e-03*S88+(-1.340053e-03)*S89'
.param V24_part10='V24_part9+2.038089e-02*S90+2.229809e-02*S91+2.430681e-02*S92+1.092557e-02*S93+1.880744e-02*S94+2.014125e-02*S95+(-6.280899e-04)*S96+8.572501e-03*S97+2.444838e-02*S98+(-6.460024e-03)*S99'
.param V24_part11='V24_part10+2.493394e-03*S100+6.040247e-03*S101+(-1.811994e-02)*S102+(-7.371000e-03)*S103+1.168965e-02*S104+2.413452e-02*S105+2.421395e-02*S106+3.734418e-02*S107+1.170746e-02*S108+1.918056e-02*S109'
.param V24_part12='V24_part11+3.389964e-02*S110+2.187701e-03*S111+1.070208e-02*S112+3.015242e-02*S113+(-5.911186e-03)*S114+6.768363e-03*S115+9.771209e-03*S116+(-3.357629e-02)*S117+(-6.549179e-03)*S118+1.293697e-02*S119'
.param V24_part13='V24_part12+2.882072e-02*S120+3.430343e-02*S121+4.939747e-02*S122+1.605182e-02*S123+2.531896e-02*S124+4.427784e-02*S125+(-4.693896e-04)*S126+9.328108e-03*S127+4.521395e-02*S128+(-1.919945e-02)*S129'
.param V24_part14='V24_part13+(-1.802885e-02)*S130+3.721215e-02*S131+1.729116e-02*S132+(-2.416244e-03)*S133+2.172134e-02*S134+1.377124e-02*S135+1.217400e-02*S136+1.973148e-02*S137+1.182491e-02*S138+6.354085e-03*S139'
.param V24_part15='V24_part14+1.374440e-02*S140+6.699913e-03*S141+2.287811e-03*S142+1.693981e-02*S143+8.816790e-04*S144+8.110780e-03*S145+1.102434e-02*S146+7.995266e-03*S147+1.880389e-02*S148+2.786563e-03*S149'
.param V24_part16='V24_part15+5.424146e-02*S150+6.195336e-02*S151+(-1.416453e-02)*S152+3.382470e-02*S153+(-3.105924e+00)*S154+6.271492e-01*S155+1.570056e-02*S156+1.074583e-01*S157+(-2.148406e-02)*S158+(-2.471553e-02)*S159'
.param V24_part17='V24_part16+(-3.031552e-03)*S160+4.740237e-02*S161+(-7.572275e-03)*S162+1.285925e-01*S163+3.062800e-02*S164+8.464449e-02*S165+2.611266e-01*S166+7.943464e-02*S167+5.340139e-02*S168+5.071504e-02*S169'
.param V24_part18='V24_part17+8.330794e-02*S170+1.326908e-02*S171+1.724756e-02*S172+6.592098e-02*S173+(-1.786768e-02)*S174+1.219709e-02*S175+3.938326e-02*S176+(-2.758640e-03)*S177+(-3.024617e-03)*S178+(-8.671460e-02)*S179'
.param V24_part19='V24_part18+7.771171e-02*S180+(-9.079775e-01)*S181+1.544032e+00*S182+3.214893e+01*S183+1.917880e+00*S184+7.806442e-02*S185+1.771846e-02*S186+1.723581e+01*S187+6.536929e-01*S188+(-1.371800e-02)*S189'
.param V24_part20='V24_part19+3.860052e-02*S190+1.377997e+00*S191+(-3.765495e-02)*S192+1.523068e-01*S193+6.319414e-02*S194+4.589398e-02*S195+4.608600e-02*S196+2.505183e-02*S197+3.790837e-02*S198+4.570931e-02*S199'
.param V24_part21='V24_part20+(-9.173943e-03)*S200+1.078339e-02*S201+1.056095e-02*S202+(-7.152160e-02)*S203+(-1.149474e-02)*S204+(-6.231316e+01)*S205+(-2.835147e-02)*S206+3.852190e-02*S207+(-3.396792e-03)*S208+4.945695e-02*S209'
.param V24_part22='V24_part21+7.569369e-01*S210+1.052580e-01*S211+1.545575e-01*S212+7.384537e-02*S213+8.663654e-02*S214+1.410709e-01*S215+3.690773e-02*S216+4.543202e-02*S217+1.155623e-01*S218+(-6.715543e-03)*S219'
.param V24_part23='V24_part22+5.254174e-02*S220+(-1.478039e-02)*S221+(-1.495658e-01)*S222+(-1.341294e-02)*S223+(-1.243428e-02)*S224+1.602194e+00*S225+6.845252e-01*S226+5.810464e-02*S227+9.078394e-02*S228+2.020347e-01*S229'
.param V24_part24='V24_part23+(-1.169171e-01)*S230+4.791916e-02*S231+1.923678e+02*S232+1.544801e-01*S233+2.667415e-04*S234+3.759360e-02*S235+4.218229e-01*S236+7.466682e-02*S237+1.985524e-01*S238+8.152156e-01*S239'
.param V24_part25='V24_part24+1.486759e-01*S240+4.225461e+00*S241+4.654430e+00*S242+9.817825e-02*S243+1.833993e-01*S244+(-3.634366e-02)*S245+2.990547e-01*S246+7.919622e-02*S247+(-9.370273e-03)*S248+(-3.100216e-03)*S249'
.param V24_part26='V24_part25+5.317019e-02*S250+(-2.438462e-02)*S251+9.262881e-02*S252+(-3.907881e+00)*S253+(-6.902061e-02)*S254+7.729582e-02*S255+8.273352e-02*S256+9.311082e-02*S257+6.440427e-02*S258+(-8.699139e+00)*S259'
.param V24_part27='V24_part26+6.726440e-02*S260+1.981427e-01*S261+1.782188e-01*S262+1.146507e-01*S263+3.578341e+00*S264+1.580651e-01*S265+3.334150e-01*S266+(-4.104578e-02)*S267+4.297678e+01*S268+3.539243e-01*S269'
.param V24_part28='V24_part27+1.953542e-01*S270+8.277082e-03*S271+9.987414e-02*S272+1.430976e-01*S273+(-7.321788e-01)*S274+1.845563e-01*S275+2.804330e-01*S276+(-7.233265e-02)*S277+1.963522e-01*S278+(-8.531738e-02)*S279'
.param V24_part29='V24_part28+7.097759e-02*S280+2.079316e-01*S281+(-1.534262e-01)*S282+7.269451e-02*S283+(-5.040978e-02)*S284+2.202124e-01*S285+3.154984e-01*S286+2.475997e-01*S287+1.563447e-01*S288+1.840411e-01*S289'
.param V24_part30='V24_part29+2.560763e-01*S290+3.143339e-01*S291+(-9.567406e-02)*S292+1.136865e-01*S293+(-5.416646e-05)*S294+8.340763e-02*S295+2.285912e-01*S296+(-4.911381e-02)*S297+5.447928e-02*S298+2.493828e-01*S299'
.param V24_part31='V24_part30+1.700239e-01*S300+(-3.810721e-02)*S301+2.001480e-01*S302+1.134990e-01*S303+1.074282e-01*S304+(-2.737916e-02)*S305+5.521749e-02*S306+(-8.077001e-02)*S307+3.526452e-03*S308+5.193036e-03*S309'
.param V24='V24_part31+6.142149e-02*S310+3.211118e-04*S311+(-7.554527e-02)*S312+1.357698e-02*S313+4.560517e-04*S314'
.param V25_part1='(-2.626521e-02)*S0+(-6.001181e-01)*S1+(-2.698116e-01)*S2+(-9.782446e-01)*S3+(-9.249950e-01)*S4+(-3.951113e-01)*S5+(-8.035200e-01)*S6+(-4.844193e-01)*S7+5.446679e-02*S8+(-5.487173e+00)*S9'
.param V25_part2='V25_part1+6.040907e-02*S10+1.503647e-01*S11+(-5.981993e+00)*S12+6.568696e-02*S13+(-1.621875e-01)*S14+(-3.436422e-02)*S15+1.985642e-02*S16+2.913329e-02*S17+2.743422e-02*S18+(-4.101123e-01)*S19'
.param V25_part3='V25_part2+7.591338e-02*S20+(-4.403822e-01)*S21+(-2.832616e-01)*S22+8.709943e-02*S23+(-3.919426e-01)*S24+(-2.055838e-01)*S25+(-1.478089e-01)*S26+(-4.897874e-01)*S27+(-1.483031e-01)*S28+5.037907e-02*S29'
.param V25_part4='V25_part3+(-4.145317e-02)*S30+(-1.246336e-02)*S31+1.561542e-02*S32+(-1.393609e-01)*S33+(-2.636478e-01)*S34+2.591921e-02*S35+(-1.960901e-01)*S36+(-4.652243e-01)*S37+(-1.114214e-01)*S38+(-3.367790e-01)*S39'
.param V25_part5='V25_part4+(-8.184089e-01)*S40+(-1.528918e-01)*S41+(-2.738719e-01)*S42+(-9.149161e-01)*S43+(-1.516197e-01)*S44+(-9.173260e-02)*S45+(-6.492549e-02)*S46+(-6.068617e-03)*S47+(-1.326600e-01)*S48+(-2.250024e-01)*S49'
.param V25_part6='V25_part5+4.887559e-02*S50+(-2.635942e-01)*S51+(-2.606253e-01)*S52+(-1.161444e-01)*S53+(-3.186910e-01)*S54+(-4.538390e-01)*S55+(-1.673449e-01)*S56+(-3.783901e-01)*S57+(-2.171587e-01)*S58+(-1.155103e-01)*S59'
.param V25_part7='V25_part6+(-1.281612e-01)*S60+(-4.988902e-02)*S61+4.658238e-02*S62+(-1.462259e-01)*S63+(-1.076279e-01)*S64+(-4.947554e-02)*S65+(-3.447247e-01)*S66+(-7.104998e-02)*S67+1.815407e-03*S68+8.890822e-02*S69'
.param V25_part8='V25_part7+4.874974e-02*S70+(-5.446194e-02)*S71+(-7.267122e-02)*S72+1.801219e-01*S73+3.328555e-01*S74+(-4.187016e-01)*S75+3.455584e-02*S76+(-2.891430e-01)*S77+(-5.831506e-02)*S78+(-6.915746e-02)*S79'
.param V25_part9='V25_part8+(-3.904512e-02)*S80+(-1.182265e-01)*S81+(-2.431168e-01)*S82+(-2.131930e-01)*S83+(-3.625370e-01)*S84+(-2.712936e-01)*S85+(-3.874116e-01)*S86+(-3.566867e-01)*S87+(-5.298161e-01)*S88+(-2.310678e-01)*S89'
.param V25_part10='V25_part9+(-6.358065e-02)*S90+(-4.631337e-02)*S91+2.744501e-02*S92+(-2.087076e-01)*S93+(-1.099323e-01)*S94+(-3.084711e-02)*S95+(-3.278900e-01)*S96+2.318113e-01*S97+2.557748e-01*S98+(-4.371362e-01)*S99'
.param V25_part11='V25_part10+(-3.144518e-01)*S100+(-1.108778e-01)*S101+(-4.218235e-01)*S102+(-3.421306e-01)*S103+(-2.380511e-01)*S104+(-6.136234e-02)*S105+1.201088e-02*S106+2.692489e-01*S107+(-2.434574e-01)*S108+(-3.822573e-02)*S109'
.param V25_part12='V25_part11+2.375266e-01*S110+(-3.588253e-01)*S111+(-1.338212e-01)*S112+2.087252e-01*S113+1.550078e-01*S114+(-1.767001e-01)*S115+1.200893e-01*S116+(-4.819082e-01)*S117+(-3.198444e-01)*S118+7.464618e-02*S119'
.param V25_part13='V25_part12+(-6.591838e-02)*S120+7.019337e-02*S121+2.655461e-01*S122+(-1.658709e-01)*S123+5.001711e-02*S124+2.925549e-01*S125+(-2.515617e-01)*S126+1.749882e-01*S127+3.030776e-01*S128+(-2.887867e-01)*S129'
.param V25_part14='V25_part13+1.470929e-01*S130+2.900866e-01*S131+(-3.235356e-01)*S132+(-1.774572e-01)*S133+1.881671e-01*S134+(-1.965072e-01)*S135+(-1.497647e-01)*S136+2.921702e-01*S137+(-1.820010e-01)*S138+(-2.333219e-01)*S139'
.param V25_part15='V25_part14+2.235790e-01*S140+(-2.446644e-01)*S141+1.745032e-01*S142+(-4.337900e+00)*S143+(-2.905761e-01)*S144+(-1.593802e-01)*S145+(-1.468932e-01)*S146+(-3.695321e-01)*S147+(-2.655128e-01)*S148+(-5.304185e-02)*S149'
.param V25_part16='V25_part15+4.277584e-02*S150+2.091875e-01*S151+1.364367e-01*S152+(-1.389509e-01)*S153+(-3.387494e-01)*S154+(-4.356347e-01)*S155+(-2.577686e-01)*S156+(-6.295394e-01)*S157+9.471422e-02*S158+(-2.152665e-01)*S159'
.param V25_part17='V25_part16+(-6.723983e-01)*S160+2.279468e-01*S161+(-3.171633e-01)*S162+(-8.159670e-01)*S163+2.342884e-01*S164+1.102262e-01*S165+(-2.671802e-01)*S166+2.583893e-01*S167+(-1.837114e-01)*S168+(-1.190623e+01)*S169'
.param V25_part18='V25_part17+8.931145e-01*S170+(-2.783422e-01)*S171+(-6.424205e-01)*S172+(-2.991063e-01)*S173+(-2.402565e-01)*S174+(-7.120693e-01)*S175+(-4.776091e-01)*S176+(-2.192879e-01)*S177+(-7.031247e-01)*S178+9.968942e-02*S179'
.param V25_part19='V25_part18+1.365294e-01*S180+(-1.259765e-01)*S181+(-3.721969e-01)*S182+(-5.797925e-01)*S183+(-5.473615e-01)*S184+1.966058e-01*S185+(-2.345356e-01)*S186+(-7.417149e-01)*S187+(-4.853296e-01)*S188+(-2.346375e-01)*S189'
.param V25_part20='V25_part19+7.260947e-02*S190+(-5.693912e-01)*S191+(-1.336181e-01)*S192+(-8.035508e-01)*S193+2.726872e-01*S194+2.342661e-04*S195+(-2.160294e-01)*S196+4.677929e-02*S197+8.662265e-02*S198+1.119897e-01*S199'
.param V25_part21='V25_part20+(-3.857873e-02)*S200+(-2.975144e-01)*S201+1.747719e-01*S202+(-2.903173e-02)*S203+(-2.694181e-01)*S204+(-1.105275e+00)*S205+(-4.604858e-02)*S206+(-2.656329e-01)*S207+(-2.819452e-02)*S208+6.268581e-01*S209'
.param V25_part22='V25_part21+(-5.378222e-01)*S210+8.957880e-02*S211+1.759514e+00*S212+2.089552e-03*S213+(-5.603915e+00)*S214+4.468257e-01*S215+(-1.554736e-01)*S216+(-2.979102e-01)*S217+4.876879e-01*S218+(-1.401339e-01)*S219'
.param V25_part23='V25_part22+1.611454e-01*S220+1.891006e-01*S221+2.479717e-01*S222+2.395127e-01*S223+2.038623e-01*S224+(-8.956424e-01)*S225+(-3.227522e-01)*S226+1.982033e-02*S227+2.396470e-01*S228+(-1.104271e-01)*S229'
.param V25_part24='V25_part23+1.470021e-01*S230+(-2.111939e-01)*S231+(-7.405009e-01)*S232+2.584274e-01*S233+(-6.955129e-02)*S234+(-5.454697e-01)*S235+1.934066e-01*S236+2.006175e-01*S237+(-3.791169e-01)*S238+8.739732e-02*S239'
.param V25_part25='V25_part24+2.882311e-02*S240+(-2.553515e-01)*S241+(-7.596427e-02)*S242+(-2.663872e-03)*S243+7.814719e-02*S244+1.265002e-01*S245+1.628739e-02*S246+(-5.898621e-01)*S247+2.185971e-01*S248+1.611878e-01*S249'
.param V25_part26='V25_part25+(-5.870368e-01)*S250+2.203836e-01*S251+(-5.323549e-02)*S252+(-4.377618e-01)*S253+1.972403e-01*S254+(-3.790653e-01)*S255+(-1.476021e-01)*S256+2.420633e-01*S257+1.669104e-01*S258+(-4.865089e-01)*S259'
.param V25_part27='V25_part26+2.117355e-01*S260+(-1.104185e-01)*S261+(-6.220572e-01)*S262+2.937611e-01*S263+(-8.943601e-01)*S264+(-7.102935e-01)*S265+1.695611e-01*S266+(-1.643394e-01)*S267+(-9.762495e-01)*S268+1.514310e-01*S269'
.param V25_part28='V25_part27+1.275813e-01*S270+1.302463e-01*S271+2.403536e-01*S272+1.826725e-01*S273+(-1.022804e-01)*S274+2.293105e-01*S275+1.309539e-02*S276+6.841099e-02*S277+2.448608e-01*S278+2.399735e-01*S279'
.param V25_part29='V25_part28+(-1.312461e-01)*S280+2.497398e-01*S281+2.661767e-01*S282+1.223941e-01*S283+2.169719e-01*S284+(-1.309072e-01)*S285+7.950260e-02*S286+2.626359e-01*S287+5.329492e-02*S288+1.175051e-02*S289'
.param V25_part30='V25_part29+2.669884e-01*S290+3.767125e-02*S291+1.133858e-01*S292+2.619329e-01*S293+5.763913e-02*S294+(-6.933047e-02)*S295+2.874168e-01*S296+6.588409e-02*S297+(-5.666286e-01)*S298+2.768783e-01*S299'
.param V25_part31='V25_part30+1.349864e-01*S300+1.209506e-01*S301+2.653486e-01*S302+6.059313e-03*S303+6.366437e-02*S304+5.879091e-02*S305+(-1.738050e-02)*S306+1.798141e-01*S307+2.417337e-01*S308+1.886675e-02*S309'
.param V25='V25_part31+(-6.206046e-01)*S310+2.460626e-01*S311+2.793972e-02*S312+(-6.780660e-01)*S313+2.510259e-01*S314'
.param V26_part1='9.630945e-02*S0+3.443220e-01*S1+1.968995e-01*S2+6.858771e-01*S3+5.386850e-01*S4+2.816720e-01*S5+4.603105e-01*S6+3.104540e-01*S7+1.368142e-01*S8+3.079530e+00*S9'
.param V26_part2='V26_part1+1.422033e-01*S10+8.481390e-02*S11+2.812890e+00*S12+1.075852e-01*S13+3.751417e-01*S14+3.034769e-01*S15+2.614240e-01*S16+2.319955e-01*S17+4.013651e-02*S18+4.706000e-01*S19'
.param V26_part3='V26_part2+2.080670e-01*S20+4.390352e-01*S21+3.561894e-01*S22+1.715070e-01*S23+3.555002e-01*S24+2.847161e-01*S25+2.418271e-01*S26+3.301854e-01*S27+2.310060e-01*S28+1.481568e-01*S29'
.param V26_part4='V26_part3+6.009936e-01*S30+(-1.107399e-01)*S31+4.111574e-01*S32+4.909616e-01*S33+5.277970e-01*S34+3.116340e-01*S35+3.945661e-01*S36+5.520555e-01*S37+3.332574e-01*S38+3.910472e-01*S39'
.param V26_part5='V26_part4+6.000174e-01*S40+3.022545e-01*S41+2.855790e-01*S42+5.530078e-01*S43+2.491852e-01*S44+6.774296e-01*S45+5.419850e-01*S46+5.162922e-01*S47+4.727233e-01*S48+5.288921e-01*S49'
.param V26_part6='V26_part5+2.704436e-01*S50+4.518182e-01*S51+4.351362e-01*S52+3.262886e-01*S53+3.927526e-01*S54+4.091327e-01*S55+2.654697e-01*S56+3.359395e-01*S57+2.221793e-01*S58+1.760399e-01*S59'
.param V26_part7='V26_part6+7.035058e-01*S60+5.381973e-01*S61+4.323096e-01*S62+5.061303e-01*S63+4.512084e-01*S64+4.032610e-01*S65+5.053855e-01*S66+2.895580e-01*S67+2.630392e-01*S68+1.761561e-01*S69'
.param V26_part8='V26_part7+1.494445e-01*S70+1.993753e-01*S71+2.096864e-01*S72+2.153422e-02*S73+3.752212e-03*S74+1.187867e+00*S75+(-2.119759e-01)*S76+8.606928e-01*S77+(-2.023222e-03)*S78+(-2.889472e-02)*S79'
.param V26_part9='V26_part8+(-1.614522e-01)*S80+(-1.636003e-02)*S81+4.175550e-01*S82+4.068114e-01*S83+4.043095e-01*S84+3.676073e-01*S85+4.338724e-01*S86+3.324999e-01*S87+4.133586e-01*S88+2.920658e-01*S89'
.param V26_part10='V26_part9+7.163305e-01*S90+5.598436e-01*S91+4.942534e-01*S92+6.345000e-01*S93+4.868906e-01*S94+4.001671e-01*S95+5.340743e-01*S96+(-5.548587e-03)*S97+(-3.411001e-02)*S98+4.921248e-01*S99'
.param V26_part11='V26_part10+3.876359e-01*S100+2.295301e-01*S101+4.025298e-01*S102+3.263126e-01*S103+2.351732e-01*S104+7.015637e-01*S105+4.421191e-01*S106+3.801839e-02*S107+6.635822e-01*S108+3.851528e-01*S109'
.param V26_part12='V26_part11+2.789519e-03*S110+6.042860e-01*S111+3.354040e-01*S112+7.014862e-03*S113+8.750195e-02*S114+3.119201e-01*S115+7.974871e-02*S116+4.611894e-01*S117+3.246782e-01*S118+4.849459e-02*S119'
.param V26_part13='V26_part12+7.284087e-01*S120+4.445742e-01*S121+1.853680e-03*S122+5.878863e-01*S123+2.613116e-01*S124+(-6.277063e-02)*S125+5.054481e-01*S126+5.007940e-03*S127+(-8.072252e-02)*S128+4.145331e-01*S129'
.param V26_part14='V26_part13+1.275337e-02*S130+(-7.217190e-02)*S131+3.684561e-01*S132+2.627105e-01*S133+(-2.137345e-03)*S134+8.832872e-01*S135+7.151077e-01*S136+(-1.422209e-03)*S137+5.479423e-01*S138+6.190667e-01*S139'
.param V26_part15='V26_part14+8.683861e-02*S140+4.810002e-01*S141+4.905587e-02*S142+2.441315e+00*S143+4.032348e-01*S144+3.260152e-01*S145+2.830699e-01*S146+3.720762e-01*S147+2.911072e-01*S148+1.669054e-01*S149'
.param V26_part16='V26_part15+6.774146e-01*S150+(-4.262981e-02)*S151+5.658141e-02*S152+5.968816e-01*S153+(-1.830917e-01)*S154+(-6.572497e-02)*S155+5.384822e-01*S156+6.854254e-01*S157+7.071989e-02*S158+4.099322e-01*S159'
.param V26_part17='V26_part16+5.627935e-01*S160+(-3.829584e-04)*S161+3.940636e-01*S162+5.352915e-01*S163+2.211510e-03*S164+3.539565e-01*S165+3.363184e-01*S166+(-7.275820e-02)*S167+5.975675e-01*S168+1.892744e+01*S169'
.param V26_part18='V26_part17+(-5.398544e-01)*S170+5.460446e-01*S171+6.719302e-01*S172+2.036459e-01*S173+4.309100e-01*S174+5.735858e-01*S175+8.030344e-02*S176+3.489632e-01*S177+5.018358e-01*S178+1.468904e-02*S179'
.param V26_part19='V26_part18+3.663152e-01*S180+(-2.031652e-01)*S181+(-2.308152e-01)*S182+(-1.912868e-01)*S183+(-2.447546e-01)*S184+1.146835e-01*S185+5.259047e-01*S186+(-1.132222e-01)*S187+3.170800e-02*S188+4.134444e-01*S189'
.param V26_part20='V26_part19+3.823616e-01*S190+3.669480e-03*S191+3.000984e-01*S192+5.544543e-01*S193+9.576833e-03*S194+6.217859e-01*S195+3.607674e-01*S196+1.303186e-01*S197+1.893373e-01*S198+6.886183e-02*S199'
.param V26_part21='V26_part20+1.743288e-01*S200+6.042532e-01*S201+(-1.387024e-02)*S202+1.507364e-01*S203+4.352932e-01*S204+6.071878e-02*S205+1.504846e-01*S206+3.597759e-01*S207+4.515359e-01*S208+(-3.850371e-02)*S209'
.param V26_part22='V26_part21+7.218036e-01*S210+(-1.350700e-01)*S211+(-2.036970e-01)*S212+3.823438e-01*S213+6.698904e+00*S214+(-1.266989e-01)*S215+4.563715e-01*S216+4.431048e-01*S217+(-3.381582e-01)*S218+3.663248e-01*S219'
.param V26_part23='V26_part22+3.613394e-01*S220+6.236075e-03*S221+(-1.049700e-02)*S222+1.035299e-02*S223+5.919501e-03*S224+1.259547e+00*S225+3.929964e-01*S226+5.585102e-02*S227+(-8.175451e-02)*S228+3.030574e-01*S229'
.param V26_part24='V26_part23+2.150507e-02*S230+5.055239e-01*S231+(-2.936621e-01)*S232+(-1.223133e-02)*S233+3.083022e-01*S234+4.707568e-01*S235+5.596844e-02*S236+6.159081e-02*S237+2.919961e-01*S238+6.826976e-02*S239'
.param V26_part25='V26_part24+2.490820e-01*S240+4.144852e-02*S241+5.509731e-02*S242+3.675644e-01*S243+1.014911e-01*S244+4.667999e-02*S245+2.463131e-01*S246+6.184298e-01*S247+8.097410e-03*S248+8.680141e-02*S249'
.param V26_part26='V26_part25+4.871718e-01*S250+(-2.534125e-03)*S251+2.624282e-01*S252+(-6.993749e-02)*S253+1.765068e-02*S254+(-5.755899e-01)*S255+(-2.196655e-01)*S256+5.307689e-02*S257+1.207410e-01*S258+(-2.338536e-01)*S259'
.param V26_part27='V26_part26+8.415053e-02*S260+4.300075e-01*S261+6.347262e-01*S262+(-5.332707e-02)*S263+(-1.476514e-01)*S264+5.947265e-01*S265+6.745587e-02*S266+3.126854e-01*S267+(-9.042287e-02)*S268+7.610236e-02*S269'
.param V26_part28='V26_part27+2.254848e-01*S270+(-1.149053e-01)*S271+(-5.121429e-02)*S272+(-1.052525e-01)*S273+(-7.952838e-02)*S274+(-6.525377e-03)*S275+3.083194e-01*S276+(-6.730235e-02)*S277+(-5.511510e-03)*S278+2.016727e-02*S279'
.param V26_part29='V26_part28+2.076081e-01*S280+(-3.935043e-03)*S281+1.278314e-02*S282+3.265588e-01*S283+4.440975e-03*S284+2.766859e-01*S285+9.691114e-02*S286+(-4.000718e-02)*S287+3.235720e-01*S288+1.611013e-01*S289'
.param V26_part30='V26_part29+(-1.895207e-02)*S290+2.909186e-01*S291+(-8.331851e-02)*S292+(-1.757245e-02)*S293+2.323213e-01*S294+2.216803e-01*S295+(-3.422751e-02)*S296+9.269424e-02*S297+4.603428e-01*S298+(-1.020792e-02)*S299'
.param V26_part31='V26_part30+2.019461e-01*S300+(-1.032402e-01)*S301+4.064014e-02*S302+3.342666e-01*S303+1.200549e-01*S304+6.281843e-02*S305+3.248312e-01*S306+(-8.876960e-02)*S307+(-1.849188e-02)*S308+2.485308e-01*S309'
.param V26='V26_part31+5.449587e-01*S310+(-1.081789e-02)*S311+2.049484e-01*S312+4.930544e-01*S313+4.050911e-03*S314'
.param V27_part1='2.278203e-01*S0+2.288999e-01*S1+7.571848e-02*S2+3.491937e-01*S3+2.168290e-01*S4+6.688480e-02*S5+2.152758e-01*S6+7.640277e-02*S7+2.381574e-02*S8+1.856787e+00*S9'
.param V27_part2='V27_part1+3.712558e-02*S10+6.723482e-03*S11+2.152274e+00*S12+2.255427e-02*S13+5.177039e-02*S14+9.547089e-02*S15+8.202178e-02*S16+4.720800e-02*S17+(-7.692771e-02)*S18+6.727069e-02*S19'
.param V27_part3='V27_part2+2.127799e-02*S20+3.928326e-02*S21+2.805741e-02*S22+1.210283e-02*S23+(-3.580282e-03)*S24+(-1.968983e-03)*S25+(-6.866963e-03)*S26+(-5.549937e-02)*S27+(-5.309415e-03)*S28+(-9.626693e-03)*S29'
.param V27_part4='V27_part3+1.132117e-02*S30+(-7.075488e-02)*S31+6.447791e-04*S32+(-3.997055e-02)*S33+(-5.466723e-03)*S34+(-2.805881e-02)*S35+(-9.436097e-02)*S36+(-3.716930e-02)*S37+(-2.878097e-02)*S38+(-1.493973e-01)*S39'
.param V27_part5='V27_part4+(-5.863403e-02)*S40+(-5.807026e-02)*S41+(-2.300934e-01)*S42+(-8.030772e-02)*S43+(-6.259258e-02)*S44+2.641022e-02*S45+1.292318e-01*S46+1.304726e-02*S47+(-3.408767e-02)*S48+1.760110e-02*S49'
.param V27_part6='V27_part5+(-4.052190e-02)*S50+(-4.084543e-02)*S51+1.502895e-03*S52+(-6.391852e-02)*S53+(-1.074334e-01)*S54+(-1.451446e-01)*S55+(-1.220080e-01)*S56+(-1.952706e-01)*S57+(-2.031413e-01)*S58+(-7.804632e-02)*S59'
.param V27_part7='V27_part6+9.070100e-03*S60+4.028189e-02*S61+(-1.122822e-02)*S62+(-6.095734e-02)*S63+(-3.874041e-02)*S64+(-1.759464e-02)*S65+(-1.147006e-01)*S66+(-4.414125e-02)*S67+(-7.038643e-02)*S68+(-8.414589e-02)*S69'
.param V27_part8='V27_part7+(-1.737046e-01)*S70+(-7.503643e-02)*S71+(-8.015441e-02)*S72+(-7.618510e-02)*S73+(-4.939737e-04)*S74+1.509909e-01*S75+(-7.304541e-02)*S76+7.010312e-02*S77+(-6.680189e-02)*S78+(-7.664404e-02)*S79'
.param V27_part9='V27_part8+(-8.157127e-02)*S80+(-1.183430e-01)*S81+1.770875e-03*S82+1.027143e-04*S83+(-1.185039e-02)*S84+(-2.296373e-02)*S85+(-1.717604e-02)*S86+(-5.096399e-02)*S87+(-5.334758e-02)*S88+(-2.784494e-02)*S89'
.param V27_part10='V27_part9+(-1.179214e-01)*S90+(-1.281028e-02)*S91+(-1.131741e-01)*S92+(-1.291218e-01)*S93+(-2.255807e-01)*S94+(-1.167722e-01)*S95+(-3.047425e-01)*S96+(-6.339618e-02)*S97+(-6.014137e-02)*S98+(-4.546543e-01)*S99'
.param V27_part11='V27_part10+(-1.602645e-01)*S100+(-5.299212e-02)*S101+(-5.307055e-01)*S102+(-1.439039e-01)*S103+(-5.443072e-02)*S104+(-7.847941e-02)*S105+(-2.300815e-02)*S106+(-7.520158e-02)*S107+(-1.857968e-01)*S108+(-2.665727e-01)*S109'
.param V27_part12='V27_part11+(-6.491367e-02)*S110+(-3.790651e-01)*S111+(-1.625376e-01)*S112+(-5.729757e-02)*S113+(-2.047885e-01)*S114+(-3.042045e-01)*S115+(-2.590279e-02)*S116+(-3.299205e-01)*S117+(-6.873624e-02)*S118+(-7.627883e-02)*S119'
.param V27_part13='V27_part12+(-2.312227e-01)*S120+(-2.380072e-01)*S121+(-5.753799e-02)*S122+(-2.653688e-01)*S123+(-3.232930e-01)*S124+(-5.700376e-02)*S125+(-4.409495e-01)*S126+9.217936e-03*S127+(-7.126758e-02)*S128+(-4.451418e-01)*S129'
.param V27_part14='V27_part13+6.771836e-02*S130+(-8.776187e-02)*S131+(-3.085512e-01)*S132+(-1.358199e-01)*S133+(-8.333006e-02)*S134+4.497385e-02*S135+8.424882e-02*S136+(-5.843560e-02)*S137+(-1.178202e-01)*S138+(-8.287691e-04)*S139'
.param V27_part15='V27_part14+(-6.183906e-02)*S140+(-1.418162e-01)*S141+(-4.512467e-02)*S142+(-7.953305e-02)*S143+(-2.730308e-01)*S144+(-3.417773e-01)*S145+(-8.466293e-02)*S146+(-2.827109e-01)*S147+(-2.416261e-01)*S148+(-8.447123e-02)*S149'
.param V27_part16='V27_part15+(-4.282667e-01)*S150+5.357332e-02*S151+7.106456e-02*S152+(-4.166674e-01)*S153+2.748973e-01*S154+3.626917e-01*S155+(-2.196274e-01)*S156+4.433298e-01*S157+9.231633e-02*S158+(-2.859497e-01)*S159'
.param V27_part17='V27_part16+4.549603e-01*S160+(-4.889477e-02)*S161+(-2.801872e-01)*S162+5.470779e-01*S163+(-3.207915e-02)*S164+(-4.671806e-01)*S165+(-2.149957e-01)*S166+(-1.812502e-02)*S167+(-2.816176e-01)*S168+(-5.245038e+00)*S169'
.param V27_part18='V27_part17+(-2.811352e+00)*S170+(-1.897226e-01)*S171+4.599333e-01*S172+(-4.842576e-01)*S173+(-1.429251e-01)*S174+5.150679e-01*S175+3.189218e-01*S176+(-1.776803e-01)*S177+5.532161e-01*S178+8.104161e-02*S179'
.param V27_part19='V27_part18+(-4.135488e-01)*S180+1.965046e-01*S181+3.212098e-01*S182+3.770222e-01*S183+4.226534e-01*S184+(-9.814347e-02)*S185+(-1.957455e-01)*S186+5.602865e-01*S187+3.608237e-01*S188+(-1.741370e-01)*S189'
.param V27_part20='V27_part19+(-8.926967e-01)*S190+3.834178e-01*S191+(-1.635970e-01)*S192+5.594329e-01*S193+(-2.915463e-03)*S194+(-2.077782e-01)*S195+(-1.466318e-01)*S196+1.418660e-01*S197+(-5.566172e-01)*S198+(-2.465822e-01)*S199'
.param V27_part21='V27_part20+1.701864e-01*S200+(-4.174977e-01)*S201+7.548981e-02*S202+1.461988e-01*S203+(-4.245008e-01)*S204+6.629925e-01*S205+1.599086e-01*S206+(-3.000704e-01)*S207+(-8.918050e-01)*S208+(-5.982012e-02)*S209'
.param V27_part22='V27_part21+(-7.794458e-01)*S210+1.670321e-01*S211+(-5.972832e+00)*S212+(-4.289413e-02)*S213+(-1.616445e+00)*S214+(-2.366422e+00)*S215+(-1.684600e-01)*S216+6.115627e-02*S217+(-2.275870e+00)*S218+(-1.518849e-01)*S219'
.param V27_part23='V27_part22+(-8.812571e-01)*S220+5.933751e-02*S221+3.210562e-02*S222+(-2.093095e-02)*S223+4.685427e-02*S224+(-1.570186e+00)*S225+(-2.761613e-01)*S226+1.984815e-01*S227+1.002211e-01*S228+2.954330e-01*S229'
.param V27_part24='V27_part23+7.577503e-02*S230+(-8.459820e-02)*S231+5.584165e-01*S232+(-2.774617e-02)*S233+(-1.218833e-01)*S234+4.621729e-01*S235+(-1.322894e-01)*S236+(-1.152085e-01)*S237+4.117614e-01*S238+(-1.085607e-01)*S239'
.param V27_part25='V27_part24+(-1.887471e-01)*S240+2.561662e-01*S241+(-4.150263e-02)*S242+4.232100e-02*S243+2.022517e-01*S244+1.012804e-01*S245+(-1.017194e-02)*S246+4.893538e-01*S247+4.151171e-02*S248+3.099093e-02*S249'
.param V27_part26='V27_part25+4.907472e-01*S250+3.994417e-02*S251+(-1.228787e-01)*S252+2.888765e-01*S253+4.731013e-02*S254+5.695403e-01*S255+2.252614e-01*S256+(-8.495489e-02)*S257+(-2.027792e-01)*S258+4.159615e-01*S259'
.param V27_part27='V27_part26+(-9.678363e-02)*S260+3.446682e-02*S261+4.973966e-01*S262+(-4.365279e-02)*S263+1.151553e+00*S264+4.974868e-01*S265+(-1.358043e-01)*S266+(-2.592145e-01)*S267+5.426302e-01*S268+(-1.533318e-01)*S269'
.param V27_part28='V27_part27+1.875355e-02*S270+1.825779e-01*S271+1.594149e-02*S272+1.472668e-01*S273+2.145635e-01*S274+3.540798e-02*S275+6.814931e-02*S276+1.522773e-01*S277+1.527268e-02*S278+3.062711e-02*S279'
.param V27_part29='V27_part28+3.011446e-01*S280+6.020167e-03*S281+1.198245e-03*S282+(-8.017681e-01)*S283+4.006940e-02*S284+(-2.039719e-01)*S285+2.006464e-01*S286+(-1.288981e-02)*S287+3.502855e-02*S288+2.581998e-01*S289'
.param V27_part30='V27_part29+(-1.720209e-02)*S290+5.343590e-02*S291+1.596772e-01*S292+4.780104e-03*S293+6.856434e-03*S294+1.923524e-01*S295+(-8.780680e-03)*S296+2.271733e-02*S297+4.547969e-01*S298+(-1.524317e-02)*S299'
.param V27_part31='V27_part30+(-2.003554e-02)*S300+1.804960e-01*S301+(-7.654505e-02)*S302+4.558506e-02*S303+2.158302e-01*S304+1.460657e-01*S305+4.247795e-02*S306+1.346245e-01*S307+2.553668e-02*S308+1.594169e-05*S309'
.param V27='V27_part31+4.474243e-01*S310+2.291226e-02*S311+3.407939e-02*S312+4.714457e-01*S313+1.992768e-02*S314'
.param V28_part1='(-4.171554e-02)*S0+(-1.739720e-02)*S1+(-2.012783e-02)*S2+(-6.760743e-02)*S3+(-6.807278e-02)*S4+(-3.597807e-02)*S5+(-1.118137e-01)*S6+(-7.848378e-02)*S7+(-6.003418e-02)*S8+(-7.376171e-01)*S9'
.param V28_part2='V28_part1+(-7.173524e-02)*S10+(-5.790886e-02)*S11+(-8.063906e-01)*S12+(-7.991241e-02)*S13+4.141519e-01*S14+(-8.801390e-02)*S15+(-8.366335e-02)*S16+(-7.544916e-02)*S17+1.432358e+00*S18+(-9.171365e-02)*S19'
.param V28_part3='V28_part2+(-8.404414e-02)*S20+(-1.229165e-01)*S21+(-1.104884e-01)*S22+(-9.076273e-02)*S23+(-1.348653e-01)*S24+(-1.203642e-01)*S25+(-1.067362e-01)*S26+(-1.409295e-01)*S27+(-1.213963e-01)*S28+(-9.687956e-02)*S29'
.param V28_part4='V28_part3+(-1.044461e-01)*S30+2.209016e+00*S31+(-1.031765e-01)*S32+(-1.404423e-01)*S33+(-1.339205e-01)*S34+(-9.930106e-02)*S35+(-1.449326e-01)*S36+(-1.616756e-01)*S37+(-1.181768e-01)*S38+(-1.483089e-01)*S39'
.param V28_part5='V28_part4+(-2.141902e-01)*S40+(-1.279681e-01)*S41+(-1.541217e-01)*S42+(-2.340783e-01)*S43+(-1.283192e-01)*S44+(-1.025069e-01)*S45+(-7.991516e-02)*S46+(-7.441399e-02)*S47+(-1.226118e-01)*S48+(-1.187055e-01)*S49'
.param V28_part6='V28_part5+(-9.302287e-02)*S50+(-1.540270e-01)*S51+(-1.284255e-01)*S52+(-1.148409e-01)*S53+(-1.413978e-01)*S54+(-1.631577e-01)*S55+(-1.459290e-01)*S56+(-1.691878e-01)*S57+(-1.689105e-01)*S58+(-1.387086e-01)*S59'
.param V28_part7='V28_part6+(-1.372162e-01)*S60+(-1.143678e-01)*S61+(-8.493592e-02)*S62+(-1.390885e-01)*S63+(-1.151175e-01)*S64+(-9.958711e-02)*S65+(-1.530746e-01)*S66+(-1.468045e-01)*S67+(-1.206918e-01)*S68+(-6.798219e-02)*S69'
.param V28_part8='V28_part7+(-1.211337e-01)*S70+(-1.382028e-01)*S71+(-1.476807e-01)*S72+(-1.180632e-01)*S73+(-1.525992e-02)*S74+(-2.039574e-01)*S75+4.151939e+00*S76+(-1.876771e-01)*S77+3.162508e+00*S78+3.538055e+00*S79'
.param V28_part9='V28_part8+4.398894e+00*S80+4.071883e+00*S81+(-1.941902e-01)*S82+(-1.791154e-01)*S83+(-2.050190e-01)*S84+(-1.932782e-01)*S85+(-1.789085e-01)*S86+(-1.987353e-01)*S87+(-2.060015e-01)*S88+(-1.665689e-01)*S89'
.param V28_part10='V28_part9+(-1.085349e-01)*S90+(-9.612506e-02)*S91+(-8.662064e-02)*S92+(-1.367814e-01)*S93+(-1.257657e-01)*S94+(-1.252658e-01)*S95+(-1.648238e-01)*S96+(-9.503037e-02)*S97+(-6.336752e-02)*S98+(-1.865530e-01)*S99'
.param V28_part11='V28_part10+(-1.611997e-01)*S100+(-1.373079e-01)*S101+(-1.901546e-01)*S102+(-1.601314e-01)*S103+(-1.486659e-01)*S104+(-9.459700e-02)*S105+(-9.034072e-02)*S106+(-2.813751e-02)*S107+(-1.426537e-01)*S108+(-1.021878e-01)*S109'
.param V28_part12='V28_part11+(-4.730189e-02)*S110+(-1.676926e-01)*S111+(-1.193271e-01)*S112+(-6.594334e-02)*S113+(-8.204576e-02)*S114+(-1.252064e-01)*S115+(-8.280418e-02)*S116+(-1.713576e-01)*S117+(-1.170263e-01)*S118+(-1.090982e-01)*S119'
.param V28_part13='V28_part12+(-9.791693e-02)*S120+(-7.085938e-02)*S121+(-3.685136e-02)*S122+(-1.376982e-01)*S123+(-8.100011e-02)*S124+(-4.637772e-02)*S125+(-1.527407e-01)*S126+(-7.146702e-02)*S127+(-5.491212e-02)*S128+(-1.613217e-01)*S129'
.param V28_part14='V28_part13+(-5.355372e-02)*S130+(-6.827104e-02)*S131+(-1.551504e-01)*S132+(-1.320272e-01)*S133+(-8.328506e-02)*S134+(-1.515226e-01)*S135+(-1.308646e-01)*S136+(-5.909643e-02)*S137+(-1.885523e-01)*S138+(-1.643109e-01)*S139'
.param V28_part15='V28_part14+(-7.585744e-02)*S140+(-1.734636e-01)*S141+(-1.210286e-01)*S142+(-3.123999e-01)*S143+(-1.731621e-01)*S144+(-1.671876e-01)*S145+(-1.358293e-01)*S146+(-1.836075e-01)*S147+(-1.670159e-01)*S148+(-1.366091e-01)*S149'
.param V28_part16='V28_part15+(-7.601863e-02)*S150+(-1.092420e-02)*S151+(-4.513212e-03)*S152+(-1.175349e-01)*S153+(-1.741738e-02)*S154+(-2.704444e-02)*S155+(-1.229266e-01)*S156+1.501759e-02*S157+(-7.948954e-03)*S158+(-1.158205e-01)*S159'
.param V28_part17='V28_part16+1.510654e-02*S160+(-3.389394e-02)*S161+(-1.161987e-01)*S162+2.546342e-02*S163+(-3.080375e-02)*S164+(-2.525512e-02)*S165+7.112987e-03*S166+(-8.163608e-03)*S167+(-1.042425e-01)*S168+7.930341e-01*S169'
.param V28_part18='V28_part17+(-4.903274e-03)*S170+(-1.009664e-01)*S171+1.138370e-02*S172+2.556624e-02*S173+(-1.020862e-01)*S174+2.828157e-02*S175+(-1.921548e-02)*S176+(-9.486051e-02)*S177+3.643621e-02*S178+(-1.532448e-02)*S179'
.param V28_part19='V28_part18+(-5.001643e-02)*S180+(-1.050626e-02)*S181+(-2.570423e-02)*S182+(-4.166218e-02)*S183+(-3.235346e-02)*S184+(-2.350967e-03)*S185+(-1.114047e-01)*S186+(-3.286803e-02)*S187+(-1.786122e-02)*S188+(-1.197338e-01)*S189'
.param V28_part20='V28_part19+(-4.166972e-02)*S190+(-2.251893e-02)*S191+(-9.570784e-02)*S192+3.002944e-02*S193+(-3.846686e-03)*S194+(-1.088440e-01)*S195+4.049200e-04*S196+(-5.136250e-03)*S197+(-1.606985e-02)*S198+(-1.249101e-02)*S199'
.param V28_part21='V28_part20+(-8.204799e-03)*S200+(-1.530163e-01)*S201+(-3.383804e-02)*S202+(-1.528512e-02)*S203+(-1.495908e-01)*S204+(-5.042915e-02)*S205+(-1.076146e-02)*S206+(-1.451682e-01)*S207+(-2.703861e-03)*S208+8.592238e-03*S209'
.param V28_part22='V28_part21+1.552157e-02*S210+(-5.702087e-03)*S211+(-2.630458e-02)*S212+(-4.480830e-02)*S213+3.222222e-01*S214+(-3.414235e-03)*S215+(-1.034343e-01)*S216+(-7.393255e-02)*S217+3.286640e-05*S218+(-9.556456e-02)*S219'
.param V28_part23='V28_part22+6.364285e-03*S220+(-3.838361e-03)*S221+(-1.512363e-02)*S222+(-1.111368e-02)*S223+(-5.862608e-03)*S224+3.613478e-02*S225+1.213922e-02*S226+(-1.027061e-03)*S227+(-9.419903e-03)*S228+7.239793e-03*S229'
.param V28_part24='V28_part23+(-5.207609e-06)*S230+(-8.023966e-02)*S231+(-4.673248e-02)*S232+(-1.711851e-03)*S233+(-8.781746e-02)*S234+9.325309e-03*S235+(-7.531495e-03)*S236+(-2.919278e-02)*S237+(-3.396707e-03)*S238+(-6.007904e-03)*S239'
.param V28_part25='V28_part24+(-2.471044e-04)*S240+(-1.475426e-02)*S241+(-5.527690e-03)*S242+(-4.934235e-04)*S243+(-2.360891e-03)*S244+(-1.392388e-03)*S245+(-3.039321e-03)*S246+1.472103e-02*S247+(-1.468254e-03)*S248+(-3.018994e-02)*S249'
.param V28_part26='V28_part25+2.011450e-02*S250+(-2.994437e-03)*S251+(-6.223327e-02)*S252+(-2.081223e-02)*S253+(-4.054012e-03)*S254+(-2.967866e-02)*S255+(-1.022557e-02)*S256+(-3.840866e-03)*S257+(-5.788202e-02)*S258+(-1.386461e-02)*S259'
.param V28_part27='V28_part26+(-3.351002e-03)*S260+1.574027e-02*S261+4.503730e-03*S262+(-9.326390e-03)*S263+(-8.021253e-02)*S264+3.810872e-02*S265+(-6.329573e-03)*S266+(-1.085534e-01)*S267+(-5.719752e-02)*S268+(-1.502175e-04)*S269'
.param V28_part28='V28_part27+(-1.291770e-03)*S270+(-1.685368e-03)*S271+(-8.326194e-04)*S272+(-1.107863e-02)*S273+(-8.345266e-03)*S274+8.353438e-04*S275+4.086354e-03*S276+(-2.609181e-03)*S277+(-8.516262e-04)*S278+(-8.517651e-03)*S279'
.param V28_part29='V28_part28+(-3.079247e-03)*S280+1.923578e-04*S281+(-7.576465e-03)*S282+4.416049e-03*S283+(-2.563747e-03)*S284+1.591155e-02*S285+(-2.018455e-03)*S286+(-2.232657e-03)*S287+6.551426e-03*S288+(-3.587937e-03)*S289'
.param V28_part30='V28_part29+(-3.664070e-04)*S290+(-6.763167e-04)*S291+(-7.513677e-03)*S292+(-2.521608e-03)*S293+1.813641e-03*S294+(-1.846741e-03)*S295+(-1.406947e-03)*S296+(-7.508326e-04)*S297+2.280181e-02*S298+(-1.204009e-03)*S299'
.param V28_part31='V28_part30+(-1.455399e-02)*S300+(-5.632236e-03)*S301+(-1.496514e-04)*S302+(-4.147602e-03)*S303+(-5.216598e-03)*S304+(-4.203983e-04)*S305+6.570340e-03*S306+(-3.175772e-03)*S307+(-1.069780e-03)*S308+(-4.179287e-03)*S309'
.param V28='V28_part31+1.985190e-03*S310+(-3.551976e-03)*S311+(-1.383606e-03)*S312+8.762731e-03*S313+2.516971e-04*S314'
.param V29_part1='(-4.785533e-04)*S0+(-6.147965e-04)*S1+(-1.283595e-04)*S2+(-7.684881e-04)*S3+(-1.426860e-03)*S4+(-1.985354e-03)*S5+(-1.803771e-04)*S6+(-3.877964e-04)*S7+(-5.643542e-04)*S8+3.101284e-02*S9'
.param V29_part2='V29_part1+(-3.155485e-04)*S10+(-7.137051e-04)*S11+3.646321e-02*S12+1.714603e-05*S13+6.946478e-04*S14+1.015723e-03*S15+1.328770e-03*S16+1.294182e-03*S17+9.287729e-04*S18+1.568632e-03*S19'
.param V29_part3='V29_part2+9.236038e-04*S20+1.500639e-03*S21+1.295905e-03*S22+6.286103e-04*S23+1.017103e-03*S24+8.186744e-04*S25+6.948385e-04*S26+7.232814e-04*S27+7.291628e-04*S28+2.248161e-04*S29'
.param V29_part4='V29_part3+2.772104e-03*S30+(-2.265932e-03)*S31+2.031532e-03*S32+(-1.183744e-03)*S33+(-1.859394e-03)*S34+(-3.819961e-04)*S35+(-2.626821e-03)*S36+1.269381e-03*S37+1.466979e-03*S38+(-4.102969e-03)*S39'
.param V29_part5='V29_part4+(-4.705349e-04)*S40+4.615635e-04*S41+(-3.920629e-03)*S42+(-1.505740e-04)*S43+(-3.398642e-04)*S44+1.961996e-03*S45+4.406051e-03*S46+9.003553e-03*S47+9.028320e-05*S48+3.544844e-03*S49'
.param V29_part6='V29_part5+3.132895e-03*S50+(-2.974426e-03)*S51+1.032504e-04*S52+4.381964e-03*S53+(-1.169095e-03)*S54+6.096011e-04*S55+1.371751e-02*S56+(-2.655926e-03)*S57+(-6.562589e-03)*S58+(-3.681409e-03)*S59'
.param V29_part7='V29_part6+6.717187e-03*S60+8.366555e-03*S61+1.112020e-02*S62+1.473800e-03*S63+5.621119e-03*S64+9.122995e-03*S65+1.645154e-04*S66+1.134524e-02*S67+1.252672e-02*S68+5.523816e-03*S69'
.param V29_part8='V29_part7+1.000402e-02*S70+(-1.532567e-03)*S71+2.451013e-04*S72+(-1.755020e-03)*S73+2.322098e-03*S74+5.110364e-02*S75+(-2.535961e-02)*S76+5.019878e-02*S77+(-1.510676e-02)*S78+(-1.944223e-02)*S79'
.param V29_part9='V29_part8+(-2.838642e-02)*S80+(-1.324692e-02)*S81+2.076689e-02*S82+2.324673e-02*S83+1.628657e-02*S84+1.606785e-02*S85+2.103460e-02*S86+1.274793e-02*S87+1.555272e-02*S88+1.364330e-02*S89'
.param V29_part10='V29_part9+1.441529e-02*S90+1.913152e-02*S91+2.677139e-02*S92+4.871728e-03*S93+1.186797e-02*S94+2.175950e-02*S95+(-3.303954e-03)*S96+1.389865e-03*S97+9.167161e-05*S98+(-1.508585e-02)*S99'
.param V29_part11='V29_part10+9.227805e-05*S100+(-2.585826e-03)*S101+(-1.657963e-02)*S102+(-1.441228e-03)*S103+(-4.923104e-03)*S104+1.946305e-02*S105+1.959402e-02*S106+3.392813e-03*S107+9.728180e-03*S108+7.379654e-03*S109'
.param V29_part12='V29_part11+3.675878e-04*S110+(-1.000912e-02)*S111+5.490627e-03*S112+2.338511e-03*S113+5.856659e-03*S114+1.726895e-04*S115+7.884493e-03*S116+(-7.293200e-03)*S117+(-2.531441e-03)*S118+(-4.971107e-03)*S119'
.param V29_part13='V29_part12+1.807518e-02*S120+1.260542e-02*S121+1.500812e-03*S122+8.284961e-03*S123+7.773878e-03*S124+(-8.570923e-03)*S125+(-3.955374e-03)*S126+8.709609e-03*S127+(-8.187988e-03)*S128+(-4.466628e-03)*S129'
.param V29_part14='V29_part13+1.126752e-04*S130+(-6.707737e-03)*S131+(-2.674000e-03)*S132+8.183850e-03*S133+(-1.040495e-03)*S134+2.141498e-02*S135+2.430536e-02*S136+9.386254e-03*S137+1.115523e-02*S138+6.038262e-03*S139'
.param V29_part15='V29_part14+1.050321e-03*S140+1.171505e-03*S141+(-3.057058e-03)*S142+(-1.854830e-01)*S143+1.545366e-03*S144+(-6.342456e-04)*S145+7.274007e-03*S146+(-8.398275e-04)*S147+(-3.218231e-03)*S148+(-7.444218e-03)*S149'
.param V29_part16='V29_part15+2.317946e-02*S150+(-1.202145e-02)*S151+(-8.004054e-03)*S152+1.250736e-02*S153+(-8.742538e-03)*S154+(-2.380956e-02)*S155+1.480413e-02*S156+(-1.104676e-02)*S157+(-5.798234e-03)*S158+3.658269e-03*S159'
.param V29_part17='V29_part16+(-1.311924e-02)*S160+(-2.001717e-03)*S161+8.660167e-03*S162+(-1.750542e-02)*S163+3.073890e-03*S164+(-2.783373e-03)*S165+(-2.120674e-02)*S166+(-1.760487e-02)*S167+3.423461e-03*S168+(-5.071472e-01)*S169'
.param V29_part18='V29_part17+(-1.294712e-01)*S170+(-3.450707e-03)*S171+(-1.286894e-02)*S172+(-2.395451e-02)*S173+6.297883e-03*S174+(-1.465243e-03)*S175+(-6.263995e-03)*S176+7.280882e-03*S177+2.707779e-04*S178+(-5.807504e-04)*S179'
.param V29_part19='V29_part18+1.276024e-02*S180+(-3.251567e-03)*S181+(-3.843267e-02)*S182+(-5.366136e-02)*S183+(-3.566647e-02)*S184+(-7.860613e-03)*S185+1.553593e-02*S186+(-2.816948e-02)*S187+(-1.551127e-02)*S188+1.289233e-02*S189'
.param V29_part20='V29_part19+1.469515e-02*S190+(-2.195109e-02)*S191+6.526654e-04*S192+(-5.927044e-05)*S193+(-5.599030e-03)*S194+9.887327e-03*S195+(-2.114920e-02)*S196+(-1.079223e-02)*S197+(-1.421742e-03)*S198+(-2.480739e-02)*S199'
.param V29_part21='V29_part20+(-6.270354e-03)*S200+(-7.102034e-03)*S201+2.625861e-03*S202+(-9.923893e-04)*S203+(-1.269651e-02)*S204+(-1.950532e-02)*S205+3.634335e-04*S206+(-5.421138e-03)*S207+2.670082e-02*S208+6.774040e-01*S209'
.param V29_part22='V29_part21+(-4.312539e-02)*S210+(-5.664855e-03)*S211+(-4.211354e-01)*S212+1.188225e-03*S213+(-3.111136e-01)*S214+(-1.368895e-01)*S215+1.792986e-02*S216+2.272329e-02*S217+(-1.586100e-01)*S218+1.438608e-02*S219'
.param V29_part23='V29_part22+3.382430e-02*S220+(-8.920003e-03)*S221+(-9.027179e-03)*S222+(-9.320391e-03)*S223+(-8.295776e-03)*S224+(-4.887324e-02)*S225+(-3.701235e-02)*S226+(-1.398038e-02)*S227+(-1.105376e-02)*S228+(-1.425461e-02)*S229'
.param V29_part24='V29_part23+(-1.130835e-02)*S230+1.024384e-02*S231+(-6.794389e-02)*S232+(-1.410742e-02)*S233+1.629107e-02*S234+2.084802e-03*S235+(-1.750553e-02)*S236+(-1.524334e-02)*S237+(-3.021482e-03)*S238+(-1.943642e-02)*S239'
.param V29_part25='V29_part24+(-2.482541e-02)*S240+(-4.530633e-02)*S241+(-3.900704e-02)*S242+(-3.379956e-02)*S243+(-1.453170e-02)*S244+(-6.899023e-03)*S245+(-3.802361e-02)*S246+1.225101e-02*S247+(-6.840137e-03)*S248+(-7.457998e-03)*S249'
.param V29_part26='V29_part25+9.501164e-03*S250+(-1.152681e-02)*S251+(-1.301060e-03)*S252+(-2.248741e-02)*S253+(-9.391186e-03)*S254+(-3.918991e-02)*S255+(-3.446487e-03)*S256+(-1.110484e-02)*S257+(-7.398711e-03)*S258+(-2.679503e-02)*S259'
.param V29_part27='V29_part26+(-8.454685e-03)*S260+(-3.655580e-02)*S261+(-2.783099e-03)*S262+(-1.668045e-02)*S263+(-6.045559e-02)*S264+5.836464e-03*S265+(-1.659125e-02)*S266+1.646396e-02*S267+(-6.688150e-02)*S268+(-1.740842e-02)*S269'
.param V29_part28='V29_part27+(-2.425166e-02)*S270+(-8.091143e-03)*S271+(-2.159270e-02)*S272+(-1.401407e-02)*S273+(-1.101165e-02)*S274+(-1.438778e-02)*S275+(-2.582360e-02)*S276+(-9.910379e-03)*S277+(-1.685175e-02)*S278+(-1.615685e-02)*S279'
.param V29_part29='V29_part28+(-1.272828e-02)*S280+(-1.885837e-02)*S281+(-1.590117e-02)*S282+3.087216e-02*S283+(-8.750355e-03)*S284+(-1.341513e-02)*S285+(-2.091473e-02)*S286+(-2.517161e-02)*S287+(-3.861272e-02)*S288+(-1.020744e-02)*S289'
.param V29_part30='V29_part29+(-2.114617e-02)*S290+(-2.818704e-02)*S291+(-6.798992e-03)*S292+(-2.078140e-02)*S293+(-3.537383e-02)*S294+(-1.821077e-02)*S295+(-2.177824e-02)*S296+(-2.211078e-02)*S297+6.396500e-03*S298+(-1.842854e-02)*S299'
.param V29_part31='V29_part30+(-2.093668e-02)*S300+(-3.994735e-03)*S301+(-1.457191e-02)*S302+(-3.237916e-02)*S303+(-1.194894e-02)*S304+(-1.100609e-02)*S305+(-4.231149e-02)*S306+(-6.467324e-03)*S307+(-1.582371e-02)*S308+(-3.596505e-02)*S309'
.param V29='V29_part31+3.639559e-03*S310+(-1.355678e-02)*S311+(-3.635449e-02)*S312+(-2.444160e-03)*S313+(-1.393079e-02)*S314'
.param V30_part1='1.077017e+00*S0+6.291612e-01*S1+9.492844e-01*S2+(-1.004333e-01)*S3+(-1.571073e-01)*S4+(-1.154387e-01)*S5+(-5.649373e-01)*S6+(-1.086744e+00)*S7+(-7.642171e-01)*S8+(-3.306552e-01)*S9'
.param V30_part2='V30_part1+(-1.227021e-01)*S10+(-1.396288e+00)*S11+(-2.357193e-01)*S12+(-1.046077e+00)*S13+1.321694e+00*S14+1.952767e-01*S15+(-2.573814e-01)*S16+(-9.801897e-01)*S17+(-1.610142e-01)*S18+(-4.300438e-01)*S19'
.param V30_part3='V30_part2+(-9.770011e-01)*S20+(-5.173222e-02)*S21+(-1.302905e+00)*S22+7.271708e-01*S23+(-6.750808e-01)*S24+(-1.212541e+00)*S25+(-1.306521e+00)*S26+(-6.099321e-01)*S27+(-2.206782e-01)*S28+(-2.007355e+00)*S29'
.param V30_part4='V30_part3+(-2.821911e-01)*S30+(-1.606361e+00)*S31+(-2.640045e+00)*S32+(-9.214360e-01)*S33+(-1.763711e+00)*S34+(-4.220750e+00)*S35+(-1.697646e+00)*S36+4.221387e-01*S37+(-5.593239e+00)*S38+(-2.380196e+00)*S39'
.param V30_part5='V30_part4+(-2.326720e+00)*S40+(-7.312588e+00)*S41+(-3.236157e+00)*S42+(-4.847395e+00)*S43+(-9.750049e+00)*S44+(-3.929281e-01)*S45+(-5.895556e-02)*S46+(-1.742645e+00)*S47+(-1.047048e+00)*S48+(-2.632230e-01)*S49'
.param V30_part6='V30_part5+(-5.380538e+00)*S50+(-1.082366e-01)*S51+(-1.556777e+00)*S52+(-6.850489e+00)*S53+(-1.631341e+00)*S54+(-4.305448e+00)*S55+(-1.119806e+01)*S56+(-2.746500e+00)*S57+(-6.520034e+00)*S58+(-1.034785e+01)*S59'
.param V30_part7='V30_part6+(-4.310654e-01)*S60+(-2.023104e+00)*S61+(-4.814481e+00)*S62+(-1.197950e+00)*S63+(-3.214637e+00)*S64+(-6.878152e+00)*S65+(-1.866211e+00)*S66+(-1.043661e+02)*S67+(-1.061389e+01)*S68+(-6.767722e+01)*S69'
.param V30_part8='V30_part7+(-1.664987e+02)*S70+(-1.078822e+01)*S71+(-3.333214e+00)*S72+(-7.975511e+00)*S73+(-5.010608e+00)*S74+2.715881e-01*S75+(-4.153718e-01)*S76+(-2.098328e+00)*S77+(-5.791103e-01)*S78+(-1.482014e+00)*S79'
.param V30_part9='V30_part8+(-3.902178e+00)*S80+(-1.653352e+00)*S81+(-1.881006e+00)*S82+(-2.458562e+00)*S83+(-1.729767e+00)*S84+(-3.352763e-01)*S85+(-1.799903e+00)*S86+2.514133e-01*S87+(-1.854616e+00)*S88+(-5.025910e+00)*S89'
.param V30_part10='V30_part9+(-7.170954e-01)*S90+(-2.829872e+00)*S91+(-7.024862e+00)*S92+(-1.833361e+00)*S93+(-3.964092e+00)*S94+(-6.815961e+00)*S95+(-2.878944e+00)*S96+(-7.037940e+00)*S97+(-1.205994e+01)*S98+(-2.943297e+00)*S99'
.param V30_part11='V30_part10+(-7.285071e+00)*S100+(-1.400093e+01)*S101+(-3.306257e+00)*S102+(-7.607295e+00)*S103+(-1.680970e+01)*S104+(-9.837090e-01)*S105+(-4.428782e+00)*S106+(-6.158127e+00)*S107+(-1.954518e+00)*S108+(-6.821838e+00)*S109'
.param V30_part12='V30_part11+(-1.079550e+01)*S110+(-3.031278e+00)*S111+(-6.995304e+00)*S112+(-6.562773e+00)*S113+(-1.310810e+00)*S114+(-6.025711e+00)*S115+(-9.723417e+00)*S116+(-2.494240e+00)*S117+(-6.285929e+00)*S118+(-1.791568e+01)*S119'
.param V30_part13='V30_part12+(-1.829040e+00)*S120+(-5.030703e+00)*S121+(-1.077849e+01)*S122+(-2.130144e+00)*S123+(-7.238151e+00)*S124+(-1.276998e+01)*S125+(-2.897317e+00)*S126+(-6.309560e+00)*S127+(-1.600995e+01)*S128+(-2.950978e+00)*S129'
.param V30_part14='V30_part13+(-5.189803e+00)*S130+(-1.845552e+01)*S131+(-2.812470e+00)*S132+(-6.202958e+00)*S133+(-1.870475e+01)*S134+2.356575e-01*S135+(-2.905467e+00)*S136+(-4.968262e+00)*S137+(-1.380791e+00)*S138+(-3.390830e+00)*S139'
.param V30_part15='V30_part14+(-8.079739e+00)*S140+(-2.246249e-02)*S141+(-4.491451e+00)*S142+(-9.751034e+00)*S143+(-3.177502e-01)*S144+(-6.403975e+00)*S145+(-1.198256e+01)*S146+(-1.064316e+00)*S147+(-4.728170e+00)*S148+(-1.237668e+01)*S149'
.param V30_part16='V30_part15+(-2.113953e+00)*S150+(-5.296305e+00)*S151+(-1.308086e+01)*S152+(-2.811832e+00)*S153+(-1.057434e+01)*S154+(-1.712148e+01)*S155+2.240497e+00*S156+(-6.742144e+00)*S157+(-1.975732e+01)*S158+(-2.523905e+00)*S159'
.param V30_part17='V30_part16+(-6.217561e+00)*S160+(-2.022430e+01)*S161+(-2.037945e+00)*S162+(-7.554488e+00)*S163+(-2.114733e+01)*S164+(-2.797224e+00)*S165+(-8.683059e+00)*S166+(-1.451412e+01)*S167+(-3.007655e+00)*S168+(-7.717917e+00)*S169'
.param V30_part18='V30_part17+(-1.904664e+01)*S170+(-2.648699e+00)*S171+(-4.335907e+00)*S172+(-1.631138e+01)*S173+(-1.730848e+00)*S174+(-5.361555e+00)*S175+(-1.868023e+01)*S176+(-2.627424e+00)*S177+(-6.151632e+00)*S178+(-2.385777e+01)*S179'
.param V30_part19='V30_part18+(-2.506111e+00)*S180+(-8.111179e+00)*S181+(-1.391145e+01)*S182+(-3.710806e+00)*S183+(-7.983662e+00)*S184+(-1.852551e+01)*S185+(-2.125689e+00)*S186+(-8.035133e+00)*S187+(-1.843914e+01)*S188+(-2.124641e+00)*S189'
.param V30_part20='V30_part19+(-8.776804e+00)*S190+(-1.806266e+01)*S191+(-2.581903e+00)*S192+(-5.897076e+00)*S193+(-1.794607e+01)*S194+(-3.768955e-01)*S195+(-4.183964e+00)*S196+(-1.129297e+01)*S197+(-5.238623e+00)*S198+(-8.074128e+00)*S199'
.param V30_part21='V30_part20+(-1.487535e+01)*S200+(-6.332805e-01)*S201+(-3.988200e+00)*S202+(-1.573932e+01)*S203+(-2.234235e+00)*S204+(-6.326491e+00)*S205+(-1.070680e+01)*S206+(-1.489892e+00)*S207+(-6.210821e+00)*S208+(-1.319265e+01)*S209'
.param V30_part22='V30_part21+(-3.599049e+00)*S210+(-9.279084e+00)*S211+(-1.478126e+01)*S212+1.894434e-01*S213+(-7.667163e+00)*S214+(-2.139899e+01)*S215+(-2.722179e+00)*S216+(-4.869327e+00)*S217+(-2.209956e+01)*S218+(-2.603896e+00)*S219'
.param V30_part23='V30_part22+(-1.079609e+01)*S220+(-9.845292e-01)*S221+(-5.014925e+00)*S222+(-5.992228e-01)*S223+(-2.611463e+00)*S224+(-1.637966e+00)*S225+(-8.791010e+00)*S226+(-2.025353e+01)*S227+(-3.026996e+00)*S228+(-5.667957e+00)*S229'
.param V30_part24='V30_part23+(-1.918741e+01)*S230+(-3.047008e+00)*S231+(-8.306097e+00)*S232+(-1.632077e+01)*S233+(-2.362424e+00)*S234+(-6.685922e+00)*S235+(-1.853880e+01)*S236+(-2.797193e+00)*S237+(-6.244701e+00)*S238+(-1.952144e+01)*S239'
.param V30_part25='V30_part24+(-3.426812e+00)*S240+(-7.241399e+00)*S241+(-1.181668e+01)*S242+(-1.791966e+00)*S243+(-4.974789e+00)*S244+(-1.159595e+01)*S245+(-1.733218e+00)*S246+(-6.138694e+00)*S247+(-1.454513e+01)*S248+(-2.730519e+00)*S249'
.param V30_part26='V30_part25+(-7.215509e+00)*S250+(-1.749548e+01)*S251+(-4.509342e+00)*S252+(-9.502917e+00)*S253+(-2.633865e+01)*S254+(-3.990188e+00)*S255+(-5.331754e+00)*S256+(-1.891698e+01)*S257+(-1.509687e+00)*S258+(-7.867916e+00)*S259'
.param V30_part27='V30_part26+(-1.504239e+01)*S260+(-1.311595e+00)*S261+(-3.285929e+00)*S262+(-1.862512e+01)*S263+(-2.975074e+00)*S264+(-5.314920e+00)*S265+(-1.382564e+01)*S266+(-1.894511e+00)*S267+(-6.727599e+00)*S268+(-1.667394e+01)*S269'
.param V30_part28='V30_part27+(-2.779226e+00)*S270+(-9.594687e+00)*S271+(-2.514393e+01)*S272+(-2.905898e+00)*S273+(-9.423798e+00)*S274+(-1.346280e+01)*S275+(-3.038339e+00)*S276+(-1.067124e+01)*S277+(-1.802008e+01)*S278+(-4.172828e+00)*S279'
.param V30_part29='V30_part28+(-7.388347e+00)*S280+(-2.154928e+01)*S281+(-5.231341e+00)*S282+(-1.459927e+01)*S283+(-2.638689e+01)*S284+(-2.290112e+00)*S285+(-7.161728e+00)*S286+(-1.304979e+01)*S287+(-2.939286e+00)*S288+(-6.183332e+00)*S289'
.param V30_part30='V30_part29+(-1.528205e+01)*S290+(-3.146835e+00)*S291+(-6.831208e+00)*S292+(-2.211199e+01)*S293+(-3.697690e+00)*S294+(-5.525248e+00)*S295+(-3.264170e+01)*S296+(-5.236639e+00)*S297+(-8.759634e+00)*S298+(-2.515395e+01)*S299'
.param V30_part31='V30_part30+(-1.171404e+00)*S300+(-5.768060e+00)*S301+(-1.735399e+01)*S302+(-1.418610e+00)*S303+(-1.260649e+00)*S304+(-1.860667e+01)*S305+(-1.739421e+00)*S306+(-9.735845e-01)*S307+(-1.533396e+01)*S308+(-2.464099e+00)*S309'
.param V30='V30_part31+(-3.738643e+00)*S310+(-1.847653e+01)*S311+(-2.561867e+00)*S312+(-6.020304e+00)*S313+(-2.312873e+01)*S314'
.param V31_part1='1.598331e+00*S0+1.808746e+00*S1+2.469002e+00*S2+3.190853e+00*S3+2.830887e+00*S4+3.606099e+00*S5+3.408246e+00*S6+3.504201e+00*S7+2.498669e+00*S8+2.540086e+00*S9'
.param V31_part2='V31_part1+2.113779e+00*S10+2.843827e+00*S11+2.226913e+00*S12+2.193079e+00*S13+7.541019e-01*S14+3.801870e+00*S15+4.987325e+00*S16+5.787581e+00*S17+2.745219e+00*S18+3.709184e+00*S19'
.param V31_part3='V31_part2+6.002799e+00*S20+2.815915e+00*S21+5.889140e+00*S22+2.601873e+00*S23+2.778934e+00*S24+3.476419e+00*S25+4.137941e+00*S26+2.476513e+00*S27+2.429669e+00*S28+3.647010e+00*S29'
.param V31_part4='V31_part3+6.115377e+00*S30+1.009896e+01*S31+1.042456e+01*S32+6.772996e+00*S33+7.616850e+00*S34+9.976890e+00*S35+6.863179e+00*S36+2.545448e+00*S37+1.039499e+01*S38+6.876087e+00*S39'
.param V31_part5='V31_part4+5.535663e+00*S40+8.961197e+00*S41+7.741216e+00*S42+7.400165e+00*S43+8.637856e+00*S44+8.032372e+00*S45+6.773937e+00*S46+5.634824e+00*S47+6.373432e+00*S48+6.810620e+00*S49'
.param V31_part6='V31_part5+1.247088e+01*S50+3.139441e+00*S51+5.590336e+00*S52+1.209405e+01*S53+5.511126e+00*S54+8.280578e+00*S55+1.193610e+01*S56+6.249146e+00*S57+9.102254e+00*S58+1.196527e+01*S59'
.param V31_part7='V31_part6+8.284662e+00*S60+1.044106e+01*S61+1.193435e+01*S62+7.679667e+00*S63+1.143141e+01*S64+1.354780e+01*S65+7.275380e+00*S66+1.432808e+02*S67+1.440111e+01*S68+6.593406e+01*S69'
.param V31_part8='V31_part7+1.809414e+02*S70+1.395304e+01*S71+7.111584e+00*S72+1.230231e+01*S73+6.634697e+00*S74+4.030775e+00*S75+6.473698e+00*S76+7.965283e+00*S77+5.720905e+00*S78+8.690331e+00*S79'
.param V31_part9='V31_part8+9.559885e+00*S80+6.407531e+00*S81+6.000167e+00*S82+7.147978e+00*S83+5.507805e+00*S84+3.796045e+00*S85+6.052633e+00*S86+3.136262e+00*S87+4.935650e+00*S88+6.177812e+00*S89'
.param V31_part10='V31_part9+7.549083e+00*S90+1.384858e+01*S91+1.634452e+01*S92+8.715097e+00*S93+1.482661e+01*S94+8.842044e+00*S95+8.564823e+00*S96+1.126736e+01*S97+1.788245e+01*S98+7.414114e+00*S99'
.param V31_part11='V31_part10+1.024903e+01*S100+1.503609e+01*S101+7.315355e+00*S102+9.474973e+00*S103+1.600969e+01*S104+7.996864e+00*S105+1.562005e+01*S106+1.396230e+01*S107+8.518475e+00*S108+1.501175e+01*S109'
.param V31_part12='V31_part11+1.955559e+01*S110+8.752071e+00*S111+1.193804e+01*S112+1.182875e+01*S113+3.362415e+00*S114+1.043261e+01*S115+1.160145e+01*S116+6.581475e+00*S117+9.186880e+00*S118+1.600623e+01*S119'
.param V31_part13='V31_part12+1.248089e+01*S120+1.708339e+01*S121+2.244255e+01*S122+9.575868e+00*S123+1.604528e+01*S124+2.074837e+01*S125+9.039000e+00*S126+1.234820e+01*S127+1.989288e+01*S128+8.341713e+00*S129'
.param V31_part14='V31_part13+1.037754e+01*S130+1.974981e+01*S131+7.071154e+00*S132+9.034208e+00*S133+1.693201e+01*S134+1.038210e+01*S135+1.130094e+01*S136+1.770701e+01*S137+9.950780e+00*S138+1.232937e+01*S139'
.param V31_part15='V31_part14+1.470032e+01*S140+3.205479e+00*S141+1.178661e+01*S142+1.506460e+01*S143+3.799118e+00*S144+1.018852e+01*S145+1.517782e+01*S146+2.754718e+00*S147+8.460855e+00*S148+1.394637e+01*S149'
.param V31_part16='V31_part15+9.781557e+00*S150+1.782568e+01*S151+2.686088e+01*S152+9.614885e+00*S153+2.014700e+01*S154+2.607043e+01*S155+6.456352e-01*S156+1.022135e+01*S157+2.326672e+01*S158+6.866751e+00*S159'
.param V31_part17='V31_part16+9.175335e+00*S160+1.746340e+01*S161+4.770351e+00*S162+9.783964e+00*S163+1.639964e+01*S164+1.270904e+01*S165+1.895356e+01*S166+2.734509e+01*S167+9.914709e+00*S168+1.440356e+01*S169'
.param V31_part18='V31_part17+2.974727e+01*S170+8.147211e+00*S171+8.500691e+00*S172+1.373939e+01*S173+7.488164e+00*S174+8.695273e+00*S175+1.467380e+01*S176+6.784727e+00*S177+8.143696e+00*S178+1.697083e+01*S179'
.param V31_part19='V31_part18+1.164203e+01*S180+1.903093e+01*S181+2.563880e+01*S182+1.364814e+01*S183+1.982083e+01*S184+2.412138e+01*S185+8.290923e+00*S186+1.442814e+01*S187+1.637852e+01*S188+7.292799e+00*S189'
.param V31_part20='V31_part19+8.939950e+00*S190+1.338785e+01*S191+6.535890e+00*S192+9.179253e+00*S193+1.347080e+01*S194+9.930497e+00*S195+1.672926e+01*S196+2.343386e+01*S197+1.828269e+01*S198+1.814069e+01*S199'
.param V31_part21='V31_part20+2.375882e+01*S200+8.748200e+00*S201+1.201605e+01*S202+2.023806e+01*S203+7.723753e+00*S204+1.233277e+01*S205+1.303495e+01*S206+6.203083e+00*S207+8.733357e+00*S208+1.370020e+01*S209'
.param V31_part22='V31_part21+1.271041e+01*S210+2.308499e+01*S211+2.839131e+01*S212+7.552286e-01*S213+1.235463e+01*S214+2.450006e+01*S215+7.645387e+00*S216+9.748182e+00*S217+1.928931e+01*S218+5.527401e+00*S219'
.param V31_part23='V31_part22+1.116615e+01*S220+5.848790e+00*S221+9.209738e+00*S222+5.160126e+00*S223+4.785006e+00*S224+7.680553e+00*S225+1.918685e+01*S226+2.296308e+01*S227+1.055521e+01*S228+1.102504e+01*S229'
.param V31_part24='V31_part23+1.901086e+01*S230+7.860786e+00*S231+1.476391e+01*S232+1.678271e+01*S233+6.811113e+00*S234+9.891735e+00*S235+1.689082e+01*S236+7.043879e+00*S237+1.047226e+01*S238+1.347066e+01*S239'
.param V31_part25='V31_part24+1.182064e+01*S240+1.434667e+01*S241+1.644987e+01*S242+7.366542e+00*S243+1.263223e+01*S244+1.571458e+01*S245+3.101822e+00*S246+1.054493e+01*S247+1.465420e+01*S248+7.684265e+00*S249'
.param V31_part26='V31_part25+1.066962e+01*S250+1.568336e+01*S251+8.277391e+00*S252+1.466389e+01*S253+1.797309e+01*S254+1.524093e+01*S255+1.840240e+01*S256+3.309506e+01*S257+1.011399e+01*S258+1.797785e+01*S259'
.param V31_part27='V31_part26+2.122845e+01*S260+6.916037e+00*S261+7.646522e+00*S262+1.794582e+01*S263+8.208427e+00*S264+9.089947e+00*S265+1.301550e+01*S266+6.838352e+00*S267+1.248230e+01*S268+1.370167e+01*S269'
.param V31_part28='V31_part27+1.135284e+01*S270+1.996863e+01*S271+3.314131e+01*S272+1.038065e+01*S273+1.703995e+01*S274+1.635032e+01*S275+7.705520e+00*S276+1.771662e+01*S277+1.640002e+01*S278+9.509085e+00*S279'
.param V31_part29='V31_part28+1.076384e+01*S280+1.698747e+01*S281+9.220074e+00*S282+1.200645e+01*S283+1.752367e+01*S284+1.117880e+01*S285+1.577217e+01*S286+2.283264e+01*S287+7.973931e+00*S288+1.264477e+01*S289'
.param V31_part30='V31_part29+1.604961e+01*S290+8.200256e+00*S291+1.735406e+01*S292+2.159514e+01*S293+7.807177e+00*S294+1.092747e+01*S295+2.321720e+01*S296+9.609277e+00*S297+1.120995e+01*S298+1.692942e+01*S299'
.param V31_part31='V31_part30+1.064344e+01*S300+1.592764e+01*S301+2.373779e+01*S302+8.020140e+00*S303+9.665185e+00*S304+2.093502e+01*S305+7.636607e+00*S306+1.495763e+01*S307+1.621370e+01*S308+7.675838e+00*S309'
.param V31='V31_part31+1.123109e+01*S310+1.486038e+01*S311+7.803422e+00*S312+1.135546e+01*S313+1.812808e+01*S314'
.param V32_part1='1.814072e+00*S0+2.928404e+00*S1+1.673236e+00*S2+3.026514e+00*S3+3.174645e+00*S4+3.545812e+00*S5+3.821166e+00*S6+4.804519e+00*S7+3.065511e+00*S8+4.493724e+00*S9'
.param V32_part2='V32_part1+2.335031e+00*S10+3.623099e+00*S11+5.148880e+00*S12+3.695270e+00*S13+3.015810e+00*S14+3.224974e+00*S15+4.541735e+00*S16+5.219798e+00*S17+3.656098e+00*S18+5.133787e+00*S19'
.param V32_part3='V32_part2+5.292895e+00*S20+2.505729e+00*S21+5.463461e+00*S22+2.071902e+00*S23+4.056031e+00*S24+4.537854e+00*S25+4.625681e+00*S26+3.561641e+00*S27+3.808678e+00*S28+4.426801e+00*S29'
.param V32_part4='V32_part3+5.591145e+00*S30+7.433174e+00*S31+8.812837e+00*S32+7.069990e+00*S33+8.751294e+00*S34+1.080278e+01*S35+8.792958e+00*S36+5.918579e+00*S37+1.215271e+01*S38+1.031446e+01*S39'
.param V32_part5='V32_part4+8.689921e+00*S40+1.491735e+01*S41+1.165943e+01*S42+1.268406e+01*S43+1.613971e+01*S44+6.064365e+00*S45+4.439918e+00*S46+7.981984e+00*S47+8.766083e+00*S48+5.736192e+00*S49'
.param V32_part6='V32_part5+1.273212e+01*S50+3.059718e+00*S51+5.293940e+00*S52+1.449075e+01*S53+8.901864e+00*S54+1.190991e+01*S55+1.838221e+01*S56+1.157516e+01*S57+1.702873e+01*S58+1.911984e+01*S59'
.param V32_part7='V32_part6+7.710978e+00*S60+1.047226e+01*S61+1.414190e+01*S62+9.841280e+00*S63+1.197354e+01*S64+1.643850e+01*S65+1.088612e+01*S66+1.779246e+02*S67+1.898175e+01*S68+2.189011e+02*S69'
.param V32_part8='V32_part7+2.453868e+02*S70+2.115477e+01*S71+1.019808e+01*S72+1.897607e+01*S73+1.125687e+01*S74+3.700368e+00*S75+4.604586e+00*S76+6.894472e+00*S77+5.076821e+00*S78+5.362063e+00*S79'
.param V32_part9='V32_part8+8.461269e+00*S80+6.463236e+00*S81+8.262438e+00*S82+6.273794e+00*S83+8.305739e+00*S84+6.505440e+00*S85+7.508214e+00*S86+7.258117e+00*S87+8.500459e+00*S88+9.675464e+00*S89'
.param V32_part10='V32_part9+1.114272e+01*S90+1.386120e+01*S91+1.722027e+01*S92+1.421535e+01*S93+1.605103e+01*S94+1.817249e+01*S95+1.783733e+01*S96+2.370823e+01*S97+2.496960e+01*S98+2.034466e+01*S99'
.param V32_part11='V32_part10+2.607459e+01*S100+3.016458e+01*S101+2.299888e+01*S102+2.806614e+01*S103+3.317167e+01*S104+1.276896e+01*S105+1.768271e+01*S106+1.881492e+01*S107+1.458589e+01*S108+2.195128e+01*S109'
.param V32_part12='V32_part11+2.486089e+01*S110+1.864703e+01*S111+2.509347e+01*S112+2.248522e+01*S113+1.691303e+01*S114+2.667445e+01*S115+2.564479e+01*S116+2.007110e+01*S117+2.849955e+01*S118+3.778817e+01*S119'
.param V32_part13='V32_part12+1.740516e+01*S120+2.001271e+01*S121+2.653751e+01*S122+1.748084e+01*S123+2.476964e+01*S124+3.032359e+01*S125+2.146737e+01*S126+2.663862e+01*S127+3.507170e+01*S128+2.367797e+01*S129'
.param V32_part14='V32_part13+2.730173e+01*S130+3.860923e+01*S131+2.110723e+01*S132+2.573407e+01*S133+4.222033e+01*S134+5.668260e+00*S135+1.311870e+01*S136+1.347906e+01*S137+1.056099e+01*S138+1.375746e+01*S139'
.param V32_part15='V32_part14+1.936656e+01*S140+1.006092e+01*S141+1.635748e+01*S142+1.985146e+01*S143+1.372730e+01*S144+1.900915e+01*S145+2.416717e+01*S146+1.613368e+01*S147+1.685910e+01*S148+2.637353e+01*S149'
.param V32_part16='V32_part15+2.396596e+01*S150+2.418033e+01*S151+3.333916e+01*S152+2.546375e+01*S153+4.263626e+01*S154+3.912067e+01*S155+1.811709e+01*S156+3.471348e+01*S157+4.434875e+01*S158+2.687130e+01*S159'
.param V32_part17='V32_part16+3.666319e+01*S160+4.957789e+01*S161+2.593178e+01*S162+4.024753e+01*S163+5.000487e+01*S164+2.328623e+01*S165+3.264722e+01*S166+3.828624e+01*S167+2.536692e+01*S168+3.381561e+01*S169'
.param V32_part18='V32_part17+4.275029e+01*S170+2.940020e+01*S171+3.384414e+01*S172+4.430051e+01*S173+2.208013e+01*S174+2.974760e+01*S175+5.216919e+01*S176+2.594616e+01*S177+3.088280e+01*S178+5.989136e+01*S179'
.param V32_part19='V32_part18+2.466196e+01*S180+3.452821e+01*S181+3.692554e+01*S182+2.814513e+01*S183+3.527715e+01*S184+4.881175e+01*S185+2.395721e+01*S186+3.859572e+01*S187+5.405071e+01*S188+2.404573e+01*S189'
.param V32_part20='V32_part19+2.970615e+01*S190+5.222475e+01*S191+2.871939e+01*S192+3.201415e+01*S193+3.884394e+01*S194+1.683321e+01*S195+2.123005e+01*S196+2.956860e+01*S197+3.438987e+01*S198+4.603348e+01*S199'
.param V32_part21='V32_part20+3.399425e+01*S200+2.153589e+01*S201+2.655536e+01*S202+3.769520e+01*S203+2.557273e+01*S204+2.902623e+01*S205+3.019407e+01*S206+2.246628e+01*S207+2.815413e+01*S208+3.044121e+01*S209'
.param V32_part22='V32_part21+3.100571e+01*S210+3.874395e+01*S211+4.537343e+01*S212+2.128828e+01*S213+4.445236e+01*S214+5.295742e+01*S215+3.118129e+01*S216+3.067096e+01*S217+5.748871e+01*S218+2.697386e+01*S219'
.param V32_part23='V32_part22+4.516606e+01*S220+2.512719e+01*S221+3.538552e+01*S222+2.521603e+01*S223+2.304325e+01*S224+2.806695e+01*S225+4.306061e+01*S226+5.901037e+01*S227+2.745552e+01*S228+3.465920e+01*S229'
.param V32_part24='V32_part23+6.160594e+01*S230+3.459365e+01*S231+4.078680e+01*S232+5.303051e+01*S233+3.040633e+01*S234+3.875941e+01*S235+5.490798e+01*S236+3.535500e+01*S237+3.944654e+01*S238+5.400651e+01*S239'
.param V32_part25='V32_part24+3.370693e+01*S240+4.495269e+01*S241+4.889364e+01*S242+2.836135e+01*S243+3.348603e+01*S244+4.696414e+01*S245+3.146077e+01*S246+3.958139e+01*S247+4.825144e+01*S248+3.150079e+01*S249'
.param V32_part26='V32_part25+4.089109e+01*S250+4.568291e+01*S251+3.738564e+01*S252+4.052893e+01*S253+5.945689e+01*S254+2.621406e+01*S255+3.582652e+01*S256+4.789534e+01*S257+2.502958e+01*S258+3.731624e+01*S259'
.param V32_part27='V32_part26+4.960447e+01*S260+2.752343e+01*S261+3.172602e+01*S262+4.860683e+01*S263+2.913107e+01*S264+3.384377e+01*S265+5.013851e+01*S266+2.870193e+01*S267+3.535222e+01*S268+5.063221e+01*S269'
.param V32_part28='V32_part27+3.363488e+01*S270+5.477735e+01*S271+6.319468e+01*S272+3.393536e+01*S273+4.893373e+01*S274+5.655620e+01*S275+3.716989e+01*S276+5.164718e+01*S277+6.186617e+01*S278+4.006007e+01*S279'
.param V32_part29='V32_part28+4.894604e+01*S280+6.500008e+01*S281+4.261800e+01*S282+5.921466e+01*S283+7.047466e+01*S284+3.075178e+01*S285+4.641845e+01*S286+5.364232e+01*S287+3.629523e+01*S288+4.164031e+01*S289'
.param V32_part30='V32_part29+5.536178e+01*S290+3.683776e+01*S291+4.203046e+01*S292+6.188577e+01*S293+3.897533e+01*S294+4.741921e+01*S295+6.749826e+01*S296+3.961991e+01*S297+4.815954e+01*S298+5.503710e+01*S299'
.param V32_part31='V32_part30+2.869229e+01*S300+4.495135e+01*S301+6.036908e+01*S302+3.031650e+01*S303+3.276330e+01*S304+5.333415e+01*S305+3.216578e+01*S306+2.789363e+01*S307+4.504488e+01*S308+3.713954e+01*S309'
.param V32='V32_part31+4.006977e+01*S310+4.759969e+01*S311+3.462873e+01*S312+4.494374e+01*S313+5.450440e+01*S314'
.param V33_part1='6.678477e-01*S0+1.107617e+00*S1+(-5.729595e-02)*S2+6.701663e-01*S3+8.316374e-01*S4+1.134552e+00*S5+6.331490e-01*S6+6.418207e-01*S7+1.026440e+00*S8+6.975558e-01*S9'
.param V33_part2='V33_part1+6.917570e-01*S10+1.078906e+00*S11+7.252879e-01*S12+8.513133e-01*S13+9.256548e-01*S14+6.357255e-01*S15+5.245074e-01*S16+1.055854e+00*S17+4.849975e-02*S18+2.827065e-01*S19'
.param V33_part3='V33_part2+1.171510e+00*S20+6.483230e-01*S21+6.948449e-01*S22+(-5.546831e-02)*S23+7.081809e-01*S24+1.047861e+00*S25+1.440102e+00*S26+(-4.742538e-02)*S27+2.211003e-02*S28+1.833072e-01*S29'
.param V33_part4='V33_part3+5.728950e-01*S30+9.335730e-01*S31+7.257628e-01*S32+5.397852e-01*S33+5.843750e-01*S34+4.877849e-01*S35+5.455129e-01*S36+6.300066e-01*S37+3.800497e-01*S38+1.017947e-01*S39'
.param V33_part5='V33_part4+8.652392e-01*S40+6.657459e-01*S41+1.131363e+00*S42+5.593396e-01*S43+8.826469e-02*S44+8.983894e-01*S45+(-3.063650e-02)*S46+(-3.051805e-01)*S47+4.138465e-01*S48+8.002512e-01*S49'
.param V33_part6='V33_part5+9.158092e-01*S50+(-1.007220e-01)*S51+(-3.061849e-01)*S52+1.023932e+00*S53+(-1.141835e-01)*S54+8.592294e-02*S55+8.785164e-01*S56+4.944036e-01*S57+6.949473e-01*S58+1.130488e+00*S59'
.param V33_part7='V33_part6+5.865599e-01*S60+4.317806e-01*S61+4.959205e-01*S62+5.513029e-01*S63+5.336864e-01*S64+6.397242e-01*S65+3.493629e-01*S66+(-8.912386e+00)*S67+4.622552e-01*S68+(-6.659862e-01)*S69'
.param V33_part8='V33_part7+(-7.104962e+00)*S70+8.382674e-01*S71+4.903511e-02*S72+4.743087e-01*S73+(-1.174040e+00)*S74+7.147041e-01*S75+8.944078e-01*S76+3.042298e-01*S77+7.988320e-01*S78+1.285742e+00*S79'
.param V33_part9='V33_part8+5.628352e-01*S80+4.397907e-01*S81+7.559816e-01*S82+1.390793e+00*S83+7.691780e-01*S84+1.816169e+00*S85+2.250821e+00*S86+1.763855e+00*S87+1.867262e+00*S88+1.815396e+00*S89'
.param V33_part10='V33_part9+2.383757e-01*S90+2.796185e-01*S91+(-1.243669e-01)*S92+(-2.332236e-01)*S93+2.837857e-01*S94+(-6.587035e-01)*S95+(-3.952458e-02)*S96+(-1.103297e-01)*S97+7.013692e-01*S98+(-3.992710e-01)*S99'
.param V33_part11='V33_part10+(-7.381475e-01)*S100+4.761713e-01*S101+(-6.381124e-03)*S102+(-7.286754e-01)*S103+6.251838e-01*S104+(-1.763174e-01)*S105+5.505525e-01*S106+1.254699e-01*S107+(-3.214916e-01)*S108+1.439036e-01*S109'
.param V33_part12='V33_part11+1.103509e+00*S110+(-4.003674e-01)*S111+(-5.360452e-02)*S112+1.515416e+00*S113+(-1.680219e+00)*S114+2.681535e-01*S115+(-7.041557e-02)*S116+(-5.698394e-01)*S117+1.392003e-01*S118+1.151211e+00*S119'
.param V33_part13='V33_part12+2.647531e-01*S120+(-1.733465e-01)*S121+5.582331e-01*S122+1.075690e-01*S123+(-3.166856e-01)*S124+7.385837e-01*S125+5.249628e-02*S126+9.172926e-02*S127+1.155511e+00*S128+1.807714e-01*S129'
.param V33_part14='V33_part13+(-1.011259e+00)*S130+1.338121e+00*S131+(-4.049277e-01)*S132+(-5.270968e-01)*S133+1.251217e+00*S134+1.751466e-01*S135+3.694411e-01*S136+1.999389e+00*S137+1.809974e+00*S138+8.583411e-01*S139'
.param V33_part15='V33_part14+7.214495e-01*S140+1.472194e+00*S141+1.208229e+00*S142+7.807746e-01*S143+1.645534e+00*S144+2.173338e+00*S145+1.206377e+00*S146+(-8.414653e-01)*S147+(-6.747179e-01)*S148+1.520835e+00*S149'
.param V33_part16='V33_part15+(-4.112781e-01)*S150+(-1.105308e+00)*S151+4.742986e-01*S152+(-7.621903e-02)*S153+(-1.818657e+00)*S154+9.600112e-01*S155+(-6.225695e-01)*S156+(-1.491491e+00)*S157+(-4.103024e-01)*S158+(-1.890347e-01)*S159'
.param V33_part17='V33_part16+(-1.616531e+00)*S160+(-4.584963e-01)*S161+2.155672e-01*S162+(-1.174744e+00)*S163+(-3.735982e-01)*S164+(-7.932412e-03)*S165+(-1.417752e+00)*S166+1.568166e+00*S167+(-3.746879e-01)*S168+(-1.130751e+00)*S169'
.param V33_part18='V33_part17+1.358397e+00*S170+1.283707e-01*S171+(-1.011795e+00)*S172+(-5.904621e-01)*S173+(-1.489714e-01)*S174+(-1.293747e+00)*S175+(-2.531001e-01)*S176+1.256212e-01*S177+(-1.455130e+00)*S178+1.734306e+00*S179'
.param V33_part19='V33_part18+(-1.781293e-01)*S180+(-9.813638e-01)*S181+(-2.960511e-01)*S182+(-2.574930e-01)*S183+(-9.545022e-02)*S184+6.694617e-01*S185+(-3.931253e-01)*S186+(-4.818780e-01)*S187+2.919545e-01*S188+(-5.069675e-01)*S189'
.param V33_part20='V33_part19+(-7.566769e-01)*S190+(-4.812191e-01)*S191+(-1.596554e-01)*S192+(-1.508795e+00)*S193+(-1.404941e+00)*S194+4.689878e-01*S195+(-3.349332e-01)*S196+1.300773e+00*S197+9.595502e-01*S198+1.797260e+00*S199'
.param V33_part21='V33_part20+1.387315e+00*S200+1.202590e+00*S201+7.820671e-01*S202+1.379562e+00*S203+7.527651e-01*S204+(-4.777037e-01)*S205+(-5.399943e-01)*S206+5.007836e-01*S207+(-3.416704e-01)*S208+(-1.180055e+00)*S209'
.param V33_part22='V33_part21+(-9.948599e-01)*S210+(-5.836986e-01)*S211+1.016975e+00*S212+(-7.538255e-01)*S213+(-9.078002e-01)*S214+(-6.153565e-02)*S215+5.178850e-02*S216+(-1.008372e+00)*S217+(-6.024913e-01)*S218+(-6.732195e-01)*S219'
.param V33_part23='V33_part22+(-7.709947e-01)*S220+(-2.815986e+00)*S221+(-5.271061e-01)*S222+(-2.539908e+00)*S223+(-1.913789e+00)*S224+(-2.698808e-01)*S225+(-4.919255e-01)*S226+(-5.059463e-01)*S227+(-4.049531e-01)*S228+(-6.797912e-01)*S229'
.param V33_part24='V33_part23+1.254081e-01*S230+4.314068e-02*S231+3.355862e-01*S232+1.082120e-01*S233+2.325982e-01*S234+(-4.592959e-01)*S235+7.747063e-01*S236+(-1.207112e+00)*S237+(-8.271896e-02)*S238+(-2.946570e-01)*S239'
.param V33_part25='V33_part24+(-7.221619e-01)*S240+(-6.962569e-01)*S241+(-4.567609e-01)*S242+(-7.922556e-01)*S243+(-1.034389e+00)*S244+(-5.424661e-01)*S245+(-1.075569e+00)*S246+(-9.744651e-01)*S247+(-1.175603e+00)*S248+(-1.019086e-01)*S249'
.param V33_part26='V33_part25+(-6.766498e-01)*S250+(-1.142772e+00)*S251+7.997550e-02*S252+(-8.704287e-01)*S253+(-5.737197e-01)*S254+(-5.997869e-01)*S255+(-1.763659e-01)*S256+1.036507e+00*S257+2.821866e-01*S258+(-2.206527e-01)*S259'
.param V33_part27='V33_part26+1.417923e+00*S260+2.489773e-01*S261+(-4.367212e-01)*S262+6.449773e-01*S263+(-9.642527e-01)*S264+9.035645e-02*S265+2.124528e-01*S266+7.581712e-01*S267+4.959419e-01*S268+8.027189e-01*S269'
.param V33_part28='V33_part27+(-4.788172e-01)*S270+(-1.295411e+00)*S271+(-1.094028e+00)*S272+(-2.780394e-01)*S273+(-1.328521e+00)*S274+(-9.093920e-01)*S275+(-3.179575e-01)*S276+2.983032e-01*S277+(-6.769833e-01)*S278+(-3.618182e-01)*S279'
.param V33_part29='V33_part28+(-1.935082e-01)*S280+(-7.067859e-01)*S281+5.726542e-02*S282+3.686885e-02*S283+(-3.643182e-01)*S284+(-5.270254e-01)*S285+(-1.056093e-01)*S286+1.488838e+00*S287+(-1.428049e-01)*S288+(-2.630384e-01)*S289'
.param V33_part30='V33_part29+2.117232e-01*S290+(-9.686238e-02)*S291+2.394446e-01*S292+8.492310e-01*S293+(-1.995237e-01)*S294+4.597799e-02*S295+(-6.137670e-01)*S296+(-1.218863e-02)*S297+(-3.270616e-01)*S298+(-1.560879e+00)*S299'
.param V33_part31='V33_part30+3.262687e-01*S300+8.120278e-01*S301+7.141253e-01*S302+2.612604e-01*S303+5.806168e-01*S304+(-4.213805e-02)*S305+3.942092e-01*S306+4.130737e-01*S307+(-9.634424e-01)*S308+3.022932e-01*S309'
.param V33='V33_part31+6.548370e-01*S310+(-1.789620e-01)*S311+3.920164e-01*S312+1.122290e+00*S313+(-9.562985e-02)*S314'
.param V34_part1='4.102783e-03*S0+(-8.850196e-03)*S1+(-1.760742e-02)*S2+1.188439e-02*S3+(-1.240449e-02)*S4+(-1.666775e-02)*S5+(-6.772740e-03)*S6+(-1.759800e-02)*S7+(-5.352973e-03)*S8+(-1.424696e-02)*S9'
.param V34_part2='V34_part1+(-3.011997e-03)*S10+(-3.442255e-03)*S11+(-2.374621e-02)*S12+7.532314e-04*S13+3.124852e-03*S14+(-7.945449e-03)*S15+2.425311e-02*S16+1.932990e-02*S17+(-1.151829e-03)*S18+1.480341e-02*S19'
.param V34_part3='V34_part2+1.217005e-02*S20+9.519985e-03*S21+9.225361e-03*S22+(-4.859151e-04)*S23+3.023645e-03*S24+8.908634e-03*S25+4.716031e-03*S26+(-6.847609e-04)*S27+(-1.759787e-03)*S28+1.629951e-02*S29'
.param V34_part4='V34_part3+1.008248e-01*S30+7.284880e-03*S31+1.791715e-01*S32+9.544893e-02*S33+1.197603e-01*S34+1.718617e-01*S35+2.708267e-02*S36+4.434588e-02*S37+1.326903e-01*S38+(-1.532524e-01)*S39'
.param V34_part5='V34_part4+5.742658e-02*S40+2.426779e-02*S41+(-2.380870e-01)*S42+(-3.477277e-01)*S43+(-4.212414e-01)*S44+1.596191e-01*S45+6.655152e-02*S46+2.357788e-01*S47+5.968636e-02*S48+(-1.723420e-01)*S49'
.param V34_part6='V34_part5+2.303125e-01*S50+(-2.291162e-01)*S51+(-1.597474e-01)*S52+1.234664e-01*S53+(-5.125162e-01)*S54+(-3.280703e-01)*S55+(-1.175091e+00)*S56+(-1.068376e+00)*S57+(-4.404088e-01)*S58+(-2.420764e-01)*S59'
.param V34_part7='V34_part6+1.375855e-01*S60+2.591776e-01*S61+2.854285e-01*S62+1.917990e-02*S63+1.676216e-01*S64+1.970294e-01*S65+(-3.053406e-01)*S66+1.112893e+00*S67+(-9.037253e-01)*S68+(-4.241316e+00)*S69'
.param V34_part8='V34_part7+(-1.043208e+00)*S70+5.896283e-02*S71+(-1.044871e+00)*S72+(-8.256501e-01)*S73+(-1.335827e+00)*S74+6.871471e-02*S75+7.712328e-02*S76+3.787450e-02*S77+6.254782e-02*S78+1.126880e-01*S79'
.param V34_part9='V34_part8+1.799212e-01*S80+8.882116e-02*S81+(-1.513190e-02)*S82+(-3.389399e-02)*S83+4.136024e-02*S84+(-1.648820e-01)*S85+(-1.964764e-01)*S86+(-3.889845e-01)*S87+(-5.043912e-02)*S88+1.634822e-02*S89'
.param V34_part10='V34_part9+4.998041e-01*S90+5.248658e-01*S91+6.141205e-01*S92+(-3.924095e-01)*S93+5.159598e-01*S94+3.084509e-01*S95+(-7.225463e-01)*S96+(-7.412760e-01)*S97+7.372433e-01*S98+(-9.187981e-01)*S99'
.param V34_part11='V34_part10+(-1.170340e+00)*S100+(-2.325247e-01)*S101+(-8.845775e-01)*S102+(-1.176716e+00)*S103+2.028779e-01*S104+(-7.561672e-02)*S105+8.311223e-03*S106+6.051133e-01*S107+(-2.554139e-01)*S108+(-6.022726e-01)*S109'
.param V34_part12='V34_part11+8.341140e-01*S110+(-7.541329e-01)*S111+(-9.156038e-01)*S112+6.015499e-01*S113+2.522684e-01*S114+(-8.406947e-01)*S115+(-1.189819e+00)*S116+(-9.861510e-01)*S117+(-1.129685e+00)*S118+(-6.099532e-02)*S119'
.param V34_part13='V34_part12+2.105047e-01*S120+8.316048e-02*S121+9.661859e-01*S122+(-3.359326e-01)*S123+(-6.936403e-01)*S124+5.370557e-01*S125+(-3.965781e-01)*S126+(-1.011265e+00)*S127+5.181550e-01*S128+(-4.873204e-01)*S129'
.param V34_part14='V34_part13+(-3.525533e-01)*S130+3.014602e-01*S131+(-8.548676e-01)*S132+(-1.321557e+00)*S133+(-2.088757e-01)*S134+(-1.901362e-02)*S135+2.581979e-01*S136+4.340676e-01*S137+4.461457e-01*S138+(-8.927009e-02)*S139'
.param V34_part15='V34_part14+5.236360e-01*S140+4.549298e-01*S141+(-4.914460e-01)*S142+6.499260e-01*S143+4.612628e-01*S144+5.118532e-01*S145+6.967854e-01*S146+5.360719e-01*S147+6.153000e-01*S148+(-1.201814e-01)*S149'
.param V34_part16='V34_part15+(-3.316168e-01)*S150+1.152786e+00*S151+1.419997e+00*S152+(-4.228109e-01)*S153+(-9.181567e-01)*S154+1.491898e+00*S155+8.504655e-01*S156+(-7.925748e-01)*S157+7.107287e-01*S158+(-1.217978e-01)*S159'
.param V34_part17='V34_part16+(-9.059560e-01)*S160+(-2.672157e-01)*S161+7.843667e-01*S162+(-7.370492e-01)*S163+(-6.475146e-01)*S164+(-1.228846e-02)*S165+(-3.225680e-01)*S166+1.629032e+00*S167+(-2.057973e-01)*S168+(-7.442145e-01)*S169'
.param V34_part18='V34_part17+1.951871e+00*S170+6.640380e-03*S171+(-4.262656e-01)*S172+1.290251e+00*S173+(-9.714005e-01)*S174+(-1.467205e+00)*S175+(-8.293138e-01)*S176+(-6.691936e-01)*S177+(-1.396746e+00)*S178+(-1.024579e+00)*S179'
.param V34_part19='V34_part18+(-4.031289e-02)*S180+(-4.196090e-01)*S181+1.497457e+00*S182+7.281306e-02*S183+(-9.203441e-02)*S184+4.449544e-01*S185+(-7.329094e-01)*S186+(-6.041165e-01)*S187+(-6.879436e-01)*S188+(-8.492807e-01)*S189'
.param V34_part20='V34_part19+6.518240e-01*S190+(-1.098896e+00)*S191+(-4.287014e-01)*S192+(-1.424209e+00)*S193+(-3.419243e-01)*S194+(-6.189949e-01)*S195+(-7.001171e-01)*S196+1.095813e+00*S197+(-5.338149e-01)*S198+(-3.190188e+00)*S199'
.param V34_part21='V34_part20+1.381771e+00*S200+(-1.223309e+00)*S201+(-1.689652e+00)*S202+1.833119e-01*S203+(-4.810730e-01)*S204+(-1.703818e+00)*S205+(-2.220093e+00)*S206+(-1.073865e+00)*S207+(-2.188310e+00)*S208+(-1.527940e+00)*S209'
.param V34_part22='V34_part21+1.337970e-01*S210+1.641199e+00*S211+2.067075e+00*S212+5.387909e-01*S213+(-2.554021e-01)*S214+2.113261e+00*S215+(-2.188015e-01)*S216+8.203719e-01*S217+(-6.051970e-01)*S218+8.592795e-01*S219'
.param V34_part23='V34_part22+(-8.796848e-01)*S220+7.850493e-02*S221+(-4.238291e-01)*S222+2.771945e-01*S223+1.062858e-01*S224+6.103302e-01*S225+5.425118e-01*S226+3.872218e-02*S227+(-9.855827e-02)*S228+(-8.394913e-01)*S229'
.param V34_part24='V34_part23+5.737533e-02*S230+1.006945e-01*S231+(-5.326688e-01)*S232+(-1.085332e+00)*S233+(-4.815816e-01)*S234+(-6.121889e-01)*S235+(-8.470639e-01)*S236+5.194311e-01*S237+(-7.276722e-01)*S238+(-1.207281e+00)*S239'
.param V34_part25='V34_part24+7.098817e-01*S240+1.366242e-02*S241+(-6.193526e-01)*S242+(-6.810477e-02)*S243+(-6.783240e-01)*S244+(-1.525709e+00)*S245+1.129035e+00*S246+(-5.924727e-01)*S247+(-1.407088e+00)*S248+(-7.305223e-02)*S249'
.param V34_part26='V34_part25+(-6.212339e-01)*S250+1.362461e+00*S251+(-1.562093e-01)*S252+(-7.790631e-01)*S253+1.964874e-01*S254+7.948730e-01*S255+(-1.147168e+00)*S256+2.128359e+00*S257+(-8.988886e-01)*S258+(-5.775625e-01)*S259'
.param V34_part27='V34_part26+6.011109e-02*S260+(-5.324221e-01)*S261+(-1.469241e+00)*S262+(-5.171566e-01)*S263+(-1.034133e+00)*S264+(-1.071523e+00)*S265+(-1.977168e+00)*S266+(-1.152100e+00)*S267+(-9.158650e-01)*S268+(-8.308390e-01)*S269'
.param V34_part28='V34_part27+3.363730e-01*S270+7.365338e-01*S271+2.696392e+00*S272+(-4.911264e-02)*S273+1.409364e-01*S274+(-3.543140e-01)*S275+8.418808e-02*S276+2.712177e-02*S277+(-4.927650e-01)*S278+(-3.746120e-02)*S279'
.param V34_part29='V34_part28+(-3.079927e-01)*S280+(-5.614580e-01)*S281+1.184069e-01*S282+(-6.608791e-01)*S283+(-2.160814e-01)*S284+(-1.324147e-01)*S285+(-6.325797e-02)*S286+3.230092e+00*S287+5.720918e-01*S288+(-5.794072e-01)*S289'
.param V34_part30='V34_part29+2.634525e+00*S290+3.461236e-01*S291+(-3.709859e-02)*S292+2.773430e-01*S293+3.865954e-01*S294+3.242398e-02*S295+3.090792e+00*S296+(-6.290744e-02)*S297+(-1.160140e-01)*S298+2.210266e+00*S299'
.param V34_part31='V34_part30+(-3.053213e-01)*S300+(-5.247846e-01)*S301+(-1.436150e-01)*S302+(-3.073685e-01)*S303+(-8.618385e-01)*S304+1.492181e+00*S305+(-3.278459e-01)*S306+8.546501e-02*S307+1.385137e+00*S308+(-8.469729e-02)*S309'
.param V34='V34_part31+(-1.009331e+00)*S310+1.571409e+00*S311+(-4.414774e-01)*S312+(-6.665714e-01)*S313+1.654546e-01*S314'
.param V35_part1='1.516669e+01*S0+1.236240e+01*S1+3.210070e+01*S2+1.390522e+01*S3+1.770675e+01*S4+6.733046e+00*S5+8.979912e+00*S6+9.072217e+00*S7+1.242259e+02*S8+7.297187e+00*S9'
.param V35_part2='V35_part1+3.987174e+01*S10+1.255216e+02*S11+7.484270e+00*S12+5.746449e+01*S13+1.577481e+01*S14+7.183445e+00*S15+7.972408e+00*S16+1.453542e+01*S17+1.237605e+01*S18+8.820980e+00*S19'
.param V35_part3='V35_part2+(-2.650788e+01)*S20+6.701338e+01*S21+1.935497e+01*S22+2.276382e+01*S23+3.531763e+02*S24+2.151971e+01*S25+5.041264e+01*S26+1.044177e+01*S27+2.411275e+01*S28+4.500460e+01*S29'
.param V35_part4='V35_part3+6.985412e+00*S30+8.853720e+00*S31+5.986441e+00*S32+8.458925e+00*S33+6.608621e+00*S34+5.469025e+00*S35+6.172356e+00*S36+1.192496e+01*S37+4.851961e+00*S38+7.533917e+00*S39'
.param V35_part5='V35_part4+9.276335e+00*S40+5.552794e+00*S41+4.364398e+00*S42+3.965923e+00*S43+6.158197e+00*S44+9.848146e+00*S45+1.023740e+01*S46+8.304717e+00*S47+6.468854e+00*S48+9.593574e+00*S49'
.param V35_part6='V35_part5+5.409897e+00*S50+1.100561e+01*S51+2.982514e+00*S52+1.352164e+01*S53+2.421146e+01*S54+1.033488e+01*S55+7.098969e+00*S56+1.229187e+01*S57+7.514308e+00*S58+1.291846e+01*S59'
.param V35_part7='V35_part6+1.381567e+01*S60+6.541487e+00*S61+8.323964e+00*S62+1.246899e+01*S63+5.677627e+00*S64+8.078774e+00*S65+7.087435e+00*S66+8.414541e+03*S67+5.221922e+00*S68+9.378423e+01*S69'
.param V35_part8='V35_part7+1.067085e+03*S70+1.095951e+01*S71+2.061643e+00*S72+7.997040e+00*S73+2.497813e+00*S74+1.045531e+01*S75+1.243595e+01*S76+6.476013e+00*S77+1.023139e+01*S78+8.296017e+00*S79'
.param V35_part9='V35_part8+1.342955e+01*S80+7.906749e+00*S81+1.003868e+01*S82+1.196513e+01*S83+9.443069e+00*S84+8.205011e+00*S85+5.287495e+00*S86+1.794618e+00*S87+5.463029e+00*S88+1.241260e+01*S89'
.param V35_part10='V35_part9+7.524497e+00*S90+7.031876e+00*S91+4.088553e+00*S92+6.444709e+00*S93+7.602415e+00*S94+4.801783e+00*S95+5.308436e+00*S96+4.092942e+00*S97+3.562583e+00*S98+4.712161e+00*S99'
.param V35_part11='V35_part10+4.242510e+00*S100+3.625085e+01*S101+4.312727e+00*S102+3.801612e+00*S103+8.389935e+00*S104+8.336006e+00*S105+2.034855e+01*S106+1.293536e+01*S107+6.516406e+00*S108+7.883487e+00*S109'
.param V35_part12='V35_part11+9.477577e+00*S110+2.116635e+01*S111+4.808865e+00*S112+4.080940e+00*S113+5.874202e+00*S114+6.260167e+00*S115+3.449555e+00*S116+5.024306e+00*S117+2.218253e+01*S118+9.466511e+02*S119'
.param V35_part13='V35_part12+7.551514e+00*S120+5.473492e+00*S121+5.505034e+00*S122+6.086149e+00*S123+4.601674e+00*S124+6.741096e+00*S125+5.093735e+00*S126+4.486404e+00*S127+1.917578e+01*S128+4.519663e+00*S129'
.param V35_part14='V35_part13+5.120544e+00*S130+1.075763e+01*S131+1.316563e+01*S132+3.366968e+00*S133+1.180973e+01*S134+9.911196e+00*S135+1.088323e+01*S136+1.560581e+01*S137+4.192556e+01*S138+2.076308e+03*S139'
.param V35_part15='V35_part14+1.475617e+01*S140+1.000000e+04*S141+8.612110e+00*S142+4.993076e+00*S143+1.000000e+04*S144+1.000000e+04*S145+1.762730e+02*S146+1.820281e+02*S147+8.979181e+00*S148+6.137325e+01*S149'
.param V35_part16='V35_part15+7.996634e+00*S150+5.210301e+00*S151+3.493537e+00*S152+5.657472e+00*S153+8.100109e+00*S154+3.781781e+00*S155+4.240987e+00*S156+1.264412e+01*S157+5.136140e+00*S158+4.685948e+00*S159'
.param V35_part17='V35_part16+4.502809e+00*S160+3.264984e+00*S161+5.349476e+00*S162+3.873078e+00*S163+2.425517e+00*S164+6.847570e+00*S165+2.329634e+02*S166+6.780094e+03*S167+4.745359e+01*S168+9.668131e+00*S169'
.param V35_part18='V35_part17+3.817090e+00*S170+5.010708e+00*S171+4.990713e+00*S172+3.429710e+00*S173+4.783089e+00*S174+4.034645e+00*S175+3.375264e+00*S176+4.784978e+00*S177+3.861040e+00*S178+3.374385e+00*S179'
.param V35_part19='V35_part18+5.986273e+00*S180+4.359312e+00*S181+3.682856e+00*S182+6.496228e+00*S183+5.702622e+00*S184+6.905668e+01*S185+4.685090e+00*S186+4.272337e+00*S187+3.436150e+00*S188+4.348515e+00*S189'
.param V35_part20='V35_part19+5.138783e+00*S190+4.023043e+00*S191+4.133680e+00*S192+3.615781e+00*S193+3.038084e+00*S194+9.470611e+00*S195+5.621057e+00*S196+5.257788e+01*S197+2.064995e+01*S198+6.052153e+01*S199'
.param V35_part21='V35_part20+7.819523e+01*S200+8.500092e+00*S201+1.000000e+04*S202+6.094108e+01*S203+8.249345e+00*S204+9.563915e+01*S205+3.243936e+01*S206+9.973579e+00*S207+3.399734e+00*S208+4.686724e+00*S209'
.param V35_part22='V35_part21+5.475629e+00*S210+4.063605e+00*S211+3.778340e+00*S212+6.394245e+00*S213+4.292140e+00*S214+3.356286e+00*S215+1.000000e+04*S216+3.114726e+00*S217+2.687196e+00*S218+2.715186e+00*S219'
.param V35_part23='V35_part22+3.151087e+00*S220+3.056014e+00*S221+5.275359e+00*S222+3.663178e+00*S223+3.567786e+00*S224+6.803381e+00*S225+5.830467e+00*S226+3.403222e+00*S227+3.914508e+00*S228+4.192565e+00*S229'
.param V35_part24='V35_part23+3.362910e+00*S230+7.023197e+00*S231+6.074284e+00*S232+3.338064e+00*S233+4.404723e+00*S234+4.073904e+00*S235+3.311905e+00*S236+8.028051e+00*S237+3.425330e+00*S238+2.692276e+00*S239'
.param V35_part25='V35_part24+4.286430e+00*S240+4.560067e+00*S241+3.500479e+00*S242+4.702912e+00*S243+4.007040e+00*S244+3.108026e+00*S245+6.157508e+00*S246+3.839703e+00*S247+2.864128e+00*S248+4.141478e+00*S249'
.param V35_part26='V35_part25+3.468436e+00*S250+1.486102e+00*S251+4.118568e+00*S252+2.730768e+00*S253+1.271279e+00*S254+5.506459e+00*S255+6.476293e+00*S256+4.820970e+00*S257+7.053170e+00*S258+6.407897e+00*S259'
.param V35_part27='V35_part26+4.017860e+00*S260+6.323582e+00*S261+4.835991e+00*S262+6.270128e+00*S263+5.227308e+00*S264+4.629149e+00*S265+3.291849e+00*S266+3.794908e+00*S267+2.684801e+00*S268+2.812205e+00*S269'
.param V35_part28='V35_part27+3.931519e+00*S270+4.629653e+00*S271+3.497249e+00*S272+4.915742e+00*S273+4.499232e+00*S274+2.241029e+00*S275+4.097688e+00*S276+2.119225e+00*S277+2.156257e+00*S278+4.223453e+00*S279'
.param V35_part29='V35_part28+4.081467e+00*S280+1.954859e+00*S281+2.976650e+00*S282+2.737291e+00*S283+2.579967e+00*S284+5.170642e+00*S285+4.258489e+00*S286+4.007124e+00*S287+3.646081e+00*S288+3.911188e+00*S289'
.param V35_part30='V35_part29+3.862762e+00*S290+4.363597e+00*S291+3.616487e+00*S292+2.151945e+00*S293+3.682746e+00*S294+3.213382e+00*S295+1.274685e+00*S296+2.958435e+00*S297+2.537608e+00*S298+1.296633e+00*S299'
.param V35_part31='V35_part30+4.614843e+01*S300+4.906149e+00*S301+4.665215e+00*S302+5.361643e+00*S303+5.544532e+00*S304+3.118689e+00*S305+4.867232e+00*S306+3.887649e+00*S307+1.680167e+00*S308+4.095787e+00*S309'
.param V35='V35_part31+3.845599e+00*S310+1.284873e+00*S311+3.169795e+00*S312+3.330264e+00*S313+1.124778e+00*S314'
.param V36_part1='(-1.927879e+01)*S0+2.257666e+01*S1+(-4.643882e+01)*S2+(-1.003056e+01)*S3+(-1.330139e+01)*S4+(-1.546103e-01)*S5+1.267733e+00*S6+9.875835e-01*S7+(-1.315275e+02)*S8+(-1.672567e+00)*S9'
.param V36_part2='V36_part1+(-2.758154e+01)*S10+(-9.060771e+01)*S11+(-1.725312e+00)*S12+(-1.016814e+01)*S13+(-2.928072e+00)*S14+(-6.703117e+00)*S15+(-6.689218e+00)*S16+(-1.004022e+01)*S17+(-5.892080e+00)*S18+(-2.731369e+00)*S19'
.param V36_part3='V36_part2+9.090468e+01*S20+(-5.327832e+01)*S21+(-1.389947e+01)*S22+9.714068e+00*S23+(-4.838921e+01)*S24+(-2.484960e+00)*S25+(-3.612552e+01)*S26+(-4.296957e+00)*S27+(-3.632189e-01)*S28+(-1.586803e+01)*S29'
.param V36_part4='V36_part3+(-2.989709e+00)*S30+(-1.897091e+00)*S31+(-2.888096e+00)*S32+(-2.774756e+00)*S33+(-2.247870e+00)*S34+(-2.383706e+00)*S35+(-2.140873e+00)*S36+(-9.535939e+00)*S37+(-1.873120e+00)*S38+(-2.295144e+00)*S39'
.param V36_part5='V36_part4+(-3.292289e+00)*S40+(-1.676647e+00)*S41+(-1.109091e-01)*S42+(-1.185040e+00)*S43+(-1.645065e+00)*S44+(-4.946244e+00)*S45+(-7.738582e+00)*S46+(-4.238770e+00)*S47+(-2.137230e+00)*S48+(-4.481428e+00)*S49'
.param V36_part6='V36_part5+(-1.850466e+00)*S50+(-5.734738e+00)*S51+(-1.152871e+00)*S52+(-1.241792e+00)*S53+(-4.253885e-01)*S54+(-1.365611e+00)*S55+(-1.205498e+00)*S56+(-3.072149e+00)*S57+(-2.830355e+00)*S58+(-3.031815e+00)*S59'
.param V36_part7='V36_part6+6.308346e-01*S60+(-2.309542e+00)*S61+(-2.382662e+00)*S62+(-9.990374e+00)*S63+(-1.969713e+00)*S64+(-4.410911e+00)*S65+(-4.109283e+00)*S66+3.420102e+02*S67+(-1.856650e+00)*S68+(-3.305457e+01)*S69'
.param V36_part8='V36_part7+2.124981e+02*S70+(-3.616282e+00)*S71+(-4.409049e-02)*S72+(-9.354530e-01)*S73+(-7.611615e-01)*S74+(-1.010866e+01)*S75+(-1.453636e+01)*S76+(-5.048540e+00)*S77+(-4.604973e+00)*S78+(-4.159599e+00)*S79'
.param V36_part9='V36_part8+(-4.976328e+00)*S80+(-4.931023e+00)*S81+(-5.565076e+00)*S82+(-7.346126e+00)*S83+(-1.654521e+00)*S84+(-3.380962e+00)*S85+(-7.714294e-01)*S86+3.280908e+00*S87+(-3.081703e-01)*S88+(-3.953100e+00)*S89'
.param V36_part10='V36_part9+(-7.083237e-01)*S90+(-2.676067e+00)*S91+(-5.534995e-01)*S92+(-3.117809e+00)*S93+(-1.424126e+00)*S94+(-1.699853e+00)*S95+(-2.382630e+00)*S96+(-1.811543e+00)*S97+(-9.202520e-01)*S98+(-2.008175e+00)*S99'
.param V36_part11='V36_part10+(-1.339732e+00)*S100+(-1.320955e+00)*S101+(-1.308101e+00)*S102+(-1.037285e+00)*S103+(-1.054944e+00)*S104+(-6.439110e+00)*S105+3.139708e+01*S106+(-3.520635e+00)*S107+(-3.316343e+00)*S108+(-2.587094e+00)*S109'
.param V36_part12='V36_part11+(-9.009608e-01)*S110+(-1.091680e+01)*S111+(-1.573513e+00)*S112+(-1.875924e-01)*S113+(-7.113644e-01)*S114+(-1.907258e+00)*S115+(-5.901711e-01)*S116+(-1.590054e+00)*S117+(-3.492298e+00)*S118+7.610391e-01*S119'
.param V36_part13='V36_part12+(-2.571429e+00)*S120+(-2.393182e+00)*S121+(-2.126068e+00)*S122+(-2.437941e+00)*S123+(-1.330961e+00)*S124+(-1.156724e+00)*S125+(-2.053847e+00)*S126+(-1.354094e+00)*S127+(-3.829429e+00)*S128+(-1.613215e+00)*S129'
.param V36_part14='V36_part13+(-1.598192e+00)*S130+(-1.931548e+00)*S131+(-1.487622e+00)*S132+(-9.993122e-01)*S133+(-1.703503e+00)*S134+(-5.458885e+00)*S135+(-4.604078e+00)*S136+(-2.689765e-03)*S137+2.262242e+01*S138+1.833031e+01*S139'
.param V36_part15='V36_part14+(-9.213303e+00)*S140+(-4.694460e-01)*S141+(-3.831115e+00)*S142+(-1.288497e+00)*S143+(-5.367738e+00)*S144+(-4.207670e+00)*S145+4.412137e+00*S146+(-1.251556e+00)*S147+6.584634e-01*S148+1.758342e+00*S149'
.param V36_part16='V36_part15+(-5.365194e+00)*S150+(-1.562582e+00)*S151+(-6.511614e-01)*S152+(-2.548408e+00)*S153+(-1.301924e+00)*S154+(-6.801929e-01)*S155+(-3.731861e-01)*S156+(-1.534190e+00)*S157+(-9.072343e-01)*S158+(-1.855011e+00)*S159'
.param V36_part17='V36_part16+(-1.490593e+00)*S160+(-8.355044e-01)*S161+(-1.805601e+00)*S162+(-1.089943e+00)*S163+(-4.127942e-01)*S164+(-3.487807e+00)*S165+(-5.909901e+00)*S166+5.652054e+00*S167+(-3.332264e+01)*S168+(-1.148647e+00)*S169'
.param V36_part18='V36_part17+(-2.731113e-01)*S170+(-2.113982e+00)*S171+(-1.741779e+00)*S172+(-1.311019e+00)*S173+(-1.077002e+00)*S174+(-7.924013e-01)*S175+(-8.523183e-01)*S176+(-1.041856e+00)*S177+(-6.444037e-01)*S178+4.291808e-01*S179'
.param V36_part19='V36_part18+(-2.874257e+00)*S180+(-1.203690e+00)*S181+(-1.055083e+00)*S182+(-1.350219e+00)*S183+(-2.077133e-01)*S184+9.530871e-01*S185+(-1.196664e+00)*S186+(-6.169906e-01)*S187+(-6.968589e-01)*S188+(-1.026332e+00)*S189'
.param V36_part20='V36_part19+(-9.587303e-01)*S190+(-1.245861e+00)*S191+(-1.017599e+00)*S192+(-5.628796e-01)*S193+(-3.233132e-01)*S194+(-5.023068e+00)*S195+(-2.419798e+00)*S196+5.680586e+00*S197+(-3.399144e+00)*S198+(-5.777249e-01)*S199'
.param V36_part21='V36_part20+3.568168e+00*S200+(-2.521988e+00)*S201+(-5.776729e+00)*S202+3.695411e+00*S203+(-1.593385e+00)*S204+(-6.852126e+00)*S205+(-1.444996e+00)*S206+(-1.361998e+00)*S207+(-7.365928e-01)*S208+(-9.781618e-01)*S209'
.param V36_part22='V36_part21+(-2.449373e+00)*S210+(-8.519696e-01)*S211+(-6.200972e-01)*S212+(-1.788121e+00)*S213+(-1.238360e+00)*S214+(-4.438732e-01)*S215+(-1.777051e+00)*S216+(-1.036804e+00)*S217+(-2.132045e-01)*S218+(-1.286269e+00)*S219'
.param V36_part23='V36_part22+(-4.576261e-01)*S220+(-4.803759e-01)*S221+(-1.028597e+00)*S222+(-5.071345e-01)*S223+(-3.214555e-01)*S224+(-8.750931e-01)*S225+(-1.701733e+00)*S226+(-7.354940e-01)*S227+(-1.351138e+00)*S228+(-9.578583e-01)*S229'
.param V36_part24='V36_part23+(-7.544478e-01)*S230+(-2.747370e+00)*S231+1.616924e-01*S232+(-1.296293e-01)*S233+(-1.085695e+00)*S234+(-9.091358e-01)*S235+(-2.389663e-01)*S236+(-2.604787e+00)*S237+(-6.838221e-01)*S238+(-2.890699e-01)*S239'
.param V36_part25='V36_part24+(-2.060576e+00)*S240+(-1.327012e+00)*S241+(-6.499392e-01)*S242+(-1.456607e+00)*S243+(-9.702610e-01)*S244+(-3.037550e-01)*S245+(-9.315883e-01)*S246+(-1.214710e+00)*S247+(-3.258625e-01)*S248+(-1.090729e+00)*S249'
.param V36_part26='V36_part25+(-8.623551e-01)*S250+(-3.930824e-01)*S251+(-1.122806e+00)*S252+(-4.390253e-01)*S253+(-3.339254e-01)*S254+(-1.095540e+00)*S255+(-9.392780e-01)*S256+(-8.106775e-01)*S257+(-2.079928e+00)*S258+(-1.764534e+00)*S259'
.param V36_part27='V36_part26+(-9.951458e-01)*S260+(-2.253201e+00)*S261+(-1.490727e+00)*S262+(-1.872981e+00)*S263+(-1.834068e+00)*S264+(-1.296903e+00)*S265+(-3.211680e-01)*S266+(-9.875956e-01)*S267+(-2.592531e-01)*S268+(-9.057235e-02)*S269'
.param V36_part28='V36_part27+(-1.563824e+00)*S270+(-1.682554e+00)*S271+(-8.379494e-01)*S272+(-1.197808e+00)*S273+(-1.141980e+00)*S274+(-3.668718e-01)*S275+(-1.224534e+00)*S276+1.582055e+00*S277+(-3.427723e-01)*S278+(-8.945429e-01)*S279'
.param V36_part29='V36_part28+(-6.574170e-01)*S280+(-3.280122e-01)*S281+(-7.746630e-01)*S282+(-3.249693e-01)*S283+(-2.457633e-01)*S284+(-1.984475e+00)*S285+(-1.182900e+00)*S286+(-8.702705e-01)*S287+(-1.940400e+00)*S288+(-7.815859e-01)*S289'
.param V36_part30='V36_part29+(-5.954797e-01)*S290+(-1.283750e+00)*S291+(-6.408842e-01)*S292+(-3.767231e-01)*S293+(-1.550988e+00)*S294+(-6.740519e-01)*S295+(-2.747009e-01)*S296+(-7.521213e-01)*S297+(-4.437726e-01)*S298+(-3.900741e-01)*S299'
.param V36_part31='V36_part30+(-7.055628e+00)*S300+(-1.797574e+00)*S301+(-1.102370e+00)*S302+(-1.039451e+00)*S303+(-1.697174e+00)*S304+(-7.513297e-01)*S305+(-9.995305e-01)*S306+(-6.572341e-01)*S307+(-4.813722e-01)*S308+(-1.092699e+00)*S309'
.param V36='V36_part31+(-8.505018e-01)*S310+(-3.406443e-01)*S311+(-8.373654e-01)*S312+(-7.667443e-01)*S313+(-2.615497e-01)*S314'
.param V37_part1='(-5.471615e-01)*S0+5.763937e+01*S1+2.767470e+01*S2+(-9.188747e+00)*S3+(-6.778805e+00)*S4+(-2.103017e+00)*S5+2.268524e-01*S6+(-3.247489e+00)*S7+(-3.008478e+00)*S8+(-3.759125e+00)*S9'
.param V37_part2='V37_part1+4.730852e+00*S10+(-1.706165e+01)*S11+(-4.018349e+00)*S12+(-4.083903e+01)*S13+(-4.578336e+00)*S14+(-4.001726e-01)*S15+(-4.511198e+00)*S16+(-6.822349e+00)*S17+(-1.034665e+01)*S18+(-5.987321e+00)*S19'
.param V37_part3='V37_part2+3.577323e+01*S20+5.993719e+01*S21+(-6.300969e+00)*S22+(-2.839571e+00)*S23+7.764069e+01*S24+(-9.383810e+00)*S25+(-3.629523e+00)*S26+2.624449e+00*S27+2.279957e+01*S28+7.987039e+00*S29'
.param V37_part4='V37_part3+(-6.068932e+00)*S30+(-6.572060e+00)*S31+(-1.705746e+00)*S32+(-5.425765e+00)*S33+(-2.979981e+00)*S34+(-1.380090e+00)*S35+(-2.407442e+00)*S36+(-2.189510e-01)*S37+(-1.208371e+00)*S38+(-3.966868e+00)*S39'
.param V37_part5='V37_part4+(-3.469019e+00)*S40+(-1.681286e+00)*S41+(-2.498727e+00)*S42+3.777320e-01*S43+(-1.632249e+00)*S44+(-6.159612e+00)*S45+(-2.862332e+00)*S46+(-2.620926e+00)*S47+(-2.898616e+00)*S48+(-3.947326e+00)*S49'
.param V37_part6='V37_part5+(-1.497131e+00)*S50+(-7.136185e+00)*S51+(-7.444363e-01)*S52+3.825503e+00*S53+(-1.158306e+01)*S54+(-6.226773e-01)*S55+1.450209e+00*S56+(-6.049292e+00)*S57+(-2.520661e+00)*S58+4.384191e+00*S59'
.param V37_part7='V37_part6+(-1.272156e+01)*S60+(-3.299249e+00)*S61+(-3.715914e+00)*S62+(-2.225246e+00)*S63+(-2.472788e+00)*S64+(-1.167598e+00)*S65+(-2.334493e+00)*S66+4.560476e+02*S67+(-1.617562e+00)*S68+(-8.964522e+01)*S69'
.param V37_part8='V37_part7+(-2.100012e+01)*S70+(-4.809660e+00)*S71+(-5.999870e-01)*S72+(-5.163300e+00)*S73+(-7.315045e-01)*S74+(-3.960805e-01)*S75+(-2.368063e+00)*S76+(-6.806130e-01)*S77+4.766953e-01*S78+1.241939e+00*S79'
.param V37_part9='V37_part8+(-5.577189e+00)*S80+(-1.467699e+00)*S81+(-2.383979e+00)*S82+(-1.977690e+00)*S83+2.516587e+00*S84+(-1.072922e+00)*S85+(-5.593422e-01)*S86+(-3.187629e-01)*S87+(-1.581700e+00)*S88+(-3.947193e+00)*S89'
.param V37_part10='V37_part9+(-7.031778e+00)*S90+(-4.443468e+00)*S91+(-1.526410e+00)*S92+(-5.053657e+00)*S93+(-5.834195e+00)*S94+(-1.428135e+00)*S95+(-2.723313e+00)*S96+(-1.101951e+00)*S97+(-1.028046e+00)*S98+(-2.145622e+00)*S99'
.param V37_part11='V37_part10+(-1.331695e+00)*S100+8.676154e+00*S101+(-1.121261e+00)*S102+(-1.046277e+00)*S103+(-4.854462e+00)*S104+(-6.786546e+00)*S105+6.201694e+01*S106+(-2.435930e+00)*S107+(-4.997653e+00)*S108+(-2.685076e+00)*S109'
.param V37_part12='V37_part11+(-3.626458e-01)*S110+(-5.954490e+00)*S111+(-2.402871e+00)*S112+(-1.515628e+00)*S113+(-2.497256e+00)*S114+(-3.641474e+00)*S115+(-1.005277e+00)*S116+(-1.897226e+00)*S117+(-1.934719e+01)*S118+1.306090e+01*S119'
.param V37_part13='V37_part12+(-6.945053e+00)*S120+(-3.449116e+00)*S121+(-2.583183e+00)*S122+(-4.398652e+00)*S123+(-2.575909e+00)*S124+(-3.903270e+00)*S125+(-3.247329e+00)*S126+(-2.368600e+00)*S127+(-1.231329e+01)*S128+(-2.470146e+00)*S129'
.param V37_part14='V37_part13+(-2.455905e+00)*S130+(-6.140760e+00)*S131+(-2.030495e-01)*S132+(-1.489371e+00)*S133+(-6.989367e+00)*S134+(-9.370310e+00)*S135+(-8.255025e+00)*S136+1.422316e+00*S137+7.808857e+00*S138+2.610063e+01*S139'
.param V37_part15='V37_part14+(-6.479774e+00)*S140+(-1.564436e+01)*S141+(-4.520336e+00)*S142+(-1.908241e+00)*S143+(-2.499114e+01)*S144+(-2.309131e+01)*S145+1.508213e+01*S146+2.353879e+00*S147+(-1.211890e+00)*S148+8.614941e+00*S149'
.param V37_part16='V37_part15+(-7.592640e+00)*S150+(-3.446569e+00)*S151+(-1.321295e+00)*S152+(-3.744783e+00)*S153+(-5.603016e+00)*S154+(-1.348794e+00)*S155+(-1.251721e+00)*S156+(-8.112040e+00)*S157+(-2.830536e+00)*S158+(-3.192735e+00)*S159'
.param V37_part17='V37_part16+(-1.935848e+00)*S160+(-1.051490e+00)*S161+(-4.184374e+00)*S162+(-1.635470e+00)*S163+(-7.800168e-01)*S164+(-7.127397e+00)*S165+(-2.469631e+01)*S166+7.444179e+00*S167+(-3.558224e+01)*S168+(-4.912826e+00)*S169'
.param V37_part18='V37_part17+(-1.590325e+00)*S170+(-2.146651e+00)*S171+(-2.798627e+00)*S172+(-1.202308e+00)*S173+(-1.823899e+00)*S174+(-1.956711e+00)*S175+(-1.143681e+00)*S176+(-1.591874e+00)*S177+(-1.662074e+00)*S178+(-5.565502e-01)*S179'
.param V37_part19='V37_part18+(-5.004225e+00)*S180+(-3.035989e+00)*S181+(-1.486140e+00)*S182+(-7.576507e+00)*S183+(-4.752688e+00)*S184+4.484324e+00*S185+(-2.067792e+00)*S186+(-2.921715e+00)*S187+(-1.359659e+00)*S188+(-1.531043e+00)*S189'
.param V37_part20='V37_part19+(-1.736512e+00)*S190+(-1.346490e+00)*S191+(-8.503095e-01)*S192+(-1.504950e+00)*S193+(-1.013678e+00)*S194+(-9.527064e+00)*S195+(-3.865356e+00)*S196+6.238715e+00*S197+(-2.341888e+01)*S198+4.534177e+01*S199'
.param V37_part21='V37_part20+9.527809e+00*S200+(-9.323126e+00)*S201+1.786041e+01*S202+8.031756e+00*S203+(-2.192236e+00)*S204+(-1.028647e+01)*S205+(-3.182224e-01)*S206+1.339455e-01*S207+(-5.408444e-01)*S208+(-2.088948e+00)*S209'
.param V37_part22='V37_part21+(-5.053747e+00)*S210+(-2.615036e+00)*S211+(-1.778823e+00)*S212+(-4.075597e+00)*S213+(-2.376723e+00)*S214+(-1.370803e+00)*S215+1.370406e+01*S216+(-1.762173e+00)*S217+(-1.040662e+00)*S218+(-6.907175e-01)*S219'
.param V37_part23='V37_part22+(-1.297591e+00)*S220+(-1.107022e+00)*S221+(-2.600376e+00)*S222+(-1.490023e+00)*S223+(-1.200930e+00)*S224+(-8.020797e+00)*S225+(-4.503599e+00)*S226+(-1.477413e+00)*S227+(-3.881205e+00)*S228+(-2.627905e+00)*S229'
.param V37_part24='V37_part23+(-1.487181e+00)*S230+(-3.368333e+00)*S231+(-1.294901e+00)*S232+(-1.703191e+00)*S233+(-2.014415e+00)*S234+(-2.024728e+00)*S235+(-1.231234e+00)*S236+(-7.592310e+00)*S237+(-1.630695e+00)*S238+(-1.013474e+00)*S239'
.param V37_part25='V37_part24+(-3.390904e+00)*S240+(-2.764700e+00)*S241+(-1.703553e+00)*S242+(-3.080566e+00)*S243+(-2.243820e+00)*S244+(-1.314061e+00)*S245+(-6.498306e+00)*S246+(-2.233845e+00)*S247+(-1.157611e+00)*S248+(-1.821320e+00)*S249'
.param V37_part26='V37_part25+(-1.772875e+00)*S250+(-5.093303e-01)*S251+(-3.466930e+00)*S252+(-1.258338e+00)*S253+(-2.730751e-01)*S254+(-4.638357e+00)*S255+(-5.106711e+00)*S256+(-1.407439e+00)*S257+(-7.571037e+00)*S258+(-4.970089e+00)*S259'
.param V37_part27='V37_part26+(-1.526215e+00)*S260+(-1.502617e+00)*S261+(-2.606531e+00)*S262+(-3.310665e+00)*S263+(-3.884359e+00)*S264+(-1.707303e+00)*S265+(-1.191881e+00)*S266+(-1.109391e+00)*S267+(-2.589962e-01)*S268+(-8.902012e-01)*S269'
.param V37_part28='V37_part27+(-4.200835e+00)*S270+(-3.114093e+00)*S271+(-1.672220e+00)*S272+(-1.170687e+00)*S273+(-3.126104e+00)*S274+(-7.795162e-01)*S275+(-2.808449e+00)*S276+7.751128e-01*S277+(-7.152210e-01)*S278+(-2.996602e+00)*S279'
.param V37_part29='V37_part28+(-1.977166e+00)*S280+(-5.060450e-01)*S281+(-2.469000e+00)*S282+(-6.728225e-01)*S283+(-9.560570e-01)*S284+(-4.350977e+00)*S285+(-2.610234e+00)*S286+(-2.072105e+00)*S287+(-2.086869e+00)*S288+(-2.523076e+00)*S289'
.param V37_part30='V37_part29+(-1.972475e+00)*S290+(-2.609374e+00)*S291+(-2.270883e+00)*S292+(-8.886872e-01)*S293+(-6.410221e-01)*S294+(-1.624662e+00)*S295+(-2.886969e-01)*S296+(-1.039661e+00)*S297+(-9.983005e-01)*S298+(-1.772437e-01)*S299'
.param V37_part31='V37_part30+(-9.870813e+00)*S300+(-3.238736e+00)*S301+(-2.636437e+00)*S302+(-2.903671e+00)*S303+(-2.590080e+00)*S304+(-1.370389e+00)*S305+(-2.019957e+00)*S306+(-2.467414e+00)*S307+(-6.674851e-01)*S308+(-2.301245e+00)*S309'
.param V37='V37_part31+(-2.191035e+00)*S310+(-3.817153e-01)*S311+(-2.262805e+00)*S312+(-1.590417e+00)*S313+(-2.947628e-01)*S314'
.param V38_part1='3.976309e+00*S0+3.005359e+01*S1+2.666551e+01*S2+(-3.723148e-02)*S3+8.422858e-01*S4+1.556341e-01*S5+(-7.058669e+00)*S6+(-4.099557e+00)*S7+7.089095e+00*S8+8.193480e-01*S9'
.param V38_part2='V38_part1+(-7.733748e+00)*S10+(-4.326119e-03)*S11+9.700235e-01*S12+(-3.865853e-02)*S13+(-1.357727e+00)*S14+2.201071e+00*S15+(-5.899992e-01)*S16+(-2.772029e-01)*S17+(-1.176505e+00)*S18+(-3.690749e-02)*S19'
.param V38_part3='V38_part2+4.754016e+00*S20+4.082532e+01*S21+3.632979e-02*S22+(-2.216556e+00)*S23+3.220298e+02*S24+(-7.503204e+00)*S25+6.654116e+00*S26+5.197733e+00*S27+2.780924e+01*S28+2.635143e+01*S29'
.param V38_part4='V38_part3+1.171715e+00*S30+1.281488e-01*S31+6.800227e-01*S32+2.350523e+00*S33+1.188502e+00*S34+7.719330e-01*S35+1.622593e+00*S36+3.194421e+00*S37+5.915281e-01*S38+1.767302e+00*S39'
.param V38_part5='V38_part4+1.770727e+00*S40+7.629716e-01*S41+1.900487e+00*S42+1.783954e+00*S43+1.386068e+00*S44+1.708984e+00*S45+1.947848e+00*S46+1.225188e+00*S47+1.276340e+00*S48+1.437107e+00*S49'
.param V38_part6='V38_part5+8.179653e-01*S50+(-2.351771e+00)*S51+8.431224e-01*S52+9.060257e+00*S53+1.342670e+01*S54+4.717813e+00*S55+4.147287e+00*S56+3.489883e+00*S57+(-2.974613e-01)*S58+8.963600e+00*S59'
.param V38_part7='V38_part6+5.086760e+00*S60+1.024797e+00*S61+3.434964e-01*S62+2.334275e+00*S63+9.680720e-01*S64+1.743859e+00*S65+8.875256e-01*S66+(-2.999372e+03)*S67+7.135884e-01*S68+(-1.774097e+01)*S69'
.param V38_part8='V38_part7+(-4.082256e+02)*S70+(-7.370811e-01)*S71+1.113665e+00*S72+(-1.197336e+00)*S73+8.350611e-02*S74+4.536095e+00*S75+2.132213e+00*S76+1.723401e+00*S77+5.446247e+00*S78+4.201028e+00*S79'
.param V38_part9='V38_part8+(-2.265817e+00)*S80+1.498299e+00*S81+1.888629e+00*S82+1.708520e-01*S83+(-4.602231e+00)*S84+(-7.783303e-01)*S85+(-6.292758e-01)*S86+(-4.258155e-01)*S87+(-1.738444e-01)*S88+5.358149e-01*S89'
.param V38_part10='V38_part9+1.663678e+00*S90+8.177534e-01*S91+7.398995e-01*S92+6.587744e-01*S93+6.006238e-01*S94+1.140889e+00*S95+8.744851e-01*S96+6.935110e-01*S97+5.275110e-01*S98+2.558989e-01*S99'
.param V38_part11='V38_part10+8.286593e-01*S100+3.673653e+01*S101+1.198786e+00*S102+8.135804e-01*S103+8.220402e-01*S104+6.088699e-01*S105+4.253479e+01*S106+6.007612e+00*S107+7.842604e-01*S108+2.239221e+00*S109'
.param V38_part12='V38_part11+5.097031e+00*S110+(-1.833354e+02)*S111+2.170000e-01*S112+4.335541e-01*S113+2.339383e+00*S114+5.017991e-02*S115+7.490213e-01*S116+1.286885e+00*S117+(-6.754294e-01)*S118+9.493594e+02*S119'
.param V38_part13='V38_part12+9.965948e-01*S120+5.483179e-01*S121+9.719691e-02*S122+1.306568e+00*S123+5.450110e-01*S124+(-4.306340e-01)*S125+3.757887e-01*S126+2.931119e-01*S127+(-2.890784e+00)*S128+4.202315e-01*S129'
.param V38_part14='V38_part13+6.937434e-01*S130+(-3.268324e-01)*S131+9.022092e+00*S132+7.670775e-02*S133+(-1.684306e+00)*S134+9.134740e-01*S135+6.961191e-01*S136+1.303286e+01*S137+4.827911e+01*S138+2.084142e+03*S139'
.param V38_part15='V38_part14+5.978468e-01*S140+9.979106e+03*S141+(-9.650134e-01)*S142+2.861856e-01*S143+9.973428e+03*S144+9.968299e+03*S145+1.827351e+02*S146+1.741929e+02*S147+5.819743e+00*S148+6.346805e+01*S149'
.param V38_part16='V38_part15+7.346200e-01*S150+6.662532e-01*S151+5.686742e-01*S152+1.094150e+00*S153+(-3.576494e-01)*S154+7.165609e-01*S155+1.526757e+00*S156+(-9.735082e+00)*S157+7.074011e-02*S158+1.657414e-02*S159'
.param V38_part17='V38_part16+5.504649e-01*S160+3.289366e-01*S161+6.055025e-01*S162+3.866090e-01*S163+3.476900e-01*S164+(-3.006641e-02)*S165+2.007827e+02*S166+6.774347e+03*S167+(-7.459954e+02)*S168+3.089674e+00*S169'
.param V38_part18='V38_part17+6.546797e-01*S170+1.035861e+00*S171+5.991907e-01*S172+2.694473e-01*S173+1.455874e+00*S174+7.034456e-01*S175+3.185355e-01*S176+1.757076e+00*S177+8.586033e-01*S178+1.423391e+00*S179'
.param V38_part19='V38_part18+1.108018e+00*S180+4.414688e-02*S181+2.483487e-01*S182+(-1.375580e-01)*S183+5.180108e-01*S184+6.482564e+01*S185+1.361940e+00*S186+1.691046e-01*S187+3.333945e-01*S188+1.377273e+00*S189'
.param V38_part20='V38_part19+1.303172e+00*S190+5.680425e-01*S191+1.558711e+00*S192+7.387177e-01*S193+6.851837e-01*S194+1.506893e+00*S195+4.029971e-01*S196+5.129031e+01*S197+6.325425e-01*S198+(-7.727978e+00)*S199'
.param V38_part21='V38_part20+7.829478e+01*S200+1.331406e-01*S201+9.990831e+03*S202+6.146599e+01*S203+3.688608e+00*S204+7.432675e+01*S205+2.586172e+01*S206+6.520363e+00*S207+8.013168e-01*S208+(-3.797887e-01)*S209'
.param V38_part22='V38_part21+7.116001e-01*S210+5.877589e-01*S211+3.701316e-01*S212+1.727555e+00*S213+6.611335e-01*S214+4.934317e-01*S215+9.996525e+03*S216+3.925597e-01*S217+4.744815e-01*S218+7.149583e-01*S219'
.param V38_part23='V38_part22+7.211620e-01*S220+5.903478e-01*S221+1.842001e+00*S222+9.687669e-01*S223+9.695387e-01*S224+6.112707e-01*S225+3.008026e-01*S226+4.886069e-01*S227+1.309689e-01*S228+6.349846e-01*S229'
.param V38_part24='V38_part23+3.445495e-01*S230+2.117109e+00*S231+2.820167e+00*S232+3.717377e-01*S233+1.296274e+00*S234+9.574610e-01*S235+7.102205e-01*S236+(-6.945271e-01)*S237+7.960665e-01*S238+4.631880e-01*S239'
.param V38_part25='V38_part24+4.429672e-01*S240+8.137272e-01*S241+3.849782e-01*S242+1.049902e+00*S243+6.847969e-01*S244+5.160046e-01*S245+6.345283e-01*S246+6.169663e-01*S247+4.746268e-01*S248+1.223414e+00*S249'
.param V38_part26='V38_part25+7.163318e-01*S250+1.780698e-01*S251+9.482252e-03*S252+5.038097e-01*S253+2.077988e-01*S254+1.140089e+00*S255+7.783459e-01*S256+1.481745e+00*S257+6.522218e-01*S258+2.551982e-01*S259'
.param V38_part27='V38_part26+6.445200e-01*S260+2.304564e+00*S261+5.973482e-01*S262+(-2.987232e-01)*S263+(-2.492980e-01)*S264+1.337948e+00*S265+3.316047e-01*S266+9.275570e-01*S267+4.205682e-01*S268+3.390554e-01*S269'
.param V38_part28='V38_part27+1.629948e-01*S270+1.144895e-01*S271+5.681234e-01*S272+1.853019e+00*S273+(-1.104389e-01)*S274+3.843572e-01*S275+8.503101e-01*S276+1.311365e+00*S277+3.944935e-01*S278+1.111540e+00*S279'
.param V38_part29='V38_part28+9.261781e-01*S280+3.809284e-01*S281+1.546855e-01*S282+8.683760e-01*S283+5.317188e-01*S284+1.011353e+00*S285+9.371525e-01*S286+2.733072e-01*S287+7.971710e-01*S288+6.352476e-01*S289'
.param V38_part30='V38_part29+3.375906e-01*S290+1.194158e+00*S291+6.384646e-01*S292+3.723069e-01*S293+1.035073e+00*S294+6.128814e-01*S295+2.627614e-01*S296+9.074716e-01*S297+5.624167e-01*S298+2.547478e-01*S299'
.param V38_part31='V38_part30+3.336862e+01*S300+7.913217e-01*S301+(-6.649490e-02)*S302+1.837595e+00*S303+1.455024e+00*S304+5.022884e-01*S305+1.662869e+00*S306+6.413510e-01*S307+1.917007e-01*S308+9.598400e-01*S309'
.param V38='V38_part31+6.654210e-01*S310+2.031480e-01*S311+5.461939e-01*S312+6.447832e-01*S313+1.900423e-01*S314'
.param V39_part1='8.688632e-02*S0+2.633924e-04*S1+1.465981e-02*S2+(-1.213172e-01)*S3+(-1.040473e-04)*S4+8.954002e-02*S5+(-4.391922e-02)*S6+6.491088e-02*S7+7.245952e-02*S8+4.382875e-02*S9'
.param V39_part2='V39_part1+5.027908e-01*S10+(-1.489020e-01)*S11+5.286502e-02*S12+1.658106e-01*S13+(-3.656885e-02)*S14+(-7.839772e-02)*S15+(-1.502069e-02)*S16+(-1.758415e-02)*S17+1.182292e-03*S18+(-2.028019e-02)*S19'
.param V39_part3='V39_part2+6.105205e-02*S20+(-9.921250e-02)*S21+(-7.973875e-03)*S22+2.466095e-03*S23+(-4.464293e-02)*S24+(-1.365383e-01)*S25+(-3.861533e-02)*S26+8.744098e-03*S27+(-1.485732e-02)*S28+2.144295e-01*S29'
.param V39_part4='V39_part3+(-8.333720e-03)*S30+(-1.558437e-01)*S31+(-4.206465e-02)*S32+(-1.111046e-02)*S33+3.061616e-03*S34+(-2.764171e-02)*S35+5.159453e-03*S36+(-1.371699e-01)*S37+(-2.218952e-02)*S38+1.653083e-02*S39'
.param V39_part5='V39_part4+1.657995e-02*S40+(-3.761741e-02)*S41+5.765954e-02*S42+(-1.151766e-01)*S43+1.591671e-01*S44+(-5.468256e-02)*S45+5.062689e-02*S46+(-2.570582e-02)*S47+9.236418e-02*S48+4.397586e-01*S49'
.param V39_part6='V39_part5+3.062739e-02*S50+(-3.842521e-01)*S51+9.162368e-02*S52+(-2.082729e-01)*S53+(-5.986464e-01)*S54+(-1.573204e-01)*S55+(-1.664513e-01)*S56+(-1.170209e+00)*S57+1.544617e-01*S58+(-4.834961e-01)*S59'
.param V39_part7='V39_part6+(-3.310193e-01)*S60+4.100742e-03*S61+7.569057e-02*S62+7.180393e-01*S63+7.235220e-02*S64+(-3.212580e-01)*S65+(-4.686427e-02)*S66+(-3.543912e+01)*S67+3.280773e-01*S68+(-3.757054e+00)*S69'
.param V39_part8='V39_part7+(-3.659798e+01)*S70+2.838272e-01*S71+(-4.374176e-01)*S72+(-4.010752e-03)*S73+(-2.034402e-02)*S74+(-2.706815e-03)*S75+1.589404e-01*S76+(-7.917635e-02)*S77+(-3.388187e-04)*S78+1.965481e-02*S79'
.param V39_part9='V39_part8+(-2.822740e-01)*S80+(-1.661598e-01)*S81+(-2.631511e-01)*S82+1.435853e-02*S83+8.172342e-01*S84+2.680002e-01*S85+3.412649e-01*S86+7.527257e-01*S87+3.143877e-01*S88+(-7.754555e-02)*S89'
.param V39_part10='V39_part9+(-9.646954e-04)*S90+(-2.183267e-02)*S91+1.166311e-02*S92+(-5.408798e-01)*S93+(-5.468436e-02)*S94+8.275908e-04*S95+(-6.776195e-01)*S96+(-2.672647e-01)*S97+(-4.223766e-02)*S98+(-5.169002e-01)*S99'
.param V39_part11='V39_part10+(-2.963409e-01)*S100+(-8.330078e-01)*S101+(-4.009800e-01)*S102+(-2.474591e-01)*S103+1.976014e-01*S104+(-7.309536e-02)*S105+(-3.959825e+00)*S106+(-9.321052e-02)*S107+(-3.797236e-01)*S108+(-5.248125e-01)*S109'
.param V39_part12='V39_part11+(-1.189664e-01)*S110+(-3.313115e+00)*S111+(-2.331851e-01)*S112+4.233872e-02*S113+(-9.742309e-02)*S114+(-6.203817e-02)*S115+6.811501e-02*S116+(-1.518695e-01)*S117+1.038016e+00*S118+(-7.631769e-01)*S119'
.param V39_part13='V39_part12+1.194930e-01*S120+(-1.550670e-01)*S121+(-1.014354e-01)*S122+(-5.307094e-01)*S123+(-2.841411e-01)*S124+9.991616e-02*S125+(-4.355962e-01)*S126+(-2.570238e-01)*S127+(-2.654251e-02)*S128+(-3.180969e-01)*S129'
.param V39_part14='V39_part13+(-1.386382e-01)*S130+(-1.046892e-01)*S131+(-1.744850e-01)*S132+(-1.856623e-01)*S133+(-1.385599e-02)*S134+(-1.449301e-02)*S135+(-1.010108e-01)*S136+(-3.265126e-01)*S137+4.707977e-01*S138+5.427800e-01*S139'
.param V39_part15='V39_part14+(-4.129346e-01)*S140+(-4.568213e-01)*S141+(-2.088398e-01)*S142+(-3.186582e-02)*S143+(-5.151738e-01)*S144+9.746273e-02*S145+1.051639e-01*S146+7.183833e-01*S147+(-3.419570e-02)*S148+5.109253e-02*S149'
.param V39_part16='V39_part15+(-7.289893e-01)*S150+(-7.100100e-02)*S151+(-4.140395e-02)*S152+(-5.824601e-01)*S153+(-9.834908e-01)*S154+(-2.116128e-02)*S155+(-1.709204e-01)*S156+(-1.143535e+00)*S157+(-1.235204e-02)*S158+(-2.719933e-01)*S159'
.param V39_part17='V39_part16+(-2.785182e-01)*S160+(-8.645144e-02)*S161+(-1.097668e-01)*S162+(-1.327435e-01)*S163+(-7.800535e-03)*S164+(-5.344549e-01)*S165+(-6.630925e+00)*S166+(-1.271595e+00)*S167+(-5.366985e+00)*S168+(-4.695151e-01)*S169'
.param V39_part18='V39_part17+3.026197e-02*S170+(-2.660303e-01)*S171+(-9.049187e-02)*S172+(-4.443731e-02)*S173+2.566398e-01*S174+1.604506e-01*S175+(-7.484634e-02)*S176+(-3.344930e-02)*S177+1.647850e-01*S178+(-5.718993e-02)*S179'
.param V39_part19='V39_part18+(-5.128952e-01)*S180+(-2.288834e-01)*S181+(-6.849671e-02)*S182+(-3.240198e-01)*S183+4.888868e-03*S184+2.563464e-01*S185+1.528999e-01*S186+(-1.210052e-01)*S187+(-1.146170e-02)*S188+2.224868e-01*S189'
.param V39_part20='V39_part19+(-1.059975e-02)*S190+(-1.232673e-01)*S191+(-2.572241e-02)*S192+1.573411e-01*S193+1.249013e-01*S194+(-6.343206e-01)*S195+(-2.777821e-01)*S196+(-7.720158e-02)*S197+(-5.359502e+00)*S198+3.683463e-01*S199'
.param V39_part21='V39_part20+(-1.711410e-01)*S200+(-9.312368e-01)*S201+(-2.941294e+00)*S202+1.373444e+00*S203+(-8.451431e-01)*S204+1.059867e-01*S205+(-3.484562e-01)*S206+3.775338e-02*S207+2.910261e-01*S208+(-1.696985e-01)*S209'
.param V39_part22='V39_part21+(-4.606779e-01)*S210+(-9.211380e-02)*S211+2.817281e-02*S212+(-1.294670e-01)*S213+(-2.304042e-01)*S214+3.308857e-03*S215+1.363142e-01*S216+(-1.178370e-01)*S217+2.088395e-02*S218+(-1.040802e-01)*S219'
.param V39_part23='V39_part22+5.200015e-02*S220+(-5.409157e-02)*S221+(-2.129107e-01)*S222+(-8.530017e-02)*S223+(-4.218024e-02)*S224+(-2.371469e-01)*S225+(-4.057545e-01)*S226+(-2.002895e-02)*S227+(-2.636884e-01)*S228+8.638242e-02*S229'
.param V39_part24='V39_part23+(-3.433070e-02)*S230+(-2.126691e-01)*S231+1.188661e-01*S232+6.952887e-02*S233+1.484537e-01*S234+(-1.190626e-01)*S235+7.536646e-02*S236+(-2.726754e-01)*S237+(-7.933589e-02)*S238+6.443135e-02*S239'
.param V39_part25='V39_part24+(-1.999310e-01)*S240+(-1.742368e-01)*S241+4.831128e-02*S242+1.722223e-01*S243+9.671892e-02*S244+6.341658e-02*S245+(-1.979984e-01)*S246+(-1.732466e-01)*S247+5.402495e-02*S248+9.631204e-02*S249'
.param V39_part26='V39_part25+(-1.291459e-01)*S250+(-4.018595e-02)*S251+(-2.841937e-01)*S252+(-4.889330e-02)*S253+(-5.306457e-02)*S254+(-3.043880e-01)*S255+(-2.674938e-01)*S256+2.785967e-03*S257+(-3.028884e-02)*S258+(-1.987940e-01)*S259'
.param V39_part27='V39_part26+(-7.222634e-02)*S260+1.308552e-01*S261+2.608666e-01*S262+(-2.251626e-01)*S263+(-1.942008e-02)*S264+(-1.390456e-01)*S265+1.631493e-01*S266+1.987084e-01*S267+3.919437e-01*S268+2.443442e-01*S269'
.param V39_part28='V39_part27+(-2.842466e-01)*S270+(-2.039657e-01)*S271+(-7.032329e-02)*S272+1.581374e-01*S273+(-1.453148e-01)*S274+(-6.603388e-03)*S275+8.876708e-02*S276+2.513949e-01*S277+(-7.561896e-03)*S278+(-1.562118e-01)*S279'
.param V39_part29='V39_part28+4.500461e-02*S280+(-1.858672e-02)*S281+(-1.309862e-01)*S282+(-3.736117e-02)*S283+1.449378e-02*S284+1.060296e-01*S285+(-1.596581e-01)*S286+(-1.244377e-01)*S287+(-1.506730e-01)*S288+5.344768e-02*S289'
.param V39_part30='V39_part29+(-8.865597e-02)*S290+1.466412e-02*S291+(-4.195943e-02)*S292+(-5.903204e-02)*S293+(-9.947825e-02)*S294+(-3.648333e-02)*S295+(-2.719483e-02)*S296+(-1.390012e-01)*S297+(-4.809597e-02)*S298+(-4.068178e-02)*S299'
.param V39_part31='V39_part30+1.591860e-01*S300+(-2.408099e-01)*S301+(-4.743783e-02)*S302+2.002052e-01*S303+(-4.127019e-02)*S304+(-6.919588e-02)*S305+1.769149e-01*S306+(-4.843746e-02)*S307+(-5.085739e-02)*S308+4.318983e-02*S309'
.param V39='V39_part31+(-3.015224e-02)*S310+(-2.803410e-02)*S311+(-1.509192e-01)*S312+(-7.552102e-02)*S313+(-4.695474e-02)*S314'
.param V40_part1='0.000000e+00*S0+6.139735e+00*S1+2.361534e+01*S2+(-4.357784e+00)*S3+(-1.962670e-01)*S4+1.786171e+01*S5+(-1.882900e+00)*S6+(-4.703257e+00)*S7+0.000000e+00*S8+(-4.330916e+00)*S9'
.param V40_part2='V40_part1+0.000000e+00*S10+0.000000e+00*S11+(-3.034282e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+2.544356e+01*S15+5.753106e+00*S16+0.000000e+00*S17+6.251420e-02*S18+0.000000e+00*S19'
.param V40_part3='V40_part2+1.704278e+01*S20+4.166714e+00*S21+0.000000e+00*S22+1.339411e+01*S23+0.000000e+00*S24+9.484987e-01*S25+1.233342e+01*S26+1.811592e+01*S27+1.432814e+01*S28+9.339925e+00*S29'
.param V40_part4='V40_part3+2.396042e+01*S30+(-5.528725e-01)*S31+1.408083e+01*S32+7.143395e+00*S33+8.229359e+00*S34+1.595845e+00*S35+3.513924e+00*S36+2.976357e-01*S37+4.045616e+00*S38+(-4.244029e+00)*S39'
.param V40_part5='V40_part4+(-6.908271e+00)*S40+1.061859e+01*S41+7.890703e-01*S42+1.631267e+01*S43+(-8.826382e+00)*S44+4.774222e+00*S45+8.408401e+00*S46+1.252988e+00*S47+7.304611e+00*S48+1.152843e+01*S49'
.param V40_part6='V40_part5+(-9.128137e+00)*S50+0.000000e+00*S51+(-2.017928e+01)*S52+(-6.671681e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V40_part7='V40_part6+0.000000e+00*S60+8.883687e+00*S61+(-3.273572e+00)*S62+0.000000e+00*S63+(-1.743294e+00)*S64+0.000000e+00*S65+0.000000e+00*S66+(-7.892856e+00)*S67+(-1.908178e+00)*S68+(-4.770020e+00)*S69'
.param V40_part8='V40_part7+(-1.586191e+01)*S70+(-1.278144e+00)*S71+4.357380e+01*S72+4.346640e+00*S73+(-1.195781e+01)*S74+0.000000e+00*S75+8.187439e+00*S76+5.424631e+00*S77+3.763256e+00*S78+6.973422e+00*S79'
.param V40_part9='V40_part8+0.000000e+00*S80+(-6.025606e+00)*S81+7.586604e+00*S82+0.000000e+00*S83+0.000000e+00*S84+1.791140e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V40_part10='V40_part9+1.063368e+00*S90+(-1.370331e+00)*S91+(-1.579448e+01)*S92+2.787525e+00*S93+0.000000e+00*S94+(-2.099039e+01)*S95+(-1.977474e+00)*S96+(-3.055043e+00)*S97+5.450748e-01*S98+1.027059e+00*S99'
.param V40_part11='V40_part10+0.000000e+00*S100+2.015336e+00*S101+7.299125e+00*S102+1.459460e+00*S103+6.530205e+01*S104+6.023910e-01*S105+(-5.352057e+00)*S106+0.000000e+00*S107+(-3.925281e+00)*S108+(-1.040419e+01)*S109'
.param V40_part12='V40_part11+(-4.221016e+00)*S110+8.589768e+00*S111+(-1.865558e+00)*S112+5.835703e+00*S113+2.937120e+00*S114+2.361084e+01*S115+1.183493e+00*S116+(-1.207278e+01)*S117+(-1.348507e+02)*S118+0.000000e+00*S119'
.param V40_part13='V40_part12+3.474565e+00*S120+(-3.162903e+00)*S121+4.269903e+00*S122+2.567903e+00*S123+(-1.584989e+00)*S124+5.670802e+00*S125+4.193367e+00*S126+1.853884e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V40_part14='V40_part13+0.000000e+00*S130+0.000000e+00*S131+(-4.603634e+00)*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+(-4.110810e+00)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V40_part15='V40_part14+1.276399e+01*S140+0.000000e+00*S141+(-5.359786e+00)*S142+9.863382e-01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+(-5.994176e+00)*S147+(-6.169808e-01)*S148+0.000000e+00*S149'
.param V40_part16='V40_part15+9.736139e-01*S150+(-4.196416e-01)*S151+4.914608e+00*S152+5.527576e-01*S153+3.697791e+00*S154+0.000000e+00*S155+3.165588e+01*S156+0.000000e+00*S157+3.602751e+01*S158+(-9.246179e+00)*S159'
.param V40_part17='V40_part16+0.000000e+00*S160+3.398885e+01*S161+2.681404e+01*S162+3.504803e+01*S163+1.396498e+01*S164+(-2.423576e+00)*S165+(-5.684077e+00)*S166+1.082655e+02*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V40_part18='V40_part17+0.000000e+00*S170+1.530104e+01*S171+1.570239e+01*S172+2.536364e+01*S173+(-7.326911e+00)*S174+(-1.526776e+00)*S175+4.610830e+01*S176+(-1.178023e+01)*S177+(-1.409412e+00)*S178+0.000000e+00*S179'
.param V40_part19='V40_part18+5.425358e+00*S180+3.389678e-01*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+4.166042e+01*S185+8.929635e+00*S186+0.000000e+00*S187+0.000000e+00*S188+8.129560e+00*S189'
.param V40_part20='V40_part19+(-7.943332e+01)*S190+5.393461e+01*S191+0.000000e+00*S192+(-8.289408e+00)*S193+(-1.972926e+01)*S194+1.631126e+00*S195+(-5.159065e+00)*S196+0.000000e+00*S197+3.252023e+00*S198+(-1.014082e+01)*S199'
.param V40_part21='V40_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+(-1.561430e+01)*S207+4.605765e+00*S208+(-1.188162e+01)*S209'
.param V40_part22='V40_part21+4.152841e+00*S210+3.365922e+00*S211+(-1.631523e+01)*S212+2.300792e+01*S213+7.078481e+01*S214+(-4.204233e+01)*S215+0.000000e+00*S216+4.680452e+01*S217+(-9.440473e+01)*S218+3.245608e+01*S219'
.param V40_part23='V40_part22+(-7.477547e+00)*S220+8.460294e+00*S221+0.000000e+00*S222+1.816294e+01*S223+0.000000e+00*S224+2.850393e+01*S225+2.071664e+01*S226+0.000000e+00*S227+0.000000e+00*S228+2.664790e+00*S229'
.param V40_part24='V40_part23+7.640522e+01*S230+0.000000e+00*S231+0.000000e+00*S232+(-4.541560e+01)*S233+9.761554e+00*S234+0.000000e+00*S235+(-3.716346e+01)*S236+0.000000e+00*S237+0.000000e+00*S238+(-5.671231e+00)*S239'
.param V40_part25='V40_part24+7.053670e+00*S240+0.000000e+00*S241+(-1.265270e+01)*S242+1.123812e+01*S243+9.534639e+00*S244+(-1.174002e+01)*S245+(-2.129608e+01)*S246+2.939963e+01*S247+8.783398e+00*S248+7.603621e+00*S249'
.param V40_part26='V40_part25+3.401803e+01*S250+1.801166e+02*S251+(-1.413368e+01)*S252+2.438190e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+(-2.428091e-01)*S258+2.581154e+01*S259'
.param V40_part27='V40_part26+0.000000e+00*S260+(-3.825617e+00)*S261+(-4.401717e+00)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+(-1.087881e+01)*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V40_part28='V40_part27+0.000000e+00*S270+(-1.300263e+01)*S271+0.000000e+00*S272+1.936727e-01*S273+0.000000e+00*S274+(-1.797332e+01)*S275+1.276852e+01*S276+0.000000e+00*S277+(-3.746295e+01)*S278+1.171732e+01*S279'
.param V40_part29='V40_part28+(-9.934132e+01)*S280+1.345455e+01*S281+0.000000e+00*S282+(-2.544975e+01)*S283+(-6.942739e+01)*S284+6.607735e+00*S285+0.000000e+00*S286+(-6.361428e+01)*S287+2.779235e+01*S288+7.749967e+00*S289'
.param V40_part30='V40_part29+(-8.013782e+01)*S290+1.433990e+01*S291+7.038690e+00*S292+0.000000e+00*S293+2.040968e+00*S294+2.750374e+01*S295+0.000000e+00*S296+(-3.564217e+01)*S297+9.254494e+01*S298+0.000000e+00*S299'
.param V40_part31='V40_part30+7.436176e+00*S300+0.000000e+00*S301+8.703524e-01*S302+7.711918e-02*S303+7.453479e+00*S304+0.000000e+00*S305+(-2.201944e+00)*S306+1.206033e+01*S307+1.273714e+02*S308+1.543582e+01*S309'
.param V40='V40_part31+4.224877e+01*S310+0.000000e+00*S311+1.558085e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V41_part1='0.000000e+00*S0+(-2.364048e+00)*S1+(-1.223765e+00)*S2+4.590358e+01*S3+2.073106e+01*S4+3.655737e+00*S5+3.591406e+01*S6+2.061522e+01*S7+0.000000e+00*S8+2.652284e+01*S9'
.param V41_part2='V41_part1+0.000000e+00*S10+0.000000e+00*S11+2.310365e+01*S12+0.000000e+00*S13+0.000000e+00*S14+4.394812e+01*S15+4.635803e+01*S16+0.000000e+00*S17+2.024631e+00*S18+0.000000e+00*S19'
.param V41_part3='V41_part2+2.393996e+01*S20+1.129933e+01*S21+0.000000e+00*S22+(-5.047005e+00)*S23+0.000000e+00*S24+6.715677e+00*S25+4.331601e-01*S26+2.194849e+01*S27+(-7.225711e+00)*S28+(-4.275696e+00)*S29'
.param V41_part4='V41_part3+4.060144e+01*S30+5.423077e+01*S31+3.989309e+01*S32+4.343725e+01*S33+3.224097e+01*S34+4.846284e+01*S35+4.522583e+01*S36+5.431893e+01*S37+3.464996e+01*S38+4.985784e+01*S39'
.param V41_part5='V41_part4+3.166271e+01*S40+3.506937e+01*S41+3.869642e+01*S42+3.413171e+01*S43+7.043284e+00*S44+6.497754e+01*S45+3.947663e+01*S46+3.239928e+01*S47+3.128325e+01*S48+1.419281e+01*S49'
.param V41_part6='V41_part5+6.527563e+01*S50+0.000000e+00*S51+1.131451e+02*S52+4.349969e+01*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V41_part7='V41_part6+0.000000e+00*S60+4.295531e+01*S61+5.997578e+01*S62+0.000000e+00*S63+6.560683e+01*S64+0.000000e+00*S65+0.000000e+00*S66+1.134563e+01*S67+5.440258e+01*S68+8.451959e+00*S69'
.param V41_part8='V41_part7+1.214477e+01*S70+4.408711e+01*S71+1.378253e+01*S72+2.856516e+01*S73+8.956625e+01*S74+0.000000e+00*S75+3.880049e+01*S76+4.502746e+01*S77+4.363527e+01*S78+6.312818e+01*S79'
.param V41_part9='V41_part8+0.000000e+00*S80+5.619633e+01*S81+2.020574e+01*S82+0.000000e+00*S83+0.000000e+00*S84+8.066475e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V41_part10='V41_part9+6.943720e+01*S90+7.135016e+01*S91+9.583631e+01*S92+4.620415e+01*S93+0.000000e+00*S94+7.079704e+01*S95+5.267822e+01*S96+5.130205e+01*S97+4.669310e+01*S98+4.482772e+01*S99'
.param V41_part11='V41_part10+0.000000e+00*S100+3.422595e+01*S101+3.614013e+01*S102+3.566687e+01*S103+(-5.016308e+01)*S104+5.471893e+01*S105+5.574850e+01*S106+0.000000e+00*S107+5.601704e+01*S108+5.946212e+01*S109'
.param V41_part12='V41_part11+5.098802e+01*S110+2.332638e+01*S111+4.141668e+01*S112+2.066396e+01*S113+1.961969e+01*S114+(-3.487510e+00)*S115+3.154616e+01*S116+4.880230e+01*S117+1.328425e+02*S118+0.000000e+00*S119'
.param V41_part13='V41_part12+6.443646e+01*S120+6.445986e+01*S121+5.701304e+01*S122+5.429301e+01*S123+5.231879e+01*S124+4.433372e+01*S125+4.563761e+01*S126+4.432003e+01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V41_part14='V41_part13+0.000000e+00*S130+0.000000e+00*S131+5.647212e+01*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+8.155018e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V41_part15='V41_part14+4.610355e+01*S140+0.000000e+00*S141+4.967969e+01*S142+2.453549e+01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+6.127487e+01*S147+4.875234e+01*S148+0.000000e+00*S149'
.param V41_part16='V41_part15+6.628171e+01*S150+5.869620e+01*S151+3.406911e+01*S152+5.686541e+01*S153+1.695164e+01*S154+0.000000e+00*S155+(-1.683132e+00)*S156+0.000000e+00*S157+(-5.052373e+01)*S158+6.861502e+01*S159'
.param V41_part17='V41_part16+0.000000e+00*S160+(-1.797173e+01)*S161+(-8.109605e+00)*S162+(-5.416586e+00)*S163+1.781150e+01*S164+5.917603e+01*S165+6.359591e+01*S166+(-7.607392e+01)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V41_part18='V41_part17+0.000000e+00*S170+9.490900e+00*S171+9.202223e+00*S172+8.555923e+00*S173+5.358836e+01*S174+3.154154e+01*S175+(-3.613219e+01)*S176+5.715285e+01*S177+3.304279e+01*S178+0.000000e+00*S179'
.param V41_part19='V41_part18+5.916295e+01*S180+5.560367e+01*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+2.185991e+01*S185+3.587630e+01*S186+0.000000e+00*S187+0.000000e+00*S188+3.659078e+01*S189'
.param V41_part20='V41_part19+1.387217e+02*S190+(-1.848447e+01)*S191+0.000000e+00*S192+3.989492e+01*S193+1.536790e+01*S194+5.111354e+01*S195+5.956749e+01*S196+0.000000e+00*S197+3.266586e+01*S198+1.804350e+01*S199'
.param V41_part21='V41_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+6.383322e+01*S207+2.318627e+01*S208+(-1.786867e+00)*S209'
.param V41_part22='V41_part21+5.623438e+01*S210+5.931102e+01*S211+7.575570e+01*S212+8.406504e+00*S213+(-8.798976e+01)*S214+1.420504e+02*S215+0.000000e+00*S216+(-1.620716e-01)*S217+1.492528e+02*S218+6.389046e+01*S219'
.param V41_part23='V41_part22+3.732780e+01*S220+9.598132e-01*S221+0.000000e+00*S222+2.883728e+01*S223+0.000000e+00*S224+(-1.683256e+01)*S225+(-3.286519e+00)*S226+0.000000e+00*S227+0.000000e+00*S228+3.629816e+01*S229'
.param V41_part24='V41_part23+(-4.174096e+01)*S230+0.000000e+00*S231+0.000000e+00*S232+4.637080e+01*S233+2.708928e+01*S234+0.000000e+00*S235+4.938020e+01*S236+0.000000e+00*S237+0.000000e+00*S238+3.541447e+01*S239'
.param V41_part25='V41_part24+5.097463e+01*S240+0.000000e+00*S241+7.036954e+01*S242+3.298355e+01*S243+4.541083e+01*S244+3.813256e+01*S245+6.095522e+01*S246+(-5.925936e+00)*S247+4.270801e+01*S248+2.448819e+01*S249'
.param V41_part26='V41_part25+(-2.585480e+01)*S250+(-1.132649e+02)*S251+9.438335e+01*S252+4.698604e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+5.249397e+01*S258+(-4.544481e+00)*S259'
.param V41_part27='V41_part26+0.000000e+00*S260+5.228484e+01*S261+4.860041e+01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+4.179441e+01*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V41_part28='V41_part27+0.000000e+00*S270+7.253757e+01*S271+0.000000e+00*S272+4.720114e+01*S273+0.000000e+00*S274+1.171148e+00*S275+2.803422e+01*S276+0.000000e+00*S277+(-1.264621e+01)*S278+2.179014e+00*S279'
.param V41_part29='V41_part28+9.855467e+01*S280+2.022661e+01*S281+0.000000e+00*S282+3.835023e+01*S283+1.189575e+02*S284+4.881274e+01*S285+0.000000e+00*S286+1.096763e+02*S287+(-1.995120e+00)*S288+4.678516e+01*S289'
.param V41_part30='V41_part29+1.637567e+02*S290+5.318221e+00*S291+2.393586e+01*S292+0.000000e+00*S293+2.725857e+01*S294+(-2.976960e+01)*S295+0.000000e+00*S296+5.369723e+01*S297+7.326760e+01*S298+0.000000e+00*S299'
.param V41_part31='V41_part30+4.283282e+01*S300+0.000000e+00*S301+2.413830e+01*S302+3.619076e+01*S303+3.383300e+01*S304+0.000000e+00*S305+3.693198e+01*S306+9.015408e+00*S307+(-6.965111e+01)*S308+7.483812e+00*S309'
.param V41='V41_part31+1.030474e+01*S310+0.000000e+00*S311+3.808390e+01*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V42_part1='0.000000e+00*S0+9.347224e+00*S1+(-9.742732e+00)*S2+1.745247e+01*S3+1.275249e+01*S4+1.106497e+01*S5+1.094970e+01*S6+3.331345e+01*S7+0.000000e+00*S8+3.003414e+01*S9'
.param V42_part2='V42_part1+0.000000e+00*S10+0.000000e+00*S11+2.989112e+01*S12+0.000000e+00*S13+0.000000e+00*S14+6.370069e+00*S15+3.373212e+01*S16+0.000000e+00*S17+2.523994e+01*S18+0.000000e+00*S19'
.param V42_part3='V42_part2+1.289307e+01*S20+(-1.718502e+01)*S21+0.000000e+00*S22+(-6.663163e+00)*S23+0.000000e+00*S24+(-5.536646e+00)*S25+(-1.149751e+01)*S26+5.870672e+01*S27+(-6.066193e+00)*S28+(-2.567474e+00)*S29'
.param V42_part4='V42_part3+3.866272e+01*S30+3.864853e+01*S31+1.617937e+01*S32+1.899147e+01*S33+2.569570e+01*S34+2.494739e+01*S35+1.520951e+01*S36+(-1.266337e+01)*S37+2.668292e+01*S38+2.537340e+01*S39'
.param V42_part5='V42_part4+2.607380e+01*S40+1.759579e+01*S41+3.387351e+01*S42+8.671360e+00*S43+2.696558e+01*S44+1.451366e+01*S45+(-9.460597e+00)*S46+2.006180e+01*S47+2.404363e+01*S48+(-6.709454e-01)*S49'
.param V42_part6='V42_part5+3.260745e+01*S50+0.000000e+00*S51+4.859082e+01*S52+3.209392e+01*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V42_part7='V42_part6+0.000000e+00*S60+2.520400e+01*S61+3.765372e+01*S62+0.000000e+00*S63+2.900602e+01*S64+0.000000e+00*S65+0.000000e+00*S66+1.140120e+01*S67+3.160105e+01*S68+9.159127e+00*S69'
.param V42_part8='V42_part7+2.352206e+01*S70+3.000384e+01*S71+2.110931e+01*S72+4.483521e+01*S73+6.223892e+01*S74+0.000000e+00*S75+3.315833e+00*S76+1.351926e+01*S77+8.011699e+00*S78+(-1.074988e+01)*S79'
.param V42_part9='V42_part8+0.000000e+00*S80+6.002464e-01*S81+2.255705e+01*S82+0.000000e+00*S83+0.000000e+00*S84+(-3.990013e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V42_part10='V42_part9+3.614281e+01*S90+4.389847e+01*S91+5.194156e+01*S92+5.313316e+01*S93+0.000000e+00*S94+4.901540e+01*S95+5.016904e+01*S96+5.227395e+01*S97+4.370219e+01*S98+5.011567e+01*S99'
.param V42_part11='V42_part10+0.000000e+00*S100+5.659373e+01*S101+4.645533e+01*S102+5.777091e+01*S103+2.214451e+01*S104+4.282328e+01*S105+5.573076e+01*S106+0.000000e+00*S107+5.287290e+01*S108+5.978429e+01*S109'
.param V42_part12='V42_part11+5.086774e+01*S110+4.590606e+01*S111+5.705159e+01*S112+4.135966e+01*S113+3.577863e+01*S114+4.035046e+01*S115+4.452040e+01*S116+6.093048e+01*S117+9.980004e+01*S118+0.000000e+00*S119'
.param V42_part13='V42_part12+5.131962e+01*S120+6.041777e+01*S121+4.847426e+01*S122+5.407635e+01*S123+6.119704e+01*S124+4.747385e+01*S125+5.486343e+01*S126+5.884507e+01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V42_part14='V42_part13+0.000000e+00*S130+0.000000e+00*S131+7.849100e+01*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+3.488625e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V42_part15='V42_part14+1.221511e+01*S140+0.000000e+00*S141+3.905731e+01*S142+2.939248e+01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+3.653138e+01*S147+3.818757e+01*S148+0.000000e+00*S149'
.param V42_part16='V42_part15+6.867135e+01*S150+6.748169e+01*S151+4.893662e+01*S152+7.135473e+01*S153+3.898288e+01*S154+0.000000e+00*S155+2.764745e+01*S156+0.000000e+00*S157+5.153315e+01*S158+7.432595e+01*S159'
.param V42_part17='V42_part16+0.000000e+00*S160+5.601161e+01*S161+2.407502e+01*S162+6.047201e+01*S163+8.310736e+01*S164+7.230834e+01*S165+7.686922e+01*S166+(-8.570800e+01)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V42_part18='V42_part17+0.000000e+00*S170+3.827490e+01*S171+4.896662e+01*S172+7.011031e+00*S173+5.725177e+01*S174+5.846755e+01*S175+4.225686e+01*S176+9.750863e+01*S177+5.289521e+01*S178+0.000000e+00*S179'
.param V42_part19='V42_part18+7.244528e+01*S180+7.641065e+01*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+7.331986e+00*S185+5.325421e+01*S186+0.000000e+00*S187+0.000000e+00*S188+4.036886e+01*S189'
.param V42_part20='V42_part19+1.309654e+02*S190+5.123774e+00*S191+0.000000e+00*S192+5.786226e+01*S193+6.476766e+01*S194+5.570980e+01*S195+6.641514e+01*S196+0.000000e+00*S197+4.602092e+01*S198+3.238070e+01*S199'
.param V42_part21='V42_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+8.007293e+01*S207+3.969811e+01*S208+3.991588e+01*S209'
.param V42_part22='V42_part21+9.246317e+01*S210+7.959836e+01*S211+8.651154e+01*S212+2.631785e+01*S213+1.489238e+00*S214+9.876979e+01*S215+0.000000e+00*S216+9.168523e+00*S217+1.431499e+02*S218+1.184977e+01*S219'
.param V42_part23='V42_part22+8.158922e+01*S220+3.944285e+01*S221+0.000000e+00*S222+(-2.096001e+01)*S223+0.000000e+00*S224+3.140312e+01*S225+6.003753e+01*S226+0.000000e+00*S227+0.000000e+00*S228+7.254305e+01*S229'
.param V42_part24='V42_part23+(-1.708011e+01)*S230+0.000000e+00*S231+0.000000e+00*S232+1.245708e+02*S233+5.905289e+01*S234+0.000000e+00*S235+9.026876e+01*S236+0.000000e+00*S237+0.000000e+00*S238+7.223550e+01*S239'
.param V42_part25='V42_part24+9.287909e+01*S240+0.000000e+00*S241+9.125120e+01*S242+6.398467e+01*S243+5.644730e+01*S244+8.554700e+01*S245+1.167991e+02*S246+1.928451e+00*S247+5.809292e+01*S248+7.842054e+01*S249'
.param V42_part26='V42_part25+2.461611e+01*S250+(-8.709119e+01)*S251+1.506842e+02*S252+8.522325e+00*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+7.907927e+01*S258+5.606401e+01*S259'
.param V42_part27='V42_part26+0.000000e+00*S260+9.353429e+01*S261+7.326014e+01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+9.075144e+01*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V42_part28='V42_part27+0.000000e+00*S270+7.056551e+00*S271+0.000000e+00*S272+7.493996e+01*S273+0.000000e+00*S274+1.136663e+02*S275+7.786356e+01*S276+0.000000e+00*S277+1.420798e+02*S278+8.735973e+01*S279'
.param V42_part29='V42_part28+1.096377e+02*S280+7.490614e+01*S281+0.000000e+00*S282+1.316938e+02*S283+9.396485e+01*S284+7.527331e+01*S285+0.000000e+00*S286+1.632297e+02*S287+5.580122e+01*S288+6.677095e+01*S289'
.param V42_part30='V42_part29+1.725495e+02*S290+7.923525e+01*S291+5.574065e+01*S292+0.000000e+00*S293+1.257425e+02*S294+5.780095e+01*S295+0.000000e+00*S296+1.308567e+02*S297+(-1.050186e+02)*S298+0.000000e+00*S299'
.param V42_part31='V42_part30+8.710573e+01*S300+0.000000e+00*S301+6.998651e+01*S302+6.204360e+01*S303+5.077327e+01*S304+0.000000e+00*S305+6.497553e+01*S306+7.030238e+01*S307+(-6.999043e+01)*S308+6.564568e+01*S309'
.param V42='V42_part31+(-2.055073e+00)*S310+0.000000e+00*S311+7.529920e+01*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V43_part1='0.000000e+00*S0+5.656600e-01*S1+(-1.229866e+01)*S2+(-2.086033e+00)*S3+3.857791e-01*S4+(-2.475286e+00)*S5+9.009774e+00*S6+3.474463e+00*S7+0.000000e+00*S8+(-9.659361e-01)*S9'
.param V43_part2='V43_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.842115e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+(-4.008040e+00)*S15+(-1.375403e+01)*S16+0.000000e+00*S17+(-9.036703e+00)*S18+0.000000e+00*S19'
.param V43_part3='V43_part2+(-1.043892e+01)*S20+(-2.629839e+00)*S21+0.000000e+00*S22+(-9.671852e+00)*S23+0.000000e+00*S24+(-1.150216e+00)*S25+(-2.778245e-01)*S26+(-2.251272e+01)*S27+(-9.226582e+00)*S28+(-6.832641e+00)*S29'
.param V43_part4='V43_part3+(-1.340605e+01)*S30+(-1.217917e+00)*S31+(-1.269490e+01)*S32+(-9.713561e+00)*S33+(-1.519018e+01)*S34+(-1.591603e+01)*S35+(-1.413156e+01)*S36+(-1.465521e+00)*S37+(-2.219931e+01)*S38+(-1.584119e+01)*S39'
.param V43_part5='V43_part4+6.572584e+00*S40+(-2.172407e+01)*S41+(-2.074324e+01)*S42+(-3.190257e+01)*S43+(-3.353158e+01)*S44+3.024308e+00*S45+(-1.020414e+01)*S46+(-1.156148e+01)*S47+(-9.410092e+00)*S48+(-5.662976e+00)*S49'
.param V43_part6='V43_part5+(-8.810601e+00)*S50+0.000000e+00*S51+(-1.535542e+01)*S52+(-1.889629e+01)*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V43_part7='V43_part6+0.000000e+00*S60+(-1.167432e+01)*S61+(-1.557948e+01)*S62+0.000000e+00*S63+(-1.306315e+01)*S64+0.000000e+00*S65+0.000000e+00*S66+(-8.199212e+00)*S67+(-2.426468e+01)*S68+(-9.014267e+00)*S69'
.param V43_part8='V43_part7+(-9.914774e+00)*S70+(-1.874241e+01)*S71+(-4.765561e+01)*S72+(-1.698182e+01)*S73+(-4.730639e+01)*S74+0.000000e+00*S75+(-6.972721e-01)*S76+(-1.672841e+01)*S77+4.187410e-01*S78+(-2.478187e-01)*S79'
.param V43_part9='V43_part8+0.000000e+00*S80+(-1.202385e+01)*S81+(-9.923117e+00)*S82+0.000000e+00*S83+0.000000e+00*S84+1.436927e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V43_part10='V43_part9+(-1.346565e+01)*S90+(-1.203511e+01)*S91+(-1.978278e+01)*S92+(-1.897018e+01)*S93+0.000000e+00*S94+(-2.691267e+01)*S95+(-2.612430e+01)*S96+(-3.211045e+01)*S97+(-2.720452e+01)*S98+(-2.990669e+01)*S99'
.param V43_part11='V43_part10+0.000000e+00*S100+(-4.071119e+01)*S101+(-3.440318e+01)*S102+(-3.855578e+01)*S103+(-5.480446e+01)*S104+(-1.194719e+01)*S105+(-1.652944e+01)*S106+0.000000e+00*S107+(-1.781835e+01)*S108+(-2.078517e+01)*S109'
.param V43_part12='V43_part11+(-2.399126e+01)*S110+(-1.335818e+01)*S111+(-2.546993e+01)*S112+(-1.974365e+01)*S113+(-3.447487e+01)*S114+(-1.175397e+01)*S115+(-3.817389e+01)*S116+(-3.599093e+01)*S117+(-3.187377e+00)*S118+0.000000e+00*S119'
.param V43_part13='V43_part12+(-1.128722e+01)*S120+(-1.861294e+01)*S121+(-9.541451e+00)*S122+(-2.122050e+01)*S123+(-2.328852e+01)*S124+(-1.790917e+01)*S125+(-2.547156e+01)*S126+(-2.793102e+01)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V43_part14='V43_part13+0.000000e+00*S130+0.000000e+00*S131+(-3.398232e+01)*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+(-1.063921e+01)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V43_part15='V43_part14+(-1.097185e+01)*S140+0.000000e+00*S141+(-2.293619e+01)*S142+(-1.446390e+01)*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+(-2.503807e+01)*S147+(-1.577805e+01)*S148+0.000000e+00*S149'
.param V43_part16='V43_part15+(-1.408082e+01)*S150+(-1.948740e+01)*S151+(-3.379481e+01)*S152+(-2.293250e+01)*S153+(-1.148298e+01)*S154+0.000000e+00*S155+(-3.037769e+01)*S156+0.000000e+00*S157+(-1.575345e+01)*S158+(-3.493187e+01)*S159'
.param V43_part17='V43_part16+0.000000e+00*S160+(-7.621288e+00)*S161+(-4.648009e+01)*S162+(-2.059685e+01)*S163+(-5.391517e+01)*S164+(-1.617963e+01)*S165+(-2.065071e+01)*S166+(-3.796108e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V43_part18='V43_part17+0.000000e+00*S170+(-3.713889e+01)*S171+(-3.806439e+01)*S172+(-2.538522e+01)*S173+(-3.064068e+01)*S174+(-4.413802e+01)*S175+(-1.940815e+00)*S176+(-3.355306e+01)*S177+(-5.024194e+01)*S178+0.000000e+00*S179'
.param V43_part19='V43_part18+(-1.783055e+01)*S180+(-2.313912e+01)*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+(-2.571191e+01)*S185+(-3.199746e+01)*S186+0.000000e+00*S187+0.000000e+00*S188+(-3.821959e+01)*S189'
.param V43_part20='V43_part19+(-3.428499e+01)*S190+(-1.245811e+01)*S191+0.000000e+00*S192+(-5.353466e+01)*S193+(-4.702389e+01)*S194+(-1.184339e+01)*S195+(-1.735652e+01)*S196+0.000000e+00*S197+(-1.328877e+01)*S198+(-1.179948e+01)*S199'
.param V43_part21='V43_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+(-3.779660e+01)*S207+(-4.810632e+01)*S208+(-5.294009e+01)*S209'
.param V43_part22='V43_part21+(-1.998626e+01)*S210+(-2.599381e+01)*S211+(-2.826881e+01)*S212+(-1.738202e+01)*S213+(-2.623228e+01)*S214+(-3.937950e+01)*S215+0.000000e+00*S216+(-1.721683e+01)*S217+(-5.959704e+01)*S218+(-1.115259e+01)*S219'
.param V43_part23='V43_part22+(-5.848580e+01)*S220+(-3.464579e+01)*S221+0.000000e+00*S222+(-4.846154e+01)*S223+0.000000e+00*S224+2.328701e+01*S225+(-8.462909e+00)*S226+0.000000e+00*S227+0.000000e+00*S228+(-3.537243e+01)*S229'
.param V43_part24='V43_part23+(-1.517053e+01)*S230+0.000000e+00*S231+0.000000e+00*S232+(-4.578426e+01)*S233+(-3.491356e+01)*S234+0.000000e+00*S235+(-7.304083e+01)*S236+0.000000e+00*S237+0.000000e+00*S238+(-6.637787e+01)*S239'
.param V43_part25='V43_part24+(-2.301697e+01)*S240+0.000000e+00*S241+(-3.879566e+01)*S242+(-3.163009e+01)*S243+(-3.794205e+01)*S244+(-5.329674e+01)*S245+(-3.429766e+01)*S246+(-2.724153e+01)*S247+(-5.731710e+01)*S248+(-3.452893e+01)*S249'
.param V43_part26='V43_part25+(-2.927942e+01)*S250+(-4.947727e+01)*S251+(-4.010765e+01)*S252+(-6.367330e+01)*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+(-2.250739e+01)*S258+(-1.481553e+01)*S259'
.param V43_part27='V43_part26+0.000000e+00*S260+(-2.843307e+01)*S261+(-3.461613e+01)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+(-3.616784e+01)*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V43_part28='V43_part27+0.000000e+00*S270+(-1.709834e+01)*S271+0.000000e+00*S272+(-3.373877e+01)*S273+0.000000e+00*S274+(-6.678944e+01)*S275+(-4.638286e+01)*S276+0.000000e+00*S277+(-8.046026e+01)*S278+(-3.099036e+01)*S279'
.param V43_part29='V43_part28+(-8.187669e+01)*S280+(-7.276085e+01)*S281+0.000000e+00*S282+(-6.678307e+01)*S283+(-9.411557e+01)*S284+(-2.649298e+01)*S285+0.000000e+00*S286+(-4.043480e+01)*S287+(-1.198297e+01)*S288+(-4.065804e+01)*S289'
.param V43_part30='V43_part29+(-4.948635e+01)*S290+(-3.102468e+01)*S291+(-3.955314e+01)*S292+0.000000e+00*S293+(-7.135955e+01)*S294+(-5.113307e+01)*S295+0.000000e+00*S296+(-3.117183e+01)*S297+(-7.509113e+01)*S298+0.000000e+00*S299'
.param V43_part31='V43_part30+(-2.004714e+01)*S300+0.000000e+00*S301+(-1.331925e+00)*S302+(-3.431196e+01)*S303+(-3.277788e+01)*S304+0.000000e+00*S305+(-3.788218e+01)*S306+(-3.702090e+01)*S307+(-6.103003e+01)*S308+(-2.662943e+01)*S309'
.param V43='V43_part31+(-2.603311e+01)*S310+0.000000e+00*S311+(-7.842636e+01)*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V44_part1='0.000000e+00*S0+(-6.257786e-01)*S1+(-2.206456e-01)*S2+8.749866e-01*S3+1.179659e-02*S4+(-5.317743e-01)*S5+(-1.524988e-01)*S6+(-4.453213e-01)*S7+0.000000e+00*S8+(-5.862142e-01)*S9'
.param V44_part2='V44_part1+0.000000e+00*S10+0.000000e+00*S11+(-5.983350e-01)*S12+0.000000e+00*S13+0.000000e+00*S14+2.470407e+00*S15+3.121151e-01*S16+0.000000e+00*S17+(-6.082295e-02)*S18+0.000000e+00*S19'
.param V44_part3='V44_part2+8.524452e-02*S20+1.182783e-01*S21+0.000000e+00*S22+(-6.032920e-02)*S23+0.000000e+00*S24+6.270045e-02*S25+(-3.598948e-02)*S26+3.682048e-03*S27+(-7.686569e-02)*S28+(-7.098262e-02)*S29'
.param V44_part4='V44_part3+1.444291e-02*S30+8.536520e-02*S31+8.377991e-01*S32+(-1.781128e-01)*S33+(-4.160720e-01)*S34+8.887959e-01*S35+(-9.850911e-01)*S36+9.216306e-01*S37+(-1.788893e-01)*S38+(-2.870605e+00)*S39'
.param V44_part5='V44_part4+(-5.511957e-01)*S40+(-3.972687e-01)*S41+(-3.937007e+00)*S42+3.926277e-01*S43+(-4.391294e+00)*S44+5.886817e-01*S45+1.111657e-01*S46+1.224278e+00*S47+(-1.804974e+00)*S48+(-4.556944e+00)*S49'
.param V44_part6='V44_part5+8.958009e-02*S50+0.000000e+00*S51+(-1.998123e+00)*S52+(-1.497147e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V44_part7='V44_part6+0.000000e+00*S60+4.140637e-01*S61+(-2.625411e-01)*S62+0.000000e+00*S63+(-1.657530e+00)*S64+0.000000e+00*S65+0.000000e+00*S66+5.043628e-01*S67+2.606824e+00*S68+5.746579e-01*S69'
.param V44_part8='V44_part7+5.617449e-01*S70+5.483883e+00*S71+3.777518e+00*S72+(-7.755092e+00)*S73+2.472803e+00*S74+0.000000e+00*S75+1.345582e-01*S76+2.068137e-01*S77+(-8.161689e-03)*S78+2.341399e-01*S79'
.param V44_part9='V44_part8+0.000000e+00*S80+1.363509e+00*S81+(-9.842855e-01)*S82+0.000000e+00*S83+0.000000e+00*S84+(-1.791136e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V44_part10='V44_part9+2.142966e+00*S90+2.542641e+00*S91+3.031996e+00*S92+(-1.481819e-01)*S93+0.000000e+00*S94+6.608023e-02*S95+2.638150e-01*S96+(-4.950776e-01)*S97+2.047260e+00*S98+(-8.677886e-01)*S99'
.param V44_part11='V44_part10+0.000000e+00*S100+(-2.938993e+00)*S101+(-3.421893e+00)*S102+(-3.790778e+00)*S103+(-1.287069e+01)*S104+(-1.596567e+00)*S105+(-1.543400e+00)*S106+0.000000e+00*S107+(-1.738693e+00)*S108+2.418066e-01*S109'
.param V44_part12='V44_part11+2.358868e+00*S110+(-8.679452e-01)*S111+(-1.918366e-01)*S112+7.686690e-01*S113+1.795751e-01*S114+(-8.367611e+00)*S115+(-6.093006e+00)*S116+(-4.153903e+00)*S117+(-8.069821e+00)*S118+0.000000e+00*S119'
.param V44_part13='V44_part12+(-2.805699e+00)*S120+1.419481e-01*S121+2.276787e+00*S122+(-2.074806e-01)*S123+7.161611e-01*S124+1.439030e+00*S125+(-6.415206e-01)*S126+(-9.894230e-02)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V44_part14='V44_part13+0.000000e+00*S130+0.000000e+00*S131+8.610608e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+(-1.020612e+00)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V44_part15='V44_part14+(-1.089540e+01)*S140+0.000000e+00*S141+(-3.310367e+00)*S142+6.910024e-01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+1.820863e+00*S147+2.897604e+00*S148+0.000000e+00*S149'
.param V44_part16='V44_part15+2.640658e+00*S150+3.324843e+00*S151+2.814320e+00*S152+2.132953e+00*S153+2.386345e+00*S154+0.000000e+00*S155+3.176707e+00*S156+0.000000e+00*S157+(-6.690720e+00)*S158+2.772114e+00*S159'
.param V44_part17='V44_part16+0.000000e+00*S160+(-7.565465e+00)*S161+(-6.224407e+00)*S162+(-8.745456e+00)*S163+(-1.549226e+01)*S164+1.417159e+00*S165+2.327318e+00*S166+(-5.319718e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V44_part18='V44_part17+0.000000e+00*S170+(-8.415282e-01)*S171+(-5.579752e+00)*S172+(-2.933046e+00)*S173+(-7.893875e-01)*S174+(-7.186524e+00)*S175+(-1.297228e+01)*S176+1.065111e+01*S177+(-9.891794e+00)*S178+0.000000e+00*S179'
.param V44_part19='V44_part18+2.044683e+00*S180+2.985741e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+3.974655e+00*S185+(-5.295803e+00)*S186+0.000000e+00*S187+0.000000e+00*S188+(-9.514412e+00)*S189'
.param V44_part20='V44_part19+6.230862e+00*S190+(-1.711678e+01)*S191+0.000000e+00*S192+(-5.081748e+00)*S193+7.850165e+00*S194+(-6.898331e-01)*S195+(-1.386967e-01)*S196+0.000000e+00*S197+(-1.091068e+00)*S198+1.609263e-01*S199'
.param V44_part21='V44_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+9.077889e+00*S207+(-1.010972e+01)*S208+6.793406e+00*S209'
.param V44_part22='V44_part21+2.873158e+00*S210+4.915250e+00*S211+5.412254e+00*S212+2.205315e+00*S213+(-3.916757e+00)*S214+1.331501e+01*S215+0.000000e+00*S216+2.489744e+00*S217+1.561979e+01*S218+3.683708e+00*S219'
.param V44_part23='V44_part22+(-5.371469e-01)*S220+(-1.434854e+00)*S221+0.000000e+00*S222+(-5.402781e+00)*S223+0.000000e+00*S224+(-6.512627e-01)*S225+(-4.646944e+00)*S226+0.000000e+00*S227+0.000000e+00*S228+(-4.835069e+00)*S229'
.param V44_part24='V44_part23+(-1.842169e+01)*S230+0.000000e+00*S231+0.000000e+00*S232+1.017757e+01*S233+(-7.181922e+00)*S234+0.000000e+00*S235+1.496111e+01*S236+0.000000e+00*S237+0.000000e+00*S238+(-7.601105e+00)*S239'
.param V44_part25='V44_part24+1.029622e+00*S240+0.000000e+00*S241+2.214282e+00*S242+(-4.719309e+00)*S243+(-4.522234e+00)*S244+(-1.125281e+00)*S245+6.373927e+00*S246+(-1.345105e+01)*S247+(-7.180493e+00)*S248+(-6.275909e+00)*S249'
.param V44_part26='V44_part25+(-1.916395e+01)*S250+(-7.996472e+00)*S251+1.300226e+01*S252+(-3.751136e+00)*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+5.620067e+00*S258+(-7.191351e+00)*S259'
.param V44_part27='V44_part26+0.000000e+00*S260+7.536848e+00*S261+(-5.662823e-01)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+(-4.275894e+00)*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V44_part28='V44_part27+0.000000e+00*S270+6.978847e+00*S271+0.000000e+00*S272+(-3.626043e+00)*S273+0.000000e+00*S274+(-6.738238e+00)*S275+(-1.604360e+00)*S276+0.000000e+00*S277+(-9.976767e+00)*S278+(-1.322212e+01)*S279'
.param V44_part29='V44_part28+1.298517e+00*S280+(-4.151908e+00)*S281+0.000000e+00*S282+(-3.087170e+00)*S283+2.005033e+01*S284+(-3.531502e+00)*S285+0.000000e+00*S286+9.073837e+00*S287+(-4.010429e+00)*S288+(-3.526262e+00)*S289'
.param V44_part30='V44_part29+1.638130e+01*S290+(-2.250456e+00)*S291+(-9.589513e+00)*S292+0.000000e+00*S293+1.003318e+01*S294+(-1.125131e+01)*S295+0.000000e+00*S296+(-2.575327e+01)*S297+1.192262e+01*S298+0.000000e+00*S299'
.param V44_part31='V44_part30+(-3.052972e+00)*S300+0.000000e+00*S301+4.445215e+00*S302+(-7.155353e+00)*S303+(-2.709801e+00)*S304+0.000000e+00*S305+(-5.237767e+00)*S306+(-7.603884e+00)*S307+(-5.901047e+00)*S308+(-6.976137e+00)*S309'
.param V44='V44_part31+(-1.574019e+01)*S310+0.000000e+00*S311+(-1.619905e+00)*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V45_part1='6.552118e-03*S0+6.577695e-02*S1+9.679586e-02*S2+6.190655e-01*S3+1.070432e-01*S4+(-8.626432e-01)*S5+3.722242e-01*S6+3.227438e-01*S7+(-1.208165e+00)*S8+(-3.574981e-01)*S9'
.param V45_part2='V45_part1+(-7.913148e-01)*S10+(-1.333350e+00)*S11+(-5.768358e-01)*S12+(-9.475964e-01)*S13+(-2.191220e+00)*S14+3.780822e-01*S15+3.471870e-01*S16+(-3.407536e-01)*S17+2.578237e-02*S18+(-4.274572e-01)*S19'
.param V45_part3='V45_part2+(-1.822438e+00)*S20+(-3.084142e-01)*S21+(-9.174882e-01)*S22+(-5.873299e-01)*S23+(-7.650916e-01)*S24+(-1.503570e+00)*S25+(-2.980283e+00)*S26+(-2.430498e-01)*S27+(-3.995559e-01)*S28+(-2.633781e+00)*S29'
.param V45_part4='V45_part3+(-1.140492e-01)*S30+(-5.054259e-01)*S31+(-2.245862e+00)*S32+(-1.144373e+00)*S33+(-1.981512e+00)*S34+(-3.120754e+00)*S35+(-1.645350e+00)*S36+8.897179e-01*S37+(-4.534098e+00)*S38+(-2.717105e+00)*S39'
.param V45_part5='V45_part4+(-1.711467e+00)*S40+(-6.987202e+00)*S41+(-3.235938e+00)*S42+(-3.913525e+00)*S43+(-7.754571e+00)*S44+(-8.753198e-01)*S45+1.275399e-01*S46+(-2.918867e-01)*S47+(-1.639848e+00)*S48+(-7.422160e-01)*S49'
.param V45_part6='V45_part5+(-5.120761e+00)*S50+(-1.849555e-01)*S51+(-1.867367e+00)*S52+(-6.251767e+00)*S53+(-1.585982e+00)*S54+(-3.519259e+00)*S55+(-1.145877e+01)*S56+(-2.729340e+00)*S57+(-6.356454e+00)*S58+(-9.596142e+00)*S59'
.param V45_part7='V45_part6+(-2.827471e-01)*S60+(-1.896302e+00)*S61+(-4.414047e+00)*S62+(-1.366246e+00)*S63+(-3.781001e+00)*S64+(-5.764047e+00)*S65+(-1.792260e+00)*S66+(-2.617918e+03)*S67+(-9.231223e+00)*S68+(-1.201525e+02)*S69'
.param V45_part8='V45_part7+(-3.466228e+02)*S70+(-9.328526e+00)*S71+(-2.592620e+00)*S72+(-6.359380e+00)*S73+(-3.491636e+00)*S74+(-4.177854e-01)*S75+(-1.025659e+00)*S76+(-1.809776e+00)*S77+(-5.730348e-01)*S78+(-1.461083e+00)*S79'
.param V45_part9='V45_part8+(-1.867374e+00)*S80+(-7.501595e-01)*S81+(-2.522494e+00)*S82+(-2.218555e+00)*S83+(-1.664150e+00)*S84+(-9.957732e-03)*S85+(-2.574457e+00)*S86+7.222483e-02*S87+(-2.097410e+00)*S88+(-5.141164e+00)*S89'
.param V45_part10='V45_part9+(-1.025718e+00)*S90+(-2.425932e+00)*S91+(-5.828092e+00)*S92+(-1.585424e+00)*S93+(-3.104514e+00)*S94+(-8.001961e+00)*S95+(-2.323117e+00)*S96+(-6.433925e+00)*S97+(-1.066190e+01)*S98+(-2.238775e+00)*S99'
.param V45_part11='V45_part10+(-5.718050e+00)*S100+(-1.173075e+01)*S101+(-2.493253e+00)*S102+(-6.109671e+00)*S103+(-1.419862e+01)*S104+(-1.016522e+00)*S105+(-3.694181e+00)*S106+(-5.743975e+00)*S107+(-1.516564e+00)*S108+(-6.340853e+00)*S109'
.param V45_part12='V45_part11+(-1.079088e+01)*S110+(-2.563007e+00)*S111+(-6.393455e+00)*S112+(-6.051530e+00)*S113+(-1.014476e+00)*S114+(-6.396106e+00)*S115+(-9.851015e+00)*S116+(-2.458550e+00)*S117+(-4.844278e+00)*S118+(-1.692575e+01)*S119'
.param V45_part13='V45_part12+(-2.168474e+00)*S120+(-4.484723e+00)*S121+(-8.925637e+00)*S122+(-1.707102e+00)*S123+(-6.653910e+00)*S124+(-1.231452e+01)*S125+(-2.184121e+00)*S126+(-5.142533e+00)*S127+(-1.495887e+01)*S128+(-2.356091e+00)*S129'
.param V45_part14='V45_part13+(-4.409502e+00)*S130+(-1.682332e+01)*S131+(-1.958217e+00)*S132+(-4.422812e+00)*S133+(-1.676784e+01)*S134+(-2.403228e-01)*S135+(-2.582558e+00)*S136+(-7.533426e+00)*S137+(-1.559842e+00)*S138+(-3.209102e+00)*S139'
.param V45_part15='V45_part14+(-7.749802e+00)*S140+(-9.917895e-01)*S141+(-4.466173e+00)*S142+(-9.633893e+00)*S143+(-2.901411e-01)*S144+(-6.883771e+00)*S145+(-1.177773e+01)*S146+(-6.883699e-01)*S147+(-3.663138e+00)*S148+(-1.217108e+01)*S149'
.param V45_part16='V45_part15+(-2.119064e+00)*S150+(-4.128659e+00)*S151+(-1.274360e+01)*S152+(-2.145790e+00)*S153+(-1.115386e+01)*S154+(-1.638082e+01)*S155+2.228350e+00*S156+(-3.848315e+00)*S157+(-1.575218e+01)*S158+(-1.567746e+00)*S159'
.param V45_part17='V45_part16+(-4.871026e+00)*S160+(-1.847017e+01)*S161+(-1.288763e+00)*S162+(-6.376724e+00)*S163+(-2.006060e+01)*S164+(-3.297217e+00)*S165+(-9.327859e+00)*S166+(-1.673290e+01)*S167+(-2.560460e+00)*S168+(-7.139668e+00)*S169'
.param V45_part18='V45_part17+(-1.972406e+01)*S170+(-2.505591e+00)*S171+(-3.113764e+00)*S172+(-1.617582e+01)*S173+(-1.827647e+00)*S174+(-4.542288e+00)*S175+(-1.755565e+01)*S176+(-2.597026e+00)*S177+(-5.612347e+00)*S178+(-1.663101e+01)*S179'
.param V45_part19='V45_part18+(-2.394672e+00)*S180+(-8.188087e+00)*S181+(-1.381100e+01)*S182+(-4.439022e+00)*S183+(-7.064395e+00)*S184+(-1.859948e+01)*S185+(-1.963381e+00)*S186+(-7.263300e+00)*S187+(-1.713495e+01)*S188+(-1.962822e+00)*S189'
.param V45_part20='V45_part19+(-7.547799e+00)*S190+(-1.692442e+01)*S191+(-2.192726e+00)*S192+(-5.160482e+00)*S193+(-1.358279e+01)*S194+(-4.445779e-01)*S195+(-4.143275e+00)*S196+(-1.168321e+01)*S197+(-4.463437e+00)*S198+(-8.684301e+00)*S199'
.param V45_part21='V45_part20+(-1.488726e+01)*S200+(-8.071967e-01)*S201+(-3.459508e+00)*S202+(-1.549128e+01)*S203+(-1.979668e+00)*S204+(-5.932329e+00)*S205+(-7.780202e+00)*S206+(-9.352288e-01)*S207+(-6.318990e+00)*S208+(-8.389757e+00)*S209'
.param V45_part22='V45_part21+(-3.375780e+00)*S210+(-9.019546e+00)*S211+(-1.392111e+01)*S212+1.058207e+00*S213+(-6.495783e+00)*S214+(-1.987969e+01)*S215+(-2.117463e+00)*S216+(-1.770617e+00)*S217+(-1.896944e+01)*S218+(-1.386330e+00)*S219'
.param V45_part23='V45_part22+(-9.802718e+00)*S220+4.654792e+00*S221+(-4.604667e+00)*S222+2.316026e+00*S223+1.736379e+00*S224+(-1.644731e+00)*S225+(-7.914416e+00)*S226+(-1.997305e+01)*S227+(-2.480845e+00)*S228+(-5.427058e+00)*S229'
.param V45_part24='V45_part23+(-1.884334e+01)*S230+(-3.645112e+00)*S231+(-7.115442e+00)*S232+(-1.579981e+01)*S233+(-2.580219e+00)*S234+(-5.290565e+00)*S235+(-1.708116e+01)*S236+(-3.637837e+00)*S237+(-4.203412e+00)*S238+(-1.813396e+01)*S239'
.param V45_part25='V45_part24+(-3.321803e+00)*S240+(-6.448290e+00)*S241+(-1.163014e+01)*S242+(-1.957242e+00)*S243+(-5.233767e+00)*S244+(-1.190220e+01)*S245+(-1.284206e+00)*S246+(-4.644256e+00)*S247+(-1.327350e+01)*S248+(-2.090624e+00)*S249'
.param V45_part26='V45_part25+(-5.344587e+00)*S250+(-1.378325e+01)*S251+(-4.425060e+00)*S252+(-7.579617e+00)*S253+(-1.963179e+01)*S254+(-4.712984e+00)*S255+(-6.767484e+00)*S256+(-2.066477e+01)*S257+(-1.355611e+00)*S258+(-6.752455e+00)*S259'
.param V45_part27='V45_part26+(-1.418288e+01)*S260+(-1.015093e+00)*S261+(-2.584745e+00)*S262+(-1.725222e+01)*S263+(-3.508242e+00)*S264+(-4.174502e+00)*S265+(-1.397032e+01)*S266+(-2.016736e+00)*S267+(-5.896321e+00)*S268+(-1.490899e+01)*S269'
.param V45_part28='V45_part27+(-2.050639e+00)*S270+(-1.039719e+01)*S271+(-2.398757e+01)*S272+(-2.815546e+00)*S273+(-1.004983e+01)*S274+(-1.122562e+01)*S275+(-2.575988e+00)*S276+(-7.503283e+00)*S277+(-1.530768e+01)*S278+(-3.622385e+00)*S279'
.param V45_part29='V45_part28+(-5.982369e+00)*S280+(-1.814705e+01)*S281+(-4.920327e+00)*S282+(-1.290155e+01)*S283+(-2.292692e+01)*S284+(-2.826544e+00)*S285+(-4.350501e+00)*S286+(-1.436522e+01)*S287+(-1.978879e+00)*S288+(-6.150619e+00)*S289'
.param V45_part30='V45_part29+(-1.492146e+01)*S290+(-2.861153e+00)*S291+(-5.702855e+00)*S292+(-1.767010e+01)*S293+(-3.331846e+00)*S294+(-1.665085e+00)*S295+(-2.833456e+01)*S296+(-4.921094e+00)*S297+(-7.612762e+00)*S298+(-2.118045e+01)*S299'
.param V45_part31='V45_part30+(-1.105141e+00)*S300+(-5.967593e+00)*S301+(-1.668813e+01)*S302+(-1.215676e+00)*S303+(-1.588817e+00)*S304+(-1.690808e+01)*S305+(-1.634997e+00)*S306+(-1.506603e-01)*S307+(-1.304300e+01)*S308+(-2.156967e+00)*S309'
.param V45='V45_part31+(-2.019829e+00)*S310+(-1.374173e+01)*S311+(-2.461401e+00)*S312+(-3.888413e+00)*S313+(-1.833001e+01)*S314'
.param V46_part1='3.260492e+00*S0+4.272117e+00*S1+2.582113e+00*S2+1.718197e+00*S3+2.547258e+00*S4+4.654487e+00*S5+2.170655e+00*S6+3.207394e+00*S7+3.123891e+00*S8+2.784692e+00*S9'
.param V46_part2='V46_part1+2.593975e+00*S10+2.792421e+00*S11+2.675701e+00*S12+2.115011e+00*S13+3.062404e+00*S14+3.572997e+00*S15+4.328087e+00*S16+6.392822e+00*S17+2.889036e+00*S18+5.822330e+00*S19'
.param V46_part3='V46_part2+6.522523e+00*S20+2.402619e+00*S21+4.170082e+00*S22+3.246922e+00*S23+2.532061e+00*S24+3.369287e+00*S25+4.658307e+00*S26+2.274309e+00*S27+2.808451e+00*S28+4.094149e+00*S29'
.param V46_part4='V46_part3+5.851952e+00*S30+5.819215e+00*S31+9.509103e+00*S32+7.417487e+00*S33+8.886993e+00*S34+1.029957e+01*S35+6.946926e+00*S36+3.716851e+00*S37+9.769791e+00*S38+7.110087e+00*S39'
.param V46_part5='V46_part4+5.208436e+00*S40+8.950130e+00*S41+7.700489e+00*S42+6.610197e+00*S43+8.262418e+00*S44+7.412521e+00*S45+7.719338e+00*S46+3.876451e+00*S47+7.735877e+00*S48+6.483814e+00*S49'
.param V46_part6='V46_part5+1.209886e+01*S50+3.190168e+00*S51+5.577588e+00*S52+1.133129e+01*S53+5.253676e+00*S54+7.507820e+00*S55+1.207999e+01*S56+6.196309e+00*S57+8.833694e+00*S58+1.177130e+01*S59'
.param V46_part7='V46_part6+7.953659e+00*S60+1.143111e+01*S61+1.505792e+01*S62+8.478982e+00*S63+1.274918e+01*S64+1.372894e+01*S65+7.053108e+00*S66+5.822501e+03*S67+1.318642e+01*S68+7.876224e+01*S69'
.param V46_part8='V46_part7+1.138890e+03*S70+1.325715e+01*S71+6.456475e+00*S72+1.017419e+01*S73+6.359899e+00*S74+5.647191e+00*S75+6.749364e+00*S76+8.510662e+00*S77+4.560879e+00*S78+4.492743e+00*S79'
.param V46_part9='V46_part8+7.776359e+00*S80+4.979851e+00*S81+6.933057e+00*S82+6.519123e+00*S83+5.420220e+00*S84+3.470850e+00*S85+6.811200e+00*S86+3.334165e+00*S87+5.166431e+00*S88+6.193531e+00*S89'
.param V46_part10='V46_part9+9.841400e+00*S90+1.707484e+01*S91+1.284992e+01*S92+8.578237e+00*S93+1.483325e+01*S94+1.342127e+01*S95+8.008582e+00*S96+1.125415e+01*S97+1.652816e+01*S98+6.700315e+00*S99'
.param V46_part11='V46_part10+8.900378e+00*S100+1.392551e+01*S101+6.607029e+00*S102+8.484902e+00*S103+1.535528e+01*S104+7.798521e+00*S105+1.604721e+01*S106+7.756844e+00*S107+7.837230e+00*S108+1.478669e+01*S109'
.param V46_part12='V46_part11+1.777398e+01*S110+8.243380e+00*S111+1.136343e+01*S112+1.147669e+01*S113+3.550037e+00*S114+1.015591e+01*S115+1.210215e+01*S116+6.614839e+00*S117+7.661825e+00*S118+1.549120e+01*S119'
.param V46_part13='V46_part12+1.549721e+01*S120+1.841808e+01*S121+1.836735e+01*S122+8.877933e+00*S123+1.540661e+01*S124+2.055062e+01*S125+8.120439e+00*S126+1.103710e+01*S127+1.910099e+01*S128+7.575863e+00*S129'
.param V46_part14='V46_part13+9.504188e+00*S130+1.793649e+01*S131+6.256961e+00*S132+7.579796e+00*S133+1.501881e+01*S134+1.254478e+01*S135+1.547269e+01*S136+1.243971e+01*S137+9.785236e+00*S138+1.201995e+01*S139'
.param V46_part15='V46_part14+1.530232e+01*S140+4.281050e+00*S141+1.184630e+01*S142+1.333109e+01*S143+3.611164e+00*S144+1.033741e+01*S145+1.487040e+01*S146+2.073864e+00*S147+6.455353e+00*S148+1.375880e+01*S149'
.param V46_part16='V46_part15+9.941598e+00*S150+1.686535e+01*S151+2.390007e+01*S152+8.514544e+00*S153+2.068017e+01*S154+2.454715e+01*S155+5.335114e-01*S156+6.095499e+00*S157+1.866826e+01*S158+5.593186e+00*S159'
.param V46_part17='V46_part16+8.047805e+00*S160+1.648895e+01*S161+3.923288e+00*S162+8.724498e+00*S163+1.607277e+01*S164+1.278023e+01*S165+2.020705e+01*S166+2.885352e+01*S167+9.264035e+00*S168+1.322678e+01*S169'
.param V46_part18='V46_part17+2.850670e+01*S170+7.745617e+00*S171+5.991515e+00*S172+1.106652e+01*S173+7.222315e+00*S174+8.013024e+00*S175+1.360172e+01*S176+6.697402e+00*S177+8.145616e+00*S178+1.099693e+01*S179'
.param V46_part19='V46_part18+1.160820e+01*S180+1.957530e+01*S181+2.246872e+01*S182+1.400885e+01*S183+1.512044e+01*S184+2.372019e+01*S185+7.592671e+00*S186+1.258938e+01*S187+1.385540e+01*S188+6.915869e+00*S189'
.param V46_part20='V46_part19+7.891041e+00*S190+1.164469e+01*S191+5.832174e+00*S192+8.684548e+00*S193+1.249754e+01*S194+1.168914e+01*S195+1.833232e+01*S196+2.027148e+01*S197+1.591304e+01*S198+2.076257e+01*S199'
.param V46_part21='V46_part20+2.217393e+01*S200+8.328424e+00*S201+1.092225e+01*S202+2.010261e+01*S203+7.671823e+00*S204+1.193156e+01*S205+1.029421e+01*S206+5.712161e+00*S207+8.822039e+00*S208+1.078246e+01*S209'
.param V46_part22='V46_part21+1.236285e+01*S210+2.340633e+01*S211+2.677955e+01*S212+(-1.278349e+00)*S213+1.008164e+01*S214+2.042473e+01*S215+6.292245e+00*S216+5.932956e+00*S217+1.640346e+01*S218+4.144964e+00*S219'
.param V46_part23='V46_part22+1.041104e+01*S220+2.029563e+00*S221+8.510892e+00*S222+2.874719e+00*S223+8.392895e-01*S224+7.342971e+00*S225+1.557340e+01*S226+1.940926e+01*S227+9.342524e+00*S228+1.032462e+01*S229'
.param V46_part24='V46_part23+1.648530e+01*S230+8.151885e+00*S231+1.288329e+01*S232+1.482517e+01*S233+6.905776e+00*S234+7.952509e+00*S235+1.570794e+01*S236+7.696274e+00*S237+8.761013e+00*S238+1.293556e+01*S239'
.param V46_part25='V46_part24+1.046830e+01*S240+1.039224e+01*S241+1.439065e+01*S242+6.989898e+00*S243+1.158491e+01*S244+1.506771e+01*S245+1.911347e+00*S246+7.533114e+00*S247+1.332540e+01*S248+6.557521e+00*S249'
.param V46_part26='V46_part25+8.704399e+00*S250+1.284867e+01*S251+7.750700e+00*S252+1.323930e+01*S253+1.421880e+01*S254+1.639813e+01*S255+1.983404e+01*S256+3.364295e+01*S257+9.643839e+00*S258+1.552351e+01*S259'
.param V46_part27='V46_part26+1.791132e+01*S260+6.060583e+00*S261+6.506307e+00*S262+1.577756e+01*S263+8.638526e+00*S264+7.850836e+00*S265+1.327198e+01*S266+6.630461e+00*S267+1.204029e+01*S268+1.257863e+01*S269'
.param V46_part28='V46_part27+7.794430e+00*S270+1.920946e+01*S271+2.966574e+01*S272+9.699735e+00*S273+1.780934e+01*S274+1.249418e+01*S275+7.365223e+00*S276+1.364431e+01*S277+1.360310e+01*S278+8.626250e+00*S279'
.param V46_part29='V46_part28+9.794876e+00*S280+1.516613e+01*S281+8.577490e+00*S282+1.146269e+01*S283+1.551771e+01*S284+1.049180e+01*S285+1.020808e+01*S286+2.081581e+01*S287+6.007944e+00*S288+1.171055e+01*S289'
.param V46_part30='V46_part29+1.274773e+01*S290+7.295687e+00*S291+1.461944e+01*S292+1.628329e+01*S293+7.237538e+00*S294+5.974639e+00*S295+1.921817e+01*S296+8.949024e+00*S297+1.040866e+01*S298+1.306506e+01*S299'
.param V46_part31='V46_part30+9.451468e+00*S300+1.531697e+01*S301+1.887978e+01*S302+7.139298e+00*S303+8.925239e+00*S304+1.592874e+01*S305+7.091516e+00*S306+1.211930e+01*S307+1.387074e+01*S308+6.858045e+00*S309'
.param V46='V46_part31+8.928167e+00*S310+1.094437e+01*S311+7.441891e+00*S312+8.975464e+00*S313+1.547351e+01*S314'
.param V47_part1='2.598613e+00*S0+2.647703e+00*S1+1.596229e+00*S2+3.205164e+00*S3+3.167945e+00*S4+3.930970e+00*S5+3.461903e+00*S6+3.019199e+00*S7+3.205512e+00*S8+4.339326e+00*S9'
.param V47_part2='V47_part1+3.197478e+00*S10+3.690093e+00*S11+5.151009e+00*S12+3.732702e+00*S13+4.282624e+00*S14+3.392596e+00*S15+3.219980e+00*S16+4.116969e+00*S17+1.867549e+00*S18+4.384482e+00*S19'
.param V47_part3='V47_part2+5.729134e+00*S20+3.189862e+00*S21+6.024448e+00*S22+2.727516e+00*S23+4.275027e+00*S24+4.930302e+00*S25+5.953916e+00*S26+2.558871e+00*S27+3.030185e+00*S28+4.514269e+00*S29'
.param V47_part4='V47_part3+5.080571e+00*S30+6.009904e+00*S31+8.057055e+00*S32+6.124544e+00*S33+7.408146e+00*S34+9.013106e+00*S35+7.587162e+00*S36+3.459927e+00*S37+1.097595e+01*S38+9.149841e+00*S39'
.param V47_part5='V47_part4+7.129183e+00*S40+1.362112e+01*S41+1.086972e+01*S42+1.112008e+01*S43+1.287914e+01*S44+7.211047e+00*S45+3.595258e+00*S46+6.353485e+00*S47+8.426965e+00*S48+6.667773e+00*S49'
.param V47_part6='V47_part5+1.271926e+01*S50+2.453952e+00*S51+5.276859e+00*S52+1.428501e+01*S53+8.471139e+00*S54+1.087831e+01*S55+1.801643e+01*S56+1.067202e+01*S57+1.671525e+01*S58+1.777330e+01*S59'
.param V47_part7='V47_part6+6.487258e+00*S60+9.347406e+00*S61+1.235868e+01*S62+8.242929e+00*S63+1.160354e+01*S64+1.424971e+01*S65+9.628246e+00*S66+7.153965e+03*S67+1.753764e+01*S68+4.489523e+02*S69'
.param V47_part8='V47_part7+5.034337e+03*S70+1.840287e+01*S71+7.431134e+00*S72+1.755540e+01*S73+7.112180e+00*S74+5.264857e+00*S75+6.539529e+00*S76+7.302195e+00*S77+6.207619e+00*S78+8.444011e+00*S79'
.param V47_part9='V47_part8+7.625641e+00*S80+6.953182e+00*S81+8.538725e+00*S82+6.617227e+00*S83+8.442170e+00*S84+6.524826e+00*S85+7.696908e+00*S86+7.317923e+00*S87+8.616068e+00*S88+9.751672e+00*S89'
.param V47_part10='V47_part9+8.581848e+00*S90+1.180621e+01*S91+1.652515e+01*S92+1.206978e+01*S93+1.337541e+01*S94+1.525508e+01*S95+1.521774e+01*S96+2.086613e+01*S97+2.330751e+01*S98+1.759102e+01*S99'
.param V47_part11='V47_part10+2.314468e+01*S100+2.589077e+01*S101+1.985280e+01*S102+2.436221e+01*S103+2.742070e+01*S104+1.217310e+01*S105+1.593563e+01*S106+2.043415e+01*S107+1.300328e+01*S108+2.059385e+01*S109'
.param V47_part12='V47_part11+2.570022e+01*S110+1.638843e+01*S111+2.308267e+01*S112+2.012365e+01*S113+1.446485e+01*S114+2.490609e+01*S115+2.306651e+01*S116+1.750012e+01*S117+2.603231e+01*S118+3.387880e+01*S119'
.param V47_part13='V47_part12+1.573807e+01*S120+1.848897e+01*S121+2.548680e+01*S122+1.524278e+01*S123+2.313958e+01*S124+2.798366e+01*S125+1.840025e+01*S126+2.352573e+01*S127+3.114557e+01*S128+2.034608e+01*S129'
.param V47_part14='V47_part13+2.345311e+01*S130+3.412317e+01*S131+1.686441e+01*S132+2.083021e+01*S133+3.716517e+01*S134+5.471230e+00*S135+1.078225e+01*S136+2.008560e+01*S137+9.871070e+00*S138+1.298244e+01*S139'
.param V47_part15='V47_part14+1.841887e+01*S140+9.972428e+00*S141+1.563177e+01*S142+2.126082e+01*S143+1.294506e+01*S144+1.897012e+01*S145+2.317666e+01*S146+1.520425e+01*S147+1.601174e+01*S148+2.450934e+01*S149'
.param V47_part16='V47_part15+2.474067e+01*S150+2.219587e+01*S151+3.344978e+01*S152+2.262976e+01*S153+3.764544e+01*S154+3.558502e+01*S155+1.505255e+01*S156+2.996058e+01*S157+3.790948e+01*S158+2.281708e+01*S159'
.param V47_part17='V47_part16+3.148496e+01*S160+4.394401e+01*S161+2.083254e+01*S162+3.531224e+01*S163+4.272631e+01*S164+2.247244e+01*S165+3.279222e+01*S166+3.863856e+01*S167+2.238230e+01*S168+3.093799e+01*S169'
.param V47_part18='V47_part17+4.110310e+01*S170+2.564402e+01*S171+3.052551e+01*S172+4.205131e+01*S173+1.953377e+01*S174+2.605205e+01*S175+4.777843e+01*S176+2.195672e+01*S177+2.675936e+01*S178+5.163071e+01*S179'
.param V47_part19='V47_part18+2.303545e+01*S180+3.298558e+01*S181+3.729924e+01*S182+2.386298e+01*S183+3.108729e+01*S184+4.460284e+01*S185+2.057507e+01*S186+3.353618e+01*S187+4.881557e+01*S188+2.000981e+01*S189'
.param V47_part20='V47_part19+2.334574e+01*S190+4.729150e+01*S191+2.398810e+01*S192+2.661628e+01*S193+3.065117e+01*S194+1.706155e+01*S195+2.024172e+01*S196+3.044985e+01*S197+2.712052e+01*S198+4.120891e+01*S199'
.param V47_part21='V47_part20+3.299673e+01*S200+1.935809e+01*S201+2.407499e+01*S202+3.460583e+01*S203+2.295234e+01*S204+2.642616e+01*S205+2.621869e+01*S206+1.940878e+01*S207+2.595891e+01*S208+2.438874e+01*S209'
.param V47_part22='V47_part21+2.753540e+01*S210+3.528292e+01*S211+4.190438e+01*S212+1.725392e+01*S213+3.960472e+01*S214+4.817317e+01*S215+2.620444e+01*S216+2.396190e+01*S217+5.023960e+01*S218+2.085290e+01*S219'
.param V47_part23='V47_part22+3.883830e+01*S220+1.550099e+01*S221+3.035360e+01*S222+1.826489e+01*S223+1.487328e+01*S224+2.515937e+01*S225+4.023314e+01*S226+5.693840e+01*S227+2.243468e+01*S228+3.108874e+01*S229'
.param V47_part24='V47_part23+5.805461e+01*S230+3.060913e+01*S231+3.463590e+01*S232+4.936668e+01*S233+2.651945e+01*S234+3.369876e+01*S235+4.886106e+01*S236+3.068396e+01*S237+3.319620e+01*S238+4.789840e+01*S239'
.param V47_part25='V47_part24+2.997532e+01*S240+4.155650e+01*S241+4.531589e+01*S242+2.455341e+01*S243+3.016900e+01*S244+4.287697e+01*S245+2.680716e+01*S246+3.323139e+01*S247+4.202086e+01*S248+2.606016e+01*S249'
.param V47_part26='V47_part25+3.306934e+01*S250+3.715052e+01*S251+3.055309e+01*S252+3.338780e+01*S253+4.868027e+01*S254+2.538489e+01*S255+3.543691e+01*S256+4.847080e+01*S257+2.196898e+01*S258+3.360986e+01*S259'
.param V47_part27='V47_part26+4.736498e+01*S260+2.345300e+01*S261+2.812444e+01*S262+4.430294e+01*S263+2.682506e+01*S264+2.917880e+01*S265+4.606361e+01*S266+2.567295e+01*S267+3.058747e+01*S268+4.551320e+01*S269'
.param V47_part28='V47_part27+2.874710e+01*S270+5.005607e+01*S271+5.754678e+01*S272+2.788770e+01*S273+4.363093e+01*S274+4.962447e+01*S275+3.132947e+01*S276+4.145267e+01*S277+5.359565e+01*S278+3.346759e+01*S279'
.param V47_part29='V47_part28+3.991775e+01*S280+5.535407e+01*S281+3.456584e+01*S282+4.895735e+01*S283+6.047234e+01*S284+2.881390e+01*S285+3.961208e+01*S286+5.186626e+01*S287+2.985507e+01*S288+3.749339e+01*S289'
.param V47_part30='V47_part29+5.159372e+01*S290+3.199426e+01*S291+3.694616e+01*S292+5.393784e+01*S293+3.317602e+01*S294+3.994704e+01*S295+5.957625e+01*S296+3.365953e+01*S297+4.024055e+01*S298+4.817213e+01*S299'
.param V47_part31='V47_part30+2.573737e+01*S300+4.251964e+01*S301+5.768176e+01*S302+2.635322e+01*S303+2.921173e+01*S304+4.916211e+01*S305+2.781306e+01*S306+2.479955e+01*S307+3.903340e+01*S308+3.303168e+01*S309'
.param V47='V47_part31+3.533610e+01*S310+4.018586e+01*S311+2.962886e+01*S312+3.910485e+01*S313+4.662511e+01*S314'
.param V48_part1='6.645882e-01*S0+6.731786e-01*S1+6.594757e-01*S2+7.275435e-01*S3+1.238904e+00*S4+1.136966e+00*S5+6.587001e-01*S6+1.114847e+00*S7+9.828107e-01*S8+8.084125e-01*S9'
.param V48_part2='V48_part1+1.014107e+00*S10+1.089085e+00*S11+8.264721e-01*S12+8.986549e-01*S13+8.381598e-01*S14+6.534575e-01*S15+1.247918e+00*S16+1.217881e+00*S17+7.174537e-01*S18+1.522202e+00*S19'
.param V48_part3='V48_part2+1.076393e+00*S20+5.614901e-01*S21+1.030461e+00*S22+4.449386e-01*S23+6.365483e-01*S24+9.571243e-01*S25+1.289543e+00*S26+3.940079e-01*S27+1.976734e-01*S28+6.671451e-01*S29'
.param V48_part4='V48_part3+6.447666e-01*S30+3.509142e-01*S31+1.457156e+00*S32+8.107553e-01*S33+1.116046e+00*S34+1.772619e+00*S35+9.409017e-01*S36+1.795549e+00*S37+1.711085e+00*S38+9.896271e-02*S39'
.param V48_part5='V48_part4+2.039646e+00*S40+1.530548e+00*S41+1.514525e+00*S42+9.944807e-01*S43+1.245118e+00*S44+4.441163e-01*S45+2.735445e-01*S46+(-9.047927e-02)*S47+5.972470e-01*S48+8.827257e-01*S49'
.param V48_part6='V48_part5+1.688186e+00*S50+(-6.221848e-02)*S51+(-4.595933e-01)*S52+1.120093e+00*S53+(-2.035646e-01)*S54+3.207370e-02*S55+6.152218e-01*S56+4.842257e-01*S57+7.368387e-01*S58+9.579769e-01*S59'
.param V48_part7='V48_part6+9.528488e-01*S60+1.278590e+00*S61+1.858945e+00*S62+9.878548e-01*S63+1.557640e+00*S64+1.695708e+00*S65+5.930820e-01*S66+2.615004e+01*S67+1.690443e+00*S68+4.885241e+00*S69'
.param V48_part8='V48_part7+6.099865e+01*S70+1.402126e+00*S71+3.505948e-01*S72+9.092978e-01*S73+5.413432e-01*S74+2.880266e-01*S75+5.021736e-01*S76+1.617141e+00*S77+2.204585e-01*S78+1.240377e-01*S79'
.param V48_part9='V48_part8+1.337625e+00*S80+8.340657e-01*S81+7.852035e-01*S82+1.370030e+00*S83+7.726047e-01*S84+1.801225e+00*S85+2.004385e+00*S86+1.712551e+00*S87+1.791882e+00*S88+1.658797e+00*S89'
.param V48_part10='V48_part9+6.663568e-01*S90+1.786417e+00*S91+1.508816e+00*S92+1.940231e-01*S93+1.449868e+00*S94+5.189818e-01*S95+3.705860e-01*S96+6.497215e-01*S97+1.849418e+00*S98+(-5.662877e-02)*S99'
.param V48_part11='V48_part10+(-2.390120e-03)*S100+1.317170e+00*S101+3.110686e-01*S102+(-2.096439e-01)*S103+1.087284e+00*S104+1.056091e-01*S105+9.652046e-01*S106+9.774997e-02*S107+(-6.216385e-02)*S108+4.900086e-01*S109'
.param V48_part12='V48_part11+1.355843e+00*S110+(-3.563985e-01)*S111+(-2.048384e-01)*S112+1.558825e+00*S113+(-1.319404e+00)*S114+(-2.808131e-01)*S115+(-2.253608e-01)*S116+(-6.658785e-01)*S117+(-3.926303e-01)*S118+4.782151e-01*S119'
.param V48_part13='V48_part12+1.144134e+00*S120+1.183218e+00*S121+1.831862e+00*S122+5.306740e-01*S123+3.460839e-01*S124+1.706891e+00*S125+3.068342e-01*S126+2.425488e-01*S127+1.184429e+00*S128+3.261434e-01*S129'
.param V48_part14='V48_part13+(-4.063394e-01)*S130+8.898950e-01*S131+(-2.552617e-01)*S132+(-3.719483e-01)*S133+7.104102e-01*S134+4.357527e-01*S135+1.080749e+00*S136+2.129419e-01*S137+1.540883e+00*S138+7.277800e-01*S139'
.param V48_part15='V48_part14+1.459902e+00*S140+1.327787e+00*S141+1.223662e+00*S142+1.118479e+00*S143+1.585747e+00*S144+2.111742e+00*S145+9.205165e-01*S146+(-1.094770e+00)*S147+(-1.279058e+00)*S148+7.583187e-01*S149'
.param V48_part16='V48_part15+4.939023e-01*S150+(-4.997722e-01)*S151+1.850011e+00*S152+3.284150e-01*S153+(-3.977521e+00)*S154+7.736991e-01*S155+(-4.013959e-01)*S156+(-1.658358e+00)*S157+(-7.888060e-02)*S158+2.395458e-02*S159'
.param V48_part17='V48_part16+(-1.143769e+00)*S160+4.594186e-01*S161+1.810816e-01*S162+(-8.174108e-01)*S163+(-1.192831e-02)*S164+(-6.838028e-01)*S165+(-1.707829e+00)*S166+7.924320e-01*S167+(-2.492441e-01)*S168+(-1.586607e+00)*S169'
.param V48_part18='V48_part17+4.545241e-01*S170+(-1.692993e-01)*S171+(-1.459901e+00)*S172+(-1.160713e+00)*S173+(-2.686290e-01)*S174+(-1.258482e+00)*S175+(-3.459756e-01)*S176+(-9.570496e-02)*S177+(-1.182611e+00)*S178+5.111137e-01*S179'
.param V48_part19='V48_part18+4.540889e-01*S180+(-1.194193e+00)*S181+8.199901e-01*S182+(-1.034189e+00)*S183+(-1.342039e+00)*S184+4.386718e-01*S185+(-2.288855e-01)*S186+(-1.078275e+00)*S187+(-2.286688e-01)*S188+(-2.600873e-01)*S189'
.param V48_part20='V48_part19+(-5.335319e-01)*S190+(-1.233378e-01)*S191+6.210767e-03*S192+(-1.109542e+00)*S193+(-1.142659e-01)*S194+1.468536e+00*S195+(-3.016582e-01)*S196+5.583590e-01*S197+(-5.448570e-01)*S198+1.820628e+00*S199'
.param V48_part21='V48_part20+6.236141e-01*S200+7.712343e-01*S201+9.812660e-02*S202+5.095334e-01*S203+9.824237e-01*S204+(-7.758924e-01)*S205+(-7.641691e-01)*S206+4.959922e-01*S207+(-2.827559e-01)*S208+(-1.511471e+00)*S209'
.param V48_part22='V48_part21+(-8.484970e-01)*S210+(-6.807393e-01)*S211+1.596071e+00*S212+(-3.937699e-01)*S213+(-7.957738e-01)*S214+5.530628e-03*S215+1.600007e-01*S216+(-6.452907e-01)*S217+(-2.387728e-02)*S218+(-4.449693e-01)*S219'
.param V48_part23='V48_part22+(-2.884312e-01)*S220+(-2.277408e+00)*S221+(-3.913955e-01)*S222+(-2.167654e+00)*S223+(-1.912062e+00)*S224+(-1.482872e-01)*S225+(-8.414834e-01)*S226+(-8.117181e-01)*S227+(-5.587972e-01)*S228+(-5.521319e-01)*S229'
.param V48_part24='V48_part23+(-4.978944e-01)*S230+(-8.492060e-02)*S231+(-5.316751e-01)*S232+7.134301e-02*S233+2.414453e-01*S234+(-7.927879e-01)*S235+2.797385e-01*S236+(-1.246946e-01)*S237+(-5.643069e-01)*S238+(-1.238703e-01)*S239'
.param V48_part25='V48_part24+(-7.769934e-01)*S240+(-8.151129e-01)*S241+(-4.003361e-01)*S242+(-5.797179e-01)*S243+(-7.148208e-01)*S244+(-1.259277e-01)*S245+(-7.244824e-01)*S246+(-1.140117e+00)*S247+(-4.592348e-01)*S248+(-6.797852e-03)*S249'
.param V48_part26='V48_part25+(-7.556599e-01)*S250+(-6.530571e-01)*S251+3.437606e-02*S252+(-5.692822e-01)*S253+(-2.086281e-01)*S254+(-8.504852e-01)*S255+(-1.190779e+00)*S256+7.935088e-01*S257+2.905128e-01*S258+(-9.148136e-01)*S259'
.param V48_part27='V48_part26+1.227500e+00*S260+(-1.720116e-02)*S261+(-6.693727e-01)*S262+1.372030e-01*S263+(-2.442136e-01)*S264+(-3.266139e-01)*S265+3.189398e-01*S266+6.500787e-01*S267+2.363042e-01*S268+6.757116e-01*S269'
.param V48_part28='V48_part27+(-6.472280e-01)*S270+(-8.877077e-01)*S271+(-1.448549e+00)*S272+(-4.182869e-01)*S273+(-1.138964e-01)*S274+(-7.566389e-01)*S275+1.523202e-01*S276+(-6.849683e-01)*S277+(-3.830111e-01)*S278+(-1.727718e-01)*S279'
.param V48_part29='V48_part28+(-1.681874e-01)*S280+(-1.643303e-01)*S281+(-1.536599e-01)*S282+1.979411e-01*S283+9.877135e-02*S284+(-4.447174e-01)*S285+(-3.863992e-01)*S286+1.554520e+00*S287+(-2.303332e-01)*S288+(-1.764732e-01)*S289'
.param V48_part30='V48_part29+2.595726e-01*S290+8.244613e-03*S291+8.511453e-02*S292+(-9.866194e-02)*S293+(-1.226694e-01)*S294+(-3.598222e-01)*S295+(-8.583873e-01)*S296+(-1.312461e-01)*S297+(-4.204748e-01)*S298+(-1.648598e+00)*S299'
.param V48_part31='V48_part30+1.163032e-01*S300+6.248756e-01*S301+4.767228e-01*S302+3.131539e-01*S303+(-1.704734e-01)*S304+(-1.101487e+00)*S305+3.404416e-01*S306+2.570113e-01*S307+(-9.990319e-01)*S308+3.405140e-01*S309'
.param V48='V48_part31+7.565933e-01*S310+(-5.637609e-01)*S311+3.493506e-01*S312+5.633980e-01*S313+(-7.147855e-02)*S314'
.param V49_part1='(-4.662566e-03)*S0+6.088593e-03*S1+3.281300e-03*S2+(-1.469322e-02)*S3+2.020505e-04*S4+3.011792e-02*S5+6.777524e-03*S6+1.921978e-02*S7+3.419399e-03*S8+3.124601e-04*S9'
.param V49_part2='V49_part1+3.545262e-02*S10+4.612851e-03*S11+(-8.977782e-04)*S12+2.065306e-03*S13+(-2.516055e-03)*S14+2.360669e-02*S15+6.659461e-03*S16+1.604855e-02*S17+6.779031e-03*S18+1.051164e-02*S19'
.param V49_part3='V49_part2+1.958366e-02*S20+6.670204e-03*S21+1.667143e-02*S22+1.551888e-02*S23+5.602588e-03*S24+1.157017e-02*S25+1.698060e-02*S26+3.623606e-03*S27+5.394324e-03*S28+3.097858e-02*S29'
.param V49_part4='V49_part3+7.796947e-02*S30+7.038131e-02*S31+8.467783e-02*S32+1.003056e-01*S33+1.269110e-01*S34+9.377112e-02*S35+1.533675e-02*S36+(-2.641901e-02)*S37+7.194927e-02*S38+(-1.073915e-01)*S39'
.param V49_part5='V49_part4+2.736040e-02*S40+(-6.721329e-02)*S41+(-2.385925e-01)*S42+(-3.647756e-01)*S43+(-3.001017e-01)*S44+1.546621e-01*S45+8.102765e-02*S46+4.855535e-02*S47+9.389831e-02*S48+(-2.528176e-01)*S49'
.param V49_part6='V49_part5+2.474572e-01*S50+(-2.227769e-01)*S51+(-2.056095e-01)*S52+2.382267e-01*S53+(-4.911807e-01)*S54+(-2.784224e-01)*S55+(-1.612308e+00)*S56+(-1.104261e+00)*S57+(-3.595868e-01)*S58+6.264671e-02*S59'
.param V49_part7='V49_part6+1.495722e-01*S60+3.055551e-01*S61+3.701327e-01*S62+3.286902e-02*S63+3.020107e-01*S64+4.569018e-01*S65+(-1.425013e-01)*S66+(-4.313641e+00)*S67+(-1.141346e+00)*S68+(-8.470889e+00)*S69'
.param V49_part8='V49_part7+(-4.814174e+02)*S70+4.940004e-01*S71+(-9.720220e-01)*S72+(-7.011097e-01)*S73+(-1.441904e+00)*S74+6.087999e-02*S75+6.366339e-02*S76+1.583430e-01*S77+8.033143e-02*S78+3.087134e-02*S79'
.param V49_part9='V49_part8+4.540988e-02*S80+4.707065e-02*S81+1.814759e-01*S82+(-1.914790e-02)*S83+3.641331e-02*S84+(-1.559972e-01)*S85+(-1.425788e-01)*S86+(-3.843281e-01)*S87+(-1.309830e-01)*S88+6.425022e-02*S89'
.param V49_part10='V49_part9+5.005606e-01*S90+6.442959e-01*S91+3.711307e-01*S92+(-4.920490e-01)*S93+7.856524e-01*S94+3.236122e-01*S95+(-6.891348e-01)*S96+(-8.073440e-01)*S97+8.152025e-01*S98+(-1.055010e+00)*S99'
.param V49_part11='V49_part10+(-1.512712e+00)*S100+(-1.883755e-01)*S101+(-1.009059e+00)*S102+(-1.173719e+00)*S103+2.000937e-01*S104+1.096277e-02*S105+2.229268e-01*S106+7.629667e-01*S107+(-2.543876e-01)*S108+(-7.776389e-01)*S109'
.param V49_part12='V49_part11+1.003461e+00*S110+(-6.763105e-01)*S111+(-1.114198e+00)*S112+5.564803e-01*S113+2.916940e-01*S114+(-9.592237e-01)*S115+(-1.076445e+00)*S116+(-1.022869e+00)*S117+(-1.367839e+00)*S118+(-1.667622e-01)*S119'
.param V49_part13='V49_part12+2.163252e-01*S120+2.768854e-01*S121+1.138407e+00*S122+(-3.773874e-01)*S123+(-9.535598e-01)*S124+9.094358e-01*S125+(-9.437800e-03)*S126+(-1.474421e+00)*S127+6.214387e-01*S128+(-6.201740e-01)*S129'
.param V49_part14='V49_part13+(-9.854554e-01)*S130+1.918963e-01*S131+(-1.139510e+00)*S132+(-1.752066e+00)*S133+(-4.102296e-01)*S134+7.280964e-02*S135+3.613144e-01*S136+6.327246e-01*S137+4.403696e-01*S138+4.123924e-02*S139'
.param V49_part15='V49_part14+1.136974e-01*S140+4.985166e-01*S141+(-1.900142e-01)*S142+6.727473e-01*S143+4.748571e-01*S144+4.731650e-01*S145+7.232846e-01*S146+5.616275e-01*S147+4.644913e-01*S148+(-3.688668e-01)*S149'
.param V49_part16='V49_part15+(-7.048926e-01)*S150+1.513137e+00*S151+1.511655e+00*S152+(-7.461088e-01)*S153+(-1.421313e+00)*S154+1.406490e+00*S155+7.667397e-01*S156+(-1.190783e+00)*S157+1.923880e-01*S158+(-5.461917e-02)*S159'
.param V49_part17='V49_part16+(-1.086105e+00)*S160+(-4.356940e-01)*S161+6.448340e-01*S162+(-1.119094e+00)*S163+(-9.571005e-01)*S164+(-1.568844e-02)*S165+(-6.062153e-01)*S166+2.106981e+00*S167+(-3.403745e-01)*S168+(-1.137357e+00)*S169'
.param V49_part18='V49_part17+1.996887e+00*S170+(-1.277303e-01)*S171+(-9.892942e-01)*S172+1.117923e+00*S173+(-8.450446e-01)*S174+(-1.245427e+00)*S175+(-1.148560e+00)*S176+(-7.308001e-01)*S177+(-1.169034e+00)*S178+(-1.695533e+00)*S179'
.param V49_part19='V49_part18+(-1.598104e-01)*S180+(-1.156163e+00)*S181+1.684387e+00*S182+(-3.368820e-02)*S183+(-9.214390e-01)*S184+5.883078e-01*S185+(-5.824754e-01)*S186+(-1.142601e+00)*S187+(-1.054211e+00)*S188+(-7.172579e-01)*S189'
.param V49_part20='V49_part19+5.072089e-01*S190+(-1.561654e+00)*S191+(-6.228769e-01)*S192+(-1.328535e+00)*S193+(-3.759971e-01)*S194+(-4.518601e-01)*S195+(-4.411416e-01)*S196+1.321526e+00*S197+(-1.492775e+00)*S198+(-3.062447e+00)*S199'
.param V49_part21='V49_part20+1.401253e+00*S200+(-1.390998e+00)*S201+(-2.045690e+00)*S202+3.111601e-01*S203+(-5.816201e-01)*S204+(-1.895228e+00)*S205+(-2.757914e+00)*S206+(-1.226200e+00)*S207+(-1.993917e+00)*S208+(-6.282733e-01)*S209'
.param V49_part22='V49_part21+(-2.450308e-02)*S210+1.742075e+00*S211+2.122766e+00*S212+4.979694e-01*S213+(-7.469912e-01)*S214+1.801238e+00*S215+(-3.407161e-01)*S216+4.683502e-01*S217+(-1.238087e+00)*S218+6.384764e-01*S219'
.param V49_part23='V49_part22+(-9.039915e-01)*S220+(-5.981798e-02)*S221+(-8.570958e-01)*S222+(-8.512449e-03)*S223+(-3.443305e-02)*S224+5.554962e-01*S225+(-3.813004e-01)*S226+(-1.735428e-01)*S227+(-4.449419e-01)*S228+(-5.593040e-01)*S229'
.param V49_part24='V49_part23+(-2.602163e-01)*S230+(-1.126533e-01)*S231+(-7.906529e-01)*S232+(-8.112739e-01)*S233+(-4.063542e-01)*S234+(-9.523565e-01)*S235+(-7.850456e-01)*S236+4.883296e-01*S237+(-1.379921e+00)*S238+(-9.787184e-01)*S239'
.param V49_part25='V49_part24+6.839873e-01*S240+(-2.705947e-01)*S241+(-4.560546e-01)*S242+6.757962e-02*S243+(-4.489188e-01)*S244+(-1.271068e+00)*S245+9.606432e-01*S246+(-8.946609e-01)*S247+(-1.137499e+00)*S248+(-2.822772e-01)*S249'
.param V49_part26='V49_part25+(-9.344538e-01)*S250+1.206978e+00*S251+(-3.547747e-01)*S252+(-1.030523e+00)*S253+(-2.274833e-01)*S254+7.448310e-01*S255+(-1.956938e+00)*S256+2.409026e+00*S257+(-1.128454e+00)*S258+(-1.759303e+00)*S259'
.param V49_part27='V49_part26+(-1.513624e-01)*S260+(-5.366718e-01)*S261+(-1.471637e+00)*S262+(-6.260615e-01)*S263+(-7.684137e-01)*S264+(-1.460537e+00)*S265+(-1.831101e+00)*S266+(-1.084376e+00)*S267+(-1.078272e+00)*S268+(-8.212963e-01)*S269'
.param V49_part28='V49_part27+1.744390e-03*S270+4.846476e-01*S271+2.604661e+00*S272+(-5.513131e-02)*S273+2.916379e-01*S274+(-4.782772e-01)*S275+8.305696e-02*S276+(-1.986630e-01)*S277+(-5.238103e-01)*S278+(-4.377040e-01)*S279'
.param V49_part29='V49_part28+(-3.511090e-01)*S280+(-4.227087e-01)*S281+(-2.292275e-01)*S282+(-7.600098e-01)*S283+(-2.812779e-01)*S284+2.185900e-01*S285+(-8.754937e-01)*S286+3.658520e+00*S287+4.670372e-01*S288+(-2.831065e-01)*S289'
.param V49_part30='V49_part29+2.802910e+00*S290+2.071224e-01*S291+(-4.287483e-01)*S292+(-2.277252e-01)*S293+1.843674e-01*S294+(-3.494768e-01)*S295+3.091988e+00*S296+(-3.296591e-01)*S297+(-4.773127e-01)*S298+2.329987e+00*S299'
.param V49_part31='V49_part30+(-5.138654e-01)*S300+(-9.843087e-01)*S301+(-6.275313e-01)*S302+(-1.597307e-01)*S303+(-7.813674e-01)*S304+1.202280e+00*S305+(-2.812755e-01)*S306+6.728544e-02*S307+1.262350e+00*S308+(-2.552338e-01)*S309'
.param V49='V49_part31+(-1.442409e+00)*S310+1.346083e+00*S311+(-6.840231e-01)*S312+(-1.381463e+00)*S313+6.368694e-02*S314'
.param V50_part1='2.779479e+01*S0+1.380351e+01*S1+(-2.150095e+01)*S2+5.678954e+00*S3+9.478957e+00*S4+1.475824e+01*S5+1.063973e+02*S6+9.407637e+01*S7+2.206360e+01*S8+6.106080e+00*S9'
.param V50_part2='V50_part1+4.406679e+01*S10+2.141826e+01*S11+5.813027e+00*S12+2.079515e+01*S13+2.065939e+02*S14+1.004352e+01*S15+1.312191e+01*S16+6.312576e+00*S17+5.703517e+02*S18+7.080541e+00*S19'
.param V50_part3='V50_part2+3.625404e+01*S20+2.644233e+01*S21+4.401716e+00*S22+5.636422e+01*S23+9.474480e+01*S24+(-8.265486e+00)*S25+1.627646e+01*S26+2.168123e+01*S27+4.973083e+01*S28+2.795395e+03*S29'
.param V50_part4='V50_part3+2.061509e+01*S30+5.465951e+00*S31+6.456164e+01*S32+7.284251e+00*S33+9.872179e+00*S34+3.934747e+01*S35+6.361661e+00*S36+1.219578e+01*S37+9.266568e+00*S38+4.770461e+00*S39'
.param V50_part5='V50_part4+9.740738e+00*S40+8.066127e+00*S41+5.074573e+00*S42+4.777100e+00*S43+1.488932e+01*S44+8.791420e+00*S45+1.256019e+01*S46+2.037319e+01*S47+8.414200e+00*S48+6.589735e+00*S49'
.param V50_part6='V50_part5+1.667949e+01*S50+1.048638e+03*S51+4.064411e+00*S52+6.052434e+00*S53+6.225373e+00*S54+7.031725e+00*S55+7.170784e+00*S56+6.739705e+00*S57+5.503814e+00*S58+4.752968e+00*S59'
.param V50_part7='V50_part6+7.715733e+00*S60+1.474227e+01*S61+6.870614e+00*S62+7.513155e+00*S63+1.002696e+01*S64+6.985504e+00*S65+5.710408e+00*S66+7.382971e+02*S67+8.096915e+00*S68+9.447736e+01*S69'
.param V50_part8='V50_part7+5.740526e+02*S70+1.208830e+01*S71+3.752185e+00*S72+5.729819e+00*S73+2.645349e+01*S74+1.583579e+01*S75+8.066932e+00*S76+1.055666e+01*S77+8.892649e+00*S78+1.118646e+01*S79'
.param V50_part9='V50_part8+7.436530e+00*S80+1.005918e+01*S81+7.314373e+00*S82+8.625014e+00*S83+1.848202e+01*S84+4.633837e+00*S85+(-7.342357e-01)*S86+6.771905e-01*S87+5.520409e+00*S88+1.215065e+01*S89'
.param V50_part10='V50_part9+1.578954e+01*S90+9.161322e+00*S91+6.012987e+00*S92+9.855537e+00*S93+9.370376e+00*S94+3.736877e+00*S95+9.269172e+01*S96+1.154365e+01*S97+6.552631e+00*S98+6.844262e+00*S99'
.param V50_part11='V50_part10+6.654928e+00*S100+6.168955e+00*S101+6.117892e+00*S102+5.760107e+00*S103+6.064219e+01*S104+1.003495e+01*S105+9.475787e+00*S106+6.408272e+00*S107+8.604982e+00*S108+7.220496e+00*S109'
.param V50_part12='V50_part11+5.783750e+00*S110+8.024152e+00*S111+6.580236e+00*S112+2.321136e+01*S113+2.889785e+01*S114+4.197294e+01*S115+4.751600e+01*S116+5.701150e+00*S117+5.485237e+00*S118+4.240136e+00*S119'
.param V50_part13='V50_part12+7.062020e+01*S120+7.320636e+01*S121+6.840459e+00*S122+8.317684e+00*S123+1.528645e+02*S124+3.239347e+01*S125+7.523491e+00*S126+6.479832e+00*S127+5.216333e+00*S128+6.257948e+00*S129'
.param V50_part14='V50_part13+4.123696e+01*S130+4.554822e+00*S131+7.198761e+00*S132+6.077808e+00*S133+4.033996e+00*S134+1.087554e+01*S135+9.433342e+00*S136+7.738855e+00*S137+8.494694e+00*S138+9.636824e+00*S139'
.param V50_part15='V50_part14+8.880349e+01*S140+1.427480e+01*S141+6.695182e+00*S142+1.059931e+01*S143+8.094173e+00*S144+8.501810e+00*S145+4.977973e+00*S146+6.382297e+00*S147+5.793070e+00*S148+4.284651e+00*S149'
.param V50_part16='V50_part15+1.209143e+01*S150+8.296205e+00*S151+8.839908e+03*S152+9.312196e+00*S153+1.967681e+01*S154+6.664927e+01*S155+3.399157e+01*S156+7.616588e+00*S157+7.861944e+01*S158+6.432462e+00*S159'
.param V50_part17='V50_part16+1.956604e+01*S160+7.942295e+00*S161+8.051718e+00*S162+6.330877e+00*S163+2.574111e+01*S164+7.935940e+00*S165+7.913117e+00*S166+5.258356e+00*S167+8.062616e+00*S168+6.885531e+00*S169'
.param V50_part18='V50_part17+4.859525e+00*S170+3.525796e+01*S171+5.958214e+01*S172+4.306221e+00*S173+7.980960e+00*S174+2.671087e+01*S175+6.966059e+00*S176+7.665990e+00*S177+4.474866e+01*S178+3.189703e+00*S179'
.param V50_part19='V50_part18+9.355858e+00*S180+7.414296e+00*S181+7.583387e+00*S182+4.968619e+00*S183+8.213406e+00*S184+6.739056e+00*S185+1.801657e+01*S186+1.017530e+01*S187+9.822454e+00*S188+8.864945e+00*S189'
.param V50_part20='V50_part19+8.451335e+00*S190+4.308827e+00*S191+6.987333e+00*S192+2.106549e+01*S193+7.833657e+00*S194+3.904586e+03*S195+2.867773e+01*S196+6.181074e+00*S197+1.733140e+01*S198+4.378961e+01*S199'
.param V50_part21='V50_part20+5.088972e+00*S200+1.000000e+04*S201+6.780665e+00*S202+5.207881e+00*S203+7.114282e+00*S204+5.093677e+00*S205+4.327547e+00*S206+6.350959e+00*S207+1.039647e+01*S208+1.109468e+01*S209'
.param V50_part22='V50_part21+9.354106e+00*S210+6.616919e+00*S211+1.082952e+01*S212+1.191541e+01*S213+2.106707e+01*S214+6.348821e+00*S215+1.512973e+01*S216+7.513619e+00*S217+8.040412e+00*S218+7.855682e+00*S219'
.param V50_part23='V50_part22+1.189487e+01*S220+6.092127e+00*S221+5.469248e+00*S222+6.324448e+00*S223+9.133023e+00*S224+2.007344e+01*S225+8.705339e+00*S226+4.918038e+00*S227+9.950398e+00*S228+7.273354e+00*S229'
.param V50_part24='V50_part23+4.453553e+00*S230+8.652442e+00*S231+6.388746e+01*S232+1.305875e+01*S233+1.260051e+01*S234+6.237558e+00*S235+1.418719e+01*S236+1.716274e+01*S237+4.528873e+00*S238+1.363662e+01*S239'
.param V50_part25='V50_part24+6.965932e+02*S240+2.605910e+01*S241+1.455166e+01*S242+1.000000e+04*S243+3.714600e+02*S244+1.547243e+03*S245+1.198576e+01*S246+6.375107e+00*S247+5.190530e+00*S248+9.509773e+00*S249'
.param V50_part26='V50_part25+7.100768e+00*S250+5.017089e+00*S251+1.740096e+01*S252+6.566112e+00*S253+5.606289e+00*S254+(-3.123067e+00)*S255+2.600637e+01*S256+6.390499e+00*S257+1.636061e+01*S258+6.755371e+00*S259'
.param V50_part27='V50_part26+1.240715e+01*S260+1.145544e+01*S261+2.699277e+01*S262+6.239432e+00*S263+2.717323e+01*S264+6.930821e+00*S265+1.881481e+02*S266+1.160191e+01*S267+2.643670e+01*S268+8.134572e+02*S269'
.param V50_part28='V50_part27+1.122661e+01*S270+1.264098e+01*S271+5.639259e+00*S272+1.247505e+02*S273+2.675333e+01*S274+6.074794e+00*S275+2.319564e+01*S276+3.450977e+01*S277+6.208078e+00*S278+6.858393e+00*S279'
.param V50_part29='V50_part28+4.973271e+02*S280+5.544549e+00*S281+1.471970e+01*S282+1.157366e+02*S283+1.419972e+01*S284+7.008376e+00*S285+6.167035e+00*S286+1.075961e+01*S287+1.308898e+01*S288+1.428198e+01*S289'
.param V50_part30='V50_part29+9.538101e+00*S290+1.007925e+01*S291+5.583323e+00*S292+6.245747e+00*S293+1.554049e+01*S294+5.633137e+00*S295+3.929692e+00*S296+1.477526e+01*S297+9.242722e+00*S298+3.708994e+00*S299'
.param V50_part31='V50_part30+1.869899e+02*S300+9.027460e+01*S301+8.264648e+00*S302+2.130029e+02*S303+5.620182e+01*S304+5.229696e+00*S305+(-2.284666e+02)*S306+5.322779e+00*S307+4.765786e+00*S308+7.074229e+00*S309'
.param V50='V50_part31+4.814540e+00*S310+4.142974e+00*S311+8.612684e+00*S312+4.360820e+00*S313+9.977315e+00*S314'
.param V51_part1='(-1.439038e+01)*S0+(-1.445259e+01)*S1+1.521362e+03*S2+3.468617e+00*S3+1.715938e+00*S4+(-3.901143e-01)*S5+8.950008e+00*S6+6.095594e+00*S7+(-5.234337e+00)*S8+(-1.451800e+00)*S9'
.param V51_part2='V51_part1+(-2.697341e+01)*S10+(-6.596495e+00)*S11+(-1.337883e+00)*S12+(-5.088673e+00)*S13+2.176944e+00*S14+(-2.653450e+00)*S15+(-6.299687e+00)*S16+(-5.063696e+00)*S17+4.326465e+02*S18+(-5.324119e+00)*S19'
.param V51_part3='V51_part2+(-1.284788e+01)*S20+1.687298e+01*S21+(-1.456790e+00)*S22+(-1.015320e+01)*S23+(-1.023998e+02)*S24+(-1.783845e+01)*S25+(-4.547803e+00)*S26+(-1.225397e+01)*S27+(-1.711429e+01)*S28+1.731291e+01*S29'
.param V51_part4='V51_part3+(-2.947792e+01)*S30+1.922697e+01*S31+(-4.921854e+01)*S32+(-3.345787e+00)*S33+(-7.680860e+00)*S34+(-3.509068e+01)*S35+(-2.078610e+00)*S36+(-9.524383e-01)*S37+(-5.175871e+00)*S38+(-8.076036e-01)*S39'
.param V51_part5='V51_part4+(-2.442629e+00)*S40+(-2.458451e+00)*S41+(-3.221474e-01)*S42+(-1.252296e+00)*S43+(-3.097512e+00)*S44+(-2.762901e+00)*S45+(-1.517007e+01)*S46+(-8.223883e+00)*S47+(-4.950317e+00)*S48+(-3.596269e+00)*S49'
.param V51_part6='V51_part5+(-1.256714e+00)*S50+(-1.025803e+03)*S51+(-2.241049e+00)*S52+(-2.523112e+00)*S53+(-1.164373e+00)*S54+(-1.709719e+00)*S55+(-2.490393e+00)*S56+(-2.342766e+00)*S57+(-2.093760e+00)*S58+(-1.415153e+00)*S59'
.param V51_part7='V51_part6+(-5.005272e+00)*S60+4.727164e+00*S61+(-1.599209e+00)*S62+(-4.289862e+00)*S63+(-3.020761e+00)*S64+(-2.191148e+00)*S65+(-2.897419e+00)*S66+6.285205e+00*S67+(-3.300952e+00)*S68+(-2.500421e+01)*S69'
.param V51_part8='V51_part7+(-2.121931e+02)*S70+(-3.910750e+00)*S71+(-5.444020e-01)*S72+(-1.542001e+00)*S73+(-2.462676e+00)*S74+(-1.178210e+01)*S75+(-1.456332e+00)*S76+(-5.029871e+00)*S77+(-6.645807e+00)*S78+(-7.535356e+00)*S79'
.param V51_part9='V51_part8+(-2.594309e+00)*S80+2.548863e+00*S81+(-3.988513e+00)*S82+(-3.962283e+00)*S83+(-2.548801e+00)*S84+1.908867e-01*S85+1.345007e+01*S86+8.716121e+00*S87+6.942191e-01*S88+(-3.822952e+00)*S89'
.param V51_part10='V51_part9+1.217823e-01*S90+(-2.435098e+00)*S91+(-1.593062e+00)*S92+(-5.459197e+00)*S93+(-2.413382e+00)*S94+(-1.314505e-01)*S95+(-2.693037e+01)*S96+(-4.495209e+00)*S97+(-2.346719e+00)*S98+(-3.476858e+00)*S99'
.param V51_part11='V51_part10+(-3.511497e+00)*S100+(-3.351426e+00)*S101+(-2.709547e+00)*S102+(-2.490057e+00)*S103+(-1.191243e+01)*S104+(-9.364883e+00)*S105+(-3.868721e+00)*S106+(-5.689295e-01)*S107+(-5.761304e+00)*S108+(-3.353118e+00)*S109'
.param V51_part12='V51_part11+(-2.450082e+00)*S110+(-4.311108e+00)*S111+(-2.923270e+00)*S112+(-7.409963e+00)*S113+2.017966e+01*S114+(-2.223034e+01)*S115+(-2.236350e+01)*S116+(-2.523386e+00)*S117+(-2.361780e+00)*S118+(-1.229346e+00)*S119'
.param V51_part13='V51_part12+6.902000e+02*S120+1.186136e+01*S121+(-3.149045e+00)*S122+(-5.006281e+00)*S123+(-1.795454e+02)*S124+(-3.827599e+00)*S125+(-4.041995e+00)*S126+(-2.734093e+00)*S127+(-1.686901e+00)*S128+(-2.896688e+00)*S129'
.param V51_part14='V51_part13+(-2.552335e+01)*S130+(-1.369462e+00)*S131+(-3.019717e+00)*S132+(-1.739228e+00)*S133+(-1.057924e+00)*S134+(-6.684285e+00)*S135+(-3.852973e+00)*S136+(-3.383302e+00)*S137+(-2.702376e+00)*S138+(-5.202937e+00)*S139'
.param V51_part15='V51_part14+8.940306e+00*S140+(-5.931947e+00)*S141+(-2.800429e+00)*S142+(-6.349242e+00)*S143+(-1.918252e+00)*S144+(-2.411348e+00)*S145+(-1.536712e+00)*S146+(-6.751504e-01)*S147+(-7.885960e-01)*S148+(-1.357529e+00)*S149'
.param V51_part16='V51_part15+(-8.781858e+00)*S150+(-3.816501e+00)*S151+(-2.046101e+01)*S152+(-6.761174e+00)*S153+1.620202e+01*S154+(-4.768437e+00)*S155+(-3.746351e+01)*S156+(-5.138547e+00)*S157+(-5.724907e+01)*S158+(-1.821051e+00)*S159'
.param V51_part17='V51_part16+(-1.117408e+01)*S160+(-3.000583e+00)*S161+(-2.997998e+00)*S162+(-2.574941e+00)*S163+(-7.702739e+00)*S164+2.389986e+01*S165+(-2.535188e+00)*S166+(-1.233821e+00)*S167+(-4.921016e+00)*S168+(-3.232302e+00)*S169'
.param V51_part18='V51_part17+(-1.329197e+00)*S170+(-1.088368e+01)*S171+(-7.493059e+01)*S172+(-2.581970e-01)*S173+(-5.065860e+00)*S174+(-2.227853e+01)*S175+(-2.308699e+00)*S176+(-3.142452e+00)*S177+(-2.156371e+01)*S178+(-4.456318e-01)*S179'
.param V51_part19='V51_part18+(-5.295724e+00)*S180+(-2.041716e+00)*S181+(-2.100186e+00)*S182+2.281004e+01*S183+(-2.598008e+00)*S184+(-2.234543e+00)*S185+(-5.195415e+00)*S186+(-5.834338e+00)*S187+(-3.798910e+00)*S188+(-4.014570e+00)*S189'
.param V51_part20='V51_part19+(-5.275393e+00)*S190+(-5.126501e-01)*S191+(-2.462101e+00)*S192+(-1.241965e+01)*S193+(-3.258187e+00)*S194+(-5.316354e+00)*S195+(-3.405222e+01)*S196+(-2.480527e+00)*S197+(-4.769786e+00)*S198+(-2.650661e-01)*S199'
.param V51_part21='V51_part20+(-1.647031e+00)*S200+(-2.049418e+01)*S201+(-2.761652e+00)*S202+(-1.543517e+00)*S203+(-3.159176e+00)*S204+(-1.576585e+00)*S205+(-7.884789e-01)*S206+(-1.623319e+00)*S207+(-4.233218e+00)*S208+(-3.765124e+00)*S209'
.param V51_part22='V51_part21+(-5.534952e+00)*S210+(-1.995857e+00)*S211+(-3.306467e+00)*S212+(-5.027778e+00)*S213+1.023871e+01*S214+(-3.959302e+00)*S215+(-7.528435e+00)*S216+(-1.937945e+00)*S217+(-5.573313e+00)*S218+(-3.098396e+00)*S219'
.param V51_part23='V51_part22+(-7.504759e+00)*S220+2.792041e-02*S221+(-2.162100e+00)*S222+(-2.933730e-02)*S223+3.757958e-02*S224+(-1.616515e+01)*S225+(-4.869428e+00)*S226+(-1.797268e+00)*S227+(-7.375308e+00)*S228+(-5.413478e-01)*S229'
.param V51_part24='V51_part23+(-1.284141e+00)*S230+(-3.631803e+00)*S231+(-6.974896e+01)*S232+(-4.232476e+00)*S233+(-4.447389e+00)*S234+(-2.750565e+00)*S235+(-1.193358e+01)*S236+(-7.156717e+00)*S237+(-1.619975e+00)*S238+(-5.705243e+00)*S239'
.param V51_part25='V51_part24+(-4.639364e+02)*S240+(-4.367889e+01)*S241+(-5.380967e+00)*S242+(-2.272673e+03)*S243+(-4.304002e+01)*S244+(-6.601232e+02)*S245+(-4.970923e+00)*S246+(-2.397008e+00)*S247+(-2.238111e+00)*S248+(-4.824078e+00)*S249'
.param V51_part26='V51_part25+(-3.205565e+00)*S250+(-1.642818e+00)*S251+(-8.837643e+00)*S252+(-2.304933e+00)*S253+(-3.670258e-01)*S254+5.703206e+01*S255+9.585263e+00*S256+(-1.257527e+00)*S257+(-1.303326e+01)*S258+(-1.987006e+00)*S259'
.param V51_part27='V51_part26+(-4.660235e+00)*S260+(-6.981861e+00)*S261+(-2.386219e+01)*S262+(-1.288852e+00)*S263+(-1.047561e+01)*S264+(-1.936262e+00)*S265+(-6.512818e+01)*S266+(-4.553849e+00)*S267+(-9.689880e+00)*S268+(-3.801602e+02)*S269'
.param V51_part28='V51_part27+(-1.471805e+01)*S270+(-6.501942e+00)*S271+(-5.667464e-01)*S272+1.053617e+01*S273+(-9.915825e+00)*S274+(-1.644213e+00)*S275+(-7.490144e+00)*S276+(-1.568785e+01)*S277+(-1.243160e+00)*S278+(-3.539663e+00)*S279'
.param V51_part29='V51_part28+9.643404e+00*S280+(-8.995635e-01)*S281+(-9.538994e+00)*S282+(-8.349723e+01)*S283+(-7.805313e+00)*S284+(-4.907583e+00)*S285+(-8.570465e-01)*S286+(-2.079766e+00)*S287+(-3.216705e+00)*S288+3.898806e-01*S289'
.param V51_part30='V51_part29+(-1.997423e+00)*S290+(-5.685859e+00)*S291+(-2.297694e+00)*S292+(-3.169363e+00)*S293+(-1.031797e+01)*S294+(-1.981114e+00)*S295+(-1.603888e+00)*S296+(-9.468940e+00)*S297+(-3.525455e+00)*S298+(-1.264660e+00)*S299'
.param V51_part31='V51_part30+(-2.749698e+02)*S300+(-7.784378e+01)*S301+(-1.749585e+00)*S302+(-4.661999e+02)*S303+(-3.801383e+01)*S304+(-7.278750e-01)*S305+(-1.559353e+02)*S306+(-2.300808e+00)*S307+(-7.406084e-01)*S308+(-2.681138e+00)*S309'
.param V51='V51_part31+(-1.627358e+00)*S310+(-2.128589e-01)*S311+(-3.341862e+00)*S312+(-1.211410e+00)*S313+(-1.282317e+00)*S314'
.param V52_part1='(-2.858484e+01)*S0+(-4.927556e+00)*S1+(-6.595217e+01)*S2+(-3.051913e+00)*S3+(-5.226629e+00)*S4+(-7.283383e+00)*S5+8.272585e+01*S6+6.800728e+01*S7+(-8.937191e+00)*S8+1.135796e+00*S9'
.param V52_part2='V52_part1+(-9.055336e+00)*S10+(-7.229266e+00)*S11+1.222596e+00*S12+(-8.581433e+00)*S13+(-7.616040e+00)*S14+(-1.204522e+01)*S15+7.506736e+00*S16+3.256811e-01*S17+9.661440e+01*S18+1.966952e+00*S19'
.param V52_part3='V52_part2+8.729013e+00*S20+1.217113e+02*S21+1.664779e+00*S22+(-2.752230e+01)*S23+1.906415e+02*S24+2.161769e+02*S25+(-6.088192e+00)*S26+1.917332e-01*S27+(-1.945263e-01)*S28+3.786524e+01*S29'
.param V52_part4='V52_part3+(-2.102469e+00)*S30+8.754556e-01*S31+2.872710e+00*S32+(-2.307849e+00)*S33+(-2.650638e+00)*S34+4.963069e-01*S35+(-2.365084e+00)*S36+(-5.435898e+00)*S37+2.772738e-01*S38+(-1.476197e+00)*S39'
.param V52_part5='V52_part4+(-3.393168e+00)*S40+(-3.011420e+00)*S41+(-2.705530e+00)*S42+1.285037e-01*S43+(-7.665196e+00)*S44+(-5.570439e+00)*S45+(-4.849632e-01)*S46+(-1.419666e+00)*S47+(-2.442373e+00)*S48+2.926888e+00*S49'
.param V52_part6='V52_part5+(-8.215182e+00)*S50+(-5.461605e+02)*S51+(-1.134758e+00)*S52+(-1.462405e+00)*S53+(-2.490999e+00)*S54+(-2.708656e+00)*S55+(-2.314312e+00)*S56+(-2.447832e+00)*S57+(-9.969096e-01)*S58+(-9.732734e-01)*S59'
.param V52_part7='V52_part6+(-1.765246e+00)*S60+(-1.306332e+01)*S61+(-2.551440e+00)*S62+(-2.519702e+00)*S63+(-6.182599e+00)*S64+(-2.333062e+00)*S65+(-1.390601e+00)*S66+(-7.271509e+02)*S67+(-2.601266e+00)*S68+(-9.974054e+01)*S69'
.param V52_part8='V52_part7+(-3.161756e+02)*S70+(-4.530475e+00)*S71+(-2.559468e+00)*S72+(-1.925351e+00)*S73+1.560220e+00*S74+(-1.757523e+01)*S75+(-5.973676e+00)*S76+(-5.163924e+00)*S77+(-6.176961e+00)*S78+(-5.272761e+00)*S79'
.param V52_part9='V52_part8+(-2.924885e+00)*S80+(-1.445716e+01)*S81+(-1.836146e+00)*S82+(-1.335441e+00)*S83+2.413966e+01*S84+(-3.591314e-01)*S85+3.937531e+00*S86+5.826949e+01*S87+(-1.331455e+00)*S88+(-3.863490e+00)*S89'
.param V52_part10='V52_part9+(-1.796010e+01)*S90+(-5.892303e+00)*S91+(-1.744115e+00)*S92+(-6.784756e+00)*S93+(-6.139125e+00)*S94+(-5.131121e-01)*S95+2.348127e+01*S96+(-6.222830e+00)*S97+(-1.965757e+00)*S98+(-2.128761e+00)*S99'
.param V52_part11='V52_part10+(-1.086319e+00)*S100+(-5.171733e-01)*S101+(-1.769203e+00)*S102+(-1.137776e+00)*S103+(-3.880902e+01)*S104+(-6.013339e+00)*S105+(-6.384015e+00)*S106+(-2.012680e+00)*S107+(-5.100737e+00)*S108+(-2.860800e+00)*S109'
.param V52_part12='V52_part11+(-1.561613e+00)*S110+(-4.000078e+00)*S111+(-2.366157e+00)*S112+(-1.186072e+01)*S113+(-1.238770e+01)*S114+(-1.910276e+01)*S115+(-2.087322e+01)*S116+(-1.474972e+00)*S117+(-1.364562e+00)*S118+(-9.192681e-01)*S119'
.param V52_part13='V52_part12+8.859030e+01*S120+(-7.065576e+01)*S121+(-2.440245e+00)*S122+(-4.949545e+00)*S123+(-3.983595e+00)*S124+5.318028e+00*S125+(-3.926856e+00)*S126+(-2.552587e+00)*S127+(-1.545737e+00)*S128+(-2.449050e+00)*S129'
.param V52_part14='V52_part13+(-7.773175e-01)*S130+(-1.159730e+00)*S131+5.200118e-01*S132+3.609183e-02*S133+(-9.178944e-01)*S134+(-8.529834e+00)*S135+(-5.959558e+00)*S136+(-2.507422e+00)*S137+(-4.180274e+00)*S138+(-3.660531e+00)*S139'
.param V52_part15='V52_part14+(-6.028024e+01)*S140+(-8.140636e+00)*S141+(-2.303777e+00)*S142+(-4.551431e-01)*S143+(-4.305204e+00)*S144+(-3.843891e+00)*S145+(-8.953232e-01)*S146+(-3.181094e+00)*S147+(-2.014197e+00)*S148+(-8.226865e-01)*S149'
.param V52_part16='V52_part15+(-8.685574e+00)*S150+(-5.064952e+00)*S151+6.462197e+01*S152+(-4.512289e+00)*S153+(-8.228351e+00)*S154+(-2.783669e+01)*S155+3.629865e+00*S156+(-1.934684e+00)*S157+(-1.024067e+01)*S158+(-7.794113e-01)*S159'
.param V52_part17='V52_part16+(-5.076560e+00)*S160+(-2.460647e+00)*S161+(-3.571675e+00)*S162+(-1.855658e+00)*S163+1.989459e+01*S164+1.613528e+01*S165+(-4.694368e+00)*S166+(-2.046559e+00)*S167+(-5.002777e+00)*S168+(-3.235544e+00)*S169'
.param V52_part18='V52_part17+(-1.706435e+00)*S170+(-1.401824e+01)*S171+8.706163e+00*S172+(-1.360197e+00)*S173+2.136403e+00*S174+9.231917e-01*S175+(-2.349212e+00)*S176+3.241964e+00*S177+2.177790e+01*S178+(-8.507242e-01)*S179'
.param V52_part19='V52_part18+(-7.523972e+00)*S180+(-4.791290e+00)*S181+(-3.110866e+00)*S182+1.365234e+01*S183+(-4.762902e+00)*S184+(-2.782137e+00)*S185+(-2.009280e+01)*S186+(-2.738207e+00)*S187+(-3.532260e+00)*S188+(-6.203188e+00)*S189'
.param V52_part20='V52_part19+(-2.775867e-01)*S190+(-1.403166e+00)*S191+1.621283e+00*S192+1.018239e+00*S193+(-2.514545e+00)*S194+(-1.934747e+01)*S195+(-8.058226e+00)*S196+(-2.335533e+00)*S197+(-9.770762e+00)*S198+(-3.592464e+01)*S199'
.param V52_part21='V52_part20+(-1.660748e+00)*S200+(-1.335361e+01)*S201+(-2.999881e+00)*S202+(-1.679843e+00)*S203+(-2.463570e+00)*S204+(-2.169219e+00)*S205+9.715450e-01*S206+(-7.517128e-01)*S207+1.861126e+00*S208+(-2.724048e+00)*S209'
.param V52_part22='V52_part21+(-7.660181e+00)*S210+(-4.060173e+00)*S211+(-5.793688e+00)*S212+(-4.907465e+00)*S213+(-2.130395e+01)*S214+(-1.323316e+00)*S215+(-9.259304e-01)*S216+(-4.051854e+00)*S217+(-5.369712e-01)*S218+(-3.823770e+00)*S219'
.param V52_part23='V52_part22+8.497815e+00*S220+(-1.509088e+00)*S221+3.874221e+00*S222+(-1.020005e+00)*S223+(-1.019013e+00)*S224+(-4.946850e+00)*S225+(-4.621874e+00)*S226+(-2.035344e+00)*S227+2.622208e+00*S228+(-5.185301e+00)*S229'
.param V52_part24='V52_part23+(-1.816531e+00)*S230+(-4.883213e+00)*S231+2.275066e+01*S232+(-5.865686e+00)*S233+(-1.336990e+00)*S234+1.596749e+00*S235+7.744933e+00*S236+2.671260e+00*S237+7.928650e-01*S238+1.587261e+00*S239'
.param V52_part25='V52_part24+(-3.807446e+02)*S240+(-2.693845e+00)*S241+(-8.073302e+00)*S242+7.645800e+02*S243+(-3.380742e+01)*S244+9.877311e+01*S245+(-1.132737e+01)*S246+(-5.008819e-01)*S247+(-1.199285e+00)*S248+1.304118e+00*S249'
.param V52_part26='V52_part25+1.211809e+00*S250+(-9.147122e-01)*S251+(-9.289737e+00)*S252+(-2.194087e+00)*S253+(-3.025108e+00)*S254+3.790804e+01*S255+2.107843e+00*S256+(-3.175203e+00)*S257+(-8.963813e+00)*S258+(-3.758517e+00)*S259'
.param V52_part27='V52_part26+(-6.170322e+00)*S260+8.667687e-02*S261+(-3.624644e+00)*S262+(-2.349430e+00)*S263+(-2.647566e+01)*S264+(-6.367398e-01)*S265+(-1.090561e+02)*S266+(-1.001047e+01)*S267+(-1.496481e+01)*S268+(-2.543647e+02)*S269'
.param V52_part28='V52_part27+1.081928e+00*S270+(-7.916287e+00)*S271+(-2.293918e+00)*S272+(-2.078027e+02)*S273+(-1.965235e+01)*S274+(-3.379330e+00)*S275+(-2.930264e+01)*S276+(-1.776652e+01)*S277+(-3.483323e+00)*S278+4.107157e+00*S279'
.param V52_part29='V52_part28+(-5.778882e+02)*S280+(-2.933223e+00)*S281+9.555239e+00*S282+1.291579e+01*S283+7.590727e+00*S284+(-5.548796e+00)*S285+(-3.263055e+00)*S286+(-6.752452e+00)*S287+(-1.400764e+01)*S288+(-1.276094e+01)*S289'
.param V52_part30='V52_part29+(-5.665361e+00)*S290+1.303121e+00*S291+(-1.422402e+00)*S292+(-9.525233e-01)*S293+(-3.670440e+00)*S294+(-1.669471e+00)*S295+(-1.552718e-02)*S296+2.130154e+00*S297+(-3.832213e+00)*S298+9.987982e-02*S299'
.param V52_part31='V52_part30+1.835731e+02*S300+6.080141e+00*S301+(-4.187138e+00)*S302+4.251210e+02*S303+6.707281e+01*S304+(-1.756830e+00)*S305+1.963865e+03*S306+(-8.836162e-01)*S307+(-1.803518e+00)*S308+(-1.470198e+00)*S309'
.param V52='V52_part31+(-3.797447e-01)*S310+(-1.496335e+00)*S311+(-5.484876e+00)*S312+(-2.994765e-01)*S313+(-5.176322e+00)*S314'
.param V53_part1='3.237748e-01*S0+1.547090e+00*S1+(-1.000000e+04)*S2+(-1.698440e+00)*S3+(-3.379633e+00)*S4+(-5.537630e+00)*S5+1.201148e+02*S6+1.163701e+02*S7+(-4.205507e-01)*S8+1.827168e-01*S9'
.param V53_part2='V53_part1+1.340023e+00*S10+5.912681e-02*S11+1.385663e-01*S12+7.215628e-01*S13+1.293908e+01*S14+(-4.373126e+00)*S15+9.647124e+00*S16+1.660165e+00*S17+7.780214e+01*S18+2.571003e+00*S19'
.param V53_part3='V53_part2+2.929165e+01*S20+(-1.000000e+04)*S21+1.677169e+00*S22+(-8.196635e+01)*S23+(-3.361116e+02)*S24+(-1.667479e+03)*S25+(-8.432879e-02)*S26+4.831699e-01*S27+(-1.130799e+03)*S28+2.819951e+03*S29'
.param V53_part4='V53_part3+2.515135e-02*S30+(-8.216544e+00)*S31+4.005085e+01*S32+2.379044e-02*S33+3.469001e-01*S34+9.997811e+00*S35+7.551795e-01*S36+5.097422e+00*S37+2.096165e+00*S38+4.461539e-01*S39'
.param V53_part5='V53_part4+2.090433e+00*S40+(-5.932572e-01)*S41+1.585720e+00*S42+1.524118e+00*S43+(-2.515096e+00)*S44+1.400399e+00*S45+1.035753e+00*S46+9.027682e+00*S47+7.151816e-01*S48+(-8.406878e-01)*S49'
.param V53_part6='V53_part5+6.294370e-01*S50+(-1.928258e-01)*S51+6.688570e-01*S52+4.201897e-01*S53+1.691413e+00*S54+1.203188e+00*S55+2.919698e-01*S56+2.276928e-01*S57+7.580733e-02*S58+3.536320e-01*S59'
.param V53_part7='V53_part6+(-9.513794e-01)*S60+(-1.132356e+00)*S61+2.479255e-01*S62+8.688767e-01*S63+6.806856e-01*S64+3.265594e-01*S65+4.318517e-01*S66+(-1.000000e+04)*S67+(-5.950868e-02)*S68+(-3.762101e+01)*S69'
.param V53_part8='V53_part7+(-4.957288e+03)*S70+1.001936e+00*S71+4.631191e-01*S72+7.778734e-02*S73+1.941480e+01*S74+(-2.106003e+00)*S75+(-1.268332e+00)*S76+(-3.257799e-01)*S77+(-6.372965e-01)*S78+4.892121e-01*S79'
.param V53_part9='V53_part8+2.415086e-01*S80+(-4.413214e+00)*S81+6.632197e-01*S82+(-9.113813e-01)*S83+(-1.108636e+02)*S84+(-1.424124e+00)*S85+(-8.787096e+00)*S86+(-2.678550e+01)*S87+(-8.848744e-01)*S88+6.195313e-01*S89'
.param V53_part10='V53_part9+1.902565e+00*S90+4.353650e-01*S91+4.640571e-01*S92+(-3.664042e-02)*S93+2.028211e-01*S94+6.166055e-01*S95+4.115703e+01*S96+(-3.124773e+00)*S97+(-8.081133e-01)*S98+7.756418e-02*S99'
.param V53_part11='V53_part10+7.631452e-02*S100+(-4.101250e-01)*S101+1.386982e-01*S102+8.137074e-02*S103+(-3.643777e+01)*S104+(-3.338938e-02)*S105+2.813186e-02*S106+5.412571e-01*S107+3.590486e-01*S108+1.876135e-01*S109'
.param V53_part12='V53_part11+2.379827e-01*S110+6.332031e-01*S111+2.269418e-01*S112+(-8.842696e+00)*S113+1.832864e+00*S114+(-3.633886e+01)*S115+(-6.060789e+00)*S116+3.321166e-01*S117+1.756037e-02*S118+1.997804e-01*S119'
.param V53_part13='V53_part12+(-2.487577e+01)*S120+(-6.425247e+00)*S121+(-5.791162e-03)*S122+9.227667e-02*S123+3.539266e+01*S124+2.596039e+01*S125+1.198236e-01*S126+7.469311e-02*S127+2.602914e-02*S128+1.825953e-01*S129'
.param V53_part14='V53_part13+(-9.020105e+02)*S130+5.081421e-02*S131+8.577786e-01*S132+7.472966e-01*S133+1.418275e-01*S134+(-2.954400e-01)*S135+4.401544e-01*S136+1.100212e+00*S137+2.888184e+00*S138+1.596770e+00*S139'
.param V53_part15='V53_part14+(-1.256392e+03)*S140+2.082661e+00*S141+5.965917e-01*S142+2.242924e+00*S143+8.197072e-01*S144+6.120406e-01*S145+7.327335e-01*S146+1.645280e+00*S147+9.061625e-01*S148+2.066608e-01*S149'
.param V53_part16='V53_part15+(-2.052399e-01)*S150+(-1.320895e-01)*S151+8.854677e+03*S152+(-1.636992e-01)*S153+(-5.139751e+02)*S154+(-7.916528e+02)*S155+2.570709e+00*S156+(-6.309064e-02)*S157+(-7.158926e+03)*S158+5.737130e-01*S159'
.param V53_part17='V53_part16+(-1.233218e+01)*S160+(-1.505876e+00)*S161+7.513890e-02*S162+(-7.284207e-01)*S163+1.844501e+01*S164+(-1.000000e+04)*S165+6.123293e-02*S166+2.482034e-01*S167+2.242363e-01*S168+5.015773e-02*S169'
.param V53_part18='V53_part17+1.784368e-01*S170+1.538852e+01*S171+(-1.427437e+00)*S172+3.409078e-01*S173+6.428474e-01*S174+2.233242e+00*S175+(-9.777878e-01)*S176+1.812072e+00*S177+2.041017e+01*S178+1.006512e-01*S179'
.param V53_part19='V53_part18+3.337938e-02*S180+(-7.858160e-01)*S181+3.536671e-02*S182+(-1.871783e+03)*S183+(-4.331182e-02)*S184+2.582655e-02*S185+(-3.172375e+00)*S186+(-2.193214e+00)*S187+(-1.667635e+00)*S188+(-1.032083e+00)*S189'
.param V53_part20='V53_part19+(-3.663090e-01)*S190+2.085314e-01*S191+(-4.049229e-01)*S192+2.950454e+00*S193+(-5.140464e-01)*S194+3.879057e+03*S195+3.975487e+00*S196+3.006860e-01*S197+4.611937e+00*S198+(-7.034111e-01)*S199'
.param V53_part21='V53_part20+2.419060e-01*S200+9.967607e+03*S201+3.150622e-01*S202+2.268282e-01*S203+1.029585e+00*S204+1.397725e-01*S205+9.336575e-01*S206+6.344058e-01*S207+2.796704e+00*S208+3.146442e-01*S209'
.param V53_part22='V53_part21+(-2.606722e-01)*S210+8.204867e-02*S211+(-1.507606e+00)*S212+2.174660e+00*S213+(-2.204925e+00)*S214+5.924794e-02*S215+1.285200e+00*S216+5.290455e-01*S217+5.930562e-01*S218+1.054121e+00*S219'
.param V53_part23='V53_part22+2.811108e+00*S220+7.482414e-01*S221+7.696754e-01*S222+1.680641e+00*S223+1.571366e+00*S224+(-1.811488e+01)*S225+(-1.375842e+00)*S226+3.609240e-02*S227+1.377099e+00*S228+8.107579e-03*S229'
.param V53_part24='V53_part23+7.475071e-02*S230+7.894452e-01*S231+2.810659e+00*S232+(-3.445018e+00)*S233+3.460669e+00*S234+4.791497e-01*S235+2.204704e+00*S236+(-1.014019e+00)*S237+2.314986e-01*S238+3.706816e+00*S239'
.param V53_part25='V53_part24+(-1.000000e+04)*S240+(-2.688896e+00)*S241+(-3.705029e+00)*S242+8.986444e+03*S243+2.209140e+02*S244+1.231727e+03*S245+(-1.177244e+00)*S246+6.223884e-01*S247+4.041603e-01*S248+4.491363e-01*S249'
.param V53_part26='V53_part25+5.965510e-01*S250+(-3.860962e-02)*S251+(-4.127957e+00)*S252+2.339082e-01*S253+(-1.240129e-01)*S254+(-1.000000e+04)*S255+(-2.952711e+03)*S256+(-2.795202e-01)*S257+4.160959e-01*S258+(-1.901132e-01)*S259'
.param V53_part27='V53_part26+(-1.979856e+00)*S260+8.537334e-01*S261+(-1.407902e+00)*S262+1.268081e-01*S263+(-9.437959e-02)*S264+1.017743e+00*S265+(-8.843097e+03)*S266+(-1.676150e+00)*S267+(-1.059000e+01)*S268+(-7.429318e+02)*S269'
.param V53_part28='V53_part27+4.048177e-01*S270+(-4.589237e+00)*S271+3.644324e-01*S272+(-4.895343e+01)*S273+(-8.211976e+00)*S274+(-2.706920e-01)*S275+(-8.061719e+00)*S276+(-2.006644e+01)*S277+(-3.697007e-01)*S278+8.471230e-01*S279'
.param V53_part29='V53_part28+(-3.598595e+02)*S280+(-2.983772e-01)*S281+(-2.642775e+00)*S282+1.438696e+01*S283+4.850005e+00*S284+3.220219e-01*S285+1.811997e-01*S286+(-1.569837e+00)*S287+7.133530e-01*S288+(-1.518074e+00)*S289'
.param V53_part30='V53_part29+(-1.249015e+00)*S290+7.329576e-01*S291+3.262902e-01*S292+(-1.576472e-02)*S293+(-2.181958e+00)*S294+2.428251e-01*S295+(-1.634983e-02)*S296+(-5.213112e-01)*S297+(-2.366812e-01)*S298+6.076140e-02*S299'
.param V53_part31='V53_part30+9.645519e+01*S300+(-1.000000e+04)*S301+(-1.366058e+00)*S302+3.640334e+01*S303+4.182560e+01*S304+3.254477e-01*S305+3.864391e+01*S306+4.435956e-01*S307+(-5.229575e-03)*S308+9.498722e-01*S309'
.param V53='V53_part31+4.429604e-01*S310+4.816427e-03*S311+(-1.584072e+00)*S312+8.635828e-02*S313+(-1.037354e-02)*S314'
.param V54_part1='(-3.120139e-01)*S0+4.287601e-02*S1+1.068202e+02*S2+2.410141e-01*S3+(-8.663269e-02)*S4+(-1.512044e-01)*S5+(-7.497774e-02)*S6+2.086132e-02*S7+8.252694e-02*S8+(-1.299389e-01)*S9'
.param V54_part2='V54_part1+(-1.178303e-01)*S10+(-3.379151e-02)*S11+(-1.290764e-01)*S12+(-4.212477e-03)*S13+(-8.921905e-01)*S14+4.806125e-02*S15+3.296728e-02*S16+4.688164e-03*S17+7.764861e-01*S18+(-1.281575e-02)*S19'
.param V54_part3='V54_part2+(-1.602217e-02)*S20+(-1.006098e+00)*S21+(-1.704588e-03)*S22+(-1.442719e-01)*S23+1.261875e-01*S24+(-1.247018e+00)*S25+(-2.095853e-02)*S26+4.092516e-02*S27+4.464090e-01*S28+1.072093e-01*S29'
.param V54_part4='V54_part3+(-2.399796e-01)*S30+3.712514e-02*S31+(-4.383612e-01)*S32+(-3.170781e-02)*S33+(-1.068165e-01)*S34+(-1.270155e-01)*S35+1.003402e-01*S36+(-1.764987e-01)*S37+(-8.634665e-02)*S38+1.751399e-01*S39'
.param V54_part5='V54_part4+7.436242e-02*S40+2.429560e-02*S41+1.511605e-01*S42+(-1.160828e-01)*S43+3.982027e-01*S44+(-9.790430e-02)*S45+3.534415e-01*S46+(-4.362726e-01)*S47+(-1.139333e-01)*S48+8.151253e-01*S49'
.param V54_part6='V54_part5+4.514710e-02*S50+(-2.875679e+00)*S51+(-2.543211e-02)*S52+2.789434e-02*S53+2.525967e-01*S54+2.147696e-01*S55+3.617350e-01*S56+7.810512e-01*S57+1.107886e-01*S58+9.870406e-02*S59'
.param V54_part7='V54_part6+3.250495e-02*S60+1.992416e-01*S61+1.282912e-02*S62+1.828249e-01*S63+6.492409e-02*S64+(-5.001328e-02)*S65+1.936536e-01*S66+(-4.555556e+01)*S67+5.309207e-01*S68+(-2.544445e+00)*S69'
.param V54_part8='V54_part7+(-2.330496e+01)*S70+(-4.353408e-01)*S71+(-8.408272e-01)*S72+(-3.005601e-02)*S73+1.266860e-01*S74+(-5.415688e-01)*S75+(-2.492283e-01)*S76+(-9.136518e-02)*S77+(-1.690334e-01)*S78+(-1.709763e-01)*S79'
.param V54_part9='V54_part8+4.534786e-02*S80+1.188021e-01*S81+(-1.012798e-01)*S82+2.013430e-01*S83+6.231105e+00*S84+4.183015e-01*S85+2.384051e+00*S86+1.371966e+00*S87+6.146239e-01*S88+(-6.325368e-02)*S89'
.param V54_part10='V54_part9+(-2.473166e-01)*S90+(-3.827427e-02)*S91+1.698343e-02*S92+(-1.151162e+00)*S93+(-4.152617e-02)*S94+(-1.547502e-01)*S95+(-3.956892e+01)*S96+(-7.039229e-01)*S97+(-1.068687e-01)*S98+(-9.757572e-01)*S99'
.param V54_part11='V54_part10+(-6.986370e-01)*S100+(-3.600927e-01)*S101+(-6.877740e-01)*S102+(-4.551400e-01)*S103+(-1.097893e+00)*S104+(-9.829862e-03)*S105+(-4.920704e-03)*S106+(-1.678655e-01)*S107+(-5.150982e-01)*S108+(-6.325593e-01)*S109'
.param V54_part12='V54_part11+(-8.461051e-02)*S110+(-7.597320e-01)*S111+(-5.304635e-01)*S112+(-1.185671e-01)*S113+(-3.645475e+01)*S114+(-1.857084e+00)*S115+(-2.709700e-01)*S116+(-1.522246e-01)*S117+(-2.070337e-01)*S118+(-1.324716e-01)*S119'
.param V54_part13='V54_part12+(-2.205215e+02)*S120+2.654373e-02*S121+(-1.140186e-01)*S122+(-7.644811e-01)*S123+(-2.663834e+00)*S124+3.845323e-02*S125+(-2.337720e-01)*S126+(-5.698634e-01)*S127+(-1.878802e-01)*S128+(-4.398331e-01)*S129'
.param V54_part14='V54_part13+(-5.105593e+00)*S130+(-1.252387e-01)*S131+7.554897e-01*S132+1.006766e+00*S133+(-8.222011e-02)*S134+(-7.918587e-02)*S135+(-8.545908e-02)*S136+(-2.548798e-01)*S137+(-1.520146e-01)*S138+(-3.232288e-01)*S139'
.param V54_part15='V54_part14+(-1.947646e+00)*S140+(-6.842894e-01)*S141+(-2.110275e-01)*S142+(-3.360062e-01)*S143+(-3.911403e-01)*S144+(-7.952996e-02)*S145+(-6.071576e-02)*S146+(-2.685875e-01)*S147+(-1.015266e-01)*S148+(-1.401697e-01)*S149'
.param V54_part16='V54_part15+(-1.833647e+00)*S150+(-7.493578e-02)*S151+(-1.694169e+00)*S152+(-1.464078e+00)*S153+(-6.421906e+00)*S154+2.504146e-01*S155+2.849468e-01*S156+(-5.960321e-01)*S157+(-1.954739e+00)*S158+3.220512e-02*S159'
.param V54_part17='V54_part16+(-2.289437e+00)*S160+(-2.491959e-01)*S161+9.871632e-02*S162+(-3.665695e-01)*S163+2.053641e-01*S164+(-2.786729e-01)*S165+(-7.599091e-01)*S166+(-8.504266e-02)*S167+(-8.658600e-01)*S168+(-6.175869e-01)*S169'
.param V54_part18='V54_part17+(-9.808051e-02)*S170+(-1.574355e+00)*S171+(-9.195500e-01)*S172+(-5.362087e-02)*S173+(-6.290948e-01)*S174+(-8.940463e-01)*S175+(-2.845301e-01)*S176+(-6.292863e-01)*S177+(-5.642981e+00)*S178+(-8.590805e-02)*S179'
.param V54_part19='V54_part18+(-1.052787e+00)*S180+(-8.500134e-01)*S181+(-1.847548e-01)*S182+(-6.049177e-01)*S183+(-1.119367e+00)*S184+(-4.547357e-01)*S185+(-9.455264e-01)*S186+(-1.261231e+00)*S187+(-7.249267e-01)*S188+(-5.223781e-01)*S189'
.param V54_part20='V54_part19+(-1.243979e-01)*S190+1.268206e-01*S191+6.110574e-01*S192+(-1.580941e+00)*S193+(-1.754674e-01)*S194+8.270233e-01*S195+6.118247e-01*S196+(-2.625476e-01)*S197+(-2.420663e+00)*S198+(-8.497978e+00)*S199'
.param V54_part21='V54_part20+(-1.733070e-01)*S200+(-3.576105e+00)*S201+(-7.136759e-01)*S202+(-3.047405e-01)*S203+(-4.512626e-01)*S204+(-3.416837e-01)*S205+1.072003e+00*S206+5.981538e-01*S207+(-1.785025e+00)*S208+(-5.968498e-02)*S209'
.param V54_part22='V54_part21+(-1.301607e+00)*S210+(-2.302250e-01)*S211+(-3.229228e-01)*S212+2.418541e-01*S213+(-6.004555e+00)*S214+(-3.253160e-01)*S215+1.118358e+00*S216+(-8.383891e-02)*S217+(-8.615939e-01)*S218+(-2.527484e-01)*S219'
.param V54_part23='V54_part22+(-2.424700e+00)*S220+4.691759e-02*S221+1.076599e+00*S222+8.544178e-02*S223+1.900674e-01*S224+(-8.870761e-02)*S225+(-6.621549e-01)*S226+(-2.617819e-01)*S227+1.850387e+00*S228+(-8.269529e-01)*S229'
.param V54_part24='V54_part23+(-1.606418e-01)*S230+2.394886e-01*S231+1.333155e+01*S232+(-7.294548e-01)*S233+(-1.823750e+00)*S234+7.011822e-01*S235+(-1.423966e+00)*S236+2.872661e+00*S237+2.567190e-01*S238+(-1.380525e+00)*S239'
.param V54_part25='V54_part24+(-3.291176e+02)*S240+(-1.767246e+00)*S241+(-8.053476e-01)*S242+(-9.248963e+00)*S243+(-6.497877e+01)*S244+(-2.903357e+01)*S245+(-6.181420e-01)*S246+2.442375e-01*S247+(-4.861065e-01)*S248+(-8.259388e-01)*S249'
.param V54_part26='V54_part25+4.452243e-01*S250+(-6.791225e-02)*S251+8.265348e-01*S252+6.145611e-02*S253+(-1.512601e-01)*S254+5.596307e-01*S255+(-1.631296e+01)*S256+(-2.253893e-01)*S257+(-3.332253e-01)*S258+(-1.035333e+00)*S259'
.param V54_part27='V54_part26+(-5.913727e-01)*S260+(-1.207785e+00)*S261+(-2.199963e+00)*S262+(-1.432878e-02)*S263+(-8.235003e-01)*S264+1.415946e-01*S265+(-1.627096e+01)*S266+(-1.015192e+00)*S267+(-1.578732e+00)*S268+(-5.197681e+01)*S269'
.param V54_part28='V54_part27+8.382734e-01*S270+(-8.820464e-01)*S271+(-1.519749e-01)*S272+2.152283e+00*S273+(-9.430498e-01)*S274+(-2.547399e-01)*S275+(-1.380744e+00)*S276+8.227452e-01*S277+(-1.623813e-01)*S278+6.239439e-01*S279'
.param V54_part29='V54_part28+5.136219e+00*S280+(-7.474417e-02)*S281+1.833506e+00*S282+(-7.016427e+00)*S283+(-2.235483e+00)*S284+(-8.767883e-01)*S285+1.893490e-01*S286+(-2.366301e-01)*S287+(-1.022414e+00)*S288+(-5.264723e-02)*S289'
.param V54_part30='V54_part29+(-1.192815e-01)*S290+(-1.060050e+00)*S291+(-1.033593e-02)*S292+(-2.112924e-01)*S293+(-2.002258e+00)*S294+(-1.688055e-02)*S295+(-6.805850e-02)*S296+1.531188e-02*S297+3.332363e-02*S298+(-2.233476e-02)*S299'
.param V54_part31='V54_part30+2.314736e+01*S300+(-6.165747e+01)*S301+(-4.138581e-01)*S302+2.190602e+00*S303+2.307071e-01*S304+(-8.647078e-02)*S305+(-1.172739e+00)*S306+(-4.717803e-03)*S307+(-1.097924e-01)*S308+(-1.004369e-01)*S309'
.param V54='V54_part31+3.036794e-03*S310+(-8.926759e-02)*S311+(-8.454291e-01)*S312+8.801245e-02*S313+(-6.336512e-01)*S314'
.param V55_part1='(-6.765296e+00)*S0+6.627918e-01*S1+0.000000e+00*S2+0.000000e+00*S3+1.137417e+01*S4+3.817878e+00*S5+1.405069e+01*S6+1.758277e+01*S7+0.000000e+00*S8+(-3.416849e-01)*S9'
.param V55_part2='V55_part1+0.000000e+00*S10+0.000000e+00*S11+(-3.820135e-01)*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+1.864528e+01*S16+1.870891e+01*S17+0.000000e+00*S18+1.400013e+01*S19'
.param V55_part3='V55_part2+3.640058e-01*S20+0.000000e+00*S21+1.744315e+01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+3.923057e+00*S27+5.488060e+00*S28+0.000000e+00*S29'
.param V55_part4='V55_part3+0.000000e+00*S30+2.029798e+01*S31+2.813514e+00*S32+(-1.152628e-01)*S33+4.701312e+00*S34+(-1.434215e+00)*S35+1.187171e+00*S36+3.416623e+00*S37+3.871072e+00*S38+9.213199e-01*S39'
.param V55_part5='V55_part4+(-1.895904e+00)*S40+(-1.617438e+00)*S41+(-4.123204e+00)*S42+1.835115e+01*S43+0.000000e+00*S44+(-2.199715e+00)*S45+2.783059e+01*S46+2.780192e+01*S47+(-1.069258e+00)*S48+0.000000e+00*S49'
.param V55_part6='V55_part5+(-8.684819e+00)*S50+0.000000e+00*S51+(-4.730454e+00)*S52+7.650273e-01*S53+8.941353e+00*S54+2.570203e+00*S55+(-8.578773e+00)*S56+4.843199e+00*S57+(-2.804533e+00)*S58+7.124763e-01*S59'
.param V55_part7='V55_part6+1.795055e+01*S60+(-1.871415e-01)*S61+(-3.286482e+00)*S62+(-1.769447e+00)*S63+(-4.981403e+00)*S64+1.426746e+01*S65+9.848869e+00*S66+0.000000e+00*S67+2.010392e+01*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+1.006436e+01*S71+2.904572e+01*S72+(-1.560250e+00)*S73+0.000000e+00*S74+2.993859e+00*S75+6.264678e+00*S76+5.928315e+00*S77+4.203197e+00*S78+3.304167e-02*S79'
.param V55_part9='V55_part8+9.935694e+00*S80+1.908955e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+2.936072e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V55_part10='V55_part9+(-8.429538e+00)*S90+(-1.007192e+00)*S91+(-4.919966e+00)*S92+0.000000e+00*S93+0.000000e+00*S94+(-1.228969e+01)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+1.132268e+01*S99'
.param V55_part11='V55_part10+1.221289e+01*S100+1.401271e+01*S101+1.532550e+01*S102+1.738718e+01*S103+(-1.739630e+01)*S104+6.481085e+00*S105+5.249118e+00*S106+1.846493e+01*S107+7.599059e+00*S108+1.068516e+01*S109'
.param V55_part12='V55_part11+1.119944e+01*S110+6.601536e+00*S111+8.710742e+00*S112+(-3.221359e+00)*S113+0.000000e+00*S114+(-3.055849e+00)*S115+(-9.943309e-01)*S116+1.824641e+01*S117+0.000000e+00*S118+2.292526e+01*S119'
.param V55_part13='V55_part12+2.938309e+00*S120+1.060438e+01*S121+1.407845e+01*S122+1.186806e+01*S123+1.255999e+01*S124+0.000000e+00*S125+1.143841e+01*S126+1.322279e+01*S127+1.564696e+01*S128+2.205528e+01*S129'
.param V55_part14='V55_part13+0.000000e+00*S130+2.081493e+01*S131+2.340200e+01*S132+2.870598e+01*S133+3.159097e+01*S134+2.405885e+00*S135+2.433653e-01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V55_part15='V55_part14+2.805136e+00*S140+0.000000e+00*S141+5.978954e+00*S142+0.000000e+00*S143+2.909755e+01*S144+0.000000e+00*S145+0.000000e+00*S146+1.840804e+01*S147+1.173471e+01*S148+1.681903e+01*S149'
.param V55_part16='V55_part15+1.265460e+01*S150+1.209142e+01*S151+8.157760e+00*S152+1.222631e+01*S153+0.000000e+00*S154+(-1.203191e+01)*S155+(-1.293966e+01)*S156+2.164687e+01*S157+0.000000e+00*S158+2.537970e+01*S159'
.param V55_part17='V55_part16+8.296063e+00*S160+1.032770e+01*S161+7.186334e+00*S162+3.708816e+01*S163+0.000000e+00*S164+1.104359e+01*S165+1.212311e+01*S166+1.511382e+01*S167+1.222264e+01*S168+1.365218e+01*S169'
.param V55_part18='V55_part17+1.786323e+01*S170+(-3.513246e+01)*S171+1.565028e+01*S172+2.322853e+01*S173+1.410239e+01*S174+0.000000e+00*S175+2.826157e+01*S176+1.255925e+01*S177+0.000000e+00*S178+1.012101e+01*S179'
.param V55_part19='V55_part18+1.256293e+01*S180+1.092737e+01*S181+0.000000e+00*S182+0.000000e+00*S183+1.959009e+00*S184+0.000000e+00*S185+1.140423e+01*S186+9.966001e+00*S187+6.276868e+00*S188+0.000000e+00*S189'
.param V55_part20='V55_part19+(-3.699741e+01)*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+2.550163e+01*S194+6.316176e+00*S195+8.694988e+00*S196+1.054175e+01*S197+9.862188e+00*S198+0.000000e+00*S199'
.param V55_part21='V55_part20+1.298578e+01*S200+0.000000e+00*S201+1.518590e+01*S202+2.269926e+01*S203+0.000000e+00*S204+3.110563e+01*S205+4.136894e+01*S206+3.043941e+01*S207+0.000000e+00*S208+1.355463e+01*S209'
.param V55_part22='V55_part21+1.308149e+01*S210+1.567661e+01*S211+6.278177e+00*S212+2.257946e+01*S213+(-1.335862e+00)*S214+9.901201e+00*S215+0.000000e+00*S216+(-7.260051e+00)*S217+0.000000e+00*S218+(-1.010438e+01)*S219'
.param V55_part23='V55_part22+0.000000e+00*S220+2.400771e+00*S221+0.000000e+00*S222+9.922081e-01*S223+0.000000e+00*S224+4.182572e+00*S225+8.394285e+00*S226+3.497373e+01*S227+1.825879e+01*S228+8.433795e+00*S229'
.param V55_part24='V55_part23+6.222791e+01*S230+0.000000e+00*S231+8.181471e+00*S232+2.852081e+01*S233+(-1.368826e+01)*S234+0.000000e+00*S235+1.956289e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V55_part25='V55_part24+0.000000e+00*S240+3.955769e+00*S241+3.542628e+00*S242+0.000000e+00*S243+0.000000e+00*S244+6.670201e+00*S245+9.009829e+00*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V55_part26='V55_part25+0.000000e+00*S250+(-1.251845e+01)*S251+0.000000e+00*S252+(-2.444754e+01)*S253+3.868505e+01*S254+0.000000e+00*S255+0.000000e+00*S256+1.138172e+01*S257+5.840617e+00*S258+8.247450e+00*S259'
.param V55_part27='V55_part26+(-1.318713e-01)*S260+1.410489e+01*S261+5.041749e-01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+(-1.381437e+01)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V55_part28='V55_part27+1.675786e+01*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+(-4.189337e+00)*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V55_part29='V55_part28+0.000000e+00*S280+(-3.391458e+01)*S281+0.000000e+00*S282+0.000000e+00*S283+(-6.010413e+00)*S284+8.802898e+00*S285+4.036089e+01*S286+9.688097e+00*S287+1.212194e+01*S288+(-1.122806e+00)*S289'
.param V55_part30='V55_part29+1.467244e+01*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+(-1.425260e+01)*S294+0.000000e+00*S295+2.471652e+01*S296+6.094759e+00*S297+(-1.054360e+02)*S298+(-1.071566e+02)*S299'
.param V55_part31='V55_part30+1.570590e+01*S300+1.464800e+00*S301+3.114197e+01*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+2.434523e+00*S308+0.000000e+00*S309'
.param V55='V55_part31+0.000000e+00*S310+3.085052e+01*S311+(-8.861744e+00)*S312+0.000000e+00*S313+(-6.764986e+01)*S314'
.param V56_part1='4.709106e+01*S0+5.297253e+01*S1+0.000000e+00*S2+0.000000e+00*S3+8.493407e-01*S4+3.708605e+01*S5+1.718699e+01*S6+1.602848e+01*S7+0.000000e+00*S8+3.355762e+01*S9'
.param V56_part2='V56_part1+0.000000e+00*S10+0.000000e+00*S11+3.357112e+01*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+1.423395e+01*S16+3.077909e+01*S17+0.000000e+00*S18+4.456326e+01*S19'
.param V56_part3='V56_part2+3.403467e+01*S20+0.000000e+00*S21+1.408654e+01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+1.530587e+01*S27+3.011467e-01*S28+0.000000e+00*S29'
.param V56_part4='V56_part3+0.000000e+00*S30+2.560491e+01*S31+3.445506e+01*S32+5.318356e+01*S33+5.337485e+01*S34+4.813345e+01*S35+4.281987e+01*S36+2.418119e+01*S37+2.860314e+01*S38+4.151509e+01*S39'
.param V56_part5='V56_part4+2.275056e+01*S40+2.980396e+01*S41+3.889665e+01*S42+1.621897e+01*S43+0.000000e+00*S44+4.481384e+01*S45+(-2.886576e+01)*S46+1.145589e+01*S47+5.368255e+01*S48+0.000000e+00*S49'
.param V56_part6='V56_part5+6.013170e+01*S50+0.000000e+00*S51+1.091974e+02*S52+2.973555e+01*S53+2.170021e+01*S54+2.427375e+01*S55+2.922017e+01*S56+2.238594e+01*S57+3.223160e+01*S58+3.139834e+01*S59'
.param V56_part7='V56_part6+2.757083e+01*S60+5.524777e+01*S61+5.205324e+01*S62+6.530048e+01*S63+6.059227e+01*S64+(-1.833797e+01)*S65+2.749422e+01*S66+0.000000e+00*S67+1.551457e+01*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+2.231343e+01*S71+9.858376e+00*S72+3.045532e+01*S73+0.000000e+00*S74+3.614096e+01*S75+1.975047e+01*S76+2.127814e+01*S77+1.198776e+01*S78+1.866830e+00*S79'
.param V56_part9='V56_part8+1.496837e+01*S80+9.470063e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+(-3.930480e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part10='V56_part9+8.543220e+01*S90+5.373072e+01*S91+6.532283e+01*S92+0.000000e+00*S93+0.000000e+00*S94+6.995958e+01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+2.194771e+01*S99'
.param V56_part11='V56_part10+2.231669e+01*S100+1.899261e+01*S101+1.848346e+01*S102+1.633143e+01*S103+4.498555e+01*S104+2.874812e+01*S105+1.953985e+01*S106+(-6.994792e+00)*S107+2.426321e+01*S108+2.191351e+01*S109'
.param V56_part12='V56_part11+2.252762e+01*S110+2.832032e+01*S111+2.631308e+01*S112+2.958716e+01*S113+0.000000e+00*S114+3.173127e+01*S115+4.227708e+01*S116+2.387900e+01*S117+0.000000e+00*S118+8.726543e+00*S119'
.param V56_part13='V56_part12+4.981758e+01*S120+1.006040e+01*S121+1.263148e+01*S122+1.802120e+01*S123+1.872801e+01*S124+0.000000e+00*S125+2.045853e+01*S126+1.957243e+01*S127+1.455047e+01*S128+8.534510e+00*S129'
.param V56_part14='V56_part13+0.000000e+00*S130+1.014162e+01*S131+3.056027e+00*S132+(-3.255365e+00)*S133+6.664670e-01*S134+7.468046e+01*S135+6.374263e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V56_part15='V56_part14+2.419723e+01*S140+0.000000e+00*S141+2.578702e+01*S142+0.000000e+00*S143+(-1.949833e+01)*S144+0.000000e+00*S145+0.000000e+00*S146+(-1.658634e+00)*S147+1.773379e+01*S148+1.873302e+01*S149'
.param V56_part16='V56_part15+1.037959e+01*S150+1.573296e+01*S151+1.782814e+01*S152+1.909039e+01*S153+0.000000e+00*S154+6.350647e+01*S155+6.264087e+01*S156+5.665001e+00*S157+0.000000e+00*S158+(-4.446797e+00)*S159'
.param V56_part17='V56_part16+2.163741e+01*S160+1.904909e+01*S161+7.119850e+00*S162+(-1.924607e+00)*S163+0.000000e+00*S164+1.414433e+01*S165+1.487127e+01*S166+7.631802e+00*S167+1.798737e+01*S168+1.705013e+01*S169'
.param V56_part18='V56_part17+1.083839e+01*S170+1.909039e+01*S171+1.591476e+01*S172+(-5.244250e+00)*S173+1.819585e+01*S174+0.000000e+00*S175+1.771949e+00*S176+1.554027e+01*S177+0.000000e+00*S178+4.279184e+00*S179'
.param V56_part19='V56_part18+1.189034e+01*S180+1.409823e+01*S181+0.000000e+00*S182+0.000000e+00*S183+3.157064e+00*S184+0.000000e+00*S185+2.138200e+01*S186+2.383140e+01*S187+2.138140e+01*S188+0.000000e+00*S189'
.param V56_part20='V56_part19+8.590978e+01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+8.931982e+01*S194+1.629941e+01*S195+1.148747e+01*S196+1.499101e+01*S197+2.052999e+01*S198+0.000000e+00*S199'
.param V56_part21='V56_part20+1.574051e+01*S200+0.000000e+00*S201+1.624171e+01*S202+7.012176e+00*S203+0.000000e+00*S204+4.649271e+00*S205+(-1.617439e+01)*S206+(-4.710968e+00)*S207+0.000000e+00*S208+3.694597e+00*S209'
.param V56_part22='V56_part21+1.209249e+01*S210+9.426306e+00*S211+1.428037e+01*S212+1.391740e+00*S213+4.365003e+01*S214+1.236771e+01*S215+0.000000e+00*S216+2.625350e+01*S217+0.000000e+00*S218+7.768967e+01*S219'
.param V56_part23='V56_part22+0.000000e+00*S220+1.547153e+01*S221+0.000000e+00*S222+1.299314e+01*S223+0.000000e+00*S224+(-2.269478e+01)*S225+2.080538e+01*S226+(-2.517542e+01)*S227+(-1.763945e+00)*S228+3.469844e+01*S229'
.param V56_part24='V56_part23+(-4.152533e+01)*S230+0.000000e+00*S231+1.101422e+01*S232+6.383073e+00*S233+5.666459e+01*S234+0.000000e+00*S235+1.808734e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V56_part25='V56_part24+0.000000e+00*S240+2.016089e+01*S241+1.066686e+01*S242+0.000000e+00*S243+0.000000e+00*S244+2.477756e+01*S245+1.916679e+00*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V56_part26='V56_part25+0.000000e+00*S250+6.048230e+01*S251+0.000000e+00*S252+3.658605e+01*S253+8.822060e+01*S254+0.000000e+00*S255+0.000000e+00*S256+9.289543e+00*S257+1.867312e+01*S258+2.542864e+01*S259'
.param V56_part27='V56_part26+3.249166e+01*S260+1.052286e+01*S261+3.232255e+01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+2.352340e+01*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V56_part28='V56_part27+(-4.964068e+00)*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+4.869944e+01*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V56_part29='V56_part28+0.000000e+00*S280+8.105855e+01*S281+0.000000e+00*S282+0.000000e+00*S283+3.122142e+01*S284+2.054063e+01*S285+(-3.897631e+01)*S286+(-7.723862e+00)*S287+9.365757e+00*S288+3.377642e+01*S289'
.param V56_part30='V56_part29+(-5.646722e+00)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+7.992914e+01*S294+0.000000e+00*S295+2.805987e+01*S296+1.854886e+01*S297+5.746862e+01*S298+1.681661e+02*S299'
.param V56_part31='V56_part30+(-1.103084e+01)*S300+2.432071e+01*S301+(-1.683519e+01)*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+5.183399e+01*S308+0.000000e+00*S309'
.param V56='V56_part31+0.000000e+00*S310+4.948822e+01*S311+3.659852e+01*S312+0.000000e+00*S313+1.216842e+02*S314'
.param V57_part1='2.371727e+01*S0+1.047013e+01*S1+0.000000e+00*S2+0.000000e+00*S3+9.615267e+00*S4+1.337382e+01*S5+(-1.654799e-01)*S6+1.880322e-01*S7+0.000000e+00*S8+(-3.746931e+00)*S9'
.param V57_part2='V57_part1+0.000000e+00*S10+0.000000e+00*S11+(-6.126007e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-1.355620e+00)*S16+(-9.920941e-01)*S17+0.000000e+00*S18+(-8.337606e+00)*S19'
.param V57_part3='V57_part2+1.760609e+01*S20+0.000000e+00*S21+7.558408e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-8.236728e+00)*S27+(-8.161194e+00)*S28+0.000000e+00*S29'
.param V57_part4='V57_part3+0.000000e+00*S30+(-1.108754e+00)*S31+2.357235e+01*S32+7.470044e+00*S33+5.602031e+00*S34+2.052056e+01*S35+8.665864e+00*S36+(-3.712467e+00)*S37+1.730293e+01*S38+1.012065e+01*S39'
.param V57_part5='V57_part4+1.433660e+01*S40+2.166080e+01*S41+2.771804e+01*S42+1.850786e+01*S43+0.000000e+00*S44+3.093506e+01*S45+(-2.672702e+01)*S46+6.523559e+00*S47+1.354579e+01*S48+0.000000e+00*S49'
.param V57_part6='V57_part5+2.870456e+01*S50+0.000000e+00*S51+1.719160e+01*S52+2.285177e+01*S53+9.890529e+00*S54+2.098237e+01*S55+2.855317e+01*S56+7.943478e+00*S57+2.187722e+01*S58+2.071815e+01*S59'
.param V57_part7='V57_part6+(-8.464104e+00)*S60+1.738619e+01*S61+2.606670e+01*S62+5.330030e-03*S63+1.886438e+01*S64+7.963261e+00*S65+9.378794e+00*S66+0.000000e+00*S67+8.042047e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+1.028061e+01*S71+1.271247e+01*S72+2.041063e+01*S73+0.000000e+00*S74+3.226725e+01*S75+3.379566e+01*S76+2.311011e+01*S77+3.775884e+01*S78+5.172301e+01*S79'
.param V57_part9='V57_part8+2.242690e+01*S80+2.250353e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+(-7.469075e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part10='V57_part9+1.569744e+01*S90+2.783074e+01*S91+2.541689e+01*S92+0.000000e+00*S93+0.000000e+00*S94+3.564887e+01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+8.634896e+00*S99'
.param V57_part11='V57_part10+7.904619e+00*S100+8.421772e+00*S101+7.307212e+00*S102+7.321887e+00*S103+4.184213e+01*S104+2.421604e+01*S105+2.948542e+01*S106+1.278920e+01*S107+2.106430e+01*S108+1.666511e+01*S109'
.param V57_part12='V57_part11+1.861027e+01*S110+1.723908e+01*S111+1.644272e+01*S112+3.742174e+01*S113+0.000000e+00*S114+3.508880e+01*S115+2.654852e+01*S116+6.243474e+00*S117+0.000000e+00*S118+1.522913e+01*S119'
.param V57_part13='V57_part12+2.735906e+01*S120+2.201605e+01*S121+1.729646e+01*S122+1.585409e+01*S123+1.414231e+01*S124+0.000000e+00*S125+1.344715e+01*S126+1.248603e+01*S127+1.358861e+01*S128+6.579654e+00*S129'
.param V57_part14='V57_part13+0.000000e+00*S130+1.148892e+01*S131+(-1.736658e+01)*S132+(-9.725214e+00)*S133+9.694832e+00*S134+3.241491e+00*S135+2.302979e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V57_part15='V57_part14+1.971785e+01*S140+0.000000e+00*S141+2.123579e+01*S142+0.000000e+00*S143+(-3.419410e+00)*S144+0.000000e+00*S145+0.000000e+00*S146+1.613480e+01*S147+7.516675e+00*S148+1.467693e+01*S149'
.param V57_part16='V57_part15+1.630875e+01*S150+2.011456e+01*S151+2.474383e+01*S152+1.005671e+01*S153+0.000000e+00*S154+3.243059e+01*S155+5.119870e+01*S156+1.595132e+00*S157+0.000000e+00*S158+8.648865e-01*S159'
.param V57_part17='V57_part16+1.710753e+01*S160+2.768588e+01*S161+2.164524e+01*S162+5.459052e+00*S163+0.000000e+00*S164+2.143883e+01*S165+1.978221e+01*S166+2.196012e+01*S167+1.513061e+01*S168+1.460445e+01*S169'
.param V57_part18='V57_part17+1.775098e+01*S170+1.331701e+02*S171+2.274676e+01*S172+6.912193e+00*S173+3.603260e+01*S174+0.000000e+00*S175+2.675552e+01*S176+1.038832e+01*S177+0.000000e+00*S178+2.495894e+01*S179'
.param V57_part19='V57_part18+1.856620e+01*S180+1.841471e+01*S181+0.000000e+00*S182+0.000000e+00*S183+2.168279e+01*S184+0.000000e+00*S185+3.697583e+01*S186+1.653728e+01*S187+2.985515e+01*S188+0.000000e+00*S189'
.param V57_part20='V57_part19+3.633643e+01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+5.961505e+00*S194+2.096401e+01*S195+2.307877e+01*S196+2.156154e+01*S197+1.639296e+01*S198+0.000000e+00*S199'
.param V57_part21='V57_part20+1.968065e+01*S200+0.000000e+00*S201+9.926262e+00*S202+8.152669e+00*S203+0.000000e+00*S204+(-1.642392e+01)*S205+(-1.122515e+01)*S206+(-1.332040e+01)*S207+0.000000e+00*S208+(-6.095127e+00)*S209'
.param V57_part22='V57_part21+1.287516e+01*S210+1.675143e+01*S211+3.660172e+01*S212+(-1.894518e+01)*S213+4.136694e+01*S214+3.212284e+01*S215+0.000000e+00*S216+5.121685e+01*S217+0.000000e+00*S218+3.871607e+01*S219'
.param V57_part23='V57_part22+0.000000e+00*S220+9.403427e+00*S221+0.000000e+00*S222+7.522520e+00*S223+0.000000e+00*S224+4.062171e+01*S225+3.384354e+01*S226+(-2.050729e+00)*S227+(-1.614837e+01)*S228+3.836335e+01*S229'
.param V57_part24='V57_part23+(-3.173065e+01)*S230+0.000000e+00*S231+9.083175e+00*S232+1.681535e+01*S233+7.720892e+01*S234+0.000000e+00*S235+2.929830e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V57_part25='V57_part24+0.000000e+00*S240+4.174797e+01*S241+3.883869e+01*S242+0.000000e+00*S243+0.000000e+00*S244+4.296622e+01*S245+7.315320e-01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V57_part26='V57_part25+0.000000e+00*S250+6.523216e+01*S251+0.000000e+00*S252+1.148006e+02*S253+(-3.297258e+01)*S254+0.000000e+00*S255+0.000000e+00*S256+2.661439e+01*S257+2.648069e+01*S258+2.137857e+01*S259'
.param V57_part27='V57_part26+3.600080e+01*S260+4.994797e+00*S261+2.583042e+01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+1.305460e+01*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V57_part28='V57_part27+(-1.074776e+01)*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+6.475998e+01*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V57_part29='V57_part28+0.000000e+00*S280+6.971683e+01*S281+0.000000e+00*S282+0.000000e+00*S283+5.317828e+01*S284+6.249544e+01*S285+(-2.946093e+01)*S286+4.672306e+01*S287+1.587662e+00*S288+7.231518e+01*S289'
.param V57_part30='V57_part29+4.684560e+01*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+5.609114e+01*S294+0.000000e+00*S295+6.702516e+01*S296+8.955714e+00*S297+2.326475e+02*S298+1.387419e+02*S299'
.param V57_part31='V57_part30+(-6.585078e+00)*S300+5.222352e+01*S301+1.424354e+01*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+4.497579e+01*S308+0.000000e+00*S309'
.param V57='V57_part31+0.000000e+00*S310+2.899887e+01*S311+7.910672e+01*S312+0.000000e+00*S313+1.432458e+02*S314'
.param V58_part1='4.690658e-01*S0+8.311266e-01*S1+0.000000e+00*S2+0.000000e+00*S3+8.842189e+00*S4+7.494005e-01*S5+1.075214e+01*S6+1.094544e+01*S7+0.000000e+00*S8+5.994486e-01*S9'
.param V58_part2='V58_part1+0.000000e+00*S10+0.000000e+00*S11+4.412803e-01*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+7.266805e+00*S16+(-5.280173e+00)*S17+0.000000e+00*S18+(-2.247535e+00)*S19'
.param V58_part3='V58_part2+(-5.832613e+00)*S20+0.000000e+00*S21+2.466122e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+3.815723e+00*S27+(-9.468694e-02)*S28+0.000000e+00*S29'
.param V58_part4='V58_part3+0.000000e+00*S30+(-6.740183e+00)*S31+(-4.354703e-02)*S32+1.252872e+00*S33+8.950027e-01*S34+(-1.224943e-01)*S35+1.688251e+00*S36+1.496797e+00*S37+(-5.956432e+00)*S38+(-5.848122e-02)*S39'
.param V58_part5='V58_part4+1.468100e+01*S40+1.422374e+00*S41+(-2.979207e+00)*S42+(-7.918072e+00)*S43+0.000000e+00*S44+(-9.234648e+00)*S45+(-7.509052e+00)*S46+(-5.167899e+00)*S47+(-7.149705e-01)*S48+0.000000e+00*S49'
.param V58_part6='V58_part5+8.776807e-03*S50+0.000000e+00*S51+1.562333e+01*S52+(-9.954635e+00)*S53+(-1.229254e+01)*S54+(-9.216168e+00)*S55+(-7.723917e+00)*S56+(-3.369442e+00)*S57+(-1.412052e+01)*S58+(-1.066236e+01)*S59'
.param V58_part7='V58_part6+7.165686e+00*S60+6.136367e-02*S61+4.124874e-01*S62+1.161148e+00*S63+2.755025e+00*S64+(-1.003445e+00)*S65+(-4.635569e+00)*S66+0.000000e+00*S67+(-2.875699e+00)*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+(-1.691695e+00)*S71+(-3.327298e+00)*S72+(-2.204452e+00)*S73+0.000000e+00*S74+(-1.017055e+01)*S75+(-9.545031e+00)*S76+2.528128e+00*S77+(-1.457995e+01)*S78+(-1.430661e+01)*S79'
.param V58_part9='V58_part8+(-3.761537e+00)*S80+(-5.027641e-01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+1.398650e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part10='V58_part9+(-1.831311e-01)*S90+3.123500e+00*S91+1.082004e+00*S92+0.000000e+00*S93+0.000000e+00*S94+3.536714e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+(-2.320292e+00)*S99'
.param V58_part11='V58_part10+(-5.236365e-01)*S100+5.346934e+00*S101+(-2.135625e+00)*S102+(-1.576155e+00)*S103+9.115829e+00*S104+(-3.777811e+00)*S105+(-2.653459e+00)*S106+(-5.469402e+00)*S107+(-5.957146e+00)*S108+(-3.216638e+00)*S109'
.param V58_part12='V58_part11+(-2.742671e+00)*S110+(-3.838029e+00)*S111+(-3.425873e+00)*S112+9.551435e-01*S113+0.000000e+00*S114+(-3.924257e+00)*S115+1.319829e+00*S116+(-8.563950e-01)*S117+0.000000e+00*S118+(-1.563962e+00)*S119'
.param V58_part13='V58_part12+2.219457e+00*S120+(-1.504083e+00)*S121+4.523155e+00*S122+(-1.079436e+00)*S123+(-5.942816e-01)*S124+0.000000e+00*S125+(-1.392504e+00)*S126+(-5.492833e-01)*S127+2.330676e+00*S128+(-1.581759e+00)*S129'
.param V58_part14='V58_part13+0.000000e+00*S130+1.995957e+00*S131+(-2.815575e+00)*S132+(-3.794169e-02)*S133+2.784723e+00*S134+(-3.419802e+00)*S135+(-8.474381e-01)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V58_part15='V58_part14+1.411079e+00*S140+0.000000e+00*S141+(-6.376113e+00)*S142+0.000000e+00*S143+7.434096e+00*S144+0.000000e+00*S145+0.000000e+00*S146+(-1.388571e+01)*S147+(-1.329693e+01)*S148+(-5.984669e+00)*S149'
.param V58_part16='V58_part15+1.815278e-01*S150+2.736290e-01*S151+3.102589e+00*S152+9.635613e-01*S153+0.000000e+00*S154+2.065801e+01*S155+2.910305e+00*S156+(-2.623317e+00)*S157+0.000000e+00*S158+2.823713e+00*S159'
.param V58_part17='V58_part16+(-6.703336e+00)*S160+(-1.465465e+00)*S161+(-1.027808e+00)*S162+(-8.252965e+00)*S163+0.000000e+00*S164+(-1.635481e-01)*S165+(-1.400645e+00)*S166+(-1.831574e+00)*S167+(-2.340660e+00)*S168+(-2.540765e+00)*S169'
.param V58_part18='V58_part17+(-1.725669e-01)*S170+2.972733e+00*S171+8.118709e-02*S172+2.606169e+00*S173+(-1.690744e+00)*S174+0.000000e+00*S175+(-4.552286e+00)*S176+(-4.862819e+00)*S177+0.000000e+00*S178+8.245281e+00*S179'
.param V58_part19='V58_part18+1.102318e-01*S180+2.713003e-01*S181+0.000000e+00*S182+0.000000e+00*S183+4.858148e-01*S184+0.000000e+00*S185+2.780794e+00*S186+(-1.151672e+00)*S187+2.125831e+00*S188+0.000000e+00*S189'
.param V58_part20='V58_part19+1.028282e+01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+1.823590e+00*S194+(-4.137379e+00)*S195+(-4.073168e+00)*S196+(-4.408460e+00)*S197+(-1.007482e+00)*S198+0.000000e+00*S199'
.param V58_part21='V58_part20+(-4.245912e+00)*S200+0.000000e+00*S201+(-4.394941e+00)*S202+(-1.860004e+00)*S203+0.000000e+00*S204+(-1.083637e+01)*S205+(-6.041636e-01)*S206+7.670388e-01*S207+0.000000e+00*S208+4.321090e-02*S209'
.param V58_part22='V58_part21+7.537253e-02*S210+(-4.437433e-01)*S211+1.040591e+00*S212+6.853293e+00*S213+2.063799e+00*S214+1.019784e+00*S215+0.000000e+00*S216+1.284158e+01*S217+0.000000e+00*S218+6.487272e+00*S219'
.param V58_part23='V58_part22+0.000000e+00*S220+1.269101e+01*S221+0.000000e+00*S222+5.551455e+00*S223+0.000000e+00*S224+5.745631e+00*S225+(-1.049299e+00)*S226+4.240396e-01*S227+(-1.131406e+00)*S228+2.123631e+00*S229'
.param V58_part24='V58_part23+5.295466e-01*S230+0.000000e+00*S231+1.120422e+01*S232+1.755935e+00*S233+2.023789e+00*S234+0.000000e+00*S235+1.329844e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V58_part25='V58_part24+0.000000e+00*S240+1.592631e+00*S241+2.935882e+00*S242+0.000000e+00*S243+0.000000e+00*S244+5.132328e+00*S245+(-1.236688e+01)*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V58_part26='V58_part25+0.000000e+00*S250+2.675954e+01*S251+0.000000e+00*S252+1.997778e+01*S253+1.477006e+01*S254+0.000000e+00*S255+0.000000e+00*S256+(-2.226829e+00)*S257+(-2.404149e+00)*S258+(-4.027859e+00)*S259'
.param V58_part27='V58_part26+(-1.618237e+00)*S260+(-4.034685e+00)*S261+(-2.086004e+00)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+4.557241e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V58_part28='V58_part27+6.552363e-01*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+1.173615e+01*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V58_part29='V58_part28+0.000000e+00*S280+2.948769e+01*S281+0.000000e+00*S282+0.000000e+00*S283+2.920787e+01*S284+2.570910e+00*S285+1.270822e+00*S286+(-2.752471e+00)*S287+4.811062e+00*S288+1.914940e+00*S289'
.param V58_part30='V58_part29+(-3.408889e+00)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+2.285962e+01*S294+0.000000e+00*S295+9.564759e+00*S296+1.564863e+01*S297+2.667429e+01*S298+5.805235e+00*S299'
.param V58_part31='V58_part30+(-9.059099e-01)*S300+4.359287e-01*S301+4.437323e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+2.248174e+01*S308+0.000000e+00*S309'
.param V58='V58_part31+0.000000e+00*S310+1.591110e+01*S311+2.712585e+01*S312+0.000000e+00*S313+4.414732e+00*S314'
.param V59_part1='9.775070e-03*S0+(-3.105672e-02)*S1+0.000000e+00*S2+0.000000e+00*S3+(-2.348301e-02)*S4+5.742636e-01*S5+1.180794e-01*S6+2.455482e-01*S7+0.000000e+00*S8+(-4.794815e-01)*S9'
.param V59_part2='V59_part1+0.000000e+00*S10+0.000000e+00*S11+(-4.007460e-01)*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-1.126414e-01)*S16+4.829226e-02*S17+0.000000e+00*S18+(-2.729855e-03)*S19'
.param V59_part3='V59_part2+7.835711e-02*S20+0.000000e+00*S21+4.717387e-02*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+1.021293e-01*S27+(-8.314882e-02)*S28+0.000000e+00*S29'
.param V59_part4='V59_part3+0.000000e+00*S30+2.530191e-01*S31+(-2.961932e-02)*S32+7.687808e-01*S33+6.182310e-01*S34+1.703528e-01*S35+(-1.044656e+00)*S36+8.100061e-01*S37+(-6.079073e-01)*S38+(-3.149778e+00)*S39'
.param V59_part5='V59_part4+(-7.891164e-01)*S40+(-6.900715e-01)*S41+(-4.169698e+00)*S42+(-1.049623e+00)*S43+0.000000e+00*S44+8.312403e-01*S45+1.478083e-01*S46+(-3.559792e-01)*S47+(-1.495200e+00)*S48+0.000000e+00*S49'
.param V59_part6='V59_part5+4.566327e-01*S50+0.000000e+00*S51+(-1.882812e+00)*S52+(-1.683749e+00)*S53+(-6.982776e+00)*S54+(-3.899920e+00)*S55+(-5.698861e+00)*S56+(-1.266693e+01)*S57+(-4.169032e+00)*S58+(-1.825613e+00)*S59'
.param V59_part7='V59_part6+(-2.737994e-01)*S60+1.488155e+00*S61+(-4.466748e-02)*S62+(-2.938966e+00)*S63+(-1.142574e+00)*S64+(-1.898490e+00)*S65+(-4.382790e+00)*S66+0.000000e+00*S67+3.568036e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+4.718347e+00*S71+5.797770e+00*S72+(-4.816601e+00)*S73+0.000000e+00*S74+(-1.552614e-01)*S75+6.018743e-01*S76+9.246237e-01*S77+8.439763e-01*S78+9.595229e-01*S79'
.param V59_part9='V59_part8+(-1.281724e+00)*S80+(-7.747069e-01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+(-2.456975e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part10='V59_part9+2.087766e+00*S90+1.807391e+00*S91+4.360163e-01*S92+0.000000e+00*S93+0.000000e+00*S94+2.528801e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+7.212014e-01*S99'
.param V59_part11='V59_part10+4.730909e-01*S100+5.619073e-01*S101+(-1.071292e+00)*S102+(-1.081957e+00)*S103+4.448448e-01*S104+(-1.461960e+00)*S105+(-2.296699e+00)*S106+1.140282e+00*S107+(-1.843023e+00)*S108+8.176623e-01*S109'
.param V59_part12='V59_part11+1.018295e+00*S110+(-7.808353e-01)*S111+1.053244e+00*S112+1.159153e+00*S113+0.000000e+00*S114+(-7.279530e+00)*S115+4.302492e+00*S116+(-1.710807e-01)*S117+0.000000e+00*S118+(-6.272399e-01)*S119'
.param V59_part13='V59_part12+(-1.989738e+00)*S120+2.216299e-02*S121+6.694036e-03*S122+2.708030e-02*S123+8.105091e-02*S124+0.000000e+00*S125+8.326601e-01*S126+7.761445e-01*S127+1.712831e+00*S128+(-1.087259e+00)*S129'
.param V59_part14='V59_part13+0.000000e+00*S130+3.623143e-01*S131+(-6.888736e+00)*S132+(-7.876605e+00)*S133+(-2.137829e+00)*S134+(-2.219478e+00)*S135+(-6.905275e-01)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V59_part15='V59_part14+(-8.537244e-01)*S140+0.000000e+00*S141+(-1.979407e-01)*S142+0.000000e+00*S143+1.268007e+00*S144+0.000000e+00*S145+0.000000e+00*S146+1.081132e+00*S147+1.156556e+00*S148+4.137307e-01*S149'
.param V59_part16='V59_part15+1.619240e+00*S150+1.411310e+00*S151+3.152526e-01*S152+1.728994e+00*S153+0.000000e+00*S154+3.998425e+00*S155+4.965534e-01*S156+(-6.633653e-01)*S157+0.000000e+00*S158+(-1.739737e+00)*S159'
.param V59_part17='V59_part16+(-4.150676e+00)*S160+(-8.497603e-01)*S161+(-3.971391e+00)*S162+(-7.852667e+00)*S163+0.000000e+00*S164+6.548968e-01*S165+2.431593e+00*S166+9.951201e-01*S167+1.124823e+00*S168+1.076647e+00*S169'
.param V59_part18='V59_part17+8.021159e-01*S170+(-3.075227e+00)*S171+(-1.864328e+00)*S172+(-2.822046e+00)*S173+8.245484e+00*S174+0.000000e+00*S175+(-6.548943e+00)*S176+(-7.061757e-01)*S177+0.000000e+00*S178+(-1.147366e+01)*S179'
.param V59_part19='V59_part18+1.228362e+00*S180+2.417045e+00*S181+0.000000e+00*S182+0.000000e+00*S183+3.140023e+00*S184+0.000000e+00*S185+8.774209e+00*S186+(-2.460397e+00)*S187+1.874428e-01*S188+0.000000e+00*S189'
.param V59_part20='V59_part19+9.994846e-01*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+6.328543e+00*S194+4.682758e-01*S195+2.418779e+00*S196+2.333059e+00*S197+8.301568e-01*S198+0.000000e+00*S199'
.param V59_part21='V59_part20+2.011194e+00*S200+0.000000e+00*S201+1.430486e+00*S202+1.222125e+00*S203+0.000000e+00*S204+(-1.815657e+00)*S205+(-8.147944e+00)*S206+(-5.586880e+00)*S207+0.000000e+00*S208+(-9.683835e+00)*S209'
.param V59_part22='V59_part21+1.930090e+00*S210+7.532243e-01*S211+1.257532e+00*S212+4.599360e-01*S213+2.554472e-01*S214+6.065724e-01*S215+0.000000e+00*S216+2.327211e+00*S217+0.000000e+00*S218+4.282745e+00*S219'
.param V59_part23='V59_part22+0.000000e+00*S220+9.025725e-01*S221+0.000000e+00*S222+(-1.041602e+00)*S223+0.000000e+00*S224+6.155385e-01*S225+2.279670e+00*S226+(-1.675333e+00)*S227+(-6.232508e+00)*S228+1.138281e+01*S229'
.param V59_part24='V59_part23+(-1.292494e+00)*S230+0.000000e+00*S231+(-1.136169e+01)*S232+(-3.827082e-01)*S233+1.549777e+01*S234+0.000000e+00*S235+(-2.008595e+00)*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V59_part25='V59_part24+0.000000e+00*S240+2.923629e+00*S241+1.382985e+00*S242+0.000000e+00*S243+0.000000e+00*S244+5.405469e+00*S245+3.766713e-01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V59_part26='V59_part25+0.000000e+00*S250+2.732932e+00*S251+0.000000e+00*S252+1.902000e+01*S253+1.080442e+01*S254+0.000000e+00*S255+0.000000e+00*S256+2.282770e+00*S257+4.907590e+00*S258+4.883505e-01*S259'
.param V59_part27='V59_part26+3.137883e+00*S260+(-3.191963e-02)*S261+3.013212e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+(-3.082577e-01)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V59_part28='V59_part27+(-3.738558e+00)*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+1.252594e+01*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V59_part29='V59_part28+0.000000e+00*S280+2.186565e+01*S281+0.000000e+00*S282+0.000000e+00*S283+3.281265e+00*S284+1.086910e+01*S285+(-7.097635e+00)*S286+(-1.578934e+00)*S287+1.268947e+00*S288+1.319205e+01*S289'
.param V59_part30='V59_part29+(-3.082301e+00)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+6.756247e+00*S294+0.000000e+00*S295+1.962297e+00*S296+(-1.940264e-01)*S297+5.457988e+00*S298+1.629329e+01*S299'
.param V59_part31='V59_part30+(-4.721848e+00)*S300+6.059563e-01*S301+(-4.518442e+00)*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+1.823438e+00*S308+0.000000e+00*S309'
.param V59='V59_part31+0.000000e+00*S310+(-3.577682e+00)*S311+1.178960e+01*S312+0.000000e+00*S313+8.173339e-01*S314'
.param V60_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.226798e+00)*S2+0.000000e+00*S3+(-1.757308e-02)*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+(-1.306578e-01)*S8+0.000000e+00*S9'
.param V60_part2='V60_part1+(-6.476902e-01)*S10+(-3.270087e-01)*S11+0.000000e+00*S12+(-6.445988e-01)*S13+(-1.969904e+00)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.630133e-01*S18+0.000000e+00*S19'
.param V60_part3='V60_part2+0.000000e+00*S20+(-3.254907e-01)*S21+0.000000e+00*S22+(-4.255763e+00)*S23+(-6.446866e-01)*S24+(-6.752961e-01)*S25+(-1.499664e+00)*S26+(-1.233717e-01)*S27+(-3.357561e+00)*S28+(-2.476164e+00)*S29'
.param V60_part4='V60_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-6.520824e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V60_part5='V60_part4+(-3.164068e+00)*S40+1.958342e+00*S41+0.000000e+00*S42+(-1.379559e+00)*S43+2.027274e+00*S44+0.000000e+00*S45+(-2.665009e+00)*S46+(-5.091008e+00)*S47+0.000000e+00*S48+(-4.260073e+00)*S49'
.param V60_part6='V60_part5+0.000000e+00*S50+(-6.548362e+00)*S51+(-4.715482e+00)*S52+0.000000e+00*S53+(-2.047574e+00)*S54+(-2.046439e+00)*S55+6.634941e+00*S56+(-4.126055e-01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V60_part7='V60_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+(-4.056692e+00)*S67+3.956263e+00*S68+(-4.543022e-01)*S69'
.param V60_part8='V60_part7+(-3.662924e+00)*S70+0.000000e+00*S71+1.099550e+01*S72+0.000000e+00*S73+(-1.300439e+01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V60_part9='V60_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-2.972017e+00)*S83+0.000000e+00*S84+(-5.526794e+00)*S85+(-5.298018e+00)*S86+(-5.342857e+00)*S87+(-3.507576e+00)*S88+(-1.612428e+00)*S89'
.param V60_part10='V60_part9+0.000000e+00*S90+0.000000e+00*S91+(-1.316025e+00)*S92+0.000000e+00*S93+0.000000e+00*S94+(-5.047454e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V60_part11='V60_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-5.173424e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V60_part12='V60_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+(-1.368021e+01)*S113+(-3.402669e+00)*S114+0.000000e+00*S115+(-1.390687e+01)*S116+(-3.185769e+00)*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V60_part13='V60_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V60_part14='V60_part13+0.000000e+00*S130+0.000000e+00*S131+(-4.315069e+00)*S132+(-9.484882e+00)*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V60_part15='V60_part14+0.000000e+00*S140+(-1.389892e+00)*S141+0.000000e+00*S142+(-4.513648e-01)*S143+(-2.901340e+00)*S144+(-1.433162e+00)*S145+0.000000e+00*S146+(-4.249666e+00)*S147+(-6.143544e+00)*S148+0.000000e+00*S149'
.param V60_part16='V60_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+(-1.099048e+01)*S156+0.000000e+00*S157+0.000000e+00*S158+(-5.757926e+00)*S159'
.param V60_part17='V60_part16+0.000000e+00*S160+0.000000e+00*S161+(-7.910486e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V60_part18='V60_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+(-1.441743e+01)*S173+(-7.303482e+00)*S174+(-1.229482e+01)*S175+0.000000e+00*S176+(-7.802454e+00)*S177+(-1.520139e+01)*S178+0.000000e+00*S179'
.param V60_part19='V60_part18+0.000000e+00*S180+0.000000e+00*S181+(-6.343317e+00)*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+(-4.464849e+00)*S186+0.000000e+00*S187+0.000000e+00*S188+(-7.859684e+00)*S189'
.param V60_part20='V60_part19+(-1.321135e+01)*S190+(-1.846336e+01)*S191+(-8.642984e+00)*S192+(-1.756943e+01)*S193+(-2.238811e+01)*S194+0.000000e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+6.164535e-01*S199'
.param V60_part21='V60_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+(-2.451080e+01)*S206+(-8.190521e+00)*S207+(-1.262976e+01)*S208+(-1.945726e+01)*S209'
.param V60_part22='V60_part21+0.000000e+00*S210+0.000000e+00*S211+(-8.827592e+00)*S212+(-8.829267e+00)*S213+0.000000e+00*S214+(-1.057345e+01)*S215+(-5.208532e+00)*S216+(-1.329752e+01)*S217+(-1.241677e+01)*S218+(-9.721871e+00)*S219'
.param V60_part23='V60_part22+(-1.221975e+01)*S220+(-6.882390e+01)*S221+(-8.939237e+00)*S222+(-4.017982e+01)*S223+(-7.035380e+01)*S224+(-2.662998e+00)*S225+0.000000e+00*S226+0.000000e+00*S227+(-3.817625e+00)*S228+(-9.223091e+00)*S229'
.param V60_part24='V60_part23+0.000000e+00*S230+(-4.129283e+00)*S231+(-9.541891e+00)*S232+(-2.657198e+01)*S233+(-1.025320e+01)*S234+(-2.046730e+01)*S235+(-3.287305e+01)*S236+(-1.027752e+01)*S237+(-2.859632e+01)*S238+(-3.817696e+01)*S239'
.param V60_part25='V60_part24+0.000000e+00*S240+0.000000e+00*S241+(-2.107915e+01)*S242+(-6.330196e+00)*S243+(-1.314342e+01)*S244+(-3.493710e+01)*S245+(-8.550908e+00)*S246+(-1.854145e+01)*S247+(-3.700236e+01)*S248+(-1.077829e+01)*S249'
.param V60_part26='V60_part25+(-2.335694e+01)*S250+(-4.292240e+01)*S251+(-9.795408e+00)*S252+(-2.309200e+01)*S253+(-3.460678e+01)*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+(-2.124714e+00)*S258+0.000000e+00*S259'
.param V60_part27='V60_part26+0.000000e+00*S260+(-7.337058e+00)*S261+(-1.415062e+01)*S262+(-1.216097e+01)*S263+(-7.777420e+00)*S264+(-1.656004e+01)*S265+(-2.822099e+01)*S266+(-1.194595e+01)*S267+(-1.836656e+01)*S268+(-3.182230e+01)*S269'
.param V60_part28='V60_part27+(-2.871181e+00)*S270+0.000000e+00*S271+(-1.661061e+01)*S272+(-6.815162e+00)*S273+(-6.163522e+00)*S274+(-4.495119e+01)*S275+(-8.622353e+00)*S276+(-1.834382e+01)*S277+(-4.349240e+01)*S278+(-1.083778e+01)*S279'
.param V60_part29='V60_part28+(-2.600816e+01)*S280+(-4.333873e+01)*S281+(-1.082376e+01)*S282+(-2.030471e+01)*S283+(-4.636969e+01)*S284+(-4.364480e+00)*S285+(-1.149329e+01)*S286+(-3.159371e+01)*S287+(-7.709181e+00)*S288+(-1.690376e+01)*S289'
.param V60_part30='V60_part29+(-3.736837e+01)*S290+(-9.755301e+00)*S291+(-2.633806e+01)*S292+(-4.348997e+01)*S293+(-1.158554e+01)*S294+(-3.606318e+01)*S295+(-2.671780e+01)*S296+(-1.270671e+01)*S297+(-3.512284e+01)*S298+(-4.893550e+01)*S299'
.param V60_part31='V60_part30+(-3.712111e+00)*S300+0.000000e+00*S301+(-1.529592e+01)*S302+(-8.569841e+00)*S303+(-1.909807e+01)*S304+(-3.293205e+01)*S305+(-1.031939e+01)*S306+(-3.198243e+01)*S307+(-4.314483e+01)*S308+(-1.287049e+01)*S309'
.param V60='V60_part31+(-3.242173e+01)*S310+(-5.046417e+01)*S311+(-1.541784e+01)*S312+(-3.410972e+01)*S313+(-4.548177e+01)*S314'
.param V61_part1='0.000000e+00*S0+0.000000e+00*S1+3.115126e+00*S2+0.000000e+00*S3+1.120773e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.977043e+00*S8+0.000000e+00*S9'
.param V61_part2='V61_part1+2.030184e+00*S10+2.948425e+00*S11+0.000000e+00*S12+2.791765e+00*S13+3.790755e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.211022e+00*S18+0.000000e+00*S19'
.param V61_part3='V61_part2+0.000000e+00*S20+2.624645e+00*S21+0.000000e+00*S22+6.754424e+00*S23+3.479326e+00*S24+3.274863e+00*S25+3.986227e+00*S26+1.779920e+00*S27+4.931908e+00*S28+4.890276e+00*S29'
.param V61_part4='V61_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+9.801683e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V61_part5='V61_part4+6.049963e+00*S40+2.275729e+00*S41+0.000000e+00*S42+2.395438e+00*S43+3.864011e+00*S44+0.000000e+00*S45+3.632334e+00*S46+1.402895e+01*S47+0.000000e+00*S48+5.658979e+00*S49'
.param V61_part6='V61_part5+0.000000e+00*S50+1.727688e+01*S51+9.382104e+00*S52+0.000000e+00*S53+5.273287e+00*S54+5.991926e+00*S55+(-1.732277e-01)*S56+1.715856e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V61_part7='V61_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+7.602398e+00*S67+(-5.496975e-01)*S68+2.410007e+00*S69'
.param V61_part8='V61_part7+4.998306e+00*S70+0.000000e+00*S71+(-1.118499e+01)*S72+0.000000e+00*S73+1.316512e+01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V61_part9='V61_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+3.170155e+00*S83+0.000000e+00*S84+6.232660e+00*S85+4.234217e+00*S86+5.641398e+00*S87+3.759472e+00*S88+4.698045e+00*S89'
.param V61_part10='V61_part9+0.000000e+00*S90+0.000000e+00*S91+4.041756e+00*S92+0.000000e+00*S93+0.000000e+00*S94+1.275855e+01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V61_part11='V61_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+1.541396e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V61_part12='V61_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+1.477998e+01*S113+9.067080e+00*S114+0.000000e+00*S115+1.435680e+01*S116+3.912733e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V61_part13='V61_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V61_part14='V61_part13+0.000000e+00*S130+0.000000e+00*S131+5.004377e+00*S132+1.035664e+01*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V61_part15='V61_part14+0.000000e+00*S140+4.538902e+00*S141+0.000000e+00*S142+1.366074e+00*S143+4.962295e+00*S144+3.831689e+00*S145+0.000000e+00*S146+8.805962e+00*S147+1.009211e+01*S148+0.000000e+00*S149'
.param V61_part16='V61_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+1.671516e+01*S156+0.000000e+00*S157+0.000000e+00*S158+9.012260e+00*S159'
.param V61_part17='V61_part16+0.000000e+00*S160+0.000000e+00*S161+1.135857e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V61_part18='V61_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+2.808354e+01*S173+7.310282e+00*S174+1.363268e+01*S175+0.000000e+00*S176+8.560088e+00*S177+1.561467e+01*S178+0.000000e+00*S179'
.param V61_part19='V61_part18+0.000000e+00*S180+0.000000e+00*S181+8.667450e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+5.576309e+00*S186+0.000000e+00*S187+0.000000e+00*S188+9.240180e+00*S189'
.param V61_part20='V61_part19+2.001175e+01*S190+2.587443e+01*S191+1.024913e+01*S192+1.556589e+01*S193+2.308743e+01*S194+0.000000e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+3.593754e+00*S199'
.param V61_part21='V61_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+2.313525e+01*S206+8.080143e+00*S207+1.174161e+01*S208+2.214690e+01*S209'
.param V61_part22='V61_part21+0.000000e+00*S210+0.000000e+00*S211+1.073010e+01*S212+2.230028e+01*S213+0.000000e+00*S214+1.849185e+01*S215+9.908859e+00*S216+1.532816e+01*S217+1.881834e+01*S218+1.557377e+01*S219'
.param V61_part23='V61_part22+1.747569e+01*S220+5.256438e+01*S221+9.657244e+00*S222+3.376216e+01*S223+5.048684e+01*S224+1.022935e+01*S225+0.000000e+00*S226+0.000000e+00*S227+7.913621e+00*S228+1.469833e+01*S229'
.param V61_part24='V61_part23+0.000000e+00*S230+9.493549e+00*S231+1.255602e+01*S232+2.378540e+01*S233+1.339819e+01*S234+2.074933e+01*S235+2.642531e+01*S236+1.200686e+01*S237+2.177134e+01*S238+3.219857e+01*S239'
.param V61_part25='V61_part24+0.000000e+00*S240+0.000000e+00*S241+2.657798e+01*S242+1.261531e+01*S243+1.345568e+01*S244+3.107188e+01*S245+2.077870e+01*S246+2.311754e+01*S247+3.537562e+01*S248+1.292628e+01*S249'
.param V61_part26='V61_part25+2.228372e+01*S250+3.576731e+01*S251+1.213071e+01*S252+1.487251e+01*S253+2.942024e+01*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+4.260505e+00*S258+0.000000e+00*S259'
.param V61_part27='V61_part26+0.000000e+00*S260+9.489282e+00*S261+1.744634e+01*S262+1.872912e+01*S263+9.385349e+00*S264+1.805299e+01*S265+2.726360e+01*S266+1.110758e+01*S267+1.167915e+01*S268+2.694606e+01*S269'
.param V61_part28='V61_part27+5.150449e+00*S270+0.000000e+00*S271+2.560477e+01*S272+1.217307e+01*S273+1.194446e+01*S274+4.356851e+01*S275+1.469377e+01*S276+1.965197e+01*S277+4.071728e+01*S278+1.255453e+01*S279'
.param V61_part29='V61_part28+2.449090e+01*S280+3.600675e+01*S281+1.291519e+01*S282+2.305076e+01*S283+3.576225e+01*S284+8.007515e+00*S285+2.284649e+01*S286+2.737417e+01*S287+1.646278e+01*S288+2.085938e+01*S289'
.param V61_part30='V61_part29+4.013862e+01*S290+1.495745e+01*S291+1.721290e+01*S292+3.530698e+01*S293+1.596439e+01*S294+3.063898e+01*S295+2.742568e+01*S296+1.364917e+01*S297+2.852925e+01*S298+3.848184e+01*S299'
.param V61_part31='V61_part30+8.018161e+00*S300+0.000000e+00*S301+1.990872e+01*S302+1.395082e+01*S303+1.999180e+01*S304+3.916012e+01*S305+1.354022e+01*S306+1.777561e+01*S307+3.788797e+01*S308+1.454824e+01*S309'
.param V61='V61_part31+2.265349e+01*S310+4.343714e+01*S311+1.433185e+01*S312+2.345301e+01*S313+3.114171e+01*S314'
.param V62_part1='0.000000e+00*S0+0.000000e+00*S1+3.335874e+00*S2+0.000000e+00*S3+4.373897e-01*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.385058e+00*S8+0.000000e+00*S9'
.param V62_part2='V62_part1+3.661097e+00*S10+2.510409e+00*S11+0.000000e+00*S12+3.099658e+00*S13+3.283138e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.282580e+00*S18+0.000000e+00*S19'
.param V62_part3='V62_part2+0.000000e+00*S20+4.597795e+00*S21+0.000000e+00*S22+7.889652e+00*S23+3.999719e+00*S24+4.065619e+00*S25+3.951412e+00*S26+7.726112e+00*S27+7.826032e+00*S28+7.398719e+00*S29'
.param V62_part4='V62_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+9.902534e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V62_part5='V62_part4+5.979275e+00*S40+(-2.516609e+00)*S41+0.000000e+00*S42+3.127857e+00*S43+1.707955e-01*S44+0.000000e+00*S45+8.498610e+00*S46+7.237419e+00*S47+0.000000e+00*S48+8.073460e+00*S49'
.param V62_part6='V62_part5+0.000000e+00*S50+1.404851e+01*S51+1.348156e+01*S52+0.000000e+00*S53+3.628374e+00*S54+2.607151e+00*S55+(-4.221611e+00)*S56+2.025028e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V62_part7='V62_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+2.055207e+01*S67+(-1.821445e+00)*S68+1.109403e+01*S69'
.param V62_part8='V62_part7+2.260407e+01*S70+0.000000e+00*S71+1.513126e+01*S72+0.000000e+00*S73+2.398368e+01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V62_part9='V62_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+5.874518e+00*S83+0.000000e+00*S84+5.920436e+00*S85+5.830553e+00*S86+3.916441e+00*S87+4.104997e+00*S88+4.109922e+00*S89'
.param V62_part10='V62_part9+0.000000e+00*S90+0.000000e+00*S91+4.938492e+00*S92+0.000000e+00*S93+0.000000e+00*S94+1.112715e+01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V62_part11='V62_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+5.893336e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V62_part12='V62_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+1.302017e+01*S113+1.093071e+01*S114+0.000000e+00*S115+1.509189e+01*S116+9.822425e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V62_part13='V62_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V62_part14='V62_part13+0.000000e+00*S130+0.000000e+00*S131+1.540009e+01*S132+1.621381e+01*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V62_part15='V62_part14+0.000000e+00*S140+4.891925e+00*S141+0.000000e+00*S142+1.355623e+00*S143+3.874881e+00*S144+2.114775e+00*S145+0.000000e+00*S146+6.173012e+00*S147+6.686112e+00*S148+0.000000e+00*S149'
.param V62_part16='V62_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+2.135867e+01*S156+0.000000e+00*S157+0.000000e+00*S158+9.308530e+00*S159'
.param V62_part17='V62_part16+0.000000e+00*S160+0.000000e+00*S161+2.297219e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V62_part18='V62_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+8.962667e+00*S173+2.528115e+01*S174+2.399117e+01*S175+0.000000e+00*S176+2.745307e+01*S177+3.060885e+01*S178+0.000000e+00*S179'
.param V62_part19='V62_part18+0.000000e+00*S180+0.000000e+00*S181+1.274293e+01*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+2.030721e+01*S186+0.000000e+00*S187+0.000000e+00*S188+2.977872e+01*S189'
.param V62_part20='V62_part19+4.069424e+01*S190+1.249239e+01*S191+2.838438e+01*S192+3.692352e+01*S193+4.422112e+01*S194+0.000000e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+3.909508e+00*S199'
.param V62_part21='V62_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+2.503379e+01*S206+1.764390e+01*S207+2.135472e+01*S208+2.495331e+01*S209'
.param V62_part22='V62_part21+0.000000e+00*S210+0.000000e+00*S211+1.414177e+01*S212+2.918049e+01*S213+0.000000e+00*S214+1.622486e+01*S215+1.892121e+01*S216+3.877877e+01*S217+1.834812e+01*S218+4.065470e+01*S219'
.param V62_part23='V62_part22+2.559168e+01*S220+9.368903e+01*S221+3.229161e+01*S222+7.196006e+01*S223+1.063880e+02*S224+5.727346e+00*S225+0.000000e+00*S226+0.000000e+00*S227+1.852031e+01*S228+2.516901e+01*S229'
.param V62_part24='V62_part23+0.000000e+00*S230+1.551506e+01*S231+2.256322e+01*S232+3.495843e+01*S233+3.713302e+01*S234+4.189908e+01*S235+4.391286e+01*S236+3.394176e+01*S237+5.340553e+01*S238+5.632246e+01*S239'
.param V62_part25='V62_part24+0.000000e+00*S240+0.000000e+00*S241+3.196756e+01*S242+2.649916e+01*S243+3.816078e+01*S244+5.069923e+01*S245+3.104854e+01*S246+4.046281e+01*S247+5.790914e+01*S248+4.419583e+01*S249'
.param V62_part26='V62_part25+5.137143e+01*S250+7.694891e+01*S251+4.279568e+01*S252+6.029672e+01*S253+6.215503e+01*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+9.915841e+00*S258+0.000000e+00*S259'
.param V62_part27='V62_part26+0.000000e+00*S260+2.033823e+01*S261+2.496844e+01*S262+2.002841e+01*S263+2.344766e+01*S264+3.185243e+01*S265+2.451168e+01*S266+3.574217e+01*S267+3.676951e+01*S268+3.460446e+01*S269'
.param V62_part28='V62_part27+1.808627e+01*S270+0.000000e+00*S271+3.534331e+01*S272+2.922493e+01*S273+1.994982e+01*S274+6.004346e+01*S275+3.534808e+01*S276+3.736453e+01*S277+6.026567e+01*S278+4.347259e+01*S279'
.param V62_part29='V62_part28+5.342729e+01*S280+6.583651e+01*S281+4.839264e+01*S282+5.017532e+01*S283+7.011453e+01*S284+2.685119e+01*S285+2.356824e+01*S286+5.594582e+01*S287+3.377405e+01*S288+4.798749e+01*S289'
.param V62_part30='V62_part29+6.662980e+01*S290+4.389197e+01*S291+6.500959e+01*S292+7.463958e+01*S293+5.243987e+01*S294+6.796954e+01*S295+7.200580e+01*S296+6.297285e+01*S297+8.181704e+01*S298+1.077114e+02*S299'
.param V62_part31='V62_part30+1.428339e+01*S300+0.000000e+00*S301+1.934459e+01*S302+2.715270e+01*S303+4.327810e+01*S304+5.168446e+01*S305+3.581711e+01*S306+7.047571e+01*S307+7.830135e+01*S308+3.931705e+01*S309'
.param V62='V62_part31+6.080609e+01*S310+8.701373e+01*S311+5.569978e+01*S312+6.263685e+01*S313+8.439097e+01*S314'
.param V63_part1='0.000000e+00*S0+0.000000e+00*S1+1.734212e+00*S2+0.000000e+00*S3+(-3.065640e-01)*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.653281e-01*S8+0.000000e+00*S9'
.param V63_part2='V63_part1+6.151158e-02*S10+1.319806e-01*S11+0.000000e+00*S12+8.045999e-02*S13+4.241420e-01*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+6.494503e-01*S18+0.000000e+00*S19'
.param V63_part3='V63_part2+0.000000e+00*S20+3.861733e-01*S21+0.000000e+00*S22+1.865353e+00*S23+3.500900e-01*S24+(-1.709086e-01)*S25+(-4.547583e-01)*S26+1.080922e+00*S27+1.593120e+00*S28+1.357774e+00*S29'
.param V63_part4='V63_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-6.601841e-01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V63_part5='V63_part4+(-1.333422e+00)*S40+(-4.412647e-02)*S41+0.000000e+00*S42+(-3.953893e-01)*S43+8.159990e-01*S44+0.000000e+00*S45+1.501073e+00*S46+2.741297e+00*S47+0.000000e+00*S48+(-2.027609e-01)*S49'
.param V63_part6='V63_part5+0.000000e+00*S50+2.417778e-01*S51+2.409769e+00*S52+0.000000e+00*S53+2.188986e+00*S54+2.148122e+00*S55+8.196140e-01*S56+(-4.342609e-01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V63_part7='V63_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.732953e+00*S67+1.361344e-01*S68+6.640277e-01*S69'
.param V63_part8='V63_part7+1.732294e+00*S70+0.000000e+00*S71+(-6.589651e+01)*S72+0.000000e+00*S73+3.018954e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V63_part9='V63_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-8.087610e-01)*S83+0.000000e+00*S84+(-2.035199e+00)*S85+(-2.193163e+00)*S86+(-1.908344e+00)*S87+(-1.899359e+00)*S88+(-1.464543e+00)*S89'
.param V63_part10='V63_part9+0.000000e+00*S90+0.000000e+00*S91+8.906479e-01*S92+0.000000e+00*S93+0.000000e+00*S94+2.230596e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V63_part11='V63_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+2.137945e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V63_part12='V63_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+(-4.420563e-01)*S113+4.329420e+00*S114+0.000000e+00*S115+2.936507e+00*S116+2.170353e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V63_part13='V63_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V63_part14='V63_part13+0.000000e+00*S130+0.000000e+00*S131+1.981979e+00*S132+2.643078e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V63_part15='V63_part14+0.000000e+00*S140+(-8.057140e-01)*S141+0.000000e+00*S142+(-3.540885e-01)*S143+(-1.437805e+00)*S144+(-1.806826e+00)*S145+0.000000e+00*S146+2.464154e+00*S147+3.288362e+00*S148+0.000000e+00*S149'
.param V63_part16='V63_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+2.378608e+00*S156+0.000000e+00*S157+0.000000e+00*S158+1.589964e+00*S159'
.param V63_part17='V63_part16+0.000000e+00*S160+0.000000e+00*S161+1.656070e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V63_part18='V63_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+3.660268e+00*S173+1.812193e+00*S174+2.923206e+00*S175+0.000000e+00*S176+1.635147e+00*S177+4.549315e+00*S178+0.000000e+00*S179'
.param V63_part19='V63_part18+0.000000e+00*S180+0.000000e+00*S181+5.216155e-01*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+1.860485e+00*S186+0.000000e+00*S187+0.000000e+00*S188+2.598166e+00*S189'
.param V63_part20='V63_part19+3.803389e+00*S190+1.994213e+00*S191+1.698618e+00*S192+3.436464e+00*S193+3.443897e+00*S194+0.000000e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+(-3.633366e-01)*S199'
.param V63_part21='V63_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+3.355645e+00*S206+6.701384e-01*S207+2.072052e+00*S208+3.235529e+00*S209'
.param V63_part22='V63_part21+0.000000e+00*S210+0.000000e+00*S211+(-5.334251e-01)*S212+1.753306e+00*S213+0.000000e+00*S214+1.144331e+00*S215+1.454622e+00*S216+3.609570e+00*S217+2.677713e+00*S218+2.991491e+00*S219'
.param V63_part23='V63_part22+3.024585e+00*S220+7.733531e+00*S221+2.261090e+00*S222+6.452666e+00*S223+6.478919e+00*S224+(-1.602772e-01)*S225+0.000000e+00*S226+0.000000e+00*S227+1.474285e+00*S228+1.338376e+00*S229'
.param V63_part24='V63_part23+0.000000e+00*S230+1.108675e+00*S231+1.343797e+00*S232+1.120572e-01*S233+1.166287e+00*S234+2.006978e+00*S235+7.138052e-01*S236+2.064048e+00*S237+3.317804e+00*S238+3.205049e+00*S239'
.param V63_part25='V63_part24+0.000000e+00*S240+0.000000e+00*S241+(-4.150866e-02)*S242+2.200427e+00*S243+1.854151e+00*S244+1.022785e+00*S245+2.789690e+00*S246+3.613959e+00*S247+3.587272e+00*S248+1.478826e+00*S249'
.param V63_part26='V63_part25+2.648020e+00*S250+4.781724e+00*S251+1.656149e+00*S252+3.611678e+00*S253+4.227517e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+(-4.543579e-02)*S258+0.000000e+00*S259'
.param V63_part27='V63_part26+0.000000e+00*S260+7.324366e-01*S261+9.034829e-01*S262+2.681267e+00*S263+2.219267e+00*S264+2.777493e+00*S265+1.118950e+00*S266+5.213668e-02*S267+5.310355e-01*S268+1.402253e+00*S269'
.param V63_part28='V63_part27+1.186521e+00*S270+0.000000e+00*S271+4.518328e+00*S272+1.817164e+00*S273+1.114209e+00*S274+4.044991e+00*S275+1.518641e+00*S276+2.821907e+00*S277+3.901138e+00*S278+1.751472e+00*S279'
.param V63_part29='V63_part28+1.506083e+00*S280+4.477612e+00*S281+1.699508e+00*S282+2.019037e+00*S283+2.816289e+00*S284+1.528058e+00*S285+6.755620e-01*S286+(-1.395101e+00)*S287+1.377541e+00*S288+1.229984e+00*S289'
.param V63_part30='V63_part29+1.775251e+00*S290+1.434150e+00*S291+1.241702e+00*S292+2.014947e+00*S293+2.340730e+00*S294+1.956963e+00*S295+4.866188e+00*S296+1.926027e+00*S297+2.739492e+00*S298+6.618079e+00*S299'
.param V63_part31='V63_part30+1.247130e-01*S300+0.000000e+00*S301+(-4.873182e-01)*S302+1.078701e-01*S303+4.642802e-01*S304+3.292075e+00*S305+1.135105e-01*S306+7.559659e-01*S307+4.219159e+00*S308+4.967250e-01*S309'
.param V63='V63_part31+(-4.148434e-03)*S310+3.832712e+00*S311+7.805175e-01*S312+(-1.026137e-01)*S313+3.697095e+00*S314'
.param V64_part1='0.000000e+00*S0+0.000000e+00*S1+1.528338e-02*S2+0.000000e+00*S3+(-5.380549e-03)*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.823089e-03*S8+0.000000e+00*S9'
.param V64_part2='V64_part1+(-3.472525e-02)*S10+(-1.668779e-03)*S11+0.000000e+00*S12+(-2.162908e-04)*S13+(-6.129100e-03)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+1.645182e-02*S18+0.000000e+00*S19'
.param V64_part3='V64_part2+0.000000e+00*S20+1.987955e-03*S21+0.000000e+00*S22+2.061271e-02*S23+1.965970e-03*S24+9.750269e-04*S25+1.297658e-02*S26+1.382124e-02*S27+2.361786e-02*S28+(-8.323074e-03)*S29'
.param V64_part4='V64_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+2.532181e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V64_part5='V64_part4+2.133342e-01*S40+2.193770e-01*S41+0.000000e+00*S42+6.590192e-01*S43+8.858521e-01*S44+0.000000e+00*S45+2.685882e-01*S46+1.820132e-01*S47+0.000000e+00*S48+7.693928e-01*S49'
.param V64_part6='V64_part5+0.000000e+00*S50+5.713113e-01*S51+6.788355e-01*S52+0.000000e+00*S53+3.977389e-01*S54+4.786490e-01*S55+3.250892e+00*S56+2.093235e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V64_part7='V64_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+2.437064e+00*S67+2.783765e+00*S68+2.260210e+00*S69'
.param V64_part8='V64_part7+2.938189e+00*S70+0.000000e+00*S71+2.315350e+00*S72+0.000000e+00*S73+3.564867e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V64_part9='V64_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+2.322479e-01*S83+0.000000e+00*S84+4.755464e-01*S85+5.101035e-01*S86+8.563549e-01*S87+3.533591e-01*S88+4.611625e-02*S89'
.param V64_part10='V64_part9+0.000000e+00*S90+0.000000e+00*S91+2.739197e-01*S92+0.000000e+00*S93+0.000000e+00*S94+9.342127e-01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V64_part11='V64_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+3.271179e-01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V64_part12='V64_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+8.508948e-01*S113+7.046401e-01*S114+0.000000e+00*S115+3.741274e+00*S116+1.129589e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V64_part13='V64_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V64_part14='V64_part13+0.000000e+00*S130+0.000000e+00*S131+3.584677e+00*S132+4.733024e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V64_part15='V64_part14+0.000000e+00*S140+5.896682e-02*S141+0.000000e+00*S142+1.357095e-03*S143+4.779417e-02*S144+2.179296e-01*S145+0.000000e+00*S146+(-1.688227e-04)*S147+2.923563e-01*S148+0.000000e+00*S149'
.param V64_part16='V64_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+3.015283e-01*S156+0.000000e+00*S157+0.000000e+00*S158+1.917934e+00*S159'
.param V64_part17='V64_part16+0.000000e+00*S160+0.000000e+00*S161+1.177781e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V64_part18='V64_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+1.614329e+00*S173+4.128164e+00*S174+4.930725e+00*S175+0.000000e+00*S176+4.036363e+00*S177+5.268169e+00*S178+0.000000e+00*S179'
.param V64_part19='V64_part18+0.000000e+00*S180+0.000000e+00*S181+6.500378e-01*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+3.454297e+00*S186+0.000000e+00*S187+0.000000e+00*S188+4.400466e+00*S189'
.param V64_part20='V64_part19+2.471286e+00*S190+6.749238e+00*S191+4.033568e+00*S192+6.032614e+00*S193+5.292268e+00*S194+0.000000e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+2.049066e-01*S199'
.param V64_part21='V64_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+7.950748e+00*S206+4.331531e+00*S207+6.441129e+00*S208+5.695066e+00*S209'
.param V64_part22='V64_part21+0.000000e+00*S210+0.000000e+00*S211+8.731714e-01*S212+1.769601e+00*S213+0.000000e+00*S214+1.491342e+00*S215+3.433555e+00*S216+2.856170e+00*S217+3.147671e+00*S218+2.138576e+00*S219'
.param V64_part23='V64_part22+5.830208e+00*S220+6.103240e+00*S221+5.417865e+00*S222+4.467481e+00*S223+6.114504e+00*S224+8.608878e-01*S225+0.000000e+00*S226+0.000000e+00*S227+3.433152e+00*S228+4.761389e+00*S229'
.param V64_part24='V64_part23+0.000000e+00*S230+3.240763e+00*S231+4.293211e+00*S232+6.497129e+00*S233+4.475545e+00*S234+5.907852e+00*S235+7.432487e+00*S236+3.283940e+00*S237+7.661911e+00*S238+8.448854e+00*S239'
.param V64_part25='V64_part24+0.000000e+00*S240+0.000000e+00*S241+3.900742e+00*S242+3.520633e+00*S243+4.821983e+00*S244+6.978278e+00*S245+1.770318e+00*S246+6.090797e+00*S247+8.259579e+00*S248+4.412081e+00*S249'
.param V64_part26='V64_part25+6.593710e+00*S250+5.007589e+00*S251+4.910312e+00*S252+7.423668e+00*S253+7.210887e+00*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+2.302434e+00*S258+0.000000e+00*S259'
.param V64_part27='V64_part26+0.000000e+00*S260+3.921727e+00*S261+5.169649e+00*S262+4.856602e+00*S263+4.684551e+00*S264+6.028036e+00*S265+7.389021e+00*S266+5.805750e+00*S267+5.495122e+00*S268+6.339816e+00*S269'
.param V64_part28='V64_part27+3.027369e+00*S270+0.000000e+00*S271+3.503680e+00*S272+4.251282e+00*S273+1.913955e+00*S274+7.858159e+00*S275+4.226550e+00*S276+5.539458e+00*S277+9.023641e+00*S278+5.440363e+00*S279'
.param V64_part29='V64_part28+6.215113e+00*S280+9.427691e+00*S281+5.404181e+00*S282+8.011343e+00*S283+9.273297e+00*S284+3.557873e+00*S285+5.258992e+00*S286+1.401525e+00*S287+3.398521e+00*S288+5.978953e+00*S289'
.param V64_part30='V64_part29+3.400803e+00*S290+4.210248e+00*S291+6.832899e+00*S292+9.158291e+00*S293+4.327715e+00*S294+6.948291e+00*S295+3.640782e+00*S296+6.231982e+00*S297+8.011138e+00*S298+5.669655e+00*S299'
.param V64_part31='V64_part30+2.351998e+00*S300+0.000000e+00*S301+4.184561e+00*S302+4.312017e+00*S303+5.222092e+00*S304+5.075951e+00*S305+4.544528e+00*S306+5.314847e+00*S307+5.405146e+00*S308+5.112571e+00*S309'
.param V64='V64_part31+7.787315e+00*S310+5.600395e+00*S311+6.163755e+00*S312+7.856915e+00*S313+7.329193e+00*S314'
.param V65_part1='7.372240e+00*S0+8.275118e+00*S1+3.407667e+00*S2+2.455757e+01*S3+0.000000e+00*S4+1.426402e+01*S5+4.810512e+00*S6+5.478058e+00*S7+0.000000e+00*S8+3.709987e+01*S9'
.param V65_part2='V65_part1+0.000000e+00*S10+0.000000e+00*S11+3.939320e+01*S12+0.000000e+00*S13+0.000000e+00*S14+(-1.203077e+01)*S15+1.390785e+01*S16+1.544971e+01*S17+0.000000e+00*S18+1.530028e+01*S19'
.param V65_part3='V65_part2+3.493517e+00*S20+0.000000e+00*S21+7.639666e-01*S22+3.043751e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+4.784619e+00*S27+2.411501e+00*S28+2.230823e+00*S29'
.param V65_part4='V65_part3+7.102551e+00*S30+1.373859e+01*S31+8.465763e+00*S32+1.096031e+01*S33+(-2.523637e+01)*S34+8.093031e+00*S35+5.193377e+01*S36+5.449437e+00*S37+1.962779e+01*S38+1.769387e+01*S39'
.param V65_part5='V65_part4+5.829891e+00*S40+1.434245e+01*S41+3.270266e+02*S42+2.673559e+01*S43+1.010625e+00*S44+1.579264e+01*S45+1.879876e+01*S46+7.787605e+00*S47+5.064866e+01*S48+1.174283e+01*S49'
.param V65_part6='V65_part5+9.902614e+00*S50+1.910184e+01*S51+1.254173e+02*S52+7.000671e+00*S53+5.604484e+00*S54+6.987882e+00*S55+6.990218e+00*S56+4.014722e+00*S57+0.000000e+00*S58+5.942432e+00*S59'
.param V65_part7='V65_part6+1.332496e+01*S60+0.000000e+00*S61+1.503262e+01*S62+1.097046e+01*S63+(-1.412468e+00)*S64+7.455304e-01*S65+1.275246e+01*S66+2.911709e+00*S67+1.540725e+01*S68+2.329529e+00*S69'
.param V65_part8='V65_part7+2.469519e+00*S70+6.381434e-01*S71+4.613721e+01*S72+2.782821e+00*S73+2.924287e+01*S74+2.839503e+01*S75+9.857653e+01*S76+2.846498e+01*S77+0.000000e+00*S78+3.141075e+00*S79'
.param V65_part9='V65_part8+1.046186e+01*S80+1.274121e+01*S81+0.000000e+00*S82+6.466560e-01*S83+0.000000e+00*S84+1.729369e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V65_part10='V65_part9+0.000000e+00*S90+2.577648e+01*S91+1.109919e+02*S92+2.091427e+01*S93+6.556682e-01*S94+4.214114e+01*S95+7.982151e+00*S96+1.500955e+01*S97+3.170166e+01*S98+9.999963e+03*S99'
.param V65_part11='V65_part10+3.769345e+01*S100+3.378565e+00*S101+4.841190e+01*S102+4.119193e+01*S103+1.170815e+00*S104+1.403890e+02*S105+7.018289e+00*S106+6.679441e+00*S107+8.599048e+01*S108+1.321241e+01*S109'
.param V65_part12='V65_part11+6.034706e+00*S110+1.491997e+00*S111+9.876065e+01*S112+3.146131e+00*S113+5.964026e+00*S114+2.332376e+00*S115+4.349938e+00*S116+3.440541e+01*S117+1.781246e+00*S118+3.687210e+00*S119'
.param V65_part13='V65_part12+1.089136e+01*S120+1.041606e+01*S121+8.860610e+00*S122+6.482155e+01*S123+7.513682e+00*S124+2.172230e+00*S125+9.431961e+01*S126+8.362286e+01*S127+4.024619e+00*S128+1.310514e+03*S129'
.param V65_part14='V65_part13+6.664530e-01*S130+4.318031e+00*S131+4.607475e+00*S132+3.127444e+01*S133+4.384599e+00*S134+2.239055e+01*S135+1.015826e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V65_part15='V65_part14+2.037000e+00*S140+0.000000e+00*S141+1.216965e+01*S142+3.272982e+00*S143+0.000000e+00*S144+0.000000e+00*S145+(-4.620400e-02)*S146+4.063428e+00*S147+6.142963e+00*S148+4.177333e+00*S149'
.param V65_part16='V65_part15+8.365310e+01*S150+6.879190e+01*S151+2.956523e+00*S152+6.962389e+01*S153+3.265389e+00*S154+(-1.657588e-01)*S155+8.724004e+00*S156+5.825423e+00*S157+2.210770e+00*S158+2.044133e+01*S159'
.param V65_part17='V65_part16+3.942187e-01*S160+4.140349e+00*S161+5.330725e+00*S162+9.758091e+00*S163+4.522217e+00*S164+0.000000e+00*S165+4.725613e+00*S166+2.974088e+00*S167+5.540514e+00*S168+8.414933e+00*S169'
.param V65_part18='V65_part17+1.192173e+02*S170+4.575300e+00*S171+4.193665e+00*S172+9.083174e+03*S173+1.457135e+01*S174+5.533245e+00*S175+3.596404e+00*S176+9.309536e+00*S177+4.615804e+00*S178+6.725579e+00*S179'
.param V65_part19='V65_part18+4.746898e+01*S180+0.000000e+00*S181+9.012416e+01*S182+6.608670e-01*S183+5.283944e+00*S184+1.180363e+00*S185+9.498770e+00*S186+6.521192e-01*S187+5.321304e-01*S188+1.403153e+01*S189'
.param V65_part20='V65_part19+5.936185e+00*S190+8.668655e+00*S191+1.361426e+01*S192+4.904058e+00*S193+6.057418e+00*S194+0.000000e+00*S195+1.545217e+01*S196+4.568298e+00*S197+1.067792e+01*S198+(-5.979246e+02)*S199'
.param V65_part21='V65_part20+4.166262e+00*S200+2.799752e-01*S201+5.318055e+00*S202+3.998938e+00*S203+7.072517e+00*S204+4.462733e+00*S205+2.867829e+00*S206+5.330735e+00*S207+8.093560e+00*S208+3.702199e+00*S209'
.param V65_part22='V65_part21+2.158133e+01*S210+5.843867e+01*S211+4.714845e+00*S212+1.040093e+01*S213+3.112645e+00*S214+1.071884e+01*S215+3.295297e+00*S216+4.436607e+01*S217+1.248375e+01*S218+2.433448e+01*S219'
.param V65_part23='V65_part22+7.142044e+00*S220+7.062790e+00*S221+8.575511e+00*S222+6.989376e+00*S223+4.344552e+00*S224+2.177763e+00*S225+5.337204e+00*S226+8.333433e+01*S227+1.000000e+04*S228+1.959730e+01*S229'
.param V65_part24='V65_part23+1.654500e+03*S230+9.425714e+00*S231+2.018227e+00*S232+3.858788e+00*S233+8.214032e+00*S234+8.331865e+00*S235+3.211127e+00*S236+2.777100e+00*S237+1.836822e+01*S238+4.045387e+00*S239'
.param V65_part25='V65_part24+7.542345e+00*S240+(-3.851570e-01)*S241+4.343195e+00*S242+6.582980e+00*S243+5.105990e+00*S244+3.495599e+00*S245+8.023367e+00*S246+2.393142e+01*S247+1.109435e+01*S248+1.015640e+01*S249'
.param V65_part26='V65_part25+1.179972e+01*S250+1.166129e+02*S251+5.682658e+00*S252+1.262575e+01*S253+1.902835e+02*S254+0.000000e+00*S255+4.116311e-01*S256+(-1.068288e-01)*S257+1.334523e+01*S258+9.255844e+00*S259'
.param V65_part27='V65_part26+8.084904e-01*S260+8.042467e+00*S261+4.353282e+00*S262+5.041045e+00*S263+4.075625e+00*S264+9.223409e+00*S265+1.488201e+00*S266+9.189038e+00*S267+3.163647e+00*S268+1.937447e+00*S269'
.param V65_part28='V65_part27+4.345209e+02*S270+2.324774e+00*S271+1.453883e+01*S272+4.980384e+00*S273+2.361747e+00*S274+3.446450e+01*S275+7.740474e+00*S276+2.811097e+00*S277+2.033104e+01*S278+1.213141e+01*S279'
.param V65_part29='V65_part28+2.561022e+00*S280+1.714211e+01*S281+1.142945e+01*S282+4.095003e+00*S283+3.345384e+00*S284+1.225835e+02*S285+1.422026e+01*S286+4.090332e+00*S287+2.353204e+01*S288+6.420176e+00*S289'
.param V65_part30='V65_part29+4.137734e+00*S290+1.071109e+01*S291+1.543556e+01*S292+2.027612e+01*S293+7.974374e+00*S294+1.417906e+01*S295+1.720999e+01*S296+1.047632e+01*S297+8.790983e+00*S298+6.747123e+00*S299'
.param V65_part31='V65_part30+2.015541e+00*S300+(-1.494300e-01)*S301+2.269473e+00*S302+4.957932e+00*S303+2.870111e+00*S304+1.869086e+01*S305+4.525388e+00*S306+1.690019e+01*S307+1.285262e+02*S308+1.614806e+01*S309'
.param V65='V65_part31+1.330487e+01*S310+9.166803e+01*S311+1.625757e+01*S312+2.070676e+01*S313+1.289894e+02*S314'
.param V66_part1='3.194801e+00*S0+7.204599e-01*S1+(-2.124861e+00)*S2+(-2.205255e+01)*S3+0.000000e+00*S4+(-1.337167e+01)*S5+(-4.553306e+00)*S6+(-4.552175e+00)*S7+0.000000e+00*S8+(-1.310575e+01)*S9'
.param V66_part2='V66_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.190382e+01)*S12+0.000000e+00*S13+0.000000e+00*S14+9.533268e+01*S15+2.322904e+01*S16+1.635269e+01*S17+0.000000e+00*S18+1.467926e+00*S19'
.param V66_part3='V66_part2+(-3.413281e+00)*S20+0.000000e+00*S21+1.723688e+00*S22+(-1.920279e+00)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-7.072871e-01)*S27+(-1.177378e+00)*S28+(-1.113694e+00)*S29'
.param V66_part4='V66_part3+(-9.279768e+00)*S30+(-1.787286e+01)*S31+(-2.662899e+00)*S32+4.200849e+00*S33+1.437842e+02*S34+(-2.370370e+00)*S35+6.286087e+00*S36+(-1.886858e+00)*S37+(-6.964159e+00)*S38+(-3.449546e+00)*S39'
.param V66_part5='V66_part4+(-3.382484e+00)*S40+(-7.581826e+00)*S41+1.601357e+02*S42+(-1.192828e+01)*S43+(-8.900360e-02)*S44+2.504798e+01*S45+(-2.467736e+00)*S46+(-4.414354e+00)*S47+4.628351e+00*S48+(-6.241757e+00)*S49'
.param V66_part6='V66_part5+(-6.774230e+00)*S50+3.925046e+00*S51+(-1.721908e+02)*S52+(-2.715869e+00)*S53+(-2.275630e+00)*S54+(-2.810663e+00)*S55+(-2.922107e+00)*S56+(-1.478439e+00)*S57+0.000000e+00*S58+(-1.670224e+00)*S59'
.param V66_part7='V66_part6+(-1.190434e+01)*S60+0.000000e+00*S61+(-1.501649e+01)*S62+2.785724e-01*S63+(-7.407206e+00)*S64+1.807990e+00*S65+(-2.659946e-02)*S66+(-1.042090e+00)*S67+(-6.789779e+00)*S68+(-7.781146e-01)*S69'
.param V66_part8='V66_part7+(-9.003284e-01)*S70+(-7.340718e-01)*S71+(-2.038676e+01)*S72+8.455443e-02*S73+6.242361e+02*S74+(-4.090476e+00)*S75+(-3.502618e+01)*S76+2.501967e+01*S77+0.000000e+00*S78+(-3.675199e+00)*S79'
.param V66_part9='V66_part8+(-8.124997e+00)*S80+(-4.060065e+00)*S81+0.000000e+00*S82+2.528329e-01*S83+0.000000e+00*S84+2.728050e-01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V66_part10='V66_part9+0.000000e+00*S90+2.930016e+01*S91+(-1.477023e+02)*S92+(-8.154291e+00)*S93+1.360621e+00*S94+(-3.379997e+01)*S95+(-4.253043e+00)*S96+(-1.056488e+01)*S97+(-7.565297e+00)*S98+(-8.356772e+00)*S99'
.param V66_part11='V66_part10+(-2.267386e+01)*S100+(-8.842979e-01)*S101+(-2.138960e+01)*S102+(-2.530731e+01)*S103+(-1.197868e+00)*S104+(-3.965390e+02)*S105+(-3.243352e+00)*S106+(-3.425069e+00)*S107+(-1.218752e+02)*S108+(-5.320530e+00)*S109'
.param V66_part12='V66_part11+(-1.930593e+00)*S110+6.843157e-01*S111+(-4.445091e-01)*S112+(-1.373343e+00)*S113+(-3.206690e+00)*S114+(-8.228186e-01)*S115+(-1.895080e+00)*S116+(-6.596828e+00)*S117+(-8.436690e-01)*S118+(-1.092554e+00)*S119'
.param V66_part13='V66_part12+(-3.840353e+00)*S120+(-4.301442e+00)*S121+1.699481e+00*S122+(-7.038799e+01)*S123+(-2.284616e+00)*S124+(-2.371010e+00)*S125+(-6.401695e+00)*S126+(-3.031150e+00)*S127+(-9.986990e-01)*S128+(-8.551716e+00)*S129'
.param V66_part14='V66_part13+(-2.163625e-01)*S130+(-5.931423e-01)*S131+(-1.581238e+00)*S132+(-1.718331e+00)*S133+(-8.090008e-01)*S134+1.364737e+01*S135+(-2.827387e+01)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V66_part15='V66_part14+(-6.461456e-01)*S140+0.000000e+00*S141+(-2.283600e+00)*S142+(-2.384826e+00)*S143+0.000000e+00*S144+0.000000e+00*S145+1.979989e-01*S146+(-1.770943e+00)*S147+(-2.176172e+00)*S148+(-1.279432e+00)*S149'
.param V66_part16='V66_part15+(-2.055883e+02)*S150+(-2.830837e+01)*S151+1.043573e+00*S152+(-5.970292e+01)*S153+(-2.074591e+00)*S154+7.015343e-01*S155+(-4.699392e+00)*S156+(-2.113881e+00)*S157+(-1.223440e+00)*S158+(-2.217688e+00)*S159'
.param V66_part17='V66_part16+4.964840e-01*S160+(-9.200512e-01)*S161+(-5.255436e-02)*S162+(-1.495974e+00)*S163+(-1.695323e+00)*S164+0.000000e+00*S165+(-1.605959e+00)*S166+(-8.868627e-01)*S167+(-2.339156e+00)*S168+(-3.039409e+00)*S169'
.param V66_part18='V66_part17+(-1.347159e+01)*S170+(-1.762283e+00)*S171+(-1.032915e+00)*S172+(-3.163846e+02)*S173+(-4.885061e+00)*S174+(-1.053898e+00)*S175+(-3.394350e-01)*S176+(-3.585804e+00)*S177+(-1.694427e+00)*S178+1.988862e+00*S179'
.param V66_part19='V66_part18+(-4.831870e+01)*S180+0.000000e+00*S181+(-2.608443e+01)*S182+3.102863e-01*S183+(-7.757018e+00)*S184+(-7.835980e-01)*S185+(-6.788751e+00)*S186+3.076798e-02*S187+5.554475e-01*S188+(-6.884098e+00)*S189'
.param V66_part20='V66_part19+(-1.665906e+00)*S190+(-2.395786e-01)*S191+(-5.587504e+00)*S192+(-1.263982e+00)*S193+(-6.887021e-01)*S194+0.000000e+00*S195+1.871850e+00*S196+(-1.575018e+00)*S197+(-7.192757e+00)*S198+(-3.966055e+02)*S199'
.param V66_part21='V66_part20+(-1.257733e+00)*S200+6.916196e-01*S201+(-1.706559e+00)*S202+(-1.330898e+00)*S203+(-2.876697e+00)*S204+(-1.171198e+00)*S205+(-7.541298e-01)*S206+(-2.045856e+00)*S207+(-2.678269e+00)*S208+(-3.188928e-01)*S209'
.param V66_part22='V66_part21+(-1.169057e+01)*S210+(-6.287129e+00)*S211+(-5.513815e-01)*S212+(-8.437879e+00)*S213+(-2.700893e+00)*S214+2.660897e-01*S215+(-1.375481e+00)*S216+(-1.161256e+01)*S217+(-2.196126e+00)*S218+(-8.955903e+00)*S219'
.param V66_part23='V66_part22+(-2.650151e+00)*S220+(-2.249088e+00)*S221+(-2.967660e+00)*S222+(-2.697071e+00)*S223+(-1.324292e+00)*S224+2.667260e-01*S225+(-2.895138e+00)*S226+(-1.990709e+01)*S227+(-5.855378e+00)*S228+(-2.323762e+01)*S229'
.param V66_part24='V66_part23+(-1.025757e+02)*S230+(-3.574340e+00)*S231+(-7.099500e-01)*S232+(-1.825189e+00)*S233+(-3.612108e+00)*S234+(-2.111069e+00)*S235+(-7.807726e-01)*S236+(-4.198615e-01)*S237+(-5.618907e+00)*S238+(-1.061423e+00)*S239'
.param V66_part25='V66_part24+(-4.152255e+00)*S240+1.363918e+00*S241+(-8.682479e-01)*S242+(-3.704512e+00)*S243+(-2.413860e+00)*S244+(-1.297326e+00)*S245+(-4.713189e+00)*S246+(-5.606810e+00)*S247+(-1.387399e+00)*S248+(-3.177784e+00)*S249'
.param V66_part26='V66_part25+(-2.742635e+00)*S250+(-3.240797e+01)*S251+(-9.135417e-01)*S252+(-3.965272e+00)*S253+(-1.271469e+02)*S254+0.000000e+00*S255+5.894024e-01*S256+5.269394e-01*S257+(-6.085546e+00)*S258+(-6.026380e+00)*S259'
.param V66_part27='V66_part26+8.396623e-02*S260+(-3.053611e+00)*S261+(-2.559720e-01)*S262+(-7.968252e-01)*S263+(-7.261471e-01)*S264+(-2.089906e+00)*S265+(-1.112151e-01)*S266+(-2.760068e+00)*S267+(-1.012043e+00)*S268+(-3.758300e-01)*S269'
.param V66_part28='V66_part27+(-1.944895e+01)*S270+(-9.032217e-02)*S271+(-4.356486e+00)*S272+(-2.346871e+00)*S273+(-6.428792e-01)*S274+(-1.599346e+01)*S275+(-3.687825e+00)*S276+(-1.112388e+00)*S277+(-1.151163e+01)*S278+(-4.598540e+00)*S279'
.param V66_part29='V66_part28+(-8.061402e-01)*S280+(-9.275980e+00)*S281+(-8.897565e-01)*S282+(-1.275854e+00)*S283+(-8.129699e-01)*S284+8.489756e+01*S285+(-3.626377e+00)*S286+(-1.146292e+00)*S287+(-2.728839e+00)*S288+(-3.790018e+00)*S289'
.param V66_part30='V66_part29+(-1.328950e+00)*S290+(-3.524186e+00)*S291+(-4.924702e+00)*S292+(-2.082929e+00)*S293+(-8.961442e-01)*S294+(-2.318616e+00)*S295+(-3.186031e+00)*S296+(-2.614786e+00)*S297+(-2.034059e+00)*S298+(-1.232864e+00)*S299'
.param V66_part31='V66_part30+(-1.184714e+00)*S300+9.413644e-01*S301+2.984507e-01*S302+(-2.606354e+00)*S303+(-7.397477e-01)*S304+(-5.453376e+00)*S305+(-2.108822e+00)*S306+(-4.045727e+00)*S307+(-6.577552e+01)*S308+(-5.697123e+00)*S309'
.param V66='V66_part31+(-4.237495e+00)*S310+(-3.904721e+01)*S311+(-3.518054e+00)*S312+(-5.879162e+00)*S313+(-3.244315e+01)*S314'
.param V67_part1='(-8.929039e+00)*S0+(-6.302521e+00)*S1+(-1.923486e+00)*S2+3.063396e+01*S3+0.000000e+00*S4+8.180254e-01*S5+(-2.173170e+00)*S6+(-2.647331e+00)*S7+0.000000e+00*S8+(-1.917407e+00)*S9'
.param V67_part2='V67_part1+0.000000e+00*S10+0.000000e+00*S11+(-3.567289e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+2.707646e+02*S15+(-1.070923e+01)*S16+(-1.063885e+01)*S17+0.000000e+00*S18+(-8.658306e-01)*S19'
.param V67_part3='V67_part2+(-1.688862e+00)*S20+0.000000e+00*S21+(-3.765692e-01)*S22+(-5.396513e-01)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-4.134536e+00)*S27+(-5.442644e-01)*S28+(-4.474546e-01)*S29'
.param V67_part4='V67_part3+2.556858e+01*S30+(-3.483085e-01)*S31+(-3.576678e+00)*S32+2.292127e+01*S33+(-3.902792e-01)*S34+(-2.888907e+00)*S35+7.385270e+00*S36+(-2.674867e+00)*S37+(-9.005735e+00)*S38+2.374848e-01*S39'
.param V67_part5='V67_part4+(-2.898998e-01)*S40+1.902854e+00*S41+(-2.010184e-01)*S42+(-1.466569e+01)*S43+(-7.242061e-01)*S44+2.501784e-01*S45+(-1.850399e+01)*S46+(-3.175614e+00)*S47+7.314368e+00*S48+(-6.422787e+00)*S49'
.param V67_part6='V67_part5+(-1.393614e-01)*S50+(-3.486121e+01)*S51+3.736238e+01*S52+(-2.441081e+00)*S53+(-2.843543e+00)*S54+(-2.626304e+00)*S55+(-1.841427e+00)*S56+(-2.992582e+00)*S57+0.000000e+00*S58+(-2.032216e+00)*S59'
.param V67_part7='V67_part6+(-1.612656e+00)*S60+0.000000e+00*S61+7.983383e-02*S62+(-7.966944e+00)*S63+6.439754e+01*S64+(-1.889099e-01)*S65+(-2.824417e+00)*S66+(-9.105892e-01)*S67+(-9.629729e-01)*S68+(-5.974317e-01)*S69'
.param V67_part8='V67_part7+(-3.639337e-01)*S70+8.986330e-01*S71+6.064599e-01*S72+1.008787e+00*S73+8.599700e+01*S74+(-2.907494e+01)*S75+(-4.887332e+00)*S76+(-9.112955e+00)*S77+0.000000e+00*S78+1.652825e+00*S79'
.param V67_part9='V67_part8+1.432530e+00*S80+1.673429e-01*S81+0.000000e+00*S82+2.229913e-02*S83+0.000000e+00*S84+(-1.755424e-03)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V67_part10='V67_part9+0.000000e+00*S90+2.069487e+01*S91+(-4.907939e+01)*S92+9.792842e+01*S93+1.099897e+00*S94+(-1.582148e+01)*S95+(-3.766771e+00)*S96+8.647301e+00*S97+1.728724e+00*S98+(-4.637601e+00)*S99'
.param V67_part11='V67_part10+(-7.834510e+00)*S100+(-1.054885e+00)*S101+(-3.875071e+01)*S102+(-5.871600e+00)*S103+1.214422e+00*S104+1.321710e+02*S105+(-4.770893e+00)*S106+(-3.306715e+00)*S107+1.365072e+01*S108+(-9.055343e+00)*S109'
.param V67_part12='V67_part11+(-2.790484e+00)*S110+(-2.763574e-01)*S111+1.065146e+01*S112+4.715492e-01*S113+(-2.362938e+00)*S114+4.621760e-01*S115+(-1.150373e-01)*S116+(-1.060410e+01)*S117+5.920813e-01*S118+(-1.323798e+00)*S119'
.param V67_part13='V67_part12+(-1.003441e+01)*S120+(-6.312771e+00)*S121+7.152875e-02*S122+(-3.512085e+01)*S123+(-3.974615e+00)*S124+(-1.856633e-02)*S125+(-1.830876e+00)*S126+5.344157e+00*S127+(-5.535796e-01)*S128+3.735343e+00*S129'
.param V67_part14='V67_part13+4.675536e-01*S130+1.027581e-01*S131+(-2.944982e+00)*S132+7.238507e-01*S133+(-3.240802e-01)*S134+3.699515e+01*S135+2.692724e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V67_part15='V67_part14+(-5.000740e-01)*S140+0.000000e+00*S141+(-1.226665e+00)*S142+(-1.024510e+00)*S143+0.000000e+00*S144+0.000000e+00*S145+5.507351e-02*S146+(-1.272673e+00)*S147+(-2.957660e+00)*S148+(-1.290359e+00)*S149'
.param V67_part16='V67_part15+5.035565e+01*S150+(-5.746002e+01)*S151+(-1.610071e+00)*S152+(-5.174035e+01)*S153+(-6.120813e-01)*S154+3.106192e-01*S155+(-5.891003e+00)*S156+(-2.833485e+00)*S157+3.496551e-01*S158+6.651879e-01*S159'
.param V67_part17='V67_part16+1.008219e+00*S160+9.839027e-01*S161+2.020261e+01*S162+2.468985e+00*S163+(-6.730982e-01)*S164+0.000000e+00*S165+(-3.236516e+00)*S166+(-1.175490e+00)*S167+(-3.978642e+00)*S168+(-5.729375e+00)*S169'
.param V67_part18='V67_part17+(-1.005580e+02)*S170+(-3.110550e+00)*S171+(-1.745119e+00)*S172+(-4.728325e+03)*S173+(-1.524595e+01)*S174+(-2.848051e+00)*S175+2.163576e-01*S176+(-7.675632e+00)*S177+(-1.574171e+00)*S178+(-5.468212e+00)*S179'
.param V67_part19='V67_part18+(-3.849805e+01)*S180+0.000000e+00*S181+(-7.662980e+01)*S182+1.573287e-01*S183+2.062379e+00*S184+(-1.552668e-01)*S185+(-2.161772e+00)*S186+1.067015e+00*S187+3.505388e-01*S188+8.773751e-01*S189'
.param V67_part20='V67_part19+(-2.852058e+00)*S190+(-3.577417e+00)*S191+(-1.262428e+01)*S192+(-2.244688e+00)*S193+(-1.076080e+00)*S194+0.000000e+00*S195+(-1.376690e+01)*S196+(-2.265786e+00)*S197+(-9.769691e+00)*S198+4.031344e+03*S199'
.param V67_part21='V67_part20+(-1.912179e+00)*S200+2.533644e-02*S201+(-3.541032e+00)*S202+(-1.814202e+00)*S203+(-6.186451e+00)*S204+(-2.554663e+00)*S205+(-1.124456e+00)*S206+(-3.530383e+00)*S207+(-4.561878e+00)*S208+(-7.615329e-01)*S209'
.param V67_part22='V67_part21+4.045207e+00*S210+(-5.444914e+01)*S211+(-4.610093e-01)*S212+(-6.563528e+00)*S213+(-3.280261e-01)*S214+(-6.564780e+00)*S215+(-2.539244e+00)*S216+(-2.903758e+01)*S217+(-7.721510e+00)*S218+(-2.165313e+01)*S219'
.param V67_part23='V67_part22+(-4.058261e+00)*S220+(-3.288239e+00)*S221+(-7.887112e+00)*S222+(-3.194361e+00)*S223+(-1.677063e+00)*S224+1.388010e-01*S225+(-3.515587e-01)*S226+(-6.369159e+01)*S227+(-7.599492e+00)*S228+(-1.506995e+00)*S229'
.param V67_part24='V67_part23+(-7.424802e+02)*S230+(-9.306740e+00)*S231+(-8.311257e-01)*S232+(-3.193534e-01)*S233+(-5.996900e+00)*S234+(-5.744705e+00)*S235+(-1.317793e+00)*S236+(-4.008168e-01)*S237+(-1.330411e+01)*S238+(-1.450219e+00)*S239'
.param V67_part25='V67_part24+(-5.841954e+00)*S240+9.094046e-01*S241+(-1.019841e+00)*S242+(-4.887905e+00)*S243+(-2.610318e+00)*S244+(-1.312011e+00)*S245+(-1.042069e+00)*S246+(-2.084924e+01)*S247+(-6.463992e+00)*S248+(-1.032088e+01)*S249'
.param V67_part26='V67_part25+(-8.982583e+00)*S250+(-6.968761e+01)*S251+7.310045e-01*S252+(-5.114159e+00)*S253+(-3.532571e+01)*S254+0.000000e+00*S255+(-1.144213e-02)*S256+4.561598e-01*S257+(-9.839032e+00)*S258+(-1.004608e+00)*S259'
.param V67_part27='V67_part26+2.361799e-01*S260+(-8.316327e+00)*S261+(-2.126939e+00)*S262+(-8.501523e-01)*S263+1.580239e+00*S264+(-7.331204e+00)*S265+(-2.800112e-01)*S266+(-8.167226e-01)*S267+(-4.864601e-01)*S268+(-5.123607e-01)*S269'
.param V67_part28='V67_part27+(-1.311149e+01)*S270+(-6.274827e-02)*S271+(-9.358307e+00)*S272+(-4.715425e+00)*S273+3.594269e-01*S274+(-3.552883e+00)*S275+(-2.125151e+00)*S276+(-1.313195e+00)*S277+(-2.808337e+00)*S278+(-1.222958e+01)*S279'
.param V67_part29='V67_part28+(-8.549541e-01)*S280+(-3.184428e+00)*S281+4.010960e+00*S282+(-2.268136e+00)*S283+(-1.340584e+00)*S284+(-2.528595e+02)*S285+(-1.284204e+01)*S286+(-1.216848e+00)*S287+(-3.259772e+01)*S288+(-2.333829e+00)*S289'
.param V67_part30='V67_part29+(-1.163230e+00)*S290+(-1.211060e+01)*S291+(-1.063601e+01)*S292+(-1.475713e+01)*S293+(-9.321531e+00)*S294+(-1.109351e+01)*S295+(-1.080968e+01)*S296+(-1.222113e+01)*S297+(-6.062176e+00)*S298+(-3.518885e+00)*S299'
.param V67_part31='V67_part30+(-1.428091e+00)*S300+8.614371e-01*S301+4.306552e-02*S302+(-4.432363e+00)*S303+(-1.612817e+00)*S304+(-1.185757e+01)*S305+(-3.454216e+00)*S306+(-1.363074e+01)*S307+(-6.001997e+01)*S308+(-1.668041e+01)*S309'
.param V67='V67_part31+(-8.317014e+00)*S310+(-4.271745e+01)*S311+2.383525e+01*S312+(-1.567099e+01)*S313+(-7.695483e+01)*S314'
.param V68_part1='(-5.210891e+00)*S0+(-3.303940e+00)*S1+(-1.441765e+00)*S2+1.736278e+01*S3+0.000000e+00*S4+3.160755e+00*S5+(-1.297826e+00)*S6+(-1.326666e+00)*S7+0.000000e+00*S8+1.903786e+01*S9'
.param V68_part2='V68_part1+0.000000e+00*S10+0.000000e+00*S11+1.983340e+01*S12+0.000000e+00*S13+0.000000e+00*S14+(-4.197815e+03)*S15+(-1.568690e+01)*S16+(-1.645371e+01)*S17+0.000000e+00*S18+(-9.829190e+01)*S19'
.param V68_part3='V68_part2+(-1.249128e+00)*S20+0.000000e+00*S21+1.264804e+00*S22+(-3.875143e-02)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-1.663948e-01)*S27+(-2.169830e-01)*S28+(-5.399061e-01)*S29'
.param V68_part4='V68_part3+(-1.125524e+02)*S30+3.747777e+00*S31+(-8.805287e-01)*S32+(-2.461165e+01)*S33+(-5.980211e+00)*S34+5.045168e-02*S35+9.137380e+00*S36+(-4.931279e+00)*S37+(-3.611508e+00)*S38+4.518229e+00*S39'
.param V68_part5='V68_part4+(-3.894759e+00)*S40+7.290773e+00*S41+3.634724e+01*S42+(-2.016972e+01)*S43+8.994347e-02*S44+(-7.741147e+01)*S45+(-2.784877e+00)*S46+(-1.047399e+00)*S47+3.639136e+00*S48+(-1.128602e+00)*S49'
.param V68_part6='V68_part5+1.811220e+00*S50+2.575543e+00*S51+(-4.373606e+01)*S52+3.225421e-01*S53+2.460899e-01*S54+(-7.459039e-02)*S55+(-1.635212e-01)*S56+(-1.789803e+00)*S57+0.000000e+00*S58+1.969518e-01*S59'
.param V68_part7='V68_part6+(-2.129384e+00)*S60+0.000000e+00*S61+4.941369e+00*S62+3.958137e+00*S63+7.164897e+00*S64+8.449355e-01*S65+7.641959e+00*S66+2.205720e-01*S67+2.527846e+00*S68+4.498669e-01*S69'
.param V68_part8='V68_part7+2.686793e-01*S70+(-5.835576e-02)*S71+(-1.064745e+01)*S72+2.379047e+00*S73+(-1.309844e+00)*S74+(-6.081238e+01)*S75+7.450143e+01*S76+(-1.000000e+04)*S77+0.000000e+00*S78+(-4.801193e-01)*S79'
.param V68_part9='V68_part8+4.403968e+00*S80+6.875453e+00*S81+0.000000e+00*S82+7.666505e-01*S83+0.000000e+00*S84+1.885202e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V68_part10='V68_part9+0.000000e+00*S90+1.201044e+01*S91+(-3.397934e+01)*S92+(-9.425393e+01)*S93+1.169684e+00*S94+(-4.778982e+01)*S95+(-3.460334e-01)*S96+5.784355e+00*S97+2.068118e+01*S98+9.981431e+03*S99'
.param V68_part11='V68_part10+(-1.000000e+04)*S100+3.014565e-01*S101+(-1.000000e+04)*S102+(-1.000000e+04)*S103+1.601583e-01*S104+(-7.888299e+01)*S105+5.198533e-01*S106+(-4.043406e-01)*S107+(-8.295527e+02)*S108+(-1.546040e+00)*S109'
.param V68_part12='V68_part11+(-1.271296e-01)*S110+1.169735e+00*S111+9.332804e+01*S112+1.160929e+00*S113+2.053460e-01*S114+1.282617e+00*S115+4.086331e-02*S116+(-1.541772e+01)*S117+7.609404e-01*S118+2.352795e-02*S119'
.param V68_part13='V68_part12+6.257106e-01*S120+4.187878e-01*S121+8.313002e+00*S122+(-7.052073e+01)*S123+(-1.747830e-01)*S124+3.760900e-02*S125+8.068146e+01*S126+7.483012e+01*S127+1.356007e+00*S128+1.295873e+03*S129'
.param V68_part14='V68_part13+4.878132e-01*S130+2.077253e+00*S131+(-1.869338e-01)*S132+2.580968e+01*S133+1.848252e+00*S134+(-1.161456e+03)*S135+5.298090e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V68_part15='V68_part14+6.571077e-01*S140+0.000000e+00*S141+7.082520e+00*S142+(-2.796365e+00)*S143+0.000000e+00*S144+0.000000e+00*S145+6.457381e-02*S146+2.749329e-01*S147+1.925200e-02*S148+1.128369e-01*S149'
.param V68_part16='V68_part15+(-1.000000e+04)*S150+(-6.289030e+02)*S151+(-4.675616e-01)*S152+(-1.000000e+04)*S153+7.906214e-01*S154+1.871941e-01*S155+(-1.498817e-01)*S156+1.150053e+00*S157+6.477128e-01*S158+1.544299e+01*S159'
.param V68_part17='V68_part16+9.682354e-01*S160+2.878105e+00*S161+6.365934e+00*S162+7.743556e+00*S163+(-2.689212e-01)*S164+0.000000e+00*S165+(-7.746789e-02)*S166+8.998862e-02*S167+9.077608e-01*S168+(-1.807875e+00)*S169'
.param V68_part18='V68_part17+(-4.779151e+01)*S170+(-1.302333e+00)*S171+3.517178e-02*S172+(-1.000000e+04)*S173+(-2.606727e-01)*S174+(-3.741908e-03)*S175+2.358318e+00*S176+(-2.029341e+00)*S177+(-4.076915e-02)*S178+(-4.054916e+00)*S179'
.param V68_part19='V68_part18+(-1.000000e+04)*S180+0.000000e+00*S181+2.156093e-01*S182+7.616932e-01*S183+7.610146e-01*S184+(-6.323072e-02)*S185+7.648048e-01*S186+9.843725e-01*S187+6.801322e-01*S188+3.650787e+00*S189'
.param V68_part20='V68_part19+5.120506e-01*S190+(-3.768508e+00)*S191+(-2.029037e+00)*S192+(-5.642484e-02)*S193+8.570177e-01*S194+0.000000e+00*S195+(-2.558009e-01)*S196+1.059847e-01*S197+2.729248e-01*S198+4.567569e+02*S199'
.param V68_part21='V68_part20+9.943163e-02*S200+5.646622e-01*S201+2.749093e-01*S202+1.888401e-02*S203+(-6.764086e-01)*S204+1.595418e-01*S205+3.848356e-02*S206+(-2.615233e-01)*S207+(-3.201450e-01)*S208+1.297620e+00*S209'
.param V68_part22='V68_part21+(-1.283069e+03)*S210+(-6.019252e+03)*S211+1.513742e+00*S212+(-1.101088e+00)*S213+4.823305e-01*S214+2.842832e-01*S215+1.688324e-01*S216+(-5.206911e+01)*S217+(-9.366968e-01)*S218+(-7.060104e+00)*S219'
.param V68_part23='V68_part22+(-3.369666e-01)*S220+(-3.056731e-01)*S221+(-1.666589e+00)*S222+(-5.359457e-01)*S223+(-1.193998e-01)*S224+2.133676e+00*S225+3.190878e+00*S226+(-9.995678e+03)*S227+9.985317e+03*S228+8.080264e-01*S229'
.param V68_part24='V68_part23+(-4.087923e+03)*S230+(-3.066902e+00)*S231+1.508108e-01*S232+7.177074e-01*S233+(-1.135040e+00)*S234+(-2.154664e+00)*S235+(-8.142331e-02)*S236+1.169494e+00*S237+(-8.138262e+00)*S238+(-1.667835e-01)*S239'
.param V68_part25='V68_part24+(-2.966956e-02)*S240+1.952275e-01*S241+8.533588e-01*S242+1.976314e-02*S243+(-8.765733e-03)*S244+(-4.256328e-02)*S245+1.780210e+00*S246+(-9.763396e+00)*S247+(-1.358277e+00)*S248+(-7.614354e-01)*S249'
.param V68_part26='V68_part25+(-3.041972e+00)*S250+(-6.941878e+02)*S251+3.137428e+00*S252+(-3.245920e-01)*S253+(-1.000000e+04)*S254+0.000000e+00*S255+3.729729e-01*S256+1.795583e-01*S257+1.917765e+00*S258+4.244909e+00*S259'
.param V68_part27='V68_part26+5.896539e-01*S260+(-6.494781e-01)*S261+5.743356e-01*S262+2.164840e+00*S263+2.679361e+00*S264+(-3.927810e+00)*S265+4.254923e-01*S266+2.968307e+00*S267+9.001847e-01*S268+3.242128e-01*S269'
.param V68_part28='V68_part27+4.140639e+02*S270+1.310409e+00*S271+(-4.879343e+00)*S272+4.278242e-02*S273+1.420579e+00*S274+9.976817e+00*S275+1.120609e+00*S276+3.424148e-01*S277+2.272959e+00*S278+(-2.429686e+00)*S279'
.param V68_part29='V68_part28+1.842411e-03*S280+7.743322e-01*S281+8.632482e+00*S282+(-1.909738e-01)*S283+(-2.498032e-01)*S284+(-1.000000e+04)*S285+(-6.193051e+00)*S286+8.589014e-01*S287+(-2.079632e+01)*S288+4.435024e-01*S289'
.param V68_part30='V68_part29+7.201584e-01*S290+(-1.655488e+00)*S291+(-1.559777e+00)*S292+(-5.784054e+00)*S293+8.088767e-02*S294+(-1.589920e+00)*S295+(-1.262449e+00)*S296+(-1.330789e+00)*S297+(-1.020111e-01)*S298+(-4.578748e-02)*S299'
.param V68_part31='V68_part30+1.429152e-01*S300+2.197933e-01*S301+1.433441e+00*S302+(-2.249422e-01)*S303+(-1.592884e-01)*S304+(-5.352655e+00)*S305+(-1.445477e-01)*S306+(-7.355422e-01)*S307+(-5.631900e+03)*S308+(-3.547175e+00)*S309'
.param V68='V68_part31+(-2.008130e+00)*S310+(-3.777474e+02)*S311+1.246409e+01*S312+(-5.214129e+00)*S313+(-1.000000e+04)*S314'
.param V69_part1='4.707289e-02*S0+7.459850e-02*S1+(-1.578662e-03)*S2+(-1.667162e-01)*S3+0.000000e+00*S4+3.231393e-02*S5+6.669892e-04*S6+9.663779e-03*S7+0.000000e+00*S8+1.868525e-02*S9'
.param V69_part2='V69_part1+0.000000e+00*S10+0.000000e+00*S11+3.393970e-02*S12+0.000000e+00*S13+0.000000e+00*S14+1.175199e+00*S15+(-3.765414e-02)*S16+1.836737e-02*S17+0.000000e+00*S18+(-3.227468e-02)*S19'
.param V69_part3='V69_part2+(-1.511955e-02)*S20+0.000000e+00*S21+4.599985e-03*S22+(-3.803325e-03)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-8.784819e-03)*S27+(-2.567909e-03)*S28+(-7.573986e-03)*S29'
.param V69_part4='V69_part3+6.832612e-02*S30+(-2.662315e-01)*S31+3.772585e-03*S32+2.109888e+00*S33+1.784566e-01*S34+7.151495e-04*S35+7.010865e+00*S36+1.271837e-01*S37+6.695272e-03*S38+5.518318e-01*S39'
.param V69_part5='V69_part4+(-2.071785e-01)*S40+3.692747e-01*S41+4.393714e+01*S42+(-4.768780e-01)*S43+1.944932e-01*S44+4.003905e-01*S45+(-1.071185e+00)*S46+(-4.017107e-02)*S47+2.954205e+01*S48+(-2.012355e+00)*S49'
.param V69_part6='V69_part5+2.838154e-02*S50+(-3.947901e-01)*S51+(-2.423822e+00)*S52+2.249081e-02*S53+(-2.085025e-01)*S54+(-2.015191e-01)*S55+(-3.879427e-01)*S56+3.855253e-01*S57+0.000000e+00*S58+5.839106e-02*S59'
.param V69_part7='V69_part6+4.134575e-01*S60+0.000000e+00*S61+(-2.738220e-01)*S62+(-3.999673e-01)*S63+4.050457e+00*S64+2.558431e-02*S65+(-5.600734e-01)*S66+1.369628e-02*S67+(-5.328612e+00)*S68+2.911279e-02*S69'
.param V69_part8='V69_part7+2.638730e-02*S70+(-7.443580e-01)*S71+(-2.458380e+01)*S72+(-2.652600e-01)*S73+6.518636e+00*S74+8.065546e-01*S75+(-3.873700e+00)*S76+6.019817e+00*S77+0.000000e+00*S78+(-1.938986e-01)*S79'
.param V69_part9='V69_part8+(-1.004605e-01)*S80+1.254803e-01*S81+0.000000e+00*S82+2.215414e-02*S83+0.000000e+00*S84+2.311206e-02*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V69_part10='V69_part9+0.000000e+00*S90+(-5.532728e+00)*S91+(-3.602804e+00)*S92+1.522257e-02*S93+5.202421e-02*S94+(-3.879110e-01)*S95+(-8.472895e-01)*S96+(-2.508431e+00)*S97+(-3.478608e-01)*S98+(-8.302980e+00)*S99'
.param V69_part11='V69_part10+(-2.928445e+00)*S100+(-5.218028e-02)*S101+(-5.356790e+00)*S102+(-2.377396e+00)*S103+(-3.580355e-01)*S104+(-1.941880e+01)*S105+(-9.646038e-02)*S106+(-6.582307e-02)*S107+(-1.546963e+01)*S108+(-6.031999e-01)*S109'
.param V69_part12='V69_part11+(-5.423950e-02)*S110+(-5.744891e-01)*S111+(-5.948602e+00)*S112+(-9.740629e-02)*S113+3.960233e-02*S114+(-8.029989e-01)*S115+(-4.388716e-01)*S116+(-2.918988e+01)*S117+(-5.554050e-01)*S118+(-5.284237e-02)*S119'
.param V69_part13='V69_part12+3.429024e-01*S120+(-5.746590e-01)*S121+(-2.375150e-02)*S122+(-3.508253e+00)*S123+(-6.441722e-01)*S124+(-4.166260e-01)*S125+(-2.593855e+00)*S126+(-3.931052e+00)*S127+(-1.904499e-02)*S128+(-5.076567e-01)*S129'
.param V69_part14='V69_part13+(-2.800457e-02)*S130+7.827495e-03*S131+(-2.917108e-01)*S132+(-3.547043e-01)*S133+(-7.960984e-02)*S134+2.090420e+00*S135+1.462684e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V69_part15='V69_part14+(-4.577999e-01)*S140+0.000000e+00*S141+(-3.032792e-01)*S142+(-6.012976e-02)*S143+0.000000e+00*S144+0.000000e+00*S145+3.485571e-03*S146+(-9.802887e-02)*S147+(-1.153477e-01)*S148+2.547716e-02*S149'
.param V69_part16='V69_part15+(-8.559862e+00)*S150+9.344470e+00*S151+4.682388e-02*S152+(-7.710964e+00)*S153+(-2.683641e-01)*S154+4.649533e-02*S155+(-3.223075e-01)*S156+(-3.035231e-01)*S157+(-2.171618e-01)*S158+3.907553e-02*S159'
.param V69_part17='V69_part16+(-1.057343e-01)*S160+(-1.953092e-01)*S161+1.352924e-01*S162+(-2.410208e-01)*S163+(-2.353404e-01)*S164+0.000000e+00*S165+(-2.340778e-01)*S166+(-1.591268e-02)*S167+(-4.832144e-01)*S168+(-6.551966e-01)*S169'
.param V69_part18='V69_part17+(-8.198454e-01)*S170+(-7.193826e-01)*S171+(-6.685873e-01)*S172+(-6.294913e+03)*S173+(-1.039238e+00)*S174+(-6.203516e-01)*S175+(-2.597421e-01)*S176+(-7.836882e-02)*S177+(-2.926113e-01)*S178+(-3.547750e-01)*S179'
.param V69_part19='V69_part18+(-2.379926e+00)*S180+0.000000e+00*S181+(-1.620343e+00)*S182+4.509965e-02*S183+(-9.885690e-01)*S184+(-2.016931e-01)*S185+(-1.041366e+00)*S186+(-7.794358e-02)*S187+(-8.840482e-02)*S188+(-1.494868e+00)*S189'
.param V69_part20='V69_part19+(-2.236189e-01)*S190+3.464684e-01*S191+(-5.195843e-01)*S192+(-3.093612e-01)*S193+(-9.774362e-01)*S194+0.000000e+00*S195+(-2.510912e+00)*S196+(-3.257630e-02)*S197+(-9.124112e-01)*S198+7.000786e+02*S199'
.param V69_part21='V69_part20+(-2.720305e-02)*S200+1.916098e-02*S201+(-3.817640e-01)*S202+(-4.668638e-02)*S203+(-1.531542e+00)*S204+(-3.467692e-01)*S205+(-1.359210e-01)*S206+(-3.340598e-01)*S207+(-1.847109e-01)*S208+(-1.094863e-02)*S209'
.param V69_part22='V69_part21+(-5.551729e+00)*S210+(-2.066760e+00)*S211+(-2.631221e-01)*S212+(-7.884449e-01)*S213+(-1.116923e-01)*S214+(-1.975002e-01)*S215+(-1.204382e-01)*S216+(-3.959286e+00)*S217+(-3.704055e-01)*S218+(-1.243493e+00)*S219'
.param V69_part23='V69_part22+(-1.842708e-01)*S220+(-2.398602e-01)*S221+(-5.573257e-01)*S222+(-2.184942e-01)*S223+(-1.097080e-01)*S224+(-6.249291e-03)*S225+(-6.936318e-01)*S226+(-7.851221e-01)*S227+(-8.592440e-01)*S228+(-1.533306e+00)*S229'
.param V69_part24='V69_part23+6.237798e+01*S230+(-4.457448e-01)*S231+(-1.911810e-02)*S232+(-1.767841e-01)*S233+(-4.198163e-01)*S234+(-4.553472e-01)*S235+(-8.877418e-02)*S236+(-1.024774e-01)*S237+(-1.004784e+00)*S238+(-1.982381e-01)*S239'
.param V69_part25='V69_part24+(-6.070595e-01)*S240+1.150385e-01*S241+(-4.274839e-01)*S242+(-7.418091e-01)*S243+(-4.985411e-01)*S244+(-2.505853e-01)*S245+(-2.310786e-01)*S246+(-1.255205e+00)*S247+(-1.789212e-01)*S248+(-7.190000e-01)*S249'
.param V69_part26='V69_part25+(-4.661297e-01)*S250+(-2.726285e+00)*S251+1.696070e-01*S252+(-2.344456e+00)*S253+(-3.141217e+00)*S254+0.000000e+00*S255+3.815972e-02*S256+7.475643e-02*S257+(-1.823212e+00)*S258+(-1.065658e+00)*S259'
.param V69_part27='V69_part26+(-1.422693e-01)*S260+(-2.405855e-01)*S261+(-4.737599e-01)*S262+(-1.299320e-03)*S263+7.911697e-02*S264+(-1.097716e-01)*S265+(-3.365689e-02)*S266+(-6.631813e-01)*S267+(-1.959222e-01)*S268+(-9.115255e-02)*S269'
.param V69_part28='V69_part27+(-1.380814e+00)*S270+(-5.033466e-03)*S271+(-2.712763e-01)*S272+(-2.896433e-01)*S273+2.172917e-02*S274+(-6.775619e+00)*S275+(-1.065147e+00)*S276+(-1.107739e-01)*S277+(-3.145329e+00)*S278+(-8.490947e-01)*S279'
.param V69_part29='V69_part28+(-1.006197e-01)*S280+(-2.355800e+00)*S281+3.207207e-01*S282+(-8.332080e-02)*S283+(-1.024425e-01)*S284+(-2.994067e+00)*S285+(-1.173104e+00)*S286+(-1.241096e-01)*S287+(-1.114990e+00)*S288+(-8.107808e-01)*S289'
.param V69_part30='V69_part29+(-1.412147e-01)*S290+(-6.700028e-01)*S291+(-2.083700e+00)*S292+(-4.268795e-01)*S293+(-4.816336e-01)*S294+(-1.875139e+00)*S295+(-2.858534e-01)*S296+(-4.124874e-01)*S297+(-8.029537e-01)*S298+(-1.042160e-01)*S299'
.param V69_part31='V69_part30+(-2.447258e-01)*S300+6.667441e-02*S301+8.791522e-02*S302+(-3.069661e-01)*S303+(-1.170440e-01)*S304+(-5.966714e-01)*S305+(-2.096374e-01)*S306+(-1.596817e+00)*S307+(-4.526163e+00)*S308+(-2.119769e+00)*S309'
.param V69='V69_part31+(-1.485883e+00)*S310+(-2.841042e+00)*S311+1.194619e+00*S312+(-1.318340e+00)*S313+3.667488e+00*S314'
.param V70_part1='3.312738e+01*S0+2.717760e+01*S1+3.952935e+01*S2+2.462445e+01*S3+0.000000e+00*S4+0.000000e+00*S5+(-2.525777e+01)*S6+(-7.582408e+00)*S7+0.000000e+00*S8+1.918370e+00*S9'
.param V70_part2='V70_part1+0.000000e+00*S10+0.000000e+00*S11+1.272926e+00*S12+1.000000e+04*S13+0.000000e+00*S14+5.000900e+00*S15+0.000000e+00*S16+1.182334e+01*S17+0.000000e+00*S18+6.853787e+00*S19'
.param V70_part3='V70_part2+0.000000e+00*S20+1.000000e+04*S21+4.782471e+01*S22+4.681360e+01*S23+1.000000e+04*S24+0.000000e+00*S25+1.000000e+04*S26+0.000000e+00*S27+5.252009e+01*S28+1.749396e+01*S29'
.param V70_part4='V70_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+2.139387e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V70_part5='V70_part4+2.380333e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+3.062267e+02*S44+0.000000e+00*S45+7.796854e+00*S46+(-1.159226e+01)*S47+0.000000e+00*S48+2.947396e+02*S49'
.param V70_part6='V70_part5+0.000000e+00*S50+3.029831e+01*S51+0.000000e+00*S52+0.000000e+00*S53+(-4.157546e+00)*S54+(-8.727978e+00)*S55+(-5.523234e-01)*S56+4.255363e+01*S57+0.000000e+00*S58+(-2.284066e+01)*S59'
.param V70_part7='V70_part6+1.884940e+01*S60+0.000000e+00*S61+0.000000e+00*S62+5.463646e+00*S63+0.000000e+00*S64+1.467434e+02*S65+1.067139e+01*S66+3.362370e+01*S67+0.000000e+00*S68+4.061786e+01*S69'
.param V70_part8='V70_part7+5.212537e+01*S70+1.578783e+02*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.294009e+01*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V70_part9='V70_part8+(-3.449263e+00)*S80+0.000000e+00*S81+0.000000e+00*S82+5.980614e+02*S83+0.000000e+00*S84+5.791008e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V70_part10='V70_part9+7.323097e+01*S90+0.000000e+00*S91+0.000000e+00*S92+1.228490e+01*S93+1.803383e+02*S94+0.000000e+00*S95+1.095722e+01*S96+7.473549e+00*S97+1.276446e+01*S98+0.000000e+00*S99'
.param V70_part11='V70_part10+(-1.930526e+00)*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+1.820088e+00*S105+0.000000e+00*S106+(-1.090136e+01)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V70_part12='V70_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+1.492165e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+2.486503e+02*S118+(-1.893462e+02)*S119'
.param V70_part13='V70_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+(-1.768752e+01)*S125+0.000000e+00*S126+0.000000e+00*S127+(-4.447956e+01)*S128+9.787895e+00*S129'
.param V70_part14='V70_part13+2.129951e+02*S130+(-6.891067e+01)*S131+0.000000e+00*S132+(-1.728182e+01)*S133+(-1.386955e+02)*S134+4.757494e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V70_part15='V70_part14+0.000000e+00*S140+9.656938e+03*S141+0.000000e+00*S142+3.234458e+01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+0.000000e+00*S148+(-7.171199e+01)*S149'
.param V70_part16='V70_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+3.173464e+01*S154+0.000000e+00*S155+0.000000e+00*S156+(-5.264532e+01)*S157+(-7.203746e+00)*S158+0.000000e+00*S159'
.param V70_part17='V70_part16+3.791773e+02*S160+0.000000e+00*S161+(-3.516844e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-1.593455e+02)*S167+(-1.124210e+00)*S168+(-3.371822e+01)*S169'
.param V70_part18='V70_part17+(-3.285587e+01)*S170+7.642321e+01*S171+0.000000e+00*S172+(-2.956481e+01)*S173+0.000000e+00*S174+7.580675e+00*S175+0.000000e+00*S176+0.000000e+00*S177+(-6.851981e-01)*S178+(-2.082122e+02)*S179'
.param V70_part19='V70_part18+0.000000e+00*S180+0.000000e+00*S181+1.833908e+02*S182+1.886241e+02*S183+4.039132e+01*S184+(-6.775305e+01)*S185+0.000000e+00*S186+3.847179e+02*S187+3.575831e+02*S188+6.947338e-02*S189'
.param V70_part20='V70_part19+2.547886e+01*S190+(-2.764472e+00)*S191+1.584548e+01*S192+6.474854e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-3.611801e+01)*S197+0.000000e+00*S198+(-4.024049e+02)*S199'
.param V70_part21='V70_part20+(-5.281631e+01)*S200+3.498705e+02*S201+(-5.457626e+01)*S202+(-1.053090e+02)*S203+5.820715e+01*S204+(-1.987913e+01)*S205+(-4.989981e+01)*S206+0.000000e+00*S207+(-5.801022e+00)*S208+(-2.716619e+01)*S209'
.param V70_part22='V70_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+(-2.700607e+01)*S213+0.000000e+00*S214+0.000000e+00*S215+4.088297e+01*S216+1.374483e+00*S217+2.829903e+01*S218+0.000000e+00*S219'
.param V70_part23='V70_part22+7.662810e+00*S220+(-4.488413e+01)*S221+(-5.454495e+00)*S222+(-6.706158e+01)*S223+(-9.577191e+01)*S224+9.531778e+00*S225+0.000000e+00*S226+(-4.127084e+01)*S227+(-4.320986e+00)*S228+0.000000e+00*S229'
.param V70_part24='V70_part23+(-1.185055e+02)*S230+1.913975e+01*S231+1.030818e+02*S232+0.000000e+00*S233+0.000000e+00*S234+(-9.665777e+00)*S235+0.000000e+00*S236+3.260370e+00*S237+(-2.010168e+01)*S238+(-4.185600e+01)*S239'
.param V70_part25='V70_part24+9.460637e+00*S240+0.000000e+00*S241+0.000000e+00*S242+3.106641e+00*S243+(-6.518965e-01)*S244+0.000000e+00*S245+(-2.343098e-01)*S246+3.175021e-02*S247+(-1.896466e+01)*S248+(-2.013708e+00)*S249'
.param V70_part26='V70_part25+(-6.741713e+00)*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+0.000000e+00*S255+4.637817e+02*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V70_part27='V70_part26+4.034490e+02*S260+0.000000e+00*S261+0.000000e+00*S262+3.000563e+01*S263+2.734999e+01*S264+1.867901e+01*S265+1.278634e+02*S266+1.359943e+01*S267+1.398760e+02*S268+1.160096e+02*S269'
.param V70_part28='V70_part27+3.683728e+00*S270+1.819753e+02*S271+(-6.048340e+00)*S272+3.407662e+01*S273+1.238343e+02*S274+4.273636e-01*S275+0.000000e+00*S276+1.179365e+02*S277+1.142977e+01*S278+1.245617e-01*S279'
.param V70_part29='V70_part28+1.232551e+02*S280+0.000000e+00*S281+(-6.296878e+00)*S282+(-3.837452e+01)*S283+0.000000e+00*S284+0.000000e+00*S285+(-2.057613e+01)*S286+0.000000e+00*S287+(-1.337330e+01)*S288+0.000000e+00*S289'
.param V70_part30='V70_part29+0.000000e+00*S290+(-1.204558e+01)*S291+7.641612e+00*S292+(-1.441331e+01)*S293+0.000000e+00*S294+(-2.397296e+01)*S295+0.000000e+00*S296+(-6.756584e+00)*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V70_part31='V70_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+3.261542e+01*S303+4.588475e+01*S304+1.080420e+01*S305+2.557076e+01*S306+(-2.264548e+00)*S307+0.000000e+00*S308+(-8.533770e+00)*S309'
.param V70='V70_part31+(-1.442695e+01)*S310+0.000000e+00*S311+0.000000e+00*S312+1.952106e+01*S313+0.000000e+00*S314'
.param V71_part1='(-3.187154e+00)*S0+(-8.168828e+00)*S1+1.019905e+02*S2+2.088889e-01*S3+0.000000e+00*S4+0.000000e+00*S5+1.076610e+02*S6+7.543186e+01*S7+0.000000e+00*S8+(-1.080740e+00)*S9'
.param V71_part2='V71_part1+0.000000e+00*S10+0.000000e+00*S11+(-2.503712e+00)*S12+1.000000e+04*S13+0.000000e+00*S14+1.111518e+00*S15+0.000000e+00*S16+1.338236e+01*S17+0.000000e+00*S18+1.595806e+01*S19'
.param V71_part3='V71_part2+0.000000e+00*S20+1.000000e+04*S21+9.204534e+00*S22+1.319485e+02*S23+1.000000e+04*S24+0.000000e+00*S25+1.000000e+04*S26+0.000000e+00*S27+1.799804e+02*S28+1.454686e+02*S29'
.param V71_part4='V71_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-2.232580e+01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V71_part5='V71_part4+1.504627e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+3.344553e+01*S44+0.000000e+00*S45+5.801672e-01*S46+1.601040e+01*S47+0.000000e+00*S48+4.993733e+01*S49'
.param V71_part6='V71_part5+0.000000e+00*S50+2.369918e+01*S51+0.000000e+00*S52+0.000000e+00*S53+6.116442e+01*S54+6.401156e+01*S55+5.294587e+01*S56+3.707332e+01*S57+0.000000e+00*S58+4.984440e+01*S59'
.param V71_part7='V71_part6+3.066745e+01*S60+0.000000e+00*S61+0.000000e+00*S62+5.913632e+01*S63+0.000000e+00*S64+(-5.360511e+01)*S65+4.107226e+01*S66+3.303003e+01*S67+0.000000e+00*S68+3.925648e+01*S69'
.param V71_part8='V71_part7+3.628123e+01*S70+1.070157e+02*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.189400e+01*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V71_part9='V71_part8+5.205583e+01*S80+0.000000e+00*S81+0.000000e+00*S82+(-4.637565e+02)*S83+0.000000e+00*S84+(-3.317117e+01)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V71_part10='V71_part9+1.510124e+00*S90+0.000000e+00*S91+0.000000e+00*S92+1.796250e+01*S93+(-1.474589e+02)*S94+0.000000e+00*S95+2.098824e+01*S96+2.530101e+01*S97+2.119514e+01*S98+0.000000e+00*S99'
.param V71_part11='V71_part10+4.388163e+01*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+1.048114e+00*S105+0.000000e+00*S106+8.293684e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V71_part12='V71_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+5.565683e+01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+(-3.453767e+01)*S118+2.169974e+02*S119'
.param V71_part13='V71_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+3.919485e+02*S125+0.000000e+00*S126+0.000000e+00*S127+1.009198e+02*S128+3.569480e+01*S129'
.param V71_part14='V71_part13+1.655502e+01*S130+1.229382e+02*S131+0.000000e+00*S132+6.901029e+01*S133+1.854850e+02*S134+8.174929e+01*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V71_part15='V71_part14+0.000000e+00*S140+(-3.602396e+02)*S141+0.000000e+00*S142+7.201328e+01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+0.000000e+00*S148+1.028494e+02*S149'
.param V71_part16='V71_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+1.813746e+01*S154+0.000000e+00*S155+0.000000e+00*S156+1.297735e+02*S157+8.022731e+01*S158+0.000000e+00*S159'
.param V71_part17='V71_part16+(-2.511167e+02)*S160+0.000000e+00*S161+4.265153e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+2.194988e+02*S167+5.308785e+01*S168+1.005646e+02*S169'
.param V71_part18='V71_part17+9.674178e+01*S170+(-6.333700e+00)*S171+0.000000e+00*S172+2.641184e+01*S173+0.000000e+00*S174+4.039181e+01*S175+0.000000e+00*S176+0.000000e+00*S177+4.753140e+01*S178+2.089625e+02*S179'
.param V71_part19='V71_part18+0.000000e+00*S180+0.000000e+00*S181+(-1.113248e+02)*S182+(-1.602677e+02)*S183+9.812044e+01*S184+6.005222e+02*S185+0.000000e+00*S186+(-4.354848e+02)*S187+(-3.695048e+02)*S188+3.458318e+01*S189'
.param V71_part20='V71_part19+(-2.204207e+01)*S190+3.132876e+01*S191+6.151362e+01*S192+3.889413e+01*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+9.936476e+01*S197+0.000000e+00*S198+8.294642e+02*S199'
.param V71_part21='V71_part20+1.122747e+02*S200+(-3.432526e+02)*S201+1.288147e+02*S202+1.833589e+02*S203+2.325614e+01*S204+5.754936e+01*S205+9.759424e+01*S206+0.000000e+00*S207+4.923430e+01*S208+1.040394e+02*S209'
.param V71_part22='V71_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+6.110531e+01*S213+0.000000e+00*S214+0.000000e+00*S215+4.448608e+01*S216+3.467391e+01*S217+8.994608e+00*S218+0.000000e+00*S219'
.param V71_part23='V71_part22+3.902145e+01*S220+1.019921e+02*S221+7.863186e+01*S222+9.164688e+01*S223+1.799869e+02*S224+1.349996e+02*S225+0.000000e+00*S226+9.700699e+01*S227+7.097268e+01*S228+0.000000e+00*S229'
.param V71_part24='V71_part23+1.256714e+02*S230+6.442257e+01*S231+(-2.074480e+01)*S232+0.000000e+00*S233+0.000000e+00*S234+8.703159e+01*S235+0.000000e+00*S236+8.555623e+01*S237+9.556082e+01*S238+8.061523e+01*S239'
.param V71_part25='V71_part24+3.842851e+00*S240+0.000000e+00*S241+0.000000e+00*S242+3.704415e+01*S243+2.550171e+01*S244+0.000000e+00*S245+4.771424e+01*S246+4.273898e+01*S247+5.482505e+01*S248+4.850980e+01*S249'
.param V71_part26='V71_part25+6.602874e+01*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+0.000000e+00*S255+(-7.722483e+02)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V71_part27='V71_part26+(-4.170539e+02)*S260+0.000000e+00*S261+0.000000e+00*S262+6.598201e+01*S263+6.336814e+01*S264+5.870750e+01*S265+2.995657e-02*S266+2.411586e+01*S267+4.606060e+01*S268+2.819983e+01*S269'
.param V71_part28='V71_part27+6.865046e+01*S270+(-2.359976e+02)*S271+1.005192e+02*S272+7.393552e+00*S273+4.582832e+01*S274+6.366121e+01*S275+0.000000e+00*S276+2.597368e-01*S277+8.198721e+01*S278+6.256698e+01*S279'
.param V71_part29='V71_part28+(-1.974292e+01)*S280+0.000000e+00*S281+8.913167e+01*S282+8.291451e+01*S283+0.000000e+00*S284+0.000000e+00*S285+1.045026e+02*S286+0.000000e+00*S287+4.322420e+01*S288+0.000000e+00*S289'
.param V71_part30='V71_part29+0.000000e+00*S290+7.135043e+01*S291+3.377964e+01*S292+5.654601e+01*S293+0.000000e+00*S294+9.544617e+01*S295+0.000000e+00*S296+2.834436e+01*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V71_part31='V71_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+1.528207e+01*S303+1.559255e+01*S304+5.676368e+01*S305+2.413751e+01*S306+5.147683e+01*S307+0.000000e+00*S308+5.769924e+01*S309'
.param V71='V71_part31+3.832762e+01*S310+0.000000e+00*S311+0.000000e+00*S312+6.398079e+01*S313+0.000000e+00*S314'
.param V72_part1='(-1.248555e+00)*S0+8.510158e-02*S1+5.800240e+01*S2+6.522008e+00*S3+0.000000e+00*S4+0.000000e+00*S5+(-9.886456e+00)*S6+(-1.992263e+01)*S7+0.000000e+00*S8+1.040335e+01*S9'
.param V72_part2='V72_part1+0.000000e+00*S10+0.000000e+00*S11+9.614109e+00*S12+9.623159e+03*S13+0.000000e+00*S14+1.614338e+01*S15+0.000000e+00*S16+2.932585e+01*S17+0.000000e+00*S18+3.811249e+01*S19'
.param V72_part3='V72_part2+0.000000e+00*S20+1.000000e+04*S21+1.177680e+02*S22+1.076841e+01*S23+1.000000e+04*S24+0.000000e+00*S25+1.000000e+04*S26+0.000000e+00*S27+(-5.082951e+01)*S28+1.967998e+01*S29'
.param V72_part4='V72_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+4.993572e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V72_part5='V72_part4+(-1.189473e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+(-8.526663e+01)*S44+0.000000e+00*S45+9.498456e+01*S46+1.539297e+01*S47+0.000000e+00*S48+(-3.293299e+02)*S49'
.param V72_part6='V72_part5+0.000000e+00*S50+7.770022e+01*S51+0.000000e+00*S52+0.000000e+00*S53+3.132754e+01*S54+3.179885e+01*S55+2.320119e+01*S56+6.815387e+01*S57+0.000000e+00*S58+4.374501e+01*S59'
.param V72_part7='V72_part6+8.592358e+00*S60+0.000000e+00*S61+0.000000e+00*S62+1.369555e+01*S63+0.000000e+00*S64+1.447147e+01*S65+1.856650e+01*S66+3.086218e+01*S67+0.000000e+00*S68+2.284373e+01*S69'
.param V72_part8='V72_part7+(-6.880335e+00)*S70+(-3.957406e+01)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.805023e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V72_part9='V72_part8+1.733325e+01*S80+0.000000e+00*S81+0.000000e+00*S82+7.860414e+00*S83+0.000000e+00*S84+2.704765e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V72_part10='V72_part9+1.332642e+00*S90+0.000000e+00*S91+0.000000e+00*S92+1.602267e+01*S93+1.189614e+02*S94+0.000000e+00*S95+1.410247e+01*S96+1.362562e+01*S97+1.512034e+01*S98+0.000000e+00*S99'
.param V72_part11='V72_part10+5.561072e+01*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+(-1.108993e+00)*S105+0.000000e+00*S106+5.677824e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V72_part12='V72_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+2.784965e+01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+(-8.350549e+01)*S118+1.767178e+02*S119'
.param V72_part13='V72_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+2.220722e+01*S125+0.000000e+00*S126+0.000000e+00*S127+9.836842e+01*S128+5.134728e+01*S129'
.param V72_part14='V72_part13+5.884817e+00*S130+1.055290e+02*S131+0.000000e+00*S132+7.910461e+01*S133+1.367833e+02*S134+1.147368e+01*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V72_part15='V72_part14+0.000000e+00*S140+(-5.893222e+03)*S141+0.000000e+00*S142+8.839466e+01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+0.000000e+00*S148+8.580281e+01*S149'
.param V72_part16='V72_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+3.379345e+01*S154+0.000000e+00*S155+0.000000e+00*S156+1.309053e+02*S157+3.279882e+01*S158+0.000000e+00*S159'
.param V72_part17='V72_part16+(-1.158464e+02)*S160+0.000000e+00*S161+2.008307e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+2.191697e+02*S167+7.613594e+01*S168+1.167858e+02*S169'
.param V72_part18='V72_part17+9.200823e+01*S170+(-1.546467e+02)*S171+0.000000e+00*S172+7.753196e+01*S173+0.000000e+00*S174+3.089176e+01*S175+0.000000e+00*S176+0.000000e+00*S177+4.514267e+01*S178+2.807705e+02*S179'
.param V72_part19='V72_part18+0.000000e+00*S180+0.000000e+00*S181+1.477156e+02*S182+2.188977e+02*S183+4.916965e+01*S184+1.679846e+02*S185+0.000000e+00*S186+1.618392e-01*S187+(-6.343635e+01)*S188+6.390679e+01*S189'
.param V72_part20='V72_part19+2.498696e+01*S190+9.528335e+01*S191+1.053685e+02*S192+4.062039e+01*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+9.889761e+01*S197+0.000000e+00*S198+8.663152e+02*S199'
.param V72_part21='V72_part20+1.138099e+02*S200+1.309903e+02*S201+1.130562e+02*S202+1.492942e+02*S203+7.412439e+01*S204+1.032908e+02*S205+9.423613e+01*S206+0.000000e+00*S207+5.045035e+01*S208+4.313277e+01*S209'
.param V72_part22='V72_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+8.875568e+01*S213+0.000000e+00*S214+0.000000e+00*S215+1.270184e+02*S216+(-7.059893e+00)*S217+1.896638e+01*S218+0.000000e+00*S219'
.param V72_part23='V72_part22+4.323544e+01*S220+6.921717e+01*S221+1.352432e+02*S222+1.305331e+02*S223+1.395745e+02*S224+(-2.654976e+01)*S225+0.000000e+00*S226+1.364487e+02*S227+1.227120e+02*S228+0.000000e+00*S229'
.param V72_part24='V72_part23+1.654689e+02*S230+1.210525e+02*S231+(-1.178053e+01)*S232+0.000000e+00*S233+0.000000e+00*S234+1.232458e+02*S235+0.000000e+00*S236+1.206835e+02*S237+1.387951e+02*S238+7.263303e+01*S239'
.param V72_part25='V72_part24+3.319879e+01*S240+0.000000e+00*S241+0.000000e+00*S242+5.553360e+01*S243+6.812835e+01*S244+0.000000e+00*S245+2.454675e+01*S246+9.059005e+01*S247+6.819665e+01*S248+5.822387e+01*S249'
.param V72_part26='V72_part25+8.625079e+01*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+0.000000e+00*S255+(-3.533995e+01)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V72_part27='V72_part26+(-1.670725e+02)*S260+0.000000e+00*S261+0.000000e+00*S262+9.630146e+01*S263+7.078738e+01*S264+1.188697e+02*S265+5.605263e+00*S266+2.644971e+01*S267+(-6.925156e+01)*S268+3.771949e+01*S269'
.param V72_part28='V72_part27+1.312760e+02*S270+3.975461e+00*S271+1.380862e+02*S272+2.422257e+01*S273+(-3.120547e+00)*S274+4.224396e+01*S275+0.000000e+00*S276+1.470647e+01*S277+1.890889e+01*S278+5.247718e+01*S279'
.param V72_part29='V72_part28+(-5.945295e+00)*S280+0.000000e+00*S281+1.508794e+02*S282+1.048285e+02*S283+0.000000e+00*S284+0.000000e+00*S285+1.487197e+02*S286+0.000000e+00*S287+5.688108e+01*S288+0.000000e+00*S289'
.param V72_part30='V72_part29+0.000000e+00*S290+8.484991e+01*S291+7.657478e+01*S292+1.455265e+02*S293+0.000000e+00*S294+8.282187e+01*S295+0.000000e+00*S296+1.067283e+02*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V72_part31='V72_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+3.473469e+01*S303+1.811229e+01*S304+1.035856e+02*S305+4.394318e+01*S306+5.774144e+01*S307+0.000000e+00*S308+6.675381e+01*S309'
.param V72='V72_part31+1.071170e+02*S310+0.000000e+00*S311+0.000000e+00*S312+9.395062e+01*S313+0.000000e+00*S314'
.param V73_part1='(-2.667933e+00)*S0+2.376171e-01*S1+6.252615e+01*S2+(-1.378451e+00)*S3+0.000000e+00*S4+0.000000e+00*S5+(-4.201539e+01)*S6+(-2.348678e+01)*S7+0.000000e+00*S8+(-9.647050e-01)*S9'
.param V73_part2='V73_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.205470e+00)*S12+(-1.000000e+04)*S13+0.000000e+00*S14+(-5.822165e+00)*S15+0.000000e+00*S16+(-1.236711e+00)*S17+0.000000e+00*S18+(-9.621594e+00)*S19'
.param V73_part3='V73_part2+0.000000e+00*S20+(-9.999995e+03)*S21+1.731561e+01*S22+1.765179e+01*S23+(-1.000000e+04)*S24+0.000000e+00*S25+(-1.000000e+04)*S26+0.000000e+00*S27+2.148183e+01*S28+1.873210e+01*S29'
.param V73_part4='V73_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.282727e+01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V73_part5='V73_part4+(-5.409887e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+1.323724e+02*S44+0.000000e+00*S45+2.311441e+00*S46+1.906126e+00*S47+0.000000e+00*S48+(-2.681063e+01)*S49'
.param V73_part6='V73_part5+0.000000e+00*S50+(-2.040042e+01)*S51+0.000000e+00*S52+0.000000e+00*S53+(-1.039015e+01)*S54+(-1.275780e+01)*S55+(-2.276079e+01)*S56+(-3.523611e+01)*S57+0.000000e+00*S58+(-2.666449e+01)*S59'
.param V73_part7='V73_part6+(-6.707517e+00)*S60+0.000000e+00*S61+0.000000e+00*S62+(-1.559049e+01)*S63+0.000000e+00*S64+(-1.187242e+02)*S65+(-2.347892e+01)*S66+(-8.019399e+00)*S67+0.000000e+00*S68+(-1.002873e+01)*S69'
.param V73_part8='V73_part7+(-1.030908e+01)*S70+1.945286e+01*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+3.080974e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V73_part9='V73_part8+(-1.525231e+01)*S80+0.000000e+00*S81+0.000000e+00*S82+(-4.360675e+01)*S83+0.000000e+00*S84+(-1.213209e+02)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V73_part10='V73_part9+(-1.466208e+02)*S90+0.000000e+00*S91+0.000000e+00*S92+(-1.118721e+00)*S93+(-7.640026e+01)*S94+0.000000e+00*S95+(-4.544068e-01)*S96+2.470586e+00*S97+(-1.355666e+00)*S98+0.000000e+00*S99'
.param V73_part11='V73_part10+(-3.255805e+01)*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+9.058564e-02*S105+0.000000e+00*S106+(-1.714679e+01)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V73_part12='V73_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+3.411752e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+(-8.690701e+01)*S118+(-2.448141e+01)*S119'
.param V73_part13='V73_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+(-2.474154e+01)*S125+0.000000e+00*S126+0.000000e+00*S127+(-3.006382e+01)*S128+(-2.990058e+01)*S129'
.param V73_part14='V73_part13+(-1.527231e+02)*S130+(-3.456574e+01)*S131+0.000000e+00*S132+(-3.604131e+01)*S133+(-3.988219e+01)*S134+(-6.386843e+00)*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V73_part15='V73_part14+0.000000e+00*S140+(-8.095707e+03)*S141+0.000000e+00*S142+(-1.671739e+02)*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+0.000000e+00*S148+(-2.360702e+01)*S149'
.param V73_part16='V73_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+(-7.017133e+00)*S154+0.000000e+00*S155+0.000000e+00*S156+(-2.018287e+01)*S157+(-1.747744e+01)*S158+0.000000e+00*S159'
.param V73_part17='V73_part16+(-4.326525e+01)*S160+0.000000e+00*S161+5.186729e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+(-2.150606e+01)*S167+(-2.183576e+01)*S168+(-2.081932e+01)*S169'
.param V73_part18='V73_part17+(-2.893825e+01)*S170+9.851098e-01*S171+0.000000e+00*S172+(-1.975307e+01)*S173+0.000000e+00*S174+4.155199e+00*S175+0.000000e+00*S176+0.000000e+00*S177+1.533948e+01*S178+(-2.748609e+01)*S179'
.param V73_part19='V73_part18+0.000000e+00*S180+0.000000e+00*S181+(-1.290591e+02)*S182+(-9.763993e+00)*S183+(-6.310193e+01)*S184+2.047189e+00*S185+0.000000e+00*S186+(-1.198267e+01)*S187+(-3.694253e+01)*S188+7.534797e+00*S189'
.param V73_part20='V73_part19+(-9.007952e+00)*S190+(-3.201673e+01)*S191+(-3.632966e+01)*S192+9.521991e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-1.789101e+01)*S197+0.000000e+00*S198+(-1.112678e+01)*S199'
.param V73_part21='V73_part20+(-1.911070e+01)*S200+1.822218e+01*S201+(-1.703534e+01)*S202+(-2.369266e+01)*S203+(-5.665763e+01)*S204+(-2.790917e+01)*S205+(-4.122674e+01)*S206+0.000000e+00*S207+9.345253e+00*S208+4.293202e+00*S209'
.param V73_part22='V73_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+(-1.192172e+01)*S213+0.000000e+00*S214+0.000000e+00*S215+(-2.327779e+01)*S216+(-1.358743e+01)*S217+1.928844e+01*S218+0.000000e+00*S219'
.param V73_part23='V73_part22+2.199048e+01*S220+(-1.048245e+01)*S221+(-3.662059e+01)*S222+6.330753e+00*S223+(-2.263098e+01)*S224+(-1.146990e+02)*S225+0.000000e+00*S226+(-3.957180e+01)*S227+(-2.557984e+01)*S228+0.000000e+00*S229'
.param V73_part24='V73_part23+(-3.662634e+01)*S230+(-3.178170e+01)*S231+(-8.727369e+01)*S232+0.000000e+00*S233+0.000000e+00*S234+(-3.830505e+01)*S235+0.000000e+00*S236+(-3.419847e+01)*S237+3.271480e+00*S238+1.381408e+01*S239'
.param V73_part25='V73_part24+(-6.154334e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+4.094160e+00*S243+3.286117e+00*S244+0.000000e+00*S245+1.060425e+01*S246+(-5.183232e+00)*S247+1.177922e+01*S248+4.625064e-01*S249'
.param V73_part26='V73_part25+(-1.041603e-01)*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+0.000000e+00*S255+1.061958e+02*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V73_part27='V73_part26+(-2.402796e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-6.038888e+01)*S263+(-4.962693e+01)*S264+(-1.386434e+00)*S265+(-5.103639e+01)*S266+(-6.594909e+00)*S267+(-7.999113e+01)*S268+(-5.156332e+01)*S269'
.param V73_part28='V73_part27+(-2.513094e+01)*S270+6.568814e+00*S271+(-3.652043e+01)*S272+6.845266e+00*S273+(-3.619570e+01)*S274+2.154594e+01*S275+0.000000e+00*S276+(-4.404073e+01)*S277+3.211436e+01*S278+4.179640e-01*S279'
.param V73_part29='V73_part28+4.741419e+01*S280+0.000000e+00*S281+(-3.707654e+01)*S282+2.343555e+01*S283+0.000000e+00*S284+0.000000e+00*S285+(-3.213988e+01)*S286+0.000000e+00*S287+(-1.089653e+01)*S288+0.000000e+00*S289'
.param V73_part30='V73_part29+0.000000e+00*S290+1.833454e-01*S291+2.419417e+00*S292+(-1.953875e+01)*S293+0.000000e+00*S294+1.219762e+01*S295+0.000000e+00*S296+(-1.133463e+01)*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V73_part31='V73_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+6.301763e+00*S303+7.457890e-01*S304+(-3.296000e+01)*S305+5.806440e+00*S306+(-2.112448e+00)*S307+0.000000e+00*S308+(-9.330953e+00)*S309'
.param V73='V73_part31+(-1.108382e+01)*S310+0.000000e+00*S311+0.000000e+00*S312+(-3.760096e+01)*S313+0.000000e+00*S314'
.param V74_part1='8.738276e-02*S0+(-1.637536e-01)*S1+(-1.169862e-01)*S2+(-3.255578e-01)*S3+0.000000e+00*S4+0.000000e+00*S5+(-2.331398e-02)*S6+1.079710e-01*S7+0.000000e+00*S8+7.070841e-01*S9'
.param V74_part2='V74_part1+0.000000e+00*S10+0.000000e+00*S11+9.032458e-01*S12+7.121793e+03*S13+0.000000e+00*S14+(-2.234877e+00)*S15+0.000000e+00*S16+1.842281e-01*S17+0.000000e+00*S18+2.262781e-01*S19'
.param V74_part3='V74_part2+0.000000e+00*S20+(-4.386904e+02)*S21+1.715999e-01*S22+5.187872e-01*S23+(-1.839481e+02)*S24+0.000000e+00*S25+1.135836e+03*S26+0.000000e+00*S27+6.867537e-01*S28+1.349303e+00*S29'
.param V74_part4='V74_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-2.143684e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V74_part5='V74_part4+2.867528e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+(-1.329315e+00)*S44+0.000000e+00*S45+(-2.489237e-01)*S46+1.892509e-01*S47+0.000000e+00*S48+1.221287e+01*S49'
.param V74_part6='V74_part5+0.000000e+00*S50+(-5.913297e+00)*S51+0.000000e+00*S52+0.000000e+00*S53+(-4.084464e+00)*S54+1.167108e-01*S55+5.925863e+00*S56+(-2.424867e+00)*S57+0.000000e+00*S58+(-3.040831e+00)*S59'
.param V74_part7='V74_part6+(-3.459736e-01)*S60+0.000000e+00*S61+0.000000e+00*S62+(-3.428439e+00)*S63+0.000000e+00*S64+(-9.063149e+00)*S65+(-5.027184e+00)*S66+4.973264e-01*S67+0.000000e+00*S68+(-5.743505e-01)*S69'
.param V74_part8='V74_part7+(-4.639072e-01)*S70+1.979564e+02*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.225087e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V74_part9='V74_part8+2.072666e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-3.072888e+01)*S83+0.000000e+00*S84+1.994718e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V74_part10='V74_part9+(-2.070731e+01)*S90+0.000000e+00*S91+0.000000e+00*S92+(-5.423238e-01)*S93+(-9.707812e+00)*S94+0.000000e+00*S95+7.255481e-02*S96+1.094706e+00*S97+8.432853e-01*S98+0.000000e+00*S99'
.param V74_part11='V74_part10+(-8.721129e-01)*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+(-5.934084e-01)*S105+0.000000e+00*S106+2.706277e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V74_part12='V74_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+2.435034e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+5.831216e+01*S118+5.055214e+00*S119'
.param V74_part13='V74_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+7.900381e+01*S125+0.000000e+00*S126+0.000000e+00*S127+2.353397e+00*S128+(-3.054043e+00)*S129'
.param V74_part14='V74_part13+3.345611e+00*S130+2.846706e-01*S131+0.000000e+00*S132+1.061295e+01*S133+3.607911e+00*S134+(-3.068281e+00)*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V74_part15='V74_part14+0.000000e+00*S140+(-7.841560e+03)*S141+0.000000e+00*S142+8.105817e-01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+0.000000e+00*S148+(-2.761976e+00)*S149'
.param V74_part16='V74_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+1.331373e+00*S154+0.000000e+00*S155+0.000000e+00*S156+4.754971e+00*S157+3.903427e+00*S158+0.000000e+00*S159'
.param V74_part17='V74_part16+(-5.745934e+00)*S160+0.000000e+00*S161+1.217177e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+1.476342e+01*S167+1.181864e+00*S168+3.953709e+00*S169'
.param V74_part18='V74_part17+6.699995e+00*S170+8.084037e-01*S171+0.000000e+00*S172+7.923923e+00*S173+0.000000e+00*S174+1.106332e+01*S175+0.000000e+00*S176+0.000000e+00*S177+1.632690e+01*S178+8.791805e-01*S179'
.param V74_part19='V74_part18+0.000000e+00*S180+0.000000e+00*S181+(-2.155948e+01)*S182+(-6.259992e+01)*S183+1.072251e+00*S184+1.586508e+02*S185+0.000000e+00*S186+(-5.826940e+01)*S187+(-9.000586e+01)*S188+1.511083e+01*S189'
.param V74_part20='V74_part19+3.470922e+00*S190+7.558332e+00*S191+3.778736e+00*S192+1.132248e+01*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+4.493407e+00*S197+0.000000e+00*S198+1.271297e+02*S199'
.param V74_part21='V74_part20+6.821828e+00*S200+(-5.068039e+01)*S201+4.217197e+00*S202+1.128627e+01*S203+7.731590e+00*S204+(-4.226024e+00)*S205+1.358237e+01*S206+0.000000e+00*S207+9.543640e+00*S208+1.012250e+00*S209'
.param V74_part22='V74_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+3.183025e+00*S213+0.000000e+00*S214+0.000000e+00*S215+(-1.096045e+00)*S216+7.705793e-01*S217+(-3.108341e+00)*S218+0.000000e+00*S219'
.param V74_part23='V74_part22+6.978809e+00*S220+7.053607e+00*S221+6.436014e+00*S222+1.201019e+01*S223+7.425823e+00*S224+5.449657e+00*S225+0.000000e+00*S226+6.501782e+00*S227+1.146305e+01*S228+0.000000e+00*S229'
.param V74_part24='V74_part23+1.968901e+01*S230+1.543242e+00*S231+1.482874e+01*S232+0.000000e+00*S233+0.000000e+00*S234+7.740546e+00*S235+0.000000e+00*S236+1.233415e+01*S237+1.305600e+01*S238+2.152299e+01*S239'
.param V74_part25='V74_part24+1.801801e+00*S240+0.000000e+00*S241+0.000000e+00*S242+1.086483e+01*S243+1.152435e+01*S244+0.000000e+00*S245+9.977451e-01*S246+8.270665e+00*S247+1.646313e+01*S248+1.356293e+01*S249'
.param V74_part26='V74_part25+1.677337e+01*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+0.000000e+00*S255+(-6.989931e+01)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V74_part27='V74_part26+(-5.865073e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-1.008020e+01)*S263+1.648825e+00*S264+(-3.656861e+00)*S265+(-1.391532e+00)*S266+1.157510e+01*S267+(-1.603495e+01)*S268+(-8.885496e+00)*S269'
.param V74_part28='V74_part27+9.606777e+00*S270+(-3.121150e+01)*S271+8.652896e+00*S272+6.156488e+00*S273+(-1.439073e+01)*S274+1.086576e+01*S275+0.000000e+00*S276+8.616444e-01*S277+1.750383e+01*S278+1.601307e+01*S279'
.param V74_part29='V74_part28+2.626715e+00*S280+0.000000e+00*S281+1.438868e+01*S282+2.686105e+01*S283+0.000000e+00*S284+0.000000e+00*S285+1.203378e+01*S286+0.000000e+00*S287+8.559147e+00*S288+0.000000e+00*S289'
.param V74_part30='V74_part29+0.000000e+00*S290+1.016871e+01*S291+1.333030e+01*S292+9.442865e+00*S293+0.000000e+00*S294+1.525693e+01*S295+0.000000e+00*S296+3.202004e+01*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V74_part31='V74_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+8.494828e+00*S303+(-1.077642e+00)*S304+4.205141e+00*S305+8.799577e+00*S306+6.636500e+00*S307+0.000000e+00*S308+1.388248e+01*S309'
.param V74='V74_part31+1.759623e+01*S310+0.000000e+00*S311+0.000000e+00*S312+4.881363e+00*S313+0.000000e+00*S314'
.param V75_part1='2.429120e+01*S0+1.619672e+01*S1+1.979412e+01*S2+7.349973e+00*S3+1.003873e+01*S4+3.250385e+00*S5+(-1.166804e+02)*S6+5.368848e+02*S7+3.696830e+01*S8+(-4.751492e-01)*S9'
.param V75_part2='V75_part1+4.541247e+01*S10+5.573147e+01*S11+(-1.106341e+01)*S12+5.696104e+01*S13+4.611652e+02*S14+0.000000e+00*S15+2.184404e+01*S16+3.199573e+00*S17+7.368454e+00*S18+5.623692e+00*S19'
.param V75_part3='V75_part2+1.408699e+01*S20+4.124718e+00*S21+6.122228e+00*S22+6.874373e+01*S23+1.290781e+01*S24+1.467586e+01*S25+1.704103e+01*S26+3.819395e+02*S27+5.612038e+03*S28+1.586980e+02*S29'
.param V75_part4='V75_part3+0.000000e+00*S30+8.480881e+03*S31+9.352855e+00*S32+1.939523e+01*S33+1.879608e+01*S34+1.722265e+01*S35+5.694826e+01*S36+2.767640e+01*S37+3.028165e+01*S38+1.372569e+02*S39'
.param V75_part5='V75_part4+(-1.639795e+01)*S40+5.040953e+00*S41+9.990008e+03*S42+1.351198e+01*S43+2.842831e+00*S44+5.542397e+01*S45+7.475101e+01*S46+7.212237e+01*S47+9.860781e+03*S48+4.091723e+01*S49'
.param V75_part6='V75_part5+1.000000e+04*S50+1.150991e+00*S51+3.468763e+01*S52+4.125661e+02*S53+5.597513e+03*S54+4.840663e+03*S55+2.356861e+02*S56+1.020347e+02*S57+2.489453e+03*S58+5.206412e+03*S59'
.param V75_part7='V75_part6+3.194151e+01*S60+2.410039e+01*S61+2.566619e+01*S62+1.034471e+02*S63+1.482092e+02*S64+2.847072e+01*S65+8.038825e+01*S66+2.880288e+01*S67+1.320607e+01*S68+4.455075e+01*S69'
.param V75_part8='V75_part7+2.805441e+01*S70+9.979121e+03*S71+3.390899e+00*S72+1.617470e+02*S73+1.224999e-01*S74+1.825641e+01*S75+3.601633e+00*S76+6.429676e+00*S77+3.309772e+00*S78+7.869848e+00*S79'
.param V75_part9='V75_part8+(-2.724716e+01)*S80+1.542783e+00*S81+1.158096e+01*S82+1.196654e+01*S83+2.756774e+01*S84+1.817518e+01*S85+2.779531e+01*S86+6.829349e+01*S87+5.390896e+01*S88+1.006020e+01*S89'
.param V75_part10='V75_part9+3.409140e+03*S90+(-1.489889e+02)*S91+1.281917e+03*S92+5.464046e+03*S93+4.145672e+01*S94+8.472540e+03*S95+1.162691e+02*S96+7.194086e+00*S97+2.054580e+02*S98+1.482847e+01*S99'
.param V75_part11='V75_part10+1.064898e+01*S100+2.674602e+01*S101+1.285492e+01*S102+1.076566e+01*S103+3.790749e+01*S104+6.951373e+01*S105+3.030568e+01*S106+1.957283e+02*S107+3.850169e+01*S108+3.608355e+01*S109'
.param V75_part12='V75_part11+2.367446e+02*S110+3.383655e+01*S111+2.511008e+01*S112+7.578926e+03*S113+6.291597e+01*S114+3.215408e+01*S115+6.733847e+00*S116+1.386631e+01*S117+1.000000e+04*S118+1.015243e+01*S119'
.param V75_part13='V75_part12+(-1.625520e+02)*S120+2.704890e+01*S121+9.319153e+01*S122+4.408555e+01*S123+3.644502e+01*S124+6.907659e+01*S125+3.016927e+01*S126+3.761437e+01*S127+1.124415e+01*S128+3.630581e+01*S129'
.param V75_part14='V75_part13+1.459116e+02*S130+1.271466e+01*S131+8.542591e+00*S132+8.623927e+00*S133+6.072693e+01*S134+3.164497e+01*S135+1.601289e+02*S136+2.465106e+03*S137+1.000000e+04*S138+6.287594e+00*S139'
.param V75_part15='V75_part14+5.823373e+01*S140+4.235067e+02*S141+5.249988e+00*S142+9.769546e+03*S143+5.341581e+03*S144+4.989591e+02*S145+8.313830e+02*S146+5.172051e+03*S147+4.473042e+03*S148+3.637718e+00*S149'
.param V75_part16='V75_part15+1.000000e+04*S150+1.000000e+04*S151+1.000000e+04*S152+7.079116e+02*S153+1.816264e+01*S154+5.327610e+03*S155+3.636775e+01*S156+1.853730e+01*S157+2.153075e+01*S158+2.021043e+01*S159'
.param V75_part17='V75_part16+6.218805e+01*S160+6.666797e+00*S161+2.514592e+01*S162+4.458256e+01*S163+6.591380e+00*S164+3.657456e+01*S165+3.034769e+01*S166+1.000000e+04*S167+3.032131e+01*S168+3.574310e+01*S169'
.param V75_part18='V75_part17+6.669336e+03*S170+9.883665e+01*S171+2.175291e+02*S172+1.000000e+04*S173+3.030670e+01*S174+2.492010e+01*S175+3.930137e+03*S176+1.445376e+01*S177+1.259429e+01*S178+9.944944e+01*S179'
.param V75_part19='V75_part18+3.982712e+01*S180+2.782840e+01*S181+2.921868e+02*S182+3.876121e+01*S183+4.624709e+01*S184+1.804288e+02*S185+1.029836e+01*S186+3.997467e+03*S187+4.906486e+02*S188+9.256028e+00*S189'
.param V75_part20='V75_part19+1.129179e+03*S190+4.773948e+01*S191+4.158832e+01*S192+2.959981e+01*S193+2.104324e+00*S194+7.869685e+00*S195+8.750329e+00*S196+4.621943e+01*S197+2.054956e+01*S198+1.689575e+03*S199'
.param V75_part21='V75_part20+7.615928e+01*S200+1.397033e+01*S201+3.500657e+01*S202+3.221660e+01*S203+5.795622e+01*S204+(-5.185914e+00)*S205+4.090158e+00*S206+4.590828e+00*S207+5.756309e+00*S208+4.626479e+00*S209'
.param V75_part22='V75_part21+2.172871e+01*S210+8.505812e+01*S211+5.308745e+03*S212+(-1.641432e+03)*S213+2.774819e+01*S214+8.226197e+01*S215+2.340440e+01*S216+(-2.130224e+02)*S217+6.603883e+00*S218+(-2.003305e+03)*S219'
.param V75_part23='V75_part22+4.809195e+00*S220+2.468471e+03*S221+(-1.224351e+01)*S222+2.949293e+03*S223+1.000000e+04*S224+7.230505e+01*S225+7.957321e+02*S226+1.290570e+03*S227+1.239609e+01*S228+1.066515e+01*S229'
.param V75_part24='V75_part23+5.097974e+03*S230+(-1.177553e+01)*S231+5.409862e+03*S232+2.393631e+01*S233+8.475213e+00*S234+9.117748e+01*S235+1.511575e+03*S236+5.961932e+03*S237+2.811041e+02*S238+5.615641e+00*S239'
.param V75_part25='V75_part24+3.205127e+00*S240+4.158778e+01*S241+1.374622e+01*S242+1.121740e+01*S243+2.255709e+01*S244+1.834481e+02*S245+1.432902e+00*S246+1.223491e+01*S247+3.015535e+01*S248+1.489853e+01*S249'
.param V75_part26='V75_part25+9.162827e+00*S250+1.931296e+02*S251+1.537241e+01*S252+2.932033e+02*S253+4.758383e+00*S254+5.224310e+01*S255+1.699661e+01*S256+1.622639e+02*S257+4.256165e+00*S258+(-9.903217e+00)*S259'
.param V75_part27='V75_part26+9.392985e+02*S260+(-5.296448e+00)*S261+8.386266e+00*S262+2.834775e+00*S263+(-3.220193e+01)*S264+7.537340e+00*S265+5.065314e+03*S266+3.925867e+00*S267+2.414243e+02*S268+1.641193e+01*S269'
.param V75_part28='V75_part27+1.192426e+01*S270+3.033720e+01*S271+9.950431e+03*S272+5.937601e+00*S273+1.140335e+01*S274+2.000934e+03*S275+1.348885e+01*S276+3.367742e+03*S277+1.888778e+01*S278+1.570159e+01*S279'
.param V75_part29='V75_part28+2.952029e+01*S280+3.298375e+01*S281+5.530283e+00*S282+1.616550e+01*S283+1.979095e+01*S284+8.292843e+00*S285+2.620694e+01*S286+1.583318e+01*S287+8.076274e+00*S288+1.205660e+01*S289'
.param V75_part30='V75_part29+(-1.712610e+01)*S290+1.430563e+01*S291+1.021315e+03*S292+3.199839e+00*S293+5.190164e+00*S294+9.688879e+01*S295+2.104609e+01*S296+3.688482e+00*S297+4.020135e+00*S298+9.996364e+03*S299'
.param V75_part31='V75_part30+3.772354e+00*S300+2.417726e+01*S301+6.529954e+01*S302+1.036845e+01*S303+2.341273e+01*S304+1.491476e+02*S305+6.675139e+00*S306+1.841150e+01*S307+3.118420e+02*S308+3.474621e+01*S309'
.param V75='V75_part31+5.008366e+03*S310+1.645798e+02*S311+3.056540e+00*S312+5.077462e+03*S313+2.326855e+00*S314'
.param V76_part1='1.152949e+03*S0+4.866458e+03*S1+9.158165e+01*S2+3.422467e-01*S3+1.325119e+01*S4+3.952305e+01*S5+2.978512e+01*S6+6.647358e+02*S7+1.728858e+01*S8+1.143087e+02*S9'
.param V76_part2='V76_part1+3.302882e+00*S10+1.237900e+01*S11+1.115006e+02*S12+9.108541e+00*S13+3.668741e+00*S14+0.000000e+00*S15+1.351925e+00*S16+7.616882e+00*S17+(-1.387580e+01)*S18+1.640620e+00*S19'
.param V76_part3='V76_part2+6.600949e-01*S20+1.861999e+01*S21+9.023492e+00*S22+(-1.264544e+01)*S23+1.277066e+01*S24+9.574094e+00*S25+7.464113e+00*S26+2.740185e+02*S27+3.130545e+02*S28+2.899741e+01*S29'
.param V76_part4='V76_part3+0.000000e+00*S30+6.741748e+03*S31+7.957574e+00*S32+7.672969e+00*S33+6.368919e+00*S34+8.715224e+00*S35+1.008319e+01*S36+5.249923e-01*S37+4.711478e+00*S38+5.903675e+00*S39'
.param V76_part5='V76_part4+1.229678e+02*S40+1.222901e+00*S41+1.641965e+01*S42+1.445140e+00*S43+1.286501e-01*S44+2.752734e+01*S45+7.862385e+00*S46+(-7.520222e+01)*S47+9.958071e+03*S48+5.702417e-01*S49'
.param V76_part6='V76_part5+1.000000e+04*S50+(-9.940864e-01)*S51+2.084192e+01*S52+(-1.615135e+02)*S53+(-4.674547e+02)*S54+7.169903e+01*S55+(-1.214955e+02)*S56+1.186871e+00*S57+(-3.695049e+01)*S58+(-1.534263e+01)*S59'
.param V76_part7='V76_part6+8.222447e+00*S60+2.122952e+01*S61+1.309978e+01*S62+1.551841e+01*S63+1.507554e+01*S64+5.254938e+00*S65+3.854340e+00*S66+8.523140e-01*S67+1.969211e+00*S68+3.910611e-01*S69'
.param V76_part8='V76_part7+1.534787e-01*S70+2.242100e+01*S71+(-1.495242e-01)*S72+1.066836e+03*S73+(-4.366334e-03)*S74+(-2.985309e+01)*S75+4.090475e+00*S76+1.597061e-01*S77+(-4.804688e+00)*S78+2.468585e+00*S79'
.param V76_part9='V76_part8+1.665784e+02*S80+1.724550e+01*S81+9.997373e+00*S82+6.465687e+00*S83+1.576181e+01*S84+9.920404e+00*S85+9.628834e+00*S86+1.008632e+01*S87+1.006207e+01*S88+4.013399e+00*S89'
.param V76_part10='V76_part9+4.092943e+01*S90+1.116699e+03*S91+4.771715e+01*S92+8.595158e+00*S93+1.036908e+01*S94+6.827823e+03*S95+2.563358e+00*S96+1.161902e+00*S97+5.658894e+01*S98+(-3.104955e+00)*S99'
.param V76_part11='V76_part10+6.757018e-01*S100+3.298890e+00*S101+(-2.800552e+00)*S102+(-1.929295e-03)*S103+2.442947e+01*S104+6.790090e+00*S105+1.460915e+00*S106+3.453225e+01*S107+(-1.418131e+01)*S108+(-5.815857e-01)*S109'
.param V76_part12='V76_part11+6.325671e+02*S110+(-7.721519e+00)*S111+2.913448e+00*S112+5.914210e+03*S113+(-3.138996e+01)*S114+3.284791e+02*S115+(-8.569971e-02)*S116+(-5.644713e+00)*S117+(-3.339786e+00)*S118+1.013957e+01*S119'
.param V76_part13='V76_part12+1.107831e+03*S120+7.798209e+00*S121+1.980344e+01*S122+(-1.558561e+01)*S123+8.322184e+00*S124+1.661044e+01*S125+(-4.690020e+00)*S126+1.011360e+01*S127+1.178573e+01*S128+(-5.405182e+00)*S129'
.param V76_part14='V76_part13+7.949809e+00*S130+2.498300e+01*S131+(-1.948497e+00)*S132+(-2.720831e+00)*S133+3.428486e+01*S134+3.046109e+01*S135+3.136739e+01*S136+(-6.268352e+01)*S137+1.000000e+04*S138+1.268227e+00*S139'
.param V76_part15='V76_part14+2.489008e+00*S140+(-2.358289e+02)*S141+1.929472e+00*S142+3.532958e+02*S143+(-3.264522e+02)*S144+1.907327e+02*S145+(-2.780449e+00)*S146+(-1.677143e+02)*S147+4.364155e+03*S148+6.505349e+00*S149'
.param V76_part16='V76_part15+2.222202e+01*S150+4.198870e+01*S151+2.406326e+03*S152+2.676456e+00*S153+8.748452e+00*S154+1.412562e+02*S155+3.225477e+00*S156+1.063110e+00*S157+1.201252e+00*S158+(-2.954072e+00)*S159'
.param V76_part17='V76_part16+(-2.643164e+00)*S160+9.183133e+00*S161+(-8.616181e+00)*S162+7.222965e+01*S163+1.227317e+00*S164+2.667817e+00*S165+1.092413e+01*S166+9.998346e+03*S167+7.735538e+00*S168+1.215928e+01*S169'
.param V76_part18='V76_part17+6.669336e+03*S170+(-1.191503e+01)*S171+(-3.068450e+01)*S172+1.000000e+04*S173+1.077289e+00*S174+2.402948e-02*S175+1.000000e+04*S176+(-1.002581e+00)*S177+(-2.584207e+00)*S178+1.002385e+00*S179'
.param V76_part19='V76_part18+6.535597e+00*S180+1.855732e+01*S181+(-8.435159e-01)*S182+1.736189e+01*S183+8.679090e+01*S184+6.867075e+01*S185+7.449169e+00*S186+3.857879e+02*S187+8.220804e+02*S188+(-7.451068e+00)*S189'
.param V76_part20='V76_part19+(-1.253340e+03)*S190+3.568868e+01*S191+(-3.163152e+00)*S192+(-3.091879e+00)*S193+(-2.463986e-01)*S194+1.172040e+01*S195+3.530543e+01*S196+3.337128e+00*S197+4.858041e+00*S198+1.151520e+01*S199'
.param V76_part21='V76_part20+6.491857e+01*S200+9.779070e-01*S201+2.447659e+01*S202+5.269387e+01*S203+(-2.574059e-02)*S204+7.690049e+01*S205+(-6.547087e+00)*S206+(-2.879125e+00)*S207+(-2.904616e+00)*S208+1.873879e+00*S209'
.param V76_part22='V76_part21+5.257390e+00*S210+1.078221e+02*S211+6.258875e+00*S212+(-7.457886e+02)*S213+1.302593e+01*S214+1.201977e+01*S215+2.650877e-01*S216+(-1.208374e+02)*S217+1.624439e+00*S218+(-6.171754e+01)*S219'
.param V76_part23='V76_part22+(-1.545899e+00)*S220+2.468471e+03*S221+2.944834e+00*S222+2.901087e+03*S223+1.000000e+04*S224+(-6.131387e-01)*S225+3.371334e+01*S226+(-2.558853e+01)*S227+1.865833e+00*S228+(-2.388141e+00)*S229'
.param V76_part24='V76_part23+(-1.753505e+02)*S230+1.027306e+00*S231+8.659109e+00*S232+4.230216e+00*S233+(-1.013601e+01)*S234+(-1.033188e+02)*S235+(-3.988618e+01)*S236+7.287003e+03*S237+(-2.139511e-01)*S238+(-3.723766e+00)*S239'
.param V76_part25='V76_part24+(-5.864961e+00)*S240+2.454678e+01*S241+4.231010e-01*S242+(-1.772254e+01)*S243+(-1.364827e+01)*S244+(-1.986496e+02)*S245+(-1.375573e+02)*S246+(-5.847299e+00)*S247+4.433659e+00*S248+(-1.870266e+01)*S249'
.param V76_part26='V76_part25+(-3.916098e+00)*S250+4.955093e+00*S251+2.040387e-01*S252+2.788471e+01*S253+(-1.911848e+00)*S254+3.511626e+01*S255+1.633131e+01*S256+5.908601e+01*S257+3.210043e+00*S258+8.416591e+01*S259'
.param V76_part27='V76_part26+4.011301e+01*S260+(-2.716330e+01)*S261+(-1.314453e+01)*S262+1.242638e+00*S263+(-1.107653e+01)*S264+(-3.141638e+00)*S265+1.627919e+02*S266+(-2.208206e+00)*S267+2.491051e+00*S268+(-1.720855e+00)*S269'
.param V76_part28='V76_part27+1.988023e+00*S270+1.432243e+01*S271+2.403525e+02*S272+(-1.968853e+01)*S273+5.439060e+00*S274+(-1.409923e+02)*S275+9.418136e-01*S276+9.431322e+01*S277+(-3.320357e+01)*S278+1.974586e+00*S279'
.param V76_part29='V76_part28+(-2.749658e+01)*S280+(-4.196887e+01)*S281+(-3.933392e+00)*S282+(-2.637409e+01)*S283+2.870419e-01*S284+(-8.234210e+00)*S285+1.226888e+01*S286+(-2.045675e+02)*S287+(-9.438671e+00)*S288+(-1.521955e+00)*S289'
.param V76_part30='V76_part29+(-3.324717e+01)*S290+8.747986e-01*S291+1.880670e+01*S292+3.387073e-01*S293+(-4.666179e+00)*S294+(-2.014091e+01)*S295+2.736045e+00*S296+(-1.971319e+00)*S297+(-4.778530e-01)*S298+1.793222e+01*S299'
.param V76_part31='V76_part30+2.768041e+00*S300+1.699779e+01*S301+1.998094e+01*S302+(-1.361481e+01)*S303+(-3.188142e+01)*S304+(-9.612732e+01)*S305+(-7.103445e+00)*S306+(-9.873833e-01)*S307+(-3.781724e+02)*S308+(-2.234709e+01)*S309'
.param V76='V76_part31+2.776272e+01*S310+(-1.501040e+02)*S311+(-2.769702e+00)*S312+(-2.199501e+01)*S313+(-8.385325e-01)*S314'
.param V77_part1='1.216113e+02*S0+8.159569e+03*S1+(-5.928661e+00)*S2+1.464918e+01*S3+(-2.197067e-03)*S4+1.185792e+01*S5+6.332720e+02*S6+2.097656e+02*S7+1.675180e+00*S8+1.168698e+03*S9'
.param V77_part2='V77_part1+(-5.667565e+00)*S10+2.997711e+00*S11+1.308102e+03*S12+(-9.166284e+00)*S13+6.448283e+00*S14+0.000000e+00*S15+(-5.105838e+00)*S16+3.205480e-01*S17+3.059192e+00*S18+(-1.078458e+00)*S19'
.param V77_part3='V77_part2+(-3.580968e+00)*S20+(-1.205928e+00)*S21+(-3.794365e+00)*S22+(-2.955533e+01)*S23+(-7.421107e+00)*S24+(-3.844813e+00)*S25+(-1.454527e+00)*S26+1.211280e+01*S27+2.945084e+03*S28+(-1.050925e+02)*S29'
.param V77_part4='V77_part3+0.000000e+00*S30+4.749003e+03*S31+6.289021e-01*S32+(-5.122628e+00)*S33+(-2.822269e-01)*S34+2.343093e+00*S35+(-8.256482e+00)*S36+(-2.584967e-02)*S37+3.462532e+00*S38+(-5.906853e+00)*S39'
.param V77_part5='V77_part4+(-4.800470e+01)*S40+(-1.706141e-01)*S41+1.052301e+01*S42+(-5.617188e+00)*S43+(-8.091053e-01)*S44+(-3.896888e-01)*S45+8.081879e-01*S46+2.604486e+01*S47+(-2.286363e+03)*S48+7.051406e+00*S49'
.param V77_part6='V77_part5+3.395591e+03*S50+4.317380e-01*S51+6.824712e+01*S52+3.431466e+01*S53+(-2.191549e+02)*S54+8.142934e+02*S55+4.923736e+01*S56+3.253094e-01*S57+2.772863e+00*S58+(-1.001599e+02)*S59'
.param V77_part7='V77_part6+1.973560e-01*S60+1.526887e-01*S61+5.828716e+00*S62+1.222307e-01*S63+6.069435e+00*S64+4.736809e+00*S65+4.339692e+00*S66+(-2.061188e+01)*S67+2.995073e+00*S68+(-3.868997e+01)*S69'
.param V77_part8='V77_part7+(-1.912806e+01)*S70+2.928054e+01*S71+1.181441e+00*S72+(-3.880743e+01)*S73+1.289108e-01*S74+(-9.721511e+00)*S75+4.948586e+00*S76+2.485504e+01*S77+(-5.724202e-01)*S78+1.570415e-01*S79'
.param V77_part9='V77_part8+(-9.605590e+00)*S80+4.123328e+00*S81+(-9.244501e-01)*S82+3.214880e+00*S83+(-5.866983e+00)*S84+(-2.946779e+00)*S85+5.773759e+00*S86+(-4.215497e+00)*S87+3.473788e+00*S88+8.954298e-01*S89'
.param V77_part10='V77_part9+(-1.572616e+00)*S90+6.519335e+00*S91+4.059487e+01*S92+(-9.349977e+00)*S93+3.237949e+00*S94+1.116519e+03*S95+(-4.248286e+00)*S96+(-4.226960e+00)*S97+1.583150e+01*S98+(-7.159800e+00)*S99'
.param V77_part11='V77_part10+(-7.455666e+00)*S100+2.819358e+00*S101+(-2.241188e+00)*S102+(-5.937265e+00)*S103+(-1.287395e+01)*S104+3.767332e+00*S105+(-1.298605e-01)*S106+(-6.596227e+01)*S107+(-1.654983e+01)*S108+(-3.404019e+01)*S109'
.param V77_part12='V77_part11+(-3.819749e+02)*S110+(-1.716557e+01)*S111+(-1.083085e+01)*S112+(-3.747753e+02)*S113+1.740658e+00*S114+(-2.385028e+02)*S115+(-3.964219e+00)*S116+(-4.057376e+00)*S117+3.372283e+01*S118+2.149206e+00*S119'
.param V77_part13='V77_part12+5.807534e+01*S120+(-1.781503e+01)*S121+1.448644e+01*S122+(-2.907008e+01)*S123+(-3.315922e+01)*S124+1.838421e+01*S125+1.669619e+00*S126+(-3.394880e+01)*S127+(-2.360047e+00)*S128+(-1.483743e+00)*S129'
.param V77_part14='V77_part13+(-2.319616e+01)*S130+(-2.644533e+00)*S131+(-3.001740e+00)*S132+(-3.823066e+00)*S133+2.125477e+00*S134+(-4.653569e+00)*S135+9.539249e+00*S136+1.684396e+01*S137+1.000000e+04*S138+1.367762e-02*S139'
.param V77_part15='V77_part14+7.069657e+00*S140+3.157861e+00*S141+2.153908e+00*S142+1.629207e+02*S143+1.694017e+01*S144+4.716077e-01*S145+(-5.315651e+00)*S146+1.667198e+02*S147+7.352305e+02*S148+2.319139e+00*S149'
.param V77_part16='V77_part15+1.316347e+00*S150+4.075902e+01*S151+(-9.561711e+03)*S152+(-6.033179e+00)*S153+(-1.912151e+01)*S154+(-3.248639e+02)*S155+(-6.516180e+01)*S156+(-2.029031e+01)*S157+3.644240e+00*S158+(-3.169376e+01)*S159'
.param V77_part17='V77_part16+(-6.976014e+01)*S160+(-3.900173e+00)*S161+2.049599e+01*S162+(-8.920635e+01)*S163+(-4.909485e+00)*S164+(-4.262711e+01)*S165+(-2.882140e+01)*S166+1.000000e+04*S167+(-3.854529e+00)*S168+(-3.912222e+01)*S169'
.param V77_part18='V77_part17+8.334668e+03*S170+4.994523e+00*S171+(-2.315391e+02)*S172+1.000000e+04*S173+(-5.845392e+01)*S174+(-2.872131e+01)*S175+(-1.000000e+04)*S176+(-2.478923e+01)*S177+(-1.155829e+01)*S178+(-5.203798e+01)*S179'
.param V77_part19='V77_part18+(-4.982933e+01)*S180+(-2.662775e+01)*S181+(-2.052686e+02)*S182+(-3.294557e+01)*S183+(-6.113480e+01)*S184+(-9.249687e+01)*S185+1.693937e+01*S186+(-3.236777e+02)*S187+(-1.072142e+02)*S188+3.936108e+00*S189'
.param V77_part20='V77_part19+1.021218e+02*S190+(-1.735205e+01)*S191+(-7.370465e+01)*S192+(-3.107896e+01)*S193+(-5.638815e-01)*S194+(-5.419348e+00)*S195+(-4.190320e+00)*S196+(-1.435255e+01)*S197+(-1.976639e+01)*S198+7.219337e+01*S199'
.param V77_part21='V77_part20+(-6.322624e+01)*S200+(-9.559838e+00)*S201+(-4.377135e+01)*S202+(-3.503118e+01)*S203+(-8.923466e+01)*S204+(-3.101626e+01)*S205+1.285181e+01*S206+3.459276e+00*S207+2.324347e+00*S208+(-2.180547e+00)*S209'
.param V77_part22='V77_part21+(-3.270175e+01)*S210+(-1.254543e+02)*S211+(-2.590229e+02)*S212+1.000000e+04*S213+(-3.383954e+01)*S214+(-6.454795e+01)*S215+(-4.437768e+01)*S216+1.032716e+03*S217+(-4.839551e+00)*S218+1.000000e+04*S219'
.param V77_part23='V77_part22+(-2.263167e+00)*S220+1.979682e+03*S221+1.058399e+02*S222+(-4.185763e+02)*S223+8.019870e+03*S224+(-8.778359e+01)*S225+(-3.823370e+01)*S226+1.101223e+01*S227+(-2.266817e+01)*S228+(-1.029541e+01)*S229'
.param V77_part24='V77_part23+4.406575e+01*S230+1.357755e+02*S231+(-5.593567e+02)*S232+(-2.024386e+01)*S233+1.327435e+01*S234+2.093595e+01*S235+(-3.279037e+00)*S236+(-7.422569e+02)*S237+(-2.788115e+02)*S238+7.144420e-01*S239'
.param V77_part25='V77_part24+8.618640e+01*S240+(-3.508572e+01)*S241+(-8.253589e+00)*S242+2.146866e+01*S243+(-2.853438e+00)*S244+(-6.410639e+01)*S245+5.388491e+02*S246+(-6.979235e+00)*S247+(-2.807598e+01)*S248+1.955259e+01*S249'
.param V77_part26='V77_part25+(-5.019207e+00)*S250+(-1.827653e+02)*S251+(-2.829515e+01)*S252+1.000000e+04*S253+5.759774e-01*S254+(-5.756071e+01)*S255+(-1.463997e+01)*S256+(-8.411200e+01)*S257+(-3.923124e+00)*S258+1.289770e+01*S259'
.param V77_part27='V77_part26+(-1.489848e+01)*S260+2.145315e+02*S261+1.210269e+01*S262+1.863232e+00*S263+2.310989e+02*S264+(-3.986891e+00)*S265+(-1.355357e+02)*S266+8.111374e-01*S267+1.626452e+01*S268+1.921965e+00*S269'
.param V77_part28='V77_part27+(-2.107899e+01)*S270+(-2.301584e+01)*S271+2.288249e+02*S272+7.057368e+01*S273+(-1.213809e+01)*S274+4.060198e+03*S275+(-2.584870e+01)*S276+(-7.393963e+01)*S277+2.450795e+01*S278+(-3.174108e+01)*S279'
.param V77_part29='V77_part28+(-3.222264e+00)*S280+2.326081e+01*S281+6.840520e+00*S282+4.025024e+01*S283+(-1.736327e+01)*S284+1.468757e+01*S285+(-3.139613e+01)*S286+1.879767e+02*S287+2.221643e+00*S288+(-1.276266e+01)*S289'
.param V77_part30='V77_part29+9.606887e+01*S290+(-2.707813e+01)*S291+1.000000e+04*S292+1.469977e+01*S293+4.759870e+00*S294+(-9.267106e+01)*S295+(-1.961406e+01)*S296+1.867140e+00*S297+(-3.102194e+00)*S298+(-1.000000e+04)*S299'
.param V77_part31='V77_part30+1.120790e+01*S300+(-1.747929e+01)*S301+(-1.238725e+01)*S302+1.288388e+01*S303+1.033339e+01*S304+(-7.576063e+01)*S305+6.863823e+00*S306+1.213932e+01*S307+(-9.455351e+00)*S308+1.170791e+02*S309'
.param V77='V77_part31+(-7.879333e+00)*S310+(-8.609858e-01)*S311+8.525175e+00*S312+(-6.463816e+01)*S313+5.527913e-01*S314'
.param V78_part1='4.356841e+01*S0+3.764037e+02*S1+1.582722e+01*S2+7.926269e+00*S3+1.110522e+01*S4+2.325523e+01*S5+(-1.832962e+03)*S6+(-2.200621e+02)*S7+4.021826e+01*S8+(-3.399770e+02)*S9'
.param V78_part2='V78_part1+3.832944e+01*S10+5.887101e+01*S11+(-8.756151e+02)*S12+5.256699e+01*S13+4.589099e+02*S14+0.000000e+00*S15+1.337753e+00*S16+3.951484e+00*S17+(-1.076677e+01)*S18+4.795743e+00*S19'
.param V78_part3='V78_part2+8.870967e+00*S20+1.148281e+01*S21+7.245985e+00*S22+2.673507e+01*S23+1.514826e+01*S24+1.632748e+01*S25+1.845752e+01*S26+2.317735e+02*S27+(-6.652780e+02)*S28+(-1.000000e+04)*S29'
.param V78_part4='V78_part3+0.000000e+00*S30+5.769787e+03*S31+1.013121e+01*S32+1.853335e+01*S33+1.886416e+01*S34+1.990792e+01*S35+5.657561e+01*S36+2.119778e-01*S37+3.198665e+01*S38+1.336719e+02*S39'
.param V78_part5='V78_part4+(-3.958241e+00)*S40+4.167463e+00*S41+1.000000e+04*S42+7.670935e+00*S43+1.372965e+00*S44+5.792310e+01*S45+7.078075e+01*S46+(-2.693123e+02)*S47+8.031940e+03*S48+3.711399e+01*S49'
.param V78_part6='V78_part5+9.606251e+03*S50+(-1.073080e-01)*S51+1.979323e+00*S52+3.249674e+01*S53+1.726473e+01*S54+(-3.586107e+01)*S55+1.671419e+01*S56+2.742429e+01*S57+1.439953e+02*S58+(-6.249939e+02)*S59'
.param V78_part7='V78_part6+3.061648e+01*S60+2.577775e+01*S61+2.893085e+01*S62+1.047058e+02*S63+1.501357e+02*S64+2.804641e+01*S65+7.783949e+01*S66+6.122266e+00*S67+1.199288e+01*S68+1.599289e+01*S69'
.param V78_part8='V78_part7+6.145343e+00*S70+1.000000e+04*S71+1.268247e+00*S72+6.368095e+01*S73+(-2.776640e-02)*S74+(-4.439811e-02)*S75+1.532516e+00*S76+1.216510e+01*S77+(-1.442642e+00)*S78+6.550810e+00*S79'
.param V78_part9='V78_part8+2.873359e+00*S80+1.068125e+01*S81+1.435595e+01*S82+1.371650e+01*S83+3.279322e+01*S84+1.926135e+01*S85+3.388376e+01*S86+6.980554e+01*S87+5.834453e+01*S88+9.186206e+00*S89'
.param V78_part10='V78_part9+3.410477e+03*S90+1.458042e+01*S91+1.307066e+03*S92+5.454962e+03*S93+3.803432e+01*S94+4.487468e+03*S95+1.085065e+02*S96+2.643735e+00*S97+(-6.971657e+00)*S98+4.254374e+00*S99'
.param V78_part11='V78_part10+2.585689e+00*S100+2.634908e+01*S101+4.733583e-01*S102+2.328760e+00*S103+(-1.000000e+04)*S104+6.229482e+01*S105+2.271022e+01*S106+(-2.405618e-03)*S107+1.314892e+01*S108+(-1.119554e-04)*S109'
.param V78_part12='V78_part11+(-1.266630e+01)*S110+7.198332e+00*S111+9.500358e+00*S112+1.000000e+04*S113+(-1.000000e+04)*S114+(-1.000000e+04)*S115+4.626622e-02*S116+(-3.001158e+01)*S117+9.985522e+03*S118+5.160191e+00*S119'
.param V78_part13='V78_part12+3.914217e+00*S120+9.437264e-01*S121+9.286819e+01*S122+9.150978e-01*S123+(-1.317861e+00)*S124+9.085680e-02*S125+(-7.666784e-01)*S126+(-7.970509e-01)*S127+9.026716e-01*S128+(-5.048428e-01)*S129'
.param V78_part14='V78_part13+1.536464e+01*S130+3.225021e-01*S131+1.253846e+00*S132+(-1.647592e+00)*S133+8.254815e+00*S134+3.288986e+01*S135+1.659283e+02*S136+4.658792e+01*S137+(-1.000000e+04)*S138+(-3.360450e-01)*S139'
.param V78_part15='V78_part14+5.603488e+01*S140+(-7.056714e+00)*S141+4.583036e-01*S142+1.000000e+04*S143+(-2.501129e+01)*S144+(-2.297658e+02)*S145+(-1.522202e+02)*S146+1.685521e+00*S147+2.148194e+03*S148+(-2.115310e+00)*S149'
.param V78_part16='V78_part15+9.987109e+03*S150+9.999925e+03*S151+(-2.883127e+01)*S152+6.899699e+02*S153+(-3.289456e-01)*S154+(-5.329613e+01)*S155+7.137010e-01*S156+1.131771e-01*S157+(-8.423481e-01)*S158+8.066447e-01*S159'
.param V78_part17='V78_part16+1.924595e+00*S160+2.538057e+00*S161+(-1.000000e+04)*S162+(-1.000000e+04)*S163+1.488184e-01*S164+1.668248e+00*S165+3.178663e+00*S166+(-1.000000e+04)*S167+(-1.000000e+04)*S168+2.008449e+00*S169'
.param V78_part18='V78_part17+1.000000e+04*S170+2.056378e+01*S171+4.802540e+00*S172+(-1.436887e+02)*S173+2.026644e+00*S174+1.408657e-01*S175+6.445701e+01*S176+(-6.159547e-02)*S177+(-9.903104e-01)*S178+(-9.628024e+00)*S179'
.param V78_part19='V78_part18+(-2.559735e+00)*S180+7.855895e-01*S181+(-1.988766e+02)*S182+(-7.026518e-02)*S183+(-1.000000e+04)*S184+(-1.000000e+04)*S185+(-1.000000e+04)*S186+(-1.857705e+03)*S187+(-1.000000e+04)*S188+(-8.172593e+00)*S189'
.param V78_part20='V78_part19+(-9.737609e+03)*S190+(-6.182603e+00)*S191+3.812618e+00*S192+(-3.886379e-03)*S193+(-2.767027e-01)*S194+(-1.984150e+00)*S195+(-1.000000e+04)*S196+(-1.000000e+04)*S197+1.821667e+00*S198+1.693332e+03*S199'
.param V78_part21='V78_part20+(-1.000000e+04)*S200+2.833988e-01*S201+(-1.000000e+04)*S202+(-1.000000e+04)*S203+(-1.000000e+04)*S204+(-2.989158e+03)*S205+(-3.429122e+01)*S206+(-8.223193e-02)*S207+(-2.738528e+00)*S208+(-1.053720e+00)*S209'
.param V78_part22='V78_part21+1.189052e+00*S210+9.339238e-01*S211+(-6.778804e-01)*S212+(-1.609565e+01)*S213+1.089969e+00*S214+(-2.597070e+01)*S215+1.118652e+00*S216+1.246035e+01*S217+(-2.323391e-01)*S218+2.261223e+00*S219'
.param V78_part23='V78_part22+(-6.355092e-01)*S220+(-1.000000e+04)*S221+(-1.000000e+04)*S222+(-1.000000e+04)*S223+(-8.360448e+03)*S224+(-3.504072e+00)*S225+7.460490e+02*S226+8.404291e+00*S227+(-3.254472e-01)*S228+(-1.453069e+00)*S229'
.param V78_part24='V78_part23+6.592100e+00*S230+(-1.000000e+04)*S231+1.905978e+01*S232+(-6.064839e-01)*S233+(-6.144273e-01)*S234+(-1.107321e+02)*S235+6.294411e+00*S236+1.000000e+04*S237+6.125096e+00*S238+(-9.078399e-01)*S239'
.param V78_part25='V78_part24+(-4.594645e+03)*S240+(-9.068631e-01)*S241+(-5.692796e-01)*S242+(-7.633483e+01)*S243+(-2.952502e+02)*S244+(-8.025500e+01)*S245+(-3.627978e+02)*S246+(-4.301875e+00)*S247+(-1.150720e-02)*S248+(-7.793115e-01)*S249'
.param V78_part26='V78_part25+(-1.579924e+00)*S250+(-1.775461e+00)*S251+(-5.725009e-02)*S252+(-5.016414e+00)*S253+(-2.371316e-01)*S254+(-1.033399e+01)*S255+(-2.010796e+00)*S256+(-1.144818e+01)*S257+(-3.520625e+00)*S258+(-1.000000e+04)*S259'
.param V78_part27='V78_part26+(-6.677467e-01)*S260+(-1.373794e+01)*S261+(-1.703650e+01)*S262+(-1.005236e+00)*S263+(-1.674294e+01)*S264+(-2.291991e+00)*S265+6.758816e+00*S266+(-9.724676e-01)*S267+(-2.838396e+01)*S268+(-2.641956e+00)*S269'
.param V78_part28='V78_part27+(-2.548143e-01)*S270+(-3.774678e-01)*S271+5.104464e+03*S272+(-3.239515e+03)*S273+1.842276e-01*S274+(-6.352100e+00)*S275+1.599905e-01*S276+(-1.000000e+04)*S277+(-1.052963e+00)*S278+1.796111e-01*S279'
.param V78_part29='V78_part28+(-2.110502e+00)*S280+1.231394e-01*S281+(-3.092514e-01)*S282+(-4.530349e-01)*S283+(-3.029683e-03)*S284+(-3.579014e+01)*S285+(-5.217785e-01)*S286+(-1.000000e+04)*S287+(-6.588493e-01)*S288+(-1.210132e-01)*S289'
.param V78_part30='V78_part29+(-1.588656e+02)*S290+2.406634e-01*S291+(-6.070642e+00)*S292+(-4.235075e-01)*S293+(-1.619991e-01)*S294+1.142504e+00*S295+(-1.275870e-01)*S296+(-3.032420e-01)*S297+(-3.502171e-01)*S298+(-2.826858e-01)*S299'
.param V78_part31='V78_part30+(-1.578461e+01)*S300+(-3.736738e+00)*S301+(-8.105267e+00)*S302+(-2.632016e+00)*S303+(-7.694087e+01)*S304+(-6.598917e+02)*S305+(-1.376184e+00)*S306+(-6.637892e+02)*S307+(-1.843678e+02)*S308+(-3.011060e+00)*S309'
.param V78='V78_part31+(-2.384479e+01)*S310+(-3.561301e+01)*S311+(-6.567392e-01)*S312+(-1.862038e+01)*S313+(-3.027915e-01)*S314'
.param V79_part1='6.143382e+00*S0+9.631851e+01*S1+1.632746e+00*S2+(-5.764216e-01)*S3+(-6.373798e-01)*S4+(-8.672635e-01)*S5+1.374619e+00*S6+(-3.849094e+00)*S7+5.492503e-01*S8+(-1.056837e+01)*S9'
.param V79_part2='V79_part1+(-9.925932e-02)*S10+8.763112e-02*S11+(-7.582306e+00)*S12+2.693542e-01*S13+1.977791e-01*S14+0.000000e+00*S15+(-1.377845e-01)*S16+3.481762e-03*S17+(-7.076317e-02)*S18+(-3.124840e-03)*S19'
.param V79_part3='V79_part2+(-9.279912e-02)*S20+(-9.828897e-03)*S21+(-1.322925e-02)*S22+(-2.361815e-01)*S23+2.782817e-02*S24+9.707809e-03*S25+(-1.129728e-03)*S26+7.734702e+00*S27+5.716295e+03*S28+6.458478e-01*S29'
.param V79_part4='V79_part3+0.000000e+00*S30+1.000000e+04*S31+2.019791e-01*S32+1.436220e-02*S33+3.912219e-01*S34+2.813490e-01*S35+2.639772e-01*S36+(-1.077352e+00)*S37+4.860265e-01*S38+6.279870e-01*S39'
.param V79_part5='V79_part4+1.305455e+00*S40+2.424371e-01*S41+7.883110e-01*S42+1.728192e+00*S43+2.160111e-01*S44+(-3.905969e-01)*S45+5.933586e-01*S46+3.225591e+01*S47+8.439805e+03*S48+1.159519e+00*S49'
.param V79_part6='V79_part5+1.000000e+04*S50+2.985025e-02*S51+4.470722e+00*S52+4.979127e+02*S53+1.000000e+04*S54+1.000000e+04*S55+2.094836e+02*S56+8.554369e+01*S57+4.571144e+03*S58+1.000000e+04*S59'
.param V79_part7='V79_part6+7.632379e-01*S60+4.497432e-01*S61+2.642938e-01*S62+1.183613e+00*S63+1.118271e+00*S64+6.639045e-01*S65+2.407610e+00*S66+6.307060e-02*S67+7.768833e-01*S68+5.211276e-01*S69'
.param V79_part8='V79_part7+(-5.060362e-02)*S70+1.088441e+00*S71+2.465228e+00*S72+1.860966e+03*S73+3.298556e-02*S74+1.843259e+00*S75+6.077878e-01*S76+1.011284e-02*S77+4.360478e-02*S78+4.550553e-01*S79'
.param V79_part9='V79_part8+1.728010e+01*S80+7.383835e-01*S81+3.336553e-01*S82+4.420492e-01*S83+6.996279e-01*S84+8.703615e-01*S85+8.349241e-01*S86+1.642147e+00*S87+8.472176e-01*S88+6.846355e-01*S89'
.param V79_part10='V79_part9+8.240615e-01*S90+1.300675e+01*S91+(-6.140182e-03)*S92+1.106799e-01*S93+(-2.373886e-01)*S94+1.000000e+04*S95+1.759087e+00*S96+1.038520e+00*S97+4.095638e-01*S98+4.261648e+00*S99'
.param V79_part11='V79_part10+1.624569e+00*S100+1.658593e+00*S101+7.127400e+00*S102+2.875825e+00*S103+6.673264e+01*S104+8.074910e-01*S105+1.185035e+00*S106+1.816505e+02*S107+9.484433e+00*S108+7.755729e+00*S109'
.param V79_part12='V79_part11+4.391629e+01*S110+1.491548e+01*S111+7.531952e+00*S112+2.115952e+01*S113+(-8.676236e+00)*S114+1.196379e+02*S115+6.728754e-01*S116+1.929357e+00*S117+1.943380e+01*S118+1.610646e+01*S119'
.param V79_part13='V79_part12+2.266057e+01*S120+1.341315e+01*S121+(-8.238828e-01)*S122+2.283265e+01*S123+1.373232e+01*S124+1.288754e+02*S125+2.853767e+01*S126+1.725385e+01*S127+1.309132e+01*S128+3.432812e+01*S129'
.param V79_part14='V79_part13+1.993688e+02*S130+2.942563e+01*S131+2.433652e+00*S132+6.739231e-01*S133+1.290127e+02*S134+5.746062e-01*S135+1.038477e+00*S136+4.730980e+03*S137+1.000000e+04*S138+4.422148e+00*S139'
.param V79_part15='V79_part14+3.917134e+00*S140+3.831420e+02*S141+5.557584e+00*S142+(-4.003617e+01)*S143+1.000000e+04*S144+1.072736e+03*S145+1.457596e+03*S146+1.000000e+04*S147+1.000000e+04*S148+1.082770e+01*S149'
.param V79_part16='V79_part15+(-1.751326e+00)*S150+(-2.986682e+00)*S151+2.105376e+01*S152+3.010446e+00*S153+3.725937e+00*S154+1.000000e+04*S155+(-1.989624e+00)*S156+1.983890e+00*S157+2.833168e+01*S158+2.162660e+00*S159'
.param V79_part17='V79_part16+6.766348e+00*S160+4.972967e+00*S161+3.230020e-01*S162+3.879531e+01*S163+5.515937e-01*S164+1.525079e+01*S165+7.325877e+00*S166+1.000000e+04*S167+1.631963e+01*S168+8.714090e+00*S169'
.param V79_part18='V79_part17+(-1.235356e+02)*S170+1.086046e+02*S171+5.173800e+01*S172+8.434613e-01*S173+6.841502e-01*S174+2.131352e+00*S175+9.496467e+02*S176+1.502497e-01*S177+6.717019e-01*S178+1.289571e+00*S179'
.param V79_part19='V79_part18+1.823989e+01*S180+1.034599e+01*S181+7.838148e+01*S182+3.326820e+01*S183+1.314965e+01*S184+1.719595e+02*S185+2.694217e+00*S186+7.874192e+03*S187+1.493399e+03*S188+1.289622e+00*S189'
.param V79_part20='V79_part19+1.430327e+02*S190+6.818358e+01*S191+1.551401e+00*S192+2.069978e+00*S193+3.480989e-01*S194+5.752639e+00*S195+5.378131e+00*S196+7.927153e+00*S197+6.959510e+00*S198+(-1.601146e+00)*S199'
.param V79_part21='V79_part20+2.669228e+00*S200+7.717442e+00*S201+2.126948e+00*S202+1.280185e+01*S203+1.044260e+01*S204+1.627773e+00*S205+4.726926e-01*S206+2.477315e+00*S207+3.316836e+00*S208+3.423306e+00*S209'
.param V79_part22='V79_part21+5.270881e+00*S210+9.077105e+00*S211+1.000000e+04*S212+4.021802e+01*S213+5.942206e+00*S214+1.619885e+01*S215+(-6.915785e-01)*S216+(-1.364528e+00)*S217+4.579898e-01*S218+7.131717e+00*S219'
.param V79_part23='V79_part22+3.523936e-01*S220+(-1.000000e+04)*S221+(-1.099138e+00)*S222+(-1.000000e+04)*S223+(-1.000000e+04)*S224+3.326875e+01*S225+1.776773e+01*S226+2.497519e+03*S227+5.477396e-01*S228+6.612553e-01*S229'
.param V79_part24='V79_part23+9.995261e+03*S230+1.021401e+01*S231+1.000000e+04*S232+1.998600e+00*S233+1.950494e+00*S234+2.674814e+00*S235+2.862726e+03*S236+2.018191e+03*S237+1.159763e+01*S238+3.930325e-01*S239'
.param V79_part25='V79_part24+1.459438e+01*S240+2.613756e+01*S241+2.342188e+00*S242+1.328291e+00*S243+(-1.407612e+00)*S244+(-9.122515e-01)*S245+8.604299e+00*S246+8.009212e-01*S247+2.771118e-02*S248+2.580469e+00*S249'
.param V79_part26='V79_part25+4.602287e-01*S250+(-3.344034e+00)*S251+(-9.825366e-03)*S252+8.566653e+03*S253+1.445541e+00*S254+4.089987e+01*S255+8.697123e+00*S256+1.394147e+02*S257+8.035657e-01*S258+4.352249e+00*S259'
.param V79_part27='V79_part26+1.837150e+03*S260+3.720224e+01*S261+(-4.267460e-02)*S262+3.174137e+00*S263+7.457996e+00*S264+8.605907e-01*S265+1.000000e+04*S266+1.212309e+00*S267+4.573010e+02*S268+1.577281e+01*S269'
.param V79_part28='V79_part27+8.784378e-01*S270+2.057292e+01*S271+1.000000e+04*S272+3.493701e+00*S273+3.208826e+00*S274+9.235150e+03*S275+3.991236e-01*S276+6.632838e+03*S277+1.170976e+01*S278+(-1.170090e+00)*S279'
.param V79_part29='V79_part28+3.405869e-01*S280+1.144407e+01*S281+2.104252e+00*S282+1.938892e+00*S283+(-1.098419e-01)*S284+2.328380e+00*S285+4.773664e+00*S286+1.538200e+01*S287+3.323284e+00*S288+6.191363e-01*S289'
.param V79_part30='V79_part29+(-1.432049e+00)*S290+6.071083e-01*S291+1.000000e+04*S292+1.213356e+01*S293+1.359849e+00*S294+2.128021e+01*S295+(-4.827878e-01)*S296+7.613312e-01*S297+1.403438e-01*S298+(-3.511238e+00)*S299'
.param V79_part31='V79_part30+2.015029e+00*S300+1.853665e+01*S301+8.334958e+01*S302+8.986890e+00*S303+3.543478e+00*S304+9.377091e+00*S305+4.140848e+00*S306+8.338067e+00*S307+(-9.182578e-02)*S308+7.557956e+01*S309'
.param V79='V79_part31+1.000000e+04*S310+(-5.373825e-01)*S311+1.752298e+00*S312+1.000000e+04*S313+7.268810e-01*S314'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V80_part2='V80_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V80_part3='V80_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V80_part4='V80_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+(-4.091358e-01)*S38+0.000000e+00*S39'
.param V80_part5='V80_part4+0.000000e+00*S40+(-1.394661e-01)*S41+0.000000e+00*S42+(-1.410779e-01)*S43+(-3.357234e-01)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+(-1.886513e-02)*S49'
.param V80_part6='V80_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+(-1.611191e-01)*S53+0.000000e+00*S54+0.000000e+00*S55+(-4.774119e-01)*S56+(-4.614137e-02)*S57+(-1.446121e-01)*S58+(-3.254843e-01)*S59'
.param V80_part7='V80_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-1.333548e-01)*S66+0.000000e+00*S67+(-3.670850e-01)*S68+0.000000e+00*S69'
.param V80_part8='V80_part7+0.000000e+00*S70+(-3.156658e-01)*S71+(-1.933550e-01)*S72+0.000000e+00*S73+5.924233e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V80_part9='V80_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+(-2.928561e-02)*S89'
.param V80_part10='V80_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+(-2.477997e-01)*S93+0.000000e+00*S94+0.000000e+00*S95+(-2.653215e-01)*S96+(-2.824247e-01)*S97+(-3.883724e-01)*S98+(-2.033712e-01)*S99'
.param V80_part11='V80_part10+(-5.081023e-01)*S100+(-1.076884e+00)*S101+(-3.516816e-01)*S102+(-6.326855e-01)*S103+(-2.242019e-01)*S104+0.000000e+00*S105+(-1.623682e-01)*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V80_part12='V80_part11+(-2.672415e-01)*S110+(-1.587174e-01)*S111+(-2.949305e-01)*S112+(-8.960711e-02)*S113+0.000000e+00*S114+(-2.110843e-01)*S115+0.000000e+00*S116+(-2.573036e-01)*S117+(-9.005564e-01)*S118+(-9.960409e-01)*S119'
.param V80_part13='V80_part12+0.000000e+00*S120+(-2.062059e-01)*S121+(-2.140917e-01)*S122+(-1.892989e-01)*S123+(-2.925735e-01)*S124+(-4.160081e-01)*S125+0.000000e+00*S126+(-2.482749e-01)*S127+(-5.113069e-01)*S128+(-3.438866e-01)*S129'
.param V80_part14='V80_part13+(-5.465120e-01)*S130+(-7.501019e-01)*S131+(-1.202877e-01)*S132+(-3.009720e-01)*S133+(-1.077257e+00)*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+(-3.066711e-04)*S139'
.param V80_part15='V80_part14+4.300701e-02*S140+(-1.938205e-02)*S141+0.000000e+00*S142+(-2.370618e-01)*S143+(-3.930300e-02)*S144+(-1.146112e-01)*S145+(-2.633920e-01)*S146+0.000000e+00*S147+0.000000e+00*S148+(-2.598917e-01)*S149'
.param V80_part16='V80_part15+(-2.393047e-01)*S150+(-2.052165e-01)*S151+0.000000e+00*S152+(-2.748489e-01)*S153+0.000000e+00*S154+(-4.442146e-01)*S155+3.553592e-01*S156+(-7.308182e-01)*S157+0.000000e+00*S158+(-4.355110e-01)*S159'
.param V80_part17='V80_part16+(-6.141188e-01)*S160+(-8.600463e-01)*S161+(-2.169386e-01)*S162+(-9.215760e-01)*S163+(-2.149528e+00)*S164+(-1.094738e-01)*S165+0.000000e+00*S166+(-3.864469e-01)*S167+0.000000e+00*S168+(-3.777041e-01)*S169'
.param V80_part18='V80_part17+(-6.404908e-01)*S170+1.775792e-01*S171+0.000000e+00*S172+(-5.991547e-01)*S173+3.073183e-01*S174+0.000000e+00*S175+(-1.120287e+00)*S176+0.000000e+00*S177+(-2.585887e-01)*S178+(-2.198136e-01)*S179'
.param V80_part19='V80_part18+(-1.578497e-01)*S180+(-2.366655e-01)*S181+(-3.838966e-01)*S182+(-8.997887e-02)*S183+(-5.241412e-01)*S184+(-6.475876e-01)*S185+0.000000e+00*S186+(-4.061313e-01)*S187+(-6.658598e-01)*S188+0.000000e+00*S189'
.param V80_part20='V80_part19+0.000000e+00*S190+(-2.870250e-01)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+9.627972e-02*S195+0.000000e+00*S196+(-2.121705e-01)*S197+0.000000e+00*S198+(-3.092976e-02)*S199'
.param V80_part21='V80_part20+(-4.021934e-01)*S200+1.065562e-01*S201+(-2.098878e-01)*S202+(-3.819706e-01)*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+4.404372e-01*S207+2.629185e-01*S208+0.000000e+00*S209'
.param V80_part22='V80_part21+(-1.391375e-01)*S210+(-2.931773e-01)*S211+(-3.802837e-01)*S212+0.000000e+00*S213+(-3.332139e-01)*S214+(-5.722208e-01)*S215+(-4.280363e-02)*S216+(-3.359327e-02)*S217+(-9.113670e-01)*S218+(-3.340064e-02)*S219'
.param V80_part23='V80_part22+(-6.288145e-01)*S220+1.871012e-01*S221+0.000000e+00*S222+(-1.199320e-01)*S223+0.000000e+00*S224+(-7.056714e-02)*S225+(-2.479427e-01)*S226+(-9.410343e-01)*S227+(-8.836497e-02)*S228+(-2.908307e-01)*S229'
.param V80_part24='V80_part23+(-6.529105e-01)*S230+0.000000e+00*S231+(-3.279977e-01)*S232+(-4.054359e-01)*S233+1.670488e-01*S234+0.000000e+00*S235+(-7.788190e-02)*S236+(-3.767313e-01)*S237+0.000000e+00*S238+(-3.253169e-01)*S239'
.param V80_part25='V80_part24+2.807457e-04*S240+(-2.242301e-01)*S241+(-4.457577e-01)*S242+1.674710e-02*S243+(-1.060069e-01)*S244+0.000000e+00*S245+(-4.355609e-02)*S246+(-3.809441e-01)*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V80_part26='V80_part25+(-5.061191e-01)*S250+(-4.203237e-01)*S251+9.017476e-02*S252+(-6.061716e-01)*S253+(-1.767583e+00)*S254+(-4.774440e-02)*S255+4.087896e-02*S256+(-5.462518e-01)*S257+1.898410e-01*S258+(-4.664567e-02)*S259'
.param V80_part27='V80_part26+(-3.204879e-01)*S260+0.000000e+00*S261+(-7.964645e-02)*S262+(-1.803673e-01)*S263+(-2.135607e-01)*S264+6.116808e-02*S265+(-6.991144e-01)*S266+5.919018e-01*S267+(-1.643755e-02)*S268+(-2.039658e-02)*S269'
.param V80_part28='V80_part27+(-1.374137e-01)*S270+(-1.954728e-01)*S271+(-3.326430e-01)*S272+(-1.763711e-01)*S273+(-4.013988e-01)*S274+(-1.851226e-02)*S275+5.221701e-02*S276+(-4.450753e-02)*S277+(-1.453516e-03)*S278+2.001938e-01*S279'
.param V80_part29='V80_part28+(-1.215433e+00)*S280+(-8.705425e-01)*S281+(-2.491595e-01)*S282+3.731471e-01*S283+0.000000e+00*S284+1.557516e-02*S285+0.000000e+00*S286+(-1.408798e-01)*S287+(-8.238464e-02)*S288+(-1.366462e-01)*S289'
.param V80_part30='V80_part29+0.000000e+00*S290+0.000000e+00*S291+(-1.211519e-01)*S292+1.319715e-01*S293+8.915779e-02*S294+1.227203e+00*S295+(-2.044312e+00)*S296+(-4.790624e-01)*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V80_part31='V80_part30+1.469679e-01*S300+(-9.431800e-03)*S301+(-3.453549e-01)*S302+3.256562e-01*S303+(-1.262079e-01)*S304+(-2.017935e-01)*S305+2.968286e-01*S306+2.515413e-01*S307+(-3.409404e-01)*S308+0.000000e+00*S309'
.param V80='V80_part31+4.817876e-02*S310+(-2.932451e-01)*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V81_part2='V81_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V81_part3='V81_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V81_part4='V81_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+5.694324e-01*S38+0.000000e+00*S39'
.param V81_part5='V81_part4+0.000000e+00*S40+3.063279e-01*S41+0.000000e+00*S42+2.876207e-01*S43+4.881776e-01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+3.278982e-01*S49'
.param V81_part6='V81_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+4.198712e-01*S53+0.000000e+00*S54+0.000000e+00*S55+4.512342e-01*S56+2.520992e-01*S57+3.933837e-01*S58+4.458434e-01*S59'
.param V81_part7='V81_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+4.481757e-01*S66+0.000000e+00*S67+5.802026e-01*S68+0.000000e+00*S69'
.param V81_part8='V81_part7+0.000000e+00*S70+4.917763e-01*S71+7.757060e-01*S72+0.000000e+00*S73+(-2.078563e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V81_part9='V81_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+1.237092e-01*S89'
.param V81_part10='V81_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+8.423664e-01*S93+0.000000e+00*S94+0.000000e+00*S95+8.251947e-01*S96+7.196095e-01*S97+7.260598e-01*S98+7.494062e-01*S99'
.param V81_part11='V81_part10+8.219215e-01*S100+1.077793e+00*S101+8.369460e-01*S102+9.534519e-01*S103+5.516582e-01*S104+0.000000e+00*S105+8.022193e-01*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V81_part12='V81_part11+6.196895e-01*S110+6.828748e-01*S111+6.552372e-01*S112+3.561834e-01*S113+0.000000e+00*S114+3.726717e-01*S115+0.000000e+00*S116+7.546675e-01*S117+1.147936e+00*S118+1.167362e+00*S119'
.param V81_part13='V81_part12+0.000000e+00*S120+8.468778e-01*S121+6.996235e-01*S122+7.242908e-01*S123+6.722430e-01*S124+7.040702e-01*S125+0.000000e+00*S126+1.659142e-03*S127+8.810109e-01*S128+8.187868e-01*S129'
.param V81_part14='V81_part13+8.205014e-01*S130+1.016231e+00*S131+7.800935e-01*S132+7.816439e-01*S133+1.225708e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+8.244228e-01*S139'
.param V81_part15='V81_part14+7.459069e-01*S140+2.030526e-01*S141+0.000000e+00*S142+4.772317e-01*S143+2.747384e-01*S144+3.439850e-01*S145+5.397322e-01*S146+0.000000e+00*S147+0.000000e+00*S148+7.264037e-01*S149'
.param V81_part16='V81_part15+9.006657e-01*S150+6.088620e-01*S151+0.000000e+00*S152+8.611598e-01*S153+0.000000e+00*S154+1.052961e+00*S155+(-2.081914e-01)*S156+1.191185e+00*S157+0.000000e+00*S158+(-2.141359e-01)*S159'
.param V81_part17='V81_part16+9.591329e-01*S160+1.008460e+00*S161+5.297728e-01*S162+1.262223e+00*S163+2.002777e+00*S164+6.774751e-01*S165+0.000000e+00*S166+1.091692e+00*S167+0.000000e+00*S168+8.056116e-01*S169'
.param V81_part18='V81_part17+1.401386e+00*S170+(-8.011859e-02)*S171+0.000000e+00*S172+9.751864e-01*S173+2.775824e-01*S174+0.000000e+00*S175+1.299152e+00*S176+0.000000e+00*S177+8.123707e-01*S178+5.745249e-01*S179'
.param V81_part19='V81_part18+7.540699e-01*S180+6.815484e-01*S181+1.079759e+00*S182+3.486691e-01*S183+7.860039e-01*S184+1.129376e+00*S185+0.000000e+00*S186+8.200076e-01*S187+1.048860e+00*S188+0.000000e+00*S189'
.param V81_part20='V81_part19+0.000000e+00*S190+7.198005e-01*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+7.410924e-01*S195+0.000000e+00*S196+7.808712e-01*S197+0.000000e+00*S198+5.401380e-01*S199'
.param V81_part21='V81_part20+9.652802e-01*S200+3.878423e-01*S201+7.893439e-01*S202+1.022228e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+8.675517e-01*S207+1.157631e+00*S208+0.000000e+00*S209'
.param V81_part22='V81_part21+7.382790e-01*S210+9.434855e-01*S211+1.185570e+00*S212+0.000000e+00*S213+6.187881e-01*S214+1.301970e+00*S215+1.008274e+00*S216+4.159471e-01*S217+1.333969e+00*S218+1.510888e-01*S219'
.param V81_part23='V81_part22+1.563611e+00*S220+7.483856e-02*S221+0.000000e+00*S222+8.072064e-02*S223+0.000000e+00*S224+4.677771e-01*S225+6.921981e-01*S226+7.195865e-01*S227+6.729672e-01*S228+8.239645e-01*S229'
.param V81_part24='V81_part23+1.182969e+00*S230+0.000000e+00*S231+7.575338e-01*S232+6.884116e-01*S233+7.690738e-04*S234+0.000000e+00*S235+3.093841e-01*S236+1.682877e-01*S237+0.000000e+00*S238+7.038078e-01*S239'
.param V81_part25='V81_part24+7.799757e-01*S240+8.200046e-01*S241+1.219116e+00*S242+6.853291e-01*S243+8.662563e-01*S244+0.000000e+00*S245+1.550256e-01*S246+1.216003e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V81_part26='V81_part25+1.384408e+00*S250+5.972929e-01*S251+6.607304e-01*S252+1.143621e+00*S253+6.363897e-01*S254+5.383692e-01*S255+2.924823e-01*S256+1.423442e+00*S257+6.557262e-01*S258+6.112883e-01*S259'
.param V81_part27='V81_part26+8.781032e-01*S260+0.000000e+00*S261+9.784227e-01*S262+1.047997e+00*S263+1.082803e+00*S264+1.133846e+00*S265+1.174895e+00*S266+1.030865e+00*S267+7.690881e-01*S268+5.775196e-01*S269'
.param V81_part28='V81_part27+8.824189e-01*S270+4.994772e-01*S271+1.189169e+00*S272+1.009163e+00*S273+9.331630e-01*S274+5.850376e-01*S275+3.830890e-01*S276+5.520641e-02*S277+1.190201e+00*S278+1.036139e-01*S279'
.param V81_part29='V81_part28+1.844649e+00*S280+8.824899e-01*S281+1.185666e+00*S282+1.270667e+00*S283+0.000000e+00*S284+6.311612e-01*S285+0.000000e+00*S286+7.502100e-01*S287+7.394026e-01*S288+8.914547e-01*S289'
.param V81_part30='V81_part29+0.000000e+00*S290+0.000000e+00*S291+1.185645e+00*S292+6.430834e-01*S293+2.641507e-01*S294+3.942971e-01*S295+1.847051e+00*S296+1.296177e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V81_part31='V81_part30+8.291682e-01*S300+6.995365e-01*S301+1.044451e+00*S302+9.292009e-01*S303+1.130288e+00*S304+9.233107e-01*S305+1.026856e+00*S306+1.031805e+00*S307+5.441135e-01*S308+0.000000e+00*S309'
.param V81='V81_part31+1.001611e+00*S310+3.705979e-02*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V82_part2='V82_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V82_part3='V82_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V82_part4='V82_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+4.962816e-01*S38+0.000000e+00*S39'
.param V82_part5='V82_part4+0.000000e+00*S40+4.342585e-01*S41+0.000000e+00*S42+1.807828e-01*S43+9.657391e-01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+(-1.309424e-02)*S49'
.param V82_part6='V82_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+1.638480e-01*S53+0.000000e+00*S54+0.000000e+00*S55+4.634614e-01*S56+1.132815e-01*S57+1.636302e-01*S58+3.641950e-01*S59'
.param V82_part7='V82_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+3.683646e-03*S66+0.000000e+00*S67+3.038626e-01*S68+0.000000e+00*S69'
.param V82_part8='V82_part7+0.000000e+00*S70+3.645857e-01*S71+1.181630e-01*S72+0.000000e+00*S73+1.558408e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V82_part9='V82_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+9.294158e-02*S89'
.param V82_part10='V82_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+5.089169e-01*S93+0.000000e+00*S94+0.000000e+00*S95+6.281594e-01*S96+1.092129e+00*S97+3.128937e-01*S98+7.362015e-01*S99'
.param V82_part11='V82_part10+1.360709e+00*S100+2.115728e+00*S101+7.623357e-01*S102+1.390144e+00*S103+1.035283e+00*S104+0.000000e+00*S105+2.594203e-01*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V82_part12='V82_part11+3.217412e-01*S110+4.725816e-01*S111+7.715579e-01*S112+1.285387e-01*S113+0.000000e+00*S114+5.004098e-01*S115+0.000000e+00*S116+7.209488e-01*S117+8.103832e-01*S118+1.222228e+00*S119'
.param V82_part13='V82_part12+0.000000e+00*S120+3.190902e-01*S121+1.567486e-01*S122+3.111832e-01*S123+5.888582e-01*S124+8.204911e-01*S125+0.000000e+00*S126+7.610320e-01*S127+8.042022e-01*S128+5.312977e-01*S129'
.param V82_part14='V82_part13+6.566661e-01*S130+9.464646e-01*S131+2.342233e-01*S132+5.515271e-01*S133+1.086836e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+1.797071e-01*S139'
.param V82_part15='V82_part14+3.051817e-03*S140+2.523474e-02*S141+0.000000e+00*S142+1.686436e-01*S143+7.520460e-02*S144+1.512167e-01*S145+1.649391e-01*S146+0.000000e+00*S147+0.000000e+00*S148+4.754125e-01*S149'
.param V82_part16='V82_part15+7.240517e-01*S150+3.871515e-01*S151+0.000000e+00*S152+1.058993e+00*S153+0.000000e+00*S154+4.300774e-01*S155+7.977408e-03*S156+1.925619e+00*S157+0.000000e+00*S158+2.701647e+00*S159'
.param V82_part17='V82_part16+1.575348e+00*S160+1.756928e+00*S161+6.504343e-01*S162+1.362171e+00*S163+3.449054e+00*S164+5.545918e-01*S165+0.000000e+00*S166+5.182763e-01*S167+0.000000e+00*S168+1.170258e+00*S169'
.param V82_part18='V82_part17+7.617773e-01*S170+1.746689e-02*S171+0.000000e+00*S172+9.402464e-01*S173+(-6.085539e-01)*S174+0.000000e+00*S175+1.386440e+00*S176+0.000000e+00*S177+9.094214e-01*S178+1.526664e+00*S179'
.param V82_part19='V82_part18+5.214339e-01*S180+8.159936e-01*S181+4.465813e-01*S182+5.790504e-01*S183+8.493599e-01*S184+1.147151e+00*S185+0.000000e+00*S186+9.628386e-01*S187+1.069633e+00*S188+0.000000e+00*S189'
.param V82_part20='V82_part19+0.000000e+00*S190+8.415427e-01*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+2.392028e-01*S195+0.000000e+00*S196+4.631684e-01*S197+0.000000e+00*S198+6.198231e-01*S199'
.param V82_part21='V82_part20+4.911369e-01*S200+4.903045e-01*S201+8.722750e-01*S202+9.146958e-01*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+(-1.444906e-01)*S207+8.027640e-02*S208+0.000000e+00*S209'
.param V82_part22='V82_part21+1.233802e+00*S210+8.480277e-01*S211+5.501853e-01*S212+0.000000e+00*S213+1.415494e+00*S214+8.413879e-01*S215+1.261888e+00*S216+3.601159e-01*S217+2.541811e+00*S218+2.204659e-01*S219'
.param V82_part23='V82_part22+1.876007e+00*S220+(-6.550450e-03)*S221+0.000000e+00*S222+4.222436e-01*S223+0.000000e+00*S224+6.430983e-01*S225+1.051391e+00*S226+1.643454e+00*S227+1.037346e+00*S228+1.160171e+00*S229'
.param V82_part24='V82_part23+1.311144e+00*S230+0.000000e+00*S231+1.211801e+00*S232+9.950508e-01*S233+(-1.642401e-01)*S234+0.000000e+00*S235+5.334335e-01*S236+2.365121e+00*S237+0.000000e+00*S238+1.335746e+00*S239'
.param V82_part25='V82_part24+4.831257e-01*S240+8.789871e-01*S241+1.253530e+00*S242+3.830682e-01*S243+5.102197e-01*S244+0.000000e+00*S245+6.593228e-01*S246+1.467313e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V82_part26='V82_part25+1.422790e+00*S250+2.837752e-01*S251+5.351143e-01*S252+5.631341e-01*S253+3.126065e+00*S254+3.975513e-01*S255+6.441728e-01*S256+7.455329e-01*S257+7.441100e-01*S258+9.153436e-01*S259'
.param V82_part27='V82_part26+9.643557e-01*S260+0.000000e+00*S261+1.115821e+00*S262+1.177557e+00*S263+2.301863e-01*S264+7.991637e-01*S265+7.936427e-01*S266+(-8.899062e-01)*S267+7.096897e-01*S268+8.930738e-01*S269'
.param V82_part28='V82_part27+1.409760e+00*S270+9.605530e-01*S271+1.024198e+00*S272+2.065446e+00*S273+2.091634e+00*S274+1.630129e+00*S275+1.255935e+00*S276+1.436635e+00*S277+1.117894e+00*S278+1.487853e+00*S279'
.param V82_part29='V82_part28+1.953867e+00*S280+2.211372e+00*S281+8.519490e-01*S282+(-5.123428e-01)*S283+0.000000e+00*S284+6.425722e-01*S285+0.000000e+00*S286+4.843737e-01*S287+1.437356e+00*S288+8.581400e-01*S289'
.param V82_part30='V82_part29+0.000000e+00*S290+0.000000e+00*S291+4.837455e-01*S292+8.482822e-01*S293+1.017510e+00*S294+(-2.020713e+00)*S295+2.130331e+00*S296+1.069646e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V82_part31='V82_part30+1.048932e+00*S300+7.836371e-01*S301+1.174104e+00*S302+9.367082e-01*S303+1.527297e+00*S304+8.373015e-01*S305+9.551112e-01*S306+(-6.347721e-02)*S307+5.241194e-01*S308+0.000000e+00*S309'
.param V82='V82_part31+2.121040e-01*S310+6.007344e-01*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V83_part2='V83_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V83_part3='V83_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V83_part4='V83_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+1.274844e-01*S38+0.000000e+00*S39'
.param V83_part5='V83_part4+0.000000e+00*S40+(-6.056455e-03)*S41+0.000000e+00*S42+8.946582e-02*S43+(-7.293102e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+7.510685e-02*S49'
.param V83_part6='V83_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+1.452143e-01*S53+0.000000e+00*S54+0.000000e+00*S55+6.452086e-02*S56+6.206436e-02*S57+2.174779e-01*S58+1.572641e-01*S59'
.param V83_part7='V83_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+9.009488e-02*S66+0.000000e+00*S67+3.347925e-02*S68+0.000000e+00*S69'
.param V83_part8='V83_part7+0.000000e+00*S70+6.825124e-02*S71+3.018709e-02*S72+0.000000e+00*S73+5.874686e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V83_part9='V83_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+7.283865e-02*S89'
.param V83_part10='V83_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+8.826277e-02*S93+0.000000e+00*S94+0.000000e+00*S95+8.156294e-02*S96+6.272156e-02*S97+1.642341e-01*S98+2.161841e-01*S99'
.param V83_part11='V83_part10+2.232252e-01*S100+1.056263e-01*S101+1.706548e-01*S102+2.705305e-01*S103+6.354606e-02*S104+0.000000e+00*S105+4.671823e-02*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V83_part12='V83_part11+8.224248e-02*S110+1.897667e-01*S111+1.574035e-01*S112+1.041575e-01*S113+0.000000e+00*S114+6.223262e-02*S115+0.000000e+00*S116+2.521902e-01*S117+1.918731e-01*S118+1.643801e-01*S119'
.param V83_part13='V83_part12+0.000000e+00*S120+7.685224e-02*S121+3.340213e-02*S122+6.796498e-02*S123+8.187745e-02*S124+9.016881e-03*S125+0.000000e+00*S126+(-2.839684e-02)*S127+6.777418e-02*S128+1.188290e-01*S129'
.param V83_part14='V83_part13+1.641699e-01*S130+7.715428e-02*S131+1.878982e-01*S132+1.041347e-01*S133+1.089382e-01*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+2.892233e-01*S139'
.param V83_part15='V83_part14+2.134683e-01*S140+9.391149e-02*S141+0.000000e+00*S142+9.107374e-02*S143+1.539637e-01*S144+1.760700e-01*S145+2.004198e-01*S146+0.000000e+00*S147+0.000000e+00*S148+2.956366e-01*S149'
.param V83_part16='V83_part15+5.239437e-02*S150+4.628960e-02*S151+0.000000e+00*S152+8.458316e-02*S153+0.000000e+00*S154+1.569879e-01*S155+1.246626e-01*S156+2.948183e-01*S157+0.000000e+00*S158+(-1.692351e-03)*S159'
.param V83_part17='V83_part16+2.734429e-01*S160+1.180151e-01*S161+2.694737e-01*S162+2.593977e-01*S163+2.536357e-01*S164+1.137033e-01*S165+0.000000e+00*S166+1.254823e-01*S167+0.000000e+00*S168+1.792952e-01*S169'
.param V83_part18='V83_part17+1.588095e-01*S170+4.347072e-02*S171+0.000000e+00*S172+7.433731e-02*S173+2.105754e-01*S174+0.000000e+00*S175+1.204209e-01*S176+0.000000e+00*S177+1.479780e-01*S178+3.881810e-02*S179'
.param V83_part19='V83_part18+6.168679e-02*S180+1.001722e-01*S181+3.677441e-02*S182+7.195691e-02*S183+7.687397e-02*S184+5.732730e-02*S185+0.000000e+00*S186+1.354766e-01*S187+7.917192e-02*S188+0.000000e+00*S189'
.param V83_part20='V83_part19+0.000000e+00*S190+(-5.040329e-02)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+2.323027e-01*S195+0.000000e+00*S196+2.447665e-01*S197+0.000000e+00*S198+1.343365e-01*S199'
.param V83_part21='V83_part20+2.095766e-01*S200+2.024440e-01*S201+2.993435e-01*S202+2.595702e-01*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+4.842798e-01*S207+7.398417e-01*S208+0.000000e+00*S209'
.param V83_part22='V83_part21+1.732970e-01*S210+1.625746e-01*S211+1.572283e-01*S212+0.000000e+00*S213+1.236724e-01*S214+1.474333e-01*S215+1.649201e-01*S216+3.849506e-03*S217+2.566263e-01*S218+6.985833e-04*S219'
.param V83_part23='V83_part22+2.969645e-01*S220+(-1.315153e-01)*S221+0.000000e+00*S222+(-1.440674e-01)*S223+0.000000e+00*S224+1.360884e-01*S225+1.009951e-01*S226+(-1.584681e-01)*S227+1.366183e-01*S228+1.653993e-01*S229'
.param V83_part24='V83_part23+(-4.695477e-02)*S230+0.000000e+00*S231+1.320204e-02*S232+7.121745e-02*S233+1.300771e-02*S234+0.000000e+00*S235+(-2.168527e-02)*S236+2.445376e-01*S237+0.000000e+00*S238+1.386112e-01*S239'
.param V83_part25='V83_part24+1.493239e-01*S240+8.983405e-02*S241+9.777447e-02*S242+1.559169e-01*S243+1.438711e-01*S244+0.000000e+00*S245+1.432470e-01*S246+1.738475e-01*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V83_part26='V83_part25+1.821125e-01*S250+(-7.748018e-02)*S251+8.321153e-02*S252+3.083420e-02*S253+4.634053e-02*S254+1.235897e-01*S255+2.019216e-01*S256+8.143718e-02*S257+3.582339e-01*S258+2.981781e-01*S259'
.param V83_part27='V83_part26+1.976911e-01*S260+0.000000e+00*S261+4.103676e-01*S262+3.021893e-01*S263+5.505688e-01*S264+3.335414e-01*S265+1.314147e-01*S266+4.071578e-01*S267+2.286584e-01*S268+1.328072e-01*S269'
.param V83_part28='V83_part27+1.242013e-01*S270+8.415679e-02*S271+2.222709e-02*S272+1.691795e-01*S273+1.112170e-01*S274+1.644066e-02*S275+9.025847e-02*S276+(-2.156936e-02)*S277+6.246304e-01*S278+(-6.893947e-03)*S279'
.param V83_part29='V83_part28+(-4.020796e-02)*S280+(-5.277940e-02)*S281+8.785519e-02*S282+2.097354e-01*S283+0.000000e+00*S284+1.378648e-01*S285+0.000000e+00*S286+1.694921e-01*S287+1.453602e-01*S288+1.716192e-01*S289'
.param V83_part30='V83_part29+0.000000e+00*S290+0.000000e+00*S291+7.001555e-02*S292+2.957509e-01*S293+(-1.232847e-02)*S294+(-1.723607e-02)*S295+3.198280e-02*S296+4.539667e-02*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V83_part31='V83_part30+3.065664e-01*S300+1.825589e-01*S301+1.554544e-01*S302+4.119395e-01*S303+2.439193e-01*S304+1.093132e-01*S305+4.360389e-01*S306+2.147728e-01*S307+(-1.196687e-02)*S308+0.000000e+00*S309'
.param V83='V83_part31+1.108572e-01*S310+2.514856e-02*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V84_part2='V84_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V84_part3='V84_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V84_part4='V84_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+9.345908e-03*S38+0.000000e+00*S39'
.param V84_part5='V84_part4+0.000000e+00*S40+(-1.586704e-02)*S41+0.000000e+00*S42+(-3.020600e-02)*S43+(-8.598307e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+2.037983e-03*S49'
.param V84_part6='V84_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+(-8.101670e-03)*S53+0.000000e+00*S54+0.000000e+00*S55+(-1.514661e-01)*S56+(-8.974418e-02)*S57+(-2.211513e-02)*S58+(-4.375982e-02)*S59'
.param V84_part7='V84_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-1.285056e-02)*S66+0.000000e+00*S67+(-1.106263e-01)*S68+0.000000e+00*S69'
.param V84_part8='V84_part7+0.000000e+00*S70+(-1.762980e-01)*S71+(-2.981365e-01)*S72+0.000000e+00*S73+(-3.436344e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V84_part9='V84_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+(-1.503419e-05)*S89'
.param V84_part10='V84_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+(-6.359885e-02)*S93+0.000000e+00*S94+0.000000e+00*S95+(-1.063236e-01)*S96+(-1.607817e-01)*S97+1.828431e-02*S98+(-1.680522e-01)*S99'
.param V84_part11='V84_part10+(-1.618015e-01)*S100+(-2.263763e-01)*S101+(-2.055467e-01)*S102+(-2.043811e-01)*S103+(-2.492319e-01)*S104+0.000000e+00*S105+2.134128e-02*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V84_part12='V84_part11+4.164169e-02*S110+(-8.151388e-02)*S111+(-1.072095e-01)*S112+2.501918e-02*S113+0.000000e+00*S114+(-1.669299e-02)*S115+0.000000e+00*S116+(-1.649375e-01)*S117+(-2.713366e-02)*S118+(-2.063053e-01)*S119'
.param V84_part13='V84_part12+0.000000e+00*S120+(-5.488926e-02)*S121+3.701060e-03*S122+(-5.119755e-02)*S123+(-6.854603e-02)*S124+(-1.435661e-01)*S125+0.000000e+00*S126+6.699575e-02*S127+(-1.614374e-01)*S128+(-1.190531e-01)*S129'
.param V84_part14='V84_part13+(-4.049281e-02)*S130+(-1.568735e-01)*S131+(-3.629458e-01)*S132+(-3.374117e-01)*S133+(-1.443635e-01)*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+(-1.249386e-01)*S139'
.param V84_part15='V84_part14+(-1.350556e-01)*S140+(-9.863781e-03)*S141+0.000000e+00*S142+1.125912e-02*S143+(-4.552879e-03)*S144+(-5.514518e-03)*S145+(-8.514145e-03)*S146+0.000000e+00*S147+0.000000e+00*S148+(-2.661275e-01)*S149'
.param V84_part16='V84_part15+(-3.992329e-02)*S150+3.727039e-02*S151+0.000000e+00*S152+(-7.973018e-02)*S153+0.000000e+00*S154+5.753107e-02*S155+5.049998e-02*S156+(-8.840229e-02)*S157+0.000000e+00*S158+7.739429e-03*S159'
.param V84_part17='V84_part16+(-7.430386e-02)*S160+(-2.334327e-01)*S161+5.660088e-02*S162+(-2.280098e-02)*S163+(-1.927983e-01)*S164+(-3.563162e-02)*S165+0.000000e+00*S166+9.520280e-02*S167+0.000000e+00*S168+(-6.585481e-02)*S169'
.param V84_part18='V84_part17+1.085504e-01*S170+(-1.183454e-03)*S171+0.000000e+00*S172+1.095017e-01*S173+(-3.159140e-02)*S174+0.000000e+00*S175+9.920002e-05*S176+0.000000e+00*S177+(-4.142403e-01)*S178+(-1.892351e-03)*S179'
.param V84_part19='V84_part18+(-3.629557e-02)*S180+(-5.742917e-02)*S181+9.013910e-02*S182+(-1.066790e-01)*S183+1.106109e-02*S184+(-5.595590e-02)*S185+0.000000e+00*S186+(-3.656963e-02)*S187+(-6.123018e-02)*S188+0.000000e+00*S189'
.param V84_part20='V84_part19+0.000000e+00*S190+(-9.145318e-02)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+(-1.206254e-01)*S195+0.000000e+00*S196+3.281318e-03*S197+0.000000e+00*S198+(-1.220599e-01)*S199'
.param V84_part21='V84_part20+2.907714e-02*S200+(-2.277021e-01)*S201+(-1.867493e-01)*S202+(-2.608182e-01)*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+(-6.180484e-01)*S207+(-5.581141e-01)*S208+0.000000e+00*S209'
.param V84_part22='V84_part21+(-5.584503e-02)*S210+8.184838e-02*S211+8.594899e-02*S212+0.000000e+00*S213+(-6.511446e-02)*S214+1.201798e-01*S215+(-2.765852e-01)*S216+3.148061e-02*S217+(-1.579860e-01)*S218+1.211654e-02*S219'
.param V84_part23='V84_part22+(-3.247287e-01)*S220+1.263966e-02*S221+0.000000e+00*S222+1.879137e-02*S223+0.000000e+00*S224+1.351525e-02*S225+(-6.172402e-02)*S226+1.966832e-01*S227+(-1.600319e-01)*S228+(-2.096091e-01)*S229'
.param V84_part24='V84_part23+1.398284e-02*S230+0.000000e+00*S231+(-7.603469e-02)*S232+(-7.335384e-02)*S233+(-5.457138e-03)*S234+0.000000e+00*S235+(-1.580319e-01)*S236+(-4.683763e-02)*S237+0.000000e+00*S238+(-4.869213e-01)*S239'
.param V84_part25='V84_part24+(-6.797392e-02)*S240+(-5.877202e-02)*S241+(-4.817373e-02)*S242+(-2.112408e-01)*S243+(-2.042372e-01)*S244+0.000000e+00*S245+2.623578e-02*S246+(-1.240338e-01)*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V84_part26='V84_part25+(-2.147083e-01)*S250+4.257831e-02*S251+(-3.119793e-01)*S252+(-2.817785e-01)*S253+(-3.118032e-01)*S254+9.288433e-03*S255+(-1.519469e-01)*S256+7.939395e-02*S257+(-1.909716e-01)*S258+(-1.170992e-01)*S259'
.param V84_part27='V84_part26+(-1.754092e-01)*S260+0.000000e+00*S261+(-2.265468e-01)*S262+(-3.611795e-01)*S263+(-8.858748e-03)*S264+(-4.190327e-01)*S265+3.478040e-02*S266+(-5.778618e-01)*S267+(-2.825039e-01)*S268+(-3.317685e-01)*S269'
.param V84_part28='V84_part27+(-1.143556e-01)*S270+(-1.286541e-01)*S271+8.021032e-02*S272+(-1.014786e-01)*S273+(-1.184445e-01)*S274+(-1.417971e-01)*S275+(-2.541528e-01)*S276+6.121996e-02*S277+(-2.101754e-01)*S278+(-1.774632e-02)*S279'
.param V84_part29='V84_part28+(-1.944641e-01)*S280+(-3.826691e-01)*S281+(-4.222021e-01)*S282+(-4.272507e-01)*S283+0.000000e+00*S284+(-1.624075e-01)*S285+0.000000e+00*S286+1.304586e-01*S287+(-1.556298e-01)*S288+(-2.096355e-01)*S289'
.param V84_part30='V84_part29+0.000000e+00*S290+0.000000e+00*S291+(-1.001858e-01)*S292+(-9.211964e-02)*S293+(-1.923675e-01)*S294+(-1.455462e-01)*S295+2.533277e-01*S296+(-3.609477e-01)*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V84_part31='V84_part30+(-1.237922e-01)*S300+(-1.150604e-01)*S301+(-1.229321e-01)*S302+(-2.525441e-01)*S303+(-1.332118e-01)*S304+4.147096e-02*S305+(-3.292812e-01)*S306+3.258443e-03*S307+6.867889e-02*S308+0.000000e+00*S309'
.param V84='V84_part31+(-2.009566e-01)*S310+8.628971e-02*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V85_part1='0.000000e+00*S0+1.362757e+00*S1+6.885475e-01*S2+1.587414e+01*S3+1.303173e+01*S4+3.175444e+01*S5+9.059136e+00*S6+8.555173e+00*S7+2.086499e+01*S8+3.823105e+01*S9'
.param V85_part2='V85_part1+2.410333e+01*S10+2.037337e+01*S11+4.710909e+01*S12+2.131949e+01*S13+4.683218e+01*S14+0.000000e+00*S15+3.339248e+00*S16+6.825812e-01*S17+5.140680e+03*S18+0.000000e+00*S19'
.param V85_part3='V85_part2+1.232140e+00*S20+1.584215e+01*S21+1.206828e+01*S22+4.863572e+00*S23+1.374144e+01*S24+3.488048e+01*S25+1.103002e+01*S26+0.000000e+00*S27+4.487865e+00*S28+4.866322e+00*S29'
.param V85_part4='V85_part3+1.649750e+02*S30+7.292592e+00*S31+1.072782e+02*S32+0.000000e+00*S33+(-2.802408e+03)*S34+3.630778e+02*S35+0.000000e+00*S36+3.589901e+00*S37+1.777670e+01*S38+0.000000e+00*S39'
.param V85_part5='V85_part4+4.247983e+01*S40+6.450206e+01*S41+1.000000e+04*S42+5.158902e+02*S43+4.028491e+03*S44+0.000000e+00*S45+6.277737e+01*S46+1.999203e+01*S47+4.061375e+03*S48+5.601404e+01*S49'
.param V85_part6='V85_part5+9.989745e+03*S50+8.468174e+00*S51+7.421243e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+4.531613e+00*S57+1.024927e+01*S58+0.000000e+00*S59'
.param V85_part7='V85_part6+0.000000e+00*S60+(-7.774188e+01)*S61+0.000000e+00*S62+0.000000e+00*S63+(-2.662871e+02)*S64+1.408883e+01*S65+0.000000e+00*S66+9.728880e+03*S67+9.430697e+02*S68+9.957760e+03*S69'
.param V85_part8='V85_part7+9.848039e+03*S70+4.335835e+00*S71+4.912543e+01*S72+4.139287e+00*S73+(-5.767092e-02)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+5.561965e+01*S78+1.423769e+01*S79'
.param V85_part9='V85_part8+0.000000e+00*S80+7.863569e+03*S81+1.136230e+01*S82+(-3.045930e+01)*S83+9.849841e+00*S84+(-1.029416e+02)*S85+2.232953e+02*S86+9.080254e+01*S87+2.275746e+02*S88+3.560213e+01*S89'
.param V85_part10='V85_part9+3.791663e+01*S90+0.000000e+00*S91+1.967184e+02*S92+1.850408e+01*S93+4.443972e+03*S94+4.330902e+01*S95+1.811899e+01*S96+3.375788e+01*S97+2.218295e+03*S98+0.000000e+00*S99'
.param V85_part11='V85_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+3.410988e-01*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V85_part12='V85_part11+0.000000e+00*S110+4.653750e+00*S111+0.000000e+00*S112+9.953224e+03*S113+5.379684e+02*S114+1.423962e+01*S115+1.637027e+03*S116+2.289668e+01*S117+2.703913e+00*S118+2.056573e-01*S119'
.param V85_part13='V85_part12+6.260125e+02*S120+9.622624e+03*S121+3.387226e+00*S122+0.000000e+00*S123+8.024439e+02*S124+4.320779e+00*S125+0.000000e+00*S126+0.000000e+00*S127+3.902103e-03*S128+0.000000e+00*S129'
.param V85_part14='V85_part13+3.034607e+01*S130+(-3.426091e-02)*S131+0.000000e+00*S132+0.000000e+00*S133+1.039303e-01*S134+0.000000e+00*S135+0.000000e+00*S136+6.822374e+00*S137+8.852245e+00*S138+6.461685e+00*S139'
.param V85_part15='V85_part14+1.237376e+00*S140+9.710310e+00*S141+0.000000e+00*S142+1.000000e+04*S143+6.231849e+00*S144+6.100820e+00*S145+4.334452e+00*S146+0.000000e+00*S147+2.138801e+00*S148+(-1.313834e-01)*S149'
.param V85_part16='V85_part15+0.000000e+00*S150+0.000000e+00*S151+5.031504e+03*S152+0.000000e+00*S153+5.594878e+03*S154+7.290284e+01*S155+3.055333e+01*S156+8.409940e-02*S157+(-2.290464e-01)*S158+1.028175e+00*S159'
.param V85_part17='V85_part16+1.368815e+01*S160+4.947305e+00*S161+4.057483e+00*S162+1.000000e+04*S163+4.686637e+01*S164+3.985202e+02*S165+0.000000e+00*S166+7.899527e-01*S167+0.000000e+00*S168+(-2.930194e-01)*S169'
.param V85_part18='V85_part17+1.038490e-03*S170+(-3.573665e+01)*S171+6.028848e+01*S172+3.807801e+00*S173+7.255453e+00*S174+6.578084e+00*S175+2.200477e+02*S176+8.882946e+00*S177+4.046593e+00*S178+6.985633e-01*S179'
.param V85_part19='V85_part18+0.000000e+00*S180+8.029327e+03*S181+6.014414e+02*S182+8.393304e+03*S183+1.373567e+03*S184+2.399692e+00*S185+1.656789e+01*S186+4.932064e+03*S187+5.232823e+03*S188+2.377067e+01*S189'
.param V85_part20='V85_part19+7.698598e+01*S190+3.323832e+00*S191+8.681724e-01*S192+(-4.340478e-02)*S193+1.139658e+03*S194+4.237177e+01*S195+1.248960e+01*S196+(-1.573114e-01)*S197+7.343798e+03*S198+6.278774e+00*S199'
.param V85_part21='V85_part20+(-3.142503e-02)*S200+7.464890e+01*S201+(-5.454997e-02)*S202+1.062599e-01*S203+1.874145e+00*S204+7.020492e-02*S205+0.000000e+00*S206+0.000000e+00*S207+(-3.353484e-01)*S208+5.396236e-02*S209'
.param V85_part22='V85_part21+0.000000e+00*S210+0.000000e+00*S211+5.345127e+01*S212+3.706161e+01*S213+3.537278e+01*S214+(-8.457038e+01)*S215+9.235005e-01*S216+4.188084e+00*S217+(-4.691556e+01)*S218+8.420145e+00*S219'
.param V85_part23='V85_part22+(-2.074387e+01)*S220+(-3.070018e-01)*S221+5.779125e-01*S222+(-7.673114e-01)*S223+(-1.107549e+00)*S224+9.277537e+00*S225+5.694691e+00*S226+(-1.423874e-01)*S227+0.000000e+00*S228+9.424147e+01*S229'
.param V85_part24='V85_part23+3.380769e+00*S230+1.079976e+00*S231+6.425218e+00*S232+(-1.029645e+03)*S233+1.218340e+01*S234+1.267157e-01*S235+1.498620e+01*S236+3.756661e+00*S237+9.407549e-01*S238+1.469141e+01*S239'
.param V85_part25='V85_part24+2.970480e+01*S240+4.134895e+01*S241+3.291847e+02*S242+1.608535e+01*S243+1.587738e+01*S244+2.184984e+01*S245+5.661201e+01*S246+5.257190e+00*S247+9.063733e+00*S248+4.652978e+00*S249'
.param V85_part26='V85_part25+3.075620e+00*S250+2.853639e+00*S251+(-4.595155e+00)*S252+4.425307e+00*S253+3.706632e+00*S254+2.979201e+01*S255+3.406965e+01*S256+1.251680e+01*S257+8.522288e+03*S258+(-1.435347e+00)*S259'
.param V85_part27='V85_part26+1.321716e+01*S260+5.701650e+00*S261+8.522620e+00*S262+1.462983e+00*S263+2.290877e-01*S264+4.845702e-01*S265+2.732674e+01*S266+(-2.053305e+03)*S267+6.669387e+03*S268+5.298349e+01*S269'
.param V85_part28='V85_part27+0.000000e+00*S270+6.661390e+03*S271+1.792921e+00*S272+5.379977e+00*S273+1.884328e+03*S274+2.647432e+00*S275+9.487976e+00*S276+2.043767e+01*S277+1.915014e+00*S278+3.928224e+00*S279'
.param V85_part29='V85_part28+1.045501e+01*S280+2.785240e+00*S281+0.000000e+00*S282+2.731619e+00*S283+1.899463e+00*S284+2.232719e+01*S285+(-2.129394e-01)*S286+8.692997e+01*S287+3.027654e+00*S288+3.635309e+01*S289'
.param V85_part30='V85_part29+9.418413e+01*S290+5.020665e+00*S291+4.373148e+00*S292+1.239370e+00*S293+1.024222e+01*S294+2.495691e+00*S295+4.369519e+00*S296+2.899351e+00*S297+1.000000e+04*S298+5.583351e+00*S299'
.param V85_part31='V85_part30+2.950956e+00*S300+5.096719e+01*S301+3.698337e+00*S302+2.134473e+00*S303+5.669925e+00*S304+1.325051e+00*S305+2.986630e+00*S306+5.951097e+00*S307+3.364701e+00*S308+1.842793e+00*S309'
.param V85='V85_part31+4.792327e+00*S310+3.265630e+00*S311+2.618686e+00*S312+7.660681e-01*S313+2.284691e+00*S314'
.param V86_part1='0.000000e+00*S0+1.102353e+00*S1+4.238660e+00*S2+2.541657e+00*S3+5.577704e+01*S4+1.730161e+00*S5+(-1.859443e-01)*S6+6.350369e-01*S7+4.924468e+00*S8+(-3.139723e+00)*S9'
.param V86_part2='V86_part1+(-6.305451e+00)*S10+(-1.929692e+00)*S11+(-5.483638e+00)*S12+(-5.123187e+00)*S13+5.467144e-02*S14+0.000000e+00*S15+2.115632e+00*S16+(-3.881225e-01)*S17+1.000000e+04*S18+0.000000e+00*S19'
.param V86_part3='V86_part2+2.237276e+00*S20+(-1.106120e+01)*S21+2.768313e+00*S22+2.232302e-01*S23+(-5.326477e+00)*S24+(-2.403064e+01)*S25+(-3.319213e-01)*S26+0.000000e+00*S27+1.459990e+00*S28+8.955708e-01*S29'
.param V86_part4='V86_part3+2.329694e+01*S30+4.657481e-01*S31+3.586249e+02*S32+0.000000e+00*S33+7.860292e+01*S34+7.081527e+01*S35+0.000000e+00*S36+1.457146e+01*S37+5.595563e-01*S38+0.000000e+00*S39'
.param V86_part5='V86_part4+6.440220e+00*S40+(-4.727513e+01)*S41+1.674157e+03*S42+2.075991e+02*S43+6.392716e+02*S44+0.000000e+00*S45+4.070124e+00*S46+(-6.288022e-01)*S47+4.717367e+00*S48+(-5.121691e+01)*S49'
.param V86_part6='V86_part5+1.677052e+01*S50+2.192841e+00*S51+4.119885e-01*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.149438e+00)*S57+(-7.148608e-01)*S58+0.000000e+00*S59'
.param V86_part7='V86_part6+0.000000e+00*S60+5.821710e+02*S61+0.000000e+00*S62+0.000000e+00*S63+1.355285e+03*S64+(-7.460419e+00)*S65+0.000000e+00*S66+2.840366e+00*S67+(-1.066689e+03)*S68+5.131357e+01*S69'
.param V86_part8='V86_part7+2.080017e+01*S70+(-5.252956e-01)*S71+1.763152e-01*S72+(-1.821476e-01)*S73+(-3.221575e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+1.898793e+02*S78+(-8.456900e+00)*S79'
.param V86_part9='V86_part8+0.000000e+00*S80+7.863569e+03*S81+9.464538e+00*S82+9.421492e+01*S83+(-3.201096e+00)*S84+1.942954e+02*S85+(-2.059852e+02)*S86+(-7.419447e+01)*S87+(-1.916833e+02)*S88+5.455529e+00*S89'
.param V86_part10='V86_part9+(-6.462200e+01)*S90+0.000000e+00*S91+(-8.119697e+00)*S92+(-5.517102e+00)*S93+5.364247e+01*S94+(-1.679932e+01)*S95+(-7.130366e+00)*S96+2.942920e+00*S97+7.695403e+01*S98+0.000000e+00*S99'
.param V86_part11='V86_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+1.102573e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V86_part12='V86_part11+0.000000e+00*S110+(-2.887149e+00)*S111+0.000000e+00*S112+(-8.723200e+00)*S113+(-9.644714e+01)*S114+2.312550e+00*S115+1.715746e+01*S116+5.929191e+00*S117+(-4.682245e-01)*S118+4.284377e-01*S119'
.param V86_part13='V86_part12+5.755517e+01*S120+3.914401e+01*S121+(-6.725850e-01)*S122+0.000000e+00*S123+2.789607e+01*S124+7.068993e-01*S125+0.000000e+00*S126+0.000000e+00*S127+3.805500e-01*S128+0.000000e+00*S129'
.param V86_part14='V86_part13+1.686226e+00*S130+5.758046e-01*S131+0.000000e+00*S132+0.000000e+00*S133+6.023837e-01*S134+0.000000e+00*S135+0.000000e+00*S136+(-5.868582e-01)*S137+(-3.322230e+00)*S138+(-2.771690e+00)*S139'
.param V86_part15='V86_part14+8.083015e-01*S140+(-3.124087e+00)*S141+0.000000e+00*S142+(-1.003534e+01)*S143+(-1.363785e+00)*S144+(-1.365377e+00)*S145+(-1.284612e+00)*S146+0.000000e+00*S147+1.866576e+00*S148+3.755789e-01*S149'
.param V86_part16='V86_part15+0.000000e+00*S150+0.000000e+00*S151+2.565936e+02*S152+0.000000e+00*S153+2.234830e+00*S154+(-1.270816e+01)*S155+(-2.746459e+01)*S156+5.963841e-01*S157+7.271474e+00*S158+(-1.259946e+00)*S159'
.param V86_part17='V86_part16+4.478916e+00*S160+5.794515e+01*S161+(-3.361861e-01)*S162+1.000000e+04*S163+2.548871e+00*S164+(-4.197406e+00)*S165+0.000000e+00*S166+(-4.675926e-02)*S167+0.000000e+00*S168+1.036888e+00*S169'
.param V86_part18='V86_part17+9.948588e-01*S170+4.364177e+01*S171+1.481416e+01*S172+(-5.570674e-01)*S173+3.107587e+00*S174+7.779602e+00*S175+1.842036e+02*S176+(-4.951208e+00)*S177+(-5.040085e+00)*S178+7.171088e-01*S179'
.param V86_part19='V86_part18+0.000000e+00*S180+2.166865e+00*S181+1.832289e+00*S182+1.077268e+00*S183+2.275916e+01*S184+(-1.679559e-02)*S185+3.473651e+00*S186+(-4.730917e+00)*S187+9.828978e+00*S188+(-9.483377e-01)*S189'
.param V86_part20='V86_part19+(-1.379775e+01)*S190+(-7.930501e-01)*S191+(-5.884301e-01)*S192+1.076288e+01*S193+4.220866e+02*S194+(-3.309891e+01)*S195+7.000410e+00*S196+4.360534e-01*S197+2.150729e+01*S198+(-3.818370e-01)*S199'
.param V86_part21='V86_part20+3.711602e-01*S200+1.327666e+00*S201+7.321026e-01*S202+5.255508e-01*S203+(-1.332387e+00)*S204+2.348789e-02*S205+0.000000e+00*S206+0.000000e+00*S207+(-2.652649e-01)*S208+7.263213e-02*S209'
.param V86_part22='V86_part21+0.000000e+00*S210+0.000000e+00*S211+1.041619e+02*S212+5.049309e+00*S213+(-4.997745e+00)*S214+(-2.627187e+00)*S215+(-6.507913e-01)*S216+(-3.670995e+00)*S217+1.774135e+01*S218+(-4.854042e+00)*S219'
.param V86_part23='V86_part22+(-1.541238e+01)*S220+6.917050e-01*S221+(-8.781700e-02)*S222+1.060482e+00*S223+9.104733e-01*S224+8.335789e+00*S225+1.023758e+01*S226+7.897065e-01*S227+0.000000e+00*S228+(-1.193441e+01)*S229'
.param V86_part24='V86_part23+(-3.142418e-01)*S230+(-3.534487e-01)*S231+8.347579e-01*S232+3.414005e+03*S233+1.154726e+00*S234+3.512274e-01*S235+3.158605e+00*S236+2.037523e-01*S237+(-1.081074e-01)*S238+3.154485e+00*S239'
.param V86_part25='V86_part24+5.031572e+00*S240+(-6.833127e+00)*S241+9.419910e+00*S242+(-1.055356e+01)*S243+(-6.221678e-01)*S244+2.706458e+00*S245+3.543107e+00*S246+(-1.145829e+00)*S247+(-7.201375e+00)*S248+(-1.165246e+00)*S249'
.param V86_part26='V86_part25+2.206868e-01*S250+(-4.881184e-01)*S251+2.091286e+00*S252+1.646293e-01*S253+(-1.639167e+00)*S254+(-2.472305e+00)*S255+1.363485e+01*S256+(-3.883940e+00)*S257+2.075933e+03*S258+1.421969e+01*S259'
.param V86_part27='V86_part26+1.594158e+01*S260+9.059491e-01*S261+6.444840e-01*S262+(-1.723160e-01)*S263+2.376150e+00*S264+6.487560e-01*S265+3.034173e+00*S266+(-8.382692e+00)*S267+3.342725e-01*S268+2.761330e-01*S269'
.param V86_part28='V86_part27+0.000000e+00*S270+6.420623e+01*S271+(-6.759586e-01)*S272+1.199575e+00*S273+5.510401e+00*S274+(-7.447810e-01)*S275+(-1.249950e+01)*S276+1.333459e+00*S277+(-3.595474e-01)*S278+(-3.265568e+00)*S279'
.param V86_part29='V86_part28+9.547936e-01*S280+(-2.057864e-01)*S281+0.000000e+00*S282+1.475491e-02*S283+(-2.799551e+00)*S284+7.931238e+00*S285+7.122865e-01*S286+5.202295e+01*S287+(-1.967534e+00)*S288+(-5.405474e+01)*S289'
.param V86_part30='V86_part29+5.393155e+00*S290+(-6.860349e+00)*S291+6.323387e-02*S292+2.831700e-01*S293+1.746872e+00*S294+(-8.265638e-01)*S295+(-1.164075e+00)*S296+1.063623e+00*S297+1.000000e+04*S298+(-1.672473e+00)*S299'
.param V86_part31='V86_part30+(-9.010504e-02)*S300+6.715675e+00*S301+8.557306e+00*S302+(-2.767579e-01)*S303+3.056256e-02*S304+4.491791e-01*S305+(-1.625619e-01)*S306+(-7.683762e-01)*S307+(-1.016088e+00)*S308+(-1.011251e+00)*S309'
.param V86='V86_part31+(-8.216516e-01)*S310+(-1.046249e+00)*S311+(-2.253303e-01)*S312+(-1.643654e-01)*S313+(-5.438811e-01)*S314'
.param V87_part1='0.000000e+00*S0+(-1.868033e+00)*S1+3.644214e+00*S2+1.347404e+01*S3+(-2.480581e-01)*S4+(-2.801155e-01)*S5+(-6.942768e+00)*S6+(-3.233181e+00)*S7+(-1.118956e+01)*S8+(-1.765972e+01)*S9'
.param V87_part2='V87_part1+1.799259e+00*S10+(-7.828765e+00)*S11+(-2.295539e+01)*S12+2.586018e+00*S13+2.527027e+01*S14+0.000000e+00*S15+(-2.489681e-01)*S16+(-4.780821e-01)*S17+1.095680e+03*S18+0.000000e+00*S19'
.param V87_part3='V87_part2+8.134234e-01*S20+4.534089e+00*S21+(-1.260939e+01)*S22+1.769003e-01*S23+(-1.825409e+00)*S24+(-6.705997e-01)*S25+(-2.272983e+00)*S26+0.000000e+00*S27+(-1.807193e+00)*S28+(-9.236410e-01)*S29'
.param V87_part4='V87_part3+3.471565e+03*S30+7.981735e-01*S31+5.938479e+02*S32+0.000000e+00*S33+1.000000e+04*S34+3.355220e+02*S35+0.000000e+00*S36+5.715484e+00*S37+(-1.037853e+01)*S38+0.000000e+00*S39'
.param V87_part5='V87_part4+2.717802e+00*S40+2.191723e+01*S41+7.199371e+02*S42+(-3.089786e+01)*S43+(-2.645519e+03)*S44+0.000000e+00*S45+3.147176e+01*S46+5.334026e-01*S47+4.579651e+00*S48+4.849821e+00*S49'
.param V87_part6='V87_part5+2.105845e+01*S50+3.246640e+00*S51+(-1.477446e+00)*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+2.910874e-01*S57+3.012945e-01*S58+0.000000e+00*S59'
.param V87_part7='V87_part6+0.000000e+00*S60+6.149284e+01*S61+0.000000e+00*S62+0.000000e+00*S63+(-5.195515e+01)*S64+(-6.438732e+00)*S65+0.000000e+00*S66+7.552010e+02*S67+(-2.319979e+02)*S68+1.529419e+02*S69'
.param V87_part8='V87_part7+4.143405e+02*S70+(-5.352333e-01)*S71+(-8.658868e+01)*S72+(-2.149429e+00)*S73+7.329212e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+1.834643e-01*S78+(-3.226672e+00)*S79'
.param V87_part9='V87_part8+0.000000e+00*S80+(-1.467367e+02)*S81+(-8.985845e+00)*S82+1.223565e+01*S83+(-4.174355e+00)*S84+2.907845e+00*S85+(-8.324043e+00)*S86+7.403942e+00*S87+3.550380e+00*S88+(-3.541474e+00)*S89'
.param V87_part10='V87_part9+1.846688e-01*S90+0.000000e+00*S91+(-7.849558e+01)*S92+(-1.682425e+01)*S93+1.444921e+03*S94+(-2.287779e+01)*S95+(-1.293105e+01)*S96+(-1.654896e+01)*S97+(-4.398590e+02)*S98+0.000000e+00*S99'
.param V87_part11='V87_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+7.431719e-01*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V87_part12='V87_part11+0.000000e+00*S110+(-3.596384e+00)*S111+0.000000e+00*S112+1.031773e+02*S113+(-8.127842e+02)*S114+5.444090e-01*S115+(-5.412185e+02)*S116+(-2.746040e+01)*S117+(-1.174893e+00)*S118+(-8.833954e-02)*S119'
.param V87_part13='V87_part12+1.550616e+01*S120+1.564967e+01*S121+1.559617e+00*S122+0.000000e+00*S123+(-3.432588e+00)*S124+(-6.326307e-01)*S125+0.000000e+00*S126+0.000000e+00*S127+1.572903e-01*S128+0.000000e+00*S129'
.param V87_part14='V87_part13+(-3.220111e+01)*S130+1.623496e-01*S131+0.000000e+00*S132+0.000000e+00*S133+6.148234e-02*S134+0.000000e+00*S135+0.000000e+00*S136+(-3.731877e+00)*S137+(-7.188353e+00)*S138+(-3.586369e+00)*S139'
.param V87_part15='V87_part14+8.876309e-01*S140+(-7.400456e+00)*S141+0.000000e+00*S142+1.629210e+01*S143+(-4.102390e+00)*S144+(-3.276596e+00)*S145+(-1.415974e+00)*S146+0.000000e+00*S147+(-4.748104e+00)*S148+1.410538e-01*S149'
.param V87_part16='V87_part15+0.000000e+00*S150+0.000000e+00*S151+(-5.079162e+01)*S152+0.000000e+00*S153+(-4.899462e+00)*S154+(-5.366158e+01)*S155+1.271047e+01*S156+4.080118e-02*S157+(-8.767715e-01)*S158+1.033505e+00*S159'
.param V87_part17='V87_part16+(-1.351506e+01)*S160+(-2.195979e+01)*S161+(-4.405454e+00)*S162+1.000000e+04*S163+(-3.235926e+01)*S164+7.438271e+00*S165+0.000000e+00*S166+(-4.026186e-01)*S167+0.000000e+00*S168+3.667357e-01*S169'
.param V87_part18='V87_part17+9.509852e-02*S170+2.017543e+02*S171+(-6.023109e+01)*S172+(-2.306661e+00)*S173+(-5.333335e-01)*S174+2.323549e-01*S175+(-5.856415e+01)*S176+1.262646e+01*S177+1.170057e+01*S178+(-4.337959e-01)*S179'
.param V87_part19='V87_part18+0.000000e+00*S180+(-1.126952e+01)*S181+2.749900e+00*S182+(-6.923844e+00)*S183+(-1.065051e+00)*S184+(-1.450125e+00)*S185+(-2.377666e+01)*S186+6.266522e+00*S187+3.913367e+01*S188+(-4.195120e+01)*S189'
.param V87_part20='V87_part19+(-6.807522e+01)*S190+(-1.627017e+00)*S191+2.685088e-01*S192+4.965298e+00*S193+1.000000e+04*S194+(-3.745864e+01)*S195+(-9.826333e+00)*S196+2.940474e-01*S197+8.465769e+01*S198+(-4.727914e+00)*S199'
.param V87_part21='V87_part20+2.185716e-01*S200+(-5.934517e+00)*S201+1.033089e-02*S202+1.232965e-02*S203+5.736228e-01*S204+1.264525e-01*S205+0.000000e+00*S206+0.000000e+00*S207+8.900904e+00*S208+8.928004e-01*S209'
.param V87_part22='V87_part21+0.000000e+00*S210+0.000000e+00*S211+(-4.052630e+01)*S212+(-7.307144e+01)*S213+(-3.303566e+01)*S214+1.967115e+02*S215+(-3.770919e-01)*S216+1.520472e-01*S217+8.681176e+01*S218+(-4.223815e+00)*S219'
.param V87_part23='V87_part22+1.006296e+02*S220+3.208601e+00*S221+(-4.413088e-01)*S222+3.316795e+00*S223+3.067731e+00*S224+6.009356e+00*S225+(-5.421424e+00)*S226+3.959549e-01*S227+0.000000e+00*S228+(-5.315540e+01)*S229'
.param V87_part24='V87_part23+(-1.980474e+00)*S230+(-7.560619e-01)*S231+(-7.983028e+00)*S232+(-3.565785e+02)*S233+(-2.296084e+01)*S234+3.052850e-02*S235+(-1.423254e+01)*S236+(-2.383415e+00)*S237+(-3.483813e-01)*S238+(-1.394392e+01)*S239'
.param V87_part25='V87_part24+8.532200e-02*S240+(-4.131884e+01)*S241+1.045930e+01*S242+(-1.393262e+01)*S243+(-1.736881e+01)*S244+(-1.846050e+01)*S245+(-1.094175e+02)*S246+(-4.217583e+00)*S247+(-8.617804e-01)*S248+(-1.305464e+00)*S249'
.param V87_part26='V87_part25+(-2.280424e+00)*S250+(-1.326202e+00)*S251+1.440442e+01*S252+(-4.109140e+00)*S253+(-6.714655e-01)*S254+(-4.038962e+01)*S255+(-3.747688e+01)*S256+(-8.161719e+00)*S257+1.362245e+02*S258+(-4.877551e-02)*S259'
.param V87_part27='V87_part26+(-1.384125e+01)*S260+(-1.239111e+01)*S261+(-9.907510e+00)*S262+(-4.907702e-01)*S263+(-1.155062e+00)*S264+(-1.873329e-01)*S265+(-2.303788e+01)*S266+1.000000e+04*S267+(-1.000000e+04)*S268+(-4.782288e+01)*S269'
.param V87_part28='V87_part27+0.000000e+00*S270+(-1.000000e+04)*S271+(-9.060934e-01)*S272+(-1.297236e+01)*S273+(-2.824489e+03)*S274+(-7.511876e-01)*S275+8.171861e+00*S276+(-3.000834e+01)*S277+(-1.572371e-01)*S278+1.225142e+00*S279'
.param V87_part29='V87_part28+(-1.554147e+01)*S280+(-1.237826e+00)*S281+0.000000e+00*S282+(-2.765614e+00)*S283+4.997848e+00*S284+(-4.433868e+01)*S285+4.991088e-01*S286+(-7.589214e+01)*S287+7.307700e-01*S288+8.726234e+00*S289'
.param V87_part30='V87_part29+(-8.710526e+01)*S290+6.204109e+00*S291+(-3.877588e+00)*S292+(-7.832113e-01)*S293+(-1.905345e+01)*S294+(-6.111458e-01)*S295+(-1.124327e+00)*S296+(-4.076214e+00)*S297+2.708725e+03*S298+(-1.005928e+00)*S299'
.param V87_part31='V87_part30+(-4.795847e+00)*S300+(-5.886914e+01)*S301+(-5.328323e-01)*S302+(-2.016592e+00)*S303+(-7.447433e+00)*S304+(-4.215235e-01)*S305+(-4.087691e+00)*S306+(-5.222476e+00)*S307+(-1.481670e+00)*S308+5.840616e-01*S309'
.param V87='V87_part31+(-4.026095e+00)*S310+(-1.348758e+00)*S311+(-2.514881e+00)*S312+1.890204e-01*S313+(-9.351073e-01)*S314'
.param V88_part1='0.000000e+00*S0+(-1.511457e+00)*S1+3.926460e+00*S2+4.146802e+00*S3+(-4.876871e+01)*S4+2.919465e+01*S5+4.403107e+00*S6+5.558233e+00*S7+(-4.552022e+00)*S8+2.574038e+01*S9'
.param V88_part2='V88_part1+5.012845e+00*S10+(-1.909816e+00)*S11+2.930917e+01*S12+(-2.701724e+00)*S13+5.130936e+01*S14+0.000000e+00*S15+1.690661e-01*S16+(-6.662252e-02)*S17+(-5.546004e+02)*S18+0.000000e+00*S19'
.param V88_part3='V88_part2+2.333119e+00*S20+1.948036e+00*S21+(-3.794936e+00)*S22+4.107061e+00*S23+1.652844e+00*S24+6.159374e+00*S25+(-2.978101e+00)*S26+0.000000e+00*S27+3.058530e+00*S28+3.568238e+00*S29'
.param V88_part4='V88_part3+(-3.442943e+01)*S30+1.362975e-01*S31+4.778498e+01*S32+0.000000e+00*S33+(-2.820326e+01)*S34+3.860801e+00*S35+0.000000e+00*S36+1.195453e+01*S37+4.061091e+00*S38+0.000000e+00*S39'
.param V88_part5='V88_part4+4.545865e+01*S40+1.277736e+01*S41+(-1.650396e+02)*S42+1.607988e+01*S43+(-3.167649e+01)*S44+0.000000e+00*S45+1.196951e+01*S46+1.523426e+01*S47+4.056845e+03*S48+(-5.883720e+02)*S49'
.param V88_part6='V88_part5+1.000000e+04*S50+8.243153e+00*S51+(-2.614534e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+2.536808e+00*S57+6.732362e+00*S58+0.000000e+00*S59'
.param V88_part7='V88_part6+0.000000e+00*S60+(-1.785312e+03)*S61+0.000000e+00*S62+0.000000e+00*S63+1.245260e+02*S64+(-1.306338e+00)*S65+0.000000e+00*S66+1.000000e+04*S67+(-8.468433e+02)*S68+1.000000e+04*S69'
.param V88_part8='V88_part7+1.000000e+04*S70+2.117241e+00*S71+(-1.920923e+00)*S72+1.505502e+00*S73+(-9.744490e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+(-3.365598e+01)*S78+(-3.998891e+01)*S79'
.param V88_part9='V88_part8+0.000000e+00*S80+3.966833e+03*S81+(-7.043085e+00)*S82+(-1.000000e+04)*S83+2.982342e+00*S84+(-1.000000e+04)*S85+2.357014e+01*S86+2.811121e+00*S87+1.388460e+01*S88+(-4.521164e+03)*S89'
.param V88_part10='V88_part9+2.535212e-01*S90+0.000000e+00*S91+6.156752e+00*S92+1.556345e+00*S93+2.107698e-01*S94+3.237152e+00*S95+7.718186e-01*S96+(-1.111272e+02)*S97+(-5.044951e+01)*S98+0.000000e+00*S99'
.param V88_part11='V88_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+1.063444e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V88_part12='V88_part11+0.000000e+00*S110+(-2.663503e-02)*S111+0.000000e+00*S112+1.000000e+04*S113+(-1.000000e+04)*S114+1.209664e+01*S115+1.015200e+03*S116+1.390856e+01*S117+3.380720e-01*S118+2.421356e-01*S119'
.param V88_part13='V88_part12+6.316619e+02*S120+9.625250e+03*S121+3.495418e-02*S122+0.000000e+00*S123+7.937436e+02*S124+2.666047e+00*S125+0.000000e+00*S126+0.000000e+00*S127+2.581762e-01*S128+0.000000e+00*S129'
.param V88_part14='V88_part13+(-3.529105e+03)*S130+3.703142e-01*S131+0.000000e+00*S132+0.000000e+00*S133+4.631937e-01*S134+0.000000e+00*S135+0.000000e+00*S136+3.173164e-01*S137+1.692027e+00*S138+4.311274e-01*S139'
.param V88_part15='V88_part14+(-2.558547e-01)*S140+1.776232e-02*S141+0.000000e+00*S142+9.996810e+03*S143+(-1.947487e-01)*S144+(-1.721293e-01)*S145+1.458304e-01*S146+0.000000e+00*S147+(-1.533067e+00)*S148+1.919517e-01*S149'
.param V88_part16='V88_part15+0.000000e+00*S150+0.000000e+00*S151+4.106377e-01*S152+0.000000e+00*S153+5.576357e+03*S154+(-7.668664e+03)*S155+(-2.012843e+03)*S156+3.857912e-01*S157+1.210838e+00*S158+(-2.211017e+03)*S159'
.param V88_part17='V88_part16+(-1.000000e+04)*S160+(-1.000000e+04)*S161+(-1.848652e-01)*S162+(-1.000000e+04)*S163+(-4.799671e+02)*S164+3.875796e+02*S165+0.000000e+00*S166+1.819141e-01*S167+0.000000e+00*S168+1.788384e-01*S169'
.param V88_part18='V88_part17+1.846515e-01*S170+(-1.000000e+04)*S171+(-6.955909e+03)*S172+2.095806e-01*S173+(-4.850996e+01)*S174+(-1.051509e+02)*S175+(-1.000000e+04)*S176+(-1.336732e+00)*S177+(-1.198392e+01)*S178+1.109515e-01*S179'
.param V88_part19='V88_part18+0.000000e+00*S180+8.010853e+03*S181+5.973463e+02*S182+8.382729e+03*S183+1.376052e+03*S184+2.274110e-01*S185+1.937473e+00*S186+4.923452e+03*S187+5.253639e+03*S188+1.010477e+00*S189'
.param V88_part20='V88_part19+(-4.968444e+03)*S190+3.220162e-01*S191+2.076929e-01*S192+(-7.858114e+01)*S193+(-5.709751e+01)*S194+(-1.000000e+04)*S195+2.135048e-01*S196+1.477248e-01*S197+7.362592e+03*S198+3.341458e-01*S199'
.param V88_part21='V88_part20+1.923132e-01*S200+6.678965e+01*S201+2.787412e-01*S202+2.006811e-01*S203+(-3.412468e-02)*S204+8.789917e-02*S205+0.000000e+00*S206+0.000000e+00*S207+(-1.951249e+01)*S208+(-3.801729e+00)*S209'
.param V88_part22='V88_part21+0.000000e+00*S210+0.000000e+00*S211+(-1.000000e+04)*S212+(-5.399708e-01)*S213+(-1.000000e+04)*S214+(-1.000000e+04)*S215+3.010023e-01*S216+(-1.008824e-02)*S217+(-1.000000e+04)*S218+(-7.361098e-01)*S219'
.param V88_part23='V88_part22+(-1.000000e+04)*S220+3.670172e-01*S221+1.006094e-01*S222+5.714817e-03*S223+4.979596e-01*S224+(-1.000000e+04)*S225+(-1.399283e+00)*S226+6.667909e-02*S227+0.000000e+00*S228+(-1.221598e+02)*S229'
.param V88_part24='V88_part23+4.471365e-01*S230+2.009937e-01*S231+(-3.743822e-01)*S232+9.820778e+01*S233+(-2.731387e-01)*S234+1.067236e-01*S235+(-4.819400e-01)*S236+(-1.399707e+02)*S237+1.398288e-01*S238+(-2.292564e-01)*S239'
.param V88_part25='V88_part24+2.625558e+00*S240+(-1.000000e+04)*S241+(-1.736409e+02)*S242+(-1.479652e+00)*S243+(-3.481793e-01)*S244+(-1.758088e-01)*S245+(-3.431450e+03)*S246+5.184192e-01*S247+(-2.552305e+00)*S248+3.173359e-01*S249'
.param V88_part26='V88_part25+4.834582e-01*S250+4.067468e-02*S251+1.463626e-03*S252+(-3.127837e-01)*S253+(-5.938985e-02)*S254+(-1.000000e+04)*S255+(-1.000000e+04)*S256+(-2.785573e+00)*S257+(-6.906161e+02)*S258+(-3.394038e-01)*S259'
.param V88_part27='V88_part26+(-6.511980e+00)*S260+(-1.590601e+00)*S261+(-1.725768e+00)*S262+6.223532e-01*S263+(-1.000000e+04)*S264+1.458135e-01*S265+(-1.328670e+01)*S266+3.933807e-01*S267+(-1.292864e+00)*S268+(-1.067044e+01)*S269'
.param V88_part28='V88_part27+0.000000e+00*S270+(-1.346392e+00)*S271+2.537329e-01*S272+(-6.863846e-02)*S273+(-1.994978e+00)*S274+(-2.783124e-01)*S275+(-6.608161e-01)*S276+(-2.970191e-01)*S277+(-7.549289e-02)*S278+(-4.075999e-01)*S279'
.param V88_part29='V88_part28+5.928579e-02*S280+(-8.243454e-02)*S281+0.000000e+00*S282+(-2.012632e-01)*S283+(-1.193556e+00)*S284+(-7.371454e-01)*S285+5.135392e-02*S286+(-1.630130e+01)*S287+(-5.497285e-02)*S288+(-1.882916e+02)*S289'
.param V88_part30='V88_part29+(-6.456808e+00)*S290+3.211900e-01*S291+(-1.839454e-01)*S292+3.781761e-02*S293+1.022940e+00*S294+(-2.103395e-01)*S295+1.703673e-01*S296+4.665704e-01*S297+1.091351e+02*S298+1.040222e-01*S299'
.param V88_part31='V88_part30+(-2.113292e-01)*S300+(-1.695736e+02)*S301+1.322068e+00*S302+(-3.909690e+00)*S303+(-1.566571e-01)*S304+3.360942e-01*S305+(-4.278446e+00)*S306+(-5.868797e-01)*S307+7.364832e-02*S308+(-2.372600e-01)*S309'
.param V88='V88_part31+(-6.347150e-02)*S310+4.100136e-02*S311+2.516438e-01*S312+1.308939e-01*S313+(-1.098712e-01)*S314'
.param V89_part1='0.000000e+00*S0+(-2.102387e-01)*S1+4.936792e-02*S2+9.587732e-01*S3+(-8.138409e+00)*S4+2.800891e-01*S5+2.742047e-02*S6+(-2.065125e-03)*S7+4.597805e-02*S8+(-3.015757e-01)*S9'
.param V89_part2='V89_part1+(-8.500573e-01)*S10+(-3.899300e-03)*S11+(-8.337127e-01)*S12+(-6.313829e-02)*S13+9.026550e-02*S14+0.000000e+00*S15+(-1.124109e-02)*S16+(-9.333301e-04)*S17+1.200672e+02*S18+0.000000e+00*S19'
.param V89_part3='V89_part2+1.466284e-02*S20+(-1.133714e-01)*S21+(-9.747578e-02)*S22+7.744452e-03*S23+(-6.003779e-02)*S24+(-7.297336e-02)*S25+(-3.878152e-04)*S26+0.000000e+00*S27+3.543607e-03*S28+1.227842e-02*S29'
.param V89_part4='V89_part3+(-1.621298e+00)*S30+8.983220e-02*S31+4.795040e+02*S32+0.000000e+00*S33+2.349556e+03*S34+3.043148e+01*S35+0.000000e+00*S36+(-4.288228e-01)*S37+2.579888e-01*S38+0.000000e+00*S39'
.param V89_part5='V89_part4+1.890592e-01*S40+3.753083e+01*S41+2.256752e+03*S42+(-1.084247e+01)*S43+1.309289e+03*S44+0.000000e+00*S45+1.801593e+01*S46+2.474000e-01*S47+8.759868e-01*S48+7.060622e+00*S49'
.param V89_part6='V89_part5+5.345260e-01*S50+6.023151e-01*S51+(-4.128148e-01)*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+5.331649e-01*S57+(-3.316277e-01)*S58+0.000000e+00*S59'
.param V89_part7='V89_part6+0.000000e+00*S60+3.351331e+01*S61+0.000000e+00*S62+0.000000e+00*S63+1.505532e+00*S64+8.233184e-01*S65+0.000000e+00*S66+1.309442e+01*S67+4.926386e+01*S68+1.498656e+00*S69'
.param V89_part8='V89_part7+9.798657e+00*S70+8.291785e-01*S71+(-1.137524e+00)*S72+4.391942e-02*S73+1.246347e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+1.432948e+02*S78+2.762538e-01*S79'
.param V89_part9='V89_part8+0.000000e+00*S80+1.000000e+04*S81+3.069927e+00*S82+1.059289e+01*S83+(-1.786164e-01)*S84+1.257507e+01*S85+(-2.382491e+00)*S86+3.195192e+00*S87+(-2.231964e+00)*S88+6.968828e+00*S89'
.param V89_part10='V89_part9+(-6.251002e-01)*S90+0.000000e+00*S91+8.332384e-01*S92+4.392973e+00*S93+(-1.000000e+04)*S94+1.755205e-01*S95+5.040938e+00*S96+2.139070e+01*S97+3.457767e+03*S98+0.000000e+00*S99'
.param V89_part11='V89_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+4.371368e-01*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V89_part12='V89_part11+0.000000e+00*S110+(-1.450684e-01)*S111+0.000000e+00*S112+(-3.814697e+00)*S113+1.063045e+02*S114+(-1.741130e-01)*S115+7.843483e+01*S116+5.508660e+00*S117+1.714382e-01*S118+4.610164e-02*S119'
.param V89_part13='V89_part12+4.876100e-01*S120+1.041892e+00*S121+8.252226e-01*S122+0.000000e+00*S123+2.517788e+00*S124+3.795056e-01*S125+0.000000e+00*S126+0.000000e+00*S127+3.995345e-02*S128+0.000000e+00*S129'
.param V89_part14='V89_part13+1.332406e+00*S130+4.924243e-02*S131+0.000000e+00*S132+0.000000e+00*S133+6.260064e-02*S134+0.000000e+00*S135+0.000000e+00*S136+3.277513e-02*S137+(-1.220258e-01)*S138+(-2.221828e-02)*S139'
.param V89_part15='V89_part14+1.651020e+00*S140+(-2.533843e-01)*S141+0.000000e+00*S142+8.223689e-02*S143+(-2.299928e-01)*S144+(-2.918336e-03)*S145+(-3.474483e-02)*S146+0.000000e+00*S147+1.713186e-01*S148+2.276759e-02*S149'
.param V89_part16='V89_part15+0.000000e+00*S150+0.000000e+00*S151+1.000000e+04*S152+0.000000e+00*S153+(-2.599421e-01)*S154+5.090401e-02*S155+8.935593e-01*S156+4.890920e-02*S157+7.796427e-01*S158+3.008791e-01*S159'
.param V89_part17='V89_part16+(-4.409185e-01)*S160+2.729156e+01*S161+(-1.097071e+00)*S162+1.000000e+04*S163+3.833430e-02*S164+(-4.089706e+00)*S165+0.000000e+00*S166+5.316287e-03*S167+0.000000e+00*S168+4.722168e-02*S169'
.param V89_part18='V89_part17+8.563660e-02*S170+1.684713e+01*S171+1.292939e+01*S172+(-2.730141e-02)*S173+(-2.079997e+00)*S174+(-1.176158e+00)*S175+5.268039e+02*S176+1.014102e+01*S177+5.089692e-01*S178+3.555865e-02*S179'
.param V89_part19='V89_part18+0.000000e+00*S180+(-4.041541e+00)*S181+(-5.812797e-01)*S182+(-1.189016e+00)*S183+(-1.403393e-01)*S184+2.052206e-01*S185+2.616036e+00*S186+(-1.441561e+00)*S187+(-2.281192e+00)*S188+8.674348e-01*S189'
.param V89_part20='V89_part19+(-3.079198e+00)*S190+(-5.344691e-02)*S191+1.080687e-01*S192+(-2.470556e+00)*S193+7.722146e+01*S194+(-6.641899e+00)*S195+5.333142e+00*S196+2.439172e-02*S197+3.962692e+00*S198+9.157869e-02*S199'
.param V89_part21='V89_part20+3.246242e-02*S200+(-2.587721e+00)*S201+4.814452e-02*S202+1.100613e-01*S203+1.018474e+00*S204+7.463109e-03*S205+0.000000e+00*S206+0.000000e+00*S207+(-1.098373e+00)*S208+1.024217e-02*S209'
.param V89_part22='V89_part21+0.000000e+00*S210+0.000000e+00*S211+1.763334e+01*S212+(-2.467517e+00)*S213+3.526974e+00*S214+(-1.294611e+01)*S215+(-2.810663e-02)*S216+(-1.803705e-01)*S217+5.821204e+00*S218+(-3.834495e-01)*S219'
.param V89_part23='V89_part22+1.261912e+00*S220+1.835756e-01*S221+1.385131e-03*S222+1.224528e-01*S223+2.437994e-01*S224+1.739073e+00*S225+4.418150e+00*S226+2.066776e-01*S227+0.000000e+00*S228+(-7.542341e+00)*S229'
.param V89_part24='V89_part23+(-1.066166e-01)*S230+3.802381e-02*S231+(-1.743456e-02)*S232+1.641948e+00*S233+(-2.140911e-01)*S234+8.498846e-02*S235+6.025403e-01*S236+2.532003e+00*S237+9.336279e-02*S238+1.406636e-01*S239'
.param V89_part25='V89_part24+2.929784e+01*S240+(-2.236303e+00)*S241+7.206619e+01*S242+3.663909e+00*S243+1.386715e+00*S244+8.233337e-01*S245+1.057328e+00*S246+(-2.990604e-01)*S247+2.696392e-01*S248+4.660380e-01*S249'
.param V89_part26='V89_part25+(-2.512227e-01)*S250+(-8.843382e-02)*S251+5.148394e-01*S252+(-7.944016e-03)*S253+(-3.597034e-01)*S254+(-2.767093e+00)*S255+(-2.978728e+00)*S256+(-1.706289e-01)*S257+(-2.331011e-01)*S258+2.764599e+00*S259'
.param V89_part27='V89_part26+2.704494e+00*S260+6.660348e-01*S261+1.661765e-01*S262+(-4.051917e-02)*S263+9.652212e-02*S264+1.163119e-01*S265+1.928580e+00*S266+7.029309e+00*S267+7.807951e-01*S268+1.118104e+00*S269'
.param V89_part28='V89_part27+0.000000e+00*S270+(-6.520945e-02)*S271+(-4.903376e-02)*S272+(-2.300917e-01)*S273+(-9.547209e-01)*S274+9.206384e-02*S275+1.786101e+00*S276+1.684856e-01*S277+(-4.623259e-02)*S278+2.604206e-01*S279'
.param V89_part29='V89_part28+6.025496e-02*S280+(-6.430920e-02)*S281+0.000000e+00*S282+2.892290e-02*S283+6.439808e-01*S284+2.240533e+00*S285+1.108176e-01*S286+1.463513e+01*S287+(-6.386096e-01)*S288+(-4.262661e+00)*S289'
.param V89_part30='V89_part29+(-1.455530e+00)*S290+1.233783e+00*S291+(-6.042644e-02)*S292+(-7.628383e-03)*S293+(-3.917962e-01)*S294+(-2.243913e-02)*S295+(-1.889058e-01)*S296+(-5.843310e-01)*S297+1.282660e+03*S298+(-4.206652e-01)*S299'
.param V89_part31='V89_part30+3.074647e-01*S300+(-7.073238e+00)*S301+1.844654e+00*S302+2.482030e-01*S303+2.272821e-01*S304+3.394044e-02*S305+3.337448e-01*S306+(-3.176108e-02)*S307+(-1.002835e-01)*S308+5.679928e-01*S309'
.param V89='V89_part31+2.411325e-02*S310+(-8.842087e-02)*S311+3.539388e-01*S312+1.755671e-01*S313+(-1.081303e-01)*S314'
.param V90_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V90_part2='V90_part1+4.054450e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+1.820231e-01*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V90_part3='V90_part2+0.000000e+00*S20+0.000000e+00*S21+(-2.082817e-01)*S22+0.000000e+00*S23+2.675897e-02*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V90_part4='V90_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+2.180579e+02*S36+0.000000e+00*S37+0.000000e+00*S38+8.274572e+01*S39'
.param V90_part5='V90_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+3.894601e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V90_part6='V90_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+9.996379e+03*S53+1.000000e+04*S54+1.000000e+04*S55+0.000000e+00*S56+(-2.019317e-01)*S57+(-7.858436e-02)*S58+0.000000e+00*S59'
.param V90_part7='V90_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+3.747184e+03*S63+0.000000e+00*S64+(-5.441960e-01)*S65+0.000000e+00*S66+(-2.705772e-01)*S67+0.000000e+00*S68+(-9.269218e-02)*S69'
.param V90_part8='V90_part7+(-3.331974e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.635515e+00)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V90_part9='V90_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+7.922611e-02*S83+8.858623e-02*S84+0.000000e+00*S85+3.150655e-01*S86+4.223248e-01*S87+1.655411e-01*S88+0.000000e+00*S89'
.param V90_part10='V90_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+(-4.705646e-01)*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V90_part11='V90_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+(-2.212794e+00)*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V90_part12='V90_part11+0.000000e+00*S110+(-7.086530e-01)*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-6.599631e-01)*S115+(-4.752586e-01)*S116+0.000000e+00*S117+2.730613e+00*S118+0.000000e+00*S119'
.param V90_part13='V90_part12+0.000000e+00*S120+0.000000e+00*S121+(-2.288914e-01)*S122+1.955448e+01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+5.846203e+01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V90_part14='V90_part13+(-5.590664e-02)*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+(-7.142016e-02)*S137+(-4.280748e-02)*S138+(-2.222210e-03)*S139'
.param V90_part15='V90_part14+(-2.608621e-01)*S140+1.487875e-01*S141+7.751606e+00*S142+0.000000e+00*S143+2.660657e-01*S144+1.454467e-02*S145+(-3.719971e-01)*S146+0.000000e+00*S147+2.314398e+00*S148+0.000000e+00*S149'
.param V90_part16='V90_part15+0.000000e+00*S150+1.000000e+04*S151+(-1.955276e-01)*S152+0.000000e+00*S153+(-9.296957e-01)*S154+(-4.455496e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+(-2.766142e+00)*S158+6.160426e+00*S159'
.param V90_part17='V90_part16+(-8.975774e-01)*S160+(-1.963204e+00)*S161+0.000000e+00*S162+(-1.417855e+00)*S163+0.000000e+00*S164+0.000000e+00*S165+8.966638e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V90_part18='V90_part17+0.000000e+00*S170+(-7.748491e-01)*S171+(-1.116297e+00)*S172+0.000000e+00*S173+(-7.979151e-01)*S174+(-7.321177e-01)*S175+(-1.616127e+00)*S176+1.583022e-01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V90_part19='V90_part18+0.000000e+00*S180+0.000000e+00*S181+1.777417e-01*S182+6.511329e-03*S183+2.200829e-02*S184+0.000000e+00*S185+(-3.652071e-01)*S186+(-3.626268e-01)*S187+(-6.326435e-01)*S188+(-9.989073e-02)*S189'
.param V90_part20='V90_part19+0.000000e+00*S190+0.000000e+00*S191+5.297325e+00*S192+(-8.922657e-01)*S193+0.000000e+00*S194+0.000000e+00*S195+2.507848e-03*S196+0.000000e+00*S197+2.185246e-01*S198+0.000000e+00*S199'
.param V90_part21='V90_part20+0.000000e+00*S200+(-3.072112e-01)*S201+0.000000e+00*S202+0.000000e+00*S203+(-5.022332e-01)*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+1.562679e+01*S209'
.param V90_part22='V90_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+0.000000e+00*S213+(-1.521866e+00)*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V90_part23='V90_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+(-1.497974e-01)*S225+(-6.280056e-01)*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V90_part24='V90_part23+0.000000e+00*S230+3.008622e+00*S231+(-2.833513e+00)*S232+(-1.563730e+00)*S233+(-9.752187e-03)*S234+0.000000e+00*S235+(-4.788821e+00)*S236+(-3.967069e+00)*S237+6.525248e+00*S238+0.000000e+00*S239'
.param V90_part25='V90_part24+0.000000e+00*S240+(-2.717818e-01)*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+(-5.534145e-01)*S245+0.000000e+00*S246+0.000000e+00*S247+(-1.330630e-01)*S248+(-2.286905e-02)*S249'
.param V90_part26='V90_part25+0.000000e+00*S250+(-1.324968e+00)*S251+1.975942e+01*S252+0.000000e+00*S253+0.000000e+00*S254+1.599365e-02*S255+(-1.757314e-01)*S256+(-4.936857e-01)*S257+0.000000e+00*S258+1.298113e-01*S259'
.param V90_part27='V90_part26+(-5.322173e-01)*S260+1.742166e+00*S261+0.000000e+00*S262+0.000000e+00*S263+(-5.145112e-01)*S264+0.000000e+00*S265+(-1.349524e+00)*S266+0.000000e+00*S267+(-3.042304e+00)*S268+(-3.589310e+00)*S269'
.param V90_part28='V90_part27+0.000000e+00*S270+(-1.031070e+00)*S271+0.000000e+00*S272+0.000000e+00*S273+(-1.889028e+00)*S274+0.000000e+00*S275+0.000000e+00*S276+(-7.745872e+00)*S277+(-1.969755e-01)*S278+0.000000e+00*S279'
.param V90_part29='V90_part28+(-1.528906e-01)*S280+0.000000e+00*S281+0.000000e+00*S282+(-5.886474e+00)*S283+(-2.717554e+00)*S284+0.000000e+00*S285+0.000000e+00*S286+(-4.062474e-01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V90_part30='V90_part29+(-3.342864e-01)*S290+3.645916e-02*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-2.828589e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+6.729653e+00*S298+0.000000e+00*S299'
.param V90_part31='V90_part30+0.000000e+00*S300+(-3.483219e-01)*S301+(-1.378271e+00)*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+(-1.244328e+00)*S308+9.331063e-01*S309'
.param V90='V90_part31+0.000000e+00*S310+(-2.997801e+00)*S311+8.933822e-01*S312+5.456397e+00*S313+0.000000e+00*S314'
.param V91_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V91_part2='V91_part1+7.229498e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-1.135652e-01)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V91_part3='V91_part2+0.000000e+00*S20+0.000000e+00*S21+9.141892e-01*S22+0.000000e+00*S23+6.508791e-02*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V91_part4='V91_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+9.012247e+02*S36+0.000000e+00*S37+0.000000e+00*S38+3.419848e+02*S39'
.param V91_part5='V91_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+3.120555e+01*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V91_part6='V91_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+9.996379e+03*S53+9.999982e+03*S54+1.000000e+04*S55+0.000000e+00*S56+8.395774e-01*S57+3.726155e-01*S58+0.000000e+00*S59'
.param V91_part7='V91_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+3.747184e+03*S63+0.000000e+00*S64+1.957237e+00*S65+0.000000e+00*S66+6.365052e-01*S67+0.000000e+00*S68+4.574315e-01*S69'
.param V91_part8='V91_part7+6.725646e-01*S70+0.000000e+00*S71+0.000000e+00*S72+1.935716e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V91_part9='V91_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+3.009667e-01*S83+2.861291e-01*S84+0.000000e+00*S85+4.581059e-02*S86+(-7.537357e-02)*S87+8.972226e-02*S88+0.000000e+00*S89'
.param V91_part10='V91_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+1.706687e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V91_part11='V91_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+1.375154e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V91_part12='V91_part11+0.000000e+00*S110+1.281241e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+1.011345e+00*S115+5.866313e-01*S116+0.000000e+00*S117+(-2.162434e+00)*S118+0.000000e+00*S119'
.param V91_part13='V91_part12+0.000000e+00*S120+0.000000e+00*S121+7.842162e-01*S122+1.069239e+01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+1.389934e+01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V91_part14='V91_part13+4.879920e-01*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+6.700308e-01*S137+7.034982e-01*S138+4.696172e-01*S139'
.param V91_part15='V91_part14+8.467292e-02*S140+(-1.033343e-01)*S141+2.074801e+02*S142+0.000000e+00*S143+(-1.210479e-01)*S144+1.123587e-01*S145+7.884576e-01*S146+0.000000e+00*S147+4.238004e-01*S148+0.000000e+00*S149'
.param V91_part16='V91_part15+0.000000e+00*S150+1.000000e+04*S151+1.313215e+00*S152+0.000000e+00*S153+1.274869e+00*S154+1.147097e+00*S155+0.000000e+00*S156+0.000000e+00*S157+3.033705e+00*S158+5.682586e-01*S159'
.param V91_part17='V91_part16+1.240567e+00*S160+1.492865e+00*S161+0.000000e+00*S162+1.076614e+00*S163+0.000000e+00*S164+0.000000e+00*S165+1.587480e+02*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V91_part18='V91_part17+0.000000e+00*S170+1.633352e+00*S171+1.963624e+00*S172+0.000000e+00*S173+1.048202e+00*S174+1.353577e+00*S175+1.640397e+00*S176+2.246278e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V91_part19='V91_part18+0.000000e+00*S180+0.000000e+00*S181+8.553883e-01*S182+7.648871e-01*S183+(-5.087935e-01)*S184+0.000000e+00*S185+1.159533e+00*S186+6.898401e-01*S187+1.010722e+00*S188+8.597273e-01*S189'
.param V91_part20='V91_part19+0.000000e+00*S190+0.000000e+00*S191+(-2.639932e+00)*S192+1.627730e+00*S193+0.000000e+00*S194+0.000000e+00*S195+8.084300e-01*S196+0.000000e+00*S197+6.652096e-01*S198+0.000000e+00*S199'
.param V91_part21='V91_part20+0.000000e+00*S200+1.097533e+00*S201+0.000000e+00*S202+0.000000e+00*S203+3.186594e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+1.859959e+00*S209'
.param V91_part22='V91_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+0.000000e+00*S213+2.510175e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V91_part23='V91_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+7.538450e-02*S225+1.213114e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V91_part24='V91_part23+0.000000e+00*S230+(-6.375793e-01)*S231+2.070211e+00*S232+3.174853e+00*S233+6.379147e-01*S234+0.000000e+00*S235+4.182487e+00*S236+6.369915e+00*S237+(-1.369963e+00)*S238+0.000000e+00*S239'
.param V91_part25='V91_part24+0.000000e+00*S240+1.019195e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+1.856879e+00*S245+0.000000e+00*S246+0.000000e+00*S247+7.889388e-01*S248+1.238717e+00*S249'
.param V91_part26='V91_part25+0.000000e+00*S250+8.274781e-01*S251+(-5.795355e+00)*S252+0.000000e+00*S253+0.000000e+00*S254+5.245584e-01*S255+1.079237e+00*S256+1.172033e+00*S257+0.000000e+00*S258+3.366774e-02*S259'
.param V91_part27='V91_part26+8.962923e-01*S260+2.453346e+00*S261+0.000000e+00*S262+0.000000e+00*S263+1.643744e+00*S264+0.000000e+00*S265+1.485113e+00*S266+0.000000e+00*S267+1.000216e+00*S268+3.163619e+00*S269'
.param V91_part28='V91_part27+0.000000e+00*S270+4.543782e-01*S271+0.000000e+00*S272+0.000000e+00*S273+5.429476e-01*S274+0.000000e+00*S275+0.000000e+00*S276+4.750236e+00*S277+(-3.939781e-01)*S278+0.000000e+00*S279'
.param V91_part29='V91_part28+(-1.362449e+00)*S280+0.000000e+00*S281+0.000000e+00*S282+4.042121e-01*S283+2.088420e+00*S284+0.000000e+00*S285+0.000000e+00*S286+2.477273e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V91_part30='V91_part29+2.524842e+00*S290+4.839509e-01*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-7.597069e-02)*S295+0.000000e+00*S296+0.000000e+00*S297+3.066756e-01*S298+0.000000e+00*S299'
.param V91_part31='V91_part30+0.000000e+00*S300+1.040819e+00*S301+2.190313e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+9.751406e-01*S308+4.128670e-01*S309'
.param V91='V91_part31+0.000000e+00*S310+2.549017e+00*S311+1.372206e+00*S312+(-2.708795e-01)*S313+0.000000e+00*S314'
.param V92_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V92_part2='V92_part1+(-1.305269e-01)*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-7.580188e-02)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V92_part3='V92_part2+0.000000e+00*S20+0.000000e+00*S21+4.016417e-01*S22+0.000000e+00*S23+(-8.404676e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V92_part4='V92_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+3.874168e+01*S36+0.000000e+00*S37+0.000000e+00*S38+1.470118e+01*S39'
.param V92_part5='V92_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+1.067141e+01*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V92_part6='V92_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+9.996379e+03*S53+9.999973e+03*S54+1.000000e+04*S55+0.000000e+00*S56+3.788594e-01*S57+3.862712e-01*S58+0.000000e+00*S59'
.param V92_part7='V92_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+5.771718e+03*S63+0.000000e+00*S64+7.639240e-01*S65+0.000000e+00*S66+5.413853e-01*S67+0.000000e+00*S68+3.141893e-01*S69'
.param V92_part8='V92_part7+6.072035e-01*S70+0.000000e+00*S71+0.000000e+00*S72+2.041623e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V92_part9='V92_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-1.184592e-01)*S83+8.937912e-02*S84+0.000000e+00*S85+(-1.813722e-01)*S86+(-2.552672e-01)*S87+(-4.611132e-02)*S88+0.000000e+00*S89'
.param V92_part10='V92_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+9.340020e-01*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V92_part11='V92_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+2.963838e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V92_part12='V92_part11+0.000000e+00*S110+7.265817e-01*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+7.518379e-01*S115+1.243136e+00*S116+0.000000e+00*S117+(-8.737370e-01)*S118+0.000000e+00*S119'
.param V92_part13='V92_part12+0.000000e+00*S120+0.000000e+00*S121+6.645310e-01*S122+2.747696e+01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+2.214535e+01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V92_part14='V92_part13+1.281391e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+3.783672e-01*S137+2.834976e-01*S138+3.586974e-01*S139'
.param V92_part15='V92_part14+7.339529e-01*S140+3.976515e-02*S141+2.213094e+01*S142+0.000000e+00*S143+1.288539e-01*S144+3.203739e-01*S145+6.184050e-01*S146+0.000000e+00*S147+1.143335e+00*S148+0.000000e+00*S149'
.param V92_part16='V92_part15+0.000000e+00*S150+1.000000e+04*S151+2.186519e-01*S152+0.000000e+00*S153+3.004071e+00*S154+1.035530e+00*S155+0.000000e+00*S156+0.000000e+00*S157+5.002701e+00*S158+(-1.430779e+01)*S159'
.param V92_part17='V92_part16+2.366910e+00*S160+2.361323e+00*S161+0.000000e+00*S162+2.316344e+00*S163+0.000000e+00*S164+0.000000e+00*S165+9.738768e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V92_part18='V92_part17+0.000000e+00*S170+1.483374e+00*S171+2.016786e+00*S172+0.000000e+00*S173+1.606475e+00*S174+1.387198e+00*S175+1.891880e+00*S176+2.608136e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V92_part19='V92_part18+0.000000e+00*S180+0.000000e+00*S181+2.282848e-01*S182+1.176596e+00*S183+3.802634e+00*S184+0.000000e+00*S185+6.127448e-01*S186+1.849832e+00*S187+1.798473e+00*S188+2.427691e-01*S189'
.param V92_part20='V92_part19+0.000000e+00*S190+0.000000e+00*S191+(-7.195766e-01)*S192+1.256071e+00*S193+0.000000e+00*S194+0.000000e+00*S195+5.656125e-01*S196+0.000000e+00*S197+6.640427e-01*S198+0.000000e+00*S199'
.param V92_part21='V92_part20+0.000000e+00*S200+9.644303e-01*S201+0.000000e+00*S202+0.000000e+00*S203+2.427881e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+3.342392e+00*S209'
.param V92_part22='V92_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+0.000000e+00*S213+2.295501e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V92_part23='V92_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+5.734310e-01*S225+1.498795e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V92_part24='V92_part23+0.000000e+00*S230+(-1.281393e+00)*S231+7.964422e+00*S232+1.322418e+00*S233+4.665864e-01*S234+0.000000e+00*S235+6.022772e+00*S236+9.441975e+00*S237+(-7.131479e+00)*S238+0.000000e+00*S239'
.param V92_part25='V92_part24+0.000000e+00*S240+1.504986e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+1.279441e+00*S245+0.000000e+00*S246+0.000000e+00*S247+7.015875e-01*S248+(-2.452174e-01)*S249'
.param V92_part26='V92_part25+0.000000e+00*S250+1.551666e+00*S251+(-2.705101e+01)*S252+0.000000e+00*S253+0.000000e+00*S254+7.856191e-01*S255+1.202158e+00*S256+1.333567e+00*S257+0.000000e+00*S258+1.278293e+00*S259'
.param V92_part27='V92_part26+1.982777e+00*S260+2.889877e+00*S261+0.000000e+00*S262+0.000000e+00*S263+9.485116e+00*S264+0.000000e+00*S265+3.375038e+00*S266+0.000000e+00*S267+9.175223e+00*S268+4.079587e+00*S269'
.param V92_part28='V92_part27+0.000000e+00*S270+5.155892e+00*S271+0.000000e+00*S272+0.000000e+00*S273+7.137966e+00*S274+0.000000e+00*S275+0.000000e+00*S276+1.845741e+01*S277+7.406733e-01*S278+0.000000e+00*S279'
.param V92_part29='V92_part28+8.048190e+00*S280+0.000000e+00*S281+0.000000e+00*S282+1.415957e+01*S283+7.740921e+00*S284+0.000000e+00*S285+0.000000e+00*S286+2.120243e-01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V92_part30='V92_part29+6.001751e-01*S290+1.882964e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+2.144650e+00*S295+0.000000e+00*S296+0.000000e+00*S297+(-9.449873e+00)*S298+0.000000e+00*S299'
.param V92_part31='V92_part30+0.000000e+00*S300+1.749094e+00*S301+2.575464e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+1.419911e+00*S308+2.231854e-01*S309'
.param V92='V92_part31+0.000000e+00*S310+2.191978e+00*S311+(-1.404245e+00)*S312+(-6.111073e+00)*S313+0.000000e+00*S314'
.param V93_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V93_part2='V93_part1+(-2.252014e-02)*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-6.592832e-02)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V93_part3='V93_part2+0.000000e+00*S20+0.000000e+00*S21+(-8.017001e-02)*S22+0.000000e+00*S23+(-1.924055e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V93_part4='V93_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+3.809344e+01*S36+0.000000e+00*S37+0.000000e+00*S38+(-1.997643e+00)*S39'
.param V93_part5='V93_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-1.541539e+01)*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V93_part6='V93_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+1.000000e+04*S53+(-4.244128e+03)*S54+(-1.000000e+04)*S55+0.000000e+00*S56+(-2.322336e-01)*S57+(-2.664951e-01)*S58+0.000000e+00*S59'
.param V93_part7='V93_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+(-8.465115e+03)*S63+0.000000e+00*S64+(-2.391114e-02)*S65+0.000000e+00*S66+7.126267e-02*S67+0.000000e+00*S68+8.011153e-02*S69'
.param V93_part8='V93_part7+8.722168e-02*S70+0.000000e+00*S71+0.000000e+00*S72+1.934451e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V93_part9='V93_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+6.088784e-02*S83+(-5.426623e-02)*S84+0.000000e+00*S85+7.212620e-02*S86+1.164806e-01*S87+7.309518e-02*S88+0.000000e+00*S89'
.param V93_part10='V93_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+(-1.936659e-01)*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V93_part11='V93_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+3.007575e-02*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V93_part12='V93_part11+0.000000e+00*S110+(-5.215579e-03)*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-1.290446e-01)*S115+1.567930e-01*S116+0.000000e+00*S117+(-5.790052e-01)*S118+0.000000e+00*S119'
.param V93_part13='V93_part12+0.000000e+00*S120+0.000000e+00*S121+2.105083e-01*S122+(-6.833725e+00)*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+(-3.157751e+02)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V93_part14='V93_part13+(-2.261206e-01)*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+(-1.288857e-01)*S137+(-8.537078e-02)*S138+(-1.882908e-01)*S139'
.param V93_part15='V93_part14+(-6.784089e-02)*S140+(-8.291065e-04)*S141+(-2.430421e+03)*S142+0.000000e+00*S143+3.869134e-03*S144+2.520009e-03*S145+(-2.503472e-01)*S146+0.000000e+00*S147+2.956227e+00*S148+0.000000e+00*S149'
.param V93_part16='V93_part15+0.000000e+00*S150+(-7.159883e+03)*S151+1.937024e-01*S152+0.000000e+00*S153+1.281114e-02*S154+(-2.523659e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+(-9.447323e-01)*S158+(-7.961411e+01)*S159'
.param V93_part17='V93_part16+(-1.342245e-01)*S160+(-3.473484e-01)*S161+0.000000e+00*S162+(-9.239414e-02)*S163+0.000000e+00*S164+0.000000e+00*S165+(-3.366113e+01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V93_part18='V93_part17+0.000000e+00*S170+2.932463e-01*S171+3.847481e-01*S172+0.000000e+00*S173+1.057978e-01*S174+3.623067e-01*S175+(-3.519889e-01)*S176+1.802246e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V93_part19='V93_part18+0.000000e+00*S180+0.000000e+00*S181+(-3.361056e-01)*S182+(-8.510397e-02)*S183+(-4.542109e-01)*S184+0.000000e+00*S185+1.593702e-01*S186+(-2.320121e-01)*S187+(-3.880535e-01)*S188+1.694456e-01*S189'
.param V93_part20='V93_part19+0.000000e+00*S190+0.000000e+00*S191+(-6.962233e+00)*S192+4.888395e-01*S193+0.000000e+00*S194+0.000000e+00*S195+3.156254e-01*S196+0.000000e+00*S197+1.633841e-01*S198+0.000000e+00*S199'
.param V93_part21='V93_part20+0.000000e+00*S200+(-1.536275e-01)*S201+0.000000e+00*S202+0.000000e+00*S203+1.185298e-01*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+2.483911e+00*S209'
.param V93_part22='V93_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+0.000000e+00*S213+1.247060e-02*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V93_part23='V93_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+(-3.343338e-01)*S225+(-1.243384e-01)*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V93_part24='V93_part23+0.000000e+00*S230+(-1.117537e-01)*S231+(-2.403644e-01)*S232+5.254278e-02*S233+2.044573e-01*S234+0.000000e+00*S235+6.571246e-01*S236+2.747910e-01*S237+(-6.424348e-01)*S238+0.000000e+00*S239'
.param V93_part25='V93_part24+0.000000e+00*S240+(-2.543257e-01)*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+2.737112e-01*S245+0.000000e+00*S246+0.000000e+00*S247+9.713263e-02*S248+(-5.456832e-02)*S249'
.param V93_part26='V93_part25+0.000000e+00*S250+(-4.626719e-01)*S251+(-5.337243e+00)*S252+0.000000e+00*S253+0.000000e+00*S254+(-1.752726e-01)*S255+(-1.350067e-01)*S256+(-2.698830e-01)*S257+0.000000e+00*S258+1.057426e-01*S259'
.param V93_part27='V93_part26+(-2.074440e-01)*S260+3.040635e+00*S261+0.000000e+00*S262+0.000000e+00*S263+5.237977e-01*S264+0.000000e+00*S265+(-3.546116e-01)*S266+0.000000e+00*S267+3.131426e-02*S268+(-7.657253e-01)*S269'
.param V93_part28='V93_part27+0.000000e+00*S270+(-1.322049e-02)*S271+0.000000e+00*S272+0.000000e+00*S273+(-2.445343e-01)*S274+0.000000e+00*S275+0.000000e+00*S276+4.488759e-02*S277+(-1.000523e+00)*S278+0.000000e+00*S279'
.param V93_part29='V93_part28+1.193076e+00*S280+0.000000e+00*S281+0.000000e+00*S282+(-2.355764e-02)*S283+1.388873e+00*S284+0.000000e+00*S285+0.000000e+00*S286+3.690637e-02*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V93_part30='V93_part29+2.338773e-01*S290+(-4.045160e-01)*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-1.491791e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+(-8.453359e-01)*S298+0.000000e+00*S299'
.param V93_part31='V93_part30+0.000000e+00*S300+(-2.523333e-01)*S301+(-4.087155e-01)*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+(-6.074782e-01)*S308+1.021937e-02*S309'
.param V93='V93_part31+0.000000e+00*S310+(-3.457249e-01)*S311+(-1.417671e+00)*S312+(-9.355580e-02)*S313+0.000000e+00*S314'
.param V94_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V94_part2='V94_part1+2.289512e-03*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+8.203207e-04*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V94_part3='V94_part2+0.000000e+00*S20+0.000000e+00*S21+4.124595e-03*S22+0.000000e+00*S23+4.204589e-04*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V94_part4='V94_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+7.459130e+02*S36+0.000000e+00*S37+0.000000e+00*S38+(-6.801089e+01)*S39'
.param V94_part5='V94_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+4.680906e-01*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V94_part6='V94_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+1.000000e+04*S53+(-1.000000e+04)*S54+1.371434e+03*S55+0.000000e+00*S56+(-1.244588e-01)*S57+(-5.142299e-02)*S58+0.000000e+00*S59'
.param V94_part7='V94_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+(-1.000000e+04)*S63+0.000000e+00*S64+7.365750e-04*S65+0.000000e+00*S66+(-1.034566e-01)*S67+0.000000e+00*S68+(-1.222937e-01)*S69'
.param V94_part8='V94_part7+(-1.314558e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.221015e-01)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V94_part9='V94_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-2.632032e-03)*S83+3.976297e-03*S84+0.000000e+00*S85+(-3.397605e-02)*S86+(-7.649057e-02)*S87+(-2.208075e-02)*S88+0.000000e+00*S89'
.param V94_part10='V94_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+8.199207e-02*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V94_part11='V94_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+(-3.192921e-01)*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V94_part12='V94_part11+0.000000e+00*S110+(-6.369404e-02)*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-1.106516e-01)*S115+(-2.686916e-01)*S116+0.000000e+00*S117+(-3.500981e-02)*S118+0.000000e+00*S119'
.param V94_part13='V94_part12+0.000000e+00*S120+0.000000e+00*S121+1.352459e-02*S122+6.059706e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+(-3.013525e+01)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V94_part14='V94_part13+(-1.451855e-01)*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+2.001470e-02*S137+1.610115e-02*S138+(-4.005681e-02)*S139'
.param V94_part15='V94_part14+(-8.882043e-02)*S140+1.005371e-02*S141+2.704351e+00*S142+0.000000e+00*S143+1.439490e-02*S144+(-5.372493e-03)*S145+2.986386e-02*S146+0.000000e+00*S147+1.158826e-01*S148+0.000000e+00*S149'
.param V94_part16='V94_part15+0.000000e+00*S150+(-1.000000e+04)*S151+3.815798e-02*S152+0.000000e+00*S153+(-1.673514e-01)*S154+7.207014e-02*S155+0.000000e+00*S156+0.000000e+00*S157+(-5.237446e-01)*S158+4.455795e-02*S159'
.param V94_part17='V94_part16+(-1.101379e-01)*S160+(-1.191807e-03)*S161+0.000000e+00*S162+(-9.334887e-02)*S163+0.000000e+00*S164+0.000000e+00*S165+(-1.971180e-01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V94_part18='V94_part17+0.000000e+00*S170+(-1.411520e-01)*S171+(-8.114364e-03)*S172+0.000000e+00*S173+(-3.001839e-01)*S174+(-2.791841e-01)*S175+(-7.202126e-02)*S176+(-4.541639e-01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V94_part19='V94_part18+0.000000e+00*S180+0.000000e+00*S181+7.587264e-02*S182+5.993931e-02*S183+(-2.842207e-01)*S184+0.000000e+00*S185+(-2.204559e-01)*S186+(-6.719973e-02)*S187+(-1.545863e-01)*S188+(-3.320273e-01)*S189'
.param V94_part20='V94_part19+0.000000e+00*S190+0.000000e+00*S191+(-1.509912e+00)*S192+(-3.257381e-01)*S193+0.000000e+00*S194+0.000000e+00*S195+(-1.556003e-01)*S196+0.000000e+00*S197+(-4.372425e-01)*S198+0.000000e+00*S199'
.param V94_part21='V94_part20+0.000000e+00*S200+4.843187e-02*S201+0.000000e+00*S202+0.000000e+00*S203+(-7.877795e-01)*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+(-2.800117e+01)*S209'
.param V94_part22='V94_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+0.000000e+00*S213+6.899850e-02*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V94_part23='V94_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+(-1.430114e-02)*S225+(-4.297225e-02)*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V94_part24='V94_part23+0.000000e+00*S230+(-5.976921e-01)*S231+9.849771e-02*S232+(-9.210084e-02)*S233+(-3.453166e-01)*S234+0.000000e+00*S235+(-5.878671e-02)*S236+(-1.254209e+00)*S237+(-5.747887e-01)*S238+0.000000e+00*S239'
.param V94_part25='V94_part24+0.000000e+00*S240+6.605542e-02*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+(-1.924163e-01)*S245+0.000000e+00*S246+0.000000e+00*S247+(-3.284657e-01)*S248+(-3.351089e-01)*S249'
.param V94_part26='V94_part25+0.000000e+00*S250+1.678127e-01*S251+1.248113e+00*S252+0.000000e+00*S253+0.000000e+00*S254+4.255555e-02*S255+8.091603e-02*S256+9.596459e-02*S257+0.000000e+00*S258+(-1.233795e-01)*S259'
.param V94_part27='V94_part26+(-1.647960e-01)*S260+(-3.295890e-01)*S261+0.000000e+00*S262+0.000000e+00*S263+(-5.125275e-01)*S264+0.000000e+00*S265+(-4.538789e-01)*S266+0.000000e+00*S267+1.432101e-02*S268+(-1.298697e-02)*S269'
.param V94_part28='V94_part27+0.000000e+00*S270+7.685148e-02*S271+0.000000e+00*S272+0.000000e+00*S273+1.492509e-01*S274+0.000000e+00*S275+0.000000e+00*S276+(-6.678798e-02)*S277+5.789054e-04*S278+0.000000e+00*S279'
.param V94_part29='V94_part28+4.057281e-01*S280+0.000000e+00*S281+0.000000e+00*S282+(-7.145785e-02)*S283+(-7.054539e-01)*S284+0.000000e+00*S285+0.000000e+00*S286+4.588232e-01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V94_part30='V94_part29+5.476417e-01*S290+(-1.995194e-01)*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-9.285352e-02)*S295+0.000000e+00*S296+0.000000e+00*S297+(-5.370551e-01)*S298+0.000000e+00*S299'
.param V94_part31='V94_part30+0.000000e+00*S300+5.493492e-02*S301+(-3.066122e-02)*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+0.000000e+00*S307+1.726204e-01*S308+(-4.009299e-01)*S309'
.param V94='V94_part31+0.000000e+00*S310+3.032149e-01*S311+(-9.153771e-01)*S312+(-4.624337e-01)*S313+0.000000e+00*S314'
.param V95_part1='7.556832e+00*S0+6.411040e+00*S1+1.408277e+01*S2+0.000000e+00*S3+4.877928e+01*S4+0.000000e+00*S5+4.584529e-01*S6+2.232641e-01*S7+(-1.071592e+02)*S8+0.000000e+00*S9'
.param V95_part2='V95_part1+1.361491e+01*S10+(-7.569335e-01)*S11+0.000000e+00*S12+(-5.519232e+00)*S13+1.564098e+01*S14+(-3.111339e+00)*S15+0.000000e+00*S16+(-1.307430e+01)*S17+2.912692e+01*S18+2.078449e+02*S19'
.param V95_part3='V95_part2+1.405705e+00*S20+3.186185e+01*S21+3.009523e+01*S22+4.956674e+00*S23+2.209699e+01*S24+1.909559e+01*S25+8.599276e+00*S26+6.402896e+00*S27+6.645991e+00*S28+6.132704e+00*S29'
.param V95_part4='V95_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+3.126826e+03*S33+0.000000e+00*S34+0.000000e+00*S35+6.786402e+02*S36+1.046792e+01*S37+0.000000e+00*S38+5.042636e+00*S39'
.param V95_part5='V95_part4+5.476529e+02*S40+7.320664e+01*S41+0.000000e+00*S42+1.512977e+02*S43+3.963762e+01*S44+(-5.300979e+01)*S45+1.002050e+01*S46+0.000000e+00*S47+0.000000e+00*S48+8.869332e+01*S49'
.param V95_part6='V95_part5+0.000000e+00*S50+3.446015e+01*S51+2.328425e+01*S52+3.661210e+02*S53+2.853116e+03*S54+3.731406e+02*S55+2.752070e+01*S56+3.395891e+01*S57+5.378196e+01*S58+1.037168e+02*S59'
.param V95_part7='V95_part6+(-9.909274e+01)*S60+2.397861e+01*S61+5.252894e+02*S62+4.635110e+03*S63+0.000000e+00*S64+1.986052e+02*S65+4.467850e+03*S66+9.891312e+03*S67+1.923552e+02*S68+9.966117e+03*S69'
.param V95_part8='V95_part7+9.921958e+03*S70+4.800474e+00*S71+1.437086e+01*S72+2.785669e+01*S73+0.000000e+00*S74+3.723616e+00*S75+1.070489e+01*S76+3.727369e-01*S77+5.271799e+01*S78+1.899155e+01*S79'
.param V95_part9='V95_part8+1.211415e+01*S80+0.000000e+00*S81+2.129184e+02*S82+1.000000e+04*S83+7.016073e+00*S84+1.000000e+04*S85+1.111735e+01*S86+4.828613e+00*S87+3.595047e+01*S88+3.723599e+01*S89'
.param V95_part10='V95_part9+2.086933e+01*S90+1.880403e+02*S91+8.655240e+01*S92+0.000000e+00*S93+1.000000e+04*S94+1.431723e+01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+2.799550e+01*S99'
.param V95_part11='V95_part10+4.202120e+01*S100+5.127571e+00*S101+7.542190e+03*S102+3.455034e+01*S103+1.999856e+00*S104+(-4.160435e+00)*S105+2.684865e+02*S106+9.964375e+03*S107+2.129309e+01*S108+1.359633e+03*S109'
.param V95_part12='V95_part11+9.977008e+03*S110+1.330571e+01*S111+6.540334e+01*S112+4.141613e+00*S113+0.000000e+00*S114+3.399201e+00*S115+0.000000e+00*S116+3.482030e-01*S117+4.860335e+02*S118+1.222995e+02*S119'
.param V95_part13='V95_part12+0.000000e+00*S120+0.000000e+00*S121+7.526006e+01*S122+3.251238e+02*S123+0.000000e+00*S124+3.728120e+00*S125+1.000000e+04*S126+1.000000e+04*S127+9.984956e+03*S128+1.000000e+04*S129'
.param V95_part14='V95_part13+5.202354e+00*S130+9.981326e+03*S131+1.622298e+01*S132+9.824833e+02*S133+6.235302e+02*S134+1.943139e+03*S135+(-8.066162e-01)*S136+3.424105e+01*S137+5.324181e+01*S138+3.386267e+01*S139'
.param V95_part15='V95_part14+2.840396e+00*S140+1.820884e+01*S141+4.124575e+03*S142+9.938058e+00*S143+1.481195e+01*S144+5.324557e+00*S145+6.629318e+01*S146+1.000000e+04*S147+2.030359e+03*S148+9.995844e+03*S149'
.param V95_part16='V95_part15+3.069178e+01*S150+8.161110e+01*S151+2.632993e+00*S152+1.903043e+01*S153+8.768573e+00*S154+5.703776e+00*S155+0.000000e+00*S156+2.729576e+01*S157+2.378659e+00*S158+1.101237e+01*S159'
.param V95_part17='V95_part16+6.855848e+00*S160+6.320428e+00*S161+3.004411e+02*S162+9.082167e+00*S163+0.000000e+00*S164+1.154000e+01*S165+1.656118e+01*S166+1.574280e+02*S167+3.628564e+01*S168+3.413855e+01*S169'
.param V95_part18='V95_part17+6.916547e+01*S170+2.782149e+00*S171+1.987528e+00*S172+1.735734e+02*S173+5.470248e-01*S174+(-1.256975e-01)*S175+5.554984e+00*S176+3.324543e+00*S177+0.000000e+00*S178+4.039252e+03*S179'
.param V95_part19='V95_part18+7.991052e+03*S180+3.410290e+03*S181+2.098042e+01*S182+7.687912e+00*S183+1.552891e+01*S184+7.419022e+00*S185+(-5.626434e-01)*S186+1.064499e+01*S187+7.105845e+00*S188+0.000000e+00*S189'
.param V95_part20='V95_part19+8.786992e+00*S190+9.894480e+03*S191+4.630633e+00*S192+(-7.250247e-03)*S193+0.000000e+00*S194+1.524390e+01*S195+0.000000e+00*S196+2.246788e+01*S197+2.863144e-01*S198+8.552163e+00*S199'
.param V95_part21='V95_part20+2.019388e+02*S200+8.018697e+00*S201+2.001812e+01*S202+4.879648e+00*S203+6.399091e+00*S204+6.238005e+01*S205+8.033184e+00*S206+6.547136e+00*S207+2.540229e-01*S208+6.492462e+00*S209'
.param V95_part22='V95_part21+3.742007e+00*S210+3.288670e+01*S211+7.396809e+00*S212+1.597684e+01*S213+5.862818e+00*S214+6.490567e+00*S215+4.178051e+00*S216+4.113216e+01*S217+3.379700e+00*S218+5.860846e+01*S219'
.param V95_part23='V95_part22+3.355464e-01*S220+1.060912e+02*S221+1.507520e+01*S222+3.187380e+02*S223+2.340577e+02*S224+1.001214e+01*S225+1.233284e+01*S226+1.561112e+01*S227+8.311235e+00*S228+0.000000e+00*S229'
.param V95_part24='V95_part23+(-4.591565e+01)*S230+4.090984e+00*S231+3.713478e+00*S232+2.352861e+00*S233+0.000000e+00*S234+1.477569e+01*S235+1.416889e+00*S236+2.858289e+00*S237+4.858430e+01*S238+0.000000e+00*S239'
.param V95_part25='V95_part24+0.000000e+00*S240+9.572390e+00*S241+5.866429e+00*S242+0.000000e+00*S243+0.000000e+00*S244+7.003915e-01*S245+6.218348e+00*S246+1.561693e+02*S247+0.000000e+00*S248+1.227925e+02*S249'
.param V95_part26='V95_part25+1.132902e+03*S250+2.684032e+02*S251+4.544569e+00*S252+6.668516e+03*S253+6.137347e+02*S254+8.796963e+00*S255+8.449133e+00*S256+1.941825e+01*S257+7.852829e+01*S258+1.783430e+01*S259'
.param V95_part27='V95_part26+6.125963e+00*S260+3.151519e+00*S261+3.546943e+00*S262+6.055997e+03*S263+1.551455e+00*S264+1.386220e+01*S265+2.224713e+00*S266+2.259175e+00*S267+3.360859e+00*S268+2.369114e+00*S269'
.param V95_part28='V95_part27+1.279773e+01*S270+7.897835e+00*S271+1.138521e+01*S272+1.720669e+00*S273+7.045212e+00*S274+7.852071e+00*S275+1.000000e+04*S276+3.133615e+00*S277+8.349809e+00*S278+1.515077e+01*S279'
.param V95_part29='V95_part28+2.022342e+00*S280+5.707477e+00*S281+7.984142e+00*S282+(-4.447668e-02)*S283+6.176783e-01*S284+0.000000e+00*S285+9.869621e+03*S286+4.287433e+00*S287+3.333428e+01*S288+0.000000e+00*S289'
.param V95_part30='V95_part29+2.719669e+00*S290+(-2.972659e+00)*S291+6.666639e+03*S292+9.596907e+00*S293+3.721057e+02*S294+1.931362e+03*S295+(-3.075006e+03)*S296+2.297179e+02*S297+1.000000e+04*S298+1.000000e+04*S299'
.param V95_part31='V95_part30+6.229818e+00*S300+6.765707e+00*S301+5.879107e+00*S302+2.340352e+00*S303+3.009428e+00*S304+2.418302e-01*S305+2.363101e+00*S306+6.666736e+03*S307+1.222338e+02*S308+1.045146e+01*S309'
.param V95='V95_part31+6.676604e+03*S310+1.199714e+02*S311+1.634511e+02*S312+6.690652e+03*S313+1.000000e+04*S314'
.param V96_part1='(-7.707325e+00)*S0+7.387932e+00*S1+(-4.303485e+00)*S2+0.000000e+00*S3+(-7.982410e+00)*S4+0.000000e+00*S5+3.967478e+00*S6+3.551482e+00*S7+5.443058e+01*S8+0.000000e+00*S9'
.param V96_part2='V96_part1+9.974167e+00*S10+4.411418e+01*S11+0.000000e+00*S12+5.803038e+01*S13+(-3.943188e+00)*S14+1.174468e+03*S15+0.000000e+00*S16+2.484858e+02*S17+(-1.597393e+01)*S18+5.286856e+02*S19'
.param V96_part3='V96_part2+2.856209e+00*S20+(-1.064815e+01)*S21+(-2.732187e+01)*S22+2.415716e+00*S23+(-1.721285e+00)*S24+(-4.574429e+00)*S25+3.901138e+01*S26+(-2.733183e+00)*S27+(-3.144567e-02)*S28+(-1.526435e-01)*S29'
.param V96_part4='V96_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.085276e+02*S33+0.000000e+00*S34+0.000000e+00*S35+(-1.078338e+02)*S36+2.877756e+01*S37+0.000000e+00*S38+6.984446e+02*S39'
.param V96_part5='V96_part4+(-6.291530e+02)*S40+(-3.059280e+01)*S41+0.000000e+00*S42+(-1.769081e+01)*S43+5.098757e+02*S44+4.446992e+02*S45+4.471687e+00*S46+0.000000e+00*S47+0.000000e+00*S48+(-1.878505e+01)*S49'
.param V96_part6='V96_part5+0.000000e+00*S50+2.927780e+03*S51+(-4.902987e+00)*S52+2.668294e+00*S53+7.826763e+00*S54+8.494565e+00*S55+2.742177e+00*S56+2.294951e+00*S57+(-1.165574e+00)*S58+8.220310e+00*S59'
.param V96_part7='V96_part6+5.794328e+02*S60+(-3.407109e+01)*S61+9.208152e+02*S62+9.564430e+02*S63+0.000000e+00*S64+(-1.540451e+02)*S65+7.002068e+01*S66+(-1.404667e+01)*S67+6.561989e+00*S68+3.829646e+01*S69'
.param V96_part8='V96_part7+2.340149e+01*S70+(-3.145075e-01)*S71+6.028382e+01*S72+6.964605e-01*S73+0.000000e+00*S74+1.207131e+01*S75+1.274601e+01*S76+1.691470e+01*S77+4.501041e+01*S78+8.631765e+01*S79'
.param V96_part9='V96_part8+7.985233e+00*S80+0.000000e+00*S81+6.001501e+00*S82+(-4.248937e+01)*S83+(-2.701469e+00)*S84+(-8.033033e+00)*S85+(-5.522597e+00)*S86+2.348592e-01*S87+(-2.009342e+01)*S88+5.035947e-01*S89'
.param V96_part10='V96_part9+(-2.740504e+01)*S90+4.111323e+01*S91+8.639567e+00*S92+0.000000e+00*S93+7.002276e+02*S94+(-1.877218e+01)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+(-7.178430e+00)*S99'
.param V96_part11='V96_part10+5.260604e+00*S100+1.209902e+00*S101+1.194703e+00*S102+6.955615e+00*S103+2.063688e-01*S104+1.598758e-01*S105+2.400508e+01*S106+3.971266e+01*S107+(-5.469741e-01)*S108+7.838428e+00*S109'
.param V96_part12='V96_part11+2.351697e+01*S110+(-1.580355e-01)*S111+1.934416e+01*S112+(-8.092139e-01)*S113+0.000000e+00*S114+(-1.030983e+00)*S115+0.000000e+00*S116+1.307494e+00*S117+4.128667e+01*S118+3.312738e+01*S119'
.param V96_part13='V96_part12+0.000000e+00*S120+0.000000e+00*S121+6.723267e+01*S122+1.520294e+01*S123+0.000000e+00*S124+6.545223e-01*S125+1.989609e+00*S126+6.064335e+00*S127+2.056550e+01*S128+7.025970e+00*S129'
.param V96_part14='V96_part13+(-1.709105e+00)*S130+4.603306e+01*S131+(-7.754643e+00)*S132+3.783175e-01*S133+3.878907e+03*S134+4.671960e+02*S135+1.176692e+02*S136+2.863570e+01*S137+(-1.486171e+01)*S138+1.688266e+00*S139'
.param V96_part15='V96_part14+(-1.072552e+00)*S140+1.968828e+01*S141+3.263705e+03*S142+2.570490e+00*S143+1.281899e+01*S144+1.961345e+01*S145+(-1.036988e+01)*S146+6.041449e+00*S147+2.746723e+01*S148+1.280273e+01*S149'
.param V96_part16='V96_part15+1.237149e-01*S150+1.690796e+02*S151+(-2.705874e+00)*S152+(-1.724834e+00)*S153+2.234384e-01*S154+(-2.601188e+00)*S155+0.000000e+00*S156+(-1.904967e+01)*S157+(-2.796803e-01)*S158+(-1.159551e+01)*S159'
.param V96_part17='V96_part16+(-3.336997e+00)*S160+(-2.050918e+00)*S161+1.004744e+01*S162+(-1.946697e+00)*S163+0.000000e+00*S164+(-6.550415e+00)*S165+7.306970e+01*S166+1.057338e+02*S167+(-2.498326e+00)*S168+2.379356e+01*S169'
.param V96_part18='V96_part17+3.360650e+01*S170+(-2.573979e+00)*S171+(-6.900729e-01)*S172+3.756948e+01*S173+1.318302e+00*S174+5.291727e-01*S175+(-1.720067e+00)*S176+(-2.771167e+00)*S177+0.000000e+00*S178+4.142588e+03*S179'
.param V96_part19='V96_part18+2.522180e+01*S180+(-1.494156e+01)*S181+5.116883e+00*S182+(-2.601314e+00)*S183+1.263323e+00*S184+8.637460e+00*S185+1.151288e+00*S186+(-2.082656e+00)*S187+(-2.306341e+00)*S188+0.000000e+00*S189'
.param V96_part20='V96_part19+(-3.568972e+00)*S190+2.296798e+01*S191+(-4.443889e+00)*S192+3.947237e-01*S193+0.000000e+00*S194+(-1.005488e+01)*S195+0.000000e+00*S196+3.758162e+01*S197+3.617185e+01*S198+(-7.447061e-01)*S199'
.param V96_part21='V96_part20+5.945324e+01*S200+(-4.634668e+00)*S201+3.874699e+00*S202+7.721476e+00*S203+1.163377e+00*S204+2.182990e+01*S205+(-3.907706e-01)*S206+(-2.207536e+00)*S207+1.015261e+00*S208+(-1.748798e+00)*S209'
.param V96_part22='V96_part21+3.993886e+01*S210+4.693911e+01*S211+(-1.840697e+00)*S212+(-2.735149e+01)*S213+(-4.303493e+00)*S214+(-1.019840e+00)*S215+(-4.382272e+00)*S216+1.529419e-02*S217+1.526755e-01*S218+(-4.217138e+01)*S219'
.param V96_part23='V96_part22+1.596657e+00*S220+(-1.213601e+00)*S221+8.637293e-01*S222+(-2.624764e+00)*S223+(-4.916406e+00)*S224+8.661436e-01*S225+2.815089e+00*S226+3.957893e+01*S227+(-1.267425e+00)*S228+0.000000e+00*S229'
.param V96_part24='V96_part23+3.655127e+02*S230+5.052473e+00*S231+(-4.250781e-01)*S232+3.926532e-01*S233+0.000000e+00*S234+(-7.661821e-01)*S235+1.030046e-01*S236+(-1.206669e+00)*S237+1.258981e-01*S238+0.000000e+00*S239'
.param V96_part25='V96_part24+0.000000e+00*S240+(-1.561672e+00)*S241+(-1.557295e+00)*S242+0.000000e+00*S243+0.000000e+00*S244+1.714687e-01*S245+2.695114e+00*S246+(-3.768610e+00)*S247+0.000000e+00*S248+1.218255e+00*S249'
.param V96_part26='V96_part25+1.157731e+01*S250+(-1.036121e+01)*S251+(-4.159316e+00)*S252+4.083343e-01*S253+(-4.162311e+00)*S254+(-2.693483e+00)*S255+(-2.308453e+00)*S256+(-3.386402e+00)*S257+1.334643e+01*S258+(-1.088847e+00)*S259'
.param V96_part27='V96_part26+(-1.273313e+00)*S260+(-2.835113e+00)*S261+(-2.156092e+00)*S262+2.991530e+02*S263+(-3.782568e-01)*S264+(-7.380795e-01)*S265+(-5.045080e-01)*S266+3.808763e-01*S267+(-7.507574e-01)*S268+(-6.444168e-01)*S269'
.param V96_part28='V96_part27+(-2.475131e+01)*S270+(-2.213507e-01)*S271+1.963145e+01*S272+(-1.225169e+00)*S273+(-1.569601e+00)*S274+1.336008e+00*S275+1.163537e-01*S276+(-4.174445e-01)*S277+2.602237e-01*S278+(-1.610349e+00)*S279'
.param V96_part29='V96_part28+1.475753e-02*S280+4.643421e-01*S281+7.229104e-01*S282+5.612523e-02*S283+(-3.815674e-01)*S284+0.000000e+00*S285+9.869621e+03*S286+(-3.340640e-01)*S287+3.002449e+00*S288+0.000000e+00*S289'
.param V96_part30='V96_part29+1.043160e-01*S290+(-1.232614e+01)*S291+3.651753e+00*S292+5.019297e-01*S293+3.164587e+00*S294+2.217383e+01*S295+(-1.216882e+01)*S296+7.356066e+00*S297+1.000000e+04*S298+1.000000e+04*S299'
.param V96_part31='V96_part30+(-7.850396e-01)*S300+(-2.764756e+00)*S301+(-1.091683e-01)*S302+(-2.384498e-02)*S303+(-1.279588e+00)*S304+5.818055e+01*S305+9.333282e-02*S306+2.929441e-01*S307+(-3.172756e-02)*S308+(-2.204936e+00)*S309'
.param V96='V96_part31+(-7.326834e+00)*S310+(-6.180676e-01)*S311+1.769450e+00*S312+(-9.667453e+00)*S313+2.213448e+00*S314'
.param V97_part1='(-1.991893e+00)*S0+(-1.571345e+00)*S1+(-2.492262e+00)*S2+0.000000e+00*S3+(-5.536589e+00)*S4+0.000000e+00*S5+6.372918e-01*S6+1.264707e+00*S7+2.379440e+02*S8+0.000000e+00*S9'
.param V97_part2='V97_part1+(-3.559750e+00)*S10+8.300050e+01*S11+0.000000e+00*S12+1.298088e+02*S13+(-4.536297e+00)*S14+1.089577e+03*S15+0.000000e+00*S16+(-4.988077e+00)*S17+1.231013e+01*S18+(-3.486162e+00)*S19'
.param V97_part3='V97_part2+7.680563e-01*S20+(-2.748331e+01)*S21+2.726164e+01*S22+4.182099e-01*S23+(-2.259177e+01)*S24+(-1.053302e+01)*S25+3.020079e+01*S26+(-1.299679e+00)*S27+(-1.649728e+00)*S28+(-1.538295e+00)*S29'
.param V97_part4='V97_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.000000e+04*S33+0.000000e+00*S34+0.000000e+00*S35+1.000000e+04*S36+3.709172e+01*S37+0.000000e+00*S38+1.000000e+04*S39'
.param V97_part5='V97_part4+5.829886e+01*S40+(-2.888058e+01)*S41+0.000000e+00*S42+(-1.849917e+02)*S43+3.886992e+01*S44+4.319680e+02*S45+3.038949e+01*S46+0.000000e+00*S47+0.000000e+00*S48+(-1.004530e+02)*S49'
.param V97_part6='V97_part5+0.000000e+00*S50+1.116145e+03*S51+(-2.171627e+01)*S52+9.013654e+00*S53+2.339078e+00*S54+5.764934e+00*S55+4.071151e+00*S56+(-1.387007e+00)*S57+2.045175e+00*S58+4.181602e+00*S59'
.param V97_part7='V97_part6+5.143358e+01*S60+(-2.186649e+00)*S61+5.648468e+01*S62+5.490491e+02*S63+0.000000e+00*S64+2.249063e+01*S65+1.649520e+02*S66+3.772609e+02*S67+(-6.393110e+01)*S68+1.414003e+02*S69'
.param V97_part8='V97_part7+2.226222e+02*S70+4.446826e-01*S71+(-1.028904e+02)*S72+1.192852e+00*S73+0.000000e+00*S74+(-2.613878e+00)*S75+(-6.507062e+00)*S76+2.337008e+00*S77+(-1.063823e+02)*S78+(-6.163461e+01)*S79'
.param V97_part9='V97_part8+8.100294e-01*S80+0.000000e+00*S81+5.219669e+01*S82+2.636676e+01*S83+(-2.135048e+00)*S84+1.388338e+01*S85+(-1.680345e+00)*S86+(-1.646958e+00)*S87+(-6.900814e+00)*S88+(-3.460153e+00)*S89'
.param V97_part10='V97_part9+(-3.823698e+00)*S90+1.547008e+01*S91+(-2.349284e+01)*S92+0.000000e+00*S93+3.390261e+03*S94+(-4.290414e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+(-4.708316e+00)*S99'
.param V97_part11='V97_part10+(-4.574555e+01)*S100+(-3.614366e+00)*S101+1.082212e+01*S102+(-3.807034e+01)*S103+(-1.252023e+00)*S104+2.071571e+02*S105+(-2.075448e+02)*S106+7.405705e+01*S107+1.056310e+01*S108+2.209109e+00*S109'
.param V97_part12='V97_part11+6.254311e+01*S110+1.114744e+01*S111+(-6.610845e+01)*S112+(-2.715122e+00)*S113+0.000000e+00*S114+(-2.017985e+00)*S115+0.000000e+00*S116+(-8.446034e-01)*S117+(-6.013110e+02)*S118+(-8.305271e+01)*S119'
.param V97_part13='V97_part12+0.000000e+00*S120+0.000000e+00*S121+(-5.857764e+01)*S122+4.164752e+00*S123+0.000000e+00*S124+(-2.178639e+00)*S125+2.970679e+00*S126+7.153289e+00*S127+3.205607e+01*S128+2.844251e+01*S129'
.param V97_part14='V97_part13+(-2.783449e+00)*S130+1.632610e+01*S131+7.993309e+00*S132+(-2.537360e+01)*S133+1.459614e+03*S134+1.821954e+01*S135+(-2.333186e+00)*S136+(-1.580242e+01)*S137+(-5.607053e+01)*S138+(-2.707771e+01)*S139'
.param V97_part15='V97_part14+(-7.988847e-01)*S140+(-8.912912e-01)*S141+2.826970e+02*S142+(-6.609702e+00)*S143+4.253781e+00*S144+1.108458e+01*S145+(-3.929236e+01)*S146+2.373245e+01*S147+3.891290e+01*S148+3.668376e+01*S149'
.param V97_part16='V97_part15+(-4.273353e+01)*S150+(-1.281304e+02)*S151+(-4.525494e-01)*S152+(-2.404351e+01)*S153+(-7.480050e+00)*S154+(-2.225850e+00)*S155+0.000000e+00*S156+(-7.690578e-01)*S157+(-1.643019e+00)*S158+2.748721e+01*S159'
.param V97_part17='V97_part16+(-3.295881e+00)*S160+(-2.445834e+00)*S161+(-2.128919e+02)*S162+(-6.321669e+00)*S163+0.000000e+00*S164+(-8.876034e+00)*S165+(-2.722938e+00)*S166+(-1.264115e+02)*S167+(-2.677598e+01)*S168+(-2.442770e+01)*S169'
.param V97_part18='V97_part17+(-3.139738e+01)*S170+5.258325e-02*S171+(-1.435582e+00)*S172+(-1.640048e+02)*S173+(-2.491104e+00)*S174+(-3.208767e-02)*S175+(-1.458479e+00)*S176+4.313745e+00*S177+0.000000e+00*S178+(-6.967655e+02)*S179'
.param V97_part19='V97_part18+2.219074e+01*S180+(-2.917737e+01)*S181+1.064041e+01*S182+(-7.441845e+00)*S183+(-1.169878e+01)*S184+(-2.083691e+00)*S185+3.846944e-01*S186+(-7.964151e+00)*S187+(-2.343956e+00)*S188+0.000000e+00*S189'
.param V97_part20='V97_part19+(-5.249443e+00)*S190+1.798768e+02*S191+1.257341e+01*S192+8.245498e-02*S193+0.000000e+00*S194+(-1.497180e+01)*S195+0.000000e+00*S196+(-1.366366e+01)*S197+(-4.314378e+00)*S198+(-5.508055e+00)*S199'
.param V97_part21='V97_part20+(-7.824503e+01)*S200+(-5.997364e+00)*S201+(-1.447591e+01)*S202+1.333764e+00*S203+9.029945e+00*S204+(-3.177921e+01)*S205+(-5.098204e+00)*S206+1.228017e+00*S207+(-4.332852e-01)*S208+(-1.797481e+00)*S209'
.param V97_part22='V97_part21+2.724814e+01*S210+(-6.778627e+00)*S211+(-5.740084e+00)*S212+1.001739e+01*S213+(-2.818143e+00)*S214+(-5.010198e+00)*S215+5.567402e+00*S216+(-3.715242e+01)*S217+(-2.516974e+00)*S218+(-2.976051e+01)*S219'
.param V97_part23='V97_part22+(-2.302959e-01)*S220+(-9.855774e+01)*S221+(-2.986741e+01)*S222+(-4.600518e+02)*S223+(-2.176652e+02)*S224+(-1.592574e+01)*S225+(-1.365928e+01)*S226+(-1.366114e+01)*S227+1.450081e+01*S228+0.000000e+00*S229'
.param V97_part24='V97_part23+(-3.699766e+01)*S230+2.006396e+01*S231+(-3.000157e+00)*S232+(-1.763125e+00)*S233+0.000000e+00*S234+(-1.656387e+01)*S235+(-7.795225e-01)*S236+(-5.848510e-01)*S237+(-6.554614e+01)*S238+0.000000e+00*S239'
.param V97_part25='V97_part24+0.000000e+00*S240+(-8.535088e+00)*S241+(-4.478943e+00)*S242+0.000000e+00*S243+0.000000e+00*S244+(-5.436131e-01)*S245+(-1.497515e+01)*S246+(-2.170138e+02)*S247+0.000000e+00*S248+(-3.087637e+02)*S249'
.param V97_part26='V97_part25+(-1.697854e+03)*S250+(-2.451978e+02)*S251+8.153426e+00*S252+(-1.000000e+04)*S253+(-6.037976e+02)*S254+(-7.339016e+00)*S255+(-6.561500e+00)*S256+(-2.529817e+00)*S257+(-1.778231e+02)*S258+(-1.574461e+01)*S259'
.param V97_part27='V97_part26+(-2.490538e+00)*S260+7.606852e-01*S261+(-2.335681e+00)*S262+(-6.167458e+03)*S263+7.370902e-01*S264+4.106406e+00*S265+(-8.769803e-01)*S266+(-4.848028e+00)*S267+(-1.859173e+00)*S268+(-8.594764e-01)*S269'
.param V97_part28='V97_part27+3.990249e+01*S270+(-7.476771e+00)*S271+(-5.155333e+00)*S272+6.740342e-01*S273+(-5.800929e+00)*S274+(-8.737290e+00)*S275+2.449342e+00*S276+(-2.230942e+00)*S277+(-8.507950e+00)*S278+(-5.916796e+00)*S279'
.param V97_part29='V97_part28+(-1.470976e+00)*S280+(-6.073952e+00)*S281+(-1.462817e+01)*S282+1.037938e+00*S283+3.725277e-01*S284+0.000000e+00*S285+1.409703e+03*S286+(-3.255259e+00)*S287+(-6.815873e+01)*S288+0.000000e+00*S289'
.param V97_part30='V97_part29+(-2.173586e+00)*S290+8.350615e+01*S291+(-1.000000e+04)*S292+(-8.468058e+00)*S293+(-9.344062e+02)*S294+3.879774e+03*S295+1.000000e+04*S296+(-5.838570e+02)*S297+1.000000e+04*S298+1.000000e+04*S299'
.param V97_part31='V97_part30+(-8.249594e+00)*S300+(-5.595307e+00)*S301+(-3.371442e+00)*S302+(-2.419096e+00)*S303+(-1.873681e+00)*S304+(-4.829428e+00)*S305+(-2.630791e+00)*S306+(-1.000000e+04)*S307+(-1.136069e+02)*S308+(-8.506998e+00)*S309'
.param V97='V97_part31+(-1.000000e+04)*S310+(-1.130973e+02)*S311+(-4.079305e+02)*S312+(-1.000000e+04)*S313+(-9.995291e+03)*S314'
.param V98_part1='1.032906e+00*S0+6.771997e+00*S1+5.773348e+00*S2+0.000000e+00*S3+(-5.427395e+01)*S4+0.000000e+00*S5+1.073813e+00*S6+1.307642e+00*S7+(-8.817230e+02)*S8+0.000000e+00*S9'
.param V98_part2='V98_part1+(-1.791426e+01)*S10+(-2.224042e+02)*S11+0.000000e+00*S12+(-1.989423e+03)*S13+(-1.658196e+00)*S14+(-1.133841e+01)*S15+0.000000e+00*S16+6.503830e+00*S17+2.000086e+01*S18+3.158601e+00*S19'
.param V98_part3='V98_part2+1.695433e+00*S20+8.484017e-01*S21+(-5.863677e+03)*S22+4.511736e+00*S23+1.051770e+00*S24+(-5.948722e-01)*S25+(-3.445544e+02)*S26+1.439683e-01*S27+3.752464e+00*S28+2.753529e+00*S29'
.param V98_part4='V98_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.537546e+02*S33+0.000000e+00*S34+0.000000e+00*S35+2.653020e+03*S36+2.465905e+00*S37+0.000000e+00*S38+1.398992e+03*S39'
.param V98_part5='V98_part4+2.783766e+01*S40+1.584416e-01*S41+0.000000e+00*S42+(-1.000000e+04)*S43+(-5.718069e+01)*S44+(-6.526662e+01)*S45+1.788462e+01*S46+0.000000e+00*S47+0.000000e+00*S48+5.958737e+00*S49'
.param V98_part6='V98_part5+0.000000e+00*S50+(-1.347426e+02)*S51+(-4.487640e-01)*S52+3.614015e+02*S53+2.848890e+03*S54+3.707219e+02*S55+2.629173e+01*S56+3.097658e+01*S57+4.690449e+01*S58+1.021927e+02*S59'
.param V98_part7='V98_part6+2.307674e+00*S60+3.377420e+00*S61+5.059472e+02*S62+6.101411e+01*S63+0.000000e+00*S64+1.206821e+01*S65+(-1.976300e+01)*S66+1.000000e+04*S67+9.787490e+01*S68+1.000000e+04*S69'
.param V98_part8='V98_part7+1.000000e+04*S70+5.107025e-01*S71+(-6.868314e+00)*S72+2.349591e+01*S73+0.000000e+00*S74+(-1.218785e+00)*S75+6.786618e+00*S76+3.641179e+00*S77+(-3.006348e+02)*S78+(-1.487292e+01)*S79'
.param V98_part9='V98_part8+1.444914e+01*S80+0.000000e+00*S81+2.300242e+02*S82+9.971122e+03*S83+1.802924e+00*S84+9.957452e+03*S85+4.836200e-01*S86+2.463473e-01*S87+3.483751e+00*S88+(-1.000000e+04)*S89'
.param V98_part10='V98_part9+(-3.885287e-02)*S90+1.951530e+02*S91+(-7.772733e+00)*S92+0.000000e+00*S93+(-4.568696e+03)*S94+(-5.477223e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+(-1.000000e+04)*S99'
.param V98_part11='V98_part10+(-1.000000e+04)*S100+2.601123e-01*S101+7.533601e+03*S102+(-1.000000e+04)*S103+2.281686e-01*S104+(-5.145893e+02)*S105+(-1.000000e+04)*S106+1.000000e+04*S107+(-1.000000e+04)*S108+1.347840e+03*S109'
.param V98_part12='V98_part11+1.000000e+04*S110+(-1.000000e+04)*S111+(-1.000000e+04)*S112+(-2.703309e-01)*S113+0.000000e+00*S114+(-3.676556e-01)*S115+0.000000e+00*S116+(-5.516550e+00)*S117+9.902335e+01*S118+(-7.156260e+02)*S119'
.param V98_part13='V98_part12+0.000000e+00*S120+0.000000e+00*S121+(-8.684444e+00)*S122+3.184084e+02*S123+0.000000e+00*S124+(-2.525725e-01)*S125+9.982638e+03*S126+9.983384e+03*S127+1.000000e+04*S128+9.991273e+03*S129'
.param V98_part14='V98_part13+4.848613e-02*S130+1.000000e+04*S131+(-4.396311e+03)*S132+9.513222e+02*S133+(-7.746622e+02)*S134+(-7.870105e+01)*S135+(-1.772560e+00)*S136+(-1.000000e+04)*S137+(-1.000000e+04)*S138+(-1.000000e+04)*S139'
.param V98_part15='V98_part14+(-3.417280e-01)*S140+(-9.695455e+03)*S141+(-2.826006e+01)*S142+(-7.552463e-01)*S143+(-1.000000e+04)*S144+(-6.638721e+02)*S145+(-1.000000e+04)*S146+9.993496e+03*S147+2.054673e+03*S148+1.000000e+04*S149'
.param V98_part16='V98_part15+4.021099e-01*S150+1.425693e+00*S151+2.834005e-01*S152+(-5.660936e-01)*S153+1.544708e-02*S154+5.385942e-03*S155+0.000000e+00*S156+(-4.600726e+02)*S157+(-3.093054e-01)*S158+3.261328e-01*S159'
.param V98_part17='V98_part16+(-1.368429e-01)*S160+(-5.642854e-02)*S161+(-7.072212e-01)*S162+1.630136e-01*S163+0.000000e+00*S164+1.459101e+00*S165+(-1.000000e+04)*S166+(-4.687037e+02)*S167+6.514036e+00*S168+(-3.841752e+03)*S169'
.param V98_part18='V98_part17+(-1.000000e+04)*S170+2.417552e-01*S171+5.363964e-02*S172+(-5.011732e+01)*S173+2.086337e-01*S174+1.153269e-01*S175+3.198996e-01*S176+2.643924e-01*S177+0.000000e+00*S178+(-1.000000e+04)*S179'
.param V98_part19='V98_part18+7.980487e+03*S180+3.363735e+03*S181+1.595921e+01*S182+(-1.390558e-01)*S183+5.625246e-01*S184+1.891312e+00*S185+9.346131e-02*S186+7.812622e-01*S187+6.441254e-01*S188+0.000000e+00*S189'
.param V98_part20='V98_part19+(-1.777648e+00)*S190+1.000000e+04*S191+(-2.239766e-01)*S192+1.872184e-01*S193+0.000000e+00*S194+(-5.430483e-01)*S195+0.000000e+00*S196+(-3.361634e+00)*S197+(-1.000000e+04)*S198+1.591214e-01*S199'
.param V98_part21='V98_part20+(-2.430537e+01)*S200+(-1.203115e+00)*S201+8.068340e-01*S202+(-7.170438e-02)*S203+2.626878e+00*S204+5.422569e+00*S205+(-8.828502e-01)*S206+(-2.266053e+01)*S207+6.463336e-01*S208+(-3.487394e+00)*S209'
.param V98_part22='V98_part21+(-1.000000e+04)*S210+(-1.000000e+04)*S211+(-5.412239e-02)*S212+(-2.633805e+02)*S213+(-5.031406e-01)*S214+4.320903e-01*S215+(-7.192785e-01)*S216+(-5.949485e+01)*S217+4.722867e-01*S218+(-1.000000e+04)*S219'
.param V98_part23='V98_part22+5.314707e-01*S220+(-3.696973e+00)*S221+(-3.803771e-01)*S222+(-3.149175e+00)*S223+(-4.340342e+00)*S224+(-1.873955e+00)*S225+(-3.054115e-01)*S226+(-6.080656e-01)*S227+(-1.001290e+02)*S228+0.000000e+00*S229'
.param V98_part24='V98_part23+(-3.039414e-01)*S230+1.356875e+00*S231+(-2.900438e-01)*S232+7.046672e-02*S233+0.000000e+00*S234+1.841159e-01*S235+5.393569e-02*S236+(-4.485185e-01)*S237+9.950921e-01*S238+0.000000e+00*S239'
.param V98_part25='V98_part24+0.000000e+00*S240+7.876915e-02*S241+2.184357e-01*S242+0.000000e+00*S243+0.000000e+00*S244+8.589015e-02*S245+(-6.252714e-01)*S246+4.859625e-01*S247+0.000000e+00*S248+(-1.585832e-01)*S249'
.param V98_part26='V98_part25+1.544494e+00*S250+(-1.636597e+00)*S251+(-1.142524e-01)*S252+(-1.081675e+00)*S253+(-3.408584e+00)*S254+1.059351e+00*S255+2.788086e-02*S256+7.459786e+00*S257+8.215051e+00*S258+(-3.369782e-01)*S259'
.param V98_part27='V98_part26+5.320382e-01*S260+(-2.359354e-01)*S261+2.541981e-03*S262+7.906199e+00*S263+(-8.776420e-01)*S264+(-1.772478e+00)*S265+(-2.557608e-01)*S266+(-1.635719e-03)*S267+(-1.413012e-01)*S268+(-3.120428e-01)*S269'
.param V98_part28='V98_part27+(-7.848081e+03)*S270+1.894630e-01*S271+(-4.740858e+00)*S272+(-5.535735e-02)*S273+(-6.024865e-01)*S274+(-2.961552e-02)*S275+9.999486e+03*S276+(-5.456151e-02)*S277+(-1.551384e-01)*S278+(-1.000000e+04)*S279'
.param V98_part29='V98_part28+1.611980e-02*S280+(-1.053794e-01)*S281+(-9.969582e-02)*S282+(-2.196256e-02)*S283+1.347274e-01*S284+0.000000e+00*S285+(-1.000000e+04)*S286+5.583394e-02*S287+(-8.344255e+03)*S288+0.000000e+00*S289'
.param V98_part30='V98_part29+3.156373e-02*S290+(-1.375947e+00)*S291+(-1.162763e-01)*S292+(-2.671723e-01)*S293+(-1.306973e+00)*S294+(-9.999967e+03)*S295+1.039125e+01*S296+4.428256e-02*S297+(-1.000000e+04)*S298+(-1.000000e+04)*S299'
.param V98_part31='V98_part30+(-2.063799e-01)*S300+9.328754e-02*S301+(-1.212811e-01)*S302+7.019923e-02*S303+(-4.471272e-02)*S304+(-4.105007e+00)*S305+6.369867e-02*S306+(-2.695761e-02)*S307+(-3.705127e+00)*S308+(-2.996509e+01)*S309'
.param V98='V98_part31+(-9.466716e-01)*S310+(-2.020506e+00)*S311+(-1.053437e+00)*S312+5.521932e+00*S313+(-9.089495e-01)*S314'
.param V99_part1='1.078710e-01*S0+(-7.085099e-02)*S1+(-2.541097e-01)*S2+0.000000e+00*S3+2.603151e-02*S4+0.000000e+00*S5+(-1.872911e-02)*S6+(-3.697868e-02)*S7+(-4.488592e+00)*S8+0.000000e+00*S9'
.param V99_part2='V99_part1+(-3.917253e-01)*S10+1.996196e+00*S11+0.000000e+00*S12+1.107066e-01*S13+(-2.382337e-02)*S14+6.700616e+00*S15+0.000000e+00*S16+(-2.509236e+01)*S17+7.346867e-02*S18+(-2.611607e+00)*S19'
.param V99_part3='V99_part2+1.486432e-02*S20+(-4.551833e-02)*S21+5.324240e-01*S22+(-8.605877e-04)*S23+(-9.679915e-02)*S24+(-4.819738e-02)*S25+(-3.133516e-01)*S26+(-7.016574e-02)*S27+(-2.306064e-03)*S28+(-7.158442e-04)*S29'
.param V99_part4='V99_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+4.952549e+02*S33+0.000000e+00*S34+0.000000e+00*S35+3.052745e+01*S36+(-1.419393e-02)*S37+0.000000e+00*S38+4.319909e+02*S39'
.param V99_part5='V99_part4+8.844507e+00*S40+2.405424e-01*S41+0.000000e+00*S42+6.933399e+00*S43+2.469860e+01*S44+2.828200e+01*S45+(-1.013394e+00)*S46+0.000000e+00*S47+0.000000e+00*S48+6.976533e-01*S49'
.param V99_part6='V99_part5+0.000000e+00*S50+3.097565e+01*S51+(-1.346620e+00)*S52+1.537974e+00*S53+3.905637e-01*S54+(-3.852491e-02)*S55+3.984810e-01*S56+4.775793e-01*S57+(-1.057974e+00)*S58+4.733854e+00*S59'
.param V99_part7='V99_part6+4.194663e+00*S60+(-7.512815e-01)*S61+2.836899e+02*S62+9.965472e+03*S63+0.000000e+00*S64+1.702038e+02*S65+8.954515e+03*S66+8.248081e+00*S67+(-4.113529e+01)*S68+1.132253e-01*S69'
.param V99_part8='V99_part7+3.010825e+00*S70+2.367591e+00*S71+(-1.171525e+01)*S72+1.244099e+00*S73+0.000000e+00*S74+(-3.731605e-02)*S75+4.425551e-01*S76+6.103167e-01*S77+(-1.306657e+01)*S78+1.485529e-01*S79'
.param V99_part9='V99_part8+5.250722e-01*S80+0.000000e+00*S81+2.081547e+00*S82+5.399064e+00*S83+(-7.422609e-02)*S84+2.829294e+01*S85+1.212219e-01*S86+7.831307e-01*S87+(-8.237076e-01)*S88+6.099775e+00*S89'
.param V99_part10='V99_part9+(-8.524024e-02)*S90+3.042127e-01*S91+1.277743e+00*S92+0.000000e+00*S93+(-1.892391e+02)*S94+(-1.575692e-02)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+1.270794e+01*S99'
.param V99_part11='V99_part10+5.630238e+00*S100+9.020235e-01*S101+7.832243e+00*S102+6.258788e+00*S103+3.406304e-01*S104+1.557458e+01*S105+1.811411e+02*S106+(-1.504651e+00)*S107+1.117621e+01*S108+1.931114e+00*S109'
.param V99_part12='V99_part11+(-4.865414e+00)*S110+4.025758e+00*S111+2.455814e+01*S112+(-2.030805e-02)*S113+0.000000e+00*S114+6.773982e-01*S115+0.000000e+00*S116+1.178214e-01*S117+2.788304e+00*S118+7.872564e+01*S119'
.param V99_part13='V99_part12+0.000000e+00*S120+0.000000e+00*S121+1.552896e+01*S122+2.065341e+00*S123+0.000000e+00*S124+3.832959e-01*S125+1.020257e+01*S126+9.761303e+00*S127+6.292860e+00*S128+1.315791e+01*S129'
.param V99_part14='V99_part13+(-1.115512e-01)*S130+1.001104e+01*S131+3.724564e+00*S132+6.326626e+00*S133+1.068702e+03*S134+4.030916e+03*S135+1.554327e+01*S136+6.932973e+00*S137+2.022739e+00*S138+(-1.873392e+00)*S139'
.param V99_part15='V99_part14+5.834997e-01*S140+1.154512e+00*S141+8.495177e+02*S142+2.496562e-01*S143+1.618041e+00*S144+(-3.575555e+00)*S145+(-2.381153e+00)*S146+8.540073e-02*S147+(-3.520675e+00)*S148+4.615919e+01*S149'
.param V99_part16='V99_part15+7.479656e+00*S150+9.561550e+00*S151+(-9.047708e-02)*S152+4.535735e+00*S153+(-1.044283e+00)*S154+(-2.095623e-01)*S155+0.000000e+00*S156+(-1.331252e+00)*S157+1.817176e-02*S158+8.830531e+00*S159'
.param V99_part17='V99_part16+(-9.536812e-02)*S160+(-3.208697e-01)*S161+(-3.954562e+02)*S162+5.477988e-01*S163+0.000000e+00*S164+(-1.202093e+00)*S165+1.222958e+01*S166+4.729473e+01*S167+1.761125e+01*S168+4.505671e+00*S169'
.param V99_part18='V99_part17+2.092914e+01*S170+2.696960e-01*S171+2.407961e-01*S172+2.081485e+01*S173+(-3.935228e-02)*S174+4.837789e-02*S175+3.800524e-01*S176+1.484812e+00*S177+0.000000e+00*S178+1.000000e+04*S179'
.param V99_part19='V99_part18+2.978240e+00*S180+(-4.757931e+00)*S181+(-5.717620e-01)*S182+(-5.906614e-01)*S183+5.322392e+00*S184+4.145274e+00*S185+4.718494e-02*S186+2.522840e-01*S187+2.637734e-01*S188+0.000000e+00*S189'
.param V99_part20='V99_part19+(-4.866642e-01)*S190+1.091788e+01*S191+2.547312e+00*S192+7.266171e-02*S193+0.000000e+00*S194+(-1.686186e+00)*S195+0.000000e+00*S196+1.159322e+01*S197+(-9.040848e-02)*S198+7.611868e-01*S199'
.param V99_part21='V99_part20+2.288557e+02*S200+(-1.192841e+00)*S201+9.958913e+00*S202+9.124728e+00*S203+7.278017e+00*S204+7.451482e+01*S205+5.036977e-01*S206+7.456660e-01*S207+(-3.330317e-01)*S208+1.970059e+00*S209'
.param V99_part22='V99_part21+6.699393e+00*S210+1.216769e+01*S211+9.107626e-02*S212+3.669293e+00*S213+(-1.426622e-01)*S214+(-9.143124e-03)*S215+1.714229e+00*S216+1.515092e+00*S217+9.359371e-02*S218+(-1.217352e+00)*S219'
.param V99_part23='V99_part22+(-1.784364e-01)*S220+(-1.302193e+00)*S221+5.826674e-02*S222+(-3.220987e+00)*S223+(-3.144810e+00)*S224+(-8.529903e-01)*S225+6.832314e-01*S226+4.814203e+00*S227+1.444883e+00*S228+0.000000e+00*S229'
.param V99_part24='V99_part23+4.647145e+01*S230+8.677968e+00*S231+(-4.692309e-02)*S232+(-1.614019e-03)*S233+0.000000e+00*S234+4.417437e-01*S235+1.792288e-02*S236+2.433846e-01*S237+5.889839e-01*S238+0.000000e+00*S239'
.param V99_part25='V99_part24+0.000000e+00*S240+(-8.089483e-01)*S241+1.538918e-01*S242+0.000000e+00*S243+0.000000e+00*S244+9.250846e-03*S245+(-2.337921e-01)*S246+(-1.303000e+00)*S247+0.000000e+00*S248+(-2.014297e-02)*S249'
.param V99_part26='V99_part25+(-7.774654e-01)*S250+(-9.853130e-02)*S251+1.223215e+00*S252+(-2.160543e-01)*S253+(-1.148434e+00)*S254+(-8.777591e-01)*S255+(-8.536537e-01)*S256+(-6.989187e-01)*S257+1.043152e+00*S258+5.803000e+00*S259'
.param V99_part27='V99_part26+7.950710e-02*S260+1.298949e+00*S261+4.708241e-01*S262+1.421153e+01*S263+8.723266e-01*S264+1.530716e+01*S265+1.319784e-01*S266+5.670031e-02*S267+2.845205e-01*S268+3.797924e-02*S269'
.param V99_part28='V99_part27+4.568877e+00*S270+(-7.277402e-01)*S271+6.992300e+00*S272+3.355723e-01*S273+(-7.569643e-01)*S274+4.275788e-01*S275+6.681602e-01*S276+1.786926e-01*S277+4.761657e-02*S278+(-1.862909e+00)*S279'
.param V99_part29='V99_part28+1.074368e-01*S280+9.218625e-02*S281+(-1.996070e-01)*S282+9.080174e-04*S283+1.661372e-02*S284+0.000000e+00*S285+1.000000e+04*S286+(-1.917663e-01)*S287+4.408235e-01*S288+0.000000e+00*S289'
.param V99_part30='V99_part29+(-1.060256e-01)*S290+9.733139e+00*S291+(-1.207261e-01)*S292+(-1.556710e-02)*S293+1.013022e-01*S294+6.946986e+03*S295+7.042486e+03*S296+(-1.065060e-01)*S297+(-6.069668e+03)*S298+1.000000e+04*S299'
.param V99_part31='V99_part30+6.472109e-01*S300+(-5.738457e-01)*S301+1.655158e-01*S302+(-1.936363e-02)*S303+1.196734e-01*S304+1.141504e+01*S305+(-3.216220e-01)*S306+3.166132e-01*S307+(-1.527685e-01)*S308+3.720310e+00*S309'
.param V99='V99_part31+(-3.967968e-01)*S310+(-1.360060e+00)*S311+1.225982e+00*S312+2.961931e+00*S313+(-1.352946e+00)*S314'
.param V100_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+6.149600e+03*S9'
.param V100_part2='V100_part1+1.062064e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V100_part3='V100_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V100_part4='V100_part3+3.044627e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+8.617469e+03*S38+0.000000e+00*S39'
.param V100_part5='V100_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+(-2.913395e-01)*S46+0.000000e+00*S47+1.085228e+01*S48+1.536086e-01*S49'
.param V100_part6='V100_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V100_part7='V100_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-3.037397e-01)*S65+0.000000e+00*S66+(-2.524210e-01)*S67+0.000000e+00*S68+(-1.137836e-01)*S69'
.param V100_part8='V100_part7+(-3.622853e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-7.760349e-02)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V100_part9='V100_part8+0.000000e+00*S80+0.000000e+00*S81+(-4.885248e-02)*S82+1.280630e-01*S83+5.152226e-02*S84+0.000000e+00*S85+2.823188e-01*S86+4.200538e-01*S87+1.570538e-01*S88+0.000000e+00*S89'
.param V100_part10='V100_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+(-1.061558e-01)*S94+(-4.723778e-01)*S95+8.175071e+01*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V100_part11='V100_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+(-9.059765e-02)*S105+0.000000e+00*S106+0.000000e+00*S107+(-9.802209e-02)*S108+(-3.371120e-01)*S109'
.param V100_part12='V100_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+2.150583e-01*S115+0.000000e+00*S116+0.000000e+00*S117+5.845823e-01*S118+0.000000e+00*S119'
.param V100_part13='V100_part12+1.000000e+04*S120+0.000000e+00*S121+(-6.842433e-02)*S122+0.000000e+00*S123+0.000000e+00*S124+2.999595e-01*S125+(-1.965082e-01)*S126+(-1.012076e-01)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V100_part14='V100_part13+3.657304e-01*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+1.979709e-02*S137+(-3.180558e-03)*S138+1.306933e-01*S139'
.param V100_part15='V100_part14+1.085595e-01*S140+8.990276e-02*S141+1.314723e-01*S142+2.466698e-01*S143+0.000000e+00*S144+1.181991e-01*S145+(-1.400884e-03)*S146+0.000000e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V100_part16='V100_part15+0.000000e+00*S150+0.000000e+00*S151+(-4.247382e-01)*S152+0.000000e+00*S153+(-3.450791e-01)*S154+6.791003e-02*S155+0.000000e+00*S156+0.000000e+00*S157+(-6.498763e-01)*S158+2.895712e-01*S159'
.param V100_part17='V100_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+(-2.793399e-01)*S166+0.000000e+00*S167+(-1.808550e-01)*S168+0.000000e+00*S169'
.param V100_part18='V100_part17+0.000000e+00*S170+5.874881e-01*S171+1.797230e-01*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+(-3.548812e-01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V100_part19='V100_part18+0.000000e+00*S180+0.000000e+00*S181+5.100258e-01*S182+1.091704e-01*S183+3.872064e-01*S184+2.409125e-01*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V100_part20='V100_part19+0.000000e+00*S190+(-4.585760e-01)*S191+1.064318e-01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+1.000000e+04*S196+0.000000e+00*S197+1.548214e-01*S198+0.000000e+00*S199'
.param V100_part21='V100_part20+0.000000e+00*S200+(-1.218051e-01)*S201+0.000000e+00*S202+0.000000e+00*S203+3.289273e-01*S204+(-4.317760e-01)*S205+3.819690e-02*S206+0.000000e+00*S207+0.000000e+00*S208+1.910372e-02*S209'
.param V100_part22='V100_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+(-4.381368e-01)*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V100_part23='V100_part22+0.000000e+00*S220+8.146700e-03*S221+(-2.892296e-01)*S222+(-4.692998e-02)*S223+0.000000e+00*S224+3.053783e-01*S225+0.000000e+00*S226+(-1.289130e-02)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V100_part24='V100_part23+(-8.819554e-01)*S230+(-1.150765e-01)*S231+0.000000e+00*S232+0.000000e+00*S233+2.178346e+02*S234+(-1.329852e+00)*S235+0.000000e+00*S236+7.133854e-01*S237+(-1.936854e+00)*S238+0.000000e+00*S239'
.param V100_part25='V100_part24+9.993416e+03*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+1.298840e-01*S249'
.param V100_part26='V100_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+(-3.713689e+00)*S253+0.000000e+00*S254+8.668440e-02*S255+(-3.065934e-02)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V100_part27='V100_part26+0.000000e+00*S260+2.976566e-01*S261+0.000000e+00*S262+0.000000e+00*S263+8.530802e-01*S264+0.000000e+00*S265+1.537857e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V100_part28='V100_part27+0.000000e+00*S270+(-2.350945e-01)*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+(-1.811135e+01)*S275+6.696788e-01*S276+(-2.663482e-01)*S277+(-1.670092e+01)*S278+(-1.232987e+00)*S279'
.param V100_part29='V100_part28+0.000000e+00*S280+(-1.725234e+01)*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+(-5.446870e-01)*S286+0.000000e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V100_part30='V100_part29+9.747862e-01*S290+1.018924e+00*S291+(-6.099282e+00)*S292+(-3.260056e+00)*S293+(-1.911835e-01)*S294+(-8.108068e+00)*S295+0.000000e+00*S296+0.000000e+00*S297+(-4.845539e+00)*S298+0.000000e+00*S299'
.param V100_part31='V100_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+(-8.693775e+00)*S307+0.000000e+00*S308+(-6.189887e-02)*S309'
.param V100='V100_part31+(-3.166283e+00)*S310+0.000000e+00*S311+6.899560e-01*S312+(-1.686913e+00)*S313+0.000000e+00*S314'
.param V101_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+5.188799e+03*S9'
.param V101_part2='V101_part1+6.455638e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V101_part3='V101_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V101_part4='V101_part3+1.055552e+01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+8.890853e+03*S38+0.000000e+00*S39'
.param V101_part5='V101_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+1.745477e+00*S46+0.000000e+00*S47+1.026316e+00*S48+(-2.455042e-02)*S49'
.param V101_part6='V101_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V101_part7='V101_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+1.115076e+00*S65+0.000000e+00*S66+6.255583e-01*S67+0.000000e+00*S68+4.887063e-01*S69'
.param V101_part8='V101_part7+6.463952e-01*S70+0.000000e+00*S71+0.000000e+00*S72+4.084023e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V101_part9='V101_part8+0.000000e+00*S80+0.000000e+00*S81+4.458272e-01*S82+2.257040e-01*S83+3.401644e-01*S84+0.000000e+00*S85+8.022864e-02*S86+(-7.248363e-02)*S87+1.054836e-01*S88+0.000000e+00*S89'
.param V101_part10='V101_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+9.225301e-01*S94+2.099836e+00*S95+5.486291e+02*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V101_part11='V101_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+7.283839e-01*S105+0.000000e+00*S106+0.000000e+00*S107+7.016812e-01*S108+7.595178e-01*S109'
.param V101_part12='V101_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+2.587457e-01*S115+0.000000e+00*S116+0.000000e+00*S117+(-1.438157e-01)*S118+0.000000e+00*S119'
.param V101_part13='V101_part12+6.839925e+03*S120+0.000000e+00*S121+9.514461e-02*S122+0.000000e+00*S123+0.000000e+00*S124+(-8.059824e-04)*S125+6.816205e-01*S126+7.044549e-01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V101_part14='V101_part13+1.198581e-01*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+4.269690e-01*S137+6.192775e-01*S138+2.186841e-01*S139'
.param V101_part15='V101_part14+(-8.318204e-02)*S140+(-4.962965e-02)*S141+6.645417e-01*S142+8.350988e-02*S143+0.000000e+00*S144+(-3.469359e-03)*S145+3.670917e-01*S146+0.000000e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V101_part16='V101_part15+0.000000e+00*S150+0.000000e+00*S151+2.784034e+00*S152+0.000000e+00*S153+1.273228e+00*S154+(-2.262700e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+1.346240e+00*S158+1.011284e+00*S159'
.param V101_part17='V101_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+7.234349e-01*S166+0.000000e+00*S167+7.844825e-01*S168+0.000000e+00*S169'
.param V101_part18='V101_part17+0.000000e+00*S170+1.655627e+00*S171+1.006416e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+1.074144e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V101_part19='V101_part18+0.000000e+00*S180+0.000000e+00*S181+(-2.918300e-01)*S182+5.122310e-01*S183+8.434887e-02*S184+(-6.633784e-02)*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V101_part20='V101_part19+0.000000e+00*S190+8.332436e-01*S191+1.159909e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+1.000000e+04*S196+0.000000e+00*S197+6.572188e-01*S198+0.000000e+00*S199'
.param V101_part21='V101_part20+0.000000e+00*S200+8.249795e-01*S201+0.000000e+00*S202+0.000000e+00*S203+1.393719e+00*S204+9.807537e-01*S205+6.590299e-01*S206+0.000000e+00*S207+0.000000e+00*S208+6.656075e-01*S209'
.param V101_part22='V101_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+8.441955e-01*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V101_part23='V101_part22+0.000000e+00*S220+(-4.076687e-03)*S221+1.316204e+00*S222+1.604077e-01*S223+0.000000e+00*S224+(-2.220865e-01)*S225+0.000000e+00*S226+8.971495e-01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V101_part24='V101_part23+7.634617e-01*S230+1.354632e+00*S231+0.000000e+00*S232+0.000000e+00*S233+(-1.933851e+01)*S234+1.982102e+00*S235+0.000000e+00*S236+7.401434e-01*S237+2.450273e+00*S238+0.000000e+00*S239'
.param V101_part25='V101_part24+1.000000e+04*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+5.333206e+00*S249'
.param V101_part26='V101_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+2.948927e-01*S253+0.000000e+00*S254+1.865273e-01*S255+6.494167e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V101_part27='V101_part26+0.000000e+00*S260+9.873178e-01*S261+0.000000e+00*S262+0.000000e+00*S263+(-4.459919e-01)*S264+0.000000e+00*S265+(-1.467647e+00)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V101_part28='V101_part27+0.000000e+00*S270+9.717762e-01*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+7.128161e+00*S275+6.973836e+00*S276+1.107667e+00*S277+4.538196e+00*S278+2.301393e+00*S279'
.param V101_part29='V101_part28+0.000000e+00*S280+4.849508e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+1.014427e+00*S286+0.000000e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V101_part30='V101_part29+(-1.858672e-01)*S290+2.321694e+00*S291+4.689127e-01*S292+3.035804e+00*S293+1.391824e+00*S294+2.622333e+00*S295+0.000000e+00*S296+0.000000e+00*S297+3.145367e+00*S298+0.000000e+00*S299'
.param V101_part31='V101_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+8.828545e-01*S307+0.000000e+00*S308+3.045285e+00*S309'
.param V101='V101_part31+2.218019e+00*S310+0.000000e+00*S311+1.822036e+00*S312+2.340678e+00*S313+0.000000e+00*S314'
.param V102_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+1.000000e+04*S9'
.param V102_part2='V102_part1+(-2.969228e-02)*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V102_part3='V102_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V102_part4='V102_part3+5.538191e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+9.135698e+03*S38+0.000000e+00*S39'
.param V102_part5='V102_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+(-5.001338e-02)*S46+0.000000e+00*S47+2.990175e+02*S48+1.429355e-01*S49'
.param V102_part6='V102_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V102_part7='V102_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+2.372228e-01*S65+0.000000e+00*S66+3.149411e-01*S67+0.000000e+00*S68+2.044080e-01*S69'
.param V102_part8='V102_part7+4.752093e-01*S70+0.000000e+00*S71+0.000000e+00*S72+1.601696e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V102_part9='V102_part8+0.000000e+00*S80+0.000000e+00*S81+1.981076e-01*S82+(-1.218423e-01)*S83+8.338201e-02*S84+0.000000e+00*S85+(-1.649936e-01)*S86+(-2.391638e-01)*S87+(-4.023562e-02)*S88+0.000000e+00*S89'
.param V102_part10='V102_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+3.747361e-01*S94+1.085081e+00*S95+1.012739e+03*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V102_part11='V102_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+3.361067e-03*S105+0.000000e+00*S106+0.000000e+00*S107+3.073713e-01*S108+6.950801e-01*S109'
.param V102_part12='V102_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-1.910167e-02)*S115+0.000000e+00*S116+0.000000e+00*S117+3.768274e-01*S118+0.000000e+00*S119'
.param V102_part13='V102_part12+7.004759e+03*S120+0.000000e+00*S121+1.655227e-01*S122+0.000000e+00*S123+0.000000e+00*S124+9.376093e-02*S125+3.863281e-01*S126+(-5.871362e-02)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V102_part14='V102_part13+2.488950e-01*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+2.337023e-01*S137+1.509303e-01*S138+1.182280e-01*S139'
.param V102_part15='V102_part14+3.650632e-01*S140+(-4.483472e-02)*S141+7.747597e-03*S142+1.248304e-01*S143+0.000000e+00*S144+1.020623e-01*S145+2.519007e-01*S146+0.000000e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V102_part16='V102_part15+0.000000e+00*S150+0.000000e+00*S151+2.491625e-01*S152+0.000000e+00*S153+2.626527e+00*S154+8.990707e-02*S155+0.000000e+00*S156+0.000000e+00*S157+4.364751e+00*S158+(-1.328171e+00)*S159'
.param V102_part17='V102_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+9.678086e-01*S166+0.000000e+00*S167+7.736491e-01*S168+0.000000e+00*S169'
.param V102_part18='V102_part17+0.000000e+00*S170+(-2.281207e+00)*S171+9.981305e-01*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+1.930639e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V102_part19='V102_part18+0.000000e+00*S180+0.000000e+00*S181+(-4.564245e-01)*S182+3.005614e-01*S183+4.784083e-02*S184+2.637574e-01*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V102_part20='V102_part19+0.000000e+00*S190+6.958334e-01*S191+6.110305e-01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+1.000000e+04*S196+0.000000e+00*S197+6.587475e-01*S198+0.000000e+00*S199'
.param V102_part21='V102_part20+0.000000e+00*S200+3.241178e-01*S201+0.000000e+00*S202+0.000000e+00*S203+4.310724e-01*S204+1.196837e+00*S205+7.195531e-01*S206+0.000000e+00*S207+0.000000e+00*S208+8.502686e-01*S209'
.param V102_part22='V102_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+1.926075e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V102_part23='V102_part22+0.000000e+00*S220+2.148773e-01*S221+2.084655e+00*S222+8.480254e-01*S223+0.000000e+00*S224+(-4.711136e-01)*S225+0.000000e+00*S226+3.993994e-01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V102_part24='V102_part23+1.369723e+00*S230+1.221832e+00*S231+0.000000e+00*S232+0.000000e+00*S233+(-5.541655e+01)*S234+2.892713e+00*S235+0.000000e+00*S236+(-2.897434e+00)*S237+4.046650e+00*S238+0.000000e+00*S239'
.param V102_part25='V102_part24+5.941634e+03*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+8.656145e+00*S249'
.param V102_part26='V102_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+1.214457e+01*S253+0.000000e+00*S254+2.788151e-01*S255+5.150733e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V102_part27='V102_part26+0.000000e+00*S260+5.409417e-01*S261+0.000000e+00*S262+0.000000e+00*S263+(-9.010231e-02)*S264+0.000000e+00*S265+(-5.151346e-03)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V102_part28='V102_part27+0.000000e+00*S270+1.579807e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+2.591312e+01*S275+5.164150e+00*S276+2.223480e-01*S277+2.529004e+01*S278+2.391795e+00*S279'
.param V102_part29='V102_part28+0.000000e+00*S280+3.019095e+01*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+1.896724e+00*S286+0.000000e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V102_part30='V102_part29+3.275156e-01*S290+5.069377e+00*S291+1.657901e+01*S292+4.111899e+00*S293+2.389885e+00*S294+1.793421e+01*S295+0.000000e+00*S296+0.000000e+00*S297+1.094164e+01*S298+0.000000e+00*S299'
.param V102_part31='V102_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+2.240355e+01*S307+0.000000e+00*S308+4.882588e+00*S309'
.param V102='V102_part31+7.116169e+00*S310+0.000000e+00*S311+9.652830e-01*S312+4.224875e+00*S313+0.000000e+00*S314'
.param V103_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-1.213226e+03)*S9'
.param V103_part2='V103_part1+2.849951e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V103_part3='V103_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V103_part4='V103_part3+(-2.478542e+00)*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+7.502407e+03*S38+0.000000e+00*S39'
.param V103_part5='V103_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+5.171516e-02*S46+0.000000e+00*S47+(-1.883204e+03)*S48+2.252143e-03*S49'
.param V103_part6='V103_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V103_part7='V103_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+6.917381e-02*S65+0.000000e+00*S66+1.131354e-02*S67+0.000000e+00*S68+2.695494e-02*S69'
.param V103_part8='V103_part7+2.270913e-02*S70+0.000000e+00*S71+0.000000e+00*S72+1.176343e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V103_part9='V103_part8+0.000000e+00*S80+0.000000e+00*S81+(-1.190403e-01)*S82+3.779052e-02*S83+(-5.739420e-02)*S84+0.000000e+00*S85+6.996339e-02*S86+1.149671e-01*S87+7.792946e-02*S88+0.000000e+00*S89'
.param V103_part10='V103_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+4.103125e-02*S94+5.247724e-01*S95+(-1.274106e+01)*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V103_part11='V103_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+7.021137e-02*S105+0.000000e+00*S106+0.000000e+00*S107+1.966851e-01*S108+9.208590e-02*S109'
.param V103_part12='V103_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+2.571647e-01*S115+0.000000e+00*S116+0.000000e+00*S117+(-1.477692e-02)*S118+0.000000e+00*S119'
.param V103_part13='V103_part12+(-8.086486e+03)*S120+0.000000e+00*S121+4.089980e-04*S122+0.000000e+00*S123+0.000000e+00*S124+6.303700e-02*S125+9.908591e-02*S126+1.274286e-01*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V103_part14='V103_part13+5.218564e-02*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+1.364497e-02*S137+4.371288e-02*S138+(-4.937827e-02)*S139'
.param V103_part15='V103_part14+2.735328e-03*S140+4.388711e-02*S141+2.592808e-01*S142+6.527204e-02*S143+0.000000e+00*S144+9.105263e-02*S145+(-5.943524e-02)*S146+0.000000e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V103_part16='V103_part15+0.000000e+00*S150+0.000000e+00*S151+(-9.939961e-02)*S152+0.000000e+00*S153+4.907781e-01*S154+(-2.063155e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+1.178928e+00*S158+2.461066e-01*S159'
.param V103_part17='V103_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+1.406313e-01*S166+0.000000e+00*S167+1.584015e-01*S168+0.000000e+00*S169'
.param V103_part18='V103_part17+0.000000e+00*S170+(-2.420478e-01)*S171+(-3.136997e-02)*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+(-3.964985e-01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V103_part19='V103_part18+0.000000e+00*S180+0.000000e+00*S181+5.140522e-04*S182+1.173995e-01*S183+7.803276e-02*S184+5.283337e-02*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V103_part20='V103_part19+0.000000e+00*S190+3.827252e-01*S191+4.591215e-01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+2.281376e+03*S196+0.000000e+00*S197+4.434363e-01*S198+0.000000e+00*S199'
.param V103_part21='V103_part20+0.000000e+00*S200+7.450767e-02*S201+0.000000e+00*S202+0.000000e+00*S203+4.911213e-01*S204+4.238457e-01*S205+2.998453e-01*S206+0.000000e+00*S207+0.000000e+00*S208+3.282003e-01*S209'
.param V103_part22='V103_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+2.710634e-01*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V103_part23='V103_part22+0.000000e+00*S220+3.471230e-03*S221+3.525366e-01*S222+(-6.311400e-02)*S223+0.000000e+00*S224+2.753473e-02*S225+0.000000e+00*S226+2.964902e-01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V103_part24='V103_part23+2.351432e-01*S230+2.681130e-01*S231+0.000000e+00*S232+0.000000e+00*S233+(-3.394967e+02)*S234+3.295955e-01*S235+0.000000e+00*S236+(-1.481811e-01)*S237+5.254848e-01*S238+0.000000e+00*S239'
.param V103_part25='V103_part24+(-3.072487e+02)*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+3.921225e+00*S249'
.param V103_part26='V103_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+8.966820e-01*S253+0.000000e+00*S254+(-2.116348e-02)*S255+1.768732e-02*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V103_part27='V103_part26+0.000000e+00*S260+1.044989e-01*S261+0.000000e+00*S262+0.000000e+00*S263+(-3.182303e-01)*S264+0.000000e+00*S265+(-1.461497e-02)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V103_part28='V103_part27+0.000000e+00*S270+8.095509e-02*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+9.028933e-01*S275+4.004747e+00*S276+1.561364e-01*S277+(-3.676554e-01)*S278+6.351336e-01*S279'
.param V103_part29='V103_part28+0.000000e+00*S280+2.773353e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+8.889215e-02*S286+0.000000e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V103_part30='V103_part29+5.248391e-01*S290+2.234207e+00*S291+3.705511e-01*S292+(-7.605078e-02)*S293+1.243365e+00*S294+4.677120e-01*S295+0.000000e+00*S296+0.000000e+00*S297+4.776420e-01*S298+0.000000e+00*S299'
.param V103_part31='V103_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+3.223320e-01*S307+0.000000e+00*S308+1.836713e+00*S309'
.param V103='V103_part31+8.834946e-01*S310+0.000000e+00*S311+1.333350e+00*S312+7.942272e-01*S313+0.000000e+00*S314'
.param V104_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+1.497704e+03*S9'
.param V104_part2='V104_part1+4.175546e-03*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V104_part3='V104_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V104_part4='V104_part3+1.855803e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+1.000000e+04*S38+0.000000e+00*S39'
.param V104_part5='V104_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+(-2.539021e-03)*S46+0.000000e+00*S47+6.857577e+00*S48+(-6.828512e-02)*S49'
.param V104_part6='V104_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V104_part7='V104_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+1.297549e-02*S65+0.000000e+00*S66+(-9.005773e-02)*S67+0.000000e+00*S68+(-1.088036e-01)*S69'
.param V104_part8='V104_part7+(-1.165951e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-4.440943e-02)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V104_part9='V104_part8+0.000000e+00*S80+0.000000e+00*S81+2.786249e-02*S82+(-7.859349e-03)*S83+2.333727e-03*S84+0.000000e+00*S85+(-3.112406e-02)*S86+(-7.988833e-02)*S87+(-2.628464e-02)*S88+0.000000e+00*S89'
.param V104_part10='V104_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+4.016216e-02*S94+2.804637e-01*S95+(-4.787489e+01)*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V104_part11='V104_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+2.786128e-03*S105+0.000000e+00*S106+0.000000e+00*S107+(-3.241911e-02)*S108+(-5.603960e-02)*S109'
.param V104_part12='V104_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-4.902923e-02)*S115+0.000000e+00*S116+0.000000e+00*S117+(-2.014459e-01)*S118+0.000000e+00*S119'
.param V104_part13='V104_part12+1.401727e+03*S120+0.000000e+00*S121+4.394369e-02*S122+0.000000e+00*S123+0.000000e+00*S124+(-8.554795e-03)*S125+(-1.090211e-01)*S126+(-1.625967e-01)*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V104_part14='V104_part13+(-1.259914e-01)*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+9.219680e-03*S137+1.325260e-02*S138+(-1.548535e-02)*S139'
.param V104_part15='V104_part14+(-1.341238e-01)*S140+1.682830e-02*S141+(-2.118112e-01)*S142+1.189012e-02*S143+0.000000e+00*S144+(-2.706781e-03)*S145+2.161287e-02*S146+0.000000e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V104_part16='V104_part15+0.000000e+00*S150+0.000000e+00*S151+1.980982e-01*S152+0.000000e+00*S153+(-9.706194e-02)*S154+(-1.076337e-02)*S155+0.000000e+00*S156+0.000000e+00*S157+(-3.991617e-01)*S158+(-2.884161e-01)*S159'
.param V104_part17='V104_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+(-6.416412e-02)*S166+0.000000e+00*S167+(-7.281943e-02)*S168+0.000000e+00*S169'
.param V104_part18='V104_part17+0.000000e+00*S170+(-4.106486e-02)*S171+(-1.267579e-01)*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+(-6.216902e-01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V104_part19='V104_part18+0.000000e+00*S180+0.000000e+00*S181+(-1.045127e-02)*S182+6.141084e-02*S183+(-1.185405e-01)*S184+(-6.318289e-02)*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V104_part20='V104_part19+0.000000e+00*S190+(-1.619304e-01)*S191+(-4.411895e-01)*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+(-9.999878e+03)*S196+0.000000e+00*S197+(-1.350466e-01)*S198+0.000000e+00*S199'
.param V104_part21='V104_part20+0.000000e+00*S200+7.050830e-02*S201+0.000000e+00*S202+0.000000e+00*S203+(-4.606487e-01)*S204+(-1.821085e-01)*S205+(-4.957926e-01)*S206+0.000000e+00*S207+0.000000e+00*S208+(-9.794193e-02)*S209'
.param V104_part22='V104_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+(-3.130417e-02)*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V104_part23='V104_part22+0.000000e+00*S220+(-1.437865e-02)*S221+(-4.874556e-01)*S222+(-3.935089e-02)*S223+0.000000e+00*S224+(-5.186321e-02)*S225+0.000000e+00*S226+(-2.355709e-01)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V104_part24='V104_part23+(-1.076389e-01)*S230+(-2.903270e-01)*S231+0.000000e+00*S232+0.000000e+00*S233+2.065291e+02*S234+(-2.243309e-01)*S235+0.000000e+00*S236+(-6.780379e-02)*S237+(-2.667885e-01)*S238+0.000000e+00*S239'
.param V104_part25='V104_part24+1.000000e+04*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+(-9.842361e-01)*S249'
.param V104_part26='V104_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+1.420746e-01*S253+0.000000e+00*S254+2.332403e-02*S255+8.427613e-02*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V104_part27='V104_part26+0.000000e+00*S260+(-6.081960e-01)*S261+0.000000e+00*S262+0.000000e+00*S263+(-4.732455e-01)*S264+0.000000e+00*S265+(-5.844380e-01)*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V104_part28='V104_part27+0.000000e+00*S270+1.500155e-01*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+2.648174e-01*S275+(-1.139494e+00)*S276+(-3.807119e-01)*S277+1.488241e-01*S278+(-4.201340e-01)*S279'
.param V104_part29='V104_part28+0.000000e+00*S280+(-6.252687e-01)*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+(-8.378897e-02)*S286+0.000000e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V104_part30='V104_part29+1.463743e-01*S290+(-3.064509e-01)*S291+9.733286e-02*S292+(-1.040011e-01)*S293+(-1.909639e-01)*S294+1.368415e-01*S295+0.000000e+00*S296+0.000000e+00*S297+(-5.858081e-01)*S298+0.000000e+00*S299'
.param V104_part31='V104_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+0.000000e+00*S305+0.000000e+00*S306+3.868726e-03*S307+0.000000e+00*S308+(-4.661480e-01)*S309'
.param V104='V104_part31+2.589230e-01*S310+0.000000e+00*S311+(-9.038237e-01)*S312+(-1.993256e-01)*S313+0.000000e+00*S314'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='V30+V31*rad_+V32*w_'
.param _P23='_P22+V33*gdis_+V34*spacing_'
.param _P24='0.5*(_P23+sqrt(_P23*_P23+0.001))'
.param _P25='V35+V36*rad_+V37*w_'
.param _P26='_P25+V38*gdis_+V39*spacing_'
.param _P27='0.5*(_P26+sqrt(_P26*_P26+0.001))'
.param _P28='V40+V41*rad_+V42*w_'
.param _P29='_P28+V43*gdis_+V44*spacing_'
.param _P30='0.5*(_P29+sqrt(_P29*_P29+0.001))'
.param _P31='V45+V46*rad_+V47*w_'
.param _P32='_P31+V48*gdis_+V49*spacing_'
.param _P33='0.5*(_P32+sqrt(_P32*_P32+0.001))'
.param _P34='V50+V51*rad_+V52*w_'
.param _P35='_P34+V53*gdis_+V54*spacing_'
.param _P36='0.5*(_P35+sqrt(_P35*_P35+0.001))'
.param _P37='V55+V56*rad_+V57*w_'
.param _P38='_P37+V58*gdis_+V59*spacing_'
.param _P39='0.5*(_P38+sqrt(_P38*_P38+0.001))'
.param _P40='V60+V61*rad_+V62*w_'
.param _P41='_P40+V63*gdis_+V64*spacing_'
.param _P42='0.5*(_P41+sqrt(_P41*_P41+0.001))'
.param _P43='V65+V66*rad_+V67*w_'
.param _P44='_P43+V68*gdis_+V69*spacing_'
.param _P45='0.5*(_P44+sqrt(_P44*_P44+0.001))'
.param _P46='V70+V71*rad_+V72*w_'
.param _P47='_P46+V73*gdis_+V74*spacing_'
.param _P48='0.5*(_P47+sqrt(_P47*_P47+0.001))'
.param _P49='1e-14*_P24'
.param _P50='100*_P27'
.param _P51='1e-15*_P30'
.param _P52='1e-14*_P33'
.param _P53='100*_P36'
.param _P54='1e-15*_P39'
.param _P55='1e-14*_P42'
.param _P56='100*_P45'
.param _P57='1e-15*_P48'
.param _P58='V75+V76*rad_+V77*w_'
.param _P59='_P58+V78*gdis_+V79*spacing_'
.param _P60='0.5*(_P59+sqrt(_P59*_P59+0.001))'
.param _P61='V80+V81*rad_+V82*w_'
.param _P62='_P61+V83*gdis_+V84*spacing_'
.param _P63='0.5*(_P62+sqrt(_P62*_P62+0.001))'
.param _P64='100*_P60'
.param _P65='1e-13*_P63'
.param _P66='V85+V86*rad_+V87*w_'
.param _P67='_P66+V88*gdis_+V89*spacing_'
.param _P68='0.5*(_P67+sqrt(_P67*_P67+0.001))'
.param _P69='V90+V91*rad_+V92*w_'
.param _P70='_P69+V93*gdis_+V94*spacing_'
.param _P71='0.5*(_P70+sqrt(_P70*_P70+0.001))'
.param _P72='100*_P68'
.param _P73='1e-13*_P71'
.param _P74='V95+V96*rad_+V97*w_'
.param _P75='_P74+V98*gdis_+V99*spacing_'
.param _P76='0.5*(_P75+sqrt(_P75*_P75+0.001))'
.param _P77='V100+V101*rad_+V102*w_'
.param _P78='_P77+V103*gdis_+V104*spacing_'
.param _P79='0.5*(_P78+sqrt(_P78*_P78+0.001))'
.param _P80='100*_P76'
.param _P81='1e-13*_P79'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P21
k2 ls2_1 ls1_2 K=_P21
c_1_sub top _n1_1_sub '_P49*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P50*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P51* csub_indfac'
c_2_sub bottom _n1_2_sub '_P52*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P53*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P54* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P55*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P56*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_3_sub _n1_3_sub gnode '_P57* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P64*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P65* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P72*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P73* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P80*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P81* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_std_mu_a
*
*
*
.subckt spiral_sym_mu_a top bottom gnode rad=6e-05 w=9e-06 nr=1 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-50)' spacing_='0.5*(spacing/1e-06*scale-3)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-1.616941e+00)*S18+0.000000e+00*S19'
.param V0_part3='V0_part2+(-2.122160e+01)*S20+(-6.231436e+00)*S21+(-1.071658e+01)*S22+(-9.806923e-01)*S23+(-5.300634e+00)*S24+(-6.707620e+00)*S25+(-7.483462e+00)*S26+0.000000e+00*S27+(-4.081322e-01)*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+0.000000e+00*S30+0.000000e+00*S31+(-2.338206e+01)*S32+(-6.224589e+00)*S33+0.000000e+00*S34+(-2.782042e+01)*S35+(-2.602533e+00)*S36+(-7.026158e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V0_part5='V0_part4+1.609316e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-9.092068e+00)*S45+(-2.281057e+00)*S46+(-4.306421e+01)*S47+4.678404e+00*S48+(-1.418855e+01)*S49'
.param V0_part6='V0_part5+(-4.180161e+01)*S50+(-2.021080e+01)*S51+(-6.253413e+01)*S52+(-1.490213e+01)*S53+(-3.152444e+01)*S54+(-2.213124e+01)*S55+(-6.114519e+01)*S56+(-3.566013e+01)*S57+(-3.036507e+00)*S58+(-1.310060e+02)*S59'
.param V0_part7='V0_part6+(-1.744800e+01)*S60+1.612704e+01*S61+(-2.160135e+01)*S62+(-3.407581e+01)*S63+0.000000e+00*S64+0.000000e+00*S65+(-4.858058e+01)*S66+(-1.133276e+02)*S67+0.000000e+00*S68+(-5.894739e+01)*S69'
.param V0_part8='V0_part7+(-4.236525e+01)*S70+1.656793e+01*S71+(-6.780839e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+1.465148e+01*S75+(-1.595253e+01)*S76+(-1.185577e+01)*S77+1.714780e+01*S78+(-4.053265e-01)*S79'
.param V0='V0_part8+(-4.106949e+01)*S80+1.591164e+01*S81+2.252018e+00*S82+(-2.405590e+01)*S83+1.606207e+01*S84+(-1.447897e+01)*S85+(-4.377800e+01)*S86+5.255318e+00*S87+(-2.582502e+01)*S88+(-5.339411e+01)*S89'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.512352e+01*S18+0.000000e+00*S19'
.param V1_part3='V1_part2+3.585214e+01*S20+2.281949e+01*S21+2.992699e+01*S22+1.826251e+00*S23+1.525315e+01*S24+1.685604e+01*S25+1.018520e+01*S26+0.000000e+00*S27+6.275909e+00*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+0.000000e+00*S30+0.000000e+00*S31+6.254126e+01*S32+3.609984e+01*S33+0.000000e+00*S34+5.382210e+01*S35+3.403161e+01*S36+4.293577e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V1_part5='V1_part4+2.857709e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+8.431277e+01*S45+5.270399e+01*S46+9.362074e+01*S47+2.993146e+01*S48+6.669240e+01*S49'
.param V1_part6='V1_part5+8.880821e+01*S50+3.007118e+01*S51+6.919383e+01*S52+7.469584e+01*S53+4.143117e+01*S54+5.904571e+01*S55+9.205381e+01*S56+3.436708e+01*S57+4.177427e+01*S58+6.790421e+01*S59'
.param V1_part7='V1_part6+8.939432e+01*S60+1.235983e+02*S61+8.129494e+01*S62+9.543942e+01*S63+0.000000e+00*S64+0.000000e+00*S65+1.038331e+02*S66+1.003731e+02*S67+0.000000e+00*S68+1.007829e+02*S69'
.param V1_part8='V1_part7+9.227184e+01*S70+8.168142e+01*S71+1.001835e+02*S72+0.000000e+00*S73+0.000000e+00*S74+4.476860e+01*S75+1.397949e+02*S76+1.506115e+02*S77+4.403525e+01*S78+8.962783e+01*S79'
.param V1='V1_part8+1.439864e+02*S80+4.958012e+01*S81+8.363947e+01*S82+1.232246e+02*S83+5.075196e+01*S84+8.321117e+01*S85+1.442193e+02*S86+6.207582e+01*S87+8.139528e+01*S88+1.150292e+02*S89'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-3.147245e-01)*S18+0.000000e+00*S19'
.param V2_part3='V2_part2+2.305811e+01*S20+2.618846e+00*S21+1.330608e+01*S22+1.242333e+01*S23+8.321579e+00*S24+2.897551e+01*S25+1.369933e+01*S26+0.000000e+00*S27+3.448355e+00*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+0.000000e+00*S30+0.000000e+00*S31+6.037622e+01*S32+3.535525e+01*S33+0.000000e+00*S34+6.756349e+01*S35+(-4.257288e+00)*S36+4.482916e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V2_part5='V2_part4+(-3.185125e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+1.360251e+00*S45+5.129425e+01*S46+9.012411e+01*S47+6.458194e+00*S48+9.072667e+01*S49'
.param V2_part6='V2_part5+1.174749e+02*S50+6.935637e+01*S51+1.259083e+02*S52+9.709118e+00*S53+9.118519e+01*S54+1.025260e+02*S55+1.345135e+02*S56+1.181398e+02*S57+8.042986e+01*S58+1.700236e+02*S59'
.param V2_part7='V2_part6+8.155978e+01*S60+(-3.930879e+01)*S61+3.016539e+01*S62+9.409757e+01*S63+0.000000e+00*S64+0.000000e+00*S65+8.687090e+01*S66+2.277104e+02*S67+0.000000e+00*S68+8.558158e+01*S69'
.param V2_part8='V2_part7+4.886136e+01*S70+(-5.743097e+01)*S71+7.469548e+01*S72+0.000000e+00*S73+0.000000e+00*S74+2.933870e+01*S75+3.857437e+01*S76+1.358018e+02*S77+2.736251e+01*S78+1.063596e+01*S79'
.param V2='V2_part8+2.141673e+02*S80+2.167205e+01*S81+(-1.191562e+01)*S82+2.069067e+02*S83+1.092223e+01*S84+1.855813e+02*S85+2.104320e+02*S86+(-1.017442e+00)*S87+2.159573e+02*S88+2.110727e+02*S89'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-4.242618e-02)*S18+0.000000e+00*S19'
.param V3_part3='V3_part2+(-1.526967e+00)*S20+(-5.041480e-01)*S21+4.891705e-02*S22+(-6.275797e-01)*S23+(-9.232820e-01)*S24+1.681347e+00*S25+(-5.311537e-01)*S26+0.000000e+00*S27+(-2.478256e+00)*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+0.000000e+00*S30+0.000000e+00*S31+2.301367e+00*S32+2.955079e+00*S33+0.000000e+00*S34+1.198401e+00*S35+(-4.435453e-01)*S36+3.042374e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V3_part5='V3_part4+9.809033e-01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-1.774964e-01)*S45+(-1.289430e+00)*S46+2.348557e+00*S47+(-1.756810e+00)*S48+1.854318e+00*S49'
.param V3_part6='V3_part5+2.400312e+00*S50+(-1.913506e-01)*S51+2.899818e+00*S52+(-9.643562e-01)*S53+2.145026e-01*S54+5.938203e+00*S55+6.236850e+00*S56+3.641727e-01*S57+4.351817e+00*S58+(-1.765228e+00)*S59'
.param V3_part7='V3_part6+1.526536e+00*S60+(-8.573768e-01)*S61+(-4.223169e+00)*S62+(-1.096853e+00)*S63+0.000000e+00*S64+0.000000e+00*S65+(-1.411168e+00)*S66+6.325767e-01*S67+0.000000e+00*S68+(-1.462539e+00)*S69'
.param V3_part8='V3_part7+3.065280e+00*S70+1.369842e+00*S71+(-7.675850e-01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.144188e+00)*S75+(-3.304477e-01)*S76+3.647906e+00*S77+(-7.814016e-01)*S78+(-3.630556e+00)*S79'
.param V3='V3_part8+3.796331e+00*S80+(-7.648184e-01)*S81+(-5.430654e+00)*S82+4.121787e+00*S83+(-2.767996e-01)*S84+7.605369e+00*S85+5.880112e+00*S86+1.399256e-02*S87+7.701860e+00*S88+5.848995e+00*S89'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-4.067536e+00)*S18+0.000000e+00*S19'
.param V4_part3='V4_part2+(-5.331472e+00)*S20+(-5.235189e+00)*S21+(-4.425146e+00)*S22+(-7.232966e+00)*S23+(-5.782162e+00)*S24+(-6.793641e+00)*S25+(-8.015491e+00)*S26+0.000000e+00*S27+(-8.020659e+00)*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.181034e+01)*S32+(-1.021993e+01)*S33+0.000000e+00*S34+(-1.402550e+01)*S35+(-1.535807e+01)*S36+(-1.272599e+01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V4_part5='V4_part4+(-1.936117e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-1.537596e+01)*S45+(-1.343231e+01)*S46+(-2.084725e+01)*S47+(-1.476890e+01)*S48+(-1.725642e+01)*S49'
.param V4_part6='V4_part5+(-2.733481e+01)*S50+(-2.335393e+01)*S51+(-1.975274e+01)*S52+(-1.299985e+01)*S53+(-2.283312e+01)*S54+(-2.977646e+01)*S55+(-3.709257e+01)*S56+(-2.661333e+01)*S57+(-3.240818e+01)*S58+(-4.826364e+01)*S59'
.param V4_part7='V4_part6+(-1.478160e+01)*S60+(-4.612781e+00)*S61+(-4.146446e+01)*S62+(-2.519191e+01)*S63+0.000000e+00*S64+0.000000e+00*S65+(-3.189376e+01)*S66+(-3.612200e+01)*S67+0.000000e+00*S68+(-3.752975e+01)*S69'
.param V4_part8='V4_part7+(-3.530283e+01)*S70+(-3.642093e+01)*S71+(-4.257504e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.669331e+01)*S75+(-5.326299e+01)*S76+(-1.906354e+01)*S77+(-2.469723e+01)*S78+(-5.443833e+01)*S79'
.param V4='V4_part8+(-4.329525e+01)*S80+(-3.189724e+01)*S81+(-5.849424e+01)*S82+(-4.671308e+01)*S83+(-3.832810e+01)*S84+(-5.328204e+01)*S85+(-5.339755e+01)*S86+(-4.487552e+01)*S87+(-6.078435e+01)*S88+(-7.507625e+01)*S89'
.param V5_part1='(-1.240189e-02)*S0+2.256409e-01*S1+6.745088e-03*S2+(-4.233731e-02)*S3+(-2.424198e-02)*S4+(-6.672390e-03)*S5+(-6.867911e-02)*S6+4.536667e-01*S7+(-2.057200e-02)*S8+4.688557e-01*S9'
.param V5_part2='V5_part1+1.233548e+00*S10+(-2.613194e-02)*S11+5.397177e-01*S12+(-7.723883e-02)*S13+(-1.387686e-01)*S14+(-4.674247e-02)*S15+3.900476e-01*S16+(-6.303609e-02)*S17+2.626172e-02*S18+5.925188e+00*S19'
.param V5_part3='V5_part2+2.043507e-01*S20+2.311647e-01*S21+(-1.049324e-01)*S22+1.834493e+00*S23+(-6.166796e-02)*S24+(-3.990920e-01)*S25+5.319551e-03*S26+(-1.315709e-01)*S27+(-2.361930e-01)*S28+2.749425e-01*S29'
.param V5_part4='V5_part3+1.485150e+00*S30+1.132604e-01*S31+5.678173e-01*S32+1.328579e-01*S33+9.085066e-01*S34+1.565880e-01*S35+(-9.046870e-04)*S36+(-1.366754e-01)*S37+1.573755e-01*S38+(-3.398307e-02)*S39'
.param V5_part5='V5_part4+(-7.826581e-02)*S40+1.362889e-01*S41+(-2.086470e+00)*S42+5.920925e+00*S43+3.238479e-01*S44+2.882429e-01*S45+(-1.633390e-01)*S46+3.568113e-01*S47+2.425007e-01*S48+(-3.290443e-01)*S49'
.param V5_part6='V5_part5+2.371991e-01*S50+2.189902e-01*S51+(-2.504027e-01)*S52+4.796561e-01*S53+1.338791e-01*S54+(-1.044557e-01)*S55+2.565033e-01*S56+3.588667e-02*S57+(-1.153013e+01)*S58+1.076809e-01*S59'
.param V5_part7='V5_part6+4.048153e-01*S60+2.776667e-01*S61+4.616622e-01*S62+2.532280e-01*S63+(-4.332714e-01)*S64+5.123389e-01*S65+8.785802e-02*S66+(-1.379032e-01)*S67+3.390798e-01*S68+(-9.371257e-02)*S69'
.param V5_part8='V5_part7+2.929463e+01*S70+2.277656e-01*S71+(-2.625481e-01)*S72+6.661000e-02*S73+1.635507e-01*S74+4.940415e-01*S75+(-7.928676e-01)*S76+1.314060e+00*S77+3.779257e-01*S78+4.689478e+00*S79'
.param V5='V5_part8+1.663450e+00*S80+2.182574e-01*S81+1.430824e+01*S82+1.559915e+00*S83+5.222255e-02*S84+2.266179e+01*S85+2.719397e+00*S86+(-1.492582e-01)*S87+2.078059e+01*S88+1.996249e+00*S89'
.param V6_part1='1.806330e-01*S0+6.771317e+00*S1+7.227951e-02*S2+1.854343e-01*S3+1.286905e-01*S4+7.358263e-02*S5+1.843447e-01*S6+(-1.867496e-01)*S7+7.945467e-02*S8+(-3.701407e-01)*S9'
.param V6_part2='V6_part1+(-3.662163e-01)*S10+7.206934e-02*S11+(-2.891682e-01)*S12+1.253699e-01*S13+(-4.296124e-01)*S14+(-1.673261e+00)*S15+(-2.681004e+00)*S16+4.171468e-01*S17+6.043391e-01*S18+(-4.507026e+00)*S19'
.param V6_part3='V6_part2+3.257790e-01*S20+(-1.610527e+00)*S21+2.777087e-01*S22+(-8.106740e-01)*S23+3.097724e-01*S24+5.235785e-01*S25+1.261228e-01*S26+3.481713e-01*S27+1.114605e-01*S28+1.116040e-01*S29'
.param V6_part4='V6_part3+(-3.925203e+00)*S30+(-6.142059e+00)*S31+3.139617e-01*S32+3.708185e-01*S33+(-8.213607e+00)*S34+6.945882e-01*S35+1.427410e+00*S36+3.238191e-01*S37+1.820834e-01*S38+4.715175e-01*S39'
.param V6_part5='V6_part4+2.541897e-01*S40+3.162664e-01*S41+1.263506e+00*S42+(-1.183719e+01)*S43+1.868570e-01*S44+5.483366e-01*S45+1.294906e-01*S46+5.664885e-02*S47+5.512181e-01*S48+2.589065e-02*S49'
.param V6_part6='V6_part5+2.246347e-01*S50+4.073268e-01*S51+(-6.371852e-02)*S52+(-5.164816e-01)*S53+4.130395e-01*S54+(-7.527253e-02)*S55+2.289888e-01*S56+3.973923e-01*S57+6.302507e+00*S58+2.060547e-01*S59'
.param V6_part7='V6_part6+1.000544e+00*S60+5.319220e-01*S61+8.066555e-03*S62+9.676089e-01*S63+(-1.983399e+01)*S64+2.846877e-01*S65+9.611595e-01*S66+(-2.982066e-01)*S67+4.277510e-01*S68+9.679600e-01*S69'
.param V6_part8='V6_part7+9.634407e+00*S70+4.374428e-01*S71+9.900884e-01*S72+1.890515e-01*S73+4.332972e-01*S74+1.131216e+00*S75+(-2.479678e+01)*S76+2.516057e+00*S77+1.000128e+00*S78+(-3.591235e+01)*S79'
.param V6='V6_part8+1.664949e+00*S80+9.783359e-01*S81+(-4.684366e+01)*S82+1.222449e+00*S83+9.289195e-01*S84+(-6.381334e+01)*S85+8.911554e-01*S86+9.384589e-01*S87+(-4.373609e+01)*S88+1.340741e+00*S89'
.param V7_part1='2.168667e-02*S0+2.043440e+00*S1+2.333672e-02*S2+3.053067e-02*S3+3.031065e-02*S4+3.257426e-02*S5+3.770050e-02*S6+4.642099e-01*S7+4.400165e-02*S8+3.729388e-01*S9'
.param V7_part2='V7_part1+1.036831e+00*S10+5.277216e-02*S11+3.956409e-01*S12+5.723213e-02*S13+1.122855e+00*S14+8.108718e-01*S15+6.407153e-01*S16+2.705250e-01*S17+4.353092e-02*S18+1.245765e-01*S19'
.param V7_part3='V7_part2+1.080947e-02*S20+1.576467e+00*S21+6.275802e-01*S22+1.061056e+00*S23+9.080409e-02*S24+2.019106e-01*S25+9.880751e-02*S26+1.075077e-01*S27+2.238651e-01*S28+1.763384e+00*S29'
.param V7_part4='V7_part3+5.017549e+00*S30+2.171872e+00*S31+(-1.251020e-02)*S32+8.975248e-02*S33+3.131288e+00*S34+(-7.155403e-03)*S35+3.022515e-01*S36+2.182523e-01*S37+8.442999e-02*S38+1.348519e-01*S39'
.param V7_part5='V7_part4+2.242998e-01*S40+9.934329e-02*S41+1.837607e+00*S42+6.516062e+00*S43+6.767629e-02*S44+8.803093e-02*S45+3.124799e-01*S46+3.482208e-02*S47+1.110461e-01*S48+4.207191e-01*S49'
.param V7_part6='V7_part5+7.873674e-02*S50+1.473576e-01*S51+4.528972e-01*S52+6.580070e-01*S53+1.830093e-01*S54+4.455608e-01*S55+3.935320e-02*S56+2.270663e-01*S57+7.786777e+00*S58+1.982939e-01*S59'
.param V7_part7='V7_part6+9.730781e-02*S60+1.942478e-01*S61+2.928322e-01*S62+1.402500e-01*S63+1.078855e+01*S64+1.246194e-02*S65+1.837484e-01*S66+5.812851e-01*S67+9.164053e-02*S68+2.306261e-01*S69'
.param V7_part8='V7_part7+(-7.607076e+00)*S70+1.261305e-01*S71+2.773475e-01*S72+4.166979e-01*S73+2.879534e-01*S74+1.319043e-01*S75+1.067090e+01*S76+(-3.810251e-01)*S77+1.784350e-01*S78+1.358924e+01*S79'
.param V7='V7_part8+(-2.065080e-01)*S80+2.305137e-01*S81+1.678431e+01*S82+(-1.415089e-01)*S83+2.924352e-01*S84+2.669901e+01*S85+(-1.419806e-02)*S86+3.539636e-01*S87+2.552742e+01*S88+1.004677e+00*S89'
.param V8_part1='2.372911e-02*S0+2.673754e-01*S1+1.177690e-02*S2+2.322303e-02*S3+1.663413e-02*S4+1.065368e-02*S5+2.190343e-02*S6+2.715483e-01*S7+1.001990e-02*S8+2.198255e-01*S9'
.param V8_part2='V8_part1+5.495551e-01*S10+1.007450e-02*S11+2.496036e-01*S12+1.427335e-02*S13+(-2.353010e-01)*S14+(-6.110611e-03)*S15+8.205500e-02*S16+(-1.214232e-02)*S17+2.890719e-02*S18+(-1.368325e-01)*S19'
.param V8_part3='V8_part2+2.023243e-02*S20+1.932050e-01*S21+3.131155e-03*S22+(-1.209270e-01)*S23+2.055269e-02*S24+(-3.590820e-05)*S25+6.383570e-03*S26+1.966300e-02*S27+(-8.920879e-04)*S28+2.140185e-01*S29'
.param V8_part4='V8_part3+(-1.061997e+00)*S30+(-2.311262e-02)*S31+(-1.285598e-02)*S32+1.368742e-02*S33+4.674450e-02*S34+5.785348e-03*S35+(-1.261180e-01)*S36+1.803626e-02*S37+1.137607e-02*S38+2.713536e-02*S39'
.param V8_part5='V8_part4+2.013377e-02*S40+2.256003e-03*S41+(-4.441269e-01)*S42+2.877688e-01*S43+(-1.528404e-03)*S44+1.660976e-02*S45+4.668020e-03*S46+(-1.407829e-02)*S47+1.883881e-02*S48+8.144586e-03*S49'
.param V8_part6='V8_part5+(-4.441051e-04)*S50+7.684166e-03*S51+1.412609e-02*S52+1.418725e-02*S53+6.845524e-03*S54+2.203698e-02*S55+(-6.824638e-03)*S56+9.610339e-04*S57+(-3.582207e-01)*S58+(-2.759336e-03)*S59'
.param V8_part7='V8_part6+3.243178e-02*S60+2.653445e-02*S61+(-4.816646e-03)*S62+3.601538e-02*S63+7.036767e-01*S64+(-6.752997e-03)*S65+4.265105e-02*S66+3.131909e-02*S67+(-7.513155e-03)*S68+5.022821e-02*S69'
.param V8_part8='V8_part7+1.991065e-01*S70+4.073347e-03*S71+6.261055e-02*S72+2.129067e-02*S73+(-1.381612e-02)*S74+6.265901e-03*S75+7.158174e-01*S76+(-1.534226e-02)*S77+2.390199e-03*S78+1.063250e+00*S79'
.param V8='V8_part8+1.115712e-02*S80+(-1.005914e-02)*S81+1.191510e+00*S82+(-5.602173e-02)*S83+(-3.301313e-02)*S84+9.449526e-01*S85+(-6.618262e-02)*S86+(-4.352246e-02)*S87+5.340188e-01*S88+(-2.244587e-01)*S89'
.param V9_part1='2.799395e-03*S0+9.950735e-02*S1+8.969158e-04*S2+2.261983e-03*S3+1.001437e-03*S4+7.880025e-04*S5+1.972268e-03*S6+(-2.258426e-02)*S7+9.500716e-04*S8+(-4.370538e-02)*S9'
.param V9_part2='V9_part1+(-3.913036e-02)*S10+7.751982e-04*S11+(-4.575382e-02)*S12+1.073329e-03*S13+(-5.163260e-03)*S14+(-1.230968e-01)*S15+(-2.016849e-02)*S16+(-2.092697e-02)*S17+1.928311e-02*S18+(-5.904619e-02)*S19'
.param V9_part3='V9_part2+1.159920e-02*S20+(-1.664558e-01)*S21+(-1.708371e-02)*S22+(-1.210700e-01)*S23+1.484888e-02*S24+1.532404e-02*S25+2.115053e-03*S26+1.691912e-02*S27+1.540799e-03*S28+(-2.126253e-02)*S29'
.param V9_part4='V9_part3+(-5.279774e-01)*S30+(-1.401107e-01)*S31+1.747871e-02*S32+1.803802e-02*S33+(-3.344696e-01)*S34+3.082278e-02*S35+(-2.674135e-02)*S36+1.717342e-02*S37+6.230554e-03*S38+2.368355e-02*S39'
.param V9_part5='V9_part4+1.341208e-02*S40+2.006653e-02*S41+(-4.751228e-01)*S42+(-8.709249e-03)*S43+(-1.664983e-03)*S44+3.176641e-02*S45+2.478178e-02*S46+1.104043e-02*S47+3.043177e-02*S48+(-1.331278e-02)*S49'
.param V9_part6='V9_part5+9.327501e-03*S50+3.428982e-02*S51+6.477795e-03*S52+(-2.043544e-03)*S53+4.564732e-02*S54+2.255853e-02*S55+2.293482e-02*S56+4.944926e-02*S57+1.302591e-02*S58+2.071375e-02*S59'
.param V9_part7='V9_part6+8.453839e-02*S60+5.541302e-02*S61+1.809862e-02*S62+9.828073e-02*S63+(-1.096896e+00)*S64+5.003681e-02*S65+1.122509e-01*S66+2.444576e-02*S67+4.496321e-02*S68+1.302654e-01*S69'
.param V9_part8='V9_part7+(-6.763572e-01)*S70+3.852132e-02*S71+1.480563e-01*S72+3.313574e-02*S73+1.476455e-01*S74+1.078033e-01*S75+(-4.542807e-01)*S76+8.020028e-02*S77+1.571780e-01*S78+1.088359e-01*S79'
.param V9='V9_part8+3.793660e-03*S80+2.220881e-01*S81+3.775594e-01*S82+9.512442e-02*S83+2.834867e-01*S84+(-1.188049e+00)*S85+1.295352e-01*S86+3.239827e-01*S87+(-7.537533e-01)*S88+2.391836e-02*S89'
.param V10_part1='2.095969e-02*S0+1.197793e-01*S1+2.416393e-02*S2+2.137746e-02*S3+2.083691e-02*S4+2.612097e-02*S5+2.064697e-02*S6+3.764988e-02*S7+2.773705e-02*S8+4.020421e-02*S9'
.param V10_part2='V10_part1+7.929984e-02*S10+2.825172e-02*S11+3.909555e-02*S12+1.627839e-02*S13+1.513703e-01*S14+8.918892e-02*S15+6.291719e-02*S16+1.691003e-02*S17+1.675270e-02*S18+(-4.476200e-02)*S19'
.param V10_part3='V10_part2+3.982880e-02*S20+1.840885e-01*S21+7.174746e-03*S22+1.456867e-02*S23+1.382948e-02*S24+(-5.903720e-02)*S25+5.353263e-02*S26+8.422852e-03*S27+(-4.830223e-02)*S28+4.610384e-01*S29'
.param V10_part4='V10_part3+1.807880e-01*S30+2.638842e-01*S31+4.332569e-02*S32+(-1.541205e-03)*S33+7.706071e-01*S34+1.030731e-01*S35+9.019653e-03*S36+(-1.613659e-02)*S37+9.905065e-02*S38+(-4.806924e-03)*S39'
.param V10_part5='V10_part4+(-4.122489e-02)*S40+9.525165e-02*S41+1.185932e-01*S42+2.167279e+00*S43+6.454030e-02*S44+6.049322e-02*S45+4.996964e-02*S46+2.173941e-01*S47+3.451181e-02*S48+(-4.040180e-02)*S49'
.param V10_part6='V10_part5+2.390678e-01*S50+(-2.321358e-02)*S51+(-1.002206e-01)*S52+9.113163e-01*S53+(-6.962273e-02)*S54+(-1.792827e-01)*S55+2.811551e-01*S56+(-1.531926e-01)*S57+9.395995e-01*S58+2.188162e-01*S59'
.param V10_part7='V10_part6+1.430768e-01*S60+2.747127e-01*S61+6.045629e-01*S62+1.103493e-01*S63+2.757039e+00*S64+3.706533e-01*S65+8.173058e-02*S66+(-1.315678e-01)*S67+4.210477e-01*S68+4.545388e-02*S69'
.param V10_part8='V10_part7+(-3.924978e-02)*S70+3.563886e-01*S71+8.073729e-03*S72+(-1.934743e-01)*S73+3.239048e-01*S74+2.025357e-01*S75+2.924064e+00*S76+4.225924e-01*S77+1.471503e-01*S78+5.089835e+00*S79'
.param V10='V10_part8+3.071825e-01*S80+9.504046e-02*S81+8.032321e+00*S82+2.748422e-01*S83+9.753277e-03*S84+9.571602e+00*S85+1.753125e-01*S86+(-4.352167e-02)*S87+1.054238e+01*S88+4.951827e-01*S89'
.param V11_part1='1.994354e-01*S0+4.807025e-01*S1+1.766232e-01*S2+2.203885e-01*S3+2.037861e-01*S4+1.811048e-01*S5+2.388909e-01*S6+2.159805e-01*S7+1.949941e-01*S8+2.356479e-01*S9'
.param V11_part2='V11_part1+2.441219e-01*S10+1.981344e-01*S11+2.477799e-01*S12+2.421637e-01*S13+2.174029e-01*S14+6.148306e-01*S15+5.844848e-01*S16+7.532555e-01*S17+8.008240e-01*S18+6.898168e-01*S19'
.param V11_part3='V11_part2+6.204712e-01*S20+7.663282e-01*S21+8.001002e-01*S22+9.765428e-01*S23+8.670620e-01*S24+9.629143e-01*S25+7.029259e-01*S26+8.988706e-01*S27+8.741532e-01*S28+9.897232e-01*S29'
.param V11_part4='V11_part3+3.431013e+00*S30+1.382404e+00*S31+1.272295e+00*S32+1.667119e+00*S33+1.151988e+00*S34+1.263720e+00*S35+1.699211e+00*S36+1.733355e+00*S37+1.395087e+00*S38+1.803797e+00*S39'
.param V11_part5='V11_part4+1.805164e+00*S40+1.432049e+00*S41+1.843984e+00*S42+1.136005e+00*S43+1.454648e+00*S44+2.431525e+00*S45+2.354599e+00*S46+2.179274e+00*S47+2.681923e+00*S48+2.669553e+00*S49'
.param V11_part6='V11_part5+2.224062e+00*S50+2.952402e+00*S51+2.835766e+00*S52+2.249716e+00*S53+3.122844e+00*S54+3.062471e+00*S55+2.527712e+00*S56+3.297768e+00*S57+3.595685e+00*S58+2.618283e+00*S59'
.param V11_part7='V11_part6+3.581402e+00*S60+3.485713e+00*S61+3.455617e+00*S62+3.935905e+00*S63+3.075115e+00*S64+3.290800e+00*S65+4.211111e+00*S66+4.194889e+00*S67+3.382961e+00*S68+4.443996e+00*S69'
.param V11_part8='V11_part7+3.353541e+00*S70+3.922328e+00*S71+4.619906e+00*S72+4.740907e+00*S73+3.746688e+00*S74+5.021468e+00*S75+4.113416e+00*S76+4.196706e+00*S77+5.511924e+00*S78+2.872842e+00*S79'
.param V11='V11_part8+4.659060e+00*S80+5.884875e+00*S81+1.936790e+00*S82+4.925351e+00*S83+6.216074e+00*S84+1.987241e+00*S85+5.298247e+00*S86+6.468501e+00*S87+3.794092e+00*S88+5.575636e+00*S89'
.param V12_part1='(-2.874384e-04)*S0+(-5.544548e-02)*S1+7.893156e-03*S2+(-2.305704e-02)*S3+(-3.933982e-03)*S4+3.784377e-03*S5+(-4.766723e-02)*S6+(-2.310730e-02)*S7+(-4.820630e-03)*S8+(-7.905718e-02)*S9'
.param V12_part2='V12_part1+(-4.826064e-02)*S10+(-1.267689e-02)*S11+(-9.788324e-02)*S12+(-4.873320e-02)*S13+(-8.659097e-02)*S14+(-4.445128e-02)*S15+2.000784e-02*S16+9.308356e-02*S17+1.057703e-02*S18+4.304219e-01*S19'
.param V12_part3='V12_part2+4.173288e-02*S20+(-2.214828e-01)*S21+(-1.009207e-02)*S22+5.076955e-02*S23+(-1.688180e-01)*S24+(-3.486691e-02)*S25+(-7.041482e-03)*S26+(-2.592531e-01)*S27+(-3.174577e-02)*S28+(-2.927662e-01)*S29'
.param V12_part4='V12_part3+4.330884e-01*S30+(-5.651360e-02)*S31+2.292600e-01*S32+1.841619e-01*S33+(-5.719677e-01)*S34+1.713084e-01*S35+(-1.108666e-01)*S36+1.122494e-01*S37+1.396728e-01*S38+(-1.858710e-01)*S39'
.param V12_part5='V12_part4+4.037562e-03*S40+8.641811e-02*S41+(-5.889978e-01)*S42+(-2.064406e+00)*S43+9.922690e-02*S44+6.723580e-01*S45+7.335359e-01*S46+5.835474e-01*S47+4.713229e-01*S48+7.259306e-01*S49'
.param V12_part6='V12_part5+5.478828e-01*S50+2.626706e-01*S51+5.810617e-01*S52+1.996988e-01*S53+2.816520e-03*S54+3.982900e-01*S55+3.194324e-01*S56+(-2.277406e-01)*S57+(-1.925310e+00)*S58+2.915404e-01*S59'
.param V12_part7='V12_part6+1.309385e+00*S60+1.223391e+00*S61+1.196484e+00*S62+1.030483e+00*S63+(-2.136014e+00)*S64+1.024951e+00*S65+6.803038e-01*S66+1.219099e+00*S67+9.182795e-01*S68+2.933762e-01*S69'
.param V12_part8='V12_part7+3.299660e+00*S70+9.037269e-01*S71+(-1.287489e-01)*S72+5.145020e-01*S73+6.850195e-01*S74+2.456262e+00*S75+(-1.377365e+00)*S76+1.977904e+00*S77+2.078772e+00*S78+(-3.353753e+00)*S79'
.param V12='V12_part8+1.907630e+00*S80+1.615801e+00*S81+(-5.815877e+00)*S82+1.782483e+00*S83+1.158916e+00*S84+(-6.898352e+00)*S85+1.653401e+00*S86+6.335250e-01*S87+(-9.027015e+00)*S88+1.170374e+00*S89'
.param V13_part1='1.992911e-02*S0+5.373218e-02*S1+1.824955e-02*S2+1.982845e-02*S3+1.958146e-02*S4+1.924471e-02*S5+2.010881e-02*S6+2.785796e-02*S7+2.027867e-02*S8+2.572184e-02*S9'
.param V13_part2='V13_part1+4.415436e-02*S10+1.901690e-02*S11+2.775147e-02*S12+1.946964e-02*S13+1.436077e-02*S14+2.118124e-02*S15+2.221971e-02*S16+2.298667e-02*S17+2.290229e-02*S18+2.536847e-02*S19'
.param V13_part3='V13_part2+2.076982e-02*S20+4.777546e-02*S21+2.702503e-02*S22+3.757072e-02*S23+2.000769e-02*S24+2.398485e-02*S25+2.263756e-02*S26+2.022877e-02*S27+2.642654e-02*S28+3.917292e-02*S29'
.param V13_part4='V13_part3+3.887681e-02*S30+2.316691e-02*S31+2.307271e-02*S32+2.469698e-02*S33+3.759921e-02*S34+2.384677e-02*S35+1.990434e-02*S36+1.921209e-02*S37+2.323105e-02*S38+2.045006e-02*S39'
.param V13_part5='V13_part4+1.889794e-02*S40+2.819855e-02*S41+6.619984e-03*S42+5.567171e-02*S43+2.952689e-02*S44+2.130959e-02*S45+2.439201e-02*S46+3.659280e-02*S47+2.157867e-02*S48+2.203193e-02*S49'
.param V13_part6='V13_part5+3.011199e-02*S50+2.404309e-02*S51+2.238443e-02*S52+3.963588e-02*S53+2.595490e-02*S54+1.944422e-02*S55+3.886934e-02*S56+2.800508e-02*S57+1.083791e-02*S58+3.424675e-02*S59'
.param V13_part7='V13_part6+1.866056e-02*S60+1.658018e-02*S61+4.270093e-02*S62+1.872869e-02*S63+7.365421e-02*S64+3.360019e-02*S65+1.728295e-02*S66+2.086361e-02*S67+3.320703e-02*S68+1.542727e-02*S69'
.param V13_part8='V13_part7+4.881672e-02*S70+2.445245e-02*S71+1.423956e-02*S72+1.694678e-02*S73+3.912978e-02*S74+2.355418e-02*S75+6.168838e-02*S76+3.646291e-02*S77+2.644411e-02*S78+1.032406e-01*S79'
.param V13='V13_part8+3.957679e-02*S80+3.083558e-02*S81+1.362427e-01*S82+4.224629e-02*S83+3.699282e-02*S84+1.434236e-01*S85+4.377028e-02*S86+3.986784e-02*S87+1.360618e-01*S88+5.352792e-02*S89'
.param V14_part1='4.022231e-03*S0+8.304213e-03*S1+3.024958e-03*S2+3.937368e-03*S3+3.499039e-03*S4+2.974989e-03*S5+3.983449e-03*S6+2.859515e-03*S7+3.031528e-03*S8+2.853439e-03*S9'
.param V14_part2='V14_part1+2.456960e-03*S10+3.009561e-03*S11+2.729106e-03*S12+3.516520e-03*S13+2.644481e-03*S14+9.808957e-03*S15+1.126417e-02*S16+1.068170e-02*S17+1.212993e-02*S18+7.859677e-03*S19'
.param V14_part3='V14_part2+1.303246e-02*S20+5.988002e-03*S21+1.397914e-02*S22+2.838880e-02*S23+6.947044e-03*S24+9.890549e-03*S25+1.101730e-02*S26+4.338551e-03*S27+9.387695e-03*S28+(-1.043032e-02)*S29'
.param V14_part4='V14_part3+1.686369e-01*S30+5.328276e-02*S31+4.112359e-02*S32+3.191085e-02*S33+2.910671e-02*S34+3.139044e-02*S35+2.731380e-02*S36+2.603005e-02*S37+2.877157e-02*S38+1.335297e-02*S39'
.param V14_part5='V14_part4+2.200160e-02*S40+2.760403e-02*S41+2.635735e-03*S42+4.506870e-02*S43+1.500093e-02*S44+6.765747e-02*S45+6.403996e-02*S46+6.821996e-02*S47+5.706056e-02*S48+6.967198e-02*S49'
.param V14_part6='V14_part5+6.421128e-02*S50+4.560338e-02*S51+5.996949e-02*S52+3.202471e-02*S53+2.910474e-02*S54+4.842371e-02*S55+5.437584e-02*S56+1.295183e-02*S57+8.212101e-02*S58+5.102960e-02*S59'
.param V14_part7='V14_part6+1.131262e-01*S60+1.233906e-01*S61+1.069516e-01*S62+9.294867e-02*S63+1.861768e-01*S64+8.845153e-02*S65+6.988251e-02*S66+1.023879e-01*S67+7.576714e-02*S68+4.325043e-02*S69'
.param V14_part8='V14_part7+3.405991e-02*S70+1.056703e-01*S71+1.306749e-02*S72+2.606082e-02*S73+(-1.998161e-03)*S74+1.899768e-01*S75+2.911166e-01*S76+2.255898e-01*S77+1.570960e-01*S78+3.376368e-01*S79'
.param V14='V14_part8+2.505138e-01*S80+1.099537e-01*S81+3.885895e-01*S82+2.391834e-01*S83+5.810430e-02*S84+2.656582e-01*S85+2.832959e-01*S86+6.432401e-03*S87+3.163646e-01*S88+3.282205e-01*S89'
.param V15_part1='1.920099e+00*S0+1.213234e-02*S1+1.759443e+00*S2+1.940162e+00*S3+8.594451e-01*S4+4.145007e+00*S5+2.887962e+00*S6+(-8.778860e-02)*S7+1.860474e+00*S8+(-2.443733e-01)*S9'
.param V15_part2='V15_part1+(-1.185276e-01)*S10+3.647473e+00*S11+(-3.123129e-01)*S12+1.297870e+00*S13+(-1.004910e-01)*S14+1.515708e-01*S15+(-1.756138e-02)*S16+6.298069e-01*S17+1.106310e+00*S18+(-2.437641e-01)*S19'
.param V15_part3='V15_part2+(-1.073974e-02)*S20+(-8.919412e-02)*S21+(-3.482912e-01)*S22+1.306809e-01*S23+(-7.107461e+02)*S24+1.752796e+00*S25+(-2.753890e+02)*S26+(-1.094401e+01)*S27+1.000000e+04*S28+(-2.759308e-02)*S29'
.param V15_part4='V15_part3+3.567922e-01*S30+2.202892e-02*S31+2.143691e-01*S32+1.958762e+01*S33+(-3.637652e-01)*S34+1.294783e+00*S35+1.449111e-01*S36+5.243648e+00*S37+4.829786e+00*S38+4.557481e+02*S39'
.param V15_part5='V15_part4+6.411813e+00*S40+5.156650e+00*S41+(-3.252872e-01)*S42+(-1.309945e-01)*S43+5.641652e-01*S44+2.701555e+02*S45+(-1.035570e+02)*S46+8.182146e+01*S47+9.121647e+02*S48+(-3.252232e+01)*S49'
.param V15_part6='V15_part5+3.383602e+00*S50+1.081490e+02*S51+4.714809e+01*S52+4.588812e-01*S53+1.970946e+02*S54+(-1.902388e+00)*S55+4.430618e+01*S56+2.657768e+02*S57+(-2.309198e-01)*S58+3.030514e+01*S59'
.param V15_part7='V15_part6+(-1.324846e+03)*S60+(-1.086281e+01)*S61+3.844675e+00*S62+(-5.404448e+02)*S63+1.017029e-01*S64+(-1.046509e+00)*S65+(-3.623582e+02)*S66+2.055270e+01*S67+(-1.859988e+00)*S68+(-1.565586e+02)*S69'
.param V15_part8='V15_part7+(-3.457833e-01)*S70+4.356308e+01*S71+3.457038e+01*S72+4.367154e+01*S73+(-2.057273e+00)*S74+4.924901e+03*S75+9.006098e-01*S76+2.855726e+00*S77+5.128394e+03*S78+3.504830e-01*S79'
.param V15='V15_part8+1.098572e+00*S80+5.961602e+03*S81+2.517735e-01*S82+6.253462e-01*S83+1.000000e+04*S84+1.442045e-01*S85+6.474640e-01*S86+1.000000e+04*S87+(-7.170108e-02)*S88+1.877583e-01*S89'
.param V16_part1='4.619009e+00*S0+2.212786e-01*S1+(-4.868244e-01)*S2+5.382492e+00*S3+1.766542e+01*S4+2.221066e+00*S5+1.126720e+01*S6+2.881339e-01*S7+(-2.769559e-01)*S8+4.649123e-01*S9'
.param V16_part2='V16_part1+2.643036e-01*S10+(-4.970216e+00)*S11+4.587419e-01*S12+5.801708e+00*S13+1.899476e-01*S14+1.332888e+00*S15+1.220495e+00*S16+(-2.962070e-01)*S17+(-5.144105e+00)*S18+5.421856e-01*S19'
.param V16_part3='V16_part2+(-3.033855e-01)*S20+9.683832e-01*S21+3.908043e-01*S22+1.484726e-01*S23+(-2.478907e+02)*S24+(-3.643251e+00)*S25+(-3.821665e+01)*S26+(-8.632624e+00)*S27+(-1.000000e+04)*S28+3.136212e-01*S29'
.param V16_part4='V16_part3+1.019083e+00*S30+5.664210e-01*S31+(-4.082546e-01)*S32+(-2.438421e+01)*S33+1.045932e+00*S34+(-2.231229e+00)*S35+1.517628e+00*S36+(-2.282532e+01)*S37+(-9.418592e+00)*S38+(-1.575623e+02)*S39'
.param V16_part5='V16_part4+(-2.293012e+01)*S40+(-8.354720e+00)*S41+1.572392e+00*S42+3.997020e-01*S43+(-1.039329e+00)*S44+(-1.015160e+02)*S45+1.081422e+03*S46+1.033831e+02*S47+(-4.203229e+02)*S48+(-1.159344e+02)*S49'
.param V16_part6='V16_part5+2.415456e+02*S50+(-6.814649e+00)*S51+(-3.982383e+02)*S52+2.552145e+00*S53+(-6.919121e+01)*S54+(-3.868107e+01)*S55+1.123385e+02*S56+(-8.141088e+01)*S57+4.450623e-01*S58+2.075997e+02*S59'
.param V16_part7='V16_part6+5.700306e+02*S60+3.519406e+00*S61+1.424436e+00*S62+(-2.422620e+02)*S63+1.107816e+00*S64+(-7.043731e+00)*S65+(-2.705962e+02)*S66+(-1.225327e+03)*S67+(-7.891595e+00)*S68+(-2.248737e+02)*S69'
.param V16_part8='V16_part7+5.275863e-01*S70+(-3.062010e+01)*S71+(-3.775917e+01)*S72+(-7.849324e+01)*S73+(-6.584935e-01)*S74+(-2.504974e+03)*S75+8.450644e-01*S76+(-2.445492e+00)*S77+(-1.962576e+03)*S78+9.016611e-01*S79'
.param V16='V16_part8+(-4.290998e-01)*S80+(-1.267245e+03)*S81+7.036719e-01*S82+2.178356e-01*S83+(-1.699845e+03)*S84+6.563263e-01*S85+7.137774e-01*S86+6.598739e+02*S87+1.025234e+00*S88+7.211753e-01*S89'
.param V17_part1='(-3.302785e-02)*S0+3.888365e-02*S1+7.449678e-01*S2+2.052955e-01*S3+1.720325e+00*S4+3.146376e+00*S5+9.368233e-01*S6+8.064106e-02*S7+1.296585e+00*S8+1.019349e-01*S9'
.param V17_part2='V17_part1+9.589433e-02*S10+3.297349e+00*S11+1.231811e-01*S12+1.594215e+00*S13+1.290296e-01*S14+6.214828e-02*S15+1.413838e-01*S16+9.966895e-02*S17+1.941439e+00*S18+2.741176e-01*S19'
.param V17_part3='V17_part2+7.205986e-01*S20+1.358464e-01*S21+4.041580e-01*S22+1.550083e-01*S23+4.918763e+02*S24+1.661882e+00*S25+4.841917e+02*S26+1.638578e+01*S27+1.000000e+04*S28+2.388967e-01*S29'
.param V17_part4='V17_part3+1.246799e-01*S30+3.240327e-01*S31+6.590457e-01*S32+1.264971e+01*S33+3.946413e-01*S34+1.352171e+00*S35+3.311500e-01*S36+9.765274e+00*S37+2.517592e+01*S38+5.477468e+00*S39'
.param V17_part5='V17_part4+1.267692e+01*S40+4.198704e+00*S41+3.062214e-01*S42+4.675003e-01*S43+2.714049e+00*S44+2.509118e+01*S45+1.095374e+02*S46+(-2.000438e+01)*S47+3.098956e+01*S48+1.148361e+02*S49'
.param V17_part6='V17_part5+(-5.134888e+00)*S50+6.848072e+01*S51+2.271506e+02*S52+(-2.144548e-01)*S53+9.048001e+01*S54+3.879971e+01*S55+(-3.999807e+00)*S56+4.443357e+01*S57+7.849681e-01*S58+5.882760e-01*S59'
.param V17_part7='V17_part6+6.953033e+02*S60+1.648950e+01*S61+(-7.151113e-01)*S62+4.088967e+02*S63+5.848787e-01*S64+9.473514e+00*S65+3.589980e+02*S66+1.867533e+03*S67+1.082515e+01*S68+2.498554e+02*S69'
.param V17_part8='V17_part7+1.170496e+00*S70+1.061311e+00*S71+3.260478e+01*S72+3.486311e+01*S73+5.998801e+00*S74+(-3.865906e+02)*S75+4.550493e-01*S76+2.723412e-01*S77+(-4.139808e+02)*S78+6.980270e-01*S79'
.param V17='V17_part8+1.085868e+00*S80+(-6.008548e+02)*S81+8.048539e-01*S82+1.381460e+00*S83+(-1.186597e+03)*S84+9.251726e-01*S85+8.202107e-01*S86+(-1.499311e+03)*S87+8.986217e-01*S88+1.055140e+00*S89'
.param V18_part1='1.022867e-01*S0+3.291939e-02*S1+4.250074e-01*S2+1.310735e-01*S3+(-6.784307e-04)*S4+8.570725e-01*S5+6.691429e-02*S6+3.228621e-02*S7+7.212109e-02*S8+4.087859e-02*S9'
.param V18_part2='V18_part1+3.084020e-02*S10+(-9.270670e-01)*S11+3.744513e-02*S12+(-4.574402e-01)*S13+2.538023e-02*S14+7.107217e-02*S15+4.211054e-02*S16+4.852498e-02*S17+3.163168e-02*S18+2.912834e-02*S19'
.param V18_part3='V18_part2+(-2.635265e-02)*S20+3.809223e-02*S21+2.784616e-02*S22+8.149573e-03*S23+(-3.717851e+01)*S24+2.416005e-01*S25+4.441956e+00*S26+(-3.556537e+00)*S27+1.489872e+03*S28+1.336578e-02*S29'
.param V18_part4='V18_part3+3.671853e-02*S30+4.953415e-02*S31+1.406366e-02*S32+(-3.209603e+00)*S33+4.912746e-02*S34+8.709158e-03*S35+1.843535e-01*S36+9.574422e-01*S37+2.561976e+00*S38+6.166817e+01*S39'
.param V18_part5='V18_part4+1.133592e+00*S40+2.651315e-01*S41+7.555178e-02*S42+3.479126e-02*S43+8.092577e-01*S44+1.825461e+01*S45+(-2.517753e+00)*S46+(-7.358513e+00)*S47+9.095539e+01*S48+1.151569e+01*S49'
.param V18_part6='V18_part5+(-4.109392e-01)*S50+1.675609e+01*S51+2.756276e+01*S52+(-1.123262e-02)*S53+1.479871e+01*S54+2.528057e+00*S55+(-6.815163e+00)*S56+1.064917e+01*S57+2.083424e-02*S58+6.393034e+00*S59'
.param V18_part7='V18_part6+(-7.695084e+00)*S60+8.900069e-01*S61+(-1.115535e-01)*S62+5.639108e+00*S63+4.323194e-02*S64+(-1.504149e-01)*S65+1.821825e+01*S66+8.423892e+01*S67+(-9.088471e-02)*S68+1.430763e+01*S69'
.param V18_part8='V18_part7+(-3.100312e-02)*S70+6.468307e-01*S71+3.402535e+00*S72+6.430382e-01*S73+(-2.751416e-02)*S74+1.139030e+02*S75+4.699038e-02*S76+2.849393e-02*S77+9.572887e+01*S78+8.064929e-02*S79'
.param V18='V18_part8+9.147153e-04*S80+3.595208e+01*S81+7.721169e-02*S82+5.410028e-02*S83+(-3.295567e+02)*S84+3.020619e-02*S85+5.602484e-02*S86+(-2.955849e+02)*S87+2.349386e-02*S88+3.038463e-02*S89'
.param V19_part1='1.823166e-01*S0+1.592510e-03*S1+(-7.723641e-02)*S2+2.243875e-01*S3+2.402668e-01*S4+(-5.826420e-02)*S5+3.605343e-01*S6+3.186949e-03*S7+(-2.097673e-04)*S8+7.449317e-03*S9'
.param V19_part2='V19_part1+2.248472e-03*S10+1.732198e-02*S11+7.350921e-03*S12+1.442057e-02*S13+1.817882e-03*S14+4.250265e-02*S15+2.611076e-02*S16+2.721125e-02*S17+(-2.010731e-01)*S18+1.852045e-02*S19'
.param V19_part3='V19_part2+(-1.371911e-02)*S20+3.357166e-02*S21+1.195084e-02*S22+(-6.842506e-06)*S23+(-1.553113e+01)*S24+(-1.190986e-02)*S25+(-1.007671e+01)*S26+(-5.567374e-01)*S27+5.397063e+00*S28+1.108855e-02*S29'
.param V19_part4='V19_part3+2.922828e-02*S30+4.626611e-02*S31+(-1.698148e-02)*S32+(-1.006360e+00)*S33+6.784676e-02*S34+(-2.138159e-01)*S35+1.509689e-01*S36+(-1.349827e-01)*S37+(-2.282622e+00)*S38+5.423179e+01*S39'
.param V19_part5='V19_part4+(-8.745145e-03)*S40+(-4.627993e-01)*S41+9.470697e-02*S42+1.384830e-02*S43+(-4.941300e-02)*S44+(-6.622824e+01)*S45+(-1.159929e+02)*S46+6.654729e+00*S47+(-1.372763e+02)*S48+6.882256e+00*S49'
.param V19_part6='V19_part5+5.509326e+00*S50+5.157836e+00*S51+1.236421e+01*S52+1.496146e-01*S53+1.220525e+01*S54+(-5.726452e-01)*S55+1.112657e+01*S56+1.126531e+01*S57+6.929162e-02*S58+2.508158e+01*S59'
.param V19_part7='V19_part6+(-1.165062e+02)*S60+(-2.197245e+00)*S61+2.914355e-01*S62+(-5.104848e+01)*S63+1.004217e-01*S64+(-3.501562e+00)*S65+(-4.074992e+01)*S66+(-1.501439e+02)*S67+(-3.280554e+00)*S68+(-2.191619e+01)*S69'
.param V19_part8='V19_part7+2.076001e-02*S70+(-2.343816e+00)*S71+(-8.566845e+00)*S72+(-1.515573e+00)*S73+(-4.801785e+00)*S74+(-8.901180e+02)*S75+1.554933e-01*S76+2.017072e-02*S77+(-9.133468e+02)*S78+1.154714e-01*S79'
.param V19='V19_part8+6.839234e-02*S80+(-1.132583e+03)*S81+1.004362e-01*S82+3.885214e-02*S83+(-2.013742e+03)*S84+1.307423e-01*S85+8.563454e-02*S86+(-2.455239e+03)*S87+1.321864e-01*S88+4.291761e-02*S89'
.param V20_part1='8.209062e-02*S0+5.474583e-02*S1+9.648727e-02*S2+7.014581e-02*S3+8.657865e-02*S4+2.771570e-01*S5+5.815681e-02*S6+4.199550e-02*S7+1.110784e-01*S8+4.275695e-02*S9'
.param V20_part2='V20_part1+3.773586e-02*S10+4.542094e-01*S11+3.585277e-02*S12+1.064459e-01*S13+6.365376e-02*S14+5.903883e-02*S15+7.916889e-02*S16+5.787346e-02*S17+2.357573e-01*S18+4.485339e-02*S19'
.param V20_part3='V20_part2+1.704637e-01*S20+2.331738e-02*S21+(-3.399026e-03)*S22+7.314020e-02*S23+7.737872e+01*S24+3.037592e-01*S25+7.955111e+01*S26+2.396435e+00*S27+(-1.954654e+03)*S28+9.832855e-02*S29'
.param V20_part4='V20_part3+5.791632e-02*S30+1.042367e-01*S31+2.230499e-01*S32+(-6.269753e-01)*S33+7.802331e-02*S34+1.289699e+00*S35+(-4.953062e-02)*S36+2.360292e+00*S37+8.480889e+00*S38+1.741561e-01*S39'
.param V20_part5='V20_part4+2.714450e+00*S40+1.914899e+00*S41+(-7.168388e-02)*S42+(-1.816439e-01)*S43+7.662382e-01*S44+(-6.894306e+00)*S45+(-3.011480e+01)*S46+7.100134e-01*S47+(-7.865831e+00)*S48+2.596086e+01*S49'
.param V20_part6='V20_part5+(-6.318951e+00)*S50+2.282819e+00*S51+5.215159e+01*S52+3.779765e-01*S53+4.770742e+00*S54+4.857973e+00*S55+3.069458e-01*S56+(-6.632607e+00)*S57+(-1.274836e-01)*S58+(-1.685045e+01)*S59'
.param V20_part7='V20_part6+1.902281e+02*S60+3.392594e+00*S61+4.468085e-01*S62+1.565642e+02*S63+3.251779e-01*S64+6.732689e+00*S65+1.739974e+02*S66+(-1.658873e+02)*S67+7.718960e+00*S68+1.494181e+02*S69'
.param V20_part8='V20_part7+6.110244e-01*S70+6.507427e+00*S71+3.023434e+01*S72+1.475531e+01*S73+3.868898e+00*S74+(-1.121073e+02)*S75+7.601182e-01*S76+2.005752e+00*S77+(-1.343747e+02)*S78+4.388241e-01*S79'
.param V20='V20_part8+1.149441e+00*S80+(-2.345124e+02)*S81+1.104897e-01*S82+1.172058e+00*S83+(-6.102164e+02)*S84+(-2.677834e-01)*S85+1.108779e+00*S86+(-8.935989e+02)*S87+(-1.454518e-01)*S88+9.969147e-01*S89'
.param V21_part1='6.621025e-01*S0+3.656250e-01*S1+3.284168e-01*S2+8.245987e-01*S3+1.453469e+00*S4+4.832112e-01*S5+1.271148e+00*S6+4.578264e-01*S7+4.092570e-01*S8+5.306352e-01*S9'
.param V21_part2='V21_part1+4.775948e-01*S10+4.433035e-01*S11+5.569181e-01*S12+1.039806e+00*S13+4.141473e-01*S14+1.411404e+00*S15+1.407075e+00*S16+1.187046e+00*S17+1.339265e+00*S18+1.469059e+00*S19'
.param V21_part3='V21_part2+1.432217e+00*S20+1.698069e+00*S21+1.670488e+00*S22+1.464078e+00*S23+3.943435e+01*S24+1.400857e+00*S25+1.656600e+01*S26+4.157060e+00*S27+4.566769e+03*S28+1.461579e+00*S29'
.param V21_part4='V21_part3+2.986485e+00*S30+3.010031e+00*S31+3.106333e+00*S32+1.054014e+01*S33+3.222146e+00*S34+2.213898e+00*S35+3.756611e+00*S36+2.190884e+00*S37+4.838234e+00*S38+1.936212e+01*S39'
.param V21_part5='V21_part4+2.624302e+00*S40+2.732030e+00*S41+3.840133e+00*S42+3.846965e+00*S43+3.511998e+00*S44+5.672059e+01*S45+2.948250e+02*S46+3.373762e+01*S47+8.371128e+01*S48+2.919692e+01*S49'
.param V21_part6='V21_part5+4.811346e+01*S50+5.228323e+01*S51+2.379410e+01*S52+4.515792e+00*S53+6.349708e+01*S54+1.160606e+01*S55+4.369790e+01*S56+4.889123e+01*S57+6.062520e+00*S58+6.500784e+01*S59'
.param V21_part7='V21_part6+1.547113e+02*S60+8.057951e+00*S61+6.302961e+00*S62+2.881604e+01*S63+7.888573e+00*S64+7.171433e+00*S65+1.831501e+01*S66+1.411150e+03*S67+6.784002e+00*S68+1.217369e+01*S69'
.param V21_part8='V21_part7+8.023187e+00*S70+2.608257e+00*S71+1.097379e+01*S72+4.301294e+00*S73+9.447537e+00*S74+1.398891e+02*S75+1.017129e+01*S76+8.486141e+00*S77+1.898370e+02*S78+1.117272e+01*S79'
.param V21='V21_part8+1.025235e+01*S80+2.413638e+02*S81+1.202641e+01*S82+1.088195e+01*S83+3.684479e+02*S84+1.249424e+01*S85+1.140732e+01*S86+5.041349e+02*S87+1.262095e+01*S88+1.143032e+01*S89'
.param V22_part1='9.929829e-02*S0+8.675169e-03*S1+1.758001e-02*S2+7.062337e-02*S3+9.264585e-02*S4+(-2.382640e-02)*S5+1.562392e-01*S6+(-3.967052e-02)*S7+(-7.615550e-03)*S8+(-1.585417e-01)*S9'
.param V22_part2='V22_part1+(-6.696078e-02)*S10+(-2.102887e-01)*S11+(-2.121780e-01)*S12+(-1.466776e-01)*S13+(-4.968168e-02)*S14+1.525858e-01*S15+1.034276e-01*S16+1.309341e-01*S17+(-2.393037e-01)*S18+7.328146e-02*S19'
.param V22_part3='V22_part2+6.056391e-02*S20+(-1.187631e-01)*S21+2.742564e-02*S22+3.961923e-02*S23+(-1.758814e+02)*S24+(-3.107187e-01)*S25+(-6.615362e+01)*S26+(-4.856483e+00)*S27+2.784769e+03*S28+(-8.261746e-02)*S29'
.param V22_part4='V22_part3+5.928839e-01*S30+5.247082e-01*S31+5.741826e-01*S32+3.016344e+00*S33+3.850277e-01*S34+(-1.819496e-02)*S35+2.977981e-01*S36+(-2.059829e+00)*S37+(-4.660346e+00)*S38+7.001023e+01*S39'
.param V22_part5='V22_part4+(-2.742028e+00)*S40+(-5.544694e-01)*S41+(-3.657121e-01)*S42+(-2.250349e-01)*S43+(-1.740803e-01)*S44+8.055011e+01*S45+4.141552e+01*S46+4.951216e+00*S47+1.807445e+02*S48+(-2.946310e+01)*S49'
.param V22_part6='V22_part5+5.268219e+00*S50+(-4.578715e+00)*S51+(-5.420549e+01)*S52+8.052293e-01*S53+(-1.274570e+01)*S54+(-9.087771e+00)*S55+(-4.698019e+00)*S56+1.369003e+01*S57+4.350843e-01*S58+1.152452e+01*S59'
.param V22_part7='V22_part6+(-3.993943e+02)*S60+(-2.311706e+00)*S61+2.158586e+00*S62+(-2.798626e+02)*S63+2.213326e+00*S64+(-5.450482e-01)*S65+(-3.048964e+02)*S66+(-1.782610e+02)*S67+(-1.235483e+00)*S68+(-2.521607e+02)*S69'
.param V22_part8='V22_part7+1.109927e+00*S70+1.404301e+00*S71+(-3.808558e+01)*S72+(-1.226589e+01)*S73+1.848717e-01*S74+1.391427e+03*S75+4.421878e+00*S76+4.990971e+00*S77+1.466010e+03*S78+4.206712e+00*S79'
.param V22='V22_part8+5.051478e+00*S80+1.914795e+03*S81+3.731348e+00*S82+4.722324e+00*S83+3.770271e+03*S84+3.447755e+00*S85+3.882099e+00*S86+4.806810e+03*S87+2.759612e+00*S88+3.852940e+00*S89'
.param V23_part1='6.888177e-02*S0+3.773512e-02*S1+5.022096e-02*S2+8.020771e-02*S3+1.239242e-01*S4+1.070618e-01*S5+1.296657e-01*S6+4.069350e-02*S7+5.970981e-02*S8+4.176278e-02*S9'
.param V23_part2='V23_part1+4.089417e-02*S10+3.166630e-02*S11+4.216148e-02*S12+5.281881e-02*S13+3.802978e-02*S14+4.377809e-02*S15+4.320118e-02*S16+3.758910e-02*S17+4.946028e-02*S18+4.374306e-02*S19'
.param V23_part3='V23_part2+5.310194e-02*S20+4.680436e-02*S21+5.050899e-02*S22+5.044982e-02*S23+8.891508e-01*S24+7.229865e-02*S25+1.429317e+00*S26+(-1.317353e-01)*S27+8.533937e+02*S28+4.840175e-02*S29'
.param V23_part4='V23_part3+4.726216e-02*S30+4.209970e-02*S31+7.256110e-02*S32+1.704987e-01*S33+4.075990e-02*S34+5.751231e-02*S35+6.104331e-02*S36+8.816078e-02*S37+1.065992e-01*S38+4.140587e+00*S39'
.param V23_part5='V23_part4+1.002693e-01*S40+7.413895e-02*S41+5.332626e-02*S42+4.444546e-02*S43+6.371066e-02*S44+2.320207e+00*S45+2.107774e+00*S46+3.734340e-02*S47+8.362768e+00*S48+1.183698e+00*S49'
.param V23_part6='V23_part5+3.471905e-01*S50+2.173899e+00*S51+2.629298e+00*S52+6.667459e-02*S53+3.675389e+00*S54+1.980531e-01*S55+1.414944e-01*S56+3.679704e+00*S57+5.295762e-02*S58+2.898979e+00*S59'
.param V23_part7='V23_part6+(-3.253942e+00)*S60+5.985705e-02*S61+6.732471e-02*S62+(-1.442879e+00)*S63+3.489238e-02*S64+8.088369e-02*S65+(-4.064674e-01)*S66+(-4.774568e+00)*S67+5.126674e-02*S68+(-2.903434e-01)*S69'
.param V23_part8='V23_part7+5.925037e-02*S70+2.076490e-01*S71+(-8.332296e-01)*S72+1.971444e-01*S73+8.835563e-02*S74+2.038006e+01*S75+2.707750e-02*S76+4.760618e-02*S77+2.728983e+01*S78+9.217037e-03*S79'
.param V23='V23_part8+4.230467e-02*S80+3.762302e+01*S81+1.096237e-03*S82+5.887240e-02*S83+5.579200e+01*S84+4.345234e-02*S85+2.996660e-02*S86+8.264669e+01*S87+4.593035e-02*S88+7.067575e-02*S89'
.param V24_part1='1.230074e-02*S0+6.778859e-03*S1+3.797615e-03*S2+1.549813e-02*S3+2.474417e-02*S4+3.360239e-03*S5+2.553161e-02*S6+7.107691e-03*S7+4.708473e-03*S8+8.171203e-03*S9'
.param V24_part2='V24_part1+7.121168e-03*S10+5.822836e-03*S11+8.212575e-03*S12+9.816772e-03*S13+5.983868e-03*S14+2.405180e-02*S15+2.092826e-02*S16+2.283210e-02*S17+2.064538e-02*S18+2.113124e-02*S19'
.param V24_part3='V24_part2+2.663283e-02*S20+1.999869e-02*S21+2.672587e-02*S22+2.917857e-02*S23+(-3.080119e+00)*S24+2.229496e-02*S25+(-2.975076e-01)*S26+(-3.688645e-01)*S27+2.006862e+02*S28+1.891584e-02*S29'
.param V24_part4='V24_part3+7.377342e-02*S30+7.188069e-02*S31+9.026195e-02*S32+5.284824e-01*S33+5.794369e-02*S34+2.034616e-02*S35+4.770474e-02*S36+7.974540e-02*S37+(-2.838633e-01)*S38+4.463002e+00*S39'
.param V24_part5='V24_part4+8.857422e-02*S40+(-3.299346e-02)*S41+1.188513e-02*S42+1.844440e-02*S43+(-9.582439e-04)*S44+2.569921e-01*S45+(-1.029489e+01)*S46+2.855353e+00*S47+4.728679e+00*S48+2.618278e+00*S49'
.param V24_part6='V24_part5+2.647943e+00*S50+4.503058e+00*S51+4.256392e+00*S52+1.380227e-01*S53+7.640946e+00*S54+2.972364e-01*S55+3.448950e+00*S56+6.145308e+00*S57+6.401635e-02*S58+8.795034e+00*S59'
.param V24_part7='V24_part6+(-3.139309e+00)*S60+3.779275e-01*S61+3.046551e-01*S62+(-9.305894e-01)*S63+2.237463e-01*S64+(-3.470481e-01)*S65+(-1.614309e+00)*S66+3.378449e+00*S67+(-3.677459e-01)*S68+(-1.668892e+00)*S69'
.param V24_part8='V24_part7+1.316817e-01*S70+1.585211e-01*S71+(-1.580169e+00)*S72+2.603541e-01*S73+(-9.403259e-01)*S74+6.684767e+00*S75+3.880755e-01*S76+4.707887e-01*S77+(-5.856246e+00)*S78+3.746873e-01*S79'
.param V24='V24_part8+5.415255e-01*S80+(-3.359100e+01)*S81+3.539318e-01*S82+4.746620e-01*S83+(-1.255895e+02)*S84+2.995941e-01*S85+3.934581e-01*S86+(-2.044929e+02)*S87+2.517226e-01*S88+4.491777e-01*S89'
.param V25_part1='1.117008e+00*S0+(-4.928599e-01)*S1+(-4.503056e-02)*S2+9.861974e-01*S3+4.684911e-01*S4+(-3.195870e-01)*S5+5.693670e-01*S6+5.433131e-02*S7+9.715865e-02*S8+6.058636e-03*S9'
.param V25_part2='V25_part1+(-5.448628e-02)*S10+2.403543e-02*S11+1.280169e-01*S12+6.005441e-01*S13+(-3.200946e-03)*S14+(-2.719065e-01)*S15+(-1.000896e+00)*S16+3.120619e+00*S17+(-3.813924e-01)*S18+4.277740e-01*S19'
.param V25_part3='V25_part2+2.988712e+00*S20+(-7.647172e-02)*S21+1.663468e+00*S22+3.248282e-01*S23+(-5.265709e-01)*S24+(-3.432483e-01)*S25+(-4.679801e-01)*S26+9.205401e-02*S27+(-1.127176e+00)*S28+3.972314e-01*S29'
.param V25_part4='V25_part3+(-1.507467e-01)*S30+(-3.287213e-01)*S31+1.879661e+00*S32+1.167030e-02*S33+(-7.808502e-01)*S34+2.953634e-01*S35+2.022332e+00*S36+(-8.128839e-01)*S37+(-7.709121e-02)*S38+(-1.177235e-01)*S39'
.param V25_part5='V25_part4+(-7.402666e-01)*S40+(-1.064826e-01)*S41+6.623345e-01*S42+(-7.656236e-01)*S43+1.288039e+00*S44+(-5.927950e-02)*S45+(-6.066452e-02)*S46+(-5.827894e+00)*S47+(-1.960079e-01)*S48+(-1.536313e+01)*S49'
.param V25_part6='V25_part5+(-2.072010e+00)*S50+(-3.406363e-01)*S51+(-1.673612e+01)*S52+1.403914e+00*S53+(-2.294321e-02)*S54+(-2.264239e-01)*S55+(-2.886938e+00)*S56+1.330166e-01*S57+(-1.596644e-01)*S58+(-1.464718e+00)*S59'
.param V25_part7='V25_part6+(-3.515102e-01)*S60+(-8.586314e-01)*S61+1.086652e+00*S62+(-4.099367e-01)*S63+(-8.916774e-01)*S64+5.989636e-02*S65+(-4.538835e-01)*S66+(-5.538444e-01)*S67+6.214612e-02*S68+(-4.578397e-01)*S69'
.param V25_part8='V25_part7+5.292052e-01*S70+(-6.543427e-01)*S71+(-2.455595e-01)*S72+(-8.328268e-01)*S73+8.040579e-01*S74+(-2.254924e-01)*S75+(-8.982728e-01)*S76+2.496511e+00*S77+(-2.591828e-01)*S78+(-9.759034e-01)*S79'
.param V25='V25_part8+2.633215e+00*S80+(-2.917800e-01)*S81+(-9.964357e-01)*S82+2.657290e+00*S83+(-3.697478e-01)*S84+(-9.551941e-01)*S85+1.355927e+00*S86+(-4.221821e-01)*S87+(-8.465871e-01)*S88+7.601886e-01*S89'
.param V26_part1='1.244691e-01*S0+2.695666e-01*S1+1.273524e+00*S2+(-3.684043e-02)*S3+(-1.476007e-01)*S4+4.336529e-01*S5+(-3.097015e-02)*S6+7.886072e-01*S7+4.385608e-01*S8+1.044615e+00*S9'
.param V26_part2='V26_part1+4.139915e-01*S10+6.869260e-01*S11+8.444318e-01*S12+4.353012e-02*S13+1.092564e+00*S14+2.775027e+00*S15+3.837128e+00*S16+(-8.630541e-01)*S17+2.240732e+00*S18+9.564505e-01*S19'
.param V26_part3='V26_part2+(-1.608100e+00)*S20+9.773432e-01*S21+(-6.489980e-01)*S22+(-1.217869e-01)*S23+1.302545e-02*S24+1.034825e+00*S25+1.088810e-03*S26+8.354798e-02*S27+1.569329e-01*S28+2.232466e-01*S29'
.param V26_part4='V26_part3+4.638372e-01*S30+8.346252e-01*S31+(-1.155213e+00)*S32+1.221612e-02*S33+1.186892e+00*S34+9.786673e-01*S35+(-1.571038e-01)*S36+8.903718e-01*S37+1.562768e-01*S38+8.481487e-02*S39'
.param V26_part5='V26_part4+6.018838e-01*S40+9.770138e-01*S41+8.599795e-01*S42+5.119085e-01*S43+2.372710e-01*S44+(-1.121812e-01)*S45+(-6.383849e-01)*S46+4.195266e+00*S47+(-5.656373e-02)*S48+1.814258e+01*S49'
.param V26_part6='V26_part5+(-2.179275e-01)*S50+2.265113e-01*S51+1.536950e+01*S52+(-3.176489e-01)*S53+7.031801e-02*S54+(-1.485206e-01)*S55+(-1.225859e-01)*S56+(-2.341627e-01)*S57+3.389704e-02*S58+1.133620e+00*S59'
.param V26_part7='V26_part6+(-3.568680e-01)*S60+7.956676e-01*S61+1.913025e-01*S62+(-4.338530e-02)*S63+9.162876e-01*S64+5.728757e-01*S65+2.776908e-02*S66+7.753160e-04*S67+4.583008e-01*S68+7.731491e-02*S69'
.param V26_part8='V26_part7+9.835458e-01*S70+1.100806e+00*S71+2.073548e-01*S72+5.698875e-01*S73+(-7.752197e-02)*S74+(-3.135176e-01)*S75+1.041764e+00*S76+(-1.264142e+00)*S77+(-1.945694e-01)*S78+1.028742e+00*S79'
.param V26='V26_part8+(-9.116057e-01)*S80+(-1.399398e-01)*S81+8.873356e-01*S82+(-5.402528e-01)*S83+(-1.194712e-01)*S84+7.729129e-01*S85+(-2.160929e-02)*S86+(-1.054240e-01)*S87+5.261701e-01*S88+1.050049e-01*S89'
.param V27_part1='(-8.182038e-01)*S0+4.042746e-01*S1+2.040273e-01*S2+(-6.720290e-01)*S3+(-1.923492e-01)*S4+1.682528e-01*S5+(-4.306814e-01)*S6+6.052806e-01*S7+2.044460e-01*S8+7.639950e-01*S9'
.param V27_part2='V27_part1+2.333308e-01*S10+3.055679e-01*S11+6.112729e-01*S12+(-1.850722e-01)*S13+6.155784e-01*S14+7.553000e-01*S15+2.443899e+00*S16+(-1.036816e+00)*S17+7.115697e-01*S18+(-1.054552e+00)*S19'
.param V27_part3='V27_part2+(-7.595847e-01)*S20+(-7.335928e-03)*S21+(-7.145294e-01)*S22+(-6.226136e-03)*S23+7.090994e-01*S24+9.189812e-01*S25+2.891969e-01*S26+4.786759e-01*S27+8.762501e-01*S28+4.489653e-01*S29'
.param V27_part4='V27_part3+(-7.457475e-01)*S30+9.641562e-01*S31+(-5.526410e-01)*S32+(-1.358286e+00)*S33+1.076737e+00*S34+9.194016e-01*S35+(-1.798373e+00)*S36+1.171725e+00*S37+3.757367e-01*S38+(-1.186212e-01)*S39'
.param V27_part5='V27_part4+1.270170e+00*S40+1.035877e+00*S41+(-7.489021e-01)*S42+1.088359e+00*S43+4.462194e-01*S44+1.688905e-01*S45+3.171183e-01*S46+2.020151e+00*S47+1.823403e-01*S48+4.584745e+00*S49'
.param V27_part6='V27_part5+1.535615e-01*S50+(-5.251846e+00)*S51+4.539084e+00*S52+6.733614e-01*S53+(-7.390963e+00)*S54+6.007631e-01*S55+1.733900e+00*S56+(-3.385942e+00)*S57+1.204467e+00*S58+(-3.367394e+00)*S59'
.param V27_part7='V27_part6+1.027192e+00*S60+1.730260e+00*S61+2.753534e-01*S62+1.083191e+00*S63+1.502675e+00*S64+1.010207e+00*S65+1.108483e+00*S66+5.597209e-01*S67+1.030554e+00*S68+1.120977e+00*S69'
.param V27_part8='V27_part7+(-1.359320e+00)*S70+1.188230e-01*S71+1.091702e+00*S72+1.032330e+00*S73+7.869597e-01*S74+2.993286e-01*S75+1.740265e+00*S76+(-4.077051e-01)*S77+2.736585e-01*S78+1.520267e+00*S79'
.param V27='V27_part8+(-8.116605e-01)*S80+2.301290e-01*S81+1.303639e+00*S82+(-8.186897e-01)*S83+2.522013e-01*S84+1.152265e+00*S85+(-1.153333e-01)*S86+3.046437e-01*S87+1.077469e+00*S88+1.299958e-01*S89'
.param V28_part1='(-8.721160e-03)*S0+4.644887e-03*S1+(-7.307617e-02)*S2+(-3.214754e-02)*S3+(-9.501420e-03)*S4+(-3.715542e-02)*S5+(-2.891120e-02)*S6+(-2.140899e-01)*S7+(-7.502049e-02)*S8+(-2.815941e-01)*S9'
.param V28_part2='V28_part1+(-1.094122e-01)*S10+6.565784e-02*S11+(-3.297384e-01)*S12+1.563520e-02*S13+1.156110e-01*S14+2.961246e-02*S15+(-3.744396e-02)*S16+(-1.683895e-01)*S17+(-2.157754e-02)*S18+1.424587e-02*S19'
.param V28_part3='V28_part2+(-1.979657e-01)*S20+(-8.831705e-02)*S21+(-8.250955e-02)*S22+(-1.790590e-02)*S23+(-2.552848e-02)*S24+(-1.637941e-01)*S25+(-1.218150e-02)*S26+1.172307e-02*S27+2.954600e-03*S28+(-1.371109e-02)*S29'
.param V28_part4='V28_part3+5.509281e-03*S30+3.170651e-02*S31+(-2.852182e-02)*S32+(-1.338701e-02)*S33+1.758387e-02*S34+7.038656e-03*S35+8.621435e-02*S36+1.141540e-02*S37+(-5.690807e-03)*S38+(-3.492529e-02)*S39'
.param V28_part5='V28_part4+1.515945e-02*S40+(-2.957951e-03)*S41+1.182997e-01*S42+1.162939e-02*S43+1.479207e-01*S44+(-1.358835e-02)*S45+(-7.548974e-03)*S46+1.418725e-02*S47+(-2.244804e-02)*S48+4.647449e-02*S49'
.param V28_part6='V28_part5+9.197682e-02*S50+(-1.241244e-01)*S51+2.190826e-01*S52+(-5.507450e-03)*S53+(-1.502362e-01)*S54+1.596502e-02*S55+4.356522e-02*S56+(-9.031847e-02)*S57+3.001790e-02*S58+(-1.549106e-01)*S59'
.param V28_part7='V28_part6+(-6.602509e-03)*S60+2.078351e-02*S61+1.540272e-02*S62+(-9.682053e-03)*S63+5.156736e-03*S64+(-1.923325e-03)*S65+(-1.523023e-02)*S66+(-2.224903e-02)*S67+4.912274e-03*S68+(-1.784065e-02)*S69'
.param V28_part8='V28_part7+9.072254e-03*S70+(-1.083578e-03)*S71+(-7.310960e-03)*S72+1.171364e-02*S73+(-1.986074e-02)*S74+(-1.072781e-02)*S75+8.867905e-03*S76+5.508782e-02*S77+(-1.482508e-02)*S78+1.095603e-02*S79'
.param V28='V28_part8+7.738897e-03*S80+(-1.613904e-02)*S81+1.219230e-02*S82+4.996971e-02*S83+(-1.225582e-02)*S84+5.830847e-03*S85+5.820762e-02*S86+(-1.301801e-02)*S87+9.472896e-03*S88+3.319559e-02*S89'
.param V29_part1='(-1.104668e-03)*S0+1.137652e-02*S1+4.754440e-02*S2+(-8.510866e-03)*S3+(-3.752371e-03)*S4+1.618497e-02*S5+(-6.323395e-03)*S6+4.379769e-02*S7+2.361632e-02*S8+7.429294e-02*S9'
.param V29_part2='V29_part1+1.738309e-02*S10+1.268352e-02*S11+7.002937e-02*S12+4.973919e-03*S13+2.555341e-02*S14+8.003235e-02*S15+8.938908e-02*S16+(-1.329630e-01)*S17+5.585927e-02*S18+4.288787e-02*S19'
.param V29_part3='V29_part2+(-1.176887e-01)*S20+4.212994e-02*S21+(-3.444092e-02)*S22+(-2.173709e-02)*S23+(-9.629321e-03)*S24+1.961760e-02*S25+(-5.202072e-03)*S26+3.756025e-02*S27+(-3.680583e-03)*S28+3.769659e-02*S29'
.param V29_part4='V29_part3+(-3.937878e-02)*S30+1.572430e-02*S31+(-1.890808e-01)*S32+(-3.471936e-02)*S33+5.452499e-02*S34+(-5.906801e-02)*S35+(-2.033392e-03)*S36+2.128714e-02*S37+7.347884e-03*S38+(-4.092588e-02)*S39'
.param V29_part5='V29_part4+1.055885e-02*S40+2.990883e-02*S41+4.192930e-02*S42+(-5.117821e-03)*S43+1.900739e-02*S44+(-2.977929e-02)*S45+(-1.814689e-02)*S46+2.225050e-01*S47+(-4.374154e-02)*S48+(-1.343284e+00)*S49'
.param V29_part6='V29_part5+1.856922e-01*S50+(-6.715190e-02)*S51+1.121655e-03*S52+(-1.003173e-01)*S53+(-1.050855e-01)*S54+1.514976e-02*S55+4.585708e-02*S56+(-7.807481e-02)*S57+1.950532e-02*S58+(-4.407406e-01)*S59'
.param V29_part7='V29_part6+(-5.178684e-02)*S60+5.649827e-02*S61+(-1.338122e-01)*S62+(-4.579744e-02)*S63+2.325180e-02*S64+(-3.098141e-02)*S65+(-4.245046e-02)*S66+(-3.454122e-02)*S67+(-3.536794e-02)*S68+(-4.092907e-02)*S69'
.param V29_part8='V29_part7+7.930997e-02*S70+5.602439e-02*S71+(-2.533971e-02)*S72+(-2.623685e-03)*S73+(-1.310618e-01)*S74+(-8.821168e-02)*S75+5.840167e-02*S76+(-2.787868e-01)*S77+(-9.780004e-02)*S78+2.489243e-02*S79'
.param V29='V29_part8+(-2.673801e-01)*S80+(-1.202646e-01)*S81+8.617726e-03*S82+(-2.837269e-01)*S83+(-1.580011e-01)*S84+2.991264e-02*S85+(-1.491254e-01)*S86+(-1.774774e-01)*S87+2.066243e-02*S88+(-1.502165e-01)*S89'
.param V30_part1='5.662005e-02*S0+(-7.441185e-02)*S1+(-1.591419e+00)*S2+(-1.601406e-01)*S3+(-7.324506e-01)*S4+(-2.050839e+00)*S5+(-2.042298e-01)*S6+9.814650e-01*S7+(-1.893501e+00)*S8+(-1.541149e+00)*S9'
.param V30_part2='V30_part1+1.003251e+00*S10+(-2.829669e+00)*S11+(-1.386998e+00)*S12+6.378093e-01*S13+(-3.552095e+00)*S14+(-1.299708e+00)*S15+(-2.375687e+00)*S16+(-5.561515e+00)*S17+(-1.158992e+00)*S18+(-2.716210e+00)*S19'
.param V30_part3='V30_part2+(-6.045872e+00)*S20+4.586970e-01*S21+(-1.584212e+00)*S22+(-9.393587e+00)*S23+(-1.186710e+00)*S24+(-1.827162e-02)*S25+(-3.953008e+00)*S26+(-2.089392e+00)*S27+(-4.760250e+00)*S28+(-6.375931e+00)*S29'
.param V30_part4='V30_part3+(-2.761478e+00)*S30+(-1.347622e+01)*S31+(-2.398933e+01)*S32+(-2.365202e+00)*S33+(-8.788130e+00)*S34+1.274946e+00*S35+(-1.219639e+00)*S36+(-2.516538e+00)*S37+(-1.010941e+01)*S38+(-2.076747e+00)*S39'
.param V30_part5='V30_part4+(-8.159297e+00)*S40+(-1.325503e+01)*S41+(-3.205708e+00)*S42+(-6.673790e+00)*S43+(-1.236950e+01)*S44+2.117536e-01*S45+(-4.859384e+00)*S46+2.991844e+00*S47+(-2.899774e+00)*S48+4.678993e-01*S49'
.param V30_part6='V30_part5+(-5.977036e-01)*S50+6.821196e-01*S51+7.299978e+00*S52+(-9.685460e+00)*S53+2.485063e+00*S54+(-2.552903e+00)*S55+(-2.415637e+00)*S56+2.659240e+00*S57+(-4.030777e+00)*S58+1.082015e+01*S59'
.param V30_part7='V30_part6+1.745674e+00*S60+(-5.905184e+00)*S61+(-7.289733e+00)*S62+4.219677e+00*S63+(-6.406159e+00)*S64+(-2.345952e+01)*S65+6.196904e+00*S66+1.472900e+01*S67+(-3.207086e+01)*S68+7.368182e+00*S69'
.param V30_part8='V30_part7+1.664580e+00*S70+(-2.438251e+01)*S71+8.647378e+00*S72+(-1.290607e+01)*S73+(-2.849667e+01)*S74+(-5.198605e+00)*S75+(-1.839726e+00)*S76+(-1.871477e+01)*S77+(-7.006359e+00)*S78+(-4.420757e+00)*S79'
.param V30='V30_part8+(-2.003985e+01)*S80+(-7.810680e+00)*S81+(-6.218367e+00)*S82+(-2.483687e+01)*S83+(-8.354778e+00)*S84+(-5.289247e+00)*S85+(-1.894778e+01)*S86+(-7.693085e+00)*S87+(-6.833247e+00)*S88+(-1.390534e+01)*S89'
.param V31_part1='4.864074e+00*S0+3.935110e+00*S1+4.543377e+00*S2+3.001846e+00*S3+3.775880e+00*S4+5.215435e+00*S5+3.073446e+00*S6+1.375943e+00*S7+4.227704e+00*S8+3.335059e+00*S9'
.param V31_part2='V31_part1+2.042322e+00*S10+5.392102e+00*S11+2.525759e+00*S12+1.318159e+00*S13+4.882962e+00*S14+8.301263e+00*S15+1.164235e+01*S16+1.273956e+01*S17+1.549468e+00*S18+9.309680e+00*S19'
.param V31_part3='V31_part2+1.030587e+01*S20+1.208697e+00*S21+3.925537e+00*S22+1.334226e+01*S23+4.745296e+00*S24+5.635911e+00*S25+6.803256e+00*S26+6.859132e+00*S27+9.278782e+00*S28+8.963832e+00*S29'
.param V31_part4='V31_part3+1.834336e+01*S30+4.678004e+01*S31+2.144221e+01*S32+8.803736e+00*S33+5.650521e+01*S34+8.572329e-01*S35+3.562399e+00*S36+4.067260e+00*S37+1.609554e+01*S38+1.046902e+01*S39'
.param V31_part5='V31_part4+6.594108e+00*S40+1.783195e+01*S41+1.016263e+01*S42+1.247754e+01*S43+1.577156e+01*S44+(-1.357305e-01)*S45+1.773020e+01*S46+2.066910e+00*S47+9.849833e+00*S48+2.476781e+00*S49'
.param V31_part6='V31_part5+(-8.364439e-01)*S50+1.036005e+01*S51+3.887867e+00*S52+6.466268e+00*S53+7.542746e+00*S54+6.129803e+00*S55+3.328493e+00*S56+8.810325e+00*S57+5.877528e+00*S58+5.936104e+00*S59'
.param V31_part7='V31_part6+3.312982e+00*S60+(-2.973745e+00)*S61+1.329008e+01*S62+1.404803e+00*S63+2.241164e+01*S64+3.200684e+01*S65+(-4.347517e-01)*S66+6.077994e+00*S67+3.502190e+01*S68+(-1.874803e-03)*S69'
.param V31_part8='V31_part7+1.505673e+00*S70+1.276509e+01*S71+(-1.715977e-01)*S72+2.313929e+01*S73+2.983463e+01*S74+1.874244e+01*S75+3.456331e+00*S76+9.457644e+00*S77+1.830677e+01*S78+9.336621e+00*S79'
.param V31='V31_part8+1.372419e+01*S80+1.657567e+01*S81+9.717531e+00*S82+1.457242e+01*S83+1.551377e+01*S84+8.592661e+00*S85+7.473049e+00*S86+1.311697e+01*S87+1.260760e+01*S88+1.180571e+01*S89'
.param V32_part1='4.513738e+00*S0+3.569869e+00*S1+4.982379e+00*S2+4.424386e+00*S3+4.625456e+00*S4+5.324661e+00*S5+4.300189e+00*S6+3.697274e+00*S7+5.742429e+00*S8+7.478951e+00*S9'
.param V32_part2='V32_part1+3.357512e+00*S10+6.932792e+00*S11+8.438978e+00*S12+6.387904e+00*S13+8.449687e+00*S14+1.101431e+01*S15+1.254939e+01*S16+1.451402e+01*S17+1.242442e+01*S18+1.242576e+01*S19'
.param V32_part3='V32_part2+1.614619e+01*S20+1.184136e+01*S21+1.342545e+01*S22+1.857837e+01*S23+1.263541e+01*S24+7.341574e+00*S25+1.265090e+01*S26+1.167871e+01*S27+1.587408e+01*S28+1.529880e+01*S29'
.param V32_part4='V32_part3+2.303519e+01*S30+7.264301e+01*S31+5.146288e+01*S32+1.369505e+01*S33+2.006203e+02*S34+1.103400e+01*S35+1.887313e+01*S36+1.221319e+01*S37+2.684809e+01*S38+1.783879e+01*S39'
.param V32_part5='V32_part4+2.846618e+01*S40+2.852981e+01*S41+2.086338e+01*S42+2.692898e+01*S43+2.868077e+01*S44+2.426646e+01*S45+2.177636e+01*S46+1.667660e+01*S47+2.356204e+01*S48+1.284650e+01*S49'
.param V32_part6='V32_part5+1.642915e+01*S50+1.334495e+01*S51+6.245610e+00*S52+3.956548e+01*S53+1.101663e+01*S54+1.335472e+01*S55+1.651174e+01*S56+7.462620e+00*S57+1.851403e+01*S58+1.202938e+01*S59'
.param V32_part7='V32_part6+1.674560e+01*S60+4.448566e+01*S61+4.588837e+01*S62+1.747517e+01*S63+4.450557e+01*S64+6.785355e+01*S65+2.190609e+01*S66+(-2.023763e+00)*S67+7.666817e+01*S68+2.514550e+01*S69'
.param V32_part8='V32_part7+3.506577e+01*S70+7.274040e+01*S71+2.935637e+01*S72+5.554783e+01*S73+7.536668e+01*S74+4.111800e+01*S75+4.391634e+01*S76+4.875288e+01*S77+4.558249e+01*S78+5.212505e+01*S79'
.param V32='V32_part8+3.990880e+01*S80+5.055629e+01*S81+6.082894e+01*S82+4.417362e+01*S83+5.587922e+01*S84+2.285668e+01*S85+4.250441e+01*S86+6.221405e+01*S87+1.948654e+01*S88+4.088718e+01*S89'
.param V33_part1='5.481669e-01*S0+7.422483e-01*S1+7.809510e-01*S2+5.525658e-01*S3+9.529263e-01*S4+8.514149e-01*S5+8.324131e-01*S6+8.239164e-01*S7+8.488328e-01*S8+1.025110e+00*S9'
.param V33_part2='V33_part1+1.135024e+00*S10+1.433253e+00*S11+9.788935e-01*S12+9.173142e-01*S13+1.466918e+00*S14+5.962470e-01*S15+8.554634e-01*S16+9.388953e-01*S17+5.100276e-01*S18+5.446004e-01*S19'
.param V33_part3='V33_part2+2.192500e+00*S20+8.260377e-01*S21+1.014548e+00*S22+1.420994e+00*S23+1.284242e+00*S24+7.606678e-01*S25+6.727566e-01*S26+5.653308e-01*S27+1.754437e+00*S28+1.951768e-01*S29'
.param V33_part4='V33_part3+4.165266e-01*S30+4.074255e+00*S31+8.389018e-01*S32+(-3.393021e-01)*S33+2.972500e+01*S34+2.151215e-01*S35+4.328080e-01*S36+(-5.462484e-01)*S37+4.139574e-01*S38+4.016945e-01*S39'
.param V33_part5='V33_part4+1.587835e-01*S40+6.629480e-01*S41+5.219648e-01*S42+3.713135e-01*S43+(-3.465932e-01)*S44+4.633577e-01*S45+1.250838e+00*S46+9.494621e-01*S47+8.202086e-01*S48+(-2.092678e-01)*S49'
.param V33_part6='V33_part5+4.607965e-01*S50+5.163664e-01*S51+(-1.826448e-01)*S52+1.114932e+00*S53+5.227541e-01*S54+(-6.695062e-01)*S55+(-4.530449e-02)*S56+5.346317e-01*S57+(-3.257508e-01)*S58+1.324063e+00*S59'
.param V33_part7='V33_part6+1.193579e-01*S60+6.932957e-01*S61+2.148354e+00*S62+7.033791e-01*S63+6.436210e-01*S64+1.359027e+00*S65+8.309506e-01*S66+4.678255e-01*S67+1.114133e+00*S68+9.003555e-01*S69'
.param V33_part8='V33_part7+(-8.241174e-03)*S70+8.294836e-01*S71+7.742368e-01*S72+8.134190e-01*S73+1.633885e+00*S74+7.670872e-01*S75+7.478974e-01*S76+(-1.060016e-01)*S77+7.469098e-01*S78+1.539512e+00*S79'
.param V33='V33_part8+2.746209e-01*S80+7.853206e-01*S81+2.016625e+00*S82+2.817519e-01*S83+8.017560e-01*S84+(-9.071734e-01)*S85+(-8.332266e-02)*S86+7.375947e-01*S87+(-9.757920e-01)*S88+3.528281e-01*S89'
.param V34_part1='7.108170e-02*S0+6.013969e-02*S1+4.591403e-02*S2+1.276285e-01*S3+4.526128e-02*S4+2.617910e-02*S5+6.862994e-02*S6+1.545239e-03*S7+1.978637e-02*S8+2.401242e-02*S9'
.param V34_part2='V34_part1+1.844846e-02*S10+3.962189e-02*S11+1.083657e-02*S12+6.603534e-03*S13+4.275670e-02*S14+1.426046e-01*S15+4.346931e-01*S16+(-1.079963e-01)*S17+1.962996e-01*S18+(-6.154016e-01)*S19'
.param V34_part3='V34_part2+3.577588e-01*S20+2.782406e-01*S21+1.193544e-01*S22+5.105666e-01*S23+2.082334e-01*S24+2.129841e-01*S25+2.618216e-01*S26+(-1.531148e+00)*S27+4.855706e-01*S28+(-1.728097e+00)*S29'
.param V34_part4='V34_part3+(-1.693735e+00)*S30+(-6.141689e+00)*S31+3.117414e+00*S32+6.576752e-01*S33+(-2.218835e+01)*S34+(-1.683117e-01)*S35+1.046928e+00*S36+(-4.640286e-02)*S37+(-3.182688e+00)*S38+(-2.504071e+00)*S39'
.param V34_part5='V34_part4+9.497168e-01*S40+(-3.343781e+00)*S41+(-2.785988e+00)*S42+(-1.956357e+00)*S43+(-2.144101e+00)*S44+1.624955e+00*S45+6.196654e-01*S46+(-3.920735e-01)*S47+9.829125e-01*S48+(-1.360753e+00)*S49'
.param V34_part6='V34_part5+2.631907e-02*S50+1.355501e+00*S51+(-3.928417e-01)*S52+(-3.435372e+00)*S53+6.271239e-01*S54+8.681857e-01*S55+6.390941e-01*S56+5.450393e-01*S57+8.179153e-01*S58+2.394185e+00*S59'
.param V34_part7='V34_part6+4.263990e-01*S60+(-2.542150e+00)*S61+1.022331e+00*S62+1.444280e+00*S63+(-3.912774e+00)*S64+(-1.632563e+00)*S65+1.657902e+00*S66+1.063233e+00*S67+(-2.108673e+00)*S68+1.686753e+00*S69'
.param V34_part8='V34_part7+3.036694e-01*S70+(-2.237962e+00)*S71+1.714239e+00*S72+(-5.672303e+00)*S73+(-1.673371e+00)*S74+1.243466e+00*S75+4.235381e+00*S76+(-4.900584e+00)*S77+1.542124e+00*S78+2.683277e+00*S79'
.param V34='V34_part8+(-4.875031e-01)*S80+1.971173e+00*S81+2.177831e+00*S82+(-1.422319e+00)*S83+2.335141e+00*S84+8.942104e-01*S85+(-2.133245e+00)*S86+2.174313e+00*S87+1.013364e+00*S88+1.265883e+00*S89'
.param V35_part1='1.071599e+01*S0+2.838597e+01*S1+2.023145e+01*S2+1.486393e+01*S3+2.551688e+01*S4+1.655291e+01*S5+1.436070e+01*S6+3.111221e+01*S7+2.267410e+01*S8+1.891982e+01*S9'
.param V35_part2='V35_part1+1.345653e+01*S10+1.475927e+01*S11+1.633195e+01*S12+3.968087e+01*S13+1.050236e+01*S14+4.236340e+00*S15+9.219176e+00*S16+1.674569e+01*S17+1.517032e+01*S18+3.266672e+01*S19'
.param V35_part3='V35_part2+1.018075e+01*S20+3.652256e+01*S21+1.184940e+01*S22+1.506800e+01*S23+1.233424e+01*S24+1.584882e+01*S25+4.209936e+01*S26+2.320519e+01*S27+1.151487e+01*S28+9.180783e+00*S29'
.param V35_part4='V35_part3+6.435364e+01*S30+2.547664e+02*S31+6.175198e+03*S32+9.102853e+00*S33+4.026049e+03*S34+4.416484e+03*S35+2.331055e+01*S36+1.246181e+01*S37+1.212674e+01*S38+3.467396e+01*S39'
.param V35_part5='V35_part4+7.910781e+00*S40+8.085292e+01*S41+1.351163e+01*S42+5.772775e+00*S43+6.357745e+00*S44+1.517302e+02*S45+9.098729e+03*S46+6.253498e+00*S47+1.780030e+01*S48+1.427138e+01*S49'
.param V35_part6='V35_part5+1.112688e+01*S50+1.390502e+01*S51+7.436956e+00*S52+3.677538e+00*S53+7.846195e+00*S54+2.797211e+00*S55+4.808534e+00*S56+6.902973e+00*S57+2.565129e+00*S58+3.537611e+00*S59'
.param V35_part7='V35_part6+8.231167e+00*S60+7.501853e+00*S61+9.825784e+01*S62+3.511673e+01*S63+1.000000e+04*S64+4.161808e+00*S65+1.928935e+01*S66+9.154411e+00*S67+5.245452e+00*S68+1.372029e+01*S69'
.param V35_part8='V35_part7+4.961899e+00*S70+3.490237e+00*S71+1.789418e+01*S72+5.119861e+00*S73+2.725891e+00*S74+9.960866e+03*S75+5.854421e+00*S76+5.079629e+00*S77+1.000000e+04*S78+1.145133e+01*S79'
.param V35='V35_part8+4.431505e+00*S80+1.000000e+04*S81+1.007830e+02*S82+5.240853e+00*S83+1.000000e+04*S84+8.146467e-01*S85+5.116390e+00*S86+9.990846e+03*S87+6.293996e-01*S88+4.437814e+00*S89'
.param V36_part1='(-8.943451e+00)*S0+(-2.715600e+01)*S1+(-7.762091e+00)*S2+(-4.784572e+00)*S3+(-1.567169e+01)*S4+(-6.115370e+00)*S5+(-5.051633e+00)*S6+(-9.471570e+00)*S7+(-3.541384e+00)*S8+(-9.289441e+00)*S9'
.param V36_part2='V36_part1+(-4.537760e+00)*S10+(-3.459918e+00)*S11+(-4.594535e+00)*S12+1.009821e+01*S13+(-1.835356e+00)*S14+7.918586e+01*S15+(-4.479075e+00)*S16+(-7.786162e+00)*S17+(-3.697812e+00)*S18+(-8.803734e+00)*S19'
.param V36_part3='V36_part2+(-2.212595e+00)*S20+2.674036e+02*S21+(-6.602642e-01)*S22+(-5.067370e+00)*S23+(-3.316524e+00)*S24+(-5.257935e+00)*S25+(-1.423087e+01)*S26+(-1.148235e+01)*S27+(-2.504307e+00)*S28+(-3.046667e+00)*S29'
.param V36_part4='V36_part3+(-3.606016e+01)*S30+(-1.372904e+02)*S31+(-2.242319e+03)*S32+1.487013e+00*S33+3.848944e+02*S34+(-5.962510e+02)*S35+(-1.235979e+01)*S36+(-3.749686e+00)*S37+(-3.638576e+00)*S38+(-1.031952e+01)*S39'
.param V36_part5='V36_part4+(-2.841757e+00)*S40+(-2.239500e+01)*S41+(-6.288576e+00)*S42+(-8.115911e-01)*S43+(-1.509861e+00)*S44+1.246727e+02*S45+4.205898e+03*S46+(-1.872477e+00)*S47+7.322071e+01*S48+(-5.686054e+00)*S49'
.param V36_part6='V36_part5+(-2.971201e+00)*S50+(-4.556407e+00)*S51+(-1.870480e+00)*S52+(-7.398418e-01)*S53+(-2.254451e+00)*S54+1.257789e-01*S55+(-9.029260e-01)*S56+(-1.639957e+00)*S57+(-9.077148e-01)*S58+(-5.769801e-01)*S59'
.param V36_part7='V36_part6+(-2.983242e+00)*S60+(-2.538431e+00)*S61+5.833877e+00*S62+(-3.638990e+00)*S63+3.116635e+01*S64+(-1.823743e-01)*S65+(-2.189261e+00)*S66+(-1.159663e+00)*S67+9.792046e-01*S68+(-1.715149e+00)*S69'
.param V36_part8='V36_part7+(-1.542982e+00)*S70+(-5.837838e-01)*S71+(-5.947258e-01)*S72+(-1.120119e+00)*S73+(-4.516964e-01)*S74+1.062194e+02*S75+(-2.430316e+00)*S76+(-4.589576e-01)*S77+(-1.389864e+01)*S78+(-4.224921e+00)*S79'
.param V36='V36_part8+8.078618e-01*S80+(-1.959705e+01)*S81+(-2.837594e+01)*S82+3.564992e-01*S83+(-1.218227e+01)*S84+(-9.222771e-02)*S85+8.643411e-01*S86+1.335250e+00*S87+1.759153e-01*S88+(-2.617783e-01)*S89'
.param V37_part1='(-5.789752e+00)*S0+(-5.602056e+00)*S1+(-8.427634e+00)*S2+(-9.569453e+00)*S3+(-1.367893e+01)*S4+(-5.047537e+00)*S5+(-4.198662e+00)*S6+(-4.669371e-01)*S7+(-8.904888e+00)*S8+(-8.495003e+00)*S9'
.param V37_part2='V37_part1+2.006488e+00*S10+(-4.710375e+00)*S11+(-6.650177e+00)*S12+2.126400e+00*S13+(-3.577338e+00)*S14+6.220636e+01*S15+(-5.648617e+00)*S16+(-8.150561e+00)*S17+(-1.335214e+01)*S18+(-2.681732e+01)*S19'
.param V37_part3='V37_part2+(-4.048937e+00)*S20+1.773665e+02*S21+(-9.033573e+00)*S22+(-6.189941e+00)*S23+(-1.125428e+01)*S24+(-9.639362e+00)*S25+(-2.019480e+01)*S26+(-1.012537e+01)*S27+(-5.843531e+00)*S28+(-3.164654e+00)*S29'
.param V37_part4='V37_part3+(-5.065973e+01)*S30+(-1.706734e+01)*S31+2.052843e+02*S32+(-1.162141e+01)*S33+2.800641e+03*S34+1.504569e+03*S35+(-1.884573e+01)*S36+(-9.989333e+00)*S37+(-5.645491e+00)*S38+(-4.126069e+01)*S39'
.param V37_part5='V37_part4+(-3.907378e+00)*S40+(-4.813890e+01)*S41+(-7.068529e+00)*S42+(-2.369539e+00)*S43+(-1.782990e+00)*S44+9.000367e+01*S45+(-1.582536e+03)*S46+(-2.008477e+00)*S47+5.012942e+02*S48+(-1.154762e+01)*S49'
.param V37_part6='V37_part5+(-6.540713e+00)*S50+8.079965e-01*S51+(-3.653950e+00)*S52+(-1.096959e+00)*S53+(-1.180721e+00)*S54+(-1.673856e+00)*S55+(-1.609033e+00)*S56+(-1.485017e+00)*S57+(-7.278318e-01)*S58+(-1.649920e+00)*S59'
.param V37_part7='V37_part6+(-5.718923e+00)*S60+(-5.844911e+00)*S61+6.683595e+00*S62+2.150884e+00*S63+4.738214e+01*S64+(-1.908579e+00)*S65+2.011647e+00*S66+(-2.668081e+00)*S67+(-3.177734e+00)*S68+1.437906e+00*S69'
.param V37_part8='V37_part7+(-2.619511e+00)*S70+(-1.460990e+00)*S71+4.945217e+00*S72+(-2.970700e+00)*S73+(-9.140570e-01)*S74+2.736141e+02*S75+(-4.361325e+00)*S76+(-2.870130e+00)*S77+2.172683e+02*S78+(-8.657013e+00)*S79'
.param V37='V37_part8+(-2.369725e+00)*S80+2.016746e+02*S81+(-9.157098e+01)*S82+(-3.335926e+00)*S83+2.026626e+02*S84+2.123005e-01*S85+(-3.993609e+00)*S86+1.720773e+02*S87+2.910774e-01*S88+(-2.908573e+00)*S89'
.param V38_part1='1.497280e+00*S0+6.457943e+00*S1+(-1.176272e+00)*S2+1.442059e-01*S3+6.419686e-01*S4+(-1.199215e+00)*S5+1.210607e+00*S6+1.244651e+01*S7+(-6.337148e+00)*S8+5.876862e-01*S9'
.param V38_part2='V38_part1+4.433089e+00*S10+(-3.598777e+00)*S11+1.980160e+00*S12+3.254983e+01*S13+(-4.394080e-01)*S14+2.518272e+01*S15+5.221069e-01*S16+(-8.666657e-01)*S17+(-4.422768e-01)*S18+2.442227e+00*S19'
.param V38_part3='V38_part2+(-9.508736e-01)*S20+1.564450e+02*S21+(-7.915272e-01)*S22+(-1.600109e+00)*S23+(-8.224825e-01)*S24+(-4.758513e-02)*S25+(-9.746939e+00)*S26+(-4.795825e+00)*S27+(-1.213718e+00)*S28+(-5.229122e-01)*S29'
.param V38_part4='V38_part3+(-2.617851e+01)*S30+3.627312e+00*S31+(-5.257091e+01)*S32+(-2.319437e-01)*S33+7.411925e+01*S34+8.490675e+01*S35+(-6.928838e+00)*S36+(-1.527945e-01)*S37+(-1.439234e+00)*S38+(-4.908669e+00)*S39'
.param V38_part5='V38_part4+(-3.721676e-01)*S40+(-3.728793e+01)*S41+5.590888e-01*S42+1.033213e+00*S43+(-2.519818e-01)*S44+1.509434e+02*S45+8.918002e+03*S46+1.244796e+00*S47+1.220100e+02*S48+(-7.962171e-01)*S49'
.param V38_part6='V38_part5+3.743973e-01*S50+6.067374e+00*S51+1.577646e+00*S52+5.251281e-01*S53+2.588258e+00*S54+3.969836e-01*S55+6.617050e-01*S56+2.155499e+00*S57+1.590878e-02*S58+2.993929e-01*S59'
.param V38_part7='V38_part6+1.963002e+00*S60+(-4.112226e-01)*S61+8.613790e+01*S62+2.353240e+01*S63+9.981077e+03*S64+3.669755e-01*S65+1.131878e+01*S66+3.024161e+00*S67+3.004611e-01*S68+7.229228e+00*S69'
.param V38_part8='V38_part7+7.206598e-03*S70+8.392614e-03*S71+1.194456e+01*S72+2.846800e-01*S73+2.304351e-01*S74+1.000000e+04*S75+(-1.474449e-01)*S76+2.942058e-01*S77+9.999981e+03*S78+(-1.742160e+00)*S79'
.param V38='V38_part8+5.440192e-02*S80+9.991332e+03*S81+(-3.519163e+02)*S82+5.748209e-02*S83+9.995526e+03*S84+2.624645e-01*S85+1.673589e-01*S86+1.000000e+04*S87+3.052912e-01*S88+2.713927e-01*S89'
.param V39_part1='(-2.063710e-01)*S0+(-6.874412e-01)*S1+(-7.595873e-02)*S2+(-6.248758e-01)*S3+(-1.507762e-01)*S4+(-3.497422e-02)*S5+(-3.145909e-01)*S6+(-5.784924e-01)*S7+(-1.259665e-03)*S8+(-1.556521e-01)*S9'
.param V39_part2='V39_part1+(-8.712180e-02)*S10+6.001367e-03*S11+(-1.041099e-01)*S12+1.243393e-01*S13+(-2.373230e-02)*S14+(-8.314922e-01)*S15+6.014724e-02*S16+(-2.105892e-01)*S17+(-3.673594e-01)*S18+(-2.740077e-01)*S19'
.param V39_part3='V39_part2+(-8.084383e-03)*S20+1.307243e+01*S21+2.141230e-02*S22+(-1.660851e-01)*S23+(-1.957526e-01)*S24+(-4.010715e-01)*S25+(-4.778989e-01)*S26+1.748482e-01*S27+(-3.558080e-01)*S28+(-4.126476e-01)*S29'
.param V39_part4='V39_part3+(-9.674107e+00)*S30+(-2.191725e+02)*S31+(-1.000000e+04)*S32+5.644201e-01*S33+(-1.000000e+04)*S34+(-1.000000e+04)*S35+(-1.068784e+00)*S36+3.179222e-01*S37+(-4.026114e-01)*S38+(-3.694286e+00)*S39'
.param V39_part5='V39_part4+(-1.903598e-01)*S40+(-2.393742e-01)*S41+(-4.012691e-01)*S42+(-3.195841e-01)*S43+(-2.393543e-01)*S44+2.391682e+01*S45+(-1.945056e+00)*S46+(-1.957462e-01)*S47+1.399037e+01*S48+(-2.036790e+00)*S49'
.param V39_part6='V39_part5+3.477238e-01*S50+(-1.196228e-01)*S51+(-1.784061e-01)*S52+(-8.034871e-02)*S53+(-1.501970e-01)*S54+3.865462e-01*S55+8.427453e-02*S56+(-1.154699e-01)*S57+(-1.390052e-01)*S58+(-6.334253e-02)*S59'
.param V39_part7='V39_part6+(-3.847266e-01)*S60+(-2.602868e-01)*S61+1.374240e+00*S62+(-9.374404e-01)*S63+(-6.031030e+01)*S64+(-8.987814e-02)*S65+(-3.648736e-01)*S66+(-3.415230e-01)*S67+(-1.277186e-01)*S68+(-1.285234e-01)*S69'
.param V39_part8='V39_part7+(-1.891583e-01)*S70+(-6.439270e-02)*S71+1.302357e-01*S72+(-1.858434e-01)*S73+(-7.680326e-02)*S74+3.089518e+01*S75+(-2.628661e-01)*S76+(-1.111467e-01)*S77+2.709986e+01*S78+(-5.903392e-01)*S79'
.param V39='V39_part8+(-5.951387e-01)*S80+2.816207e+01*S81+(-7.828365e+00)*S82+(-5.994743e-01)*S83+2.822301e+01*S84+(-6.560217e-02)*S85+(-6.063732e-01)*S86+1.904211e+01*S87+(-4.335200e-02)*S88+(-6.710789e-01)*S89'
.param V40_part1='5.382091e+00*S0+5.893108e+00*S1+0.000000e+00*S2+4.006174e+00*S3+0.000000e+00*S4+0.000000e+00*S5+6.536242e+00*S6+1.896013e+01*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V40_part2='V40_part1+1.293426e+01*S10+8.499902e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+1.016248e+01*S15+0.000000e+00*S16+0.000000e+00*S17+4.795704e+00*S18+0.000000e+00*S19'
.param V40_part3='V40_part2+2.960387e+01*S20+1.971210e+01*S21+0.000000e+00*S22+6.013928e+00*S23+1.605124e+01*S24+(-2.070972e+01)*S25+0.000000e+00*S26+0.000000e+00*S27+1.153594e+01*S28+9.993078e+00*S29'
.param V40_part4='V40_part3+(-8.101316e-01)*S30+(-3.748484e+00)*S31+(-1.190175e+01)*S32+9.361998e+00*S33+(-2.454699e-01)*S34+(-1.484214e+01)*S35+(-3.626840e-01)*S36+(-1.420645e+01)*S37+1.314992e+01*S38+0.000000e+00*S39'
.param V40_part5='V40_part4+8.072099e+00*S40+8.317194e+00*S41+0.000000e+00*S42+0.000000e+00*S43+1.489202e+00*S44+1.404854e+01*S45+0.000000e+00*S46+1.039428e+01*S47+9.939136e+00*S48+(-2.597244e+01)*S49'
.param V40_part6='V40_part5+(-1.402256e+01)*S50+4.061491e+00*S51+(-1.160252e+01)*S52+(-1.909779e+01)*S53+(-2.168739e+00)*S54+5.718944e+00*S55+1.364131e+01*S56+(-4.428303e+00)*S57+(-3.326073e+01)*S58+0.000000e+00*S59'
.param V40_part7='V40_part6+3.108088e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V40_part8='V40_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+2.045586e+02*S74+7.907391e+00*S75+(-3.723178e-03)*S76+(-2.271600e+01)*S77+1.011063e+01*S78+(-6.799089e+00)*S79'
.param V40='V40_part8+(-3.259739e+02)*S80+1.658046e+01*S81+0.000000e+00*S82+(-5.140199e+02)*S83+1.846497e+01*S84+0.000000e+00*S85+(-4.745783e+02)*S86+5.297292e+01*S87+(-8.283131e+02)*S88+(-7.473772e+02)*S89'
.param V41_part1='3.727284e+01*S0+2.126119e+00*S1+0.000000e+00*S2+(-1.588500e+00)*S3+0.000000e+00*S4+0.000000e+00*S5+(-1.449770e+00)*S6+(-1.977752e+01)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V41_part2='V41_part1+5.176096e-01*S10+(-4.556135e+00)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+3.657755e+01*S15+0.000000e+00*S16+0.000000e+00*S17+(-2.414021e+01)*S18+0.000000e+00*S19'
.param V41_part3='V41_part2+(-3.047352e+01)*S20+(-2.703930e+01)*S21+0.000000e+00*S22+1.238647e+01*S23+3.642192e-01*S24+4.279544e+01*S25+0.000000e+00*S26+0.000000e+00*S27+5.068927e+00*S28+1.501699e+01*S29'
.param V41_part4='V41_part3+3.832233e+01*S30+3.881752e+01*S31+5.139526e+01*S32+3.627738e+01*S33+1.908828e+01*S34+7.688139e+01*S35+3.573707e+00*S36+2.805180e+01*S37+2.407110e+01*S38+0.000000e+00*S39'
.param V41_part5='V41_part4+6.031616e+00*S40+2.485562e+01*S41+0.000000e+00*S42+0.000000e+00*S43+3.204702e+01*S44+(-2.653534e+00)*S45+0.000000e+00*S46+6.301218e+01*S47+1.595311e+01*S48+7.739202e+01*S49'
.param V41_part6='V41_part5+9.128949e+01*S50+2.899196e+01*S51+4.632235e+01*S52+6.600609e+01*S53+3.313442e+01*S54+1.600625e+02*S55+7.561422e+01*S56+2.893129e+01*S57+2.134074e+02*S58+0.000000e+00*S59'
.param V41_part7='V41_part6+4.140947e+01*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V41_part8='V41_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-6.301164e+01)*S74+1.663966e+01*S75+5.213554e+01*S76+4.664818e+01*S77+9.524826e+00*S78+3.732750e+01*S79'
.param V41='V41_part8+3.635914e+02*S80+(-3.684866e+00)*S81+0.000000e+00*S82+4.212546e+02*S83+(-5.363863e+00)*S84+0.000000e+00*S85+2.820607e+02*S86+(-3.040789e+01)*S87+1.422798e+03*S88+7.720459e+02*S89'
.param V42_part1='1.737160e+01*S0+(-6.155625e+00)*S1+0.000000e+00*S2+8.710878e-01*S3+0.000000e+00*S4+0.000000e+00*S5+(-1.243918e+01)*S6+(-9.254460e+00)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V42_part2='V42_part1+(-1.666927e+01)*S10+(-4.944992e+00)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+8.669115e+00*S15+0.000000e+00*S16+0.000000e+00*S17+3.420373e+01*S18+0.000000e+00*S19'
.param V42_part3='V42_part2+(-5.208518e+00)*S20+(-6.068003e-01)*S21+0.000000e+00*S22+1.133769e+01*S23+9.291253e-01*S24+1.187977e+01*S25+0.000000e+00*S26+0.000000e+00*S27+2.365861e+01*S28+2.692081e-02*S29'
.param V42_part4='V42_part3+5.079106e+01*S30+4.656672e+01*S31+2.670268e+01*S32+4.867136e+01*S33+3.079668e+01*S34+2.960028e+01*S35+4.526167e+01*S36+6.393027e+01*S37+2.765975e+01*S38+0.000000e+00*S39'
.param V42_part5='V42_part4+1.563664e+01*S40+3.229309e+01*S41+0.000000e+00*S42+0.000000e+00*S43+3.837907e+01*S44+4.657162e+01*S45+0.000000e+00*S46+(-2.956706e+00)*S47+4.591436e+01*S48+6.568493e+01*S49'
.param V42_part6='V42_part5+4.061652e+01*S50+5.718609e+01*S51+7.498018e+01*S52+5.958795e+01*S53+7.106121e+01*S54+(-3.690804e+01)*S55+2.403595e+01*S56+9.018082e+01*S57+1.093869e+01*S58+0.000000e+00*S59'
.param V42_part7='V42_part6+7.014864e+01*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V42_part8='V42_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.120919e+02)*S74+6.549913e+01*S75+7.896135e+01*S76+1.059541e+02*S77+6.742213e+01*S78+8.914818e+01*S79'
.param V42='V42_part8+3.880966e+02*S80+7.012044e+01*S81+0.000000e+00*S82+5.747261e+02*S83+7.199293e+01*S84+0.000000e+00*S85+6.544323e+02*S86+4.695299e+01*S87+(-5.179371e+02)*S88+8.027078e+02*S89'
.param V43_part1='(-5.937076e+00)*S0+(-1.460646e+00)*S1+0.000000e+00*S2+(-2.967020e+00)*S3+0.000000e+00*S4+0.000000e+00*S5+(-1.003463e+00)*S6+(-1.466657e+00)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V43_part2='V43_part1+1.960305e-01*S10+(-9.521178e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-5.922653e+00)*S15+0.000000e+00*S16+0.000000e+00*S17+2.371429e-02*S18+0.000000e+00*S19'
.param V43_part3='V43_part2+5.492251e+00*S20+(-2.187715e+00)*S21+0.000000e+00*S22+4.026820e+00*S23+8.658647e+00*S24+(-2.454497e+00)*S25+0.000000e+00*S26+0.000000e+00*S27+8.796861e+00*S28+(-1.196269e+01)*S29'
.param V43_part4='V43_part3+(-5.679219e+00)*S30+(-5.764879e+00)*S31+(-6.791453e+00)*S32+(-1.096767e+01)*S33+(-5.875506e+00)*S34+(-8.374495e+00)*S35+(-1.004917e+01)*S36+(-1.337287e+01)*S37+(-8.928206e+00)*S38+0.000000e+00*S39'
.param V43_part5='V43_part4+(-1.474569e+01)*S40+(-1.377873e+01)*S41+0.000000e+00*S42+0.000000e+00*S43+(-1.634066e+01)*S44+(-7.722729e+00)*S45+0.000000e+00*S46+3.177605e-01*S47+(-8.309921e+00)*S48+(-5.107811e+00)*S49'
.param V43_part6='V43_part5+(-1.706669e+01)*S50+(-1.337230e+01)*S51+(-1.512605e+01)*S52+(-1.925038e+01)*S53+(-1.555622e+01)*S54+(-6.579430e+01)*S55+(-4.128134e+01)*S56+(-1.742630e+01)*S57+(-8.377370e+01)*S58+0.000000e+00*S59'
.param V43_part7='V43_part6+(-1.028320e+01)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V43_part8='V43_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.179641e+01)*S74+(-7.906930e+00)*S75+(-1.297652e+01)*S76+1.640838e+01*S77+(-9.190131e+00)*S78+(-1.177814e+01)*S79'
.param V43='V43_part8+(-2.775474e+01)*S80+(-9.591761e+00)*S81+0.000000e+00*S82+(-3.149129e+01)*S83+(-1.028791e+01)*S84+0.000000e+00*S85+(-4.655746e+01)*S86+(-1.224357e+01)*S87+(-8.581892e+01)*S88+(-9.214694e+01)*S89'
.param V44_part1='1.095776e+00*S0+3.056540e-01*S1+0.000000e+00*S2+1.452515e+00*S3+0.000000e+00*S4+0.000000e+00*S5+4.339979e-01*S6+(-8.215380e-02)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V44_part2='V44_part1+1.667794e-01*S10+(-6.157759e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-1.235006e+00)*S15+0.000000e+00*S16+0.000000e+00*S17+(-1.516599e-01)*S18+0.000000e+00*S19'
.param V44_part3='V44_part2+(-2.143870e+00)*S20+(-3.749333e-01)*S21+0.000000e+00*S22+(-1.188129e+00)*S23+(-1.123308e+00)*S24+7.391173e-01*S25+0.000000e+00*S26+0.000000e+00*S27+8.417695e-01*S28+5.003832e-01*S29'
.param V44_part4='V44_part3+6.264929e+00*S30+4.056935e+00*S31+1.339794e+00*S32+3.194862e+00*S33+1.452352e+00*S34+(-1.374520e-01)*S35+1.952725e+00*S36+1.005410e+00*S37+3.610609e+00*S38+0.000000e+00*S39'
.param V44_part5='V44_part4+(-2.428914e+00)*S40+(-3.462081e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-3.075726e+00)*S44+2.748433e+00*S45+0.000000e+00*S46+5.394110e+00*S47+2.168265e+00*S48+6.637076e+00*S49'
.param V44_part6='V44_part5+9.065315e+00*S50+3.845716e+00*S51+4.444231e+00*S52+1.120738e+01*S53+4.284693e+00*S54+2.351470e+01*S55+1.080653e+01*S56+4.766370e+00*S57+1.948111e+01*S58+0.000000e+00*S59'
.param V44_part7='V44_part6+4.357947e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V44_part8='V44_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-6.009446e+01)*S74+1.786264e-01*S75+2.746041e+00*S76+7.364666e+00*S77+1.612328e+00*S78+1.912529e+00*S79'
.param V44='V44_part8+(-1.659018e+01)*S80+2.004512e+00*S81+0.000000e+00*S82+(-5.270766e+01)*S83+(-1.210403e-01)*S84+0.000000e+00*S85+(-8.797704e+01)*S86+(-6.045596e-01)*S87+4.763724e+01*S88+4.042721e+01*S89'
.param V45_part1='0.000000e+00*S0+(-6.214290e-01)*S1+(-1.077798e+00)*S2+(-7.166255e-01)*S3+(-4.794247e-01)*S4+(-2.146682e+00)*S5+(-1.699986e+00)*S6+(-5.140237e+00)*S7+(-4.633853e+00)*S8+(-5.119411e-01)*S9'
.param V45_part2='V45_part1+(-6.260081e+00)*S10+(-4.490898e+00)*S11+(-1.985458e+00)*S12+(-6.586951e+00)*S13+(-5.288655e+00)*S14+0.000000e+00*S15+0.000000e+00*S16+(-3.100475e+00)*S17+(-1.344014e+00)*S18+(-2.973343e+00)*S19'
.param V45_part3='V45_part2+(-5.248666e+00)*S20+(-3.045670e+00)*S21+(-3.833406e+00)*S22+(-3.657199e+00)*S23+(-2.675813e+00)*S24+(-4.947139e+00)*S25+(-1.729389e+01)*S26+(-3.935597e+00)*S27+(-5.644249e+00)*S28+(-1.606083e+01)*S29'
.param V45_part4='V45_part3+(-4.602417e+00)*S30+(-1.138100e+01)*S31+(-2.580828e+01)*S32+(-2.408244e+00)*S33+(-1.314295e+01)*S34+(-3.376835e+01)*S35+(-3.599335e+00)*S36+(-9.240714e+00)*S37+(-1.855397e+01)*S38+8.419232e-01*S39'
.param V45_part5='V45_part4+(-1.786569e+00)*S40+(-2.159565e+01)*S41+(-1.626511e+00)*S42+0.000000e+00*S43+(-2.009837e+01)*S44+(-5.032920e+00)*S45+(-3.679762e+00)*S46+(-4.864396e+01)*S47+(-3.059158e+00)*S48+(-1.177965e+01)*S49'
.param V45_part6='V45_part5+(-4.316146e+01)*S50+(-1.244006e+01)*S51+(-2.984518e+01)*S52+(-3.773271e+01)*S53+(-1.777955e+01)*S54+(-1.099934e+01)*S55+(-5.781437e+01)*S56+(-2.039038e+01)*S57+(-1.550588e+01)*S58+(-9.162171e+01)*S59'
.param V45_part7='V45_part6+(-1.203454e+01)*S60+(-1.003589e+01)*S61+(-4.231773e+01)*S62+(-1.998736e+01)*S63+0.000000e+00*S64+0.000000e+00*S65+(-2.702846e+01)*S66+(-5.332370e+01)*S67+0.000000e+00*S68+(-3.272665e+01)*S69'
.param V45_part8='V45_part7+(-3.629984e+01)*S70+(-4.201142e+01)*S71+(-3.771955e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-2.407928e+00)*S75+(-2.181871e+01)*S76+(-4.514284e+01)*S77+(-2.531458e+00)*S78+(-2.089010e+01)*S79'
.param V45='V45_part8+(-5.411103e+01)*S80+(-4.048975e+00)*S81+(-2.530418e+01)*S82+(-5.753268e+01)*S83+(-7.022131e+00)*S84+(-3.195185e+01)*S85+(-7.887546e+01)*S86+(-9.752974e+00)*S87+(-4.007112e+01)*S88+(-5.619285e+01)*S89'
.param V46_part1='0.000000e+00*S0+3.750075e+00*S1+7.460141e+00*S2+4.328728e+00*S3+4.711123e+00*S4+7.475972e+00*S5+4.897861e+00*S6+9.649714e+00*S7+1.016127e+01*S8+3.718463e+00*S9'
.param V46_part2='V46_part1+8.361964e+00*S10+7.680053e+00*S11+5.538972e+00*S12+9.554481e+00*S13+8.561542e+00*S14+0.000000e+00*S15+0.000000e+00*S16+8.008386e+00*S17+1.000187e+01*S18+7.657208e+00*S19'
.param V46_part3='V46_part2+1.163901e+01*S20+7.749165e+00*S21+1.106744e+01*S22+6.651217e+00*S23+5.861128e+00*S24+8.340683e+00*S25+1.860987e+01*S26+3.906327e+00*S27+7.529822e+00*S28+1.391307e+01*S29'
.param V46_part4='V46_part3+1.073103e+01*S30+2.143092e+01*S31+3.811269e+01*S32+8.373826e+00*S33+2.634159e+01*S34+3.953143e+01*S35+1.003200e+01*S36+1.928204e+01*S37+1.671906e+01*S38+3.766744e+00*S39'
.param V46_part5='V46_part4+1.417770e+01*S40+1.379232e+01*S41+6.897077e-01*S42+0.000000e+00*S43+1.766693e+01*S44+2.080518e+01*S45+1.201376e+01*S46+5.888752e+01*S47+7.106198e+00*S48+2.473204e+01*S49'
.param V46_part6='V46_part5+5.497594e+01*S50+5.904600e+00*S51+2.520637e+01*S52+5.041382e+01*S53+1.038775e+01*S54+1.552224e+01*S55+5.275658e+01*S56+7.538216e+00*S57+1.726758e+01*S58+4.731022e+01*S59'
.param V46_part7='V46_part6+2.585388e+01*S60+4.832358e+01*S61+4.704943e+01*S62+2.942941e+01*S63+0.000000e+00*S64+0.000000e+00*S65+3.217567e+01*S66+3.329174e+01*S67+0.000000e+00*S68+3.122387e+01*S69'
.param V46_part8='V46_part7+3.825793e+01*S70+5.112857e+01*S71+3.048503e+01*S72+0.000000e+00*S73+0.000000e+00*S74+3.999975e+00*S75+4.027150e+01*S76+7.077319e+01*S77+2.875923e+00*S78+2.620818e+01*S79'
.param V46='V46_part8+6.364987e+01*S80+4.291108e+00*S81+2.700182e+01*S82+6.276294e+01*S83+6.620760e+00*S84+2.731475e+01*S85+7.273736e+01*S86+8.914423e+00*S87+2.459602e+01*S88+3.763973e+01*S89'
.param V47_part1='0.000000e+00*S0+3.746914e+00*S1+4.873326e+00*S2+3.083707e+00*S3+3.683883e+00*S4+5.787956e+00*S5+5.500905e+00*S6+7.936270e+00*S7+6.884815e+00*S8+4.207984e+00*S9'
.param V47_part2='V47_part1+1.077989e+01*S10+6.423917e+00*S11+5.404730e+00*S12+7.446653e+00*S13+5.967939e+00*S14+0.000000e+00*S15+0.000000e+00*S16+6.359124e+00*S17+3.760460e+00*S18+4.482225e+00*S19'
.param V47_part3='V47_part2+6.842965e+00*S20+6.191760e+00*S21+6.270642e+00*S22+6.967390e+00*S23+7.028897e+00*S24+1.611030e+01*S25+2.248604e+01*S26+1.406585e+01*S27+8.234143e+00*S28+2.152438e+01*S29'
.param V47_part4='V47_part3+2.097720e+01*S30+3.913827e+01*S31+6.078244e+01*S32+1.384635e+01*S33+4.637153e+01*S34+6.867247e+01*S35+1.162903e+01*S36+3.310628e+01*S37+2.306293e+01*S38+5.234169e+00*S39'
.param V47_part5='V47_part4+8.850058e+00*S40+2.905796e+01*S41+2.228050e+01*S42+0.000000e+00*S43+2.421474e+01*S44+5.824157e+00*S45+1.534202e+01*S46+6.959424e+01*S47+1.550940e+01*S48+4.386579e+01*S49'
.param V47_part6='V47_part5+7.617915e+01*S50+4.851698e+01*S51+6.334371e+01*S52+3.825905e+01*S53+5.869094e+01*S54+6.203397e+01*S55+9.352102e+01*S56+7.480069e+01*S57+6.697854e+01*S58+1.101618e+02*S59'
.param V47_part7='V47_part6+4.082659e+01*S60+1.295408e+01*S61+5.310279e+01*S62+5.096609e+01*S63+0.000000e+00*S64+0.000000e+00*S65+5.447649e+01*S66+1.093864e+02*S67+0.000000e+00*S68+5.974183e+01*S69'
.param V47_part8='V47_part7+6.248775e+01*S70+3.542906e+01*S71+6.281833e+01*S72+0.000000e+00*S73+0.000000e+00*S74+2.106576e+01*S75+4.459687e+01*S76+1.075199e+02*S77+2.522696e+01*S78+4.144894e+01*S79'
.param V47='V47_part8+1.378928e+02*S80+2.816180e+01*S81+4.097304e+01*S82+1.432237e+02*S83+3.020489e+01*S84+1.314337e+02*S85+1.603237e+02*S86+2.940259e+01*S87+1.567913e+02*S88+1.579500e+02*S89'
.param V48_part1='0.000000e+00*S0+1.026657e-01*S1+8.494662e-01*S2+(-6.119945e-02)*S3+(-2.787315e-01)*S4+7.579061e-01*S5+(-2.844876e-01)*S6+(-8.428966e-02)*S7+7.739219e-01*S8+(-6.917455e-01)*S9'
.param V48_part2='V48_part1+(-6.022550e-01)*S10+(-4.457613e-01)*S11+(-4.727627e-01)*S12+(-4.495490e-03)*S13+(-5.071229e-01)*S14+0.000000e+00*S15+0.000000e+00*S16+7.134675e-01*S17+(-3.611353e-01)*S18+(-6.318192e-01)*S19'
.param V48_part3='V48_part2+(-1.805083e+00)*S20+(-4.296868e-01)*S21+(-8.763584e-01)*S22+(-1.552461e-01)*S23+(-6.120741e-01)*S24+(-2.838157e-01)*S25+9.976797e-01*S26+8.707807e-02*S27+(-1.240674e+00)*S28+2.136848e+00*S29'
.param V48_part4='V48_part3+3.532791e-01*S30+2.098506e+00*S31+3.708599e+00*S32+8.317545e-01*S33+2.537021e+00*S34+3.433440e+00*S35+6.563991e-02*S36+2.348202e+00*S37+1.494069e+00*S38+(-1.164087e+00)*S39'
.param V48_part5='V48_part4+1.498287e+00*S40+1.325934e+00*S41+(-6.473535e-01)*S42+0.000000e+00*S43+2.378972e+00*S44+(-1.967168e-01)*S45+(-8.649864e-01)*S46+9.678523e-01*S47+(-3.448578e-01)*S48+8.316607e-01*S49'
.param V48_part6='V48_part5+1.674792e+00*S50+1.156078e+00*S51+1.933385e+00*S52+4.954180e-01*S53+6.358456e-01*S54+3.980699e+00*S55+2.966188e+00*S56+5.959457e-01*S57+2.109505e+00*S58+1.729090e-02*S59'
.param V48_part7='V48_part6+9.635455e-01*S60+1.763650e-01*S61+(-1.025984e+00)*S62+2.739651e-01*S63+0.000000e+00*S64+0.000000e+00*S65+1.063463e-01*S66+1.176310e+00*S67+0.000000e+00*S68+(-4.696406e-02)*S69'
.param V48_part8='V48_part7+1.900355e+00*S70+9.789026e-01*S71+1.183935e-01*S72+0.000000e+00*S73+0.000000e+00*S74+(-2.168622e-01)*S75+2.364938e-01*S76+3.532469e+00*S77+(-2.284995e-01)*S78+(-1.058227e+00)*S79'
.param V48='V48_part8+3.119207e+00*S80+(-3.506066e-01)*S81+(-2.202897e+00)*S82+3.243158e+00*S83+(-4.068226e-01)*S84+3.735166e+00*S85+4.014894e+00*S86+(-2.450562e-01)*S87+4.243322e+00*S88+8.366008e+00*S89'
.param V49_part1='0.000000e+00*S0+3.838819e-02*S1+1.097128e-01*S2+(-5.997004e-02)*S3+8.575519e-02*S4+1.276988e-01*S5+3.047942e-02*S6+1.487630e-01*S7+1.535802e-01*S8+6.954904e-02*S9'
.param V49_part2='V49_part1+1.229799e-01*S10+1.072462e-01*S11+8.861013e-02*S12+1.338620e-01*S13+9.471148e-02*S14+0.000000e+00*S15+0.000000e+00*S16+1.298000e+00*S17+4.180030e-01*S18+1.668335e+00*S19'
.param V49_part3='V49_part2+7.115754e-01*S20+3.257549e-01*S21+8.481758e-01*S22+5.115657e-01*S23+6.051561e-01*S24+6.363708e-01*S25+1.041140e+00*S26+2.526713e+00*S27+4.244750e-01*S28+5.024496e+00*S29'
.param V49_part4='V49_part3+2.726465e+00*S30+6.602064e-01*S31+2.443241e+00*S32+9.753702e-01*S33+1.364550e+00*S34+2.905204e+00*S35+4.880976e-02*S36+2.348511e+00*S37+8.963508e+00*S38+(-3.823715e-01)*S39'
.param V49_part5='V49_part4+3.159275e-01*S40+1.014896e+01*S41+3.204638e+00*S42+0.000000e+00*S43+7.661318e+00*S44+8.999558e-02*S45+7.320043e-01*S46+6.051142e+00*S47+9.671992e-01*S48+4.079756e+00*S49'
.param V49_part6='V49_part5+5.283678e+00*S50+1.625350e+00*S51+4.269397e+00*S52+1.266752e+01*S53+2.746318e+00*S54+2.147635e+00*S55+5.136667e+00*S56+3.315503e+00*S57+3.130899e+00*S58+1.639821e+00*S59'
.param V49_part7='V49_part6+2.925540e+00*S60+9.160842e+00*S61+5.045366e+00*S62+1.437651e+00*S63+0.000000e+00*S64+0.000000e+00*S65+1.560182e+00*S66+3.443443e+00*S67+0.000000e+00*S68+2.061839e+00*S69'
.param V49_part8='V49_part7+5.166408e+00*S70+1.176106e+01*S71+2.517340e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.331452e+00*S75+(-1.441127e+00)*S76+2.182386e+01*S77+2.628540e+00*S78+1.930057e+00*S79'
.param V49='V49_part8+1.253767e+01*S80+2.598689e+00*S81+3.176047e+00*S82+1.408448e+01*S83+2.490389e+00*S84+6.878664e+00*S85+1.561575e+01*S86+3.257572e+00*S87+7.537268e+00*S88+7.485513e+00*S89'
.param V50_part1='0.000000e+00*S0+0.000000e+00*S1+5.999283e-01*S2+0.000000e+00*S3+0.000000e+00*S4+4.004957e-01*S5+0.000000e+00*S6+8.539867e-01*S7+9.853063e-02*S8+0.000000e+00*S9'
.param V50_part2='V50_part1+7.664753e-01*S10+1.740175e-01*S11+9.249537e-02*S12+(-2.505480e-01)*S13+(-1.429917e-01)*S14+0.000000e+00*S15+1.045801e+00*S16+6.943940e-01*S17+4.225345e+00*S18+1.603422e+00*S19'
.param V50_part3='V50_part2+1.148210e+00*S20+2.336542e-01*S21+1.863511e+00*S22+7.228824e-01*S23+1.082890e+00*S24+2.527465e+00*S25+1.478254e+00*S26+7.791249e-01*S27+8.080839e-01*S28+2.044362e+00*S29'
.param V50_part4='V50_part3+8.453308e+00*S30+6.928445e+00*S31+3.201793e+00*S32+1.302084e+01*S33+5.269505e+00*S34+3.152574e+00*S35+2.871841e+00*S36+5.025271e+00*S37+1.939241e+00*S38+3.637461e+01*S39'
.param V50_part5='V50_part4+6.005935e+00*S40+1.544809e+00*S41+1.228666e+01*S42+8.556983e+00*S43+2.398442e+00*S44+2.635521e+00*S45+1.138500e+00*S46+5.748651e+00*S47+2.731766e+00*S48+5.424005e+00*S49'
.param V50_part6='V50_part5+3.213544e+00*S50+4.443475e+00*S51+7.130728e+00*S52+1.698090e+01*S53+6.071717e+00*S54+5.868409e+00*S55+3.549831e+00*S56+5.915318e+00*S57+8.605174e+00*S58+7.416688e+01*S59'
.param V50_part7='V50_part6+1.081044e+01*S60+6.321161e+00*S61+1.193266e+00*S62+3.120960e+00*S63+2.357649e+00*S64+9.624236e+00*S65+3.091539e+00*S66+3.532628e+00*S67+3.714352e+00*S68+3.002397e+00*S69'
.param V50_part8='V50_part7+9.506706e+00*S70+7.893138e+00*S71+2.329866e+00*S72+1.077721e+01*S73+5.682699e+01*S74+2.265319e+00*S75+8.512041e+00*S76+3.522298e+00*S77+2.161351e+00*S78+1.789067e+00*S79'
.param V50='V50_part8+2.560641e+00*S80+1.861720e+00*S81+1.008190e+00*S82+2.246956e+00*S83+1.437739e+00*S84+5.069487e+00*S85+2.162618e+00*S86+1.533748e+00*S87+6.997140e+00*S88+2.621338e+00*S89'
.param V51_part1='0.000000e+00*S0+0.000000e+00*S1+4.263663e-01*S2+0.000000e+00*S3+0.000000e+00*S4+2.286831e-01*S5+0.000000e+00*S6+(-5.601847e-01)*S7+4.564884e-01*S8+0.000000e+00*S9'
.param V51_part2='V51_part1+7.765294e-02*S10+1.291467e-01*S11+2.679541e-01*S12+3.870047e-01*S13+4.324171e-01*S14+0.000000e+00*S15+1.332109e+00*S16+9.920276e-02*S17+(-1.071156e+00)*S18+6.868700e-01*S19'
.param V51_part3='V51_part2+(-2.071848e-01)*S20+2.943887e-01*S21+(-1.215605e-01)*S22+2.275418e-01*S23+4.902279e-01*S24+(-2.508875e-01)*S25+(-2.021599e-01)*S26+(-5.894697e-02)*S27+2.044570e-01*S28+2.218330e-01*S29'
.param V51_part4='V51_part3+(-5.020978e+00)*S30+(-3.950064e+00)*S31+(-7.320350e-01)*S32+(-9.805636e+00)*S33+(-2.383144e+00)*S34+(-7.787281e-01)*S35+(-9.671035e-01)*S36+(-2.219957e+00)*S37+(-3.130330e-01)*S38+(-7.492744e-01)*S39'
.param V51_part5='V51_part4+(-1.087937e+00)*S40+(-4.098788e-01)*S41+1.171217e+00*S42+(-4.774663e+00)*S43+(-4.792693e-01)*S44+(-1.337941e+00)*S45+(-1.654309e+00)*S46+(-1.665259e+00)*S47+(-1.630885e+00)*S48+(-2.695643e+00)*S49'
.param V51_part6='V51_part5+(-1.135970e+00)*S50+(-2.074713e+00)*S51+(-3.293755e+00)*S52+(-3.350951e+00)*S53+(-2.639174e+00)*S54+(-2.494227e+00)*S55+(-1.218134e+00)*S56+(-2.666564e+00)*S57+1.123468e+00*S58+(-4.241281e+01)*S59'
.param V51_part7='V51_part6+(-4.522893e+00)*S60+(-6.911018e-02)*S61+(-1.121761e-01)*S62+(-1.491344e+00)*S63+(-1.087792e+00)*S64+(-6.236158e+00)*S65+(-1.317479e+00)*S66+(-1.513808e+00)*S67+(-2.334841e+00)*S68+(-1.171172e+00)*S69'
.param V51_part8='V51_part7+(-6.194528e-01)*S70+(-8.420356e-01)*S71+(-9.277904e-01)*S72+(-3.500642e+00)*S73+(-1.143405e+00)*S74+(-1.992618e+00)*S75+9.708131e-01*S76+(-1.843976e+00)*S77+(-1.877328e+00)*S78+2.488850e-01*S79'
.param V51='V51_part8+(-7.545429e-01)*S80+(-1.597871e+00)*S81+(-1.115957e-01)*S82+(-5.721476e-01)*S83+(-1.236285e+00)*S84+(-1.410210e+00)*S85+(-5.932914e-01)*S86+(-1.096837e+00)*S87+(-2.271871e+00)*S88+(-5.315762e-01)*S89'
.param V52_part1='0.000000e+00*S0+0.000000e+00*S1+2.594746e-01*S2+0.000000e+00*S3+0.000000e+00*S4+3.225009e-01*S5+0.000000e+00*S6+(-2.075374e-02)*S7+2.917635e-01*S8+0.000000e+00*S9'
.param V52_part2='V52_part1+1.403977e-01*S10+1.084476e-01*S11+(-8.069172e-02)*S12+2.360224e-01*S13+2.043494e-01*S14+0.000000e+00*S15+1.787882e-01*S16+7.423240e-02*S17+(-3.776465e+00)*S18+(-1.291390e+00)*S19'
.param V52_part3='V52_part2+(-4.267029e-01)*S20+(-5.432630e-03)*S21+(-2.443303e-01)*S22+1.275174e-01*S23+4.366588e-01*S24+4.029669e-02*S25+(-8.965327e-02)*S26+4.696738e-01*S27+4.737964e-01*S28+6.327340e-01*S29'
.param V52_part4='V52_part3+(-7.642398e+00)*S30+(-5.037211e+00)*S31+(-1.421141e+00)*S32+(-7.831980e+00)*S33+(-3.348252e+00)*S34+(-1.341192e+00)*S35+(-3.678244e-01)*S36+(-1.262654e+00)*S37+(-3.401557e-02)*S38+(-1.321977e+01)*S39'
.param V52_part5='V52_part4+(-1.563656e+00)*S40+(-2.747653e-01)*S41+(-1.186368e+01)*S42+(-3.059403e+00)*S43+(-4.164620e-02)*S44+(-2.223176e+00)*S45+(-1.505130e-01)*S46+(-2.912108e+00)*S47+(-1.588774e+00)*S48+(-2.577022e+00)*S49'
.param V52_part6='V52_part5+(-8.550060e-01)*S50+(-3.055358e+00)*S51+(-3.939932e+00)*S52+(-1.062990e+01)*S53+(-4.072755e+00)*S54+(-2.752538e+00)*S55+(-9.451834e-01)*S56+(-2.604112e+00)*S57+(-6.836804e+00)*S58+(-1.708283e+01)*S59'
.param V52_part7='V52_part6+(-1.274426e+01)*S60+(-2.017293e+00)*S61+(-4.076483e-01)*S62+(-2.583654e+00)*S63+(-1.478104e+00)*S64+(-4.122283e+00)*S65+(-2.293545e+00)*S66+(-1.759895e+00)*S67+(-9.019131e-01)*S68+(-1.990670e+00)*S69'
.param V52_part8='V52_part7+(-2.557075e-01)*S70+(-3.154450e-01)*S71+(-9.800852e-01)*S72+(-3.416796e+00)*S73+(-4.521022e+01)*S74+(-1.467322e+00)*S75+(-1.860213e+00)*S76+(-7.559003e-01)*S77+(-8.913360e-01)*S78+(-1.290542e-01)*S79'
.param V52='V52_part8+(-9.228174e-01)*S80+(-1.330204e-01)*S81+(-8.838520e-02)*S82+(-6.703371e-01)*S83+6.101818e-01*S84+(-3.026711e+00)*S85+(-5.420921e-01)*S86+3.634170e-01*S87+(-4.098655e+00)*S88+(-7.800703e-01)*S89'
.param V53_part1='0.000000e+00*S0+0.000000e+00*S1+8.978972e-01*S2+0.000000e+00*S3+0.000000e+00*S4+7.080964e-01*S5+0.000000e+00*S6+(-8.117281e-01)*S7+5.186033e-01*S8+0.000000e+00*S9'
.param V53_part2='V53_part1+(-9.438341e-01)*S10+2.618474e-01*S11+2.425930e-01*S12+1.304641e-01*S13+3.056480e-01*S14+0.000000e+00*S15+6.784134e-01*S16+6.567741e-01*S17+9.379994e-01*S18+(-1.189391e+00)*S19'
.param V53_part3='V53_part2+3.583451e-01*S20+3.680778e-01*S21+7.485716e-01*S22+6.720861e-01*S23+1.448301e+00*S24+8.257621e-01*S25+4.272589e-01*S26+6.516671e-01*S27+8.468948e-01*S28+1.528300e+00*S29'
.param V53_part4='V53_part3+3.054902e-01*S30+1.892035e-02*S31+1.346976e-01*S32+1.022247e+00*S33+1.349830e-01*S34+1.416473e-01*S35+1.052285e+00*S36+6.725789e-01*S37+7.847554e-01*S38+(-2.627339e-01)*S39'
.param V53_part5='V53_part4+2.346419e+00*S40+2.547794e-01*S41+(-5.585435e-01)*S42+(-2.651651e-01)*S43+5.885368e-01*S44+2.292330e-01*S45+1.652325e-01*S46+(-6.648285e-01)*S47+2.877378e-01*S48+6.493647e-01*S49'
.param V53_part6='V53_part5+2.551480e-01*S50+(-1.208497e-01)*S51+(-7.996428e-01)*S52+(-4.332229e+00)*S53+(-8.417595e-01)*S54+2.984941e-01*S55+1.626788e-01*S56+(-8.938536e-01)*S57+(-1.702788e+00)*S58+(-1.621021e+01)*S59'
.param V53_part7='V53_part6+(-2.797961e+00)*S60+2.722822e+00*S61+4.026988e-02*S62+(-1.444201e-02)*S63+9.547992e-02*S64+(-1.544924e-01)*S65+(-8.007380e-02)*S66+(-2.591550e-01)*S67+2.225796e-01*S68+(-1.079386e-01)*S69'
.param V53_part8='V53_part7+5.247437e+00*S70+3.861887e+00*S71+4.675391e-03*S72+7.721726e-01*S73+(-6.614773e+01)*S74+2.440454e-01*S75+4.501311e+00*S76+1.726636e-01*S77+2.148487e-01*S78+6.942831e-01*S79'
.param V53='V53_part8+1.658241e-01*S80+2.009094e-01*S81+1.793582e-01*S82+1.486843e-01*S83+1.896272e-01*S84+3.212762e-01*S85+1.236214e-01*S86+1.750780e-01*S87+2.852460e-01*S88+1.694369e-01*S89'
.param V54_part1='0.000000e+00*S0+0.000000e+00*S1+3.551115e-03*S2+0.000000e+00*S3+0.000000e+00*S4+9.331879e-03*S5+0.000000e+00*S6+(-3.335430e-04)*S7+7.406676e-03*S8+0.000000e+00*S9'
.param V54_part2='V54_part1+(-1.491921e-02)*S10+(-3.149074e-04)*S11+1.841727e-03*S12+(-6.921623e-03)*S13+1.249246e-03*S14+0.000000e+00*S15+3.771385e-01*S16+1.765442e-02*S17+(-2.559344e-02)*S18+(-3.005541e-01)*S19'
.param V54_part3='V54_part2+(-9.049903e-03)*S20+1.329515e-02*S21+1.112451e-02*S22+9.022603e-04*S23+7.668274e-02*S24+3.698312e-04*S25+(-5.673178e-03)*S26+4.773694e-02*S27+3.590813e-02*S28+5.012207e-01*S29'
.param V54_part4='V54_part3+1.838155e-01*S30+(-1.884483e-01)*S31+(-5.975739e-02)*S32+(-1.104289e+00)*S33+(-1.567146e-01)*S34+(-7.275512e-02)*S35+(-2.013055e-01)*S36+(-3.068492e-01)*S37+3.348162e-01*S38+(-5.975214e+01)*S39'
.param V54_part5='V54_part4+(-1.876940e-01)*S40+(-1.272394e-02)*S41+(-1.066484e+01)*S42+(-7.435938e-01)*S43+(-2.234734e-02)*S44+(-1.931989e-01)*S45+(-3.468772e-02)*S46+(-1.421366e-01)*S47+(-1.115887e-01)*S48+(-1.082504e-01)*S49'
.param V54_part6='V54_part5+(-2.741636e-01)*S50+(-1.069766e-01)*S51+(-3.589668e-01)*S52+(-1.332326e-01)*S53+(-1.775436e-01)*S54+(-3.427203e-01)*S55+(-1.570309e-01)*S56+(-1.617430e-01)*S57+(-4.695097e-01)*S58+(-2.448765e+00)*S59'
.param V54_part7='V54_part6+(-6.976367e-01)*S60+1.070038e-01*S61+(-5.460580e-02)*S62+(-9.840960e-02)*S63+(-3.995539e-01)*S64+(-9.424372e-01)*S65+(-6.420586e-02)*S66+(-7.596938e-02)*S67+(-5.610870e-01)*S68+(-3.716737e-02)*S69'
.param V54_part8='V54_part7+(-6.520946e-02)*S70+(-7.853825e-02)*S71+2.103234e-02*S72+(-6.867925e+00)*S73+(-1.969424e+00)*S74+(-1.690267e-01)*S75+(-4.769739e-01)*S76+(-4.316873e-01)*S77+(-5.442020e-02)*S78+(-9.615300e-02)*S79'
.param V54='V54_part8+(-6.196557e-02)*S80+(-1.182383e-02)*S81+(-7.810606e-02)*S82+(-6.601937e-02)*S83+(-1.663807e-02)*S84+(-2.400431e-01)*S85+(-6.377536e-02)*S86+3.257051e-02*S87+(-2.134732e-01)*S88+(-5.902501e-02)*S89'
.param V55_part1='0.000000e+00*S0+0.000000e+00*S1+1.805024e+02*S2+0.000000e+00*S3+0.000000e+00*S4+2.853678e+02*S5+0.000000e+00*S6+2.831864e+01*S7+3.231287e+02*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+1.063682e+02*S10+3.242539e+02*S11+9.475796e+02*S12+2.488827e+02*S13+4.285266e+02*S14+0.000000e+00*S15+2.252827e+02*S16+7.755036e+01*S17+2.152464e+01*S18+(-1.610923e+02)*S19'
.param V55_part3='V55_part2+(-1.071275e+02)*S20+1.224389e+03*S21+9.610851e+01*S22+1.819813e+01*S23+(-1.817204e+01)*S24+7.574827e+01*S25+3.444815e+01*S26+7.845312e+01*S27+(-1.043120e+01)*S28+(-4.011591e+00)*S29'
.param V55_part4='V55_part3+0.000000e+00*S30+0.000000e+00*S31+8.486027e-01*S32+0.000000e+00*S33+(-1.199591e+01)*S34+(-2.550336e+01)*S35+3.704386e+01*S36+1.167223e+01*S37+0.000000e+00*S38+(-4.199894e+02)*S39'
.param V55_part5='V55_part4+(-9.152605e+00)*S40+0.000000e+00*S41+(-2.513650e+00)*S42+(-3.228566e+00)*S43+0.000000e+00*S44+0.000000e+00*S45+2.991185e+02*S46+(-3.211251e+01)*S47+0.000000e+00*S48+1.470624e+01*S49'
.param V55_part6='V55_part5+(-2.540729e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+(-1.215160e+02)*S56+0.000000e+00*S57+0.000000e+00*S58+(-8.698702e+00)*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+2.714317e+01*S61+1.795617e+02*S62+5.675624e+00*S63+3.506775e+01*S64+4.588980e+01*S65+(-3.066658e+00)*S66+(-8.731304e+00)*S67+2.108812e+01*S68+(-2.003658e+01)*S69'
.param V55_part8='V55_part7+(-1.306282e+02)*S70+(-4.292845e+01)*S71+(-1.745512e+01)*S72+(-1.254222e+02)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-7.150341e+01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V55='V55_part8+(-5.448211e+00)*S80+0.000000e+00*S81+3.045143e+02*S82+2.743184e+01*S83+0.000000e+00*S84+(-3.230975e+01)*S85+(-1.766486e+02)*S86+0.000000e+00*S87+(-9.738074e+01)*S88+0.000000e+00*S89'
.param V56_part1='0.000000e+00*S0+0.000000e+00*S1+(-6.128257e+01)*S2+0.000000e+00*S3+0.000000e+00*S4+(-8.354135e+01)*S5+0.000000e+00*S6+1.879093e+02*S7+(-1.696371e+02)*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+(-6.354725e+01)*S10+(-1.406161e+02)*S11+(-3.701950e+02)*S12+5.331056e+00*S13+(-1.684059e+02)*S14+0.000000e+00*S15+(-2.566378e+02)*S16+1.160107e+02*S17+1.268962e+02*S18+8.467013e+02*S19'
.param V56_part3='V56_part2+2.882550e+02*S20+(-9.677367e+02)*S21+(-1.541170e+01)*S22+2.142998e+01*S23+4.314517e+01*S24+(-5.340351e+01)*S25+4.777883e+01*S26+5.229806e+01*S27+3.473597e+01*S28+2.815934e+01*S29'
.param V56_part4='V56_part3+0.000000e+00*S30+0.000000e+00*S31+8.144001e+00*S32+0.000000e+00*S33+4.224688e+01*S34+2.524655e+01*S35+3.912578e+01*S36+3.951458e+01*S37+0.000000e+00*S38+4.834678e+02*S39'
.param V56_part5='V56_part4+4.758408e+01*S40+0.000000e+00*S41+8.358019e+01*S42+8.151100e+01*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.831599e+02)*S46+(-9.191994e+00)*S47+0.000000e+00*S48+4.235818e+00*S49'
.param V56_part6='V56_part5+4.798702e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.066616e+02*S56+0.000000e+00*S57+0.000000e+00*S58+1.404887e+02*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+4.169835e+01*S61+5.173060e+00*S62+1.248249e+02*S63+2.154339e+02*S64+4.894882e+01*S65+1.246975e+02*S66+1.432364e+02*S67+1.824694e+02*S68+1.369040e+02*S69'
.param V56_part8='V56_part7+1.949264e+02*S70+1.294189e+02*S71+1.430966e+02*S72+3.342679e+02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.666080e+02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V56='V56_part8+1.176793e+02*S80+0.000000e+00*S81+(-9.379147e+01)*S82+1.606776e+02*S83+0.000000e+00*S84+3.493385e+01*S85+3.768492e+02*S86+0.000000e+00*S87+1.714806e+00*S88+0.000000e+00*S89'
.param V57_part1='0.000000e+00*S0+0.000000e+00*S1+1.362295e+01*S2+0.000000e+00*S3+0.000000e+00*S4+(-7.197113e+01)*S5+0.000000e+00*S6+7.484503e+00*S7+(-6.252689e+01)*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+1.057374e+02*S10+1.371746e+01*S11+(-8.712074e+02)*S12+(-1.261606e+02)*S13+(-2.469445e+01)*S14+0.000000e+00*S15+1.590945e+01*S16+5.805699e+01*S17+(-3.607498e+01)*S18+2.726783e+02*S19'
.param V57_part3='V57_part2+1.048322e+02*S20+(-4.614821e+02)*S21+5.987584e+01*S22+2.146824e+01*S23+1.321092e+02*S24+2.796012e+01*S25+4.406210e+01*S26+3.040988e+01*S27+7.798439e+00*S28+4.828012e+01*S29'
.param V57_part4='V57_part3+0.000000e+00*S30+0.000000e+00*S31+4.577772e+01*S32+0.000000e+00*S33+3.456066e+01*S34+6.095504e+01*S35+(-4.486210e+01)*S36+(-7.777883e+00)*S37+0.000000e+00*S38+1.826734e+03*S39'
.param V57_part5='V57_part4+5.068315e+01*S40+0.000000e+00*S41+2.299773e+02*S42+9.847218e+01*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.115303e+02)*S46+1.190047e+02*S47+0.000000e+00*S48+2.423533e+01*S49'
.param V57_part6='V57_part5+5.573339e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.147164e+02*S56+0.000000e+00*S57+0.000000e+00*S58+1.118950e+01*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+1.102720e+02*S61+7.220487e+00*S62+1.308811e+02*S63+4.316931e+01*S64+1.223135e+02*S65+1.343176e+02*S66+1.188738e+02*S67+8.853768e+01*S68+1.355737e+02*S69'
.param V57_part8='V57_part7+2.597758e+02*S70+1.303567e+02*S71+9.259107e+01*S72+6.544758e+01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.152455e+02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V57='V57_part8+3.067163e+01*S80+0.000000e+00*S81+(-1.370450e+02)*S82+(-4.253355e+01)*S83+0.000000e+00*S84+9.706777e+01*S85+8.373354e+00*S86+0.000000e+00*S87+4.170466e+02*S88+0.000000e+00*S89'
.param V58_part1='0.000000e+00*S0+0.000000e+00*S1+(-9.151437e+01)*S2+0.000000e+00*S3+0.000000e+00*S4+(-8.029905e+01)*S5+0.000000e+00*S6+(-7.847217e+01)*S7+(-6.781743e+01)*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+(-6.436690e+01)*S10+3.374414e+01*S11+(-1.188643e+02)*S12+(-1.990717e+01)*S13+(-5.439809e+01)*S14+0.000000e+00*S15+(-7.895980e+01)*S16+(-9.466697e+01)*S17+(-3.852971e+01)*S18+(-1.065347e+02)*S19'
.param V58_part3='V58_part2+(-1.052708e+02)*S20+6.964478e+01*S21+(-4.463669e+01)*S22+(-3.203341e+01)*S23+(-1.035303e+02)*S24+(-2.320014e+01)*S25+(-3.457760e+01)*S26+(-4.441003e+01)*S27+(-4.547164e+01)*S28+(-9.904893e+00)*S29'
.param V58_part4='V58_part3+0.000000e+00*S30+0.000000e+00*S31+(-7.101123e+00)*S32+0.000000e+00*S33+(-1.437178e+00)*S34+(-1.356301e+01)*S35+6.626431e+00*S36+(-6.602488e+00)*S37+0.000000e+00*S38+1.895155e+01*S39'
.param V58_part5='V58_part4+(-3.716408e+00)*S40+0.000000e+00*S41+(-4.652283e+01)*S42+(-4.327200e+01)*S43+0.000000e+00*S44+0.000000e+00*S45+(-6.436520e+01)*S46+(-2.388047e+01)*S47+0.000000e+00*S48+(-1.513070e+01)*S49'
.param V58_part6='V58_part5+(-1.806828e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+(-9.888430e+00)*S56+0.000000e+00*S57+0.000000e+00*S58+(-2.356070e+01)*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+(-3.117010e+01)*S61+(-5.297954e+01)*S62+(-2.878395e+01)*S63+(-4.997676e+01)*S64+(-4.738796e+01)*S65+(-3.048495e+01)*S66+(-3.296415e+01)*S67+(-8.937675e+01)*S68+(-3.270324e+01)*S69'
.param V58_part8='V58_part7+(-4.466351e+01)*S70+(-5.510441e+01)*S71+(-4.361217e+01)*S72+(-1.047945e+02)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-5.090301e+01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V58='V58_part8+(-4.310134e+01)*S80+0.000000e+00*S81+(-7.477919e+01)*S82+(-5.020327e+01)*S83+0.000000e+00*S84+(-4.981539e+00)*S85+(-4.829270e+01)*S86+0.000000e+00*S87+(-2.544566e+00)*S88+0.000000e+00*S89'
.param V59_part1='0.000000e+00*S0+0.000000e+00*S1+7.215020e-01*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.383443e+00)*S5+0.000000e+00*S6+(-1.141871e+00)*S7+(-2.083349e+00)*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+(-1.955171e+00)*S10+(-2.438508e+00)*S11+(-8.821802e-01)*S12+(-5.494996e-01)*S13+(-1.647709e+00)*S14+0.000000e+00*S15+(-4.272425e+01)*S16+2.029382e+01*S17+2.081253e+00*S18+3.202659e+01*S19'
.param V59_part3='V59_part2+1.968616e+01*S20+(-3.985805e+01)*S21+1.322183e+00*S22+8.221600e+00*S23+7.918591e+00*S24+(-1.056801e-02)*S25+9.686256e-01*S26+4.377069e+00*S27+2.871183e+00*S28+(-1.949997e+00)*S29'
.param V59_part4='V59_part3+0.000000e+00*S30+0.000000e+00*S31+3.032288e+00*S32+0.000000e+00*S33+3.070818e+00*S34+6.894269e+00*S35+(-6.762477e-01)*S36+5.008025e+00*S37+0.000000e+00*S38+1.567669e+02*S39'
.param V59_part5='V59_part4+8.722314e+00*S40+0.000000e+00*S41+1.453413e+01*S42+9.328861e+00*S43+0.000000e+00*S44+0.000000e+00*S45+(-2.885012e+01)*S46+(-4.178162e+00)*S47+0.000000e+00*S48+2.566704e+00*S49'
.param V59_part6='V59_part5+2.772282e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+5.114161e+00*S56+0.000000e+00*S57+0.000000e+00*S58+(-4.772489e+00)*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+3.617154e+00*S61+7.010362e+00*S62+(-5.625679e+00)*S63+1.150244e+01*S64+3.147729e+01*S65+(-9.562879e+00)*S66+(-7.798505e+00)*S67+5.050503e+01*S68+(-1.342366e+01)*S69'
.param V59_part8='V59_part7+1.075174e+01*S70+(-6.008526e+00)*S71+(-2.310099e+01)*S72+(-5.150679e+01)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+3.893836e+01*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V59='V59_part8+3.592797e+01*S80+0.000000e+00*S81+1.336385e+01*S82+6.262612e+01*S83+0.000000e+00*S84+1.781298e+01*S85+8.837676e+01*S86+0.000000e+00*S87+3.313263e+01*S88+0.000000e+00*S89'
.param V60_part1='9.842716e+00*S0+7.111865e+00*S1+(-2.203989e+01)*S2+4.934591e+01*S3+2.772996e+01*S4+(-5.513631e+01)*S5+1.055041e+02*S6+1.211522e+02*S7+1.414044e+02*S8+4.700914e+01*S9'
.param V60_part2='V60_part1+3.020984e+03*S10+4.799348e+02*S11+6.860892e+01*S12+8.485159e+01*S13+3.331636e+02*S14+(-6.078757e+01)*S15+(-1.260290e+02)*S16+1.617721e+01*S17+(-4.984019e+02)*S18+8.380413e+01*S19'
.param V60_part3='V60_part2+6.771873e+03*S20+1.108673e+03*S21+5.075346e+02*S22+1.000000e+04*S23+6.885895e+02*S24+3.826988e+03*S25+3.687608e+03*S26+6.457455e+00*S27+5.485222e+03*S28+7.700379e+00*S29'
.param V60_part4='V60_part3+1.452988e+01*S30+2.896520e+01*S31+1.657840e+01*S32+(-7.974543e+01)*S33+3.514171e+01*S34+1.357988e+01*S35+6.602920e+00*S36+5.150823e+00*S37+3.402763e+00*S38+1.455884e+00*S39'
.param V60_part5='V60_part4+4.522281e+00*S40+6.480099e+00*S41+3.829124e-01*S42+1.605961e+01*S43+8.446857e+03*S44+5.024394e+03*S45+3.984104e+03*S46+1.087851e+02*S47+1.781340e+01*S48+4.942269e+03*S49'
.param V60_part6='V60_part5+1.992851e+01*S50+(-1.833907e-01)*S51+(-2.589790e+00)*S52+6.562815e+02*S53+(-1.469949e+00)*S54+5.920921e+01*S55+6.571408e+02*S56+(-1.489235e+00)*S57+2.391987e+01*S58+2.087417e+02*S59'
.param V60_part7='V60_part6+1.054122e+01*S60+3.299108e+02*S61+5.676407e+00*S62+5.229649e+01*S63+(-1.731270e+00)*S64+9.178928e+00*S65+1.103522e+02*S66+8.866329e+00*S67+(-8.427708e+00)*S68+5.001349e+03*S69'
.param V60_part8='V60_part7+4.743043e+03*S70+1.141863e+00*S71+5.001726e+03*S72+1.370107e-01*S73+4.688267e-01*S74+5.154521e+02*S75+1.402670e+00*S76+5.013269e+03*S77+5.001347e+03*S78+1.932885e+00*S79'
.param V60='V60_part8+5.023881e+03*S80+5.001018e+03*S81+2.679610e+00*S82+5.028220e+03*S83+5.000664e+03*S84+9.525666e+03*S85+5.024178e+03*S86+4.825115e+03*S87+1.000000e+04*S88+5.040702e+03*S89'
.param V61_part1='3.087057e+00*S0+5.726140e+01*S1+1.175383e+02*S2+3.756184e+01*S3+9.427923e+01*S4+2.684017e+02*S5+1.587676e+02*S6+6.255156e+00*S7+4.565362e+02*S8+(-5.011743e+01)*S9'
.param V61_part2='V61_part1+5.110955e+03*S10+4.799348e+02*S11+(-5.575499e+01)*S12+4.177744e+00*S13+(-2.024305e+02)*S14+6.654040e+02*S15+6.110881e+02*S16+(-9.195256e+00)*S17+2.088521e+03*S18+(-8.301307e+01)*S19'
.param V61_part3='V61_part2+6.212184e+03*S20+(-7.350971e+02)*S21+5.690952e+00*S22+1.000000e+04*S23+(-3.883000e+01)*S24+6.556278e+02*S25+(-2.212074e+02)*S26+(-2.262961e-01)*S27+(-1.669124e+02)*S28+(-9.604788e-01)*S29'
.param V61_part4='V61_part3+(-3.374345e+00)*S30+(-2.200890e+00)*S31+4.369768e+00*S32+3.536974e+02*S33+2.121479e+00*S34+(-4.792504e+00)*S35+9.438263e+00*S36+7.496077e+01*S37+(-9.943087e-01)*S38+(-1.804405e-01)*S39'
.param V61_part5='V61_part4+1.061800e+00*S40+5.542809e+00*S41+(-1.267497e-01)*S42+2.035016e-01*S43+6.918526e+02*S44+(-4.807185e+01)*S45+(-6.618667e+00)*S46+1.069435e+01*S47+(-7.186676e+00)*S48+5.949162e+01*S49'
.param V61_part6='V61_part5+(-1.107967e+01)*S50+1.770957e+00*S51+5.287449e+00*S52+(-5.068165e+00)*S53+3.319677e+00*S54+1.752520e+01*S55+1.787831e+01*S56+2.607268e+00*S57+6.519092e+03*S58+5.744723e+00*S59'
.param V61_part7='V61_part6+(-3.886825e+00)*S60+(-2.138900e+01)*S61+1.700375e+00*S62+(-2.221440e+00)*S63+(-6.638516e-01)*S64+(-6.842490e-01)*S65+2.845157e-01*S66+(-1.173963e+00)*S67+2.032963e+00*S68+6.621789e-01*S69'
.param V61_part8='V61_part7+(-9.944932e+03)*S70+(-1.096117e-02)*S71+3.977452e-01*S72+3.534059e-01*S73+3.115715e-01*S74+(-3.583232e+00)*S75+3.664394e+00*S76+(-7.092368e+00)*S77+(-1.130796e+00)*S78+2.880881e+00*S79'
.param V61='V61_part8+(-1.229743e+01)*S80+(-4.146866e-01)*S81+3.075246e+00*S82+(-1.401247e+01)*S83+(-5.418188e-02)*S84+9.086958e+01*S85+(-7.823818e-01)*S86+(-5.870512e-02)*S87+5.113679e+00*S88+(-8.190977e-01)*S89'
.param V62_part1='1.056683e+01*S0+4.919703e+00*S1+3.235587e+01*S2+(-4.964978e+00)*S3+1.285760e+01*S4+2.220532e+01*S5+5.105066e+01*S6+3.200974e+02*S7+8.139755e+01*S8+1.332828e+02*S9'
.param V62_part2='V62_part1+7.608763e+03*S10+4.799348e+02*S11+9.899203e+01*S12+5.759813e+02*S13+6.794335e+03*S14+7.651561e+01*S15+1.424698e+02*S16+(-2.870538e+00)*S17+1.440898e+02*S18+(-3.554446e+01)*S19'
.param V62_part3='V62_part2+6.255508e+03*S20+(-1.096895e+02)*S21+1.721031e+03*S22+(-8.608982e+02)*S23+(-1.585598e+02)*S24+3.843913e+03*S25+(-1.101071e+02)*S26+(-5.073211e+00)*S27+(-3.474178e+02)*S28+(-3.897655e+00)*S29'
.param V62_part4='V62_part3+(-1.615978e+01)*S30+(-2.668677e+01)*S31+(-9.081133e+00)*S32+6.502243e+01*S33+(-3.224132e+01)*S34+(-6.574420e+00)*S35+(-6.156925e+00)*S36+(-3.332791e+01)*S37+(-1.432448e+00)*S38+(-1.174434e+00)*S39'
.param V62_part5='V62_part4+(-5.781021e+00)*S40+(-5.793387e+00)*S41+1.023035e+00*S42+(-1.903221e+01)*S43+(-8.531838e+02)*S44+(-8.020647e+00)*S45+(-2.079803e+02)*S46+(-1.617888e+01)*S47+(-6.576505e-01)*S48+1.790276e+02*S49'
.param V62_part6='V62_part5+2.188985e-01*S50+9.190730e-01*S51+5.340218e+00*S52+(-7.795496e+00)*S53+2.350507e+00*S54+1.146588e+01*S55+2.124373e+01*S56+2.656337e+00*S57+(-7.098362e+01)*S58+1.647869e+01*S59'
.param V62_part7='V62_part6+(-1.818821e+00)*S60+3.180184e-01*S61+(-3.728939e-02)*S62+(-4.821437e-01)*S63+7.287481e+00*S64+(-6.548949e+00)*S65+(-2.018964e+00)*S66+4.718866e+00*S67+1.609242e+01*S68+(-2.120005e+00)*S69'
.param V62_part8='V62_part7+9.843609e+03*S70+(-7.608838e-01)*S71+(-2.800052e+00)*S72+(-2.432940e-01)*S73+8.387290e-01*S74+(-4.362302e-01)*S75+9.398116e-01*S76+(-6.221089e+00)*S77+(-6.279469e-01)*S78+1.140404e+00*S79'
.param V62='V62_part8+(-9.521287e+00)*S80+(-6.318864e-01)*S81+5.851373e-01*S82+(-1.265563e+01)*S83+(-3.704516e-01)*S84+5.028700e+03*S85+(-1.782303e+01)*S86+(-6.085770e-01)*S87+1.710454e+03*S88+(-3.604202e+01)*S89'
.param V63_part1='1.027400e+01*S0+1.359443e+01*S1+1.834419e+01*S2+5.158498e+01*S3+5.093242e+01*S4+3.154695e+01*S5+1.768117e+02*S6+(-6.401342e+03)*S7+3.572883e+02*S8+(-1.640331e+01)*S9'
.param V63_part2='V63_part1+(-1.000000e+04)*S10+(-4.547462e+02)*S11+9.438479e+00*S12+(-5.202529e+03)*S13+(-1.909470e+02)*S14+1.861051e+01*S15+1.558526e+01*S16+(-1.473599e+00)*S17+1.383564e+02*S18+(-2.331427e+01)*S19'
.param V63_part3='V63_part2+(-3.235790e+03)*S20+6.938622e+00*S21+3.688193e+00*S22+(-1.950159e+01)*S23+(-1.313577e+01)*S24+(-2.252277e+02)*S25+(-5.676983e+00)*S26+(-4.641824e-01)*S27+(-5.790415e+00)*S28+(-1.593215e-01)*S29'
.param V63_part4='V63_part3+(-8.816291e-01)*S30+(-8.810240e-01)*S31+(-4.753321e-01)*S32+4.021281e+00*S33+(-1.302721e+00)*S34+(-1.997621e-01)*S35+(-8.072002e-01)*S36+5.457621e-01*S37+(-5.293132e-02)*S38+(-8.596206e-02)*S39'
.param V63_part5='V63_part4+(-4.858056e-02)*S40+3.518386e-01*S41+8.574019e-03*S42+(-3.666511e-01)*S43+3.114642e+03*S44+(-2.562259e-01)*S45+(-2.018056e-01)*S46+(-4.343171e-01)*S47+1.090834e-01*S48+(-1.661769e+01)*S49'
.param V63_part6='V63_part5+8.858914e-03*S50+(-4.087804e-02)*S51+(-3.523579e-01)*S52+2.749057e-01*S53+(-3.327868e-02)*S54+1.623230e+00*S55+7.300071e-01*S56+(-4.498376e-02)*S57+4.154354e+03*S58+(-1.914084e-01)*S59'
.param V63_part7='V63_part6+1.624218e-01*S60+1.029907e-01*S61+7.890472e-02*S62+8.410483e-02*S63+4.770896e-02*S64+(-1.769340e-01)*S65+9.002201e-02*S66+(-1.302512e-01)*S67+1.866048e-01*S68+1.189174e-01*S69'
.param V63_part8='V63_part7+3.618920e+02*S70+4.129511e-02*S71+5.631474e-02*S72+4.585919e-02*S73+4.133780e-02*S74+1.044785e-01*S75+5.525699e-02*S76+4.797201e-01*S77+1.378203e-01*S78+1.315559e-02*S79'
.param V63='V63_part8+1.623517e+00*S80+1.302942e-01*S81+7.875483e-03*S82+1.207698e+00*S83+1.247849e-01*S84+(-3.035032e+03)*S85+7.615356e-01*S86+1.018941e-01*S87+(-4.497010e+00)*S88+1.011461e+00*S89'
.param V64_part1='2.167250e+00*S0+1.701994e+00*S1+7.765982e-01*S2+1.995617e-01*S3+1.191893e+00*S4+7.802609e-02*S5+(-1.549016e+00)*S6+2.121344e+01*S7+1.058224e+01*S8+1.421679e+00*S9'
.param V64_part2='V64_part1+(-2.667369e+02)*S10+7.407145e+01*S11+1.293987e-01*S12+1.334693e+01*S13+5.880487e+01*S14+7.932514e+01*S15+9.875220e+00*S16+3.532720e+00*S17+3.569460e+01*S18+(-1.517921e-01)*S19'
.param V64_part3='V64_part2+(-1.000000e+04)*S20+8.682939e+02*S21+1.823684e+03*S22+(-2.932878e+00)*S23+9.504417e+02*S24+(-1.000000e+04)*S25+6.640594e+03*S26+1.547724e+00*S27+1.000000e+04*S28+8.733762e-01*S29'
.param V64_part4='V64_part3+1.503032e+00*S30+1.241218e+00*S31+5.869665e-01*S32+(-2.238434e+01)*S33+(-4.514077e-01)*S34+(-1.546484e-01)*S35+(-9.969701e+00)*S36+(-4.981833e+00)*S37+8.592713e-01*S38+6.187299e-01*S39'
.param V64_part5='V64_part4+8.170627e-02*S40+(-3.615536e+00)*S41+4.344261e-01*S42+3.739558e+00*S43+(-1.000000e+04)*S44+1.000000e+04*S45+7.653435e+03*S46+(-1.676941e+02)*S47+2.595103e+01*S48+(-1.000000e+04)*S49'
.param V64_part6='V64_part5+(-1.326837e+01)*S50+(-5.112746e-01)*S51+(-2.089916e+00)*S52+1.284697e+03*S53+(-1.067910e+00)*S54+(-1.400042e+02)*S55+(-1.348779e+03)*S56+(-1.165122e+00)*S57+(-1.194826e+03)*S58+(-4.463073e+02)*S59'
.param V64_part7='V64_part6+1.463582e+01*S60+6.432457e+02*S61+(-9.007570e+00)*S62+9.943937e+01*S63+9.312895e-01*S64+2.432586e+00*S65+2.172461e+02*S66+1.563291e+01*S67+5.625024e+00*S68+1.000000e+04*S69'
.param V64_part8='V64_part7+(-5.529101e+01)*S70+1.509948e-02*S71+1.000000e+04*S72+1.225425e-01*S73+2.148286e+00*S74+1.027015e+03*S75+(-3.802274e+00)*S76+1.000000e+04*S77+1.000000e+04*S78+(-5.709137e+00)*S79'
.param V64='V64_part8+1.000000e+04*S80+1.000000e+04*S81+(-7.857977e+00)*S82+1.000000e+04*S83+1.000000e+04*S84+(-2.922351e+03)*S85+1.000000e+04*S86+9.648819e+03*S87+(-7.538139e+02)*S88+1.000000e+04*S89'
.param V65_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-4.699324e-02)*S9'
.param V65_part2='V65_part1+0.000000e+00*S10+(-1.061297e-01)*S11+(-2.015664e-02)*S12+(-1.351703e-02)*S13+(-5.417927e-02)*S14+(-1.408370e-01)*S15+0.000000e+00*S16+(-1.784577e-01)*S17+0.000000e+00*S18+(-1.484938e-01)*S19'
.param V65_part3='V65_part2+(-1.620802e-01)*S20+(-1.717903e-02)*S21+0.000000e+00*S22+(-3.328686e-01)*S23+(-7.485159e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+(-8.167906e-02)*S27+(-1.950981e-01)*S28+(-3.084197e-01)*S29'
.param V65_part4='V65_part3+(-1.646450e-01)*S30+(-1.548746e-01)*S31+0.000000e+00*S32+0.000000e+00*S33+(-1.441174e-01)*S34+0.000000e+00*S35+9.767059e-03*S36+0.000000e+00*S37+(-8.397419e-01)*S38+9.999291e-02*S39'
.param V65_part5='V65_part4+(-1.059596e+00)*S40+(-2.340671e-01)*S41+5.717555e-01*S42+(-7.438453e-02)*S43+4.654606e-01*S44+1.870049e-01*S45+(-2.065993e-01)*S46+(-4.546054e-02)*S47+(-2.237466e-01)*S48+0.000000e+00*S49'
.param V65_part6='V65_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+5.621722e+00*S59'
.param V65_part7='V65_part6+0.000000e+00*S60+4.407707e-01*S61+(-1.668525e+00)*S62+3.093891e+00*S63+(-2.089148e-01)*S64+(-3.289056e+00)*S65+4.794773e+00*S66+8.103486e+00*S67+(-1.375226e+00)*S68+6.447054e+00*S69'
.param V65_part8='V65_part7+0.000000e+00*S70+0.000000e+00*S71+7.299615e+00*S72+(-6.651542e+00)*S73+0.000000e+00*S74+(-6.600499e-01)*S75+2.968600e+00*S76+(-2.132287e+00)*S77+(-9.059298e-01)*S78+(-3.048777e+00)*S79'
.param V65='V65_part8+0.000000e+00*S80+(-1.173035e+00)*S81+(-5.199802e+00)*S82+0.000000e+00*S83+(-1.420282e+00)*S84+0.000000e+00*S85+0.000000e+00*S86+(-1.131524e+00)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V66_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+1.699527e-01*S9'
.param V66_part2='V66_part1+0.000000e+00*S10+1.383118e-01*S11+1.127204e-01*S12+5.547312e-02*S13+7.018935e-02*S14+8.503402e-01*S15+0.000000e+00*S16+7.948890e-01*S17+0.000000e+00*S18+7.134840e-01*S19'
.param V66_part3='V66_part2+3.532158e-01*S20+2.215365e-01*S21+0.000000e+00*S22+6.192367e-01*S23+2.557969e-01*S24+0.000000e+00*S25+0.000000e+00*S26+6.771175e-01*S27+3.501691e-01*S28+8.331748e-01*S29'
.param V66_part4='V66_part3+1.062434e+00*S30+6.935847e-01*S31+0.000000e+00*S32+0.000000e+00*S33+5.462243e-01*S34+0.000000e+00*S35+3.256550e-01*S36+0.000000e+00*S37+3.009299e+00*S38+3.163086e+00*S39'
.param V66_part5='V66_part4+6.317951e-01*S40+2.527212e+00*S41+4.282379e+00*S42+2.919563e+00*S43+3.036461e+00*S44+(-2.967274e-01)*S45+5.559003e-01*S46+7.244090e-01*S47+1.486578e+00*S48+0.000000e+00*S49'
.param V66_part6='V66_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+1.207617e+00*S59'
.param V66_part7='V66_part6+0.000000e+00*S60+(-1.960965e+00)*S61+6.395900e+00*S62+(-1.573034e+00)*S63+1.014462e+01*S64+1.188414e+01*S65+(-2.794832e+00)*S66+(-1.402568e+00)*S67+1.023330e+01*S68+(-3.323699e+00)*S69'
.param V66_part8='V66_part7+0.000000e+00*S70+0.000000e+00*S71+(-3.571797e+00)*S72+1.676346e+01*S73+0.000000e+00*S74+2.678444e+00*S75+1.888414e+00*S76+2.223426e+00*S77+2.548378e+00*S78+6.641040e+00*S79'
.param V66='V66_part8+0.000000e+00*S80+2.346341e+00*S81+6.520352e+00*S82+0.000000e+00*S83+2.288350e+00*S84+0.000000e+00*S85+0.000000e+00*S86+2.018321e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V67_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-4.308368e-02)*S9'
.param V67_part2='V67_part1+0.000000e+00*S10+6.996950e-02*S11+(-2.815939e-02)*S12+4.974308e-02*S13+7.802860e-02*S14+(-6.237575e-02)*S15+0.000000e+00*S16+2.740979e-01*S17+0.000000e+00*S18+2.789123e-01*S19'
.param V67_part3='V67_part2+1.611928e-01*S20+1.847688e-01*S21+0.000000e+00*S22+2.756779e-01*S23+1.747610e-01*S24+0.000000e+00*S25+0.000000e+00*S26+4.735762e-01*S27+4.372063e-01*S28+7.223828e-01*S29'
.param V67_part4='V67_part3+6.062225e-01*S30+4.636839e-01*S31+0.000000e+00*S32+0.000000e+00*S33+5.323239e-01*S34+0.000000e+00*S35+1.716026e+00*S36+0.000000e+00*S37+1.814059e+00*S38+1.092883e+00*S39'
.param V67_part5='V67_part4+3.493534e+00*S40+1.555197e+00*S41+(-2.188205e+00)*S42+1.356327e+00*S43+1.871016e-01*S44+2.267305e+00*S45+8.469557e-01*S46+5.403739e-01*S47+2.790157e+00*S48+0.000000e+00*S49'
.param V67_part6='V67_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+(-4.490557e+00)*S59'
.param V67_part7='V67_part6+0.000000e+00*S60+6.100321e-01*S61+4.924725e+00*S62+(-1.792342e+00)*S63+4.864799e+00*S64+6.827997e+00*S65+(-9.828904e-01)*S66+(-9.135954e+00)*S67+5.801664e+00*S68+(-1.551186e-01)*S69'
.param V67_part8='V67_part7+0.000000e+00*S70+0.000000e+00*S71+3.327757e+00*S72+1.001520e+01*S73+0.000000e+00*S74+5.170241e+00*S75+(-1.841718e+00)*S76+3.168535e+00*S77+7.201388e+00*S78+1.084421e+01*S79'
.param V67='V67_part8+0.000000e+00*S80+9.603104e+00*S81+1.823310e+01*S82+0.000000e+00*S83+1.187591e+01*S84+0.000000e+00*S85+0.000000e+00*S86+1.483731e+01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V68_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+5.071178e-02*S9'
.param V68_part2='V68_part1+0.000000e+00*S10+3.285214e-02*S11+3.010131e-02*S12+4.027931e-02*S13+2.440022e-02*S14+1.764398e-02*S15+0.000000e+00*S16+(-8.578586e-03)*S17+0.000000e+00*S18+3.218115e-02*S19'
.param V68_part3='V68_part2+(-2.780561e-03)*S20+3.485282e-02*S21+0.000000e+00*S22+(-2.204562e-02)*S23+(-1.812865e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+(-2.589034e-02)*S27+1.686120e-02*S28+1.928277e-02*S29'
.param V68_part4='V68_part3+6.435647e-02*S30+2.451145e-02*S31+0.000000e+00*S32+0.000000e+00*S33+2.425655e-02*S34+0.000000e+00*S35+7.433314e-02*S36+0.000000e+00*S37+(-2.007028e-01)*S38+(-1.873705e-01)*S39'
.param V68_part5='V68_part4+(-7.617828e-02)*S40+(-3.373581e-01)*S41+(-4.000545e-01)*S42+(-3.071648e-01)*S43+(-2.406808e-01)*S44+1.401335e-02*S45+2.037141e-02*S46+(-1.615314e-01)*S47+7.679964e-02*S48+0.000000e+00*S49'
.param V68_part6='V68_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+(-2.937278e-01)*S59'
.param V68_part7='V68_part6+0.000000e+00*S60+2.805843e-03*S61+(-2.162529e-01)*S62+(-1.583482e-01)*S63+(-6.751597e-01)*S64+(-6.281101e-01)*S65+(-2.217441e-01)*S66+(-4.055246e-01)*S67+(-4.659118e-01)*S68+(-3.173261e-01)*S69'
.param V68_part8='V68_part7+0.000000e+00*S70+0.000000e+00*S71+(-3.608016e-01)*S72+(-1.756161e+00)*S73+0.000000e+00*S74+6.245185e-02*S75+(-1.064106e-01)*S76+(-3.291128e-01)*S77+3.043834e-02*S78+5.652517e-02*S79'
.param V68='V68_part8+0.000000e+00*S80+3.028743e-02*S81+7.579257e-02*S82+0.000000e+00*S83+(-2.279506e-02)*S84+0.000000e+00*S85+0.000000e+00*S86+3.836763e-03*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V69_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+2.849982e-03*S9'
.param V69_part2='V69_part1+0.000000e+00*S10+2.762243e-03*S11+1.805537e-03*S12+1.249938e-03*S13+2.092554e-03*S14+1.912343e-02*S15+0.000000e+00*S16+(-3.968260e-02)*S17+0.000000e+00*S18+(-3.630159e-02)*S19'
.param V69_part3='V69_part2+6.820266e-03*S20+2.451840e-03*S21+0.000000e+00*S22+9.435607e-03*S23+(-2.048616e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+(-2.373854e-01)*S27+(-6.289514e-03)*S28+(-3.669088e-01)*S29'
.param V69_part4='V69_part3+(-1.038835e-01)*S30+(-1.256618e-01)*S31+0.000000e+00*S32+0.000000e+00*S33+(-1.156843e-01)*S34+0.000000e+00*S35+2.089602e-01*S36+0.000000e+00*S37+(-1.026400e+00)*S38+(-1.663785e+00)*S39'
.param V69_part5='V69_part4+2.102497e-01*S40+(-1.345256e+00)*S41+(-2.327902e+00)*S42+(-1.577282e+00)*S43+(-2.065060e-01)*S44+2.860040e-02*S45+2.178547e-02*S46+3.066642e-02*S47+(-1.591675e-01)*S48+0.000000e+00*S49'
.param V69_part6='V69_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+4.718808e-01*S59'
.param V69_part7='V69_part6+0.000000e+00*S60+(-6.854527e-03)*S61+9.621126e-01*S62+4.474755e-01*S63+(-2.655025e+00)*S64+(-3.391683e+00)*S65+6.125060e-01*S66+3.167575e-01*S67+(-4.594563e+00)*S68+6.905062e-01*S69'
.param V69_part8='V69_part7+0.000000e+00*S70+0.000000e+00*S71+7.388946e-01*S72+(-2.761098e+00)*S73+0.000000e+00*S74+(-2.314254e-01)*S75+2.392326e+00*S76+(-7.618934e-01)*S77+(-2.324447e-01)*S78+2.219362e+00*S79'
.param V69='V69_part8+0.000000e+00*S80+(-2.473938e-01)*S81+2.376604e+00*S82+0.000000e+00*S83+(-3.256239e-01)*S84+0.000000e+00*S85+0.000000e+00*S86+(-3.344944e-01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V70_part1='7.333603e+01*S0+3.158881e+01*S1+8.572629e+03*S2+2.516274e+02*S3+5.726446e+00*S4+2.240142e+02*S5+2.497432e-01*S6+2.917211e+00*S7+2.469562e+01*S8+6.564601e+01*S9'
.param V70_part2='V70_part1+1.002376e+01*S10+3.305237e+01*S11+4.611233e+01*S12+1.028612e+01*S13+2.266796e+02*S14+9.495071e+00*S15+3.196067e+01*S16+1.300697e+01*S17+8.205837e+01*S18+4.860114e+00*S19'
.param V70_part3='V70_part2+2.849240e+01*S20+8.633953e+00*S21+1.174973e+02*S22+9.958355e+00*S23+1.738737e+01*S24+6.293831e+03*S25+3.971028e+00*S26+6.251062e+00*S27+1.172531e+01*S28+1.986254e+00*S29'
.param V70_part4='V70_part3+(-4.944391e+02)*S30+(-1.716471e+03)*S31+4.730952e+03*S32+5.118757e+03*S33+5.018002e+03*S34+5.654546e+03*S35+5.271995e+00*S36+3.964867e+03*S37+1.348008e+00*S38+9.849668e+00*S39'
.param V70_part5='V70_part4+3.928386e+03*S40+4.862008e-01*S41+2.184759e+00*S42+2.954015e-01*S43+3.432829e-01*S44+1.992171e+00*S45+6.278263e+00*S46+8.785658e+00*S47+1.418261e+00*S48+4.953685e+01*S49'
.param V70_part6='V70_part5+1.213182e+02*S50+4.950306e+03*S51+6.091962e+00*S52+1.846296e+00*S53+3.902067e+00*S54+1.000000e+04*S55+3.226388e+01*S56+3.202205e+00*S57+8.622211e+00*S58+8.057358e-01*S59'
.param V70_part7='V70_part6+(-1.065321e+00)*S60+2.095899e+00*S61+1.699324e+00*S62+(-5.995858e-01)*S63+1.003879e+00*S64+4.822232e-01*S65+(-7.341598e-01)*S66+(-1.299383e+00)*S67+6.403812e-01*S68+(-8.292027e-01)*S69'
.param V70_part8='V70_part7+1.177708e-01*S70+1.268121e+01*S71+(-6.066330e-01)*S72+(-5.262456e-01)*S73+8.605630e+00*S74+1.789593e+00*S75+5.273913e+00*S76+9.656763e+00*S77+1.363392e+00*S78+4.634012e+00*S79'
.param V70='V70_part8+2.110916e+02*S80+1.367162e+00*S81+2.597329e+00*S82+1.854308e+02*S83+1.629226e+00*S84+1.968350e+01*S85+1.328815e+02*S86+7.939043e-01*S87+1.032908e+01*S88+2.225850e+01*S89'
.param V71_part1='5.465184e+01*S0+5.829853e+00*S1+(-5.962099e+01)*S2+(-1.822261e+02)*S3+1.182994e+02*S4+(-6.430554e+01)*S5+1.601658e+02*S6+1.658907e+01*S7+(-4.524176e+00)*S8+3.978975e+01*S9'
.param V71_part2='V71_part1+2.451068e+01*S10+(-9.846102e+00)*S11+(-9.990768e+00)*S12+(-4.672628e-01)*S13+(-4.350777e-01)*S14+(-1.095466e+01)*S15+2.338822e+01*S16+(-6.897649e-01)*S17+(-3.173166e+01)*S18+1.498179e+00*S19'
.param V71_part3='V71_part2+5.170766e-01*S20+(-1.428355e+00)*S21+3.805740e+01*S22+(-3.618377e+00)*S23+1.107049e+00*S24+(-1.042992e+03)*S25+(-1.264589e+00)*S26+(-9.754660e-01)*S27+6.535664e-01*S28+(-1.242024e+00)*S29'
.param V71_part4='V71_part3+8.762625e+03*S30+1.000000e+04*S31+1.899102e+03*S32+5.671122e+01*S33+1.810847e+03*S34+3.705643e+02*S35+(-5.240481e-01)*S36+4.341741e+01*S37+(-3.361419e-01)*S38+(-4.191112e+00)*S39'
.param V71_part5='V71_part4+1.468980e+01*S40+(-6.614843e-03)*S41+(-1.463294e+00)*S42+(-6.987777e-03)*S43+(-1.758026e-01)*S44+1.558781e+00*S45+4.322939e+00*S46+(-2.075238e+00)*S47+1.191877e+00*S48+2.082238e+01*S49'
.param V71_part6='V71_part5+(-6.299047e+01)*S50+(-1.831727e+00)*S51+(-1.399464e+00)*S52+(-7.104590e-03)*S53+3.808451e-01*S54+1.000000e+04*S55+1.084229e+01*S56+4.271979e-01*S57+(-3.160629e+00)*S58+(-9.452843e-01)*S59'
.param V71_part7='V71_part6+7.728512e+00*S60+1.769230e+00*S61+(-5.051795e-01)*S62+2.881320e+00*S63+5.131390e-03*S64+(-4.938173e-01)*S65+2.389600e+00*S66+2.657490e+00*S67+7.558099e-02*S68+2.017702e+00*S69'
.param V71_part8='V71_part7+7.467982e-02*S70+(-1.340251e+01)*S71+1.560879e+00*S72+(-4.623701e-01)*S73+(-1.376904e-01)*S74+2.573518e+00*S75+(-3.394760e-01)*S76+2.123016e+00*S77+2.518389e+00*S78+(-2.836809e+00)*S79'
.param V71='V71_part8+(-3.907563e+00)*S80+2.280933e+00*S81+(-9.690281e-01)*S82+(-2.054663e-02)*S83+1.814062e+00*S84+(-7.064002e-01)*S85+(-4.355524e+00)*S86+1.785609e+00*S87+(-8.765627e-01)*S88+(-9.715133e-02)*S89'
.param V72_part1='(-1.354927e+02)*S0+(-2.171327e+01)*S1+1.183819e+00*S2+1.340492e+02*S3+1.095864e+01*S4+7.455885e+00*S5+(-5.557552e+00)*S6+(-9.857393e-01)*S7+(-3.854937e+00)*S8+(-6.776892e+01)*S9'
.param V72_part2='V72_part1+(-1.157828e+01)*S10+(-4.406201e+00)*S11+1.464635e+01*S12+(-4.753639e+00)*S13+(-4.132838e+00)*S14+(-3.384101e+00)*S15+1.534817e+02*S16+(-4.015480e-01)*S17+(-4.001406e+01)*S18+(-9.164516e-01)*S19'
.param V72_part3='V72_part2+(-1.262825e+01)*S20+(-7.476575e+00)*S21+(-1.376492e+02)*S22+(-2.543749e+00)*S23+2.096958e+01*S24+(-5.040428e+02)*S25+(-1.175038e+00)*S26+1.898562e+00*S27+(-1.091696e+01)*S28+4.044702e+00*S29'
.param V72_part4='V72_part3+(-5.604556e+02)*S30+3.738203e+02*S31+5.421014e+02*S32+(-2.170295e+02)*S33+(-8.590158e+02)*S34+(-4.795814e+02)*S35+(-8.090878e+00)*S36+5.394323e+01*S37+2.049299e-01*S38+(-1.793243e+00)*S39'
.param V72_part5='V72_part4+3.019006e+00*S40+(-3.680083e-02)*S41+9.631480e+00*S42+1.020817e+00*S43+1.495508e-01*S44+(-3.394029e+00)*S45+(-7.254255e+00)*S46+(-6.126226e+00)*S47+(-2.858036e+00)*S48+(-6.545820e+01)*S49'
.param V72_part6='V72_part5+(-3.336761e+01)*S50+1.618110e+00*S51+(-9.992107e-01)*S52+(-1.309241e+00)*S53+1.123837e+00*S54+1.000000e+04*S55+(-3.417124e+01)*S56+1.579637e+00*S57+(-3.769911e+00)*S58+1.192882e+00*S59'
.param V72_part7='V72_part6+3.634562e+00*S60+(-3.326476e+00)*S61+(-1.144218e+00)*S62+9.887875e-01*S63+(-1.110330e+00)*S64+7.309448e-01*S65+4.555738e-01*S66+1.513829e+00*S67+(-6.742021e-03)*S68+1.996345e-01*S69'
.param V72_part8='V72_part7+4.404853e-03*S70+1.752648e+01*S71+(-5.022444e-01)*S72+6.956673e+00*S73+(-7.236690e+00)*S74+(-3.690492e+00)*S75+(-7.213525e+00)*S76+(-8.455686e+00)*S77+(-3.588635e+00)*S78+(-4.852304e+00)*S79'
.param V72='V72_part8+(-1.993893e+02)*S80+(-4.249685e+00)*S81+(-2.717333e+00)*S82+(-1.749552e+02)*S83+(-4.999273e+00)*S84+(-1.367483e+01)*S85+(-1.191165e+02)*S86+(-3.824528e+00)*S87+(-7.137670e+00)*S88+(-1.633827e+01)*S89'
.param V73_part1='(-2.853879e+03)*S0+(-3.123815e+01)*S1+8.503847e+03*S2+(-9.445284e+02)*S3+(-4.104743e+02)*S4+1.686183e+02*S5+(-6.961226e+03)*S6+2.821754e+00*S7+7.715807e+00*S8+(-3.375999e+03)*S9'
.param V73_part2='V73_part1+(-9.504698e+00)*S10+1.080050e+01*S11+(-4.639407e+02)*S12+(-1.335133e+00)*S13+1.914806e+02*S14+2.878252e-01*S15+7.502547e+01*S16+4.621499e+00*S17+(-8.054340e+01)*S18+(-2.666367e-02)*S19'
.param V73_part3='V73_part2+3.500372e+00*S20+(-6.586485e-01)*S21+1.364261e+01*S22+6.590371e-01*S23+7.852593e+00*S24+8.007715e+00*S25+1.426436e-02*S26+1.546712e+00*S27+4.760855e-02*S28+(-5.925011e-01)*S29'
.param V73_part4='V73_part3+6.621423e+02*S30+1.862613e+01*S31+2.663014e+02*S32+(-1.645748e+01)*S33+(-2.614965e+01)*S34+4.751144e+01*S35+(-2.724239e-01)*S36+(-8.148481e+00)*S37+(-2.397678e-02)*S38+1.879437e+00*S39'
.param V73_part5='V73_part4+(-1.016220e-01)*S40+1.546658e-02*S41+8.349407e-01*S42+(-8.711022e-02)*S43+(-1.185906e-01)*S44+(-9.737615e-02)*S45+(-3.533126e-01)*S46+(-1.575426e-01)*S47+(-1.254371e-01)*S48+2.737557e-02*S49'
.param V73_part6='V73_part5+(-1.906281e+00)*S50+2.316744e-02*S51+(-2.793049e-01)*S52+(-2.856395e-02)*S53+1.348531e-01*S54+(-1.676603e+03)*S55+(-1.497628e+00)*S56+1.332090e-01*S57+1.344276e+00*S58+(-8.604117e-02)*S59'
.param V73_part7='V73_part6+1.311251e-02*S60+9.382629e-03*S61+7.925295e-03*S62+(-3.204809e-02)*S63+2.443682e-02*S64+2.881403e-02*S65+(-2.589182e-02)*S66+(-2.062104e-02)*S67+(-5.183233e-02)*S68+(-1.719387e-02)*S69'
.param V73_part8='V73_part7+4.186207e-02*S70+1.085895e-01*S71+(-3.283197e-02)*S72+1.065134e-01*S73+6.336886e-02*S74+(-1.846490e-01)*S75+6.275651e-02*S76+(-7.572058e-01)*S77+(-1.594279e-01)*S78+4.900987e-02*S79'
.param V73='V73_part8+(-1.001762e+01)*S80+(-1.526334e-01)*S81+3.248791e-02*S82+(-1.199811e+01)*S83+(-1.396563e-01)*S84+(-4.294887e+00)*S85+(-1.218098e+01)*S86+(-1.281291e-01)*S87+(-8.517732e-01)*S88+(-4.939379e+00)*S89'
.param V74_part1='2.522806e-01*S0+(-1.451057e-01)*S1+(-3.622684e+00)*S2+3.082571e+00*S3+1.443692e+00*S4+(-1.139048e-02)*S5+9.362506e+00*S6+2.777050e-01*S7+4.438364e-02*S8+(-1.613153e+00)*S9'
.param V74_part2='V74_part1+5.000293e-01*S10+(-1.962638e-01)*S11+(-7.201217e-01)*S12+3.098298e-02*S13+(-1.199662e+00)*S14+(-1.333635e-01)*S15+(-2.766827e+00)*S16+1.634281e+00*S17+5.217872e-01*S18+1.604355e+00*S19'
.param V74_part3='V74_part2+7.617650e-01*S20+(-2.942302e-01)*S21+9.208006e+00*S22+5.939830e-02*S23+3.815031e+00*S24+1.000000e+04*S25+(-7.291780e-02)*S26+1.155927e+00*S27+(-1.546594e-01)*S28+1.598067e+00*S29'
.param V74_part4='V74_part3+7.077675e+01*S30+5.393718e+01*S31+1.000000e+04*S32+(-1.000000e+04)*S33+1.000000e+04*S34+1.000000e+04*S35+4.630346e-01*S36+(-7.966394e+03)*S37+(-3.077465e-01)*S38+(-4.487692e-02)*S39'
.param V74_part5='V74_part4+(-7.872418e+03)*S40+2.401705e-01*S41+1.978826e+00*S42+6.967728e-01*S43+9.483335e-02*S44+1.099566e-01*S45+(-3.183914e-01)*S46+8.132661e-01*S47+(-2.553242e-02)*S48+9.868608e+00*S49'
.param V74_part6='V74_part5+9.297211e+01*S50+9.897905e+03*S51+6.288568e+00*S52+(-1.014029e-01)*S53+7.890295e+00*S54+1.377305e+03*S55+1.080628e+00*S56+6.910707e+00*S57+(-1.297725e-01)*S58+1.015389e-01*S59'
.param V74_part7='V74_part6+(-1.215539e+00)*S60+1.549881e-01*S61+7.434465e-02*S62+(-5.705532e-01)*S63+2.345781e-01*S64+1.112876e+00*S65+(-5.754125e-01)*S66+(-7.048594e-01)*S67+7.729254e-01*S68+(-5.599933e-01)*S69'
.param V74_part8='V74_part7+3.366622e-03*S70+2.541135e+01*S71+(-4.629474e-01)*S72+2.422080e+00*S73+1.733131e+00*S74+1.973195e-01*S75+9.214968e-02*S76+2.564705e-01*S77+(-6.144908e-02)*S78+1.056568e-01*S79'
.param V74='V74_part8+3.074281e+00*S80+(-1.306402e-01)*S81+9.390042e-02*S82+1.906540e+00*S83+(-7.143539e-02)*S84+(-1.622611e+00)*S85+7.981356e-01*S86+(-1.448346e-01)*S87+(-7.188964e-01)*S88+2.097487e+00*S89'
.param V75_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V75_part2='V75_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+1.840870e-01*S13+0.000000e+00*S14+0.000000e+00*S15+(-7.876435e-02)*S16+1.972945e-01*S17+(-9.682529e-02)*S18+3.070444e-01*S19'
.param V75_part3='V75_part2+0.000000e+00*S20+0.000000e+00*S21+3.939156e-02*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+(-3.972109e-01)*S26+4.194654e-01*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V75_part4='V75_part3+2.104316e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V75_part5='V75_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+4.946951e-03*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V75_part6='V75_part5+0.000000e+00*S50+4.457941e+00*S51+6.325100e+00*S52+(-2.691808e+00)*S53+6.087446e+00*S54+0.000000e+00*S55+0.000000e+00*S56+6.804465e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V75_part7='V75_part6+2.628667e+00*S60+(-3.143061e+00)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V75_part8='V75_part7+0.000000e+00*S70+(-1.145245e+01)*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.722441e+01)*S74+0.000000e+00*S75+(-5.508144e+00)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V75='V75_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V76_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V76_part2='V76_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-1.593962e-01)*S13+0.000000e+00*S14+0.000000e+00*S15+9.812130e-01*S16+(-1.647725e-02)*S17+4.636503e-01*S18+(-2.748671e-01)*S19'
.param V76_part3='V76_part2+0.000000e+00*S20+0.000000e+00*S21+3.185591e-02*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+1.169824e+00*S26+1.773229e-01*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V76_part4='V76_part3+1.407945e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V76_part5='V76_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+5.630539e-02*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V76_part6='V76_part5+0.000000e+00*S50+4.260157e+00*S51+(-3.145264e-01)*S52+2.900875e+00*S53+2.281668e+00*S54+0.000000e+00*S55+0.000000e+00*S56+4.179585e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V76_part7='V76_part6+(-9.246809e-01)*S60+3.059464e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V76_part8='V76_part7+0.000000e+00*S70+1.306459e+01*S71+0.000000e+00*S72+0.000000e+00*S73+2.820989e+01*S74+0.000000e+00*S75+3.485508e-01*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V76='V76_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V77_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V77_part2='V77_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-4.021775e-02)*S13+0.000000e+00*S14+0.000000e+00*S15+4.676117e-01*S16+4.703371e-02*S17+(-6.070215e-02)*S18+(-2.686810e-02)*S19'
.param V77_part3='V77_part2+0.000000e+00*S20+0.000000e+00*S21+3.876423e-01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+7.581064e-01*S26+(-5.345141e-01)*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V77_part4='V77_part3+(-3.548277e-01)*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V77_part5='V77_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+2.184703e-02*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V77_part6='V77_part5+0.000000e+00*S50+(-7.716789e+00)*S51+(-7.307061e+00)*S52+7.871881e+00*S53+(-1.020625e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.591085e+01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V77_part7='V77_part6+(-2.062320e+00)*S60+1.225028e+01*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V77_part8='V77_part7+0.000000e+00*S70+2.442688e+01*S71+0.000000e+00*S72+0.000000e+00*S73+2.356850e+01*S74+0.000000e+00*S75+1.394710e+01*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V77='V77_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V78_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V78_part2='V78_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-2.297855e-02)*S13+0.000000e+00*S14+0.000000e+00*S15+(-5.949436e-02)*S16+1.418562e-02*S17+3.345460e-02*S18+(-2.419217e-02)*S19'
.param V78_part3='V78_part2+0.000000e+00*S20+0.000000e+00*S21+2.345083e-02*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+(-8.502196e-03)*S26+4.562637e-02*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V78_part4='V78_part3+(-3.991434e-02)*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V78_part5='V78_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+(-5.181301e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V78_part6='V78_part5+0.000000e+00*S50+(-4.588529e-01)*S51+(-5.188444e-01)*S52+(-4.555583e-01)*S53+(-5.552212e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-6.831765e-01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V78_part7='V78_part6+(-3.496558e-01)*S60+(-1.582379e-01)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V78_part8='V78_part7+0.000000e+00*S70+(-2.605715e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.944096e+00)*S74+0.000000e+00*S75+(-9.496671e-03)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V78='V78_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V79_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V79_part2='V79_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-5.254562e-03)*S13+0.000000e+00*S14+0.000000e+00*S15+4.907012e-02*S16+(-8.661583e-02)*S17+8.332436e-03*S18+(-1.352416e-01)*S19'
.param V79_part3='V79_part2+0.000000e+00*S20+0.000000e+00*S21+(-3.268275e-02)*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+1.193106e-03*S26+(-2.807985e-01)*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V79_part4='V79_part3+(-2.168030e-01)*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V79_part5='V79_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+(-9.155425e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V79_part6='V79_part5+0.000000e+00*S50+5.868962e-01*S51+(-3.086744e-01)*S52+(-2.135218e+00)*S53+(-1.578991e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-2.818720e-01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V79_part7='V79_part6+(-6.680637e-03)*S60+(-1.474945e+00)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V79_part8='V79_part7+0.000000e+00*S70+(-3.246111e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.217846e+01)*S74+0.000000e+00*S75+(-2.802259e-01)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V79='V79_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='0.7064*_P21'
.param _P23='0.7064*_P21'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='V35+V36*rad_+V37*w_'
.param _P28='_P27+V38*gdis_+V39*spacing_'
.param _P29='0.5*(_P28+sqrt(_P28*_P28+0.001))'
.param _P30='V40+V41*rad_+V42*w_'
.param _P31='_P30+V43*gdis_+V44*spacing_'
.param _P32='0.5*(_P31+sqrt(_P31*_P31+0.001))'
.param _P33='V45+V46*rad_+V47*w_'
.param _P34='_P33+V48*gdis_+V49*spacing_'
.param _P35='0.5*(_P34+sqrt(_P34*_P34+0.001))'
.param _P36='V50+V51*rad_+V52*w_'
.param _P37='_P36+V53*gdis_+V54*spacing_'
.param _P38='0.5*(_P37+sqrt(_P37*_P37+0.001))'
.param _P39='V55+V56*rad_+V57*w_'
.param _P40='_P39+V58*gdis_+V59*spacing_'
.param _P41='0.5*(_P40+sqrt(_P40*_P40+0.001))'
.param _P42='1e-14*_P26'
.param _P43='100*_P29'
.param _P44='1e-15*_P32'
.param _P45='1e-14*_P26'
.param _P46='100*_P29'
.param _P47='1e-15*_P32'
.param _P48='1e-14*_P35'
.param _P49='100*_P38'
.param _P50='1e-15*_P41'
.param _P51='V60+V61*rad_+V62*w_'
.param _P52='_P51+V63*gdis_+V64*spacing_'
.param _P53='0.5*(_P52+sqrt(_P52*_P52+0.001))'
.param _P54='V65+V66*rad_+V67*w_'
.param _P55='_P54+V68*gdis_+V69*spacing_'
.param _P56='0.5*(_P55+sqrt(_P55*_P55+0.001))'
.param _P57='100*_P53'
.param _P58='1e-13*_P56'
.param _P59='V70+V71*rad_+V72*w_'
.param _P60='_P59+V73*gdis_+V74*spacing_'
.param _P61='0.5*(_P60+sqrt(_P60*_P60+0.001))'
.param _P62='V75+V76*rad_+V77*w_'
.param _P63='_P62+V78*gdis_+V79*spacing_'
.param _P64='0.5*(_P63+sqrt(_P63*_P63+0.001))'
.param _P65='100*_P61'
.param _P66='1e-13*_P64'
.param _P67='100*_P61'
.param _P68='1e-13*_P64'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P22
k2 ls2_1 ls1_2 K=_P23
c_1_sub top _n1_1_sub '_P42*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P43*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P44* csub_indfac'
c_2_sub bottom _n1_2_sub '_P45*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P46*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P47* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P48*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P49*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_3_sub _n1_3_sub gnode '_P50* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P57*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P58* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P65*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P66* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P67*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P68* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_sym_mu_a
*
*
*
.subckt spiral_sym_ct_mu_a top bottom gnode tap rad=6e-05 w=9e-06 nr=1 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-50)' spacing_='0.5*(spacing/1e-06*scale-3)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='8.545530e-01*S0+4.407485e-01*S1+2.375993e-02*S2+3.542889e-02*S3+(-5.560298e-01)*S4+4.942798e-01*S5+3.562005e-02*S6+2.785701e+01*S7+1.840525e-02*S8+5.157508e-02*S9'
.param V0_part2='V0_part1+1.324958e-02*S10+1.790383e-02*S11+6.984109e-02*S12+6.384652e-02*S13+(-3.381223e-01)*S14+1.684873e-02*S15+(-9.140602e-03)*S16+3.145528e-01*S17+2.558886e-01*S18+5.597818e-01*S19'
.param V0_part3='V0_part2+(-1.401128e-01)*S20+(-2.194056e-02)*S21+(-4.662814e-03)*S22+2.055381e-01*S23+6.843179e-02*S24+4.273130e-03*S25+(-4.625105e-02)*S26+1.565169e-01*S27+2.885346e-02*S28+2.019815e-03*S29'
.param V0_part4='V0_part3+1.106413e-02*S30+1.363132e+00*S31+(-3.718167e-02)*S32+(-7.947394e-03)*S33+(-1.596675e+00)*S34+(-7.697898e-02)*S35+1.590969e-02*S36+(-6.962900e-03)*S37+9.067148e-03*S38+(-2.084226e-01)*S39'
.param V0_part5='V0_part4+3.339938e-02*S40+3.720803e-02*S41+(-1.177603e-01)*S42+(-4.298932e-02)*S43+2.179945e-02*S44+3.113893e-02*S45+2.346014e+01*S46+2.873799e-01*S47+6.551335e+01*S48+(-1.566078e-02)*S49'
.param V0_part6='V0_part5+8.300468e+00*S50+3.816859e-01*S51+1.139306e-01*S52+1.639543e+00*S53+(-4.320768e-01)*S54+4.821942e+00*S55+1.011391e+00*S56+(-2.338915e+00)*S57+8.995550e-01*S58+3.377724e+00*S59'
.param V0_part7='V0_part6+1.910561e-01*S60+(-8.526439e-02)*S61+1.541555e-01*S62+9.547254e-02*S63+(-1.236443e-01)*S64+1.703310e-01*S65+(-1.406510e-02)*S66+(-2.018402e-01)*S67+8.761685e-01*S68+(-2.562265e-01)*S69'
.param V0_part8='V0_part7+(-5.578665e-02)*S70+1.398839e+03*S71+(-3.154081e-01)*S72+(-5.458052e-01)*S73+1.901884e-01*S74+2.981509e-01*S75+2.741965e-01*S76+6.415506e+00*S77+2.624624e-01*S78+3.804097e-02*S79'
.param V0='V0_part8+1.178430e+01*S80+(-2.552921e-01)*S81+(-8.088003e-01)*S82+5.368734e+01*S83+(-9.247858e-02)*S84+(-5.018232e-01)*S85+(-1.178279e+00)*S86+(-2.501531e-01)*S87+(-3.108808e-01)*S88+4.312776e-04*S89'
.param V1_part1='(-1.131436e+00)*S0+7.913117e-01*S1+1.411554e-01*S2+1.684064e-01*S3+6.717741e-01*S4+6.386497e-01*S5+1.837578e-01*S6+2.080255e-01*S7+1.008810e-01*S8+1.613080e-01*S9'
.param V1_part2='V1_part1+1.419891e-01*S10+1.232446e-01*S11+1.562715e-01*S12+1.382395e-01*S13+9.521198e-01*S14+6.249228e-01*S15+6.539126e-01*S16+8.567461e-01*S17+6.987119e-01*S18+7.276354e-01*S19'
.param V1_part3='V1_part2+1.092747e+00*S20+7.600139e-01*S21+8.431862e-01*S22+8.685968e-01*S23+7.719561e-01*S24+8.223178e-01*S25+9.021877e-01*S26+5.810641e-01*S27+7.806182e-01*S28+8.658702e-01*S29'
.param V1_part4='V1_part3+2.185768e+00*S30+(-7.084623e-01)*S31+1.409050e+00*S32+1.333881e+00*S33+1.283587e+01*S34+1.501177e+00*S35+1.227522e+00*S36+1.179434e+00*S37+1.424666e+00*S38+1.463261e+00*S39'
.param V1_part5='V1_part4+1.259208e+00*S40+1.448210e+00*S41+1.418074e+00*S42+1.385863e+00*S43+1.493569e+00*S44+1.636401e+00*S45+(-3.024301e+01)*S46+1.931780e+00*S47+(-4.093601e+01)*S48+1.942221e+00*S49'
.param V1_part6='V1_part5+7.966434e+00*S50+3.959892e+00*S51+5.601934e+00*S52+1.219703e+00*S53+6.414728e+00*S54+(-9.481734e-01)*S55+2.095781e+00*S56+1.994211e+01*S57+1.425360e+00*S58+6.481189e-01*S59'
.param V1_part7='V1_part6+3.200754e+00*S60+2.662898e+00*S61+2.865999e+00*S62+3.346552e+00*S63+3.015414e+00*S64+3.069747e+00*S65+3.222155e+00*S66+2.916497e+00*S67+2.799285e+00*S68+3.547271e+00*S69'
.param V1_part8='V1_part7+3.302767e+00*S70+5.754500e+00*S71+4.531303e+00*S72+3.308128e+00*S73+1.078665e+02*S74+3.706218e+00*S75+3.522103e+00*S76+4.393607e+01*S77+5.440072e+00*S78+4.525880e+00*S79'
.param V1='V1_part8+5.391778e+01*S80+5.219328e+00*S81+5.773409e+00*S82+8.709150e+01*S83+4.915868e+00*S84+4.535927e+00*S85+2.501950e+02*S86+5.658326e+00*S87+4.627643e+00*S88+1.026221e+01*S89'
.param V2_part1='8.475262e-01*S0+9.678447e-02*S1+4.790824e-03*S2+(-4.365430e-02)*S3+1.272561e+01*S4+2.685324e-01*S5+(-6.525171e-02)*S6+(-2.023174e+00)*S7+(-4.651188e-03)*S8+(-9.710935e-02)*S9'
.param V2_part2='V2_part1+(-2.024906e-02)*S10+(-8.227204e-03)*S11+(-1.226092e-01)*S12+(-6.547628e-02)*S13+2.191102e-02*S14+8.409140e-02*S15+6.203728e-01*S16+2.547918e-01*S17+5.018126e-03*S18+(-3.674368e-01)*S19'
.param V2_part3='V2_part2+2.309999e-01*S20+2.884758e-02*S21+5.970663e-02*S22+2.950023e-01*S23+(-4.725720e-02)*S24+4.062547e-02*S25+1.414134e-01*S26+(-2.005150e-01)*S27+8.014941e-04*S28+9.154117e-02*S29'
.param V2_part4='V2_part3+4.781939e-01*S30+(-3.455745e-01)*S31+3.227570e-01*S32+1.079632e-01*S33+2.550039e+00*S34+2.744497e-01*S35+2.504876e-01*S36+1.755967e-01*S37+2.060982e-01*S38+(-1.073219e-01)*S39'
.param V2_part5='V2_part4+6.823724e-02*S40+1.566674e-01*S41+(-1.990599e-01)*S42+4.049729e-02*S43+1.196346e-01*S44+3.644959e-01*S45+(-7.347552e+00)*S46+5.059633e-01*S47+(-1.173617e+01)*S48+5.201285e-01*S49'
.param V2_part6='V2_part5+(-2.570048e+00)*S50+4.639760e-01*S51+6.603902e-01*S52+5.629563e-01*S53+1.202785e-02*S54+(-4.957944e-01)*S55+6.033553e-01*S56+9.251637e-01*S57+2.262521e-01*S58+5.731551e-01*S59'
.param V2_part7='V2_part6+8.363558e-01*S60+9.296396e-01*S61+1.038842e+00*S62+6.317989e-01*S63+9.375160e-01*S64+1.013004e+00*S65+4.723086e-01*S66+7.288740e-01*S67+1.062195e+00*S68+2.573055e-01*S69'
.param V2_part8='V2_part7+5.421271e-01*S70+(-7.109157e+02)*S71+3.212256e-01*S72+5.447657e-01*S73+(-1.723273e+00)*S74+1.789794e+00*S75+1.501560e+00*S76+9.923214e+00*S77+1.558631e+00*S78+1.675537e+00*S79'
.param V2='V2_part8+(-6.605346e-01)*S80+1.282861e+00*S81+1.680873e+00*S82+(-3.730193e+01)*S83+1.137504e+00*S84+1.622467e+00*S85+(-3.743534e+01)*S86+1.365022e+00*S87+1.377609e+00*S88+2.794844e+00*S89'
.param V3_part1='(-2.664161e-01)*S0+(-3.957496e-02)*S1+1.307421e-02*S2+1.366474e-02*S3+(-1.003970e+00)*S4+(-4.445660e-01)*S5+1.295057e-02*S6+(-5.788571e-02)*S7+1.319757e-02*S8+9.948709e-03*S9'
.param V3_part2='V3_part1+1.643835e-02*S10+1.455561e-02*S11+3.403670e-03*S12+7.715355e-03*S13+3.513964e-02*S14+3.668229e-02*S15+8.398935e-02*S16+2.279129e-01*S17+1.617250e-01*S18+1.696536e-01*S19'
.param V3_part3='V3_part2+1.160118e-01*S20+8.280531e-02*S21+1.113104e-01*S22+2.079576e-01*S23+1.277480e-01*S24+1.226958e-01*S25+1.218232e-01*S26+9.368061e-02*S27+1.133774e-01*S28+1.494138e-01*S29'
.param V3_part4='V3_part3+3.707913e-02*S30+(-4.622017e-02)*S31+7.304770e-02*S32+5.643824e-02*S33+1.240154e-02*S34+7.875932e-02*S35+4.207640e-03*S36+5.731959e-02*S37+1.096672e-01*S38+9.755749e-03*S39'
.param V3_part5='V3_part4+8.381533e-02*S40+1.350328e-01*S41+6.455116e-02*S42+8.968468e-02*S43+1.591772e-01*S44+3.374251e-02*S45+(-9.926616e-01)*S46+1.318206e-01*S47+(-2.614040e+00)*S48+7.959870e-02*S49'
.param V3_part6='V3_part5+(-9.005067e-01)*S50+(-5.650884e-02)*S51+(-9.705073e-02)*S52+2.644955e-01*S53+(-4.554963e-02)*S54+4.746563e-01*S55+2.492020e-01*S56+7.685372e-03*S57+1.606435e-01*S58+4.246608e-01*S59'
.param V3_part7='V3_part6+8.309628e-03*S60+2.164710e-02*S61+1.440751e-01*S62+(-4.101388e-03)*S63+7.134121e-02*S64+2.044179e-01*S65+(-3.728120e-03)*S66+2.544927e-04*S67+3.315184e-01*S68+(-1.629242e-02)*S69'
.param V3_part8='V3_part7+(-5.901912e-03)*S70+(-1.673665e+02)*S71+(-5.882573e-05)*S72+(-1.304122e-02)*S73+(-1.375982e+01)*S74+7.065050e-03*S75+2.662622e-03*S76+(-1.146486e-01)*S77+(-2.178022e-02)*S78+(-4.571019e-02)*S79'
.param V3='V3_part8+(-1.002644e+00)*S80+3.457040e-03*S81+3.549502e-03*S82+5.688846e-01*S83+2.603589e-02*S84+2.314057e-02*S85+(-7.496101e+00)*S86+3.691145e-02*S87+(-6.814468e-02)*S88+(-3.094757e-01)*S89'
.param V4_part1='1.761628e-02*S0+5.506288e-02*S1+2.030513e-03*S2+2.780644e-03*S3+9.089219e-02*S4+4.589409e-02*S5+2.741659e-03*S6+4.813859e-02*S7+1.535312e-03*S8+2.402453e-03*S9'
.param V4_part2='V4_part1+1.565084e-03*S10+1.538421e-03*S11+2.447421e-03*S12+2.149768e-03*S13+7.400849e-03*S14+1.225607e-02*S15+1.196754e-02*S16+4.397165e-02*S17+3.758374e-03*S18+1.893855e-02*S19'
.param V4_part3='V4_part2+2.800787e-02*S20+6.513511e-03*S21+7.520410e-03*S22+1.341503e-02*S23+(-2.351703e-03)*S24+(-2.687726e-04)*S25+2.893719e-04*S26+(-2.398738e-02)*S27+(-8.167819e-03)*S28+(-3.520179e-02)*S29'
.param V4_part4='V4_part3+9.736218e-02*S30+(-9.807595e-02)*S31+3.491912e-02*S32+3.590246e-02*S33+6.811869e-01*S34+3.687011e-02*S35+2.228244e-01*S36+2.139669e-02*S37+4.955261e-02*S38+5.724650e-02*S39'
.param V4_part5='V4_part4+2.081505e-02*S40+4.903428e-02*S41+4.655113e-02*S42+4.052243e-02*S43+4.989984e-02*S44+6.064094e-02*S45+9.070230e-02*S46+1.138063e-01*S47+(-6.833252e-01)*S48+9.474570e-02*S49'
.param V4_part6='V4_part5+(-5.640762e-01)*S50+3.442781e-01*S51+3.888137e-01*S52+1.329396e-01*S53+5.329917e-01*S54+(-1.122805e-01)*S55+8.849473e-02*S56+2.932048e+00*S57+(-2.191466e-02)*S58+2.714677e-02*S59'
.param V4_part7='V4_part6+3.222494e-01*S60+1.414936e-01*S61+1.938094e-01*S62+3.911482e-01*S63+1.720959e-01*S64+1.838730e-01*S65+3.917805e-01*S66+2.254410e-01*S67+1.344126e-01*S68+4.108658e-01*S69'
.param V4_part8='V4_part7+4.088236e-01*S70+3.032158e+01*S71+7.469814e-01*S72+3.332918e-01*S73+1.003821e+01*S74+7.665449e-01*S75+6.762415e-01*S76+2.785424e+00*S77+1.047339e+00*S78+6.758407e-01*S79'
.param V4='V4_part8+2.236537e+00*S80+9.277532e-01*S81+7.593374e-01*S82+1.397366e+01*S83+9.918085e-01*S84+7.011678e-01*S85+1.697363e+01*S86+1.570925e+00*S87+1.204094e+00*S88+(-3.309795e-01)*S89'
.param V5_part1='1.519230e+01*S0+7.127902e+00*S1+1.263763e-03*S2+(-4.511462e-02)*S3+2.949913e+02*S4+1.181995e+01*S5+(-6.920670e-02)*S6+3.596225e+02*S7+(-2.889289e-02)*S8+(-9.579508e-02)*S9'
.param V5_part2='V5_part1+(-6.591783e-02)*S10+(-3.777027e-02)*S11+(-1.233246e-01)*S12+(-7.829428e-02)*S13+(-1.112513e+01)*S14+1.474891e+00*S15+1.612882e+00*S16+2.847661e+00*S17+1.403166e+00*S18+9.140004e-01*S19'
.param V5_part3='V5_part2+2.545632e+00*S20+1.268299e+00*S21+1.154939e+00*S22+2.529294e+00*S23+9.395418e-01*S24+9.769031e-01*S25+2.608297e+00*S26+9.700689e-01*S27+1.536697e+00*S28+2.372877e+00*S29'
.param V5_part4='V5_part3+1.686741e+00*S30+(-9.612073e-02)*S31+3.572689e+00*S32+1.652117e+00*S33+4.893874e-01*S34+3.540868e+00*S35+1.474159e+00*S36+1.033309e+00*S37+3.361132e+00*S38+1.175238e+00*S39'
.param V5_part5='V5_part4+9.539034e-01*S40+3.271403e+00*S41+1.525470e+00*S42+5.475700e-01*S43+2.759587e+00*S44+2.664947e+00*S45+(-6.221782e-02)*S46+5.477024e+00*S47+2.037531e-01*S48+2.294869e+00*S49'
.param V5_part6='V5_part5+2.011365e-01*S50+1.900669e+00*S51+1.156717e+00*S52+4.571250e+00*S53+1.693673e+00*S54+1.452096e+00*S55+4.534824e+00*S56+1.744455e+00*S57+2.255284e+00*S58+4.793583e+00*S59'
.param V5_part7='V5_part6+2.718402e+00*S60+2.330089e+00*S61+6.806240e+00*S62+2.399958e+00*S63+1.747872e+00*S64+6.733247e+00*S65+2.087389e+00*S66+1.491168e+00*S67+5.885183e+00*S68+1.756422e+00*S69'
.param V5_part8='V5_part7+1.313376e+00*S70+3.329393e-01*S71+1.512494e+00*S72+1.453830e+00*S73+9.622806e-02*S74+3.375826e+00*S75+2.523510e+00*S76+8.339513e+00*S77+3.077957e+00*S78+2.259674e+00*S79'
.param V5='V5_part8+7.961069e+00*S80+3.267640e+00*S81+1.608711e+00*S82+7.581457e+00*S83+2.880308e+00*S84+2.997995e+00*S85+6.235080e+00*S86+2.486060e+00*S87+2.862585e+00*S88+2.132307e-01*S89'
.param V6_part1='5.436890e+00*S0+2.340966e+01*S1+5.634531e-02*S2+1.875362e-01*S3+1.736257e+01*S4+3.156238e+00*S5+1.786418e-01*S6+(-6.155177e+00)*S7+7.718648e-02*S8+1.775583e-01*S9'
.param V6_part2='V6_part1+1.264156e-01*S10+7.282736e-02*S11+1.771230e-01*S12+1.193068e-01*S13+2.203447e+01*S14+1.831109e+00*S15+7.907983e-01*S16+3.694366e-01*S17+1.344554e+00*S18+4.032180e-01*S19'
.param V6_part3='V6_part2+5.556505e-01*S20+9.872300e-01*S21+4.281418e-01*S22+4.232311e-01*S23+1.046004e+00*S24+5.041412e-01*S25+(-8.019834e-02)*S26+5.421096e-01*S27+(-7.029708e-02)*S28+1.153842e-01*S29'
.param V6_part4='V6_part3+1.622689e+00*S30+1.904475e-01*S31+(-2.855939e-01)*S32+1.312815e+00*S33+1.853275e+00*S34+4.508970e-01*S35+1.384002e+00*S36+7.306039e-01*S37+5.316589e-01*S38+1.084015e+00*S39'
.param V6_part5='V6_part4+1.938075e-01*S40+5.786856e-01*S41+5.675539e-01*S42+6.950342e-01*S43+7.361930e-01*S44+6.253677e-01*S45+1.715439e-01*S46+(-2.887924e-01)*S47+8.427450e-01*S48+(-2.952130e-01)*S49'
.param V6_part6='V6_part5+1.314824e-01*S50+1.932826e+00*S51+1.278828e+00*S52+1.312114e-03*S53+1.926390e+00*S54+6.049538e-02*S55+8.732455e-02*S56+1.633054e+00*S57+3.114055e-03*S58+5.907406e-02*S59'
.param V6_part7='V6_part6+1.886241e-01*S60+6.893201e-01*S61+1.373711e-02*S62+8.789309e-01*S63+5.615355e-01*S64+2.920596e-02*S65+1.643435e+00*S66+(-5.174337e-01)*S67+1.242513e+00*S68+1.956456e+00*S69'
.param V6_part8='V6_part7+7.896886e-03*S70+2.352217e-01*S71+2.086190e+00*S72+3.236008e-01*S73+4.460436e-01*S74+6.429622e-01*S75+(-1.689124e+00)*S76+(-2.075726e-01)*S77+1.122115e+00*S78+(-1.546160e+00)*S79'
.param V6='V6_part8+1.278787e+00*S80+7.491030e-01*S81+2.656353e-01*S82+1.188677e+00*S83+1.875247e+00*S84+(-1.996925e+00)*S85+1.963921e+00*S86+2.066144e+00*S87+(-4.098415e-01)*S88+5.307679e-01*S89'
.param V7_part1='5.729879e-01*S0+7.281381e+00*S1+2.479064e-02*S2+2.845348e-02*S3+(-4.189762e+01)*S4+3.355583e+00*S5+3.713067e-02*S6+1.940002e+02*S7+4.079286e-02*S8+4.586236e-02*S9'
.param V7_part2='V7_part1+4.645934e-02*S10+5.087570e-02*S11+5.468761e-02*S12+5.580508e-02*S13+2.988793e+00*S14+7.399797e-02*S15+2.139365e-01*S16+(-2.615688e-01)*S17+1.227170e-01*S18+6.366718e-01*S19'
.param V7_part3='V7_part2+(-9.244155e-02)*S20+1.977800e-01*S21+5.335121e-01*S22+(-6.126972e-02)*S23+2.634614e-01*S24+5.613571e-01*S25+1.220045e-01*S26+3.451448e-01*S27+5.284262e-01*S28+2.386654e-01*S29'
.param V7_part4='V7_part3+1.464928e-01*S30+2.199459e-01*S31+(-2.609742e-01)*S32+1.168917e-01*S33+6.918237e-01*S34+(-4.361092e-01)*S35+2.074306e-01*S36+6.502209e-01*S37+(-3.372835e-01)*S38+2.764100e-01*S39'
.param V7_part5='V7_part4+7.992626e-01*S40+(-3.199673e-01)*S41+2.879519e-01*S42+9.353554e-01*S43+(-8.446999e-02)*S44+1.456564e-01*S45+3.090474e-01*S46+(-8.132263e-01)*S47+1.541446e-01*S48+6.911683e-01*S49'
.param V7_part6='V7_part5+1.835833e-01*S50+1.472474e-01*S51+8.166318e-01*S52+(-9.118546e-03)*S53+1.701959e-01*S54+1.100139e+00*S55+(-1.328192e-03)*S56+2.010750e-01*S57+8.643387e-01*S58+(-2.007196e-01)*S59'
.param V7_part7='V7_part6+1.465711e-01*S60+6.390467e-01*S61+(-1.458235e+00)*S62+1.802362e-01*S63+9.313112e-01*S64+(-1.362776e+00)*S65+1.700327e-01*S66+9.820597e-01*S67+(-1.188378e+00)*S68+1.907646e-01*S69'
.param V7_part8='V7_part7+1.042485e+00*S70+2.365360e-01*S71+2.058414e-01*S72+1.041474e+00*S73+3.178127e-01*S74+1.217946e-01*S75+7.729067e-01*S76+(-1.794760e+00)*S77+1.628002e-01*S78+1.045023e+00*S79'
.param V7='V7_part8+(-1.965630e+00)*S80+2.055710e-01*S81+1.134977e+00*S82+(-1.727129e+00)*S83+1.610310e-01*S84+1.414861e+00*S85+(-1.262770e+00)*S86+2.050320e-01*S87+1.182968e+00*S88+3.679275e-01*S89'
.param V8_part1='(-4.789711e+00)*S0+4.736189e-01*S1+1.019081e-02*S2+2.493927e-02*S3+(-2.921442e+01)*S4+(-2.823884e+00)*S5+2.299467e-02*S6+3.793855e+00*S7+5.069520e-03*S8+2.312123e-02*S9'
.param V8_part2='V8_part1+1.174381e-02*S10+6.419257e-03*S11+2.134610e-02*S12+1.408003e-02*S13+7.586089e-01*S14+6.131520e-01*S15+6.272266e-01*S16+7.859368e-01*S17+7.219963e-01*S18+7.485766e-01*S19'
.param V8_part3='V8_part2+7.507516e-01*S20+7.374177e-01*S21+7.664262e-01*S22+6.942931e-01*S23+5.823631e-01*S24+6.108188e-01*S25+6.635254e-01*S26+3.767817e-01*S27+5.325924e-01*S28+6.580535e-01*S29'
.param V8_part4='V8_part3+3.279169e-01*S30+7.848370e-03*S31+5.038210e-01*S32+3.520206e-01*S33+9.466399e-02*S34+5.939257e-01*S35+5.119067e-01*S36+3.478876e-01*S37+6.282936e-01*S38+(-1.187042e-02)*S39'
.param V8_part5='V8_part4+3.568945e-01*S40+6.411158e-01*S41+1.848478e-01*S42+2.637082e-01*S43+6.170966e-01*S44+3.963125e-01*S45+1.783977e-02*S46+6.736201e-01*S47+2.098957e-02*S48+4.417825e-01*S49'
.param V8_part6='V8_part5+1.236703e-02*S50+2.316851e-01*S51+2.125474e-01*S52+7.240588e-01*S53+2.643401e-01*S54+2.764990e-01*S55+7.012879e-01*S56+2.375972e-01*S57+5.868058e-01*S58+6.549887e-01*S59'
.param V8_part7='V8_part6+2.505373e-01*S60+1.204480e-01*S61+5.409480e-01*S62+3.167879e-01*S63+2.457118e-01*S64+5.690579e-01*S65+4.168710e-01*S66+3.951606e-01*S67+6.017239e-01*S68+4.765090e-01*S69'
.param V8_part8='V8_part7+5.228362e-01*S70+1.890361e-02*S71+5.276434e-01*S72+6.622193e-01*S73+1.215990e-02*S74+3.290629e-01*S75+2.866870e-01*S76+5.576423e-01*S77+4.032096e-01*S78+3.820523e-01*S79'
.param V8='V8_part8+5.472992e-01*S80+4.567418e-01*S81+5.405880e-01*S82+5.132775e-01*S83+7.048083e-01*S84+6.476982e-01*S85+3.448574e-01*S86+7.386280e-01*S87+8.137112e-01*S88+3.417968e-02*S89'
.param V9_part1='6.617040e-01*S0+1.686433e+00*S1+4.537128e-04*S2+1.811827e-03*S3+7.228428e-01*S4+2.348137e-01*S5+1.818737e-03*S6+(-4.386209e+00)*S7+6.379300e-04*S8+1.715746e-03*S9'
.param V9_part2='V9_part1+1.186901e-03*S10+7.504371e-04*S11+1.644822e-03*S12+9.970679e-04*S13+(-1.485067e-02)*S14+(-3.581658e-03)*S15+4.073036e-03*S16+(-3.947965e-02)*S17+(-4.017327e-02)*S18+(-1.001152e-02)*S19'
.param V9_part3='V9_part2+(-2.546212e-02)*S20+(-3.142501e-03)*S21+(-1.829840e-02)*S22+2.089955e-03*S23+1.109896e-02*S24+2.883997e-02*S25+(-1.127309e-02)*S26+9.734873e-02*S27+6.960734e-02*S28+(-1.024070e-02)*S29'
.param V9_part4='V9_part3+2.828309e-02*S30+2.620361e-02*S31+(-2.152130e-01)*S32+3.520950e-02*S33+(-6.364441e-02)*S34+(-1.397587e-01)*S35+4.134301e-01*S36+(-3.504031e-01)*S37+(-1.347186e-01)*S38+(-3.944340e-01)*S39'
.param V9_part5='V9_part4+(-5.023828e-01)*S40+(-4.565743e-02)*S41+(-6.201899e-01)*S42+(-3.667700e-01)*S43+(-4.893646e-02)*S44+(-4.772605e-01)*S45+3.653446e-02*S46+(-3.690081e-01)*S47+9.407885e-02*S48+(-6.671707e-01)*S49'
.param V9_part6='V9_part5+2.095850e-02*S50+(-4.129531e-01)*S51+(-5.016295e-01)*S52+(-2.614208e-01)*S53+(-4.647885e-01)*S54+(-8.341445e-01)*S55+(-6.124654e-02)*S56+(-6.444698e-01)*S57+(-1.789974e-01)*S58+(-1.256348e-01)*S59'
.param V9_part7='V9_part6+(-1.309755e-01)*S60+2.786580e-01*S61+(-1.062626e-01)*S62+(-1.564634e-02)*S63+(-6.747192e-01)*S64+(-2.259210e-01)*S65+7.096482e-02*S66+3.729336e-02*S67+(-2.621617e-01)*S68+7.545802e-02*S69'
.param V9_part8='V9_part7+7.790915e-02*S70+4.113342e-02*S71+1.081431e-01*S72+8.055366e-03*S73+6.090379e-02*S74+1.384580e-01*S75+9.327456e-04*S76+(-5.013361e-01)*S77+2.117645e-01*S78+1.048874e-01*S79'
.param V9='V9_part8+(-4.017514e-01)*S80+9.878948e-02*S81+1.123216e-01*S82+(-4.313106e-01)*S83+2.224469e-01*S84+7.943632e-02*S85+(-1.588348e-01)*S86+2.510939e-01*S87+1.221467e-01*S88+5.092996e-02*S89'
.param V10_part1='0.000000e+00*S0+8.223144e-01*S1+2.379476e-03*S2+1.443593e-02*S3+2.025867e+00*S4+0.000000e+00*S5+2.194938e-02*S6+0.000000e+00*S7+0.000000e+00*S8+1.956721e-02*S9'
.param V10_part2='V10_part1+5.588990e-02*S10+4.527080e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-6.107390e-03)*S17+0.000000e+00*S18+2.677547e-02*S19'
.param V10_part3='V10_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V10_part4='V10_part3+1.045883e-01*S30+3.240178e+01*S31+3.018271e-02*S32+0.000000e+00*S33+1.489200e-01*S34+0.000000e+00*S35+7.553956e-02*S36+7.509632e-02*S37+0.000000e+00*S38+(-1.163140e-01)*S39'
.param V10_part5='V10_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+2.297791e-02*S43+6.785919e-03*S44+2.540546e-02*S45+3.964241e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V10_part6='V10_part5+1.189182e+00*S50+4.555432e-02*S51+6.075919e-02*S52+0.000000e+00*S53+5.685609e-02*S54+0.000000e+00*S55+0.000000e+00*S56+5.530836e-02*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V10_part7='V10_part6+0.000000e+00*S60+0.000000e+00*S61+7.252814e-02*S62+0.000000e+00*S63+0.000000e+00*S64+7.985395e-02*S65+0.000000e+00*S66+0.000000e+00*S67+(-3.655338e-02)*S68+(-1.117076e-02)*S69'
.param V10_part8='V10_part7+1.710519e-01*S70+8.190433e+01*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.520033e+01)*S74+2.512481e-02*S75+8.322844e-02*S76+9.728490e-02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V10='V10_part8+(-1.929621e-02)*S80+1.644790e-01*S81+2.075301e-01*S82+(-1.560200e-01)*S83+1.271453e-01*S84+1.786917e-01*S85+1.313210e-01*S86+3.717797e-02*S87+1.648536e-01*S88+(-6.510497e+00)*S89'
.param V11_part1='0.000000e+00*S0+2.377364e-01*S1+9.466842e-02*S2+1.118824e-01*S3+(-3.536801e-01)*S4+0.000000e+00*S5+9.091810e-02*S6+0.000000e+00*S7+0.000000e+00*S8+8.897581e-02*S9'
.param V11_part2='V11_part1+7.585345e-02*S10+6.875845e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-1.433671e-02)*S17+0.000000e+00*S18+1.584282e-02*S19'
.param V11_part3='V11_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V11_part4='V11_part3+9.253950e-02*S30+(-2.598900e+01)*S31+1.351693e-01*S32+0.000000e+00*S33+(-1.662617e-01)*S34+0.000000e+00*S35+1.804727e-01*S36+2.004100e-01*S37+0.000000e+00*S38+3.775594e-01*S39'
.param V11_part5='V11_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+7.769906e-02*S43+1.062266e-02*S44+1.050756e-01*S45+(-4.661926e+01)*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V11_part6='V11_part5+(-5.594578e-01)*S50+7.584602e-02*S51+1.931538e-02*S52+0.000000e+00*S53+6.731206e-02*S54+0.000000e+00*S55+0.000000e+00*S56+8.218043e-02*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V11_part7='V11_part6+0.000000e+00*S60+0.000000e+00*S61+3.007198e-02*S62+0.000000e+00*S63+0.000000e+00*S64+3.796704e-02*S65+0.000000e+00*S66+0.000000e+00*S67+1.463644e-01*S68+(-1.308211e-02)*S69'
.param V11_part8='V11_part7+1.556161e-02*S70+(-3.108684e+01)*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.605748e-01)*S74+2.088647e-01*S75+1.256477e-01*S76+1.768521e-01*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V11='V11_part8+3.534415e-01*S80+1.358835e-02*S81+2.293441e-03*S82+5.530109e-01*S83+(-3.085079e-03)*S84+1.260716e-01*S85+1.591156e-01*S86+2.317332e-01*S87+1.590000e-01*S88+(-1.881366e+00)*S89'
.param V12_part1='0.000000e+00*S0+(-4.911413e-01)*S1+1.634738e-02*S2+(-1.097966e-03)*S3+(-9.003646e-04)*S4+0.000000e+00*S5+(-9.720385e-03)*S6+0.000000e+00*S7+0.000000e+00*S8+4.956607e-03*S9'
.param V12_part2='V12_part1+(-4.092034e-02)*S10+(-2.887459e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+1.714572e-02*S17+0.000000e+00*S18+(-4.642220e-02)*S19'
.param V12_part3='V12_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V12_part4='V12_part3+(-5.945819e-02)*S30+3.004389e+01*S31+6.901050e-02*S32+0.000000e+00*S33+(-5.579351e-02)*S34+0.000000e+00*S35+(-2.724036e-02)*S36+(-1.447116e-02)*S37+0.000000e+00*S38+(-6.757261e-02)*S39'
.param V12_part5='V12_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+(-7.615965e-02)*S43+1.435048e-02*S44+5.436473e-02*S45+6.691780e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V12_part6='V12_part5+4.618398e+01*S50+1.176983e-02*S51+(-2.774386e-03)*S52+0.000000e+00*S53+1.631354e-02*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.916612e-03)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V12_part7='V12_part6+0.000000e+00*S60+0.000000e+00*S61+1.029555e-01*S62+0.000000e+00*S63+0.000000e+00*S64+1.028897e-01*S65+0.000000e+00*S66+0.000000e+00*S67+9.363296e-02*S68+7.984697e-02*S69'
.param V12_part8='V12_part7+(-1.731008e-01)*S70+2.927979e+01*S71+0.000000e+00*S72+0.000000e+00*S73+6.080684e+01*S74+1.640149e-01*S75+6.423655e-02*S76+(-1.495928e-03)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V12='V12_part8+(-1.498076e-02)*S80+(-1.009949e-01)*S81+(-8.510171e-02)*S82+(-9.216232e-02)*S83+1.141638e-01*S84+(-2.642811e-02)*S85+(-3.246226e-02)*S86+9.810335e-02*S87+(-2.428851e-02)*S88+5.822915e+01*S89'
.param V13_part1='0.000000e+00*S0+1.868206e-01*S1+4.847100e-02*S2+5.901342e-02*S3+(-2.611286e-01)*S4+0.000000e+00*S5+5.629868e-02*S6+0.000000e+00*S7+0.000000e+00*S8+5.400444e-02*S9'
.param V13_part2='V13_part1+2.986565e-02*S10+5.786080e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-4.786027e-04)*S17+0.000000e+00*S18+1.707115e-03*S19'
.param V13_part3='V13_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V13_part4='V13_part3+4.153546e-02*S30+3.109476e+01*S31+2.593173e-02*S32+0.000000e+00*S33+4.029566e-02*S34+0.000000e+00*S35+5.043828e-02*S36+4.121498e-02*S37+0.000000e+00*S38+6.243170e-02*S39'
.param V13_part5='V13_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+(-5.237272e-04)*S43+1.316226e-02*S44+6.021111e-03*S45+4.189082e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V13_part6='V13_part5+1.818489e+01*S50+5.238972e-03*S51+2.733676e-04*S52+0.000000e+00*S53+4.526121e-03*S54+0.000000e+00*S55+0.000000e+00*S56+(-5.534451e-04)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V13_part7='V13_part6+0.000000e+00*S60+0.000000e+00*S61+2.312796e-03*S62+0.000000e+00*S63+0.000000e+00*S64+1.353870e-03*S65+0.000000e+00*S66+0.000000e+00*S67+(-5.896457e-02)*S68+(-2.151495e-02)*S69'
.param V13_part8='V13_part7+(-9.459858e-04)*S70+6.426144e+01*S71+0.000000e+00*S72+0.000000e+00*S73+9.666512e+00*S74+6.553282e-03*S75+(-7.706230e-04)*S76+(-7.238339e-03)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V13='V13_part8+(-6.106574e-03)*S80+(-1.305581e-03)*S81+(-5.791040e-04)*S82+3.935235e-03*S83+(-1.241313e-02)*S84+1.926027e-02*S85+(-5.337351e-03)*S86+1.571249e-02*S87+9.676917e-03*S88+1.284328e+00*S89'
.param V14_part1='0.000000e+00*S0+2.964849e-03*S1+1.933878e-04*S2+(-9.816366e-04)*S3+(-8.842046e-03)*S4+0.000000e+00*S5+(-7.011803e-04)*S6+0.000000e+00*S7+0.000000e+00*S8+(-4.529069e-04)*S9'
.param V14_part2='V14_part1+6.057738e-04*S10+2.186603e-04*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+1.832909e-02*S17+0.000000e+00*S18+2.281225e-02*S19'
.param V14_part3='V14_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V14_part4='V14_part3+8.062540e-03*S30+2.604082e+00*S31+3.578747e-03*S32+0.000000e+00*S33+7.307860e-03*S34+0.000000e+00*S35+1.895853e-02*S36+(-6.231719e-03)*S37+0.000000e+00*S38+(-1.636544e-02)*S39'
.param V14_part5='V14_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+4.691475e-02*S43+1.598408e-03*S44+1.713530e-02*S45+9.665824e-01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V14_part6='V14_part5+3.198678e+00*S50+1.861295e-02*S51+9.386178e-03*S52+0.000000e+00*S53+2.134845e-02*S54+0.000000e+00*S55+0.000000e+00*S56+2.082461e-02*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V14_part7='V14_part6+0.000000e+00*S60+0.000000e+00*S61+2.690123e-02*S62+0.000000e+00*S63+0.000000e+00*S64+3.005010e-02*S65+0.000000e+00*S66+0.000000e+00*S67+2.281402e-02*S68+1.054313e-04*S69'
.param V14_part8='V14_part7+1.782410e-02*S70+1.174677e+01*S71+0.000000e+00*S72+0.000000e+00*S73+1.629919e+01*S74+6.719982e-02*S75+6.571375e-02*S76+4.021108e-02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V14='V14_part8+5.752491e-02*S80+7.163078e-02*S81+5.132176e-02*S82+4.005093e-02*S83+7.123941e-02*S84+7.428637e-02*S85+6.542847e-02*S86+8.445894e-02*S87+8.495548e-02*S88+1.162135e+00*S89'
.param V15_part1='(-8.491979e-02)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.687962e-02*S8+0.000000e+00*S9'
.param V15_part2='V15_part1+0.000000e+00*S10+2.648698e-02*S11+(-3.937493e-03)*S12+2.489094e-03*S13+0.000000e+00*S14+0.000000e+00*S15+(-1.091904e-02)*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V15_part3='V15_part2+6.679919e-02*S20+2.210795e-02*S21+2.441331e-02*S22+1.419968e-02*S23+(-1.094084e-02)*S24+8.857317e-03*S25+0.000000e+00*S26+(-9.634511e-03)*S27+0.000000e+00*S28+4.179682e-02*S29'
.param V15_part4='V15_part3+0.000000e+00*S30+0.000000e+00*S31+1.725934e-02*S32+0.000000e+00*S33+1.449115e-02*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+2.392065e-01*S39'
.param V15_part5='V15_part4+0.000000e+00*S40+0.000000e+00*S41+2.436199e-01*S42+8.397983e-02*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+1.107914e+00*S48+0.000000e+00*S49'
.param V15_part6='V15_part5+0.000000e+00*S50+0.000000e+00*S51+3.794363e-02*S52+8.233681e-02*S53+0.000000e+00*S54+5.381297e-02*S55+8.168251e-02*S56+0.000000e+00*S57+3.205664e-02*S58+7.460499e-02*S59'
.param V15_part7='V15_part6+1.115762e-01*S60+5.226966e-02*S61+1.106521e-01*S62+1.463241e-01*S63+(-1.403516e-01)*S64+9.365844e-02*S65+1.281543e-01*S66+1.311137e-01*S67+2.064774e-01*S68+8.502060e-02*S69'
.param V15_part8='V15_part7+1.341573e-01*S70+0.000000e+00*S71+9.863001e-02*S72+1.381073e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+2.173316e-01*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V15='V15_part8+3.501244e-01*S80+2.249721e-04*S81+2.116605e-03*S82+5.984668e-01*S83+(-8.582890e-02)*S84+0.000000e+00*S85+2.729278e-01*S86+0.000000e+00*S87+0.000000e+00*S88+6.057036e+00*S89'
.param V16_part1='1.382497e-01*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+6.579425e-02*S8+0.000000e+00*S9'
.param V16_part2='V16_part1+0.000000e+00*S10+1.928875e-03*S11+9.506715e-02*S12+7.471728e-02*S13+0.000000e+00*S14+0.000000e+00*S15+3.900631e-02*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V16_part3='V16_part2+3.827750e-02*S20+(-3.057471e-03)*S21+(-1.448816e-02)*S22+(-9.021148e-04)*S23+6.202759e-02*S24+5.722002e-02*S25+0.000000e+00*S26+6.835872e-02*S27+0.000000e+00*S28+2.310477e-02*S29'
.param V16_part4='V16_part3+0.000000e+00*S30+0.000000e+00*S31+5.413498e-02*S32+0.000000e+00*S33+1.109910e-02*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+(-2.597621e-01)*S39'
.param V16_part5='V16_part4+0.000000e+00*S40+0.000000e+00*S41+(-9.090679e-02)*S42+1.119911e-01*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+7.610168e-01*S48+0.000000e+00*S49'
.param V16_part6='V16_part5+0.000000e+00*S50+0.000000e+00*S51+(-3.255178e-02)*S52+5.739619e-02*S53+0.000000e+00*S54+1.254049e-02*S55+5.947985e-02*S56+0.000000e+00*S57+1.238033e-01*S58+6.674853e-02*S59'
.param V16_part7='V16_part6+1.448255e-01*S60+2.980036e-01*S61+1.430309e-01*S62+2.227273e-01*S63+2.181354e-01*S64+1.136759e-01*S65+2.448499e-01*S66+1.527355e-01*S67+(-1.562097e-02)*S68+2.724604e-01*S69'
.param V16_part8='V16_part7+1.610447e-01*S70+0.000000e+00*S71+2.680239e-01*S72+1.867886e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-1.788854e-01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V16='V16_part8+(-3.292321e-01)*S80+2.138082e-01*S81+2.018920e-01*S82+(-5.265420e-01)*S83+2.359923e-01*S84+0.000000e+00*S85+(-1.661570e-01)*S86+0.000000e+00*S87+0.000000e+00*S88+8.412405e+00*S89'
.param V17_part1='3.448188e-02*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+9.077142e-03*S8+0.000000e+00*S9'
.param V17_part2='V17_part1+0.000000e+00*S10+(-2.397323e-03)*S11+2.276883e-03*S12+5.360734e-03*S13+0.000000e+00*S14+0.000000e+00*S15+3.984516e-03*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V17_part3='V17_part2+(-1.870414e-02)*S20+1.281236e-03*S21+1.065481e-03*S22+3.038033e-03*S23+2.115124e-03*S24+5.429052e-03*S25+0.000000e+00*S26+2.845075e-03*S27+0.000000e+00*S28+5.382044e-03*S29'
.param V17_part4='V17_part3+0.000000e+00*S30+0.000000e+00*S31+(-2.586273e-03)*S32+0.000000e+00*S33+1.149719e-02*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+8.496468e-04*S39'
.param V17_part5='V17_part4+0.000000e+00*S40+0.000000e+00*S41+1.773273e-03*S42+(-6.797301e-04)*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-1.720281e-01)*S48+0.000000e+00*S49'
.param V17_part6='V17_part5+0.000000e+00*S50+0.000000e+00*S51+4.119923e-03*S52+(-1.968292e-02)*S53+0.000000e+00*S54+1.059821e-02*S55+(-1.165207e-02)*S56+0.000000e+00*S57+(-9.838435e-04)*S58+(-1.941261e-02)*S59'
.param V17_part7='V17_part6+(-8.400471e-03)*S60+3.247185e-02*S61+(-4.250371e-02)*S62+(-4.406390e-03)*S63+7.937704e-02*S64+(-3.548740e-02)*S65+(-3.554837e-03)*S66+1.928699e-02*S67+(-3.728018e-02)*S68+2.118761e-03*S69'
.param V17_part8='V17_part7+(-1.791686e-02)*S70+0.000000e+00*S71+(-7.585288e-04)*S72+1.776997e-02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-7.938388e-02)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V17='V17_part8+(-7.962609e-02)*S80+(-1.593624e-02)*S81+(-2.412874e-02)*S82+(-1.029461e-01)*S83+5.443020e-04*S84+0.000000e+00*S85+(-7.272247e-02)*S86+0.000000e+00*S87+0.000000e+00*S88+(-1.423466e+00)*S89'
.param V18_part1='(-6.767624e-02)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.309659e-02*S8+0.000000e+00*S9'
.param V18_part2='V18_part1+0.000000e+00*S10+(-1.390456e-02)*S11+5.993103e-02*S12+5.124377e-02*S13+0.000000e+00*S14+0.000000e+00*S15+8.489100e-03*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V18_part3='V18_part2+1.811274e-02*S20+1.724168e-02*S21+1.512406e-02*S22+9.226267e-04*S23+4.490046e-03*S24+1.047263e-02*S25+0.000000e+00*S26+6.309408e-03*S27+0.000000e+00*S28+1.147577e-02*S29'
.param V18_part4='V18_part3+0.000000e+00*S30+0.000000e+00*S31+2.549004e-02*S32+0.000000e+00*S33+(-1.026443e-02)*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+(-1.064003e-02)*S39'
.param V18_part5='V18_part4+0.000000e+00*S40+0.000000e+00*S41+8.067809e-02*S42+4.250219e-02*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+2.882340e-03*S48+0.000000e+00*S49'
.param V18_part6='V18_part5+0.000000e+00*S50+0.000000e+00*S51+8.539782e-03*S52+1.077372e-02*S53+0.000000e+00*S54+(-3.108027e-03)*S55+1.098706e-02*S56+0.000000e+00*S57+1.095785e-02*S58+5.648009e-04*S59'
.param V18_part7='V18_part6+4.632812e-02*S60+4.160398e-02*S61+4.695879e-02*S62+4.762430e-02*S63+3.772957e-02*S64+4.579903e-02*S65+5.173709e-02*S66+4.828615e-02*S67+1.053468e-01*S68+6.922694e-02*S69'
.param V18_part8='V18_part7+5.522516e-02*S70+0.000000e+00*S71+5.635125e-02*S72+5.763545e-02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+2.528172e-02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V18='V18_part8+2.274579e-02*S80+1.097496e-02*S81+1.635919e-02*S82+1.952532e-02*S83+2.942097e-02*S84+0.000000e+00*S85+2.962035e-02*S86+0.000000e+00*S87+0.000000e+00*S88+2.238184e+00*S89'
.param V19_part1='(-1.371930e-03)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+1.258335e-04*S8+0.000000e+00*S9'
.param V19_part2='V19_part1+0.000000e+00*S10+(-1.119458e-04)*S11+(-5.832434e-04)*S12+(-7.907956e-04)*S13+0.000000e+00*S14+0.000000e+00*S15+2.080918e-02*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V19_part3='V19_part2+1.475278e-02*S20+1.441649e-02*S21+1.060282e-02*S22+2.154675e-02*S23+2.675722e-02*S24+2.117769e-02*S25+0.000000e+00*S26+2.864463e-02*S27+0.000000e+00*S28+1.490386e-02*S29'
.param V19_part4='V19_part3+0.000000e+00*S30+0.000000e+00*S31+(-4.700138e-03)*S32+0.000000e+00*S33+(-2.104670e-04)*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+2.633639e-03*S39'
.param V19_part5='V19_part4+0.000000e+00*S40+0.000000e+00*S41+(-3.974711e-02)*S42+(-4.702161e-02)*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+4.137986e-01*S48+0.000000e+00*S49'
.param V19_part6='V19_part5+0.000000e+00*S50+0.000000e+00*S51+5.316296e-03*S52+2.963716e-02*S53+0.000000e+00*S54+6.263885e-03*S55+3.681860e-02*S56+0.000000e+00*S57+3.644446e-02*S58+3.911059e-02*S59'
.param V19_part7='V19_part6+2.221117e-03*S60+2.865340e-02*S61+(-3.208234e-03)*S62+2.593387e-02*S63+5.180592e-02*S64+(-4.026773e-03)*S65+2.760865e-02*S66+2.676291e-02*S67+6.265588e-03*S68+2.919379e-02*S69'
.param V19_part8='V19_part7+1.415935e-02*S70+0.000000e+00*S71+3.874580e-02*S72+2.436544e-02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.500567e-03*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V19='V19_part8+(-1.560775e-02)*S80+3.270010e-03*S81+8.302763e-03*S82+1.165089e-02*S83+1.400181e-02*S84+0.000000e+00*S85+(-1.356390e-03)*S86+0.000000e+00*S87+0.000000e+00*S88+6.616941e-02*S89'
.param V20_part1='5.214568e-02*S0+4.582043e-03*S1+(-6.651394e-01)*S2+2.655912e+01*S3+1.180263e-02*S4+6.563528e-02*S5+4.013174e+01*S6+3.786337e-02*S7+1.681074e-01*S8+5.132214e+01*S9'
.param V20_part2='V20_part1+2.572738e+00*S10+6.787765e+00*S11+8.977653e+01*S12+3.428971e+01*S13+3.298680e-02*S14+4.381001e-02*S15+8.896463e-02*S16+3.085681e-01*S17+7.102463e-01*S18+3.208246e-01*S19'
.param V20_part3='V20_part2+1.028088e-01*S20+1.249506e-01*S21+5.184853e-02*S22+3.591816e-01*S23+4.775974e-01*S24+3.425291e-02*S25+6.543866e-02*S26+(-8.216920e-02)*S27+(-7.016151e-04)*S28+2.958709e-02*S29'
.param V20_part4='V20_part3+7.773162e-01*S30+5.688797e-01*S31+1.222940e-01*S32+2.765342e-01*S33+6.650353e+00*S34+1.044224e-01*S35+4.976256e+03*S36+(-4.800301e-02)*S37+3.558545e-02*S38+9.505785e-01*S39'
.param V20_part5='V20_part4+(-2.580314e-01)*S40+7.207599e-03*S41+(-4.674404e-02)*S42+(-9.755545e-02)*S43+(-7.700351e-03)*S44+2.367079e-01*S45+8.544224e-01*S46+3.723845e-01*S47+1.798493e-01*S48+2.616214e-02*S49'
.param V20_part6='V20_part5+(-1.932138e-02)*S50+2.204277e+01*S51+1.475116e+01*S52+2.712871e+00*S53+2.829137e+01*S54+1.255615e+01*S55+2.296501e+00*S56+6.684910e+01*S57+2.454304e-01*S58+4.678508e+00*S59'
.param V20_part7='V20_part6+4.855470e+03*S60+1.094103e+00*S61+1.069325e+00*S62+4.869645e+03*S63+5.529332e-01*S64+1.182929e+00*S65+4.874633e+03*S66+4.858518e+03*S67+3.638418e+00*S68+4.848130e+03*S69'
.param V20_part8='V20_part7+4.508473e+03*S70+(-3.400913e+00)*S71+4.493834e+03*S72+4.823754e+03*S73+5.308028e+00*S74+4.973716e+03*S75+4.978492e+03*S76+1.710317e+02*S77+4.919263e+03*S78+4.971549e+03*S79'
.param V20='V20_part8+2.358264e+02*S80+4.898457e+03*S81+4.673982e+03*S82+6.847408e+02*S83+4.974753e+03*S84+4.973031e+03*S85+1.363937e+03*S86+4.875405e+03*S87+4.903001e+03*S88+(-8.978442e-01)*S89'
.param V21_part1='1.807984e-01*S0+1.245161e-01*S1+2.714123e+01*S2+1.058363e+02*S3+1.320296e-01*S4+1.206551e-01*S5+8.826167e+01*S6+1.489761e-01*S7+6.627412e+00*S8+1.143895e+02*S9'
.param V21_part2='V21_part1+5.197360e+00*S10+1.086373e+01*S11+6.117430e+01*S12+2.112581e+01*S13+1.200361e-01*S14+6.899707e-01*S15+5.006164e-01*S16+2.400867e-01*S17+4.087261e-01*S18+5.230492e-01*S19'
.param V21_part3='V21_part2+4.128422e-01*S20+7.798906e-01*S21+6.287887e-01*S22+2.981157e-01*S23+6.561977e-01*S24+6.993601e-01*S25+5.370395e-01*S26+1.233114e+00*S27+8.005950e-01*S28+5.995004e-01*S29'
.param V21_part4='V21_part3+1.890702e+00*S30+9.935582e-01*S31+9.610498e-01*S32+1.549958e+00*S33+(-4.258787e+00)*S34+1.145865e+00*S35+3.713337e+01*S36+2.084271e+00*S37+1.321520e+00*S38+1.749194e+00*S39'
.param V21_part5='V21_part4+2.199448e+00*S40+1.407842e+00*S41+2.886641e+00*S42+2.050300e+00*S43+1.475385e+00*S44+4.057936e+00*S45+1.355606e+01*S46+1.760471e+00*S47+2.799550e+01*S48+3.180298e+00*S49'
.param V21_part6='V21_part5+1.616615e+01*S50+(-1.605817e+01)*S51+(-8.006215e+00)*S52+1.369973e-01*S53+(-1.203449e+01)*S54+(-6.751133e+00)*S55+1.786533e+00*S56+4.394335e+00*S57+5.023264e+00*S58+6.529168e-01*S59'
.param V21_part7='V21_part6+5.393256e+02*S60+3.097440e+00*S61+2.349596e+00*S62+2.994541e+02*S63+3.852322e+00*S64+2.707367e+00*S65+2.418606e+02*S66+2.089620e+02*S67+8.094260e-01*S68+2.462060e+02*S69'
.param V21_part8='V21_part7+3.541837e+02*S70+5.003030e+02*S71+6.761500e+02*S72+1.692560e+02*S73+3.182183e+01*S74+8.058233e+01*S75+1.468690e+02*S76+(-1.360736e+01)*S77+4.125910e+02*S78+3.196346e+02*S79'
.param V21='V21_part8+1.172457e-01*S80+2.789120e+02*S81+8.271541e+02*S82+(-4.738997e+01)*S83+1.096466e+02*S84+1.370245e+02*S85+(-4.647908e+01)*S86+2.159969e+02*S87+1.713660e+02*S88+5.648351e+00*S89'
.param V22_part1='(-1.110191e-02)*S0+1.428204e-02*S1+3.674439e+00*S2+(-7.849241e+01)*S3+1.394728e-03*S4+(-1.070195e-02)*S5+(-8.904481e+01)*S6+(-3.305669e-02)*S7+1.186008e+00*S8+(-1.454156e+02)*S9'
.param V22_part2='V22_part1+(-7.787916e-02)*S10+(-3.263774e-02)*S11+(-1.144070e+02)*S12+(-2.459427e+01)*S13+(-1.512999e-02)*S14+(-2.393427e-02)*S15+1.761240e-01*S16+(-5.768872e-02)*S17+(-8.297062e-01)*S18+(-2.224309e-01)*S19'
.param V22_part3='V22_part2+(-2.623798e-02)*S20+(-3.394394e-01)*S21+(-7.591975e-02)*S22+(-1.242629e-01)*S23+(-7.754517e-01)*S24+(-1.058228e-01)*S25+(-4.848028e-02)*S26+(-3.775854e-01)*S27+(-1.787687e-01)*S28+(-5.623872e-02)*S29'
.param V22_part4='V22_part3+(-1.303503e-01)*S30+2.624330e-01*S31+1.964504e-01*S32+(-2.497598e-01)*S33+(-3.021305e-01)*S34+1.480996e-01*S35+9.957171e+01*S36+4.802083e-02*S37+1.399791e-01*S38+(-2.190494e-01)*S39'
.param V22_part5='V22_part4+1.842452e-01*S40+1.092308e-01*S41+(-5.042032e-01)*S42+1.488681e-03*S43+7.988336e-02*S44+7.994310e-01*S45+2.024895e+00*S46+6.103730e-01*S47+2.951459e+00*S48+5.297537e-01*S49'
.param V22_part6='V22_part5+8.586930e-01*S50+(-3.064081e-01)*S51+(-2.562140e+00)*S52+5.655680e-01*S53+(-1.245560e+00)*S54+(-1.676320e+00)*S55+8.652328e-02*S56+6.158258e+00*S57+2.889824e-02*S58+1.229680e-01*S59'
.param V22_part7='V22_part6+5.395353e+02*S60+1.912541e+00*S61+1.376886e+00*S62+4.724196e+02*S63+1.846067e+00*S64+1.312735e+00*S65+2.502695e+02*S66+1.778424e+02*S67+1.486639e+00*S68+2.081588e+02*S69'
.param V22_part8='V22_part7+4.247535e+02*S70+(-4.770057e+01)*S71+6.735084e+02*S72+2.037497e+02*S73+7.207964e-01*S74+9.707131e+01*S75+2.317202e+01*S76+(-6.537556e+01)*S77+6.599604e+01*S78+2.143476e+01*S79'
.param V22='V22_part8+(-1.233462e+02)*S80+3.775100e-01*S81+(-1.365422e+00)*S82+(-4.419891e+02)*S83+7.751373e+01*S84+2.461760e+01*S85+(-8.048710e+02)*S86+1.746514e+02*S87+2.759113e+01*S88+1.579793e+00*S89'
.param V23_part1='3.738713e-02*S0+1.257984e-02*S1+(-1.261915e+00)*S2+2.294462e+01*S3+1.283047e-02*S4+2.404740e-02*S5+1.893452e+01*S6+1.013574e-02*S7+1.816082e+00*S8+5.349748e+01*S9'
.param V23_part2='V23_part1+1.568081e+00*S10+4.917602e+00*S11+7.084687e+01*S12+2.347713e+01*S13+1.487757e-02*S14+(-5.786844e-03)*S15+(-3.336629e-02)*S16+(-1.094809e-02)*S17+(-5.370485e-02)*S18+(-7.551003e-02)*S19'
.param V23_part3='V23_part2+(-1.115454e-02)*S20+(-8.981299e-02)*S21+(-4.781678e-02)*S22+(-1.854379e-02)*S23+(-1.118354e-01)*S24+(-5.338902e-02)*S25+(-1.498254e-02)*S26+(-1.569553e-01)*S27+(-4.654905e-02)*S28+(-3.195030e-02)*S29'
.param V23_part4='V23_part3+(-3.239399e-01)*S30+2.023053e-01*S31+(-2.257396e-02)*S32+(-9.645877e-02)*S33+(-5.843087e-01)*S34+(-3.272234e-02)*S35+(-4.081537e-02)*S36+(-8.056784e-02)*S37+(-5.508805e-02)*S38+1.055109e-01*S39'
.param V23_part5='V23_part4+(-1.357354e-01)*S40+(-7.816520e-02)*S41+(-1.954296e-01)*S42+(-1.146454e-01)*S43+(-1.125764e-01)*S44+(-1.744845e-01)*S45+(-3.543386e-02)*S46+(-8.570889e-02)*S47+3.050891e-03*S48+(-1.264605e-01)*S49'
.param V23_part6='V23_part5+2.492574e-01*S50+(-6.115476e-01)*S51+(-6.362241e-01)*S52+(-2.282408e-01)*S53+(-1.744315e+00)*S54+(-2.119107e-01)*S55+(-2.612468e-01)*S56+(-1.226577e+01)*S57+(-6.168582e-01)*S58+(-5.093478e-01)*S59'
.param V23_part7='V23_part6+(-1.446473e+01)*S60+2.187553e-02*S61+(-1.421625e-01)*S62+(-1.159142e+01)*S63+(-1.396093e-01)*S64+(-2.086993e-01)*S65+(-4.513090e+00)*S66+(-4.212567e-01)*S67+(-3.238052e-01)*S68+4.706205e-01*S69'
.param V23_part8='V23_part7+(-3.825291e+00)*S70+(-1.036754e+01)*S71+(-1.293990e+01)*S72+(-1.152798e+00)*S73+2.560421e+00*S74+(-3.149880e-01)*S75+(-1.675922e+00)*S76+(-1.181860e+01)*S77+(-5.781192e+00)*S78+(-2.067240e+01)*S79'
.param V23='V23_part8+(-1.613111e+01)*S80+(-1.185827e+00)*S81+5.169604e+00*S82+(-5.429598e+00)*S83+8.914862e+00*S84+1.466964e+01*S85+(-3.869158e+01)*S86+8.111167e+00*S87+(-1.937166e+01)*S88+1.652832e-01*S89'
.param V24_part1='1.765943e-03*S0+2.395742e-03*S1+7.823268e-01*S2+4.803627e-01*S3+1.956002e-03*S4+1.406466e-03*S5+1.183450e+00*S6+2.165416e-03*S7+3.239194e-03*S8+3.856359e-01*S9'
.param V24_part2='V24_part1+(-2.528596e-03)*S10+(-2.180379e-03)*S11+(-3.614792e-01)*S12+(-6.641726e-02)*S13+2.080810e-03*S14+1.006185e-02*S15+(-3.874588e-03)*S16+7.744194e-03*S17+1.682550e-02*S18+1.007265e-02*S19'
.param V24_part3='V24_part2+6.938536e-03*S20+1.431332e-02*S21+1.452534e-02*S22+(-3.292222e-04)*S23+2.206872e-02*S24+1.052091e-02*S25+9.136912e-03*S26+7.103075e-02*S27+1.839287e-02*S28+2.691497e-02*S29'
.param V24_part4='V24_part3+1.631423e-02*S30+3.768561e-02*S31+1.895388e-02*S32+1.876330e-02*S33+3.260296e-01*S34+2.385696e-02*S35+1.000000e+04*S36+1.065275e-02*S37+1.820929e-02*S38+(-3.648533e-01)*S39'
.param V24_part5='V24_part4+1.975195e-02*S40+1.389526e-02*S41+(-1.480751e-01)*S42+(-3.788619e-02)*S43+(-1.006898e-03)*S44+9.913442e-02*S45+8.305321e-01*S46+2.827157e-02*S47+2.309448e+00*S48+(-1.501222e-02)*S49'
.param V24_part6='V24_part5+7.543965e-01*S50+(-1.862697e+00)*S51+(-5.931938e-01)*S52+(-4.813050e-02)*S53+(-9.266770e-01)*S54+(-6.479258e-01)*S55+(-1.506321e-01)*S56+6.133659e+00*S57+(-5.673628e-02)*S58+(-2.084128e-01)*S59'
.param V24_part7='V24_part6+(-1.000000e+04)*S60+(-1.726399e-01)*S61+(-8.814357e-02)*S62+(-1.000000e+04)*S63+(-2.069871e-01)*S64+(-8.789775e-02)*S65+(-1.000000e+04)*S66+(-1.000000e+04)*S67+(-1.174495e-01)*S68+(-1.000000e+04)*S69'
.param V24_part8='V24_part7+(-9.576487e+03)*S70+3.412550e+01*S71+(-1.000000e+04)*S72+(-1.000000e+04)*S73+3.146051e+00*S74+1.000000e+04*S75+1.000000e+04*S76+(-1.285521e+00)*S77+1.000000e+04*S78+1.000000e+04*S79'
.param V24='V24_part8+(-9.282868e+00)*S80+1.000000e+04*S81+1.000000e+04*S82+3.524352e+01*S83+1.000000e+04*S84+1.000000e+04*S85+5.069846e+01*S86+1.000000e+04*S87+1.000000e+04*S88+2.106749e-03*S89'
.param V25_part1='(-1.491204e-02)*S0+(-6.675034e-03)*S1+(-7.328394e+00)*S2+(-9.409730e+02)*S3+(-2.883866e-02)*S4+(-8.988351e-03)*S5+(-4.229669e+02)*S6+(-4.662896e-02)*S7+1.447188e-01*S8+(-1.911491e+03)*S9'
.param V25_part2='V25_part1+(-9.087236e-01)*S10+(-8.801357e-01)*S11+6.713227e+00*S12+1.511999e+02*S13+(-4.512784e-02)*S14+7.470329e-02*S15+(-5.593947e-02)*S16+6.064395e-02*S17+(-6.206871e-03)*S18+(-1.324504e-01)*S19'
.param V25_part3='V25_part2+3.801064e-02*S20+(-5.258767e-02)*S21+(-1.485024e-01)*S22+1.576606e-02*S23+(-1.754970e-01)*S24+(-1.784636e-01)*S25+(-5.056228e-04)*S26+(-2.704314e-01)*S27+(-2.227075e-01)*S28+(-4.298676e-02)*S29'
.param V25_part4='V25_part3+1.476232e-01*S30+1.621562e+00*S31+1.841842e-01*S32+4.059155e-02*S33+(-1.773282e-01)*S34+1.528462e-01*S35+3.150621e-02*S36+(-2.692251e-01)*S37+1.299237e-01*S38+(-1.629499e-01)*S39'
.param V25_part5='V25_part4+(-3.154301e-01)*S40+9.073999e-02*S41+(-4.896965e-01)*S42+(-3.347830e-01)*S43+3.152258e-02*S44+2.727961e-01*S45+2.380721e+00*S46+2.764658e-01*S47+2.358976e+00*S48+(-3.041909e-01)*S49'
.param V25_part6='V25_part5+5.085722e+00*S50+(-8.339140e-02)*S51+(-2.473536e-01)*S52+1.712860e-03*S53+(-3.184470e-01)*S54+(-4.034493e-01)*S55+(-1.490562e-02)*S56+(-6.457670e-01)*S57+(-5.837026e-01)*S58+1.710913e-02*S59'
.param V25_part7='V25_part6+4.848597e-01*S60+(-3.853074e-02)*S61+4.558179e-01*S62+1.114259e-01*S63+(-2.706192e-01)*S64+4.384511e-01*S65+(-2.552947e-01)*S66+(-6.554311e-01)*S67+3.356721e-01*S68+(-6.121873e-01)*S69'
.param V25_part8='V25_part7+(-6.591431e-01)*S70+5.666125e+00*S71+(-1.035435e+00)*S72+(-7.873999e-01)*S73+5.396277e+00*S74+5.149487e-01*S75+(-1.022477e-01)*S76+6.893729e-01*S77+9.897113e-02*S78+(-5.195652e-01)*S79'
.param V25='V25_part8+6.580452e-01*S80+(-5.047232e-01)*S81+(-5.531896e-01)*S82+5.557411e-01*S83+(-9.629086e-01)*S84+(-7.808227e-01)*S85+3.857411e-01*S86+(-1.431014e+00)*S87+(-8.729957e-01)*S88+6.176832e+00*S89'
.param V26_part1='1.872379e-01*S0+1.267862e-01*S1+6.398822e+01*S2+2.499280e+03*S3+1.309022e-01*S4+6.928676e-02*S5+7.805261e+02*S6+1.277238e-01*S7+2.077805e+02*S8+3.548583e+03*S9'
.param V26_part2='V26_part1+1.271946e+02*S10+2.758295e+02*S11+1.581109e+03*S12+5.181396e+02*S13+6.925958e-02*S14+4.496102e-01*S15+1.990202e-01*S16+7.552590e-02*S17+4.313572e-01*S18+2.195117e-01*S19'
.param V26_part3='V26_part2+8.050143e-02*S20+3.732119e-01*S21+1.627012e-01*S22+9.492625e-02*S23+4.195946e-01*S24+1.706018e-01*S25+1.129625e-01*S26+4.935123e-01*S27+2.080265e-01*S28+1.396477e-01*S29'
.param V26_part4='V26_part3+7.138275e-01*S30+8.195889e-01*S31+1.259641e-01*S32+5.912069e-01*S33+1.844940e-01*S34+1.495843e-01*S35+8.670343e-01*S36+3.453849e-01*S37+1.896937e-01*S38+7.193571e-01*S39'
.param V26_part5='V26_part4+3.221164e-01*S40+2.083177e-01*S41+9.034262e-01*S42+3.309471e-01*S43+1.998006e-01*S44+1.102216e+00*S45+1.891337e+00*S46+1.019118e-01*S47+2.776005e+00*S48+5.010501e-01*S49'
.param V26_part6='V26_part5+1.247838e+00*S50+9.739913e-01*S51+2.555780e-01*S52+3.694472e-01*S53+9.730776e-01*S54+3.890651e-01*S55+3.872501e-01*S56+1.056879e+00*S57+6.011859e-01*S58+2.929959e-01*S59'
.param V26_part7='V26_part6+2.114918e+00*S60+3.597449e-01*S61+2.238185e-02*S62+2.052565e+00*S63+5.205932e-01*S64+4.758521e-02*S65+1.862137e+00*S66+1.032871e+00*S67+3.267151e-01*S68+1.741853e+00*S69'
.param V26_part8='V26_part7+8.471373e-01*S70+1.298236e+00*S71+1.689421e+00*S72+9.419775e-01*S73+(-1.208831e-01)*S74+2.582968e+00*S75+1.048880e+00*S76+1.497448e-01*S77+2.412346e+00*S78+1.365274e+00*S79'
.param V26='V26_part8+2.027168e-01*S80+2.696353e+00*S81+1.099794e+00*S82+2.216438e-01*S83+2.275337e+00*S84+1.283769e+00*S85+4.161398e-01*S86+2.219887e+00*S87+1.207576e+00*S88+(-3.190158e-01)*S89'
.param V27_part1='1.947704e-02*S0+2.015672e-02*S1+1.104733e+02*S2+3.594478e+02*S3+2.925358e-02*S4+3.146936e-02*S5+4.796507e+02*S6+3.788586e-02*S7+6.491755e+00*S8+8.006133e+02*S9'
.param V27_part2='V27_part1+5.489990e+01*S10+9.917086e+01*S11+7.924163e+02*S12+3.030428e+02*S13+6.135205e-02*S14+4.433307e-02*S15+1.119759e-01*S16+6.097792e-02*S17+7.188056e-02*S18+1.466656e-01*S19'
.param V27_part3='V27_part2+8.026829e-02*S20+9.759579e-02*S21+1.729159e-01*S22+9.606595e-02*S23+1.288752e-01*S24+1.933830e-01*S25+1.041809e-01*S26+1.449026e-01*S27+2.076418e-01*S28+1.298442e-01*S29'
.param V27_part4='V27_part3+8.598288e-02*S30+4.177006e-01*S31+5.944459e-02*S32+1.372520e-01*S33+2.684639e-01*S34+8.144315e-02*S35+1.336591e-01*S36+3.029619e-01*S37+8.849008e-02*S38+2.014535e-01*S39'
.param V27_part5='V27_part4+3.445515e-01*S40+1.136276e-01*S41+2.534762e-01*S42+3.554207e-01*S43+1.762752e-01*S44+1.170637e-01*S45+3.449093e-01*S46+1.192875e-01*S47+2.214131e-01*S48+3.893024e-01*S49'
.param V27_part6='V27_part5+(-1.063153e+00)*S50+2.497640e-01*S51+4.412183e-01*S52+2.515039e-01*S53+3.289661e-01*S54+4.856979e-01*S55+2.481699e-01*S56+4.118829e-01*S57+5.218102e-01*S58+2.846594e-01*S59'
.param V27_part7='V27_part6+1.558728e-01*S60+4.090736e-01*S61+1.493700e-01*S62+2.607609e-01*S63+4.988547e-01*S64+1.773194e-01*S65+3.884247e-01*S66+7.129580e-01*S67+1.631576e-01*S68+5.173542e-01*S69'
.param V27_part8='V27_part7+7.808250e-01*S70+(-1.225038e+00)*S71+6.653975e-01*S72+7.977187e-01*S73+3.325030e-02*S74+2.361106e-01*S75+6.011571e-01*S76+1.240723e-01*S77+3.690052e-01*S78+7.408010e-01*S79'
.param V27='V27_part8+1.460207e-01*S80+4.912370e-01*S81+8.178274e-01*S82+2.388333e-01*S83+6.833224e-01*S84+8.542364e-01*S85+2.938173e-01*S86+8.427146e-01*S87+9.066693e-01*S88+2.505555e-01*S89'
.param V28_part1='2.571915e-02*S0+1.768642e-02*S1+(-1.509665e+01)*S2+6.190447e+02*S3+1.624054e-02*S4+1.161768e-02*S5+3.786802e+02*S6+1.473147e-02*S7+1.333712e+01*S8+2.015482e+03*S9'
.param V28_part2='V28_part1+1.547268e+01*S10+5.951442e+01*S11+2.558307e+03*S12+7.433463e+02*S13+8.675316e-03*S14+1.360550e-02*S15+1.110690e-02*S16+5.314514e-03*S17+5.123780e-03*S18+7.603850e-03*S19'
.param V28_part3='V28_part2+4.131745e-03*S20+(-1.693513e-03)*S21+2.895937e-03*S22+3.714031e-03*S23+1.571641e-03*S24+5.449323e-03*S25+3.533237e-03*S26+9.344779e-03*S27+5.740018e-03*S28+5.417737e-03*S29'
.param V28_part4='V28_part3+1.751748e-02*S30+4.316393e-01*S31+5.048630e-03*S32+6.829589e-03*S33+1.408061e-02*S34+2.470922e-03*S35+(-2.326700e-02)*S36+1.105477e-02*S37+1.186621e-03*S38+4.222372e-02*S39'
.param V28_part5='V28_part4+4.750366e-03*S40+(-1.890614e-03)*S41+9.585022e-03*S42+1.063080e-02*S43+(-4.018986e-03)*S44+7.745699e-03*S45+3.863671e-01*S46+4.749953e-03*S47+2.737145e-01*S48+4.414865e-03*S49'
.param V28_part6='V28_part5+4.945836e-01*S50+3.037365e-02*S51+2.002689e-02*S52+1.755391e-02*S53+1.993240e-02*S54+7.402699e-03*S55+1.163231e-02*S56+7.757391e-03*S57+5.908800e-03*S58+6.574979e-03*S59'
.param V28_part7='V28_part6+2.612072e-02*S60+2.105758e-02*S61+1.424648e-02*S62+1.254102e-04*S63+7.776896e-03*S64+1.671554e-02*S65+(-3.766940e-02)*S66+1.098782e-02*S67+1.466811e-02*S68+(-7.463862e-02)*S69'
.param V28_part8='V28_part7+2.662649e-03*S70+4.108811e-01*S71+(-1.008522e-01)*S72+(-4.200550e-02)*S73+5.434008e-01*S74+1.587551e-02*S75+2.558292e-02*S76+1.644159e-02*S77+(-1.727600e-02)*S78+1.522070e-02*S79'
.param V28='V28_part8+2.266618e-02*S80+(-4.276020e-03)*S81+9.867614e-03*S82+2.891961e-02*S83+(-1.368159e-01)*S84+(-3.829733e-02)*S85+3.230511e-02*S86+(-1.952620e-01)*S87+(-7.385539e-02)*S88+4.769423e-01*S89'
.param V29_part1='1.922932e-03*S0+1.166466e-03*S1+3.610777e+00*S2+7.699168e+00*S3+1.132005e-03*S4+5.030904e-04*S5+1.634358e+01*S6+1.135800e-03*S7+(-8.042031e-01)*S8+2.794508e+00*S9'
.param V29_part2='V29_part1+3.852073e-02*S10+8.904756e-02*S11+(-2.390743e+01)*S12+(-3.392025e+00)*S13+5.193104e-04*S14+1.806575e-02*S15+9.130094e-03*S16+3.784894e-03*S17+1.867392e-02*S18+9.673798e-03*S19'
.param V29_part3='V29_part2+3.754421e-03*S20+1.768771e-02*S21+1.066180e-02*S22+4.792652e-03*S23+1.914874e-02*S24+1.046500e-02*S25+5.998865e-03*S26+1.995968e-02*S27+1.128943e-02*S28+1.106477e-02*S29'
.param V29_part4='V29_part3+4.406040e-02*S30+(-4.676158e-02)*S31+1.129509e-02*S32+4.793899e-02*S33+1.509069e-02*S34+1.071660e-02*S35+(-2.719959e-02)*S36+2.686076e-02*S37+1.137334e-02*S38+8.735404e-02*S39'
.param V29_part5='V29_part4+3.324548e-02*S40+1.290620e-02*S41+1.439115e-01*S42+3.323923e-02*S43+1.178605e-02*S44+1.214973e-01*S45+9.494153e-02*S46+2.355258e-02*S47+(-3.956043e-01)*S48+4.057669e-02*S49'
.param V29_part6='V29_part5+(-2.544779e-01)*S50+1.442414e-01*S51+4.883744e-02*S52+2.894169e-02*S53+1.695723e-01*S54+6.594759e-02*S55+2.875671e-02*S56+2.124550e-01*S57+4.065177e-02*S58+2.528325e-02*S59'
.param V29_part7='V29_part6+2.422200e-01*S60+7.436122e-02*S61+1.023370e-02*S62+2.633462e-01*S63+9.304260e-02*S64+1.106596e-02*S65+2.596180e-01*S66+1.621836e-01*S67+3.487586e-02*S68+2.557674e-01*S69'
.param V29_part8='V29_part7+1.384931e-01*S70+(-2.116526e-01)*S71+1.861683e-01*S72+1.362699e-01*S73+(-4.571091e-02)*S74+2.218881e-01*S75+1.695451e-01*S76+5.785797e-02*S77+1.645268e-01*S78+1.318362e-01*S79'
.param V29='V29_part8+5.760063e-02*S80+2.261320e-01*S81+1.188568e-01*S82+5.168408e-02*S83+1.469689e-01*S84+1.301047e-01*S85+6.721005e-02*S86+1.028343e-01*S87+8.576956e-02*S88+(-1.512269e-01)*S89'
.param V30_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+4.398556e-02*S4+0.000000e+00*S5+0.000000e+00*S6+(-3.171605e-03)*S7+2.954737e-01*S8+0.000000e+00*S9'
.param V30_part2='V30_part1+3.244512e+00*S10+4.473135e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+4.132325e-01*S16+0.000000e+00*S17+3.733452e+01*S18+1.084968e+01*S19'
.param V30_part3='V30_part2+2.960254e+01*S20+0.000000e+00*S21+0.000000e+00*S22+2.659672e+01*S23+8.428170e-01*S24+2.550130e-01*S25+1.966523e+01*S26+2.211572e+01*S27+2.369486e+01*S28+0.000000e+00*S29'
.param V30_part4='V30_part3+0.000000e+00*S30+1.233264e-01*S31+1.427174e+01*S32+0.000000e+00*S33+0.000000e+00*S34+7.944228e+00*S35+1.241554e+01*S36+4.043739e+00*S37+4.460163e+00*S38+0.000000e+00*S39'
.param V30_part5='V30_part4+0.000000e+00*S40+0.000000e+00*S41+2.053711e+01*S42+(-2.031239e-02)*S43+0.000000e+00*S44+0.000000e+00*S45+7.379401e-02*S46+0.000000e+00*S47+3.094668e-02*S48+0.000000e+00*S49'
.param V30_part6='V30_part5+4.404137e-02*S50+0.000000e+00*S51+0.000000e+00*S52+(-1.860023e-01)*S53+1.047089e+02*S54+1.322859e+01*S55+1.313102e+00*S56+0.000000e+00*S57+(-4.141485e+01)*S58+(-8.037894e+00)*S59'
.param V30_part7='V30_part6+0.000000e+00*S60+0.000000e+00*S61+1.026155e+00*S62+1.000000e+04*S63+8.252544e+01*S64+1.149813e+00*S65+1.000000e+04*S66+1.000000e+04*S67+5.907968e+01*S68+1.000000e+04*S69'
.param V30_part8='V30_part7+1.000000e+04*S70+1.619199e-01*S71+1.000000e+04*S72+1.000000e+04*S73+1.426393e-01*S74+0.000000e+00*S75+5.045958e+03*S76+0.000000e+00*S77+6.826395e+01*S78+0.000000e+00*S79'
.param V30='V30_part8+9.660424e+01*S80+3.461568e+03*S81+1.649156e+03*S82+0.000000e+00*S83+4.590030e+03*S84+1.000000e+04*S85+1.112131e+02*S86+0.000000e+00*S87+1.000000e+04*S88+0.000000e+00*S89'
.param V31_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+9.907769e-02*S4+0.000000e+00*S5+0.000000e+00*S6+(-7.769863e-03)*S7+1.242370e-01*S8+0.000000e+00*S9'
.param V31_part2='V31_part1+(-6.390983e-01)*S10+(-1.150140e+00)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-5.560255e+00)*S16+0.000000e+00*S17+(-1.586108e+01)*S18+(-1.576232e+01)*S19'
.param V31_part3='V31_part2+(-1.271699e+01)*S20+0.000000e+00*S21+0.000000e+00*S22+(-8.508955e+00)*S23+5.082048e-01*S24+1.090261e-01*S25+(-2.202528e+00)*S26+4.740015e-01*S27+(-4.118561e+00)*S28+0.000000e+00*S29'
.param V31_part4='V31_part3+0.000000e+00*S30+(-9.175690e-02)*S31+3.085767e+00*S32+0.000000e+00*S33+0.000000e+00*S34+1.238740e+01*S35+8.399461e-01*S36+(-5.595550e-01)*S37+9.354749e+00*S38+0.000000e+00*S39'
.param V31_part5='V31_part4+0.000000e+00*S40+0.000000e+00*S41+(-6.982989e-01)*S42+8.937805e-01*S43+0.000000e+00*S44+0.000000e+00*S45+(-7.223208e-02)*S46+0.000000e+00*S47+5.010458e-02*S48+0.000000e+00*S49'
.param V31_part6='V31_part5+9.925689e-03*S50+0.000000e+00*S51+0.000000e+00*S52+(-2.535948e-01)*S53+(-5.281440e+01)*S54+1.496115e+00*S55+2.206827e+00*S56+0.000000e+00*S57+2.803580e+00*S58+1.293131e+00*S59'
.param V31_part7='V31_part6+0.000000e+00*S60+0.000000e+00*S61+4.259949e+01*S62+1.000000e+04*S63+6.308620e+00*S64+4.178666e+01*S65+1.000000e+04*S66+1.000000e+04*S67+(-4.842773e+01)*S68+1.000000e+04*S69'
.param V31_part8='V31_part7+1.000000e+04*S70+1.034654e-01*S71+1.000000e+04*S72+1.000000e+04*S73+1.531216e-01*S74+0.000000e+00*S75+1.127265e+00*S76+0.000000e+00*S77+2.182301e+01*S78+0.000000e+00*S79'
.param V31='V31_part8+(-5.900287e+01)*S80+1.921814e+03*S81+4.518506e+03*S82+0.000000e+00*S83+1.009619e+03*S84+1.000000e+04*S85+(-7.884033e+01)*S86+0.000000e+00*S87+1.000000e+04*S88+0.000000e+00*S89'
.param V32_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-2.468495e-02)*S4+0.000000e+00*S5+0.000000e+00*S6+2.195600e-02*S7+(-1.745106e-02)*S8+0.000000e+00*S9'
.param V32_part2='V32_part1+(-2.216525e+00)*S10+(-2.699850e+00)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+5.012873e+01*S16+0.000000e+00*S17+(-1.021435e+00)*S18+3.299270e+01*S19'
.param V32_part3='V32_part2+1.004287e+01*S20+0.000000e+00*S21+0.000000e+00*S22+9.028899e+00*S23+5.666965e+01*S24+1.981071e+01*S25+2.747827e+00*S26+2.706724e+01*S27+(-6.883529e-01)*S28+0.000000e+00*S29'
.param V32_part4='V32_part3+0.000000e+00*S30+(-1.120534e-01)*S31+1.832385e+01*S32+0.000000e+00*S33+0.000000e+00*S34+7.807000e+00*S35+2.494252e+01*S36+4.028650e+01*S37+8.929582e+00*S38+0.000000e+00*S39'
.param V32_part5='V32_part4+0.000000e+00*S40+0.000000e+00*S41+1.953082e+00*S42+2.257157e+01*S43+0.000000e+00*S44+0.000000e+00*S45+(-2.768742e-03)*S46+0.000000e+00*S47+1.521164e-03*S48+0.000000e+00*S49'
.param V32_part6='V32_part5+(-1.337307e-02)*S50+0.000000e+00*S51+0.000000e+00*S52+4.200995e+01*S53+1.444338e+01*S54+6.843762e+01*S55+2.447939e+01*S56+0.000000e+00*S57+1.781482e+02*S58+6.593663e+01*S59'
.param V32_part7='V32_part6+0.000000e+00*S60+0.000000e+00*S61+6.766039e+01*S62+1.000000e+04*S63+(-6.671843e+01)*S64+6.729419e+01*S65+1.000000e+04*S66+1.000000e+04*S67+3.922426e+01*S68+1.000000e+04*S69'
.param V32_part8='V32_part7+1.000000e+04*S70+5.451058e-02*S71+1.000000e+04*S72+1.000000e+04*S73+7.478295e-02*S74+0.000000e+00*S75+3.002214e+01*S76+0.000000e+00*S77+(-1.068506e+02)*S78+0.000000e+00*S79'
.param V32='V32_part8+4.012005e+01*S80+6.155343e+03*S81+1.000000e+04*S82+0.000000e+00*S83+(-1.805163e+02)*S84+2.006834e+03*S85+5.921393e+01*S86+0.000000e+00*S87+1.000000e+04*S88+0.000000e+00*S89'
.param V33_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+4.687011e-02*S4+0.000000e+00*S5+0.000000e+00*S6+7.406815e-03*S7+1.633410e-02*S8+0.000000e+00*S9'
.param V33_part2='V33_part1+3.907996e-03*S10+1.535952e-03*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+8.900410e+00*S16+0.000000e+00*S17+2.262888e+01*S18+7.560130e+00*S19'
.param V33_part3='V33_part2+2.302545e+01*S20+0.000000e+00*S21+0.000000e+00*S22+2.201508e+01*S23+1.250056e+01*S24+2.404631e+00*S25+1.284710e+01*S26+2.771125e+01*S27+1.332263e+01*S28+0.000000e+00*S29'
.param V33_part4='V33_part3+0.000000e+00*S30+2.856532e-02*S31+2.175510e+01*S32+0.000000e+00*S33+0.000000e+00*S34+8.263127e+00*S35+1.714387e+01*S36+1.706288e+01*S37+3.927981e+00*S38+0.000000e+00*S39'
.param V33_part5='V33_part4+0.000000e+00*S40+0.000000e+00*S41+1.985149e+01*S42+8.672423e+00*S43+0.000000e+00*S44+0.000000e+00*S45+1.057647e-02*S46+0.000000e+00*S47+1.488792e-02*S48+0.000000e+00*S49'
.param V33_part6='V33_part5+(-6.112721e-04)*S50+0.000000e+00*S51+0.000000e+00*S52+1.070218e+00*S53+5.464268e+01*S54+3.506006e+01*S55+1.558861e-01*S56+0.000000e+00*S57+2.552505e+01*S58+2.850052e+01*S59'
.param V33_part7='V33_part6+0.000000e+00*S60+0.000000e+00*S61+4.241471e+01*S62+(-1.000000e+04)*S63+2.393555e+01*S64+4.789216e+01*S65+(-1.000000e+04)*S66+(-1.000000e+04)*S67+3.270374e+01*S68+(-1.000000e+04)*S69'
.param V33_part8='V33_part7+(-1.000000e+04)*S70+2.443714e-02*S71+(-1.000000e+04)*S72+(-1.000000e+04)*S73+4.320579e-02*S74+0.000000e+00*S75+1.960767e+00*S76+0.000000e+00*S77+1.725648e+00*S78+0.000000e+00*S79'
.param V33='V33_part8+5.869805e+01*S80+(-1.834266e+02)*S81+(-2.620024e+03)*S82+0.000000e+00*S83+1.095205e+02*S84+(-5.399530e+03)*S85+7.078981e+01*S86+0.000000e+00*S87+(-1.000000e+04)*S88+0.000000e+00*S89'
.param V34_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-2.354506e-04)*S4+0.000000e+00*S5+0.000000e+00*S6+(-7.986110e-05)*S7+(-4.180032e-03)*S8+0.000000e+00*S9'
.param V34_part2='V34_part1+(-5.247084e-03)*S10+(-4.735393e-05)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+1.245981e+00*S16+0.000000e+00*S17+(-3.817749e-01)*S18+(-1.120760e+00)*S19'
.param V34_part3='V34_part2+(-4.857292e-02)*S20+0.000000e+00*S21+0.000000e+00*S22+(-7.725625e-01)*S23+9.250184e-02*S24+(-8.504624e-01)*S25+(-7.764876e-01)*S26+5.073425e-02*S27+(-2.982436e-01)*S28+0.000000e+00*S29'
.param V34_part4='V34_part3+0.000000e+00*S30+(-2.697792e-03)*S31+1.440167e+00*S32+0.000000e+00*S33+0.000000e+00*S34+(-1.099549e+00)*S35+(-2.205186e-01)*S36+1.646980e+00*S37+(-1.352236e+00)*S38+0.000000e+00*S39'
.param V34_part5='V34_part4+0.000000e+00*S40+0.000000e+00*S41+1.421036e-01*S42+5.640324e-01*S43+0.000000e+00*S44+0.000000e+00*S45+2.648099e-02*S46+0.000000e+00*S47+1.975099e-02*S48+0.000000e+00*S49'
.param V34_part6='V34_part5+1.875145e-02*S50+0.000000e+00*S51+0.000000e+00*S52+3.615732e+00*S53+1.627192e+01*S54+1.155125e+01*S55+5.266614e-01*S56+0.000000e+00*S57+2.684316e+00*S58+3.513819e+00*S59'
.param V34_part7='V34_part6+0.000000e+00*S60+0.000000e+00*S61+9.765721e+00*S62+(-6.530711e+02)*S63+4.884142e+00*S64+1.502662e+01*S65+6.276930e+03*S66+(-9.999986e+03)*S67+2.902200e+01*S68+9.993304e+03*S69'
.param V34_part8='V34_part7+3.200524e+03*S70+3.028573e-02*S71+8.094107e+03*S72+5.324829e+03*S73+4.702409e-02*S74+0.000000e+00*S75+1.000000e+04*S76+0.000000e+00*S77+9.647596e+00*S78+0.000000e+00*S79'
.param V34='V34_part8+4.378338e+01*S80+9.561286e+03*S81+3.981467e+03*S82+0.000000e+00*S83+1.000000e+04*S84+5.586844e+03*S85+1.618638e+01*S86+0.000000e+00*S87+1.000000e+04*S88+0.000000e+00*S89'
.param V35_part1='0.000000e+00*S0+3.707881e-02*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+2.146814e-03*S7+6.488090e-01*S8+5.367389e-01*S9'
.param V35_part2='V35_part1+0.000000e+00*S10+8.867134e-01*S11+0.000000e+00*S12+0.000000e+00*S13+(-2.931435e-02)*S14+(-3.665126e+00)*S15+0.000000e+00*S16+2.893177e+01*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V35_part3='V35_part2+0.000000e+00*S20+4.114811e+01*S21+2.970897e+01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+1.289392e+01*S29'
.param V35_part4='V35_part3+6.190036e+01*S30+5.469282e-02*S31+0.000000e+00*S32+3.826242e+00*S33+3.069986e+01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+2.068303e+01*S39'
.param V35_part5='V35_part4+(-2.801528e+00)*S40+1.779708e+01*S41+0.000000e+00*S42+0.000000e+00*S43+1.582334e+01*S44+7.713428e+01*S45+0.000000e+00*S46+3.594739e+00*S47+2.368434e-03*S48+8.408300e+01*S49'
.param V35_part6='V35_part5+1.219058e-01*S50+1.284569e+02*S51+7.826757e+01*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.967572e+00*S56+7.530784e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V35_part7='V35_part6+(-8.607143e+02)*S60+1.101095e+01*S61+0.000000e+00*S62+3.239818e+03*S63+0.000000e+00*S64+0.000000e+00*S65+1.000000e+04*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V35_part8='V35_part7+1.000000e+04*S70+0.000000e+00*S71+1.000000e+04*S72+1.000000e+04*S73+0.000000e+00*S74+2.360752e+02*S75+0.000000e+00*S76+1.309908e+02*S77+0.000000e+00*S78+(-6.085044e+00)*S79'
.param V35='V35_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+1.495624e+02*S83+0.000000e+00*S84+3.393294e+03*S85+0.000000e+00*S86+1.000000e+04*S87+8.896424e+03*S88+0.000000e+00*S89'
.param V36_part1='0.000000e+00*S0+1.083876e-01*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+9.116500e-02*S7+5.993074e-01*S8+(-1.669165e-01)*S9'
.param V36_part2='V36_part1+0.000000e+00*S10+(-1.920631e-01)*S11+0.000000e+00*S12+0.000000e+00*S13+8.726763e-02*S14+4.611650e+01*S15+0.000000e+00*S16+(-2.297400e+00)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V36_part3='V36_part2+0.000000e+00*S20+(-3.843508e-01)*S21+(-6.001752e-01)*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-1.585358e-01)*S29'
.param V36_part4='V36_part3+8.406569e-01*S30+8.608356e-02*S31+0.000000e+00*S32+(-1.286436e+01)*S33+6.367316e-01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+5.013575e-01*S39'
.param V36_part5='V36_part4+(-3.991355e+00)*S40+3.248851e+00*S41+0.000000e+00*S42+0.000000e+00*S43+3.194577e+00*S44+(-2.315909e+01)*S45+0.000000e+00*S46+5.186465e+01*S47+5.788750e-02*S48+5.675214e-01*S49'
.param V36_part6='V36_part5+(-7.735672e-02)*S50+(-2.929488e+01)*S51+(-2.369463e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.096114e+01*S56+7.670724e-01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V36_part7='V36_part6+6.423680e+03*S60+1.312829e+00*S61+0.000000e+00*S62+1.000000e+04*S63+0.000000e+00*S64+0.000000e+00*S65+1.000000e+04*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V36_part8='V36_part7+1.000000e+04*S70+0.000000e+00*S71+1.000000e+04*S72+1.000000e+04*S73+0.000000e+00*S74+1.230963e+02*S75+0.000000e+00*S76+2.876114e+00*S77+0.000000e+00*S78+(-3.552358e+01)*S79'
.param V36='V36_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-3.855858e+01)*S83+0.000000e+00*S84+1.546272e+03*S85+0.000000e+00*S86+1.000000e+04*S87+1.000000e+04*S88+0.000000e+00*S89'
.param V37_part1='0.000000e+00*S0+2.975599e-03*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+5.435052e-03*S7+4.952269e-01*S8+2.400449e-01*S9'
.param V37_part2='V37_part1+0.000000e+00*S10+(-4.325199e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+(-7.137945e-03)*S14+7.062525e+00*S15+0.000000e+00*S16+(-1.795474e-01)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V37_part3='V37_part2+0.000000e+00*S20+(-2.132505e+00)*S21+(-1.349023e+00)*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+1.414661e+00*S29'
.param V37_part4='V37_part3+(-2.692230e+00)*S30+(-7.234479e-03)*S31+0.000000e+00*S32+4.943721e+00*S33+(-4.120727e+00)*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+(-1.731243e-01)*S39'
.param V37_part5='V37_part4+9.078670e+00*S40+(-5.173274e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-4.524757e+00)*S44+3.525722e-01*S45+0.000000e+00*S46+2.218202e+01*S47+2.159858e-04*S48+(-2.514153e+01)*S49'
.param V37_part6='V37_part5+(-4.654066e-02)*S50+(-4.758176e-01)*S51+(-1.889399e+00)*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+(-6.948658e-01)*S56+(-4.190764e-01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V37_part7='V37_part6+(-1.775878e+00)*S60+1.175525e+00*S61+0.000000e+00*S62+3.046211e+02*S63+0.000000e+00*S64+0.000000e+00*S65+1.000000e+04*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V37_part8='V37_part7+1.000000e+04*S70+0.000000e+00*S71+1.000000e+04*S72+1.000000e+04*S73+0.000000e+00*S74+1.875287e+01*S75+0.000000e+00*S76+(-2.568144e+01)*S77+0.000000e+00*S78+2.322584e+01*S79'
.param V37='V37_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-2.713738e+01)*S83+0.000000e+00*S84+1.729956e+02*S85+0.000000e+00*S86+6.850476e+01*S87+1.866832e+02*S88+0.000000e+00*S89'
.param V38_part1='0.000000e+00*S0+5.569861e-02*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+5.027415e-02*S7+3.048354e-01*S8+2.163792e-01*S9'
.param V38_part2='V38_part1+0.000000e+00*S10+(-8.678844e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+1.160611e-02*S14+2.011793e+01*S15+0.000000e+00*S16+1.337969e+01*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V38_part3='V38_part2+0.000000e+00*S20+2.265660e+01*S21+1.886365e+01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+7.326909e+00*S29'
.param V38_part4='V38_part3+4.850845e+01*S30+8.246037e-03*S31+0.000000e+00*S32+(-1.217076e+00)*S33+1.976069e+01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+1.949227e+01*S39'
.param V38_part5='V38_part4+1.407515e+00*S40+(-7.561819e-02)*S41+0.000000e+00*S42+0.000000e+00*S43+(-4.674358e-02)*S44+4.588532e+01*S45+0.000000e+00*S46+2.038669e+01*S47+(-2.029441e-02)*S48+2.726061e-01*S49'
.param V38_part6='V38_part5+9.494120e-03*S50+9.340863e+01*S51+4.715918e+01*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.374911e+00*S56+6.677807e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V38_part7='V38_part6+1.668805e+02*S60+(-5.214018e+00)*S61+0.000000e+00*S62+(-2.487156e+03)*S63+0.000000e+00*S64+0.000000e+00*S65+(-1.000000e+04)*S66+(-1.000000e+04)*S67+0.000000e+00*S68+(-1.000000e+04)*S69'
.param V38_part8='V38_part7+(-1.000000e+04)*S70+0.000000e+00*S71+(-1.000000e+04)*S72+(-1.000000e+04)*S73+0.000000e+00*S74+1.699801e+01*S75+0.000000e+00*S76+4.142635e+01*S77+0.000000e+00*S78+1.206280e+00*S79'
.param V38='V38_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+4.621758e+01*S83+0.000000e+00*S84+(-4.839338e+02)*S85+0.000000e+00*S86+1.554620e+03*S87+(-2.624372e+03)*S88+0.000000e+00*S89'
.param V39_part1='0.000000e+00*S0+(-9.023604e-04)*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+(-5.677768e-04)*S7+(-1.718260e-02)*S8+1.405755e-01*S9'
.param V39_part2='V39_part1+0.000000e+00*S10+2.061299e-02*S11+0.000000e+00*S12+0.000000e+00*S13+1.145182e-03*S14+1.242012e+00*S15+0.000000e+00*S16+1.517914e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V39_part3='V39_part2+0.000000e+00*S20+1.505371e+00*S21+6.543014e-01*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-3.316197e+00)*S29'
.param V39_part4='V39_part3+1.564948e-01*S30+8.162802e-03*S31+0.000000e+00*S32+(-1.759469e+00)*S33+2.765244e-01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+3.873152e-01*S39'
.param V39_part5='V39_part4+(-6.337624e+00)*S40+(-2.293580e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-1.913485e+00)*S44+1.013177e+01*S45+0.000000e+00*S46+(-2.562159e+00)*S47+5.452768e-03*S48+4.158095e+01*S49'
.param V39_part6='V39_part5+7.102626e-04*S50+9.647994e+00*S51+9.035499e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.144264e+00*S56+1.260386e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V39_part7='V39_part6+2.117388e+01*S60+(-4.534315e+00)*S61+0.000000e+00*S62+4.724184e+01*S63+0.000000e+00*S64+0.000000e+00*S65+3.224763e+03*S66+(-9.999989e+03)*S67+0.000000e+00*S68+9.026736e+03*S69'
.param V39_part8='V39_part7+1.644264e+03*S70+0.000000e+00*S71+5.482999e+03*S72+4.809803e+03*S73+0.000000e+00*S74+5.128677e+02*S75+0.000000e+00*S76+6.927755e+01*S77+0.000000e+00*S78+1.319849e+01*S79'
.param V39='V39_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+5.143904e+01*S83+0.000000e+00*S84+1.267239e+00*S85+0.000000e+00*S86+3.063963e+02*S87+3.529398e+02*S88+0.000000e+00*S89'
.param V40_part1='(-2.719499e-01)*S0+1.668394e+00*S1+3.987955e-01*S2+3.869872e-02*S3+8.744664e-01*S4+2.261058e-03*S5+1.593793e-01*S6+7.221201e-02*S7+(-2.536000e-02)*S8+1.040201e-01*S9'
.param V40_part2='V40_part1+8.942674e-01*S10+6.801928e-01*S11+(-6.215196e-02)*S12+(-3.096266e-03)*S13+5.860108e+02*S14+(-1.374706e+03)*S15+5.450726e-01*S16+(-4.473612e-01)*S17+(-6.382032e-01)*S18+(-7.369514e-01)*S19'
.param V40_part3='V40_part2+2.166713e+01*S20+4.696181e+00*S21+(-6.309710e+02)*S22+(-6.391934e-01)*S23+(-2.215345e+00)*S24+(-4.474806e+01)*S25+1.000000e+04*S26+(-3.155757e+01)*S27+1.000000e+04*S28+(-4.739812e+02)*S29'
.param V40_part4='V40_part3+2.504063e-01*S30+(-8.417356e-01)*S31+(-8.215153e+00)*S32+9.285236e+03*S33+(-2.687097e+00)*S34+(-1.621299e+03)*S35+1.000000e+04*S36+1.000000e+04*S37+1.000000e+04*S38+1.000000e+04*S39'
.param V40_part5='V40_part4+1.000000e+04*S40+1.000000e+04*S41+1.000000e+04*S42+1.000000e+04*S43+(-3.272425e+03)*S44+5.609438e+01*S45+(-4.432225e+00)*S46+(-1.566251e-01)*S47+(-8.220617e+00)*S48+9.999605e+03*S49'
.param V40_part6='V40_part5+(-1.890070e+00)*S50+(-1.014875e+00)*S51+(-1.165159e+00)*S52+(-6.923639e-01)*S53+(-9.916266e-01)*S54+(-2.026659e+00)*S55+(-3.458425e-01)*S56+(-3.906926e+00)*S57+(-1.061738e+00)*S58+(-9.128082e-01)*S59'
.param V40_part7='V40_part6+4.532148e+00*S60+7.445498e+01*S61+7.704067e-03*S62+3.090450e+03*S63+(-1.012493e+02)*S64+4.509824e-03*S65+1.000000e+04*S66+1.000000e+04*S67+(-3.645720e-01)*S68+1.000000e+04*S69'
.param V40_part8='V40_part7+9.510693e+02*S70+(-7.184027e+01)*S71+1.000000e+04*S72+7.688894e+03*S73+(-4.108361e+00)*S74+3.740708e+03*S75+6.250000e+02*S76+(-7.166115e+00)*S77+1.358475e+01*S78+4.526380e+00*S79'
.param V40='V40_part8+(-8.258110e+00)*S80+2.339139e+02*S81+(-2.304989e+02)*S82+(-1.886711e+01)*S83+5.512572e+03*S84+1.700160e+03*S85+(-2.756480e+01)*S86+1.000000e+04*S87+1.000000e+04*S88+1.685371e+00*S89'
.param V41_part1='1.918233e+00*S0+2.642701e+00*S1+2.461494e-01*S2+4.476617e-01*S3+8.384406e-01*S4+1.092438e+00*S5+2.844344e-01*S6+6.637949e-01*S7+2.182136e+00*S8+4.373605e-01*S9'
.param V41_part2='V41_part1+6.057452e-01*S10+6.052993e-01*S11+5.694035e-01*S12+5.645068e-01*S13+6.224731e+02*S14+8.446403e+03*S15+2.929015e+00*S16+2.584937e+00*S17+2.482317e+00*S18+2.179357e+00*S19'
.param V41_part3='V41_part2+(-4.463019e+00)*S20+4.259631e-02*S21+(-5.723169e+00)*S22+2.955941e+00*S23+5.723626e+00*S24+1.348965e+02*S25+1.000000e+04*S26+4.692217e+01*S27+1.000000e+04*S28+8.105033e+02*S29'
.param V41_part4='V41_part3+1.016429e+00*S30+3.972896e+00*S31+5.004658e+01*S32+1.000000e+04*S33+2.812124e+00*S34+1.000000e+04*S35+1.000000e+04*S36+1.000000e+04*S37+1.000000e+04*S38+1.000000e+04*S39'
.param V41_part5='V41_part4+1.000000e+04*S40+1.000000e+04*S41+1.000000e+04*S42+1.000000e+04*S43+5.355155e+03*S44+(-9.666561e+01)*S45+5.565979e+00*S46+6.561480e+00*S47+5.955473e+00*S48+9.999976e+03*S49'
.param V41_part6='V41_part5+(-9.513241e-02)*S50+1.558282e+00*S51+1.315399e+00*S52+2.233171e+00*S53+8.352260e-01*S54+2.692785e+00*S55+1.437823e+00*S56+1.206780e+00*S57+3.205890e+00*S58+1.506584e+00*S59'
.param V41_part7='V41_part6+2.176494e+01*S60+1.000000e+04*S61+7.376529e+00*S62+5.846676e+01*S63+5.215158e+02*S64+5.519533e+00*S65+1.000000e+04*S66+1.000000e+04*S67+2.390305e+00*S68+1.000000e+04*S69'
.param V41_part8='V41_part7+9.999996e+03*S70+1.591894e+00*S71+9.999997e+03*S72+7.688894e+03*S73+(-2.848097e-01)*S74+9.941250e+03*S75+6.250000e+02*S76+1.301935e+00*S77+5.026245e+00*S78+1.012437e+01*S79'
.param V41='V41_part8+5.218665e-01*S80+1.000000e+04*S81+3.357587e+03*S82+1.502710e+00*S83+1.000000e+04*S84+1.000000e+04*S85+(-2.231018e+00)*S86+1.000000e+04*S87+1.000000e+04*S88+(-1.878360e-01)*S89'
.param V42_part1='8.119605e-02*S0+(-8.490046e-01)*S1+(-4.116804e-02)*S2+5.128917e-01*S3+(-2.978599e-01)*S4+1.924544e-01*S5+3.387153e-01*S6+3.818006e-01*S7+8.958146e-01*S8+6.579557e-01*S9'
.param V42_part2='V42_part1+1.813452e-01*S10+2.120275e-01*S11+5.913912e-01*S12+5.016451e-01*S13+9.083616e+02*S14+2.500683e+02*S15+(-1.049239e+00)*S16+3.834706e-01*S17+8.550984e-01*S18+1.396849e+00*S19'
.param V42_part3='V42_part2+6.659897e-01*S20+7.656139e+03*S21+8.272880e+03*S22+3.600438e-01*S23+2.459506e+00*S24+1.077562e+00*S25+1.000000e+04*S26+3.634666e+00*S27+1.000000e+04*S28+1.207853e+02*S29'
.param V42_part4='V42_part3+(-8.859587e-02)*S30+6.249177e-01*S31+3.927052e+00*S32+1.000000e+04*S33+(-1.129770e-01)*S34+7.674884e+03*S35+5.469901e+03*S36+1.000000e+04*S37+1.000000e+04*S38+1.000000e+04*S39'
.param V42_part5='V42_part4+1.000000e+04*S40+6.250000e+02*S41+(-4.670524e+03)*S42+2.616431e+03*S43+3.239221e+02*S44+2.155369e+00*S45+1.859781e+00*S46+1.092773e+00*S47+1.869361e+00*S48+9.998601e+03*S49'
.param V42_part6='V42_part5+8.805022e-01*S50+4.784208e-02*S51+4.617663e-01*S52+2.276911e-01*S53+4.707258e-02*S54+5.597656e-01*S55+3.267729e-01*S56+(-6.524310e-01)*S57+3.303828e-01*S58+1.675197e-01*S59'
.param V42_part7='V42_part6+9.984385e+00*S60+4.564148e+03*S61+1.144562e+00*S62+(-2.507659e+01)*S63+8.195312e+00*S64+6.700063e-01*S65+7.168539e+03*S66+3.089884e+03*S67+2.949603e-01*S68+2.497052e+03*S69'
.param V42_part8='V42_part7+1.959747e+03*S70+3.237485e+01*S71+7.640277e+03*S72+9.641677e+03*S73+9.948279e-01*S74+4.989378e+03*S75+6.250000e+02*S76+2.970149e+00*S77+(-3.352764e+00)*S78+5.484081e+00*S79'
.param V42='V42_part8+4.304311e+00*S80+3.695165e+01*S81+(-3.641218e+01)*S82+1.134901e+01*S83+3.850225e+01*S84+4.380069e+03*S85+1.573604e+01*S86+1.000000e+04*S87+1.000000e+04*S88+7.183941e-01*S89'
.param V43_part1='(-6.043163e-02)*S0+4.555184e-01*S1+1.031684e-01*S2+4.158458e-02*S3+1.255981e-01*S4+9.861383e-02*S5+4.597564e-02*S6+1.248301e-01*S7+(-5.023242e-01)*S8+4.633090e-02*S9'
.param V43_part2='V43_part1+(-1.750516e-01)*S10+(-8.945162e-02)*S11+9.973548e-02*S12+5.166125e-02*S13+(-3.943209e+00)*S14+(-2.508366e+03)*S15+1.153776e-01*S16+(-5.441262e-02)*S17+(-1.924776e-01)*S18+5.862422e-02*S19'
.param V43_part3='V43_part2+4.108472e+00*S20+(-2.402516e+03)*S21+(-2.570011e+03)*S22+(-1.782083e-02)*S23+(-5.486355e-01)*S24+(-1.832153e+00)*S25+(-2.451678e+03)*S26+(-7.128324e-01)*S27+(-5.088488e+02)*S28+1.460810e+00*S29'
.param V43_part4='V43_part3+1.529928e-01*S30+(-1.055762e-01)*S31+(-1.314417e+00)*S32+1.000000e+04*S33+2.201945e-01*S34+(-6.288569e+03)*S35+(-3.726991e+03)*S36+7.175116e+03*S37+(-1.000000e+04)*S38+(-1.000000e+04)*S39'
.param V43_part5='V43_part4+(-7.252396e+02)*S40+(-3.378397e+00)*S41+(-1.508055e+03)*S42+(-3.403528e+01)*S43+(-5.673375e+00)*S44+6.852593e+00*S45+1.712006e-01*S46+(-1.608973e-01)*S47+1.996854e-01*S48+(-6.778205e+02)*S49'
.param V43_part6='V43_part5+9.108595e-02*S50+6.362868e-02*S51+9.029591e-02*S52+(-6.506394e-04)*S53+7.476577e-02*S54+(-6.984249e-02)*S55+5.951430e-03*S56+2.248607e-01*S57+5.097072e-02*S58+(-1.646346e-03)*S59'
.param V43_part7='V43_part6+(-2.095288e-02)*S60+(-4.423435e+03)*S61+(-3.850726e-01)*S62+1.615271e+01*S63+(-8.740094e+01)*S64+(-4.015236e-01)*S65+(-2.925139e+03)*S66+(-2.229016e+03)*S67+(-1.043886e-01)*S68+(-6.375469e+03)*S69'
.param V43_part8='V43_part7+(-1.000000e+04)*S70+4.776697e+00*S71+(-1.000000e+04)*S72+(-1.000000e+04)*S73+3.935252e-02*S74+(-8.186362e+02)*S75+(-1.000000e+04)*S76+2.357407e-01*S77+(-7.913460e-01)*S78+(-7.690018e-01)*S79'
.param V43='V43_part8+3.336836e-01*S80+(-1.132657e+03)*S81+(-9.999804e+02)*S82+8.960451e-02*S83+(-1.000000e+04)*S84+(-1.278944e+03)*S85+1.008101e+00*S86+(-1.000000e+04)*S87+(-6.756017e+03)*S88+(-3.475892e-02)*S89'
.param V44_part1='6.131223e-02*S0+1.259504e-02*S1+1.121804e-02*S2+1.842497e-02*S3+2.608457e-02*S4+2.020387e-02*S5+1.242003e-02*S6+1.535402e-02*S7+5.179927e-02*S8+1.260664e-02*S9'
.param V44_part2='V44_part1+4.397778e-02*S10+2.664669e-02*S11+9.584813e-03*S12+8.530374e-03*S13+7.578507e-01*S14+1.392899e+02*S15+9.692708e-02*S16+1.694803e-02*S17+3.826142e-02*S18+2.354817e-02*S19'
.param V44_part3='V44_part2+(-1.295018e+00)*S20+(-2.418966e+03)*S21+(-1.095391e+03)*S22+8.855655e-02*S23+1.030237e-01*S24+3.271118e+00*S25+3.467762e+03*S26+2.410966e+00*S27+5.026029e+03*S28+6.032529e+00*S29'
.param V44_part4='V44_part3+(-2.616913e-02)*S30+1.645137e-01*S31+1.582991e+00*S32+6.041919e+03*S33+(-2.023459e-01)*S34+1.455983e+03*S35+3.758247e+03*S36+8.099379e+03*S37+(-8.447475e+03)*S38+1.000000e+04*S39'
.param V44_part5='V44_part4+2.992114e+01*S40+2.004388e+00*S41+(-4.093970e+03)*S42+(-4.642586e+02)*S43+1.996423e+00*S44+(-1.522753e+01)*S45+(-1.430839e-01)*S46+1.326956e-01*S47+(-5.123518e-01)*S48+1.000000e+04*S49'
.param V44_part6='V44_part5+5.269246e-02*S50+(-4.938926e-02)*S51+(-2.781943e-02)*S52+2.779739e-02*S53+(-1.118219e-01)*S54+1.204323e-01*S55+5.020326e-02*S56+(-6.109167e-01)*S57+1.045567e-01*S58+4.572665e-02*S59'
.param V44_part7='V44_part6+2.931351e+00*S60+2.931312e+03*S61+1.743294e-01*S62+(-9.721308e+01)*S63+9.740567e+01*S64+2.012438e-01*S65+6.701703e+03*S66+1.000000e+04*S67+5.271454e-02*S68+8.901019e+03*S69'
.param V44_part8='V44_part7+9.723474e+03*S70+(-2.849732e+00)*S71+1.000000e+04*S72+7.688894e+03*S73+(-4.208569e-01)*S74+(-2.952500e+02)*S75+1.238358e+03*S76+(-8.408864e-02)*S77+(-3.930962e+00)*S78+(-2.780111e+00)*S79'
.param V44='V44_part8+9.168674e-02*S80+1.138930e+02*S81+6.965562e+02*S82+(-1.395239e+00)*S83+(-8.449250e+03)*S84+(-5.994988e+01)*S85+(-1.765183e+00)*S86+(-1.004492e+02)*S87+(-8.411273e+02)*S88+2.124665e-02*S89'
.param V45_part1='1.907383e-01*S0+2.930108e+00*S1+2.572829e-01*S2+6.363237e-01*S3+2.662721e+00*S4+(-2.809034e-01)*S5+6.024896e-01*S6+7.192863e-01*S7+3.225827e+01*S8+4.312567e-01*S9'
.param V45_part2='V45_part1+3.008848e+00*S10+4.756460e+00*S11+2.399191e-01*S12+2.391499e-01*S13+4.847533e-02*S14+4.078046e+00*S15+7.753784e+02*S16+1.011622e+01*S17+1.444780e+01*S18+1.919563e+02*S19'
.param V45_part3='V45_part2+2.847785e-01*S20+3.964537e+00*S21+2.179670e+00*S22+3.755228e+02*S23+2.298102e+03*S24+4.996401e+02*S25+1.437834e+00*S26+5.043039e+03*S27+1.029188e+00*S28+2.134704e+01*S29'
.param V45_part4='V45_part3+1.000000e+04*S30+1.000000e+04*S31+3.808730e+03*S32+(-6.503542e-01)*S33+1.000000e+04*S34+5.251339e-01*S35+(-1.368128e-02)*S36+4.717193e+01*S37+7.341028e-01*S38+1.805898e+01*S39'
.param V45_part5='V45_part4+3.310621e-01*S40+9.097723e-01*S41+8.519884e+00*S42+8.538214e+01*S43+1.119548e+00*S44+9.889697e+03*S45+3.079171e+03*S46+4.526569e+00*S47+3.845718e+03*S48+1.694190e+00*S49'
.param V45_part6='V45_part5+1.421236e+02*S50+1.000000e+04*S51+1.000000e+04*S52+1.000000e+04*S53+1.000000e+04*S54+1.000000e+04*S55+7.892654e+03*S56+1.000000e+04*S57+1.000000e+04*S58+5.746158e+03*S59'
.param V45_part7='V45_part6+(-2.708978e-01)*S60+1.350489e+01*S61+2.789701e+03*S62+(-5.344135e-02)*S63+2.277494e+00*S64+1.633042e+03*S65+2.673988e-01*S66+6.939450e-01*S67+1.000000e+04*S68+5.057487e-01*S69'
.param V45_part8='V45_part7+7.667400e-02*S70+3.781293e+03*S71+(-5.785780e-02)*S72+9.212918e-01*S73+2.313379e+03*S74+(-1.739608e-01)*S75+8.829024e-03*S76+1.000000e+04*S77+(-4.403661e-01)*S78+1.575447e-02*S79'
.param V45='V45_part8+2.574169e+03*S80+2.084679e-01*S81+5.090924e-01*S82+1.000000e+04*S83+1.153242e-01*S84+5.021678e-01*S85+1.000000e+04*S86+(-9.123133e-02)*S87+1.955173e-01*S88+3.398535e+00*S89'
.param V46_part1='(-2.823700e-01)*S0+(-1.303211e+00)*S1+1.506204e+00*S2+1.254490e+00*S3+(-2.831616e-01)*S4+8.188108e-01*S5+1.038468e+00*S6+7.493273e-01*S7+4.357906e+01*S8+1.217074e+00*S9'
.param V46_part2='V46_part1+(-4.855180e-02)*S10+(-3.272591e-02)*S11+1.259482e+00*S12+1.254367e+00*S13+6.889483e-01*S14+(-3.715762e+00)*S15+(-2.599750e+02)*S16+8.122428e+03*S17+(-1.200657e+01)*S18+(-2.718261e+00)*S19'
.param V46_part3='V46_part2+4.390187e+00*S20+(-8.939293e-01)*S21+(-2.416646e-01)*S22+5.355761e+03*S23+2.212201e+02*S24+6.970704e+01*S25+1.080901e+00*S26+5.043039e+03*S27+9.532383e-01*S28+(-3.289014e+00)*S29'
.param V46_part4='V46_part3+1.000000e+04*S30+1.000000e+04*S31+(-1.071481e+03)*S32+2.239500e+00*S33+1.000000e+04*S34+9.556895e-01*S35+5.183329e-01*S36+1.583147e+00*S37+6.052244e-01*S38+(-9.858238e+00)*S39'
.param V46_part5='V46_part4+2.941044e-01*S40+4.722434e-01*S41+(-6.259016e+00)*S42+5.254414e+00*S43+3.364783e-01*S44+3.449844e+03*S45+1.993286e+03*S46+2.155309e-01*S47+2.944674e+03*S48+1.183227e+00*S49'
.param V46_part6='V46_part5+1.334089e+02*S50+1.000000e+04*S51+1.000000e+04*S52+4.600991e-01*S53+1.000000e+04*S54+1.000000e+04*S55+6.177508e+01*S56+1.000000e+04*S57+1.000000e+04*S58+1.332516e+02*S59'
.param V46_part7='V46_part6+2.698450e-01*S60+7.820516e+01*S61+8.437924e+01*S62+8.103370e-02*S63+4.224439e+00*S64+7.886973e+01*S65+7.925576e-03*S66+(-2.954171e-01)*S67+1.000000e+04*S68+(-2.145140e-01)*S69'
.param V46_part8='V46_part7+2.919041e-02*S70+8.185173e+03*S71+(-6.104674e-02)*S72+(-4.272659e-01)*S73+(-7.334133e+00)*S74+7.238167e-01*S75+2.717159e-01*S76+1.000000e+04*S77+1.360206e-01*S78+(-5.873006e-02)*S79'
.param V46='V46_part8+1.000000e+04*S80+(-1.657011e-01)*S81+(-7.042148e-01)*S82+1.000000e+04*S83+7.522051e-02*S84+(-1.934098e-01)*S85+1.000000e+04*S86+7.169299e-02*S87+(-1.238294e-02)*S88+2.733549e+00*S89'
.param V47_part1='(-6.669857e-02)*S0+(-1.758570e+00)*S1+7.894477e-01*S2+5.953162e-01*S3+(-2.690578e-01)*S4+3.454204e-01*S5+7.828043e-01*S6+5.829158e-01*S7+(-3.617674e-02)*S8+9.924411e-01*S9'
.param V47_part2='V47_part1+(-5.442857e-01)*S10+(-1.061768e+00)*S11+8.359977e-01*S12+6.472411e-01*S13+(-7.983482e-03)*S14+(-1.312094e+00)*S15+5.286654e+02*S16+1.273168e+02*S17+2.721579e+00*S18+(-4.354664e+01)*S19'
.param V47_part3='V47_part2+2.944260e+01*S20+2.694762e-01*S21+1.521663e+00*S22+(-2.081517e+03)*S23+4.815084e+02*S24+6.899757e+01*S25+(-1.999891e-01)*S26+1.000000e+04*S27+7.752376e-01*S28+(-1.184718e+01)*S29'
.param V47_part4='V47_part3+1.000000e+04*S30+1.000000e+04*S31+9.996384e+03*S32+1.243247e+00*S33+1.000000e+04*S34+(-1.824733e-01)*S35+(-5.336501e-01)*S36+2.534593e+00*S37+(-1.911510e-01)*S38+(-4.160672e+00)*S39'
.param V47_part5='V47_part4+7.640560e-01*S40+(-2.490516e-01)*S41+1.437089e+00*S42+2.498575e+02*S43+(-1.629684e-01)*S44+4.762020e+03*S45+(-2.755037e+03)*S46+(-1.969738e+00)*S47+(-8.977705e+03)*S48+(-3.958681e-01)*S49'
.param V47_part6='V47_part5+(-4.476143e+01)*S50+1.000000e+04*S51+1.000000e+04*S52+(-9.806755e+03)*S53+1.000000e+04*S54+1.000000e+04*S55+(-5.881183e+03)*S56+1.000000e+04*S57+1.000000e+04*S58+(-5.799233e+03)*S59'
.param V47_part7='V47_part6+5.520685e-01*S60+(-4.289809e+01)*S61+(-1.114652e+01)*S62+3.775339e-01*S63+(-3.833706e+00)*S64+(-2.369819e+01)*S65+1.775320e-01*S66+1.867226e-01*S67+1.000000e+04*S68+1.318041e-01*S69'
.param V47_part8='V47_part7+2.982915e-01*S70+(-1.189438e+03)*S71+(-1.000823e-01)*S72+1.174209e-01*S73+(-3.139981e+02)*S74+2.287883e-01*S75+4.022663e-01*S76+1.000000e+04*S77+3.830325e-01*S78+2.309875e-01*S79'
.param V47='V47_part8+(-3.384992e+03)*S80+1.180039e-01*S81+9.425817e-02*S82+1.000000e+04*S83+(-2.072569e-02)*S84+1.314999e-02*S85+1.000000e+04*S86+(-1.097513e-01)*S87+1.109211e-01*S88+(-1.127405e+00)*S89'
.param V48_part1='(-4.631575e-01)*S0+(-1.848673e-01)*S1+1.012110e-01*S2+2.537037e-01*S3+(-8.949768e-02)*S4+(-3.008091e-01)*S5+2.313552e-01*S6+2.026801e-01*S7+(-1.434542e+01)*S8+2.752750e-01*S9'
.param V48_part2='V48_part1+(-3.878154e-01)*S10+(-2.791783e-01)*S11+3.735520e-01*S12+3.137335e-01*S13+(-1.307479e-01)*S14+(-5.290778e-01)*S15+7.622148e+00*S16+(-7.890538e+00)*S17+(-5.812405e-01)*S18+(-2.516248e+01)*S19'
.param V48_part3='V48_part2+(-3.065215e+00)*S20+8.020644e-01*S21+2.866243e-01*S22+(-9.651066e+03)*S23+(-2.661927e+00)*S24+(-2.277615e+01)*S25+(-2.262546e-01)*S26+(-4.920309e+01)*S27+(-3.703888e-02)*S28+(-1.299096e+00)*S29'
.param V48_part4='V48_part3+(-1.000000e+04)*S30+(-1.000000e+04)*S31+(-1.000000e+04)*S32+(-2.259571e-01)*S33+(-1.000000e+04)*S34+(-3.208981e-01)*S35+2.727501e-02*S36+(-1.371438e+00)*S37+(-2.631549e-01)*S38+2.965350e+00*S39'
.param V48_part5='V48_part4+(-1.678737e-01)*S40+(-2.232465e-01)*S41+9.449128e-01*S42+(-3.840406e+00)*S43+(-1.289634e-01)*S44+(-2.455786e+03)*S45+(-4.204597e+02)*S46+(-1.681494e-01)*S47+(-3.236680e+01)*S48+(-2.193943e-02)*S49'
.param V48_part6='V48_part5+(-1.391752e+02)*S50+(-1.000000e+04)*S51+(-1.000000e+04)*S52+(-2.817913e+02)*S53+(-1.000000e+04)*S54+(-1.000000e+04)*S55+(-1.000000e+04)*S56+(-1.000000e+04)*S57+(-1.000000e+04)*S58+(-3.216498e+02)*S59'
.param V48_part7='V48_part6+2.391597e-02*S60+2.726544e-02*S61+(-5.039617e-01)*S62+2.933362e-02*S63+(-1.544569e-02)*S64+(-1.071454e+00)*S65+2.071621e-02*S66+2.299488e-02*S67+(-1.384270e+03)*S68+2.926159e-02*S69'
.param V48_part8='V48_part7+1.762282e-02*S70+(-1.000000e+04)*S71+1.643946e-02*S72+1.726320e-02*S73+(-1.000000e+04)*S74+1.464805e-02*S75+2.647170e-02*S76+(-1.000000e+04)*S77+2.822450e-02*S78+4.420362e-02*S79'
.param V48='V48_part8+(-1.000000e+04)*S80+1.173741e-02*S81+1.276837e-02*S82+(-1.000000e+04)*S83+(-1.669482e-03)*S84+1.098345e-03*S85+(-1.000000e+04)*S86+(-3.446518e-03)*S87+3.057902e-02*S88+(-3.299317e-01)*S89'
.param V49_part1='4.377571e-02*S0+4.347328e-03*S1+4.981183e-02*S2+2.029956e-02*S3+5.677341e-02*S4+3.412472e-02*S5+1.881647e-02*S6+1.909119e-02*S7+9.291766e-03*S8+1.960964e-02*S9'
.param V49_part2='V49_part1+7.421175e-02*S10+1.233751e-01*S11+1.229220e-02*S12+9.037979e-03*S13+(-2.214121e-03)*S14+(-1.911933e+00)*S15+(-1.728813e+02)*S16+(-2.298029e+00)*S17+(-1.035811e+01)*S18+(-7.882464e+00)*S19'
.param V49_part3='V49_part2+(-7.503192e-01)*S20+(-9.144271e-01)*S21+(-7.937374e-01)*S22+(-1.007414e+02)*S23+(-4.882807e+02)*S24+6.711228e+00*S25+(-4.734019e-01)*S26+(-6.610206e+03)*S27+(-7.981933e-01)*S28+2.526488e-01*S29'
.param V49_part4='V49_part3+1.779979e+03*S30+1.000000e+04*S31+(-9.822776e+03)*S32+(-6.815233e-03)*S33+1.000000e+04*S34+1.096910e-02*S35+(-3.259632e-01)*S36+(-9.888346e-03)*S37+3.985250e-02*S38+(-3.201016e+00)*S39'
.param V49_part5='V49_part4+1.678301e-01*S40+(-1.478747e-04)*S41+(-8.667903e-01)*S42+(-6.774678e+00)*S43+(-4.937397e-04)*S44+(-2.283312e+01)*S45+(-8.953757e+01)*S46+(-4.666141e-01)*S47+6.288472e+02*S48+(-3.831912e-01)*S49'
.param V49_part6='V49_part5+(-1.472298e+01)*S50+(-1.889292e+02)*S51+(-3.361912e+03)*S52+1.237470e+02*S53+(-9.768745e+02)*S54+(-6.784289e+03)*S55+(-3.717992e+03)*S56+(-8.241458e+03)*S57+(-2.400725e+03)*S58+(-2.865700e+01)*S59'
.param V49_part7='V49_part6+(-5.231826e-01)*S60+5.955304e-01*S61+2.090681e+03*S62+(-5.698961e-01)*S63+9.687956e-01*S64+3.020511e+03*S65+(-6.244817e-01)*S66+(-4.925569e-01)*S67+6.101284e+02*S68+(-6.139952e-01)*S69'
.param V49_part8='V49_part7+(-4.571526e-01)*S70+(-4.306505e+03)*S71+(-5.615063e-01)*S72+(-5.460734e-01)*S73+(-7.182315e+02)*S74+(-4.606502e-01)*S75+(-3.742705e-01)*S76+(-5.560046e+02)*S77+(-3.768206e-01)*S78+(-2.058497e-01)*S79'
.param V49='V49_part8+(-5.800789e+02)*S80+(-3.017267e-01)*S81+(-2.044280e-01)*S82+(-8.052010e+03)*S83+(-2.713948e-01)*S84+(-1.676583e-01)*S85+4.767865e+03*S86+(-3.277137e-01)*S87+(-2.885465e-01)*S88+(-9.516620e-01)*S89'
.param V50_part1='(-2.412510e+00)*S0+3.241010e+03*S1+5.741086e+01*S2+3.881050e+02*S3+6.400505e+02*S4+1.081153e+01*S5+4.779819e+02*S6+1.455074e+02*S7+1.000000e+04*S8+7.355451e+03*S9'
.param V50_part2='V50_part1+1.056647e+03*S10+4.947416e+03*S11+1.000000e+04*S12+3.923879e+03*S13+1.726005e+02*S14+2.493028e-02*S15+(-7.712562e-03)*S16+1.691893e-03*S17+(-5.040747e-02)*S18+(-7.781492e-03)*S19'
.param V50_part3='V50_part2+(-1.735583e-01)*S20+(-1.105436e-01)*S21+(-1.121287e-01)*S22+(-2.478485e-01)*S23+(-1.823706e-01)*S24+(-7.466680e-02)*S25+6.654193e-02*S26+1.433381e-03*S27+(-3.817270e-02)*S28+1.736574e-01*S29'
.param V50_part4='V50_part3+(-1.074534e-01)*S30+(-2.872889e-02)*S31+2.106180e-01*S32+(-2.732941e-01)*S33+(-4.041892e-01)*S34+3.103422e-01*S35+(-3.102019e-03)*S36+1.302748e-01*S37+5.442347e-01*S38+(-2.202506e-01)*S39'
.param V50_part5='V50_part4+1.199612e-01*S40+6.349731e-01*S41+(-9.309730e-02)*S42+4.568959e-02*S43+5.036896e-01*S44+(-6.629335e-02)*S45+(-1.018585e-01)*S46+4.866244e-01*S47+(-2.624082e-01)*S48+1.319350e-01*S49'
.param V50_part6='V50_part5+(-3.624525e-02)*S50+(-3.114661e-01)*S51+(-3.524029e-01)*S52+3.677453e-04*S53+(-4.434497e-01)*S54+(-2.940593e-01)*S55+(-2.178875e-03)*S56+(-4.737923e-01)*S57+3.119996e-01*S58+1.058616e-01*S59'
.param V50_part7='V50_part6+(-3.758260e-02)*S60+8.625149e-02*S61+3.179513e-01*S62+(-3.850397e-02)*S63+3.166185e-02*S64+2.484553e-01*S65+1.435002e-02*S66+5.552908e-02*S67+5.375325e-01*S68+4.685023e-02*S69'
.param V50_part8='V50_part7+5.624091e-02*S70+(-2.581281e-01)*S71+9.668479e-02*S72+1.179239e-01*S73+5.029247e-01*S74+(-3.669259e-02)*S75+1.471801e-01*S76+(-6.103333e-02)*S77+(-6.865824e-02)*S78+8.013726e-02*S79'
.param V50='V50_part8+(-9.659077e-02)*S80+(-7.868849e-02)*S81+1.690107e-01*S82+(-3.847579e-01)*S83+3.295970e-03*S84+6.825236e-04*S85+(-7.149830e-01)*S86+4.436336e-02*S87+1.279677e-01*S88+(-1.612762e-01)*S89'
.param V51_part1='1.028009e+01*S0+4.536670e+03*S1+(-1.972998e+00)*S2+(-4.051051e+01)*S3+1.000000e+04*S4+(-4.796814e+00)*S5+(-1.720532e+02)*S6+5.691909e+02*S7+1.153312e+02*S8+(-3.072680e+03)*S9'
.param V51_part2='V51_part1+(-6.961034e-01)*S10+(-1.795568e-01)*S11+3.416771e+02*S12+3.782241e+02*S13+3.878153e+02*S14+2.189423e-01*S15+3.502856e-01*S16+5.374349e-01*S17+3.280189e-01*S18+4.600834e-01*S19'
.param V51_part3='V51_part2+8.227723e-01*S20+4.069591e-01*S21+6.179184e-01*S22+8.134196e-01*S23+4.121758e-01*S24+4.987581e-01*S25+5.513732e-01*S26+2.107033e-01*S27+4.530863e-01*S28+3.182679e-01*S29'
.param V51_part4='V51_part3+5.986905e-01*S30+9.705761e-01*S31+5.701262e-01*S32+8.801706e-01*S33+1.758614e+00*S34+6.266887e-01*S35+1.384443e-01*S36+2.929576e-01*S37+3.872320e-01*S38+5.877743e-01*S39'
.param V51_part5='V51_part4+3.824216e-01*S40+3.950269e-01*S41+4.870997e-01*S42+4.911346e-01*S43+4.525207e-01*S44+5.347693e-01*S45+1.560178e+00*S46+6.923606e-01*S47+9.279494e-01*S48+6.823874e-01*S49'
.param V51_part6='V51_part5+1.181817e+00*S50+9.825223e-01*S51+1.382830e+00*S52+8.079221e-01*S53+1.123399e+00*S54+1.289496e+00*S55+6.928822e-01*S56+1.169662e+00*S57+3.796055e-01*S58+7.904465e-01*S59'
.param V51_part7='V51_part6+3.590108e-01*S60+1.263391e+00*S61+1.421988e+00*S62+3.420222e-01*S63+1.708818e+00*S64+1.735579e+00*S65+2.922029e-01*S66+3.573397e-01*S67+1.155834e+00*S68+2.827004e-01*S69'
.param V51_part8='V51_part7+3.491238e-01*S70+1.520162e+00*S71+2.635411e-01*S72+2.815524e-01*S73+4.958149e-01*S74+4.531718e-01*S75+4.356285e-01*S76+1.450711e+00*S77+4.696485e-01*S78+5.476496e-01*S79'
.param V51='V51_part8+1.440961e+00*S80+5.018401e-01*S81+3.600584e-01*S82+1.486941e+00*S83+4.307156e-01*S84+5.846606e-01*S85+1.757378e+00*S86+4.112346e-01*S87+4.323878e-01*S88+1.280288e+00*S89'
.param V52_part1='1.238691e+01*S0+4.762069e+03*S1+(-4.171535e+01)*S2+(-6.376035e+02)*S3+2.910780e+03*S4+(-6.076417e+00)*S5+(-6.337038e+02)*S6+1.309321e+02*S7+4.439128e+01*S8+(-8.590157e+03)*S9'
.param V52_part2='V52_part1+1.832423e+01*S10+8.579743e+01*S11+1.653934e+03*S12+9.573192e+02*S13+8.141332e+00*S14+1.203667e-01*S15+2.028154e-01*S16+2.129603e-01*S17+1.593782e-01*S18+1.095333e-01*S19'
.param V52_part3='V52_part2+3.176022e-01*S20+1.900692e-01*S21+1.161192e-01*S22+2.857498e-01*S23+3.216589e-01*S24+4.382389e-02*S25+4.583505e-02*S26+3.706363e-02*S27+(-4.623211e-02)*S28+(-2.578482e-02)*S29'
.param V52_part4='V52_part3+6.088789e-01*S30+3.056171e-01*S31+2.191723e-01*S32+7.374058e-01*S33+2.987105e-01*S34+1.277160e-01*S35+2.758399e-02*S36+6.461705e-02*S37+(-1.072076e-01)*S38+2.164941e-01*S39'
.param V52_part5='V52_part4+(-1.362053e-02)*S40+(-2.491398e-01)*S41+1.715245e-01*S42+(-3.304124e-02)*S43+(-2.121187e-01)*S44+7.513414e-01*S45+3.633352e-01*S46+2.866742e-01*S47+8.365266e-01*S48+3.500195e-01*S49'
.param V52_part6='V52_part5+4.051852e-01*S50+5.857715e-01*S51+2.504038e-01*S52+5.158748e-01*S53+4.879685e-01*S54+2.979273e-01*S55+5.103509e-01*S56+3.585212e-01*S57+(-4.319698e-03)*S58+2.573508e-01*S59'
.param V52_part7='V52_part6+5.900295e-01*S60+3.895307e-01*S61+5.345908e-01*S62+5.835714e-01*S63+2.903024e-01*S64+3.701762e-01*S65+4.676321e-01*S66+1.667592e-01*S67+1.318083e-01*S68+3.904232e-01*S69'
.param V52_part8='V52_part7+1.080981e-01*S70+4.472154e-01*S71+2.905804e-01*S72+4.535841e-02*S73+3.005304e-01*S74+9.374309e-01*S75+3.743494e-01*S76+1.097687e+00*S77+9.480974e-01*S78+3.346722e-01*S79'
.param V52='V52_part8+1.015027e+00*S80+8.779861e-01*S81+2.499369e-01*S82+1.182934e+00*S83+6.581181e-01*S84+2.264073e-01*S85+1.136377e+00*S86+5.511355e-01*S87+1.115309e-01*S88+9.544782e-01*S89'
.param V53_part1='7.735002e-01*S0+(-9.807087e-02)*S1+(-1.398132e+00)*S2+(-7.611053e+00)*S3+(-2.747642e-01)*S4+(-7.164818e-01)*S5+(-2.545341e+01)*S6+(-6.548388e+01)*S7+(-6.961079e+03)*S8+(-1.275861e+03)*S9'
.param V53_part2='V53_part1+(-4.570531e+01)*S10+(-2.140006e+02)*S11+(-5.348947e+02)*S12+(-3.956489e+01)*S13+(-3.775863e-01)*S14+2.951300e-02*S15+4.284446e-02*S16+1.052848e-01*S17+2.736854e-02*S18+7.021680e-02*S19'
.param V53_part3='V53_part2+1.515272e-01*S20+4.101839e-02*S21+9.165858e-02*S22+1.238275e-01*S23+3.991687e-02*S24+7.039918e-02*S25+1.170829e-01*S26+2.751708e-02*S27+5.392221e-02*S28+8.166119e-02*S29'
.param V53_part4='V53_part3+2.269398e-02*S30+5.038775e-02*S31+7.182407e-02*S32+3.347664e-02*S33+1.918761e-02*S34+1.320463e-01*S35+(-8.821868e-03)*S36+2.649998e-03*S37+1.137746e-01*S38+(-2.191198e-02)*S39'
.param V53_part5='V53_part4+1.746987e-02*S40+1.051521e-01*S41+1.399771e-02*S42+(-1.256871e-03)*S43+8.702043e-02*S44+1.079839e-02*S45+(-1.872900e-02)*S46+1.051803e-01*S47+(-1.423533e-02)*S48+3.945982e-02*S49'
.param V53_part6='V53_part5+(-1.366121e-02)*S50+(-5.368077e-02)*S51+(-4.430439e-02)*S52+1.149485e-03*S53+(-6.865768e-02)*S54+(-2.308366e-03)*S55+(-1.000303e-02)*S56+(-5.729801e-02)*S57+(-4.543064e-02)*S58+6.432616e-03*S59'
.param V53_part7='V53_part6+(-1.581473e-02)*S60+(-2.184077e-02)*S61+4.649405e-02*S62+(-3.125291e-02)*S63+3.624467e-03*S64+5.694333e-02*S65+(-5.417658e-02)*S66+(-4.942688e-02)*S67+3.717143e-02*S68+(-7.452939e-02)*S69'
.param V53_part8='V53_part7+(-7.101985e-02)*S70+(-3.821240e-02)*S71+(-9.108426e-02)*S72+(-7.944393e-02)*S73+(-4.241373e-02)*S74+(-2.947031e-02)*S75+(-2.963814e-02)*S76+(-4.957099e-02)*S77+(-5.244948e-02)*S78+(-5.158077e-02)*S79'
.param V53='V53_part8+(-9.053315e-02)*S80+(-7.350861e-02)*S81+(-7.517282e-02)*S82+(-1.472032e-01)*S83+(-1.217287e-01)*S84+(-8.704717e-02)*S85+(-1.621603e-01)*S86+(-1.446602e-01)*S87+(-9.853734e-02)*S88+(-1.766566e-01)*S89'
.param V54_part1='4.035567e-02*S0+(-2.215691e+01)*S1+6.479500e-01*S2+(-3.347782e-01)*S3+(-9.814029e+01)*S4+3.329877e-02*S5+(-4.218867e-01)*S6+7.527960e-01*S7+7.802657e-02*S8+(-9.747461e+01)*S9'
.param V54_part2='V54_part1+2.865612e-01*S10+7.560468e-01*S11+(-2.786894e-02)*S12+8.523269e-01*S13+(-2.655536e-01)*S14+7.483006e-04*S15+3.325264e-03*S16+6.920495e-03*S17+(-6.134942e-05)*S18+(-9.934752e-04)*S19'
.param V54_part3='V54_part2+9.424294e-03*S20+(-3.090651e-03)*S21+(-8.372867e-03)*S22+1.316799e-03*S23+(-1.183332e-02)*S24+(-2.174814e-02)*S25+(-2.497338e-02)*S26+(-3.468237e-02)*S27+(-3.387816e-02)*S28+(-8.544437e-02)*S29'
.param V54_part4='V54_part3+1.284319e-02*S30+1.828661e-02*S31+(-3.646362e-02)*S32+1.025076e-02*S33+8.246209e-03*S34+(-4.964910e-02)*S35+2.098864e-03*S36+4.919063e-03*S37+(-1.939632e-02)*S38+4.499325e-02*S39'
.param V54_part5='V54_part4+4.078143e-02*S40+(-3.632274e-02)*S41+6.643057e-02*S42+2.074216e-02*S43+(-2.301651e-02)*S44+1.264778e-02*S45+(-1.935142e-02)*S46+(-1.971375e-02)*S47+2.431346e-03*S48+7.717562e-02*S49'
.param V54_part6='V54_part5+8.317759e-03*S50+4.290889e-02*S51+4.829072e-02*S52+(-4.367358e-02)*S53+4.283401e-02*S54+1.130442e-01*S55+(-6.534855e-02)*S56+5.957400e-02*S57+(-3.981438e-02)*S58+(-7.004419e-02)*S59'
.param V54_part7='V54_part6+(-3.897522e-02)*S60+(-7.999456e-03)*S61+(-1.832629e-03)*S62+(-5.888651e-02)*S63+1.992102e-01*S64+(-3.896283e-03)*S65+(-8.134998e-02)*S66+(-7.438922e-02)*S67+(-8.520851e-02)*S68+(-9.263689e-02)*S69'
.param V54_part8='V54_part7+(-8.264440e-02)*S70+(-1.007455e-01)*S71+(-1.043701e-01)*S72+(-7.341855e-02)*S73+(-1.969059e-01)*S74+(-1.795624e-02)*S75+(-4.522734e-02)*S76+(-1.079912e-01)*S77+(-5.964038e-04)*S78+(-2.632356e-02)*S79'
.param V54='V54_part8+(-8.660849e-02)*S80+(-7.201110e-03)*S81+(-2.082466e-02)*S82+(-1.357435e-01)*S83+(-2.296847e-02)*S84+(-3.021569e-02)*S85+(-2.541104e-01)*S86+(-5.512840e-03)*S87+(-2.877725e-02)*S88+(-1.976785e-01)*S89'
.param V55_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V55_part4='V55_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+6.032427e+00*S39'
.param V55_part5='V55_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+(-9.090456e-01)*S46+0.000000e+00*S47+(-1.123567e+00)*S48+0.000000e+00*S49'
.param V55_part6='V55_part5+(-3.713864e+01)*S50+(-1.443163e+00)*S51+(-3.281447e+00)*S52+0.000000e+00*S53+1.547748e+00*S54+0.000000e+00*S55+0.000000e+00*S56+(-8.304380e+00)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V55_part7='V55_part6+1.102074e+01*S60+(-3.203614e+01)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-7.976051e-01)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V55='V55_part8+0.000000e+00*S80+1.538600e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V56_part4='V56_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+(-9.844429e+00)*S39'
.param V56_part5='V56_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+2.163085e+01*S46+0.000000e+00*S47+3.056541e+01*S48+0.000000e+00*S49'
.param V56_part6='V56_part5+4.946129e+01*S50+2.939111e+01*S51+2.726574e+01*S52+0.000000e+00*S53+1.645912e+01*S54+0.000000e+00*S55+0.000000e+00*S56+2.473170e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V56_part7='V56_part6+(-5.586147e+00)*S60+1.094453e+02*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+5.273012e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V56='V56_part8+0.000000e+00*S80+1.588503e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V57_part4='V57_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+2.756037e+01*S39'
.param V57_part5='V57_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+4.408615e+01*S46+0.000000e+00*S47+5.719618e+01*S48+0.000000e+00*S49'
.param V57_part6='V57_part5+4.070051e+01*S50+7.085088e+01*S51+6.444589e+01*S52+0.000000e+00*S53+7.487481e+01*S54+0.000000e+00*S55+0.000000e+00*S56+8.018261e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V57_part7='V57_part6+9.801583e+00*S60+1.218358e+02*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+1.100317e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V57='V57_part8+0.000000e+00*S80+(-1.395742e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V58_part4='V58_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+1.993422e+00*S39'
.param V58_part5='V58_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+7.410534e+00*S46+0.000000e+00*S47+3.331200e+00*S48+0.000000e+00*S49'
.param V58_part6='V58_part5+2.914221e+00*S50+3.573694e+00*S51+4.448575e+00*S52+0.000000e+00*S53+4.714979e+00*S54+0.000000e+00*S55+0.000000e+00*S56+6.454583e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V58_part7='V58_part6+(-1.613892e+00)*S60+2.281991e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-3.106989e-01)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V58='V58_part8+0.000000e+00*S80+(-1.368091e+00)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V59_part4='V59_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+5.191990e+00*S39'
.param V59_part5='V59_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+4.330425e+00*S46+0.000000e+00*S47+(-6.786275e-02)*S48+0.000000e+00*S49'
.param V59_part6='V59_part5+1.502006e+01*S50+(-4.198343e+00)*S51+(-1.395329e+00)*S52+0.000000e+00*S53+3.056126e+00*S54+0.000000e+00*S55+0.000000e+00*S56+3.060897e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V59_part7='V59_part6+(-1.565106e+01)*S60+(-3.499502e+01)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+3.551895e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V59='V59_part8+0.000000e+00*S80+(-2.794415e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V60_part1='4.382213e+00*S0+5.124178e+00*S1+3.675151e+00*S2+(-2.068651e+03)*S3+3.240232e+00*S4+3.679322e+00*S5+(-2.065432e+03)*S6+1.000000e+04*S7+(-7.399309e+00)*S8+(-1.442337e+03)*S9'
.param V60_part2='V60_part1+1.281274e+02*S10+1.341464e+02*S11+(-1.632995e+00)*S12+1.560198e+00*S13+4.129565e+00*S14+5.579312e+00*S15+6.463606e+00*S16+(-1.246376e+01)*S17+5.657569e-02*S18+4.074146e-03*S19'
.param V60_part3='V60_part2+(-1.520069e+01)*S20+(-2.027623e+00)*S21+(-4.126703e+00)*S22+(-1.132288e+01)*S23+(-2.333613e+00)*S24+(-7.190860e-01)*S25+(-6.955513e+00)*S26+(-1.429864e+00)*S27+(-3.176370e+00)*S28+(-6.731255e+00)*S29'
.param V60_part4='V60_part3+(-3.358041e+00)*S30+(-7.888497e+00)*S31+(-5.518699e+00)*S32+(-2.614456e+00)*S33+(-6.027177e+00)*S34+(-5.979708e+00)*S35+(-6.518386e-01)*S36+(-2.351447e+00)*S37+(-6.624681e+00)*S38+(-2.959092e+00)*S39'
.param V60_part5='V60_part4+(-3.558506e+00)*S40+(-8.044612e+00)*S41+(-1.897881e+00)*S42+(-4.197976e+00)*S43+(-8.841925e+00)*S44+(-1.553318e+00)*S45+(-4.136138e+00)*S46+(-7.780064e+00)*S47+(-8.899557e-01)*S48+(-3.939393e+00)*S49'
.param V60_part6='V60_part5+(-4.619409e+00)*S50+(-1.276166e+00)*S51+(-4.412472e+00)*S52+(-1.242585e+01)*S53+(-2.323718e+00)*S54+(-5.429000e+00)*S55+(-1.213053e+01)*S56+(-4.511124e-01)*S57+(-5.121496e+00)*S58+(-1.122344e+01)*S59'
.param V60_part7='V60_part6+(-2.813098e+00)*S60+3.037996e+00*S61+(-1.124345e+01)*S62+(-1.166826e+00)*S63+(-5.315729e+00)*S64+(-1.410643e+01)*S65+(-1.911282e+00)*S66+(-4.438553e+00)*S67+(-1.606775e+01)*S68+(-2.327570e+00)*S69'
.param V60_part8='V60_part7+(-5.159679e+00)*S70+(-2.303365e+01)*S71+(-3.493404e+00)*S72+(-7.196022e+00)*S73+(-2.014225e+01)*S74+(-2.771813e-01)*S75+(-3.984627e+00)*S76+(-2.106364e+01)*S77+(-9.162932e-01)*S78+(-4.192905e+00)*S79'
.param V60='V60_part8+(-2.193550e+01)*S80+(-3.672738e+00)*S81+(-4.797855e+00)*S82+(-3.213518e+01)*S83+(-1.257427e+00)*S84+(-5.584806e+00)*S85+(-2.714144e+01)*S86+(-1.787218e+00)*S87+(-7.114897e+00)*S88+(-1.408158e+01)*S89'
.param V61_part1='(-1.542283e+01)*S0+5.900611e+00*S1+8.044727e+00*S2+1.745984e+01*S3+1.437290e+00*S4+1.621015e+00*S5+1.670225e+01*S6+1.000000e+04*S7+1.304035e+01*S8+4.367753e+01*S9'
.param V61_part2='V61_part1+1.716697e+03*S10+1.797342e+03*S11+2.708775e+00*S12+2.011682e+00*S13+1.487897e+00*S14+2.856316e+00*S15+3.874956e+00*S16+3.045947e+01*S17+8.268172e+00*S18+1.297941e+01*S19'
.param V61_part3='V61_part2+2.479219e+01*S20+9.978269e+00*S21+1.297151e+01*S22+1.591469e+01*S23+8.510340e+00*S24+7.444423e+00*S25+1.131449e+01*S26+6.637095e+00*S27+8.800301e+00*S28+1.078073e+01*S29'
.param V61_part4='V61_part3+2.108368e+01*S30+3.405396e+01*S31+1.851997e+01*S32+1.502245e+01*S33+2.299551e+01*S34+1.664771e+01*S35+9.102749e+00*S36+1.096844e+01*S37+1.504417e+01*S38+1.248480e+01*S39'
.param V61_part5='V61_part4+1.185163e+01*S40+1.551047e+01*S41+1.009999e+01*S42+1.160985e+01*S43+1.520743e+01*S44+1.753140e+01*S45+1.998758e+01*S46+2.441898e+01*S47+9.740127e+00*S48+1.793166e+01*S49'
.param V61_part6='V61_part5+1.715372e+01*S50+9.572982e+00*S51+1.368873e+01*S52+2.446217e+01*S53+1.175256e+01*S54+1.765325e+01*S55+2.192920e+01*S56+9.375505e+00*S57+1.596600e+01*S58+1.979427e+01*S59'
.param V61_part7='V61_part6+2.101695e+01*S60+2.800352e+00*S61+3.323536e+01*S62+1.894665e+01*S63+2.456648e+01*S64+3.099643e+01*S65+1.896351e+01*S66+2.153084e+01*S67+3.168698e+01*S68+1.865624e+01*S69'
.param V61_part8='V61_part7+2.096151e+01*S70+3.726512e+01*S71+1.891400e+01*S72+2.173597e+01*S73+2.871872e+01*S74+2.483822e+01*S75+3.059378e+01*S76+5.008883e+01*S77+2.421486e+01*S78+2.792413e+01*S79'
.param V61='V61_part8+4.573137e+01*S80+1.917651e+01*S81+2.678235e+01*S82+5.113901e+01*S83+2.216710e+01*S84+2.706453e+01*S85+3.971605e+01*S86+2.238625e+01*S87+2.718924e+01*S88+2.542045e+01*S89'
.param V62_part1='1.027391e+01*S0+(-3.058656e-02)*S1+2.685353e+00*S2+1.000000e+04*S3+1.895016e+00*S4+(-7.908404e-01)*S5+1.000000e+04*S6+2.205478e+03*S7+8.757278e+00*S8+6.910978e+03*S9'
.param V62_part2='V62_part1+3.832466e+02*S10+2.675199e+02*S11+8.148349e+00*S12+2.024869e+00*S13+2.295630e+00*S14+(-5.839305e+00)*S15+(-8.034410e-04)*S16+1.756267e+01*S17+4.270000e+00*S18+6.778470e+00*S19'
.param V62_part3='V62_part2+2.071154e+01*S20+7.164115e+00*S21+1.050509e+01*S22+1.899984e+01*S23+9.359412e+00*S24+8.933469e+00*S25+1.551502e+01*S26+8.860354e+00*S27+1.098468e+01*S28+1.399896e+01*S29'
.param V62_part4='V62_part3+2.156897e+01*S30+3.390602e+01*S31+2.331961e+01*S32+1.739653e+01*S33+2.700969e+01*S34+2.328486e+01*S35+1.282183e+01*S36+1.886609e+01*S37+2.425380e+01*S38+1.132210e+01*S39'
.param V62_part5='V62_part4+2.043520e+01*S40+2.531908e+01*S41+1.892481e+01*S42+2.229441e+01*S43+2.631471e+01*S44+2.256062e+01*S45+1.893163e+01*S46+3.446243e+01*S47+1.054366e+01*S48+2.926850e+01*S49'
.param V62_part6='V62_part5+2.923159e+01*S50+1.046604e+01*S51+1.689807e+01*S52+3.795590e+01*S53+1.188998e+01*S54+3.341795e+01*S55+3.892318e+01*S56+1.381495e+01*S57+3.236721e+01*S58+4.016175e+01*S59'
.param V62_part7='V62_part6+2.553630e+01*S60+1.317026e+01*S61+4.963417e+01*S62+3.116408e+01*S63+4.389649e+01*S64+5.333781e+01*S65+3.427122e+01*S66+3.901723e+01*S67+5.459430e+01*S68+3.683028e+01*S69'
.param V62_part8='V62_part7+4.206315e+01*S70+5.650202e+01*S71+4.015122e+01*S72+4.617278e+01*S73+5.741605e+01*S74+3.763144e+01*S75+4.568432e+01*S76+6.889547e+01*S77+4.153301e+01*S78+4.922839e+01*S79'
.param V62='V62_part8+7.003611e+01*S80+4.732264e+01*S81+5.261725e+01*S82+7.647678e+01*S83+4.826033e+01*S84+5.471487e+01*S85+7.682688e+01*S86+5.029448e+01*S87+5.898055e+01*S88+7.557375e+01*S89'
.param V63_part1='(-3.234894e+00)*S0+(-4.510226e-02)*S1+(-4.224092e-02)*S2+2.365130e+00*S3+(-6.407702e-01)*S4+(-2.681656e+00)*S5+6.656224e+00*S6+(-1.000000e+04)*S7+2.384528e+00*S8+1.125352e+01*S9'
.param V63_part2='V63_part1+7.760218e+02*S10+8.951861e+02*S11+1.236020e+00*S12+1.158172e-01*S13+1.117740e+00*S14+(-7.912782e-02)*S15+4.266254e-01*S16+3.974483e-01*S17+8.881762e-02*S18+3.477853e-01*S19'
.param V63_part3='V63_part2+5.262243e-02*S20+2.822064e-01*S21+5.176035e-01*S22+(-3.008977e-02)*S23+3.647645e-01*S24+2.660348e-01*S25+3.158409e-01*S26+5.702497e-01*S27+4.055507e-01*S28+6.295508e-01*S29'
.param V63_part4='V63_part3+5.593381e-01*S30+8.681140e-01*S31+5.537206e-01*S32+4.819986e-01*S33+1.011812e+00*S34+4.567542e-01*S35+2.894092e-01*S36+4.410604e-01*S37+4.838569e-01*S38+1.346443e-02*S39'
.param V63_part5='V63_part4+5.245575e-01*S40+5.101421e-01*S41+4.264120e-01*S42+5.742389e-01*S43+6.496651e-01*S44+4.211661e-01*S45+(-1.557103e+00)*S46+5.516384e-01*S47+(-2.368227e-01)*S48+4.520773e-01*S49'
.param V63_part6='V63_part5+(-2.745875e-01)*S50+(-3.003543e-01)*S51+(-4.581068e-01)*S52+1.450561e-03*S53+(-5.594491e-01)*S54+6.266650e-01*S55+6.455093e-04*S56+(-8.625083e-01)*S57+2.061919e-01*S58+4.554047e-01*S59'
.param V63_part7='V63_part6+5.062544e-01*S60+2.826234e-02*S61+4.815045e-01*S62+2.644636e-01*S63+5.656886e-01*S64+6.672601e-01*S65+3.418947e-01*S66+3.900954e-01*S67+5.106834e-01*S68+4.187091e-01*S69'
.param V63_part8='V63_part7+4.374392e-01*S70+4.962907e-01*S71+3.123566e-01*S72+6.279045e-01*S73+4.935678e-01*S74+3.041171e-01*S75+2.143192e-01*S76+(-2.011999e-01)*S77+3.828149e-01*S78+4.715349e-01*S79'
.param V63='V63_part8+3.904694e-01*S80+6.641205e-01*S81+3.597657e-01*S82+(-4.250962e-01)*S83+4.082130e-01*S84+4.247701e-01*S85+5.549392e-01*S86+4.153277e-01*S87+6.219266e-01*S88+5.585498e-01*S89'
.param V64_part1='2.111525e-01*S0+(-6.076588e-02)*S1+1.964384e-01*S2+1.055083e-01*S3+3.465403e-02*S4+1.143608e-01*S5+5.997603e-01*S6+(-2.026122e+02)*S7+1.669317e-01*S8+4.217678e-01*S9'
.param V64_part2='V64_part1+2.760485e+01*S10+1.134039e+02*S11+6.607126e-02*S12+4.127015e-02*S13+2.315030e-02*S14+(-3.084611e-01)*S15+(-2.085481e-01)*S16+(-1.536746e+00)*S17+(-1.008103e+00)*S18+(-1.759713e+00)*S19'
.param V64_part3='V64_part2+(-1.830191e+00)*S20+(-1.466782e+00)*S21+(-1.653291e+00)*S22+(-2.192500e+00)*S23+(-1.735233e+00)*S24+(-1.485160e+00)*S25+(-2.021181e+00)*S26+(-1.951589e+00)*S27+(-2.315670e+00)*S28+(-2.592914e+00)*S29'
.param V64_part4='V64_part3+(-2.078727e+00)*S30+(-5.202008e+00)*S31+(-2.652895e+00)*S32+(-2.721504e+00)*S33+(-3.968221e+00)*S34+(-3.019448e+00)*S35+(-2.122623e+00)*S36+(-1.418211e+00)*S37+(-3.140948e+00)*S38+(-2.589154e+00)*S39'
.param V64_part5='V64_part4+(-1.669919e+00)*S40+(-3.778875e+00)*S41+(-2.032137e+00)*S42+(-2.337084e+00)*S43+(-4.183895e+00)*S44+(-1.216075e+00)*S45+(-4.110485e+00)*S46+(-3.886858e+00)*S47+(-1.876500e+00)*S48+(-1.814257e+00)*S49'
.param V64_part6='V64_part5+(-7.734500e+00)*S50+(-1.505223e+00)*S51+(-2.383986e+00)*S52+(-5.532794e+00)*S53+(-3.751861e+00)*S54+(-3.089301e+00)*S55+(-6.030647e+00)*S56+(-4.188994e+00)*S57+(-5.797454e+00)*S58+(-7.260227e+00)*S59'
.param V64_part7='V64_part6+2.981680e-01*S60+2.161263e+00*S61+(-6.364287e+00)*S62+(-4.013523e+00)*S63+(-2.290193e+00)*S64+(-8.094516e+00)*S65+(-5.128807e+00)*S66+(-6.067594e+00)*S67+(-8.473100e+00)*S68+(-6.222286e+00)*S69'
.param V64_part8='V64_part7+(-7.316121e+00)*S70+(-9.487382e+00)*S71+(-7.453511e+00)*S72+(-8.690275e+00)*S73+(-8.352130e+00)*S74+(-3.620245e+00)*S75+(-4.941865e+00)*S76+(-7.639138e+00)*S77+(-5.030060e+00)*S78+(-6.590916e+00)*S79'
.param V64='V64_part8+(-9.923931e+00)*S80+(-1.081329e+00)*S81+(-8.195372e+00)*S82+(-9.550217e+00)*S83+(-7.798045e+00)*S84+(-9.596302e+00)*S85+(-8.727862e+00)*S86+(-9.345127e+00)*S87+(-1.109434e+01)*S88+(-1.052369e+01)*S89'
.param V65_part1='8.777692e+00*S0+1.028013e+01*S1+9.739164e+00*S2+5.634498e+00*S3+1.215146e+01*S4+9.698869e+00*S5+1.755904e+01*S6+1.486674e+01*S7+8.034676e+00*S8+1.653709e+01*S9'
.param V65_part2='V65_part1+1.354470e+01*S10+1.103293e+01*S11+8.131826e+00*S12+1.118509e+01*S13+6.558747e+00*S14+1.876577e+01*S15+6.774090e+00*S16+5.452942e+00*S17+6.412991e+00*S18+1.077399e+01*S19'
.param V65_part3='V65_part2+4.295778e+00*S20+4.714268e+00*S21+4.765446e+00*S22+3.917547e+00*S23+4.472364e+00*S24+4.517841e+00*S25+2.537282e+00*S26+2.100362e+00*S27+1.915642e+00*S28+1.826495e+00*S29'
.param V65_part4='V65_part3+7.117596e+00*S30+7.700505e+00*S31+3.380237e+00*S32+4.679159e+00*S33+6.166304e+00*S34+3.245991e+00*S35+4.607829e+00*S36+3.107954e+00*S37+3.130788e+00*S38+3.515497e+00*S39'
.param V65_part5='V65_part4+2.819556e+00*S40+2.411184e+00*S41+2.598138e+00*S42+2.583067e+00*S43+2.005646e+00*S44+5.852068e+00*S45+2.684144e+00*S46+3.559201e+00*S47+2.428598e+00*S48+2.800201e+00*S49'
.param V65_part6='V65_part5+2.581665e+00*S50+2.549320e+00*S51+2.279125e+00*S52+2.684560e+00*S53+3.119130e+00*S54+3.318585e+00*S55+2.406864e+00*S56+3.440218e+00*S57+2.165673e+00*S58+1.965355e+00*S59'
.param V65_part7='V65_part6+4.560499e+00*S60+2.575233e+00*S61+3.038127e+00*S62+5.771941e+00*S63+3.970997e+00*S64+2.993750e+00*S65+5.058123e+00*S66+3.610848e+00*S67+2.825728e+00*S68+5.145577e+00*S69'
.param V65_part8='V65_part7+3.494148e+00*S70+2.583588e+00*S71+4.400783e+00*S72+3.286111e+00*S73+1.716974e+00*S74+6.571943e+00*S75+4.052728e+00*S76+2.077392e+00*S77+4.988246e+00*S78+4.061006e+00*S79'
.param V65='V65_part8+1.987877e+00*S80+4.837374e+00*S81+3.322451e+00*S82+2.573870e+00*S83+5.309905e+00*S84+3.606656e+00*S85+2.496308e+00*S86+3.044173e+00*S87+2.501178e+00*S88+2.138631e+00*S89'
.param V66_part1='3.445277e+01*S0+5.702847e+01*S1+6.434281e+00*S2+3.030137e+01*S3+1.215544e+01*S4+4.277343e-01*S5+1.261876e+00*S6+3.383766e+00*S7+3.294076e-01*S8+1.689659e+00*S9'
.param V66_part2='V66_part1+1.014025e+00*S10+4.451672e-01*S11+6.801135e-01*S12+(-4.204419e+00)*S13+(-1.360540e+00)*S14+(-2.465510e+01)*S15+1.842524e+00*S16+(-1.714333e-01)*S17+1.989766e-01*S18+(-2.550118e+00)*S19'
.param V66_part3='V66_part2+(-4.564985e-01)*S20+(-5.212613e-01)*S21+(-3.976057e-01)*S22+(-1.144907e+00)*S23+(-1.383317e+00)*S24+(-2.038065e+00)*S25+(-4.253278e-01)*S26+(-3.669701e-01)*S27+7.427476e-02*S28+(-3.649727e-02)*S29'
.param V66_part4='V66_part3+1.504759e+00*S30+1.266125e+00*S31+(-2.375777e-01)*S32+4.085036e-01*S33+(-4.665464e-01)*S34+(-1.732390e-02)*S35+(-4.693914e-01)*S36+8.138602e-01*S37+(-7.305259e-02)*S38+4.758347e-01*S39'
.param V66_part5='V66_part4+5.412887e-01*S40+3.643334e-02*S41+8.526631e-01*S42+1.149251e-01*S43+1.073228e-01*S44+7.284590e-01*S45+1.833254e+00*S46+(-3.785690e-01)*S47+3.444622e-01*S48+2.385266e+00*S49'
.param V66_part6='V66_part5+6.526170e-02*S50+5.390129e-01*S51+2.181525e-01*S52+(-3.488118e-01)*S53+(-4.948686e-01)*S54+(-2.723653e-01)*S55+(-8.072845e-02)*S56+(-7.348534e-01)*S57+(-5.516659e-02)*S58+(-1.871940e-01)*S59'
.param V66_part7='V66_part6+5.502205e-01*S60+3.061420e-01*S61+(-4.544524e-01)*S62+(-7.139900e-01)*S63+4.144126e-01*S64+(-4.490246e-01)*S65+(-7.717670e-01)*S66+(-7.029849e-01)*S67+(-5.299810e-01)*S68+(-8.337643e-01)*S69'
.param V66_part8='V66_part7+(-7.265906e-01)*S70+(-4.418373e-01)*S71+(-6.953592e-01)*S72+(-5.212807e-01)*S73+9.719504e-02*S74+(-1.587294e+00)*S75+(-4.415358e-01)*S76+7.434589e-02*S77+2.397920e-01*S78+(-9.805759e-01)*S79'
.param V66='V66_part8+(-2.009295e-01)*S80+(-1.251356e+00)*S81+(-2.846791e-01)*S82+(-5.039483e-01)*S83+(-1.444811e+00)*S84+(-1.208524e+00)*S85+(-6.107353e-01)*S86+(-3.415541e-01)*S87+(-2.808481e-01)*S88+(-3.002580e-01)*S89'
.param V67_part1='(-7.691389e+00)*S0+(-1.743772e+01)*S1+(-2.179740e+00)*S2+(-3.848093e+00)*S3+(-9.042308e+00)*S4+(-2.173750e+00)*S5+(-1.270585e+01)*S6+(-8.590250e+00)*S7+(-1.240150e+00)*S8+(-1.329710e+01)*S9'
.param V67_part2='V67_part1+(-7.358408e+00)*S10+(-3.646157e+00)*S11+(-1.263835e+00)*S12+(-2.690557e+00)*S13+(-1.246342e+00)*S14+(-1.594903e+01)*S15+(-2.171948e+00)*S16+(-2.788293e+00)*S17+(-9.735943e+00)*S18+(-9.218215e+00)*S19'
.param V67_part3='V67_part2+(-1.962762e+00)*S20+(-5.256567e+00)*S21+(-3.861407e+00)*S22+(-1.693076e+00)*S23+(-4.081340e+00)*S24+(-2.699472e+00)*S25+(-1.145964e+00)*S26+(-7.864787e-01)*S27+(-1.431600e+00)*S28+(-6.646288e-01)*S29'
.param V67_part4='V67_part3+(-9.260443e+00)*S30+(-7.585492e+00)*S31+(-1.219907e+00)*S32+(-5.602450e+00)*S33+(-5.921817e+00)*S34+(-1.395616e+00)*S35+(-4.946997e+00)*S36+(-2.730959e+00)*S37+(-1.403330e+00)*S38+(-4.929078e+00)*S39'
.param V67_part5='V67_part4+(-2.312326e+00)*S40+(-8.273043e-01)*S41+(-3.749475e+00)*S42+(-1.549627e+00)*S43+(-6.199370e-01)*S44+(-7.114142e+00)*S45+(-1.488219e+00)*S46+(-1.674031e+00)*S47+(-1.630557e+00)*S48+(-2.491023e+00)*S49'
.param V67_part6='V67_part5+(-9.811473e-01)*S50+(-2.538501e+00)*S51+(-9.322706e-01)*S52+(-8.673046e-01)*S53+(-2.063010e+00)*S54+(-1.640532e+00)*S55+(-8.446913e-01)*S56+(-2.304262e+00)*S57+(-7.986150e-01)*S58+(-4.270130e-01)*S59'
.param V67_part7='V67_part6+(-4.890760e+00)*S60+(-1.412252e+00)*S61+(-1.238719e+00)*S62+(-6.342380e+00)*S63+(-3.433966e+00)*S64+(-1.274316e+00)*S65+(-5.074564e+00)*S66+(-1.988661e+00)*S67+(-1.120221e+00)*S68+(-5.521210e+00)*S69'
.param V67_part8='V67_part7+(-1.873039e+00)*S70+(-9.135028e-01)*S71+(-3.821207e+00)*S72+(-1.779687e+00)*S73+(-5.508061e-01)*S74+(-7.633164e+00)*S75+(-2.876816e+00)*S76+(-7.760128e-01)*S77+(-5.845264e+00)*S78+(-2.598491e+00)*S79'
.param V67='V67_part8+(-5.501381e-01)*S80+(-4.333730e+00)*S81+(-2.177917e+00)*S82+(-9.914292e-01)*S83+(-4.823810e+00)*S84+(-1.507269e+00)*S85+(-7.782480e-01)*S86+(-2.199388e+00)*S87+(-1.088688e+00)*S88+(-6.777222e-01)*S89'
.param V68_part1='(-1.414512e+01)*S0+4.271632e-01*S1+(-7.834291e-01)*S2+(-2.029181e+00)*S3+(-2.806763e+00)*S4+(-2.472108e-01)*S5+(-1.666497e+00)*S6+2.592430e+00*S7+(-2.136003e-02)*S8+5.129575e-01*S9'
.param V68_part2='V68_part1+5.904931e-01*S10+5.674497e-01*S11+8.530883e-01*S12+(-4.894618e-01)*S13+(-1.132283e+00)*S14+(-5.561040e-02)*S15+(-1.475140e+00)*S16+(-2.636687e-01)*S17+(-3.271678e-01)*S18+5.906025e-02*S19'
.param V68_part3='V68_part2+(-1.792132e-01)*S20+(-3.406327e-02)*S21+(-1.542502e-02)*S22+(-1.574912e-01)*S23+1.103865e-01*S24+(-2.233290e-02)*S25+(-4.751029e-02)*S26+4.915414e-01*S27+2.008261e-02*S28+1.526190e-01*S29'
.param V68_part4='V68_part3+(-4.974822e-01)*S30+(-2.024258e-01)*S31+3.764085e-01*S32+(-2.134261e-01)*S33+(-6.777990e-02)*S34+2.856064e-01*S35+6.777831e-01*S36+9.560024e-02*S37+2.943062e-01*S38+4.125451e-01*S39'
.param V68_part5='V68_part4+1.475308e-01*S40+2.737705e-01*S41+1.894501e-01*S42+3.464892e-01*S43+2.394401e-01*S44+7.465331e-01*S45+1.628771e-01*S46+2.484811e-01*S47+3.879679e-01*S48+7.907366e-02*S49'
.param V68_part6='V68_part5+2.663581e-01*S50+2.931354e-01*S51+4.146025e-01*S52+2.575834e-01*S53+3.528145e-01*S54+7.349995e-01*S55+2.624860e-01*S56+3.069723e-01*S57+2.750210e-01*S58+2.312306e-01*S59'
.param V68_part7='V68_part6+7.801571e-01*S60+3.809565e-01*S61+2.575251e-01*S62+8.495666e-01*S63+5.259909e-02*S64+2.411545e-01*S65+4.935973e-01*S66+2.577917e-01*S67+1.643450e-01*S68+4.989525e-01*S69'
.param V68_part8='V68_part7+2.299844e-01*S70+1.645844e-01*S71+5.199658e-01*S72+2.764753e-01*S73+1.412349e-01*S74+5.674189e-01*S75+3.406365e-01*S76+1.406001e-01*S77+4.127874e-01*S78+4.386551e-01*S79'
.param V68='V68_part8+1.301541e-01*S80+5.212812e-01*S81+1.910643e-01*S82+1.329917e-01*S83+2.755957e-01*S84+2.750137e-01*S85+1.831300e-01*S86+2.690282e-01*S87+2.385781e-01*S88+1.455491e-01*S89'
.param V69_part1='2.991266e+00*S0+1.471655e+00*S1+2.318355e-01*S2+1.018520e+00*S3+7.184924e-01*S4+7.133308e-02*S5+2.366829e-01*S6+(-1.432779e-02)*S7+(-9.287861e-02)*S8+3.929001e-02*S9'
.param V69_part2='V69_part1+7.592768e-03*S10+2.711106e-03*S11+(-5.351846e-02)*S12+(-8.703281e-02)*S13+1.455326e-02*S14+(-7.492692e-01)*S15+2.252259e-01*S16+1.347798e-01*S17+1.023239e-02*S18+(-7.779017e-03)*S19'
.param V69_part3='V69_part2+1.282284e-01*S20+3.593425e-02*S21+1.500628e-01*S22+(-3.590177e-02)*S23+1.185011e-01*S24+(-3.098005e-03)*S25+(-6.985130e-02)*S26+(-4.821637e-01)*S27+(-2.346162e-01)*S28+(-3.445297e-01)*S29'
.param V69_part4='V69_part3+(-9.847238e-01)*S30+2.020062e-01*S31+(-7.104969e-01)*S32+(-2.238145e+00)*S33+4.209931e-01*S34+(-6.494279e-01)*S35+(-9.155876e-01)*S36+(-8.777300e-01)*S37+(-5.078797e-01)*S38+(-7.790803e-01)*S39'
.param V69_part5='V69_part4+(-7.241320e-01)*S40+(-3.882268e-01)*S41+(-1.061545e+00)*S42+(-3.723506e-01)*S43+(-2.798348e-01)*S44+(-1.265096e+00)*S45+(-1.536451e+00)*S46+(-5.182054e-01)*S47+(-4.149213e-01)*S48+(-1.168599e+00)*S49'
.param V69_part6='V69_part5+(-4.296130e-01)*S50+(-2.547567e-01)*S51+(-1.921539e-01)*S52+(-3.086134e-01)*S53+(-2.881978e-01)*S54+(-1.283022e-01)*S55+(-1.462203e-01)*S56+(-3.073330e-01)*S57+(-1.091572e-01)*S58+(-3.642344e-02)*S59'
.param V69_part7='V69_part6+(-5.001059e-01)*S60+(-7.480613e-02)*S61+(-2.435893e-01)*S62+(-8.298614e-01)*S63+(-9.817608e-01)*S64+(-1.989098e-01)*S65+(-5.998214e-01)*S66+(-3.981725e-01)*S67+(-8.021610e-02)*S68+(-5.463083e-01)*S69'
.param V69_part8='V69_part7+(-2.351201e-01)*S70+(-8.362335e-02)*S71+(-5.564648e-01)*S72+(-2.539953e-01)*S73+(-2.841410e-02)*S74+(-9.302675e-01)*S75+(-4.647030e-01)*S76+(-1.475856e-02)*S77+(-4.444273e-01)*S78+(-2.356313e-01)*S79'
.param V69='V69_part8+(-9.222592e-02)*S80+(-2.635516e-01)*S81+(-2.453390e-01)*S82+(-1.433831e-01)*S83+(-4.993200e-01)*S84+(-2.738161e-01)*S85+(-3.751924e-02)*S86+(-2.152897e-01)*S87+(-6.027182e-02)*S88+(-1.655197e-02)*S89'
.param V70_part1='0.000000e+00*S0+(-2.029674e+00)*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-3.390706e+00)*S9'
.param V70_part2='V70_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+2.137782e+01*S13+0.000000e+00*S14+2.670979e+01*S15+0.000000e+00*S16+(-3.596682e+00)*S17+3.122654e+01*S18+0.000000e+00*S19'
.param V70_part3='V70_part2+(-6.019540e+01)*S20+2.239306e+01*S21+1.747954e+01*S22+(-7.854424e+01)*S23+3.051496e+01*S24+7.520725e-02*S25+4.252633e+01*S26+5.025086e+01*S27+(-5.780547e+01)*S28+4.541244e+01*S29'
.param V70_part4='V70_part3+1.634415e+01*S30+1.453761e+01*S31+2.699485e+01*S32+9.261089e+00*S33+1.558237e+01*S34+2.636146e+01*S35+2.173362e+01*S36+1.750230e+01*S37+7.087417e+00*S38+(-3.583708e-01)*S39'
.param V70_part5='V70_part4+(-1.094825e+01)*S40+(-6.825498e+00)*S41+(-4.956005e+01)*S42+1.092665e+00*S43+(-1.034192e+00)*S44+1.009811e+01*S45+(-1.502862e+01)*S46+1.232025e+01*S47+0.000000e+00*S48+(-2.753304e+01)*S49'
.param V70_part6='V70_part5+2.792094e+01*S50+0.000000e+00*S51+0.000000e+00*S52+5.362441e+01*S53+0.000000e+00*S54+1.602093e+01*S55+5.637186e+01*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V70_part7='V70_part6+3.246398e+01*S60+0.000000e+00*S61+2.354011e+01*S62+1.392101e+01*S63+(-1.517730e+01)*S64+3.149382e+01*S65+(-8.649366e+00)*S66+(-1.065986e+00)*S67+1.154462e+02*S68+3.632657e+00*S69'
.param V70_part8='V70_part7+4.897341e+00*S70+1.704659e+02*S71+(-5.241076e+01)*S72+3.862515e+00*S73+0.000000e+00*S74+4.591132e-01*S75+1.941986e+01*S76+0.000000e+00*S77+(-8.053143e+00)*S78+6.533982e+00*S79'
.param V70='V70_part8+0.000000e+00*S80+(-1.524264e+01)*S81+(-1.358959e+01)*S82+0.000000e+00*S83+(-4.727546e+01)*S84+(-2.492523e+01)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V71_part1='0.000000e+00*S0+1.033693e+01*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+1.859462e+01*S9'
.param V71_part2='V71_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-8.045439e+00)*S13+0.000000e+00*S14+4.404483e+01*S15+0.000000e+00*S16+4.005664e+01*S17+(-1.842818e+01)*S18+0.000000e+00*S19'
.param V71_part3='V71_part2+5.983012e+01*S20+1.482731e+01*S21+6.512320e+00*S22+9.948069e+01*S23+7.592843e+00*S24+5.032774e+01*S25+6.490854e+00*S26+(-1.550199e+01)*S27+9.869640e+01*S28+3.664334e+00*S29'
.param V71_part4='V71_part3+(-3.140976e+00)*S30+1.326902e+01*S31+2.332394e+01*S32+3.591788e+01*S33+2.005298e+01*S34+2.418950e+01*S35+1.530584e+01*S36+4.100917e+01*S37+5.005973e+01*S38+5.864072e+01*S39'
.param V71_part5='V71_part4+8.233384e+01*S40+6.073757e+01*S41+9.931306e+01*S42+6.809319e+01*S43+3.197566e+01*S44+3.171532e+01*S45+5.783566e+01*S46+2.691155e+01*S47+0.000000e+00*S48+1.035480e+02*S49'
.param V71_part6='V71_part5+2.114570e+00*S50+0.000000e+00*S51+0.000000e+00*S52+(-3.628623e+00)*S53+0.000000e+00*S54+5.323335e+01*S55+(-4.184807e+00)*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V71_part7='V71_part6+2.000222e+01*S60+0.000000e+00*S61+6.277305e-01*S62+5.215685e+01*S63+8.251596e+01*S64+1.334594e+00*S65+8.042546e+01*S66+7.049232e+01*S67+3.603443e+01*S68+8.061124e+01*S69'
.param V71_part8='V71_part7+4.507292e+01*S70+(-4.477359e+01)*S71+1.247835e+02*S72+1.170633e+02*S73+0.000000e+00*S74+6.875899e+01*S75+3.666024e+01*S76+0.000000e+00*S77+6.435635e+01*S78+4.900584e+01*S79'
.param V71='V71_part8+0.000000e+00*S80+9.765485e+01*S81+1.129435e+02*S82+0.000000e+00*S83+1.349916e+02*S84+7.956354e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V72_part1='0.000000e+00*S0+9.510889e-01*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-1.545451e+01)*S9'
.param V72_part2='V72_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+(-1.947738e+01)*S13+0.000000e+00*S14+(-8.334633e+01)*S15+0.000000e+00*S16+2.433689e+01*S17+8.292419e+00*S18+0.000000e+00*S19'
.param V72_part3='V72_part2+8.634517e+01*S20+8.563034e-01*S21+2.180736e+01*S22+7.072417e+01*S23+(-8.886334e+00)*S24+(-1.596028e-01)*S25+(-3.879069e+00)*S26+9.089966e+00*S27+5.099143e+00*S28+(-9.606719e-01)*S29'
.param V72_part4='V72_part3+5.351937e+01*S30+3.896833e+01*S31+1.872268e+01*S32+3.795708e+01*S33+3.089437e+01*S34+1.693513e+01*S35+3.671086e+01*S36+(-2.720937e+00)*S37+1.896752e+01*S38+(-1.052733e+01)*S39'
.param V72_part5='V72_part4+(-1.778539e+01)*S40+1.625875e+01*S41+8.293501e+00*S42+(-2.857481e+01)*S43+2.625199e+01*S44+2.520168e+01*S45+6.569009e+01*S46+3.899848e+01*S47+0.000000e+00*S48+4.469995e+01*S49'
.param V72_part6='V72_part5+1.867955e+01*S50+0.000000e+00*S51+0.000000e+00*S52+5.908798e-02*S53+0.000000e+00*S54+(-1.676578e+01)*S55+(-9.232693e+00)*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V72_part7='V72_part6+1.909147e+00*S60+0.000000e+00*S61+4.572559e+01*S62+2.023080e+01*S63+3.718679e+01*S64+3.216457e+01*S65+3.732320e+01*S66+1.343548e+01*S67+(-8.852526e+01)*S68+(-1.900139e+01)*S69'
.param V72_part8='V72_part7+2.762369e+01*S70+(-9.273196e+01)*S71+7.508732e+00*S72+(-1.058779e+02)*S73+0.000000e+00*S74+7.074544e+01*S75+3.815467e+01*S76+0.000000e+00*S77+9.510843e+01*S78+6.035353e+01*S79'
.param V72='V72_part8+0.000000e+00*S80+1.060849e+01*S81+3.711615e+00*S82+0.000000e+00*S83+6.275559e+01*S84+5.882164e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V73_part1='0.000000e+00*S0+(-5.684464e-01)*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+2.393481e+00*S9'
.param V73_part2='V73_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+2.535147e-01*S13+0.000000e+00*S14+(-4.123163e+00)*S15+0.000000e+00*S16+8.440647e+00*S17+2.881707e-02*S18+0.000000e+00*S19'
.param V73_part3='V73_part2+(-4.149860e-01)*S20+1.302366e+00*S21+2.043930e+00*S22+(-2.476529e+01)*S23+(-1.084831e+00)*S24+(-1.593663e+01)*S25+(-3.135211e+01)*S26+(-4.251630e+00)*S27+(-3.073176e+01)*S28+(-1.400597e+01)*S29'
.param V73_part4='V73_part3+(-4.844898e+00)*S30+(-8.387715e+00)*S31+(-1.240032e+01)*S32+(-9.329773e+00)*S33+(-1.053671e+01)*S34+(-1.437894e+01)*S35+(-5.165218e+00)*S36+(-1.515373e+01)*S37+(-1.666307e+01)*S38+(-7.327018e+00)*S39'
.param V73_part5='V73_part4+(-1.452906e+01)*S40+(-1.902022e+01)*S41+(-1.432429e+01)*S42+(-9.181198e-01)*S43+(-1.779873e+01)*S44+(-9.695377e+00)*S45+(-1.510641e+01)*S46+(-1.280456e+01)*S47+0.000000e+00*S48+(-2.020692e+01)*S49'
.param V73_part6='V73_part5+(-1.859420e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+(-1.231499e+01)*S53+0.000000e+00*S54+1.393260e+01*S55+(-1.260383e+01)*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V73_part7='V73_part6+(-2.335360e+00)*S60+0.000000e+00*S61+(-1.124173e+01)*S62+(-5.301546e+00)*S63+(-3.152909e+01)*S64+(-6.580708e+00)*S65+(-7.969003e+00)*S66+(-1.889635e+01)*S67+(-6.125553e+00)*S68+(-4.939041e+00)*S69'
.param V73_part8='V73_part7+(-1.569802e+01)*S70+3.817766e+00*S71+(-1.395335e+01)*S72+(-6.081013e+00)*S73+0.000000e+00*S74+(-1.408356e+01)*S75+(-1.814038e+01)*S76+0.000000e+00*S77+(-1.320052e+01)*S78+(-4.041703e+00)*S79'
.param V73='V73_part8+0.000000e+00*S80+(-3.325796e+00)*S81+(-2.131384e+01)*S82+0.000000e+00*S83+(-8.804029e+00)*S84+(-3.714050e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V74_part1='0.000000e+00*S0+(-1.629595e-01)*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-2.008643e-01)*S9'
.param V74_part2='V74_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+1.667902e-02*S13+0.000000e+00*S14+2.382305e+00*S15+0.000000e+00*S16+(-1.632187e+01)*S17+(-1.537131e+01)*S18+0.000000e+00*S19'
.param V74_part3='V74_part2+(-1.213916e+01)*S20+(-2.659550e+01)*S21+(-2.565916e+01)*S22+1.358456e+01*S23+(-2.797938e+01)*S24+2.032982e+00*S25+1.348747e+01*S26+(-4.268420e+00)*S27+6.303090e+00*S28+(-8.598099e+00)*S29'
.param V74_part4='V74_part3+(-8.828767e+00)*S30+4.218916e+00*S31+4.799501e+00*S32+3.168322e+00*S33+5.459909e+00*S34+(-4.539306e+00)*S35+6.651315e+00*S36+(-9.135693e+00)*S37+(-1.462021e+01)*S38+(-8.011368e-01)*S39'
.param V74_part5='V74_part4+(-1.005119e+01)*S40+(-1.821415e+01)*S41+(-8.727664e+00)*S42+(-1.544979e+00)*S43+(-1.697049e+01)*S44+8.173287e+00*S45+(-1.061351e+01)*S46+(-1.147970e+01)*S47+0.000000e+00*S48+(-1.399070e+01)*S49'
.param V74_part6='V74_part5+(-2.451976e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+(-1.750200e+01)*S53+0.000000e+00*S54+1.176184e+01*S55+(-1.941190e+01)*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V74_part7='V74_part6+(-8.077862e+00)*S60+0.000000e+00*S61+(-1.929579e+01)*S62+(-2.171801e+00)*S63+(-2.391100e+01)*S64+(-2.843216e+01)*S65+(-1.328195e+00)*S66+(-1.368419e+01)*S67+(-2.102029e+01)*S68+(-4.566557e+00)*S69'
.param V74_part8='V74_part7+(-2.065782e+01)*S70+(-3.346969e+01)*S71+(-1.676544e+01)*S72+(-4.309342e+01)*S73+0.000000e+00*S74+(-6.930854e-01)*S75+(-9.155961e+00)*S76+0.000000e+00*S77+3.615718e+00*S78+(-3.066493e+00)*S79'
.param V74='V74_part8+0.000000e+00*S80+1.629764e+00*S81+(-1.988914e+01)*S82+0.000000e+00*S83+(-1.002976e+01)*S84+(-5.207481e+01)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V75_part1='2.228467e+01*S0+1.871088e+01*S1+4.444441e+01*S2+7.551536e+01*S3+4.309316e+01*S4+3.081666e+02*S5+2.558806e+02*S6+1.399235e+02*S7+8.114603e+03*S8+5.659445e+03*S9'
.param V75_part2='V75_part1+5.998810e+03*S10+2.274082e+03*S11+1.932905e+02*S12+1.403892e+02*S13+1.000000e+04*S14+(-2.057595e+00)*S15+1.033376e+01*S16+4.516527e+03*S17+(-3.976348e+01)*S18+5.167895e+01*S19'
.param V75_part3='V75_part2+1.000000e+04*S20+5.638190e+01*S21+9.602519e+01*S22+1.148637e+03*S23+4.995471e+01*S24+1.123409e+03*S25+1.022126e+02*S26+1.273485e+01*S27+4.651582e+02*S28+1.191260e+01*S29'
.param V75_part4='V75_part3+4.487899e+01*S30+4.073341e+02*S31+4.832241e+00*S32+8.253430e+00*S33+2.158749e+01*S34+3.188256e+00*S35+(-3.245892e-02)*S36+1.475207e+00*S37+2.203389e+00*S38+9.467787e-01*S39'
.param V75_part5='V75_part4+8.866836e-01*S40+1.871219e+00*S41+8.928330e-01*S42+9.217155e-01*S43+1.590706e+00*S44+9.406043e-01*S45+7.041452e+00*S46+2.109009e+00*S47+3.395271e+00*S48+7.812000e-01*S49'
.param V75_part6='V75_part5+1.331283e+00*S50+6.446069e+00*S51+2.156409e+00*S52+6.650009e-01*S53+2.868850e+00*S54+5.945388e-01*S55+4.132911e-01*S56+2.502378e+00*S57+3.271603e-01*S58+5.301808e-01*S59'
.param V75_part7='V75_part6+1.224026e-01*S60+1.926018e+00*S61+1.090780e+00*S62+3.808682e-02*S63+7.362424e-01*S64+8.721001e-01*S65+7.002778e-02*S66+1.713332e-02*S67+5.074159e-01*S68+8.247621e-02*S69'
.param V75_part8='V75_part7+4.344947e-02*S70+2.586347e-01*S71+8.394130e-02*S72+4.549989e-02*S73+1.802157e-01*S74+4.097771e-02*S75+3.372693e-02*S76+3.110546e-01*S77+4.444443e-02*S78+2.113294e-03*S79'
.param V75='V75_part8+2.866120e-01*S80+4.638730e-02*S81+3.042176e-02*S82+2.368168e-01*S83+4.501476e-02*S84+(-2.838450e-02)*S85+1.427071e-01*S86+3.624505e-02*S87+5.427324e-03*S88+6.830710e-02*S89'
.param V76_part1='4.479456e+01*S0+1.496221e+01*S1+6.551661e+01*S2+4.293047e+01*S3+3.975452e+01*S4+1.289866e+02*S5+3.952407e+01*S6+(-2.092524e+01)*S7+3.306447e+03*S8+1.521402e+02*S9'
.param V76_part2='V76_part1+5.998606e+03*S10+1.864807e+03*S11+(-1.296114e+00)*S12+1.009904e+01*S13+1.000000e+04*S14+1.801761e+01*S15+(-7.459620e+01)*S16+2.861402e+03*S17+1.389191e+02*S18+7.383419e+01*S19'
.param V76_part3='V76_part2+1.000000e+04*S20+1.276469e+00*S21+1.753833e-01*S22+(-1.080372e+02)*S23+(-6.835981e+00)*S24+(-9.556712e+01)*S25+(-2.960485e+01)*S26+(-4.638754e+00)*S27+(-3.665838e+01)*S28+(-1.766037e+00)*S29'
.param V76_part4='V76_part3+1.279957e+01*S30+(-1.342163e+02)*S31+(-2.466617e+00)*S32+(-1.972578e+00)*S33+9.933535e+00*S34+(-1.100701e+00)*S35+1.208683e-01*S36+(-1.024804e+00)*S37+(-7.776695e-01)*S38+7.969688e-02*S39'
.param V76_part5='V76_part4+(-2.518944e-01)*S40+(-4.704631e-01)*S41+(-1.316714e-02)*S42+(-3.237373e-01)*S43+(-3.843968e-01)*S44+(-8.093989e-01)*S45+1.201769e+00*S46+(-1.104730e+00)*S47+4.967137e-01*S48+(-4.003495e-01)*S49'
.param V76_part6='V76_part5+(-2.758246e-01)*S50+1.968960e-01*S51+1.529443e-01*S52+(-3.176303e-02)*S53+8.297116e-02*S54+(-6.640503e-02)*S55+(-1.004769e-02)*S56+1.658614e-01*S57+(-1.003620e-01)*S58+(-1.235579e-01)*S59'
.param V76_part7='V76_part6+(-2.233280e-01)*S60+3.821057e+00*S61+(-4.508011e-01)*S62+(-7.994874e-03)*S63+(-1.046779e-01)*S64+(-2.638910e-01)*S65+(-3.810953e-02)*S66+(-5.553080e-03)*S67+(-1.392647e-01)*S68+(-4.293381e-02)*S69'
.param V76_part8='V76_part7+(-3.376844e-02)*S70+(-9.318129e-04)*S71+(-3.324165e-02)*S72+(-1.935894e-02)*S73+(-6.573739e-02)*S74+(-9.455557e-02)*S75+(-1.127056e-01)*S76+(-1.353140e-01)*S77+(-6.470278e-02)*S78+(-2.111376e-02)*S79'
.param V76='V76_part8+(-9.178216e-02)*S80+1.583058e-02*S81+(-5.641140e-02)*S82+(-1.321769e-01)*S83+(-2.564342e-02)*S84+1.284497e-02*S85+(-5.734610e-02)*S86+(-1.706806e-02)*S87+(-3.678246e-03)*S88+8.768202e-03*S89'
.param V77_part1='(-1.376011e+01)*S0+1.181042e+01*S1+(-6.009264e-01)*S2+(-6.232739e+01)*S3+(-4.701368e+00)*S4+2.070704e+01*S5+(-1.304423e+02)*S6+1.948686e+01*S7+5.062123e+03*S8+(-7.229118e+02)*S9'
.param V77_part2='V77_part1+3.627061e+03*S10+1.127557e+03*S11+(-1.846081e+02)*S12+(-4.623899e+01)*S13+1.000000e+04*S14+7.412560e+01*S15+1.237180e+02*S16+7.211303e+00*S17+9.975771e+01*S18+(-3.705732e+01)*S19'
.param V77_part3='V77_part2+1.000000e+04*S20+(-2.904473e+01)*S21+(-6.411757e+01)*S22+(-6.226041e+01)*S23+(-6.805755e+01)*S24+(-1.874012e+01)*S25+(-1.891032e+01)*S26+(-9.434224e+00)*S27+(-4.527527e+01)*S28+(-5.947687e+00)*S29'
.param V77_part4='V77_part3+(-6.376215e+01)*S30+(-1.930953e+01)*S31+(-2.433217e+00)*S32+(-1.087107e+01)*S33+(-6.674611e+00)*S34+(-1.709514e+00)*S35+2.846250e-01*S36+(-5.826911e-02)*S37+(-9.731874e-01)*S38+5.202374e-01*S39'
.param V77_part5='V77_part4+2.942807e-01*S40+(-8.677130e-01)*S41+2.758037e-01*S42+2.605025e-01*S43+(-6.408871e-01)*S44+3.028708e-01*S45+(-5.356772e+00)*S46+(-1.149774e+00)*S47+1.726127e+00*S48+2.911848e-01*S49'
.param V77_part6='V77_part5+(-4.777821e-01)*S50+1.758393e+00*S51+1.399856e+00*S52+(-2.668238e-01)*S53+1.048960e+00*S54+2.631393e-01*S55+(-7.428162e-02)*S56+8.318908e-01*S57+7.825043e-02*S58+(-1.083454e-01)*S59'
.param V77_part7='V77_part6+4.545508e-01*S60+5.503200e+00*S61+(-5.922628e-01)*S62+2.874968e-01*S63+1.597433e-01*S64+(-4.350733e-01)*S65+2.150616e-01*S66+2.542033e-01*S67+(-1.767423e-01)*S68+1.826518e-01*S69'
.param V77_part8='V77_part7+2.153542e-01*S70+(-3.966309e-02)*S71+1.499857e-01*S72+1.629404e-01*S73+7.485032e-02*S74+3.545331e-01*S75+3.202691e-01*S76+(-3.435428e-02)*S77+2.863757e-01*S78+2.758607e-01*S79'
.param V77='V77_part8+(-4.655555e-02)*S80+2.417723e-01*S81+2.245027e-01*S82+1.725345e-02*S83+1.855458e-01*S84+2.275229e-01*S85+6.053199e-02*S86+1.843210e-01*S87+1.557877e-01*S88+8.113119e-02*S89'
.param V78_part1='1.604218e+01*S0+1.304827e+01*S1+3.682810e+01*S2+4.244549e+01*S3+3.062750e+01*S4+3.199062e+02*S5+1.709988e+02*S6+(-4.787649e+02)*S7+1.000000e+04*S8+5.350609e+03*S9'
.param V78_part2='V78_part1+(-1.000000e+04)*S10+(-1.000000e+04)*S11+(-1.663131e+03)*S12+(-1.000000e+04)*S13+(-1.000000e+04)*S14+(-2.155402e+01)*S15+4.225375e+00*S16+(-5.734627e+02)*S17+(-1.000000e+04)*S18+(-3.147318e+02)*S19'
.param V78_part3='V78_part2+(-1.000000e+04)*S20+(-2.508565e+03)*S21+(-3.446698e+02)*S22+(-1.041176e+01)*S23+(-6.562897e+01)*S24+(-1.655397e+01)*S25+(-2.462079e+00)*S26+(-5.612860e-01)*S27+(-2.736867e+00)*S28+(-5.792931e-01)*S29'
.param V78_part4='V78_part3+(-1.958541e-01)*S30+(-1.332554e+01)*S31+(-8.761373e-02)*S32+(-3.560562e-01)*S33+5.885812e-01*S34+(-3.313755e-02)*S35+1.396117e-02*S36+2.780295e-02*S37+2.991344e-02*S38+5.304401e-02*S39'
.param V78_part5='V78_part4+6.554339e-02*S40+2.964399e-02*S41+4.807193e-02*S42+4.985455e-02*S43+3.759580e-02*S44+1.619023e-02*S45+1.010958e-01*S46+3.634888e-02*S47+1.203946e-01*S48+6.495889e-02*S49'
.param V78_part6='V78_part5+2.972285e-02*S50+1.391306e-01*S51+1.849251e-01*S52+1.644559e-03*S53+9.648218e-02*S54+4.331317e-02*S55+2.082018e-03*S56+1.050577e-01*S57+4.652291e-03*S58+1.521256e-02*S59'
.param V78_part7='V78_part6+1.942652e-02*S60+2.148184e-01*S61+1.713094e-02*S62+1.670104e-02*S63+4.673993e-02*S64+2.461455e-02*S65+1.313104e-02*S66+1.370557e-02*S67+1.718641e-02*S68+1.115711e-02*S69'
.param V78_part8='V78_part7+1.023895e-02*S70+1.641897e-02*S71+1.041833e-02*S72+6.927427e-03*S73+1.925695e-02*S74+1.244200e-02*S75+1.870819e-02*S76+(-1.772023e-03)*S77+1.029904e-02*S78+1.007215e-02*S79'
.param V78='V78_part8+4.455672e-03*S80+1.007726e-02*S81+1.065116e-02*S82+(-1.776149e-03)*S83+4.776860e-03*S84+6.474524e-03*S85+1.292360e-02*S86+4.995853e-03*S87+6.499718e-03*S88+1.161925e-02*S89'
.param V79_part1='1.782716e-01*S0+3.230481e-01*S1+4.920927e-01*S2+(-8.516447e-01)*S3+(-1.166863e+00)*S4+(-4.157659e-01)*S5+(-2.152438e+00)*S6+1.160405e+01*S7+(-1.129309e+03)*S8+(-8.591256e+00)*S9'
.param V79_part2='V79_part1+1.000000e+04*S10+7.163917e+03*S11+1.375393e+00*S12+3.945160e+00*S13+6.622483e+03*S14+7.947616e+00*S15+(-6.582981e+00)*S16+8.489749e+02*S17+1.253997e+01*S18+(-6.132091e-01)*S19'
.param V79_part3='V79_part2+1.000000e+04*S20+2.908548e+00*S21+6.998125e+00*S22+1.935240e+03*S23+6.524470e+00*S24+2.020190e+03*S25+9.536171e+01*S26+4.348589e+00*S27+7.875945e+02*S28+3.458936e+00*S29'
.param V79_part4='V79_part3+2.017244e+01*S30+(-6.259418e+02)*S31+5.600908e-01*S32+1.884913e+00*S33+(-2.566252e+01)*S34+3.762025e-01*S35+6.360426e-02*S36+9.597483e-01*S37+4.135464e-01*S38+1.879150e+00*S39'
.param V79_part5='V79_part4+1.041128e+00*S40+3.270140e-01*S41+1.480033e+00*S42+8.479982e-01*S43+3.168062e-01*S44+1.224451e+00*S45+3.849448e+00*S46+2.838838e-01*S47+7.200703e+00*S48+9.645925e-01*S49'
.param V79_part6='V79_part5+5.810729e-01*S50+1.287204e+01*S51+4.388091e+00*S52+1.645528e-01*S53+5.665712e+00*S54+8.808197e-01*S55+1.224563e-01*S56+5.041553e+00*S57+1.325439e-01*S58+1.161932e-01*S59'
.param V79_part7='V79_part6+(-1.944199e-02)*S60+(-8.235095e+00)*S61+7.255749e-02*S62+5.335737e-02*S63+1.123336e+00*S64+1.098201e-01*S65+5.129058e-02*S66+5.831920e-02*S67+6.388359e-02*S68+5.050032e-02*S69'
.param V79_part8='V79_part7+5.518935e-02*S70+5.494356e-02*S71+4.869062e-02*S72+5.903592e-02*S73+4.758587e-02*S74+4.866120e-02*S75+5.257443e-02*S76+4.219659e-02*S77+5.213228e-02*S78+5.477768e-02*S79'
.param V79='V79_part8+4.043038e-02*S80+2.306968e-02*S81+5.235344e-02*S82+3.722288e-02*S83+4.369459e-02*S84+4.924424e-02*S85+1.931271e-02*S86+4.221084e-02*S87+4.291620e-02*S88+2.391811e-02*S89'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+6.914219e-03*S8+0.000000e+00*S9'
.param V80_part2='V80_part1+0.000000e+00*S10+0.000000e+00*S11+5.050694e-02*S12+(-1.070831e-01)*S13+1.758650e-01*S14+(-1.718882e-01)*S15+2.474105e-01*S16+(-4.010540e-01)*S17+(-1.811017e-01)*S18+(-1.334778e-01)*S19'
.param V80_part3='V80_part2+(-2.373293e-01)*S20+(-2.534015e-01)*S21+(-3.134281e-01)*S22+(-3.087572e-01)*S23+(-4.771000e-01)*S24+(-3.460012e-01)*S25+(-5.720701e-01)*S26+(-4.192709e-01)*S27+3.737631e-01*S28+(-4.714746e-01)*S29'
.param V80_part4='V80_part3+(-3.212919e-01)*S30+(-5.398448e-01)*S31+(-7.725284e-01)*S32+(-3.556410e-01)*S33+(-2.918332e-01)*S34+(-9.862766e-01)*S35+0.000000e+00*S36+8.072638e-01*S37+(-4.928259e-01)*S38+7.982526e-01*S39'
.param V80_part5='V80_part4+1.357479e+00*S40+(-1.750299e-01)*S41+1.656264e+00*S42+1.291860e+00*S43+4.060336e-02*S44+9.234954e-01*S45+1.180019e-01*S46+(-1.458296e+00)*S47+5.458676e-01*S48+1.656574e+00*S49'
.param V80_part6='V80_part5+1.342063e+00*S50+3.449965e-01*S51+3.764179e-01*S52+1.453717e+00*S53+1.869489e-01*S54+1.403579e+00*S55+4.266156e+00*S56+7.555139e-01*S57+1.190518e+00*S58+4.962992e+00*S59'
.param V80_part7='V80_part6+0.000000e+00*S60+1.412420e+00*S61+5.338440e-02*S62+0.000000e+00*S63+1.389992e+00*S64+6.317624e-02*S65+0.000000e+00*S66+0.000000e+00*S67+3.044720e+00*S68+0.000000e+00*S69'
.param V80_part8='V80_part7+0.000000e+00*S70+(-2.895929e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-2.157294e+00)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V80='V80_part8+2.641124e+00*S80+0.000000e+00*S81+0.000000e+00*S82+(-5.593272e+00)*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+5.127261e-02*S8+0.000000e+00*S9'
.param V81_part2='V81_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.120897e-03)*S12+1.550820e-01*S13+2.547452e-02*S14+8.396441e-01*S15+5.563511e-01*S16+8.761460e-01*S17+6.083751e-01*S18+5.761509e-01*S19'
.param V81_part3='V81_part2+7.191992e-01*S20+7.713497e-01*S21+7.450494e-01*S22+5.756655e-01*S23+1.032371e+00*S24+8.456139e-01*S25+6.791038e-01*S26+1.425164e+00*S27+1.355502e-01*S28+7.882021e-01*S29'
.param V81_part4='V81_part3+1.611441e+00*S30+1.561691e+00*S31+2.986042e+00*S32+2.043855e+00*S33+1.049160e+00*S34+2.948901e+00*S35+0.000000e+00*S36+2.465594e+00*S37+2.682285e+00*S38+2.174237e+00*S39'
.param V81_part5='V81_part4+1.882598e+00*S40+2.569890e+00*S41+1.659991e+00*S42+2.248358e+00*S43+2.949779e+00*S44+5.292202e+00*S45+1.718815e+00*S46+7.168393e+00*S47+1.412853e+00*S48+4.127815e+00*S49'
.param V81_part6='V81_part5+3.373079e+00*S50+1.335412e+00*S51+2.108497e+00*S52+6.964461e+00*S53+2.515317e+00*S54+5.347998e+00*S55+5.529857e+00*S56+2.175402e+00*S57+7.953479e+00*S58+5.118821e+00*S59'
.param V81_part7='V81_part6+0.000000e+00*S60+1.999779e-01*S61+1.170002e+01*S62+0.000000e+00*S63+7.777833e+00*S64+1.199704e+01*S65+0.000000e+00*S66+0.000000e+00*S67+1.352545e+01*S68+0.000000e+00*S69'
.param V81_part8='V81_part7+0.000000e+00*S70+2.510585e+01*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+3.005527e+01*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V81='V81_part8+3.138537e+01*S80+0.000000e+00*S81+0.000000e+00*S82+3.068945e+01*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+(-9.824706e-03)*S8+0.000000e+00*S9'
.param V82_part2='V82_part1+0.000000e+00*S10+0.000000e+00*S11+1.156887e-02*S12+6.763598e-02*S13+(-4.484003e-02)*S14+2.009184e-01*S15+(-4.343053e-01)*S16+3.855673e-01*S17+4.043615e-01*S18+3.424489e-01*S19'
.param V82_part3='V82_part2+2.732214e-01*S20+4.278063e-01*S21+4.921519e-01*S22+5.922355e-01*S23+7.471016e-01*S24+5.989370e-01*S25+1.021600e+00*S26+1.724629e-01*S27+6.763009e-01*S28+9.452568e-01*S29'
.param V82_part4='V82_part3+8.611005e-01*S30+1.059444e+00*S31+1.808035e+00*S32+2.002347e+00*S33+1.391481e+00*S34+2.342758e+00*S35+0.000000e+00*S36+7.097753e-01*S37+2.095880e+00*S38+(-9.203569e-01)*S39'
.param V82_part5='V82_part4+4.178957e-01*S40+1.869485e+00*S41+5.482115e-02*S42+1.228809e-01*S43+1.280237e+00*S44+1.291458e+00*S45+5.210536e-01*S46+3.535901e+00*S47+(-5.723605e-01)*S48+6.987598e-01*S49'
.param V82_part6='V82_part5+8.891512e-01*S50+(-4.220277e-01)*S51+(-3.533731e-01)*S52+1.723914e-02*S53+(-9.625792e-01)*S54+7.378215e-01*S55+(-2.693673e+00)*S56+(-1.181722e+00)*S57+(-3.784977e+00)*S58+(-2.785640e+00)*S59'
.param V82_part7='V82_part6+0.000000e+00*S60+(-1.125991e+00)*S61+3.636843e+00*S62+0.000000e+00*S63+3.126098e+00*S64+3.556901e+00*S65+0.000000e+00*S66+0.000000e+00*S67+(-1.846972e+00)*S68+0.000000e+00*S69'
.param V82_part8='V82_part7+0.000000e+00*S70+(-7.579035e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.386861e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V82='V82_part8+(-8.862238e+00)*S80+0.000000e+00*S81+0.000000e+00*S82+(-5.939760e+00)*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+3.252822e-02*S8+0.000000e+00*S9'
.param V83_part2='V83_part1+0.000000e+00*S10+0.000000e+00*S11+3.806822e-02*S12+4.743626e-02*S13+1.041251e-01*S14+6.238732e-02*S15+5.908216e-02*S16+1.947045e-04*S17+6.254540e-02*S18+3.601166e-02*S19'
.param V83_part3='V83_part2+(-1.070361e-03)*S20+3.162639e-02*S21+1.617213e-02*S22+1.193846e-01*S23+2.470018e-02*S24+4.179624e-02*S25+1.246537e-01*S26+(-1.377219e-01)*S27+1.073743e-01*S28+(-1.891648e-02)*S29'
.param V83_part4='V83_part3+6.425130e-02*S30+6.070351e-02*S31+(-9.885676e-02)*S32+6.760599e-02*S33+1.155258e-02*S34+(-1.561077e-01)*S35+0.000000e+00*S36+(-1.596359e-01)*S37+(-2.850204e-01)*S38+(-3.204617e-01)*S39'
.param V83_part5='V83_part4+(-2.310348e-01)*S40+(-3.520757e-01)*S41+(-2.729726e-01)*S42+(-4.240145e-01)*S43+(-4.220786e-01)*S44+(-1.136641e-01)*S45+(-2.634048e-01)*S46+(-3.565435e-01)*S47+(-2.326332e-01)*S48+(-2.970589e-01)*S49'
.param V83_part6='V83_part5+(-5.332479e-01)*S50+(-2.286417e-01)*S51+(-3.617183e-01)*S52+(-9.996016e-01)*S53+(-3.819549e-01)*S54+(-7.208712e-01)*S55+(-1.521021e+00)*S56+(-5.516383e-01)*S57+(-1.610697e+00)*S58+(-1.422991e+00)*S59'
.param V83_part7='V83_part6+0.000000e+00*S60+(-1.883279e-01)*S61+(-8.107834e-01)*S62+0.000000e+00*S63+(-3.347301e-01)*S64+(-1.074138e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-1.697317e+00)*S68+0.000000e+00*S69'
.param V83_part8='V83_part7+0.000000e+00*S70+(-2.258898e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-2.907529e+00)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V83='V83_part8+(-2.545895e+00)*S80+0.000000e+00*S81+0.000000e+00*S82+(-7.900349e+00)*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+5.959286e-03*S8+0.000000e+00*S9'
.param V84_part2='V84_part1+0.000000e+00*S10+0.000000e+00*S11+1.841837e-03*S12+2.702049e-03*S13+(-1.291047e-03)*S14+5.650809e-03*S15+2.516140e-02*S16+3.107282e-02*S17+9.593730e-03*S18+(-5.161192e-02)*S19'
.param V84_part3='V84_part2+(-5.319356e-02)*S20+(-1.281030e-02)*S21+(-1.867707e-02)*S22+(-2.353965e-01)*S23+(-1.170897e-01)*S24+(-2.071993e-01)*S25+(-3.260184e-01)*S26+(-4.292433e-01)*S27+(-3.363186e-01)*S28+(-2.875997e-01)*S29'
.param V84_part4='V84_part3+(-1.176346e-01)*S30+(-1.428026e-01)*S31+(-4.478880e-01)*S32+(-5.715453e-01)*S33+(-1.918755e-01)*S34+(-7.605122e-01)*S35+0.000000e+00*S36+(-1.438312e+00)*S37+(-1.174663e+00)*S38+(-1.785184e+00)*S39'
.param V84_part5='V84_part4+(-1.643549e+00)*S40+(-1.432736e+00)*S41+(-2.015058e+00)*S42+(-1.890623e+00)*S43+(-1.836796e+00)*S44+(-1.891020e+00)*S45+(-5.621996e-01)*S46+(-1.190392e+00)*S47+(-7.227243e-01)*S48+(-2.083532e+00)*S49'
.param V84_part6='V84_part5+(-2.586036e+00)*S50+(-5.948323e-01)*S51+(-9.652745e-01)*S52+(-2.804851e+00)*S53+(-1.520718e+00)*S54+(-3.359182e+00)*S55+(-3.191552e+00)*S56+(-1.947588e+00)*S57+(-5.684700e+00)*S58+(-4.811285e+00)*S59'
.param V84_part7='V84_part6+0.000000e+00*S60+6.709001e-01*S61+(-2.185725e+00)*S62+0.000000e+00*S63+(-3.229844e+00)*S64+(-3.970250e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-6.170915e+00)*S68+0.000000e+00*S69'
.param V84_part8='V84_part7+0.000000e+00*S70+(-9.571086e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-4.144465e+00)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V84='V84_part8+(-9.874561e+00)*S80+0.000000e+00*S81+0.000000e+00*S82+(-9.312489e+00)*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-09*_P2'
.param _P4='1e-09*_P2'
.param _P5='V5+V6*rad_+V7/w_'
.param _P6='_P5+V8*gdis_+V9*spacing_'
.param _P7='0.5*(_P6+sqrt(_P6*_P6+0.001))'
.param _P8='V10+V11*rad_+V12*w_'
.param _P9='_P8+V13*gdis_+V14*spacing_'
.param _P10='0.5*(_P9+sqrt(_P9*_P9+0.001))'
.param _P11='1e-09*_P10'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='1e-09*_P14'
.param _P16='V20+V21*rad_+V22*w_'
.param _P17='_P16+V23*gdis_+V24*spacing_'
.param _P18='0.5*(_P17+sqrt(_P17*_P17+0.001))'
.param _P19='1e-09*_P18'
.param _P20='1e-09*_P18'
.param _P21='V25+V26*rad_+V27/w_'
.param _P22='_P21+V28*gdis_+V29*spacing_'
.param _P23='0.5*(_P22+sqrt(_P22*_P22+0.001))'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='1e-09*_P26'
.param _P28='V35+V36*rad_+V37/w_'
.param _P29='_P28+V38*gdis_+V39*spacing_'
.param _P30='0.5*(_P29+sqrt(_P29*_P29+0.001))'
.param _P31='1e-09*_P30'
.param _P32='V40+V41*rad_+V42*w_'
.param _P33='_P32+V43*gdis_+V44*spacing_'
.param _P34='atan(_P33-0.5)/1.5708'
.param _P35='V45+V46*rad_+V47*w_'
.param _P36='_P35+V48*gdis_+V49*spacing_'
.param _P37='atan(_P36-0.5)/1.5708'
.param _P38='0.5*_P34+0.5*_P37'
.param _P39='0.5*_P34-0.5*_P37'
.param _P40='V50+V51*rad_+V52*w_'
.param _P41='_P40+V53*gdis_+V54*spacing_'
.param _P42='0.5*(_P41+sqrt(_P41*_P41+0.001))'
.param _P43='1e-09*_P42'
.param _P44='1e-09*_P42'
.param _P45='1e-06'
.param _P46='V55+V56*rad_+V57*w_'
.param _P47='_P46+V58*gdis_+V59*spacing_'
.param _P48='0.5*(_P47+sqrt(_P47*_P47+0.001))'
.param _P49='1e-15*_P48'
.param _P50='V60+V61*rad_+V62*w_'
.param _P51='_P50+V63*gdis_+V64*spacing_'
.param _P52='0.5*(_P51+sqrt(_P51*_P51+0.001))'
.param _P53='V65+V66*rad_+V67*w_'
.param _P54='_P53+V68*gdis_+V69*spacing_'
.param _P55='0.5*(_P54+sqrt(_P54*_P54+0.001))'
.param _P56='V70+V71*rad_+V72*w_'
.param _P57='_P56+V73*gdis_+V74*spacing_'
.param _P58='0.5*(_P57+sqrt(_P57*_P57+0.001))'
.param _P59='1e-14*_P52'
.param _P60='100*_P55'
.param _P61='1e-15*_P58'
.param _P62='1e-14*_P52'
.param _P63='100*_P55'
.param _P64='1e-15*_P58'
.param _P65='V75+V76*rad_+V77*w_'
.param _P66='_P65+V78*gdis_+V79*spacing_'
.param _P67='0.5*(_P66+sqrt(_P66*_P66+0.001))'
.param _P68='V80+V81*rad_+V82*w_'
.param _P69='_P68+V83*gdis_+V84*spacing_'
.param _P70='0.5*(_P69+sqrt(_P69*_P69+0.001))'
.param _P71='100*_P67'
.param _P72='1e-13*_P70'
l1_sect1 top _n1i_sect1 '_P3* l_indfac'
l2_sect1 _n2i_sect1 bottom '_P4* l_indfac'
r1_sect1 _n1i_sect1 _n_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect1 _n_sect1 _n2i_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect1 _nc_sect1 tap '_P11* l_indfac'
rc_sect1 _n_sect1 _nc_sect1 '(_P15+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
l1_sect2 top _n1i_sect2 '_P19* l_indfac'
l2_sect2 _n2i_sect2 bottom '_P20* l_indfac'
r1_sect2 _n1i_sect2 _n_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect2 _n_sect2 _n2i_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect2 _nc_sect2 tap '_P27* l_indfac'
rc_sect2 _n_sect2 _nc_sect2 '(_P31+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
ks1s1 l1_sect1 l2_sect1 K=_P38
ks2s2 l1_sect2 l2_sect2 K=_P38
ks1s2_1 l1_sect1 l1_sect2 K=_P39
ks1s2_2 l2_sect1 l2_sect2 K=_P39
lx1 _n1i_sect1 _nx1 '_P43* l_indfac'
lx2 _n2i_sect1 _nx2 '_P44* l_indfac'
rx1 _nx1 _n1i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
rx2 _nx2 _n2i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
c12 top bottom '_P49*c12_indfac'
c_1_sub top _n1_1_sub '_P59*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4*3)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P60*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P61* csub_indfac'
c_2_sub bottom _n1_2_sub '_P62*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4*3)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P63*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P64* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P71*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P72* csub_indfac'
kzero1 l1_sect1 l2_sect2 K=1e-6
kzero2 l1_sect2 l2_sect1 K=1e-6
.ends spiral_sym_ct_mu_a

.subckt spiral_std_mu_z top bottom gnode rad=6e-05 w=9e-06 nr=0.5 gdis=5e-05 spacing=3e-06 lay=9 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T177='(1-abs(sgn(nr-(0.5))))'
.param T178='(min(sgn(rad_-(0.3335))+1,1))'
.param T179='(min(sgn(w_-(0.4002))+1,1))'
.param T180='(min(sgn(w_-(0.3998))+1,1))'
.param T181='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T182='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T183='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T184='(min(sgn(rad_-(0.377933))+1,1))'
.param T185='(min(sgn(rad_-(0.333167))+1,1))'
.param T186='(min(sgn(rad_-(0.500167))+1,1))'
.param T187='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T188='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T189='(min(sgn(rad_-(0.377622))+1,1))'
.param T190='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T191='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T192='(min(sgn(rad_-(0.533489))+1,1))'
.param T193='(min(sgn(rad_-(0.499833))+1,1))'
.param T194='(min(sgn(rad_-(0.666833))+1,1))'
.param T195='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T196='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T197='(min(sgn(rad_-(0.533178))+1,1))'
.param T198='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T199='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T200='(min(sgn(rad_-(0.689044))+1,1))'
.param T201='(min(sgn(rad_-(0.6665))+1,1))'
.param T202='(min(sgn(rad_-(0.8335))+1,1))'
.param T203='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T204='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T205='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T206='(min(sgn(rad_-(0.8446))+1,1))'
.param T207='(min(sgn(rad_-(0.688733))+1,1))'
.param T208='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T209='(min(sgn(rad_-(0.833167))+1,1))'
.param T210='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T211='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T212='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T213='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T214='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T215='(min(sgn(rad_-(0.844289))+1,1))'
.param T216='(1-abs(sgn(nr-(0.75))))'
.param T217='(1-abs(sgn(nr-(1.25))))'
.param T218='(1-abs(sgn(nr-(1.5))))'
.param T219='(1-abs(sgn(nr-(1.75))))'
.param T220='(1-abs(sgn(nr-(1))))'
.param T221='(1-abs(sgn(nr-(2.25))))'
.param T222='(1-abs(sgn(nr-(2.5))))'
.param T223='(1-abs(sgn(nr-(2.75))))'
.param T224='(1-abs(sgn(nr-(2))))'
.param T225='(1-abs(sgn(nr-(3.25))))'
.param T226='(1-abs(sgn(nr-(3.5))))'
.param T227='(1-abs(sgn(nr-(3.75))))'
.param T228='(1-abs(sgn(nr-(3))))'
.param T229='(1-abs(sgn(nr-(4.25))))'
.param T230='(1-abs(sgn(nr-(4.5))))'
.param T231='(1-abs(sgn(nr-(4.75))))'
.param T232='(1-abs(sgn(nr-(4))))'
.param T233='(1-abs(sgn(nr-(5.25))))'
.param T234='(1-abs(sgn(nr-(5.5))))'
.param T235='(1-abs(sgn(nr-(5))))'
.param S0='T177*(1-T178)*(1-T179)'
.param noS0='(1-S0)'
.param S1='T177*T180*(1-T178)*(1-T181)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T177*T182*T183*(1-T184)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T177*(1-T179)*T185*(1-T186)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T177*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T177*T189*T190*T191*(1-T192)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T177*(1-T179)*T193*(1-T194)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T177*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T177*T197*T198*T199*(1-T200)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T177*(1-T179)*T201*(1-T202)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T177*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T177*T205*(1-T206)*T207*T208*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T177*(1-T179)*T209*(1-T210)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T177*T209*T180*(1-T211)*(1-T212)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T177*T213*T214*T215*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T216*(1-T178)*(1-T179)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T216*T180*(1-T178)*(1-T181)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T216*T182*T183*(1-T184)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T216*(1-T179)*T185*(1-T186)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T216*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T216*T189*T190*T191*(1-T192)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T216*(1-T179)*T193*(1-T194)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T216*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T216*T197*T198*T199*(1-T200)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T216*(1-T179)*T201*(1-T202)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T216*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T216*T205*(1-T206)*T207*T208*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T216*(1-T179)*T209*(1-T210)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T216*T209*T180*(1-T211)*(1-T212)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T216*T213*T214*T215*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T217*(1-T178)*(1-T179)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T217*T180*(1-T178)*(1-T181)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T217*T182*T183*(1-T184)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T217*(1-T179)*T185*(1-T186)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T217*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T217*T189*T190*T191*(1-T192)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T217*(1-T179)*T193*(1-T194)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T217*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T217*T197*T198*T199*(1-T200)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T217*(1-T179)*T201*(1-T202)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T217*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T217*T205*(1-T206)*T207*T208*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T217*(1-T179)*T209*(1-T210)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T217*T209*T180*(1-T211)*(1-T212)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T217*T213*T214*T215*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T218*(1-T178)*(1-T179)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T218*T180*(1-T178)*(1-T181)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T218*T182*T183*(1-T184)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T218*(1-T179)*T185*(1-T186)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T218*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T218*T189*T190*T191*(1-T192)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T218*(1-T179)*T193*(1-T194)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T218*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T218*T197*T198*T199*(1-T200)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T218*(1-T179)*T201*(1-T202)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T218*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T218*T205*(1-T206)*T207*T208*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T218*(1-T179)*T209*(1-T210)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T218*T209*T180*(1-T211)*(1-T212)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T218*T213*T214*T215*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T219*(1-T178)*(1-T179)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T219*T180*(1-T178)*(1-T181)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T219*T182*T183*(1-T184)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T219*(1-T179)*T185*(1-T186)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T219*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T219*T189*T190*T191*(1-T192)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T219*(1-T179)*T193*(1-T194)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T219*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T219*T197*T198*T199*(1-T200)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T219*(1-T179)*T201*(1-T202)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T219*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T219*T205*(1-T206)*T207*T208*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T219*(1-T179)*T209*(1-T210)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T219*T209*T180*(1-T211)*(1-T212)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T219*T213*T214*T215*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T220*(1-T178)*(1-T179)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T220*T180*(1-T178)*(1-T181)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T220*T182*T183*(1-T184)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T220*(1-T179)*T185*(1-T186)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T220*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T220*T189*T190*T191*(1-T192)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T220*(1-T179)*T193*(1-T194)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T220*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T220*T197*T198*T199*(1-T200)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T220*(1-T179)*T201*(1-T202)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T220*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T220*T205*(1-T206)*T207*T208*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T220*(1-T179)*T209*(1-T210)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T220*T209*T180*(1-T211)*(1-T212)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T220*T213*T214*T215*noS88'
.param noS89='(1-S89)*noS88'
.param S90='T221*(1-T178)*(1-T179)*noS89'
.param noS90='(1-S90)*noS89'
.param S91='T221*T180*(1-T178)*(1-T181)*noS90'
.param noS91='(1-S91)*noS90'
.param S92='T221*T182*T183*(1-T184)*noS91'
.param noS92='(1-S92)*noS91'
.param S93='T221*(1-T179)*T185*(1-T186)*noS92'
.param noS93='(1-S93)*noS92'
.param S94='T221*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS93'
.param noS94='(1-S94)*noS93'
.param S95='T221*T189*T190*T191*(1-T192)*noS94'
.param noS95='(1-S95)*noS94'
.param S96='T221*(1-T179)*T193*(1-T194)*noS95'
.param noS96='(1-S96)*noS95'
.param S97='T221*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS96'
.param noS97='(1-S97)*noS96'
.param S98='T221*T197*T198*T199*(1-T200)*noS97'
.param noS98='(1-S98)*noS97'
.param S99='T221*(1-T179)*T201*(1-T202)*noS98'
.param noS99='(1-S99)*noS98'
.param S100='T221*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS99'
.param noS100='(1-S100)*noS99'
.param S101='T221*T205*(1-T206)*T207*T208*noS100'
.param noS101='(1-S101)*noS100'
.param S102='T221*(1-T179)*T209*(1-T210)*noS101'
.param noS102='(1-S102)*noS101'
.param S103='T221*T209*T180*(1-T211)*(1-T212)*noS102'
.param noS103='(1-S103)*noS102'
.param S104='T221*T213*T214*T215*noS103'
.param noS104='(1-S104)*noS103'
.param S105='T222*(1-T178)*(1-T179)*noS104'
.param noS105='(1-S105)*noS104'
.param S106='T222*T180*(1-T178)*(1-T181)*noS105'
.param noS106='(1-S106)*noS105'
.param S107='T222*T182*T183*(1-T184)*noS106'
.param noS107='(1-S107)*noS106'
.param S108='T222*(1-T179)*T185*(1-T186)*noS107'
.param noS108='(1-S108)*noS107'
.param S109='T222*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS108'
.param noS109='(1-S109)*noS108'
.param S110='T222*T189*T190*T191*(1-T192)*noS109'
.param noS110='(1-S110)*noS109'
.param S111='T222*(1-T179)*T193*(1-T194)*noS110'
.param noS111='(1-S111)*noS110'
.param S112='T222*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS111'
.param noS112='(1-S112)*noS111'
.param S113='T222*T197*T198*T199*(1-T200)*noS112'
.param noS113='(1-S113)*noS112'
.param S114='T222*(1-T179)*T201*(1-T202)*noS113'
.param noS114='(1-S114)*noS113'
.param S115='T222*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS114'
.param noS115='(1-S115)*noS114'
.param S116='T222*T205*(1-T206)*T207*T208*noS115'
.param noS116='(1-S116)*noS115'
.param S117='T222*(1-T179)*T209*(1-T210)*noS116'
.param noS117='(1-S117)*noS116'
.param S118='T222*T209*T180*(1-T211)*(1-T212)*noS117'
.param noS118='(1-S118)*noS117'
.param S119='T222*T213*T214*T215*noS118'
.param noS119='(1-S119)*noS118'
.param S120='T223*(1-T178)*(1-T179)*noS119'
.param noS120='(1-S120)*noS119'
.param S121='T223*T180*(1-T178)*(1-T181)*noS120'
.param noS121='(1-S121)*noS120'
.param S122='T223*T182*T183*(1-T184)*noS121'
.param noS122='(1-S122)*noS121'
.param S123='T223*(1-T179)*T185*(1-T186)*noS122'
.param noS123='(1-S123)*noS122'
.param S124='T223*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS123'
.param noS124='(1-S124)*noS123'
.param S125='T223*T189*T190*T191*(1-T192)*noS124'
.param noS125='(1-S125)*noS124'
.param S126='T223*(1-T179)*T193*(1-T194)*noS125'
.param noS126='(1-S126)*noS125'
.param S127='T223*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS126'
.param noS127='(1-S127)*noS126'
.param S128='T223*T197*T198*T199*(1-T200)*noS127'
.param noS128='(1-S128)*noS127'
.param S129='T223*(1-T179)*T201*(1-T202)*noS128'
.param noS129='(1-S129)*noS128'
.param S130='T223*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS129'
.param noS130='(1-S130)*noS129'
.param S131='T223*T205*(1-T206)*T207*T208*noS130'
.param noS131='(1-S131)*noS130'
.param S132='T223*(1-T179)*T209*(1-T210)*noS131'
.param noS132='(1-S132)*noS131'
.param S133='T223*T209*T180*(1-T211)*(1-T212)*noS132'
.param noS133='(1-S133)*noS132'
.param S134='T223*T213*T214*T215*noS133'
.param noS134='(1-S134)*noS133'
.param S135='T224*(1-T178)*(1-T179)*noS134'
.param noS135='(1-S135)*noS134'
.param S136='T224*T180*(1-T178)*(1-T181)*noS135'
.param noS136='(1-S136)*noS135'
.param S137='T224*T182*T183*(1-T184)*noS136'
.param noS137='(1-S137)*noS136'
.param S138='T224*(1-T179)*T185*(1-T186)*noS137'
.param noS138='(1-S138)*noS137'
.param S139='T224*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS138'
.param noS139='(1-S139)*noS138'
.param S140='T224*T189*T190*T191*(1-T192)*noS139'
.param noS140='(1-S140)*noS139'
.param S141='T224*(1-T179)*T193*(1-T194)*noS140'
.param noS141='(1-S141)*noS140'
.param S142='T224*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS141'
.param noS142='(1-S142)*noS141'
.param S143='T224*T197*T198*T199*(1-T200)*noS142'
.param noS143='(1-S143)*noS142'
.param S144='T224*(1-T179)*T201*(1-T202)*noS143'
.param noS144='(1-S144)*noS143'
.param S145='T224*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS144'
.param noS145='(1-S145)*noS144'
.param S146='T224*T205*(1-T206)*T207*T208*noS145'
.param noS146='(1-S146)*noS145'
.param S147='T224*(1-T179)*T209*(1-T210)*noS146'
.param noS147='(1-S147)*noS146'
.param S148='T224*T209*T180*(1-T211)*(1-T212)*noS147'
.param noS148='(1-S148)*noS147'
.param S149='T224*T213*T214*T215*noS148'
.param noS149='(1-S149)*noS148'
.param S150='T225*(1-T178)*(1-T179)*noS149'
.param noS150='(1-S150)*noS149'
.param S151='T225*T180*(1-T178)*(1-T181)*noS150'
.param noS151='(1-S151)*noS150'
.param S152='T225*T182*T183*(1-T184)*noS151'
.param noS152='(1-S152)*noS151'
.param S153='T225*(1-T179)*T185*(1-T186)*noS152'
.param noS153='(1-S153)*noS152'
.param S154='T225*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS153'
.param noS154='(1-S154)*noS153'
.param S155='T225*T189*T190*T191*(1-T192)*noS154'
.param noS155='(1-S155)*noS154'
.param S156='T225*(1-T179)*T193*(1-T194)*noS155'
.param noS156='(1-S156)*noS155'
.param S157='T225*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS156'
.param noS157='(1-S157)*noS156'
.param S158='T225*T197*T198*T199*(1-T200)*noS157'
.param noS158='(1-S158)*noS157'
.param S159='T225*(1-T179)*T201*(1-T202)*noS158'
.param noS159='(1-S159)*noS158'
.param S160='T225*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS159'
.param noS160='(1-S160)*noS159'
.param S161='T225*T205*(1-T206)*T207*T208*noS160'
.param noS161='(1-S161)*noS160'
.param S162='T225*(1-T179)*T209*(1-T210)*noS161'
.param noS162='(1-S162)*noS161'
.param S163='T225*T209*T180*(1-T211)*(1-T212)*noS162'
.param noS163='(1-S163)*noS162'
.param S164='T225*T213*T214*T215*noS163'
.param noS164='(1-S164)*noS163'
.param S165='T226*(1-T178)*(1-T179)*noS164'
.param noS165='(1-S165)*noS164'
.param S166='T226*T180*(1-T178)*(1-T181)*noS165'
.param noS166='(1-S166)*noS165'
.param S167='T226*T182*T183*(1-T184)*noS166'
.param noS167='(1-S167)*noS166'
.param S168='T226*(1-T179)*T185*(1-T186)*noS167'
.param noS168='(1-S168)*noS167'
.param S169='T226*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS168'
.param noS169='(1-S169)*noS168'
.param S170='T226*T189*T190*T191*(1-T192)*noS169'
.param noS170='(1-S170)*noS169'
.param S171='T226*(1-T179)*T193*(1-T194)*noS170'
.param noS171='(1-S171)*noS170'
.param S172='T226*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS171'
.param noS172='(1-S172)*noS171'
.param S173='T226*T197*T198*T199*(1-T200)*noS172'
.param noS173='(1-S173)*noS172'
.param S174='T226*(1-T179)*T201*(1-T202)*noS173'
.param noS174='(1-S174)*noS173'
.param S175='T226*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS174'
.param noS175='(1-S175)*noS174'
.param S176='T226*T205*(1-T206)*T207*T208*noS175'
.param noS176='(1-S176)*noS175'
.param S177='T226*(1-T179)*T209*(1-T210)*noS176'
.param noS177='(1-S177)*noS176'
.param S178='T226*T209*T180*(1-T211)*(1-T212)*noS177'
.param noS178='(1-S178)*noS177'
.param S179='T226*T213*T214*T215*noS178'
.param noS179='(1-S179)*noS178'
.param S180='T227*(1-T178)*(1-T179)*noS179'
.param noS180='(1-S180)*noS179'
.param S181='T227*T180*(1-T178)*(1-T181)*noS180'
.param noS181='(1-S181)*noS180'
.param S182='T227*T182*T183*(1-T184)*noS181'
.param noS182='(1-S182)*noS181'
.param S183='T227*(1-T179)*T185*(1-T186)*noS182'
.param noS183='(1-S183)*noS182'
.param S184='T227*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS183'
.param noS184='(1-S184)*noS183'
.param S185='T227*T189*T190*T191*(1-T192)*noS184'
.param noS185='(1-S185)*noS184'
.param S186='T227*(1-T179)*T193*(1-T194)*noS185'
.param noS186='(1-S186)*noS185'
.param S187='T227*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS186'
.param noS187='(1-S187)*noS186'
.param S188='T227*T197*T198*T199*(1-T200)*noS187'
.param noS188='(1-S188)*noS187'
.param S189='T227*(1-T179)*T201*(1-T202)*noS188'
.param noS189='(1-S189)*noS188'
.param S190='T227*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS189'
.param noS190='(1-S190)*noS189'
.param S191='T227*T205*(1-T206)*T207*T208*noS190'
.param noS191='(1-S191)*noS190'
.param S192='T227*(1-T179)*T209*(1-T210)*noS191'
.param noS192='(1-S192)*noS191'
.param S193='T227*T209*T180*(1-T211)*(1-T212)*noS192'
.param noS193='(1-S193)*noS192'
.param S194='T227*T213*T214*T215*noS193'
.param noS194='(1-S194)*noS193'
.param S195='T228*(1-T178)*(1-T179)*noS194'
.param noS195='(1-S195)*noS194'
.param S196='T228*T180*(1-T178)*(1-T181)*noS195'
.param noS196='(1-S196)*noS195'
.param S197='T228*T182*T183*(1-T184)*noS196'
.param noS197='(1-S197)*noS196'
.param S198='T228*(1-T179)*T185*(1-T186)*noS197'
.param noS198='(1-S198)*noS197'
.param S199='T228*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS198'
.param noS199='(1-S199)*noS198'
.param S200='T228*T189*T190*T191*(1-T192)*noS199'
.param noS200='(1-S200)*noS199'
.param S201='T228*(1-T179)*T193*(1-T194)*noS200'
.param noS201='(1-S201)*noS200'
.param S202='T228*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS201'
.param noS202='(1-S202)*noS201'
.param S203='T228*T197*T198*T199*(1-T200)*noS202'
.param noS203='(1-S203)*noS202'
.param S204='T228*(1-T179)*T201*(1-T202)*noS203'
.param noS204='(1-S204)*noS203'
.param S205='T228*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS204'
.param noS205='(1-S205)*noS204'
.param S206='T228*T205*(1-T206)*T207*T208*noS205'
.param noS206='(1-S206)*noS205'
.param S207='T228*(1-T179)*T209*(1-T210)*noS206'
.param noS207='(1-S207)*noS206'
.param S208='T228*T209*T180*(1-T211)*(1-T212)*noS207'
.param noS208='(1-S208)*noS207'
.param S209='T228*T213*T214*T215*noS208'
.param noS209='(1-S209)*noS208'
.param S210='T229*(1-T178)*(1-T179)*noS209'
.param noS210='(1-S210)*noS209'
.param S211='T229*T180*(1-T178)*(1-T181)*noS210'
.param noS211='(1-S211)*noS210'
.param S212='T229*T182*T183*(1-T184)*noS211'
.param noS212='(1-S212)*noS211'
.param S213='T229*(1-T179)*T185*(1-T186)*noS212'
.param noS213='(1-S213)*noS212'
.param S214='T229*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS213'
.param noS214='(1-S214)*noS213'
.param S215='T229*T189*T190*T191*(1-T192)*noS214'
.param noS215='(1-S215)*noS214'
.param S216='T229*(1-T179)*T193*(1-T194)*noS215'
.param noS216='(1-S216)*noS215'
.param S217='T229*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS216'
.param noS217='(1-S217)*noS216'
.param S218='T229*T197*T198*T199*(1-T200)*noS217'
.param noS218='(1-S218)*noS217'
.param S219='T229*(1-T179)*T201*(1-T202)*noS218'
.param noS219='(1-S219)*noS218'
.param S220='T229*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS219'
.param noS220='(1-S220)*noS219'
.param S221='T229*T205*(1-T206)*T207*T208*noS220'
.param noS221='(1-S221)*noS220'
.param S222='T229*(1-T179)*T209*(1-T210)*noS221'
.param noS222='(1-S222)*noS221'
.param S223='T229*T209*T180*(1-T211)*(1-T212)*noS222'
.param noS223='(1-S223)*noS222'
.param S224='T229*T213*T214*T215*noS223'
.param noS224='(1-S224)*noS223'
.param S225='T230*(1-T178)*(1-T179)*noS224'
.param noS225='(1-S225)*noS224'
.param S226='T230*T180*(1-T178)*(1-T181)*noS225'
.param noS226='(1-S226)*noS225'
.param S227='T230*T182*T183*(1-T184)*noS226'
.param noS227='(1-S227)*noS226'
.param S228='T230*(1-T179)*T185*(1-T186)*noS227'
.param noS228='(1-S228)*noS227'
.param S229='T230*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS228'
.param noS229='(1-S229)*noS228'
.param S230='T230*T189*T190*T191*(1-T192)*noS229'
.param noS230='(1-S230)*noS229'
.param S231='T230*(1-T179)*T193*(1-T194)*noS230'
.param noS231='(1-S231)*noS230'
.param S232='T230*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS231'
.param noS232='(1-S232)*noS231'
.param S233='T230*T197*T198*T199*(1-T200)*noS232'
.param noS233='(1-S233)*noS232'
.param S234='T230*(1-T179)*T201*(1-T202)*noS233'
.param noS234='(1-S234)*noS233'
.param S235='T230*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS234'
.param noS235='(1-S235)*noS234'
.param S236='T230*T205*(1-T206)*T207*T208*noS235'
.param noS236='(1-S236)*noS235'
.param S237='T230*(1-T179)*T209*(1-T210)*noS236'
.param noS237='(1-S237)*noS236'
.param S238='T230*T209*T180*(1-T211)*(1-T212)*noS237'
.param noS238='(1-S238)*noS237'
.param S239='T230*T213*T214*T215*noS238'
.param noS239='(1-S239)*noS238'
.param S240='T231*(1-T178)*(1-T179)*noS239'
.param noS240='(1-S240)*noS239'
.param S241='T231*T180*(1-T178)*(1-T181)*noS240'
.param noS241='(1-S241)*noS240'
.param S242='T231*T182*T183*(1-T184)*noS241'
.param noS242='(1-S242)*noS241'
.param S243='T231*(1-T179)*T185*(1-T186)*noS242'
.param noS243='(1-S243)*noS242'
.param S244='T231*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS243'
.param noS244='(1-S244)*noS243'
.param S245='T231*T189*T190*T191*(1-T192)*noS244'
.param noS245='(1-S245)*noS244'
.param S246='T231*(1-T179)*T193*(1-T194)*noS245'
.param noS246='(1-S246)*noS245'
.param S247='T231*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS246'
.param noS247='(1-S247)*noS246'
.param S248='T231*T197*T198*T199*(1-T200)*noS247'
.param noS248='(1-S248)*noS247'
.param S249='T231*(1-T179)*T201*(1-T202)*noS248'
.param noS249='(1-S249)*noS248'
.param S250='T231*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS249'
.param noS250='(1-S250)*noS249'
.param S251='T231*T205*(1-T206)*T207*T208*noS250'
.param noS251='(1-S251)*noS250'
.param S252='T231*(1-T179)*T209*(1-T210)*noS251'
.param noS252='(1-S252)*noS251'
.param S253='T231*T209*T180*(1-T211)*(1-T212)*noS252'
.param noS253='(1-S253)*noS252'
.param S254='T231*T213*T214*T215*noS253'
.param noS254='(1-S254)*noS253'
.param S255='T232*(1-T178)*(1-T179)*noS254'
.param noS255='(1-S255)*noS254'
.param S256='T232*T180*(1-T178)*(1-T181)*noS255'
.param noS256='(1-S256)*noS255'
.param S257='T232*T182*T183*(1-T184)*noS256'
.param noS257='(1-S257)*noS256'
.param S258='T232*(1-T179)*T185*(1-T186)*noS257'
.param noS258='(1-S258)*noS257'
.param S259='T232*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS258'
.param noS259='(1-S259)*noS258'
.param S260='T232*T189*T190*T191*(1-T192)*noS259'
.param noS260='(1-S260)*noS259'
.param S261='T232*(1-T179)*T193*(1-T194)*noS260'
.param noS261='(1-S261)*noS260'
.param S262='T232*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS261'
.param noS262='(1-S262)*noS261'
.param S263='T232*T197*T198*T199*(1-T200)*noS262'
.param noS263='(1-S263)*noS262'
.param S264='T232*(1-T179)*T201*(1-T202)*noS263'
.param noS264='(1-S264)*noS263'
.param S265='T232*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS264'
.param noS265='(1-S265)*noS264'
.param S266='T232*T205*(1-T206)*T207*T208*noS265'
.param noS266='(1-S266)*noS265'
.param S267='T232*(1-T179)*T209*(1-T210)*noS266'
.param noS267='(1-S267)*noS266'
.param S268='T232*T209*T180*(1-T211)*(1-T212)*noS267'
.param noS268='(1-S268)*noS267'
.param S269='T232*T213*T214*T215*noS268'
.param noS269='(1-S269)*noS268'
.param S270='T233*(1-T178)*(1-T179)*noS269'
.param noS270='(1-S270)*noS269'
.param S271='T233*T180*(1-T178)*(1-T181)*noS270'
.param noS271='(1-S271)*noS270'
.param S272='T233*T182*T183*(1-T184)*noS271'
.param noS272='(1-S272)*noS271'
.param S273='T233*(1-T179)*T185*(1-T186)*noS272'
.param noS273='(1-S273)*noS272'
.param S274='T233*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS273'
.param noS274='(1-S274)*noS273'
.param S275='T233*T189*T190*T191*(1-T192)*noS274'
.param noS275='(1-S275)*noS274'
.param S276='T233*(1-T179)*T193*(1-T194)*noS275'
.param noS276='(1-S276)*noS275'
.param S277='T233*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS276'
.param noS277='(1-S277)*noS276'
.param S278='T233*T197*T198*T199*(1-T200)*noS277'
.param noS278='(1-S278)*noS277'
.param S279='T233*(1-T179)*T201*(1-T202)*noS278'
.param noS279='(1-S279)*noS278'
.param S280='T233*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS279'
.param noS280='(1-S280)*noS279'
.param S281='T233*T205*(1-T206)*T207*T208*noS280'
.param noS281='(1-S281)*noS280'
.param S282='T233*(1-T179)*T209*(1-T210)*noS281'
.param noS282='(1-S282)*noS281'
.param S283='T233*T209*T180*(1-T211)*(1-T212)*noS282'
.param noS283='(1-S283)*noS282'
.param S284='T233*T213*T214*T215*noS283'
.param noS284='(1-S284)*noS283'
.param S285='T234*(1-T178)*(1-T179)*noS284'
.param noS285='(1-S285)*noS284'
.param S286='T234*T180*(1-T178)*(1-T181)*noS285'
.param noS286='(1-S286)*noS285'
.param S287='T234*T182*T183*(1-T184)*noS286'
.param noS287='(1-S287)*noS286'
.param S288='T234*(1-T179)*T185*(1-T186)*noS287'
.param noS288='(1-S288)*noS287'
.param S289='T234*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS288'
.param noS289='(1-S289)*noS288'
.param S290='T234*T189*T190*T191*(1-T192)*noS289'
.param noS290='(1-S290)*noS289'
.param S291='T234*(1-T179)*T193*(1-T194)*noS290'
.param noS291='(1-S291)*noS290'
.param S292='T234*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS291'
.param noS292='(1-S292)*noS291'
.param S293='T234*T197*T198*T199*(1-T200)*noS292'
.param noS293='(1-S293)*noS292'
.param S294='T234*(1-T179)*T201*(1-T202)*noS293'
.param noS294='(1-S294)*noS293'
.param S295='T234*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS294'
.param noS295='(1-S295)*noS294'
.param S296='T234*T205*(1-T206)*T207*T208*noS295'
.param noS296='(1-S296)*noS295'
.param S297='T234*(1-T179)*T209*(1-T210)*noS296'
.param noS297='(1-S297)*noS296'
.param S298='T234*T209*T180*(1-T211)*(1-T212)*noS297'
.param noS298='(1-S298)*noS297'
.param S299='T234*T213*T214*T215*noS298'
.param noS299='(1-S299)*noS298'
.param S300='T235*(1-T178)*(1-T179)*noS299'
.param noS300='(1-S300)*noS299'
.param S301='T235*T180*(1-T178)*(1-T181)*noS300'
.param noS301='(1-S301)*noS300'
.param S302='T235*T182*T183*(1-T184)*noS301'
.param noS302='(1-S302)*noS301'
.param S303='T235*(1-T179)*T185*(1-T186)*noS302'
.param noS303='(1-S303)*noS302'
.param S304='T235*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS303'
.param noS304='(1-S304)*noS303'
.param S305='T235*T189*T190*T191*(1-T192)*noS304'
.param noS305='(1-S305)*noS304'
.param S306='T235*(1-T179)*T193*(1-T194)*noS305'
.param noS306='(1-S306)*noS305'
.param S307='T235*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS306'
.param noS307='(1-S307)*noS306'
.param S308='T235*T197*T198*T199*(1-T200)*noS307'
.param noS308='(1-S308)*noS307'
.param S309='T235*(1-T179)*T201*(1-T202)*noS308'
.param noS309='(1-S309)*noS308'
.param S310='T235*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS309'
.param noS310='(1-S310)*noS309'
.param S311='T235*T205*(1-T206)*T207*T208*noS310'
.param noS311='(1-S311)*noS310'
.param S312='T235*(1-T179)*T209*(1-T210)*noS311'
.param noS312='(1-S312)*noS311'
.param S313='T235*T209*T180*(1-T211)*(1-T212)*noS312'
.param noS313='(1-S313)*noS312'
.param S314='T235*T213*T214*T215*noS313'
.param noS314='(1-S314)*noS313'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V0_part3='V0_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.789090e+01)*S32+0.000000e+00*S33+0.000000e+00*S34+(-2.306099e+01)*S35+0.000000e+00*S36+(-1.245239e+00)*S37+(-8.508245e+00)*S38+0.000000e+00*S39'
.param V0_part5='V0_part4+(-7.629711e-02)*S40+(-9.973027e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-1.695449e+01)*S44+0.000000e+00*S45+0.000000e+00*S46+(-2.161864e+01)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V0_part6='V0_part5+(-3.005167e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+(-5.148753e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+(-5.593202e+00)*S56+0.000000e+00*S57+(-1.292763e+00)*S58+(-5.396103e+00)*S59'
.param V0_part7='V0_part6+0.000000e+00*S60+(-5.180233e+00)*S61+(-6.814411e+00)*S62+0.000000e+00*S63+0.000000e+00*S64+(-7.689805e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+3.122446e+00*S68+0.000000e+00*S69'
.param V0_part8='V0_part7+6.483526e+00*S70+7.124470e+00*S71+0.000000e+00*S72+3.960421e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V0_part9='V0_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V0_part10='V0_part9+0.000000e+00*S90+(-7.487130e+00)*S91+(-1.934261e+01)*S92+3.733513e+00*S93+(-6.245200e+00)*S94+(-1.060832e+01)*S95+3.752927e+00*S96+(-9.410312e-01)*S97+(-8.994463e+00)*S98+3.766827e+00*S99'
.param V0_part11='V0_part10+(-5.649522e+00)*S100+9.941646e+00*S101+0.000000e+00*S102+1.395527e+00*S103+(-1.228240e+01)*S104+0.000000e+00*S105+0.000000e+00*S106+(-1.972195e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V0_part12='V0_part11+(-2.973732e+00)*S110+0.000000e+00*S111+1.581000e+00*S112+4.175875e+00*S113+0.000000e+00*S114+(-7.625929e+00)*S115+(-2.041609e+01)*S116+1.839445e+00*S117+(-2.478203e+00)*S118+0.000000e+00*S119'
.param V0_part13='V0_part12+0.000000e+00*S120+0.000000e+00*S121+(-4.761474e+00)*S122+0.000000e+00*S123+3.758726e-01*S124+(-7.732254e+00)*S125+2.349285e+00*S126+(-3.113586e+00)*S127+(-1.749040e+01)*S128+(-7.227274e-01)*S129'
.param V0_part14='V0_part13+1.719704e+00*S130+2.576682e+01*S131+0.000000e+00*S132+(-1.889887e+00)*S133+3.302990e+01*S134+0.000000e+00*S135+4.520805e+00*S136+5.950533e+00*S137+4.082938e+00*S138+4.390839e+00*S139'
.param V0_part15='V0_part14+3.347191e+00*S140+6.207973e+00*S141+1.302269e+01*S142+9.870802e-01*S143+1.108940e+01*S144+1.185490e+01*S145+4.060298e-01*S146+1.740210e+01*S147+1.279852e+01*S148+1.908502e+01*S149'
.param V0_part16='V0_part15+0.000000e+00*S150+(-4.812338e+00)*S151+(-1.672307e+01)*S152+2.256012e+00*S153+(-5.481516e+00)*S154+(-1.129080e+01)*S155+0.000000e+00*S156+6.714347e+00*S157+1.948482e+01*S158+0.000000e+00*S159'
.param V0_part17='V0_part16+1.287312e+00*S160+0.000000e+00*S161+(-1.122848e-01)*S162+0.000000e+00*S163+0.000000e+00*S164+(-3.319491e+00)*S165+(-6.332911e+00)*S166+(-3.683768e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V0_part18='V0_part17+2.087860e+01*S170+0.000000e+00*S171+(-1.108480e+01)*S172+(-2.451683e+01)*S173+0.000000e+00*S174+(-1.115940e+01)*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V0_part19='V0_part18+(-1.507433e+00)*S180+(-7.217520e-01)*S181+3.375618e+00*S182+0.000000e+00*S183+(-9.675992e+00)*S184+0.000000e+00*S185+0.000000e+00*S186+(-4.179562e+00)*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V0_part20='V0_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+6.524753e+00*S195+0.000000e+00*S196+6.354226e+00*S197+2.024673e+00*S198+2.494617e+00*S199'
.param V0_part21='V0_part20+1.034307e+01*S200+6.122145e+00*S201+5.007541e+00*S202+3.008359e+00*S203+2.141375e+00*S204+1.059049e+01*S205+4.636814e+00*S206+0.000000e+00*S207+1.778614e+01*S208+1.370208e+01*S209'
.param V0_part22='V0_part21+4.717255e-03*S210+(-2.852680e+00)*S211+(-2.606392e+00)*S212+(-1.777360e+00)*S213+(-1.812255e+01)*S214+9.945346e-01*S215+0.000000e+00*S216+0.000000e+00*S217+(-1.360118e+01)*S218+0.000000e+00*S219'
.param V0_part23='V0_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+1.471999e+01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V0_part24='V0_part23+0.000000e+00*S230+(-1.174154e+00)*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V0_part25='V0_part24+(-1.700108e+00)*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+(-5.756730e-02)*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V0_part26='V0_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.292830e+00*S255+1.804323e+00*S256+2.114108e+01*S257+0.000000e+00*S258+1.294000e+01*S259'
.param V0_part27='V0_part26+2.993671e+01*S260+0.000000e+00*S261+0.000000e+00*S262+(-5.195496e+00)*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V0_part28='V0_part27+0.000000e+00*S270+(-6.333326e+00)*S271+2.607673e+01*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V0_part29='V0_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-2.588134e+01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V0_part30='V0_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V0_part31='V0_part30+0.000000e+00*S300+3.794729e+00*S301+(-1.738238e+01)*S302+0.000000e+00*S303+0.000000e+00*S304+(-1.764322e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V0='V0_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V1_part3='V1_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+0.000000e+00*S30+0.000000e+00*S31+3.529918e+01*S32+0.000000e+00*S33+0.000000e+00*S34+3.081090e+01*S35+0.000000e+00*S36+3.616539e+00*S37+2.095464e+00*S38+0.000000e+00*S39'
.param V1_part5='V1_part4+5.072221e+00*S40+7.244568e-01*S41+0.000000e+00*S42+0.000000e+00*S43+1.039416e+01*S44+0.000000e+00*S45+0.000000e+00*S46+4.437111e+01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V1_part6='V1_part5+4.533794e+01*S50+0.000000e+00*S51+0.000000e+00*S52+1.212363e+01*S53+0.000000e+00*S54+0.000000e+00*S55+1.246570e+01*S56+0.000000e+00*S57+9.582076e+00*S58+1.101505e+01*S59'
.param V1_part7='V1_part6+0.000000e+00*S60+3.289299e+01*S61+1.978531e+01*S62+0.000000e+00*S63+0.000000e+00*S64+2.649716e+01*S65+0.000000e+00*S66+0.000000e+00*S67+5.971900e+00*S68+0.000000e+00*S69'
.param V1_part8='V1_part7+1.116923e+01*S70+7.874802e+00*S71+0.000000e+00*S72+1.263364e+01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V1_part9='V1_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V1_part10='V1_part9+0.000000e+00*S90+1.581204e+01*S91+2.782679e+01*S92+5.719960e+00*S93+1.191937e+01*S94+1.605215e+01*S95+7.880870e+00*S96+7.660431e+00*S97+9.515055e-01*S98+9.334835e+00*S99'
.param V1_part11='V1_part10+1.771842e+01*S100+(-1.699670e+01)*S101+0.000000e+00*S102+7.215197e+00*S103+1.260017e+01*S104+0.000000e+00*S105+0.000000e+00*S106+1.103322e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V1_part12='V1_part11+(-3.592646e-01)*S110+0.000000e+00*S111+3.889402e+00*S112+(-1.372561e+01)*S113+0.000000e+00*S114+1.220930e+01*S115+2.048602e+01*S116+8.429937e+00*S117+1.085400e+01*S118+0.000000e+00*S119'
.param V1_part13='V1_part12+0.000000e+00*S120+0.000000e+00*S121+1.463535e+01*S122+0.000000e+00*S123+7.398245e+00*S124+1.243865e+01*S125+1.899332e+01*S126+2.044194e+01*S127+2.836986e+01*S128+2.482896e+01*S129'
.param V1_part14='V1_part13+1.794035e+01*S130+(-1.471483e+01)*S131+0.000000e+00*S132+1.656322e+01*S133+(-1.334462e+01)*S134+0.000000e+00*S135+1.900469e+01*S136+8.365393e+00*S137+2.517393e+01*S138+1.208262e+01*S139'
.param V1_part15='V1_part14+1.742184e+01*S140+1.491551e+01*S141+3.794409e+00*S142+7.605362e+00*S143+9.776253e+00*S144+6.988945e+00*S145+1.140937e+01*S146+4.802545e+00*S147+9.544728e+00*S148+8.487093e+00*S149'
.param V1_part16='V1_part15+0.000000e+00*S150+1.584079e+00*S151+8.610638e+00*S152+9.618325e+00*S153+1.446157e+01*S154+(-9.494756e+00)*S155+0.000000e+00*S156+(-1.109478e+01)*S157+(-3.296233e+01)*S158+0.000000e+00*S159'
.param V1_part17='V1_part16+(-2.834084e+00)*S160+0.000000e+00*S161+4.832327e+00*S162+0.000000e+00*S163+0.000000e+00*S164+2.588273e+01*S165+2.585285e+01*S166+(-1.113497e+01)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V1_part18='V1_part17+(-4.111654e+01)*S170+0.000000e+00*S171+2.096882e+01*S172+2.281329e+01*S173+0.000000e+00*S174+1.343884e+01*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V1_part19='V1_part18+2.130771e+01*S180+1.990665e+01*S181+(-2.850091e+00)*S182+0.000000e+00*S183+2.359155e+01*S184+0.000000e+00*S185+0.000000e+00*S186+2.198421e+01*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V1_part20='V1_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+1.716445e+01*S195+0.000000e+00*S196+(-1.085528e+01)*S197+2.214206e+01*S198+1.605824e+01*S199'
.param V1_part21='V1_part20+(-8.317775e+00)*S200+2.136006e+01*S201+1.727073e+01*S202+1.749641e+01*S203+1.634360e+01*S204+8.151601e+00*S205+1.537161e+01*S206+0.000000e+00*S207+(-1.737444e+00)*S208+1.036597e+01*S209'
.param V1_part22='V1_part21+1.943726e+01*S210+(-4.066868e+00)*S211+(-1.889057e+01)*S212+2.651354e+01*S213+2.414992e+01*S214+(-1.935196e+01)*S215+0.000000e+00*S216+0.000000e+00*S217+(-1.464565e+01)*S218+0.000000e+00*S219'
.param V1_part23='V1_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+(-4.106559e+01)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V1_part24='V1_part23+0.000000e+00*S230+1.150375e+01*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V1_part25='V1_part24+1.531186e+01*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+1.071305e+01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V1_part26='V1_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.786564e+01*S255+6.222575e+00*S256+(-2.324944e+01)*S257+0.000000e+00*S258+(-2.100562e+00)*S259'
.param V1_part27='V1_part26+(-1.587048e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+1.688275e+01*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V1_part28='V1_part27+0.000000e+00*S270+2.365088e+01*S271+(-5.680267e+01)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V1_part29='V1_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+2.435424e+01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V1_part30='V1_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V1_part31='V1_part30+0.000000e+00*S300+1.780273e+01*S301+2.438077e+01*S302+0.000000e+00*S303+0.000000e+00*S304+2.641887e+01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V1='V1_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V2_part3='V2_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+0.000000e+00*S30+0.000000e+00*S31+3.070371e+01*S32+0.000000e+00*S33+0.000000e+00*S34+3.386619e+01*S35+0.000000e+00*S36+1.766750e+01*S37+3.354270e+01*S38+0.000000e+00*S39'
.param V2_part5='V2_part4+2.144800e+01*S40+3.858226e+01*S41+0.000000e+00*S42+0.000000e+00*S43+3.505336e+01*S44+0.000000e+00*S45+0.000000e+00*S46+2.829350e+01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V2_part6='V2_part5+3.461032e+01*S50+0.000000e+00*S51+0.000000e+00*S52+1.414066e+01*S53+0.000000e+00*S54+0.000000e+00*S55+1.385794e+01*S56+0.000000e+00*S57+1.137252e+01*S58+1.326804e+01*S59'
.param V2_part7='V2_part6+0.000000e+00*S60+1.290085e+01*S61+1.434149e+01*S62+0.000000e+00*S63+0.000000e+00*S64+1.507127e+01*S65+0.000000e+00*S66+0.000000e+00*S67+1.087092e+01*S68+0.000000e+00*S69'
.param V2_part8='V2_part7+5.326184e+00*S70+5.472118e+00*S71+0.000000e+00*S72+9.025710e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V2_part9='V2_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V2_part10='V2_part9+0.000000e+00*S90+3.615145e+01*S91+5.647429e+01*S92+1.762173e+01*S93+4.196348e+01*S94+5.102635e+01*S95+1.697373e+01*S96+3.450301e+01*S97+5.526343e+01*S98+1.548537e+01*S99'
.param V2_part11='V2_part10+3.975423e+01*S100+4.686363e+01*S101+0.000000e+00*S102+3.095152e+01*S103+6.404326e+01*S104+0.000000e+00*S105+0.000000e+00*S106+2.218377e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V2_part12='V2_part11+2.947905e+01*S110+0.000000e+00*S111+1.737333e+01*S112+3.069733e+01*S113+0.000000e+00*S114+3.520946e+01*S115+4.827178e+01*S116+1.196504e+00*S117+3.091963e+01*S118+0.000000e+00*S119'
.param V2_part13='V2_part12+0.000000e+00*S120+0.000000e+00*S121+2.918600e+01*S122+0.000000e+00*S123+1.496472e+01*S124+3.352803e+01*S125+(-5.075597e+00)*S126+1.956956e+01*S127+3.509845e+01*S128+(-1.549463e+01)*S129'
.param V2_part14='V2_part13+1.100338e+01*S130+7.699803e+00*S131+0.000000e+00*S132+1.516954e+01*S133+(-3.010916e+00)*S134+0.000000e+00*S135+1.297479e+01*S136+1.516407e+01*S137+8.796336e+00*S138+1.739748e+01*S139'
.param V2_part15='V2_part14+2.137470e+01*S140+1.440505e+01*S141+8.592173e+00*S142+2.734608e+01*S143+(-2.610424e+00)*S144+8.668317e+00*S145+2.913149e+01*S146+(-6.920271e+00)*S147+4.501613e+00*S148+7.877937e+00*S149'
.param V2_part16='V2_part15+0.000000e+00*S150+4.598100e+01*S151+7.246749e+01*S152+1.184390e+01*S153+4.406574e+01*S154+7.387607e+01*S155+0.000000e+00*S156+3.038934e+01*S157+4.482189e+01*S158+0.000000e+00*S159'
.param V2_part17='V2_part16+4.907748e+01*S160+0.000000e+00*S161+3.457607e+01*S162+0.000000e+00*S163+0.000000e+00*S164+2.788278e+01*S165+3.201805e+01*S166+4.154192e+01*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V2_part18='V2_part17+2.716848e+01*S170+0.000000e+00*S171+3.844055e+01*S172+5.605066e+01*S173+0.000000e+00*S174+4.953564e+01*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V2_part19='V2_part18+1.158729e+01*S180+1.505431e+01*S181+2.613513e+01*S182+0.000000e+00*S183+2.946229e+01*S184+0.000000e+00*S185+0.000000e+00*S186+2.465273e+01*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V2_part20='V2_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+9.508734e+00*S195+0.000000e+00*S196+2.446463e+01*S197+1.078971e+01*S198+2.435354e+01*S199'
.param V2_part21='V2_part20+3.173577e+01*S200+2.346316e+00*S201+1.939885e+01*S202+3.153886e+01*S203+2.980565e+01*S204+1.586796e+01*S205+1.948804e+01*S206+0.000000e+00*S207+1.043548e+01*S208+8.138654e+00*S209'
.param V2_part22='V2_part21+1.275513e+01*S210+4.750324e+01*S211+7.039341e+01*S212+3.165631e+01*S213+6.344678e+01*S214+6.599698e+01*S215+0.000000e+00*S216+0.000000e+00*S217+7.529648e+01*S218+0.000000e+00*S219'
.param V2_part23='V2_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+2.866249e+01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V2_part24='V2_part23+0.000000e+00*S230+3.701769e+01*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V2_part25='V2_part24+1.283001e+01*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+2.090408e+01*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V2_part26='V2_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.982327e+01*S255+3.340418e+01*S256+2.042979e+01*S257+0.000000e+00*S258+7.315925e+00*S259'
.param V2_part27='V2_part26+3.957987e+00*S260+0.000000e+00*S261+0.000000e+00*S262+3.526336e+01*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V2_part28='V2_part27+0.000000e+00*S270+4.889207e+01*S271+3.582085e+01*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V2_part29='V2_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+7.487126e+01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V2_part30='V2_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V2_part31='V2_part30+0.000000e+00*S300+2.559304e+01*S301+5.725773e+01*S302+0.000000e+00*S303+0.000000e+00*S304+5.159971e+01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V2='V2_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V3_part3='V3_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+0.000000e+00*S30+0.000000e+00*S31+(-6.611932e+00)*S32+0.000000e+00*S33+0.000000e+00*S34+(-7.029420e+00)*S35+0.000000e+00*S36+(-9.712697e-01)*S37+(-9.366302e+00)*S38+0.000000e+00*S39'
.param V3_part5='V3_part4+(-7.012024e+00)*S40+(-8.729211e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-7.335660e+00)*S44+0.000000e+00*S45+0.000000e+00*S46+(-2.262864e+00)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V3_part6='V3_part5+(-1.579454e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+(-5.961206e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+7.579934e-01*S56+0.000000e+00*S57+1.545267e+00*S58+1.668186e+00*S59'
.param V3_part7='V3_part6+0.000000e+00*S60+(-4.952537e-01)*S61+(-2.838588e+00)*S62+0.000000e+00*S63+0.000000e+00*S64+(-2.757385e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-1.339097e+00)*S68+0.000000e+00*S69'
.param V3_part8='V3_part7+(-1.073368e+00)*S70+(-3.824413e+00)*S71+0.000000e+00*S72+(-4.293094e+00)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V3_part9='V3_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V3_part10='V3_part9+0.000000e+00*S90+(-2.099930e+00)*S91+(-6.621092e+00)*S92+(-2.517112e+00)*S93+(-2.682696e+00)*S94+(-7.127566e+00)*S95+(-2.794011e+00)*S96+(-3.970839e+00)*S97+(-5.167352e+00)*S98+(-3.128074e+00)*S99'
.param V3_part11='V3_part10+(-4.125581e+00)*S100+(-4.707426e+00)*S101+0.000000e+00*S102+(-2.625588e+00)*S103+(-2.644156e+00)*S104+0.000000e+00*S105+0.000000e+00*S106+(-3.141727e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V3_part12='V3_part11+(-1.937765e+00)*S110+0.000000e+00*S111+(-1.769806e-01)*S112+(-1.410071e+00)*S113+0.000000e+00*S114+(-3.191971e-01)*S115+(-1.514864e+00)*S116+(-7.493791e-01)*S117+(-7.645529e-01)*S118+0.000000e+00*S119'
.param V3_part13='V3_part12+0.000000e+00*S120+0.000000e+00*S121+(-2.490018e+00)*S122+0.000000e+00*S123+(-7.479957e-01)*S124+(-2.124014e+00)*S125+(-7.074657e-01)*S126+(-1.353567e+00)*S127+(-2.379532e+00)*S128+1.807683e-01*S129'
.param V3_part14='V3_part13+(-1.928641e+00)*S130+7.902448e-01*S131+0.000000e+00*S132+(-2.854372e-01)*S133+1.407973e+00*S134+0.000000e+00*S135+4.714066e+00*S136+4.308886e+00*S137+5.664320e+00*S138+4.843385e+00*S139'
.param V3_part15='V3_part14+3.431894e+00*S140+4.831673e+00*S141+3.352386e+00*S142+4.418511e+00*S143+1.157215e+00*S144+2.234433e+00*S145+3.456801e+00*S146+3.152724e+00*S147+3.449965e+00*S148+4.411253e+00*S149'
.param V3_part16='V3_part15+0.000000e+00*S150+(-1.731933e+00)*S151+(-2.349730e+00)*S152+(-5.863679e-01)*S153+(-8.164462e-01)*S154+(-2.261414e+00)*S155+0.000000e+00*S156+(-2.235297e+00)*S157+(-2.454054e+00)*S158+0.000000e+00*S159'
.param V3_part17='V3_part16+1.551657e+00*S160+0.000000e+00*S161+1.493429e-01*S162+0.000000e+00*S163+0.000000e+00*S164+2.478900e-01*S165+(-1.125503e+00)*S166+4.105267e-01*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V3_part18='V3_part17+(-7.079525e-02)*S170+0.000000e+00*S171+1.345925e+00*S172+1.667131e+00*S173+0.000000e+00*S174+2.059616e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V3_part19='V3_part18+7.493201e-01*S180+(-1.858713e+00)*S181+1.202159e+00*S182+0.000000e+00*S183+(-6.525173e-01)*S184+0.000000e+00*S185+0.000000e+00*S186+7.575930e-01*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V3_part20='V3_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+5.590327e+00*S195+0.000000e+00*S196+8.370863e+00*S197+3.383031e+00*S198+9.569476e-01*S199'
.param V3_part21='V3_part20+2.327653e+00*S200+3.433303e+00*S201+1.477631e+00*S202+2.450777e+00*S203+5.719324e+00*S204+4.888596e+00*S205+3.830084e+00*S206+0.000000e+00*S207+5.721264e+00*S208+3.756691e+00*S209'
.param V3_part22='V3_part21+(-3.872269e-02)*S210+(-3.197224e-01)*S211+(-3.577611e+00)*S212+(-3.255297e-02)*S213+4.223603e+00*S214+(-5.145979e+00)*S215+0.000000e+00*S216+0.000000e+00*S217+(-5.209461e+00)*S218+0.000000e+00*S219'
.param V3_part23='V3_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+2.233317e-01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V3_part24='V3_part23+0.000000e+00*S230+2.017422e+00*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V3_part25='V3_part24+3.619857e-01*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+2.205624e+00*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V3_part26='V3_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+4.463684e+00*S255+4.142232e+00*S256+2.975621e+00*S257+0.000000e+00*S258+3.232810e+00*S259'
.param V3_part27='V3_part26+1.156261e+00*S260+0.000000e+00*S261+0.000000e+00*S262+5.725827e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V3_part28='V3_part27+0.000000e+00*S270+1.153315e-01*S271+(-1.149116e+00)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V3_part29='V3_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+2.542758e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V3_part30='V3_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V3_part31='V3_part30+0.000000e+00*S300+3.224953e+00*S301+9.211011e-01*S302+0.000000e+00*S303+0.000000e+00*S304+7.072107e-01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V3='V3_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V4_part3='V4_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+0.000000e+00*S30+0.000000e+00*S31+(-2.056340e+00)*S32+0.000000e+00*S33+0.000000e+00*S34+(-3.101924e+00)*S35+0.000000e+00*S36+(-2.650523e+00)*S37+(-4.423811e+00)*S38+0.000000e+00*S39'
.param V4_part5='V4_part4+(-3.953480e+00)*S40+(-4.893334e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+(-4.376607e+00)*S44+0.000000e+00*S45+0.000000e+00*S46+(-2.158158e+00)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V4_part6='V4_part5+(-3.294680e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+(-5.656363e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+(-6.722747e+00)*S56+0.000000e+00*S57+(-5.993637e+00)*S58+(-7.729065e+00)*S59'
.param V4_part7='V4_part6+0.000000e+00*S60+(-2.175324e+00)*S61+(-3.014625e+00)*S62+0.000000e+00*S63+0.000000e+00*S64+(-5.178395e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-5.644811e+00)*S68+0.000000e+00*S69'
.param V4_part8='V4_part7+(-5.677606e+00)*S70+(-7.356218e+00)*S71+0.000000e+00*S72+(-6.877296e+00)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V4_part9='V4_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V4_part10='V4_part9+0.000000e+00*S90+(-3.760258e+00)*S91+(-5.149151e+00)*S92+(-4.702059e+00)*S93+(-4.954882e+00)*S94+(-6.710714e+00)*S95+(-5.845966e+00)*S96+(-6.071495e+00)*S97+(-8.203475e+00)*S98+(-7.216338e+00)*S99'
.param V4_part11='V4_part10+(-7.354479e+00)*S100+(-1.016892e+01)*S101+0.000000e+00*S102+(-8.642041e+00)*S103+(-1.000375e+01)*S104+0.000000e+00*S105+0.000000e+00*S106+(-6.127075e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V4_part12='V4_part11+(-7.311620e+00)*S110+0.000000e+00*S111+(-6.457157e+00)*S112+(-8.918909e+00)*S113+0.000000e+00*S114+(-6.412675e+00)*S115+(-1.019427e+01)*S116+(-3.502417e+00)*S117+(-9.663040e+00)*S118+0.000000e+00*S119'
.param V4_part13='V4_part12+0.000000e+00*S120+0.000000e+00*S121+(-6.186721e+00)*S122+0.000000e+00*S123+(-5.199463e+00)*S124+(-7.254822e+00)*S125+(-4.590193e+00)*S126+(-5.515930e+00)*S127+(-6.938557e+00)*S128+(-5.745654e+00)*S129'
.param V4_part14='V4_part13+(-6.825912e+00)*S130+(-1.037581e+01)*S131+0.000000e+00*S132+(-8.400760e+00)*S133+(-1.138868e+01)*S134+0.000000e+00*S135+(-6.858128e+00)*S136+(-8.917772e+00)*S137+(-6.972176e+00)*S138+(-7.321047e+00)*S139'
.param V4_part15='V4_part14+(-8.976242e+00)*S140+(-7.457206e+00)*S141+(-8.645574e+00)*S142+(-8.756490e+00)*S143+(-8.708339e+00)*S144+(-9.804346e+00)*S145+(-1.119024e+01)*S146+(-1.022369e+01)*S147+(-1.088455e+01)*S148+(-1.265154e+01)*S149'
.param V4_part16='V4_part15+0.000000e+00*S150+(-3.987332e+00)*S151+(-7.163483e+00)*S152+(-5.005242e+00)*S153+(-6.202891e+00)*S154+(-9.116313e+00)*S155+0.000000e+00*S156+(-6.362138e+00)*S157+(-1.195857e+01)*S158+0.000000e+00*S159'
.param V4_part17='V4_part16+(-7.692206e+00)*S160+0.000000e+00*S161+(-6.327407e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+(-2.918356e+00)*S165+(-4.470608e+00)*S166+(-8.697273e+00)*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V4_part18='V4_part17+(-1.139733e+01)*S170+0.000000e+00*S171+(-6.471166e+00)*S172+(-8.913999e+00)*S173+0.000000e+00*S174+(-7.341031e+00)*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V4_part19='V4_part18+(-2.840879e+00)*S180+(-4.182558e+00)*S181+(-1.058214e+01)*S182+0.000000e+00*S183+(-4.649047e+00)*S184+0.000000e+00*S185+0.000000e+00*S186+(-5.578482e+00)*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V4_part20='V4_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+(-5.412690e+00)*S195+0.000000e+00*S196+(-9.983370e+00)*S197+(-7.700873e+00)*S198+(-7.265475e+00)*S199'
.param V4_part21='V4_part20+(-1.102778e+01)*S200+(-6.083078e+00)*S201+(-8.531918e+00)*S202+(-1.041470e+01)*S203+(-8.032880e+00)*S204+(-1.049408e+01)*S205+(-1.177171e+01)*S206+0.000000e+00*S207+(-1.219023e+01)*S208+(-1.361574e+01)*S209'
.param V4_part22='V4_part21+(-3.465919e+00)*S210+(-5.657212e+00)*S211+(-1.193607e+01)*S212+(-2.919258e+00)*S213+(-6.451941e+00)*S214+(-1.403199e+01)*S215+0.000000e+00*S216+0.000000e+00*S217+(-1.468411e+01)*S218+0.000000e+00*S219'
.param V4_part23='V4_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+(-1.195233e+01)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V4_part24='V4_part23+0.000000e+00*S230+(-4.531285e+00)*S231+0.000000e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V4_part25='V4_part24+(-2.584417e+00)*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+(-5.057124e+00)*S246+0.000000e+00*S247+0.000000e+00*S248+0.000000e+00*S249'
.param V4_part26='V4_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+(-4.734133e+00)*S255+(-7.633808e+00)*S256+(-1.217714e+01)*S257+0.000000e+00*S258+(-8.962693e+00)*S259'
.param V4_part27='V4_part26+(-1.443229e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-1.250341e+01)*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V4_part28='V4_part27+0.000000e+00*S270+(-4.074691e+00)*S271+(-1.699144e+01)*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V4_part29='V4_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-6.590168e+00)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V4_part30='V4_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V4_part31='V4_part30+0.000000e+00*S300+(-7.207720e+00)*S301+(-1.551805e+01)*S302+0.000000e+00*S303+0.000000e+00*S304+(-1.555946e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V4='V4_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V5_part1='(-2.609234e-02)*S0+1.006908e+00*S1+3.868893e+00*S2+8.720563e+00*S3+4.339773e-01*S4+1.276637e+00*S5+2.768495e-02*S6+1.035894e+00*S7+1.149770e+00*S8+1.029657e+00*S9'
.param V5_part2='V5_part1+1.955614e+00*S10+5.587162e+00*S11+5.720970e-01*S12+4.855850e-01*S13+6.071607e-03*S14+8.032251e+00*S15+9.454513e-01*S16+9.440238e+00*S17+3.531317e-01*S18+9.081013e-01*S19'
.param V5_part3='V5_part2+2.590895e+00*S20+(-2.220457e-01)*S21+(-3.648803e-01)*S22+2.581827e+00*S23+(-9.718794e-02)*S24+1.928873e+00*S25+2.485021e-01*S26+(-1.735862e-01)*S27+(-1.037607e-01)*S28+3.652187e+00*S29'
.param V5_part4='V5_part3+2.585784e-01*S30+4.687833e+01*S31+1.947613e-01*S32+4.224644e-01*S33+(-8.794777e-02)*S34+7.342947e+00*S35+2.153079e+01*S36+4.467772e+00*S37+4.287886e+01*S38+8.805833e+01*S39'
.param V5_part5='V5_part4+1.652285e+00*S40+1.303051e+00*S41+8.538860e+01*S42+4.062555e+00*S43+3.181729e+00*S44+1.325234e-01*S45+1.793553e+01*S46+5.359604e-02*S47+6.124524e-01*S48+6.452632e+00*S49'
.param V5_part6='V5_part5+3.236741e-02*S50+4.069765e+01*S51+4.674054e+01*S52+2.077679e+01*S53+8.900385e+00*S54+3.718834e+01*S55+2.039687e+01*S56+3.373275e+01*S57+1.272506e+01*S58+2.228559e+01*S59'
.param V5_part7='V5_part6+7.285717e-02*S60+9.963733e-02*S61+3.395145e+00*S62+9.854181e-02*S63+1.770439e+00*S64+5.213734e+00*S65+1.588779e+00*S66+7.856312e+00*S67+2.901083e+00*S68+1.437075e+01*S69'
.param V5_part8='V5_part7+3.434769e-01*S70+3.421342e+00*S71+(-9.774507e-02)*S72+1.295618e+00*S73+5.610919e+00*S74+7.500667e-03*S75+4.260139e-01*S76+9.544033e+00*S77+8.292844e-03*S78+9.825028e-01*S79'
.param V5_part9='V5_part8+1.676671e+00*S80+1.566344e+01*S81+1.790337e+00*S82+3.144698e+00*S83+1.424656e+01*S84+(-1.654610e-01)*S85+6.540936e+00*S86+1.389416e+01*S87+2.935226e+00*S88+3.883697e+00*S89'
.param V5_part10='V5_part9+1.289580e+01*S90+1.689308e+01*S91+1.098012e+01*S92+4.627215e+01*S93+2.179014e+01*S94+1.630484e+01*S95+(-1.340478e+01)*S96+5.287674e+01*S97+3.119380e+00*S98+(-3.716024e+01)*S99'
.param V5_part11='V5_part10+9.159470e+00*S100+3.769303e+00*S101+(-1.072162e+02)*S102+5.872280e+00*S103+4.803100e+00*S104+6.557966e+01*S105+7.390294e+01*S106+2.593504e+01*S107+6.658710e+01*S108+3.956459e+01*S109'
.param V5_part12='V5_part11+5.963897e+00*S110+5.889110e+03*S111+4.427632e+01*S112+5.406750e+00*S113+3.499619e+03*S114+(-7.391862e-02)*S115+7.277896e+00*S116+(-3.604331e-01)*S117+2.257759e+00*S118+1.060952e+01*S119'
.param V5_part13='V5_part12+3.531564e+00*S120+(-2.406485e+00)*S121+4.692335e+00*S122+5.512443e+01*S123+2.831462e+01*S124+1.387815e-01*S125+(-2.215407e-01)*S126+2.279940e-02*S127+1.117235e-01*S128+(-2.496339e-01)*S129'
.param V5_part14='V5_part13+(-2.584130e-02)*S130+1.145119e-01*S131+(-6.986363e-01)*S132+(-9.692739e-02)*S133+7.552087e-02*S134+9.979106e-02*S135+1.136544e+00*S136+1.132682e+01*S137+1.654738e-01*S138+5.779009e+00*S139'
.param V5_part15='V5_part14+4.375435e-01*S140+9.061435e-01*S141+5.394511e+00*S142+6.593954e+00*S143+(-2.726872e+00)*S144+4.792094e+00*S145+1.892912e+00*S146+(-1.534011e+00)*S147+6.984036e+00*S148+8.469556e-01*S149'
.param V5_part16='V5_part15+1.030151e-01*S150+1.957077e-01*S151+1.554014e+01*S152+(-2.517883e+00)*S153+2.179193e-01*S154+1.321528e+01*S155+(-3.095230e-01)*S156+2.976444e-02*S157+8.787081e+00*S158+(-3.752944e-01)*S159'
.param V5_part17='V5_part16+(-2.126814e-02)*S160+1.291039e-01*S161+6.412444e-02*S162+4.625782e-02*S163+5.964905e+00*S164+4.177694e-01*S165+6.699793e-02*S166+2.001339e-01*S167+(-4.342061e+01)*S168+8.023606e-01*S169'
.param V5_part18='V5_part17+1.521989e-01*S170+(-5.283545e-01)*S171+1.635145e-02*S172+1.917078e+00*S173+(-4.291352e-01)*S174+5.497084e-04*S175+3.135164e+00*S176+(-5.051046e-01)*S177+(-1.196975e-01)*S178+3.655758e+00*S179'
.param V5_part19='V5_part18+(-2.577801e+00)*S180+2.444540e-01*S181+8.541988e+00*S182+(-5.918820e-02)*S183+1.479469e-01*S184+1.906875e-01*S185+(-2.140989e-01)*S186+9.301324e-02*S187+1.438234e+00*S188+(-4.571432e-01)*S189'
.param V5_part20='V5_part19+(-5.610466e-02)*S190+1.944100e+00*S191+2.399303e+00*S192+(-4.614387e-02)*S193+2.812572e+00*S194+4.864765e+00*S195+1.620813e+01*S196+1.927773e-01*S197+(-2.538791e+00)*S198+1.395204e-01*S199'
.param V5_part21='V5_part20+2.125039e-01*S200+(-1.235161e+00)*S201+1.907318e-01*S202+2.476931e-01*S203+(-9.853320e-02)*S204+2.488605e+00*S205+1.846571e-01*S206+1.597117e+00*S207+2.499715e+00*S208+1.413331e-01*S209'
.param V5_part22='V5_part21+2.515664e-01*S210+7.712763e-01*S211+1.236352e+01*S212+(-2.204183e-02)*S213+3.430663e+00*S214+1.394761e+01*S215+(-3.109566e-01)*S216+8.228148e-02*S217+8.954380e+00*S218+(-1.544429e+00)*S219'
.param V5_part23='V5_part22+(-7.482053e-03)*S220+1.384626e-01*S221+(-5.829773e-01)*S222+(-7.368487e-02)*S223+(-8.703626e-02)*S224+6.148418e-01*S225+1.015808e-01*S226+1.460690e+00*S227+(-1.667490e-01)*S228+5.706295e-01*S229'
.param V5_part24='V5_part23+1.221063e+00*S230+1.193523e+01*S231+1.444222e+01*S232+3.367901e+00*S233+1.126653e+01*S234+(-3.378679e-02)*S235+2.462352e+00*S236+(-6.495634e-01)*S237+(-7.968384e-02)*S238+1.479613e+00*S239'
.param V5_part25='V5_part24+(-5.894778e-01)*S240+9.532604e-01*S241+1.362967e+00*S242+(-1.021436e+00)*S243+6.582183e-01*S244+2.897935e-01*S245+(-6.045502e+00)*S246+2.921032e-02*S247+1.790409e+00*S248+4.742006e+00*S249'
.param V5_part26='V5_part25+(-3.069047e-02)*S250+1.771404e+00*S251+(-3.519383e+00)*S252+(-9.108943e-02)*S253+2.351038e+00*S254+(-3.705572e+00)*S255+2.237409e+01*S256+1.457078e+00*S257+(-3.262892e+00)*S258+1.572641e+00*S259'
.param V5_part27='V5_part26+3.294526e+00*S260+(-3.307517e-01)*S261+1.233777e-01*S262+2.233957e-01*S263+9.709060e+00*S264+(-1.430763e-02)*S265+5.052536e+00*S266+(-5.912517e-01)*S267+(-2.934178e-02)*S268+3.908669e+00*S269'
.param V5_part28='V5_part27+(-3.691091e-01)*S270+6.789058e+00*S271+1.769999e+00*S272+8.068292e+00*S273+2.981701e+01*S274+1.614123e+00*S275+1.570418e+01*S276+5.199157e-01*S277+4.330724e+00*S278+(-9.890156e-01)*S279'
.param V5_part29='V5_part28+(-1.532617e-01)*S280+5.656220e+00*S281+6.226561e+00*S282+(-3.255625e-01)*S283+5.737283e+00*S284+(-5.831695e-01)*S285+(-9.130616e-01)*S286+3.400004e-01*S287+4.353698e+00*S288+1.127621e-01*S289'
.param V5_part30='V5_part29+2.961323e-01*S290+(-9.709290e-01)*S291+1.539806e-01*S292+2.656368e+00*S293+2.210429e-01*S294+(-4.517657e-02)*S295+3.266575e+00*S296+(-1.303325e+00)*S297+(-1.110741e-01)*S298+3.253343e+00*S299'
.param V5_part31='V5_part30+(-5.201858e-01)*S300+3.518235e+00*S301+3.866616e-01*S302+(-1.690626e-01)*S303+1.611942e+00*S304+3.418255e-01*S305+(-3.385854e-01)*S306+3.939178e-02*S307+5.396504e+00*S308+(-6.547266e-01)*S309'
.param V5='V5_part31+(-4.637688e-02)*S310+5.474440e+00*S311+(-8.935499e-01)*S312+(-1.209468e-01)*S313+7.188254e+00*S314'
.param V6_part1='1.055606e-01*S0+2.455358e+00*S1+3.225627e+00*S2+(-1.209358e+01)*S3+1.627252e+00*S4+(-1.186707e+00)*S5+4.007920e-01*S6+1.700887e+00*S7+2.739326e+00*S8+(-6.458305e-01)*S9'
.param V6_part2='V6_part1+1.797826e+00*S10+(-3.778947e+00)*S11+(-9.356218e-02)*S12+1.187838e+00*S13+1.434336e+00*S14+3.562640e+01*S15+5.726114e+00*S16+(-1.036716e+01)*S17+(-3.774027e-01)*S18+3.314138e+00*S19'
.param V6_part3='V6_part2+1.990020e+00*S20+4.772337e-01*S21+7.139656e+00*S22+(-1.913032e+00)*S23+7.587525e-01*S24+2.844699e+00*S25+2.375359e+00*S26+1.577828e-01*S27+3.301413e-03*S28+(-2.860812e+00)*S29'
.param V6_part4='V6_part3+1.346666e-01*S30+(-8.623136e+01)*S31+1.581315e+00*S32+1.366835e-01*S33+1.234636e+00*S34+(-6.261052e+00)*S35+3.740915e+01*S36+(-2.986256e+00)*S37+(-8.731572e+01)*S38+(-3.688011e+01)*S39'
.param V6_part5='V6_part4+1.073639e-01*S40+(-1.208020e+00)*S41+(-2.716490e+01)*S42+(-2.336937e+00)*S43+(-1.991774e+00)*S44+(-2.362144e-01)*S45+(-2.950544e+01)*S46+1.027677e-01*S47+(-4.014881e-01)*S48+5.793733e+01*S49'
.param V6_part6='V6_part5+1.078562e-01*S50+(-2.399273e+01)*S51+(-5.206643e+01)*S52+6.331790e+00*S53+(-1.023246e+01)*S54+(-3.943038e+01)*S55+5.550937e+00*S56+(-3.082226e+01)*S57+(-7.378217e+00)*S58+3.705653e+00*S59'
.param V6_part7='V6_part6+1.819735e-01*S60+(-2.036829e-02)*S61+(-3.018276e+00)*S62+1.127266e+00*S63+1.845113e+01*S64+(-4.891688e+00)*S65+(-1.964397e+00)*S66+(-1.863228e+01)*S67+(-2.811659e+00)*S68+(-1.595820e+01)*S69'
.param V6_part8='V6_part7+(-1.298734e-01)*S70+(-2.873771e+00)*S71+1.912643e-01*S72+(-7.114513e-01)*S73+(-3.968124e+00)*S74+(-7.041795e-02)*S75+9.183804e-01*S76+4.797122e+01*S77+2.563915e-02*S78+2.058600e-01*S79'
.param V6_part9='V6_part8+(-6.844683e-01)*S80+9.083181e+00*S81+(-9.866547e-01)*S82+(-1.863421e+00)*S83+1.287539e+00*S84+4.438794e+00*S85+(-5.809833e+00)*S86+3.622222e+00*S87+(-1.543882e+00)*S88+(-1.616274e+00)*S89'
.param V6_part10='V6_part9+4.069740e+01*S90+(-2.551453e+01)*S91+1.777938e+01*S92+(-6.214593e+01)*S93+(-9.971179e+00)*S94+(-2.989620e+00)*S95+1.476308e+00*S96+(-3.643424e+01)*S97+(-2.806954e+00)*S98+(-2.150276e+01)*S99'
.param V6_part11='V6_part10+(-4.873258e+00)*S100+(-2.518861e+00)*S101+6.661375e+01*S102+(-1.815741e+00)*S103+(-1.853323e+00)*S104+(-1.785112e+01)*S105+(-1.187450e+02)*S106+(-2.268653e+00)*S107+(-5.424273e+01)*S108+(-2.826758e+01)*S109'
.param V6_part12='V6_part11+(-3.075123e+00)*S110+(-5.566150e+03)*S111+(-2.148209e+01)*S112+(-2.854900e+00)*S113+(-1.755489e+03)*S114+3.759103e-01*S115+(-4.305880e+00)*S116+5.053364e-01*S117+(-1.287121e-02)*S118+(-7.116060e+00)*S119'
.param V6_part13='V6_part12+(-1.520591e+00)*S120+(-3.425991e+01)*S121+(-9.258216e-01)*S122+(-7.412442e+01)*S123+(-5.990816e+00)*S124+7.613174e-02*S125+5.981087e-01*S126+2.645061e-01*S127+7.861653e-02*S128+4.343014e-01*S129'
.param V6_part14='V6_part13+2.805084e-01*S130+7.505400e-03*S131+1.015421e+00*S132+3.568601e-01*S133+3.542381e-02*S134+1.195982e+00*S135+4.950121e+01*S136+(-7.741172e+00)*S137+1.156818e+00*S138+1.749237e+01*S139'
.param V6_part15='V6_part14+(-1.956145e-01)*S140+(-1.676923e+00)*S141+(-1.324564e+01)*S142+(-4.105474e+00)*S143+(-2.722979e+00)*S144+(-8.631938e+00)*S145+(-8.784687e-01)*S146+(-1.970797e+00)*S147+(-1.141218e+00)*S148+8.917696e-01*S149'
.param V6_part16='V6_part15+3.053791e-01*S150+3.219372e-01*S151+2.521200e+00*S152+(-4.692807e+00)*S153+(-1.721814e-01)*S154+1.876964e+00*S155+1.005149e+00*S156+2.372012e-01*S157+(-1.496607e+00)*S158+6.177326e-01*S159'
.param V6_part17='V6_part16+2.573852e-01*S160+1.135405e-01*S161+5.382128e-01*S162+1.306709e-01*S163+(-2.873213e+00)*S164+7.875150e-01*S165+4.113745e-01*S166+1.085318e-01*S167+7.051352e+01*S168+1.174612e+00*S169'
.param V6_part18='V6_part17+9.754704e-02*S170+1.450231e+00*S171+4.090254e-01*S172+(-4.012951e-02)*S173+7.978158e-01*S174+1.050420e+00*S175+(-4.337035e-01)*S176+8.196196e-01*S177+3.815620e-01*S178+(-5.273554e-01)*S179'
.param V6_part19='V6_part18+(-7.207435e+00)*S180+3.667930e-01*S181+2.161162e+00*S182+5.227688e-01*S183+1.613637e-01*S184+5.080311e-02*S185+6.083901e-01*S186+1.915130e-01*S187+(-5.264811e-01)*S188+8.498580e-01*S189'
.param V6_part20='V6_part19+4.243834e-01*S190+3.160321e-01*S191+4.402042e-01*S192+2.349315e-01*S193+(-4.466076e-01)*S194+(-2.257387e+00)*S195+(-1.093041e+01)*S196+9.566210e-02*S197+2.298400e+00*S198+(-6.062710e-02)*S199'
.param V6_part21='V6_part20+4.927455e-02*S200+2.361248e+00*S201+(-1.429321e-01)*S202+9.128202e-02*S203+3.515309e-01*S204+(-3.585866e+00)*S205+3.660443e-04*S206+(-7.810732e-01)*S207+(-6.016559e+00)*S208+1.865501e-02*S209'
.param V6_part22='V6_part21+1.120624e+00*S210+(-5.384459e+00)*S211+1.356023e+01*S212+1.009206e+00*S213+3.919371e+00*S214+3.478267e-01*S215+1.021642e+00*S216+4.233419e-01*S217+6.801229e+00*S218+(-3.916652e-01)*S219'
.param V6_part23='V6_part22+4.334942e-01*S220+2.906109e-01*S221+8.596617e-01*S222+4.249110e-01*S223+5.817902e-01*S224+1.264306e-01*S225+(-4.120686e+00)*S226+(-2.078839e-01)*S227+1.137868e+00*S228+1.629259e+00*S229'
.param V6_part24='V6_part23+(-1.092160e-01)*S230+(-7.462134e+00)*S231+(-4.335499e+00)*S232+(-1.857036e+00)*S233+(-2.240396e+00)*S234+3.698953e-01*S235+(-4.693302e-01)*S236+9.409436e-01*S237+3.657211e-01*S238+(-5.330864e-04)*S239'
.param V6_part25='V6_part24+3.104824e+00*S240+1.982461e+00*S241+3.182990e-02*S242+3.703309e+00*S243+1.696713e+00*S244+3.852739e-01*S245+8.276943e+00*S246+5.989516e-01*S247+(-1.497697e-03)*S248+1.064317e+00*S249'
.param V6_part26='V6_part25+3.824145e-01*S250+(-7.526701e-03)*S251+4.320953e+00*S252+3.707904e-01*S253+7.304278e-01*S254+(-5.559977e+00)*S255+3.746612e+01*S256+3.529843e-01*S257+(-3.748661e+00)*S258+(-4.434483e+00)*S259'
.param V6_part27='V6_part26+9.663638e-01*S260+9.479632e-01*S261+4.326795e-01*S262+3.420347e-01*S263+(-4.294027e+00)*S264+4.536884e-01*S265+(-1.475138e+00)*S266+9.906146e-01*S267+2.232909e-01*S268+(-7.655369e-01)*S269'
.param V6_part28='V6_part27+3.753579e+00*S270+(-1.243502e+00)*S271+(-6.541163e-01)*S272+(-1.093531e+00)*S273+(-4.854133e+00)*S274+(-4.294460e-01)*S275+(-3.597768e+00)*S276+1.948373e+00*S277+(-4.949023e-01)*S278+1.837952e+00*S279'
.param V6_part29='V6_part28+2.177168e+00*S280+(-1.635747e+00)*S281+1.315802e+01*S282+6.921469e-01*S283+(-1.393599e+00)*S284+3.709901e+00*S285+(-3.662969e-01)*S286+1.822470e-01*S287+3.801283e+00*S288+6.021828e-01*S289'
.param V6_part30='V6_part29+2.762311e-01*S290+6.732681e-01*S291+5.678039e-01*S292+(-3.101926e-01)*S293+(-1.681544e-02)*S294+6.746918e-01*S295+(-2.548376e-01)*S296+1.904720e+00*S297+5.327401e-01*S298+(-6.878899e-02)*S299'
.param V6_part31='V6_part30+4.257787e+00*S300+3.446539e+00*S301+2.933819e-01*S302+1.327270e+00*S303+(-1.384227e+00)*S304+4.073601e-01*S305+1.021548e+00*S306+4.720595e-01*S307+(-4.882699e-02)*S308+1.347622e+00*S309'
.param V6='V6_part31+4.875655e-01*S310+(-5.656695e-01)*S311+1.359904e+00*S312+4.752994e-01*S313+(-5.646587e-01)*S314'
.param V7_part1='1.326144e-02*S0+(-6.254859e-02)*S1+4.221830e-01*S2+4.921658e+00*S3+(-3.746878e-02)*S4+1.341284e-01*S5+3.476660e-01*S6+4.040592e-01*S7+1.383070e+00*S8+6.906524e-01*S9'
.param V7_part2='V7_part1+9.593410e-01*S10+5.171691e-01*S11+3.140031e-01*S12+4.704804e-01*S13+7.575789e-01*S14+4.404289e-01*S15+5.321659e-01*S16+1.653790e+00*S17+3.481292e-01*S18+6.686444e-01*S19'
.param V7_part3='V7_part2+2.118312e+00*S20+7.853522e-01*S21+2.284257e-01*S22+5.100832e-01*S23+1.584133e+00*S24+1.074646e+00*S25+7.648938e-01*S26+7.088124e-02*S27+1.989580e-01*S28+2.949166e+00*S29'
.param V7_part4='V7_part3+9.946921e-02*S30+1.523022e+01*S31+(-1.695314e-01)*S32+1.137403e-01*S33+1.634033e-03*S34+3.057656e+00*S35+2.775736e+01*S36+1.647369e+00*S37+6.308441e+01*S38+2.917141e+01*S39'
.param V7_part5='V7_part4+5.999989e-01*S40+4.455969e-01*S41+4.153659e+01*S42+9.491358e-01*S43+1.287579e+00*S44+1.660755e-01*S45+3.767434e+00*S46+2.092872e-02*S47+2.780850e-01*S48+9.913815e+00*S49'
.param V7_part6='V7_part5+3.764035e-02*S50+1.689390e+00*S51+2.057086e+01*S52+1.554463e+00*S53+2.922773e+00*S54+1.680612e+01*S55+1.300431e+00*S56+8.260772e+00*S57+2.268493e+00*S58+1.660969e+00*S59'
.param V7_part7='V7_part6+1.738813e-01*S60+2.193248e-01*S61+3.269679e+00*S62+1.034593e+00*S63+3.478984e+00*S64+3.923352e+00*S65+2.106381e+00*S66+9.574915e+00*S67+1.646823e+00*S68+6.180456e+00*S69'
.param V7_part8='V7_part7+3.906369e-01*S70+1.656593e+00*S71+4.384757e-01*S72+6.677973e-01*S73+2.318036e+00*S74+1.531842e-01*S75+1.572145e-01*S76+(-1.652577e-01)*S77+2.349567e-01*S78+2.635103e-01*S79'
.param V7_part9='V7_part8+4.251652e-01*S80+7.478789e-01*S81+2.751881e-01*S82+6.500899e-01*S83+7.368046e-01*S84+4.225728e-01*S85+1.997207e+00*S86+8.568942e-01*S87+9.151965e-01*S88+6.535937e+00*S89'
.param V7_part10='V7_part9+9.892797e-01*S90+1.598739e+01*S91+1.682713e+01*S92+3.187289e+01*S93+4.643360e+00*S94+1.816525e+01*S95+4.385716e+01*S96+1.309066e+01*S97+1.442029e+00*S98+5.927346e+01*S99'
.param V7_part11='V7_part10+2.042442e+00*S100+1.760727e+00*S101+7.332361e+01*S102+9.084069e-01*S103+2.447177e+00*S104+1.471840e+01*S105+2.081152e+01*S106+1.163841e+01*S107+3.673827e+01*S108+1.620868e+01*S109'
.param V7_part12='V7_part11+4.545467e+00*S110+(-1.346972e+01)*S111+1.957903e+01*S112+2.654099e+00*S113+1.883234e+00*S114+7.129050e-02*S115+2.865441e+00*S116+1.403086e-01*S117+3.491781e-01*S118+3.482389e+00*S119'
.param V7_part13='V7_part12+1.877341e-01*S120+2.559293e+01*S121+2.958764e+00*S122+4.873420e+00*S123+6.805544e+00*S124+6.725165e-02*S125+1.034750e-01*S126+7.787462e-02*S127+9.760355e-02*S128+1.314539e-01*S129'
.param V7_part14='V7_part13+9.866629e-02*S130+1.443197e-01*S131+1.738540e-01*S132+1.047930e-01*S133+1.685172e-01*S134+3.569208e-01*S135+1.926147e+00*S136+1.964135e+01*S137+1.140075e+00*S138+7.210711e+00*S139'
.param V7_part15='V7_part14+4.059873e-01*S140+7.440277e-01*S141+7.034233e+00*S142+5.157020e+00*S143+3.835934e+00*S144+4.884105e+00*S145+1.552403e+00*S146+3.528901e+00*S147+5.943131e-02*S148+4.983692e-01*S149'
.param V7_part16='V7_part15+6.094812e-02*S150+2.871402e-02*S151+1.464263e+01*S152+3.231197e+00*S153+2.438164e-01*S154+2.017933e+01*S155+1.288987e-01*S156+1.152938e-01*S157+6.086539e+00*S158+1.542159e-01*S159'
.param V7_part17='V7_part16+1.442493e-01*S160+1.529814e-01*S161+5.716420e-01*S162+1.749211e-01*S163+2.767460e+00*S164+1.444292e-01*S165+2.631379e-01*S166+8.893239e-02*S167+3.706490e+01*S168+2.732466e-02*S169'
.param V7_part18='V7_part17+1.239211e-01*S170+1.509955e-01*S171+9.774716e-02*S172+2.065096e+00*S173+1.649958e-01*S174+2.579982e-02*S175+3.205064e+00*S176+1.944610e-01*S177+1.707019e-01*S178+3.573562e+00*S179'
.param V7_part19='V7_part18+3.616308e+00*S180+2.921931e-02*S181+5.439031e+00*S182+1.091154e-01*S183+9.759279e-02*S184+1.204345e-01*S185+1.425075e-01*S186+1.326775e-01*S187+1.989638e+00*S188+1.754478e-01*S189'
.param V7_part20='V7_part19+1.430536e-01*S190+3.467354e+00*S191+3.117664e+00*S192+2.101824e-01*S193+3.360599e+00*S194+2.185962e-01*S195+7.328172e+00*S196+4.855826e-02*S197+1.516988e+00*S198+2.750497e-01*S199'
.param V7_part21='V7_part20+8.948444e-02*S200+3.608635e-01*S201+2.838598e-01*S202+1.161581e-01*S203+6.813383e-01*S204+3.222914e+00*S205+2.359034e-01*S206+1.655654e+00*S207+6.426219e+00*S208+3.768918e-01*S209'
.param V7_part22='V7_part21+1.195075e-01*S210+1.716237e+00*S211+1.799179e+01*S212+1.657912e-01*S213+(-1.467120e-01)*S214+1.893060e+01*S215+1.547372e-01*S216+1.185417e-01*S217+1.844464e+01*S218+2.452468e+00*S219'
.param V7_part23='V7_part22+1.647399e-01*S220+4.267047e-01*S221+2.277415e-01*S222+2.038946e-01*S223+1.680873e-01*S224+3.115098e-01*S225+2.292785e+00*S226+8.425062e-01*S227+1.245477e-01*S228+(-9.927010e-02)*S229'
.param V7_part24='V7_part23+1.148480e+00*S230+4.499228e+00*S231+(-2.379420e-01)*S232+3.516135e+00*S233+4.600916e+00*S234+2.064613e-01*S235+3.862849e+00*S236+2.444659e-01*S237+2.393403e-01*S238+1.944864e+00*S239'
.param V7_part25='V7_part24+3.101277e-01*S240+(-2.017660e-01)*S241+1.019609e+00*S242+2.184715e-01*S243+(-1.447966e-01)*S244+7.553729e-02*S245+1.725914e+00*S246+1.379749e-01*S247+2.517376e+00*S248+3.916705e+00*S249'
.param V7_part26='V7_part25+2.208171e-01*S250+3.067594e+00*S251+4.456398e-01*S252+2.633203e-01*S253+2.750403e+00*S254+3.558764e+00*S255+4.545210e+00*S256+2.816546e+00*S257+3.278453e+00*S258+3.737920e+00*S259'
.param V7_part27='V7_part26+4.089289e+00*S260+1.495486e-01*S261+8.980764e-02*S262+2.040651e-01*S263+4.079572e+00*S264+1.452658e-01*S265+7.745316e+00*S266+2.421953e-01*S267+2.324755e-01*S268+4.238877e+00*S269'
.param V7_part28='V7_part27+1.284419e-01*S270+(-7.036573e-01)*S271+1.137655e+00*S272+3.605534e+00*S273+(-3.125921e+00)*S274+1.388155e+00*S275+4.307246e+00*S276+(-1.284206e-01)*S277+6.412231e+00*S278+2.752392e-01*S279'
.param V7_part29='V7_part28+5.860123e-02*S280+7.040533e+00*S281+6.979527e+00*S282+3.729645e-01*S283+3.950641e+00*S284+3.630367e-01*S285+2.889225e+00*S286+1.190444e-01*S287+2.684005e+00*S288+1.667388e-01*S289'
.param V7_part30='V7_part29+1.226829e-01*S290+1.977694e+00*S291+1.543918e-01*S292+2.073315e+00*S293+1.111869e+00*S294+2.131090e-01*S295+3.094200e+00*S296+3.939715e-01*S297+2.856475e-01*S298+2.683384e+00*S299'
.param V7_part31='V7_part30+1.633669e-01*S300+1.711787e+00*S301+9.512911e-02*S302+1.378785e-01*S303+4.479667e+00*S304+1.011252e-01*S305+1.845560e-01*S306+1.828404e-01*S307+6.297892e+00*S308+2.351490e-01*S309'
.param V7='V7_part31+2.143103e-01*S310+5.704630e+00*S311+2.965106e-01*S312+2.577068e-01*S313+4.502822e+00*S314'
.param V8_part1='2.897120e-02*S0+1.931453e-01*S1+1.592624e+00*S2+(-4.888551e+00)*S3+1.485059e-01*S4+(-2.878523e-01)*S5+(-1.669147e-01)*S6+7.020340e-01*S7+7.307588e-01*S8+(-4.813722e-01)*S9'
.param V8_part2='V8_part1+6.380088e-01*S10+(-8.544977e-01)*S11+2.465625e-01*S12+5.528141e-01*S13+5.910864e-01*S14+3.587331e+00*S15+1.193897e+00*S16+(-1.929159e+00)*S17+(-2.515607e-01)*S18+6.669497e-01*S19'
.param V8_part3='V8_part2+1.093733e+00*S20+(-3.856302e-01)*S21+5.748297e-02*S22+(-4.649214e-01)*S23+(-6.289506e-01)*S24+7.517924e-01*S25+1.955821e-01*S26+2.362238e-02*S27+1.100555e-02*S28+7.781875e-01*S29'
.param V8_part4='V8_part3+(-2.455474e-02)*S30+(-9.840428e+00)*S31+1.698990e-01*S32+(-3.850372e-02)*S33+5.921646e-02*S34+2.084731e+00*S35+(-1.902779e+00)*S36+2.023048e+00*S37+1.028735e+01*S38+(-1.070964e+01)*S39'
.param V8_part5='V8_part4+1.060138e+00*S40+1.881243e-01*S41+(-1.418643e+01)*S42+7.054459e-02*S43+4.205565e-01*S44+(-7.183322e-02)*S45+(-2.638514e+00)*S46+7.503727e-03*S47+5.054842e-02*S48+4.651068e+00*S49'
.param V8_part6='V8_part5+3.819628e-03*S50+(-3.089470e+00)*S51+(-7.137006e+00)*S52+(-2.892595e+01)*S53+1.824386e+00*S54+(-4.256902e+00)*S55+(-2.838119e+01)*S56+(-5.497494e-02)*S57+(-4.592902e+00)*S58+(-2.993953e+01)*S59'
.param V8_part7='V8_part6+(-7.719631e-02)*S60+3.037366e-03*S61+(-2.309814e-01)*S62+(-2.875835e-01)*S63+1.635043e-01*S64+(-6.662196e-01)*S65+(-6.514477e-01)*S66+(-2.089979e+00)*S67+1.075409e-01*S68+(-3.740070e+00)*S69'
.param V8_part8='V8_part7+5.567223e-02*S70+9.332847e-02*S71+1.598417e-02*S72+8.921369e-02*S73+2.143294e-01*S74+(-1.302298e-01)*S75+(-3.774642e-01)*S76+6.833758e+00*S77+(-1.783065e-01)*S78+3.273941e-01*S79'
.param V8_part9='V8_part8+(-3.350724e-01)*S80+1.114719e-01*S81+(-2.757957e-01)*S82+(-4.343520e-01)*S83+(-1.290225e+00)*S84+1.736447e-01*S85+1.115036e+00*S86+(-8.823569e-01)*S87+7.050444e-01*S88+(-2.500991e-01)*S89'
.param V8_part10='V8_part9+1.996153e+00*S90+(-8.869162e-01)*S91+(-3.019917e+00)*S92+(-1.137938e+01)*S93+(-1.758617e+00)*S94+(-5.112976e-01)*S95+(-9.958515e+00)*S96+(-2.777928e+00)*S97+4.048274e-01*S98+(-1.440869e+00)*S99'
.param V8_part11='V8_part10+6.924145e-01*S100+5.216265e-01*S101+2.260273e+01*S102+7.058955e-01*S103+8.031605e-01*S104+(-6.086959e+00)*S105+(-5.846303e+00)*S106+(-2.439460e+00)*S107+(-1.250687e+01)*S108+(-1.530902e+00)*S109'
.param V8_part12='V8_part11+(-2.689284e-01)*S110+(-3.337294e+02)*S111+(-1.077064e+00)*S112+(-6.512938e-02)*S113+(-5.398569e+01)*S114+2.539207e-02*S115+7.545193e-01*S116+2.450577e-02*S117+3.926126e-01*S118+1.025426e+00*S119'
.param V8_part13='V8_part12+(-1.020755e-01)*S120+(-7.597689e-01)*S121+(-2.029141e-01)*S122+(-1.459728e+00)*S123+(-2.745610e+00)*S124+1.266147e-03*S125+3.260086e-02*S126+1.025238e-02*S127+2.868222e-03*S128+1.710610e-02*S129'
.param V8_part14='V8_part13+1.232695e-02*S130+4.613688e-03*S131+5.074936e-02*S132+1.263205e-02*S133+6.967112e-03*S134+(-1.774689e-01)*S135+(-1.550780e+00)*S136+(-2.134193e+00)*S137+(-3.086518e-01)*S138+(-3.465572e+00)*S139'
.param V8_part15='V8_part14+2.519688e-03*S140+3.277874e-01*S141+(-4.244145e-01)*S142+(-8.350306e-01)*S143+(-6.804320e-01)*S144+(-4.552663e-01)*S145+(-3.278498e-01)*S146+(-4.367754e-01)*S147+(-3.285305e-01)*S148+5.776072e-02*S149'
.param V8_part16='V8_part15+9.611442e-03*S150+9.273828e-03*S151+(-1.134447e+00)*S152+(-1.308818e-01)*S153+(-5.433005e-03)*S154+(-8.831683e-01)*S155+2.542910e-02*S156+6.818812e-03*S157+(-3.775833e-01)*S158+1.323715e-02*S159'
.param V8_part17='V8_part16+1.144055e-02*S160+2.235077e-03*S161+(-1.626149e-01)*S162+7.637738e-03*S163+1.026079e+00*S164+8.508626e-03*S165+3.294531e-04*S166+3.467292e-03*S167+(-3.172092e-01)*S168+(-8.406520e-02)*S169'
.param V8_part18='V8_part17+3.166081e-03*S170+8.003452e-02*S171+1.438306e-02*S172+(-1.705030e-01)*S173+3.797215e-02*S174+3.443834e-02*S175+(-1.950307e-01)*S176+2.651625e-02*S177+1.427688e-02*S178+(-4.682057e-01)*S179'
.param V8_part19='V8_part18+(-1.841702e-01)*S180+8.858594e-03*S181+(-1.696101e-01)*S182+2.314871e-02*S183+1.011286e-04*S184+(-2.519672e-04)*S185+2.893184e-02*S186+2.818901e-03*S187+(-8.742453e-02)*S188+3.592482e-02*S189'
.param V8_part20='V8_part19+1.867198e-02*S190+(-1.874295e-01)*S191+(-1.164635e+00)*S192+1.505756e-02*S193+(-3.970568e-01)*S194+(-1.486181e-01)*S195+(-1.502226e+00)*S196+6.348002e-03*S197+(-2.352835e-01)*S198+(-3.535599e-02)*S199'
.param V8_part21='V8_part20+(-1.165294e-03)*S200+1.280639e-01*S201+(-3.065836e-02)*S202+(-1.097475e-02)*S203+(-5.548398e-02)*S204+3.241721e-01*S205+6.845495e-04*S206+(-1.023842e-01)*S207+2.424328e-01*S208+2.032770e-04*S209'
.param V8_part22='V8_part21+1.995392e-02*S210+(-2.551947e-01)*S211+(-4.727256e-01)*S212+1.259342e-02*S213+(-2.238218e-01)*S214+(-5.941224e-01)*S215+2.495216e-02*S216+1.701300e-02*S217+(-4.268545e-01)*S218+(-7.045137e-02)*S219'
.param V8_part23='V8_part22+1.630445e-02*S220+(-4.053925e-03)*S221+3.683454e-02*S222+1.940362e-02*S223+5.607529e-03*S224+7.220379e-03*S225+(-1.422246e-01)*S226+(-6.308128e-02)*S227+2.719176e-02*S228+4.926204e-02*S229'
.param V8_part24='V8_part23+(-8.867476e-02)*S230+(-1.662999e+00)*S231+(-1.952015e-01)*S232+(-1.709707e-01)*S233+(-1.147973e+00)*S234+1.367249e-02*S235+(-3.035604e-01)*S236+3.424153e-02*S237+1.120438e-02*S238+(-2.119977e-01)*S239'
.param V8_part25='V8_part24+3.802259e-02*S240+4.777644e-03*S241+(-9.397679e-02)*S242+1.378232e-01*S243+5.749224e-02*S244+4.037886e-03*S245+4.574701e-01*S246+1.999528e-02*S247+(-1.977283e-01)*S248+(-5.008802e-01)*S249'
.param V8_part26='V8_part25+1.825814e-02*S250+(-2.477408e-01)*S251+2.616797e-01*S252+1.768538e-02*S253+(-2.543834e-01)*S254+(-2.449628e-01)*S255+(-8.208798e-01)*S256+(-4.562459e-02)*S257+(-1.752225e-02)*S258+(-5.220840e-02)*S259'
.param V8_part27='V8_part26+6.389064e-03*S260+4.259875e-02*S261+1.387102e-02*S262+(-2.443619e-02)*S263+5.646705e-01*S264+1.740166e-02*S265+(-6.736236e-01)*S266+5.209600e-02*S267+1.656731e-02*S268+(-5.788877e-01)*S269'
.param V8_part28='V8_part27+8.532168e-02*S270+8.377419e-03*S271+(-9.192017e-02)*S272+(-3.163111e-01)*S273+(-2.249744e-01)*S274+(-1.611645e-01)*S275+(-1.490161e+00)*S276+9.754896e-02*S277+(-5.528121e-01)*S278+5.632789e-02*S279'
.param V8_part29='V8_part28+1.079891e-01*S280+(-6.776538e-01)*S281+(-2.204254e+00)*S282+1.581941e-02*S283+(-3.890081e-01)*S284+9.255688e-02*S285+(-1.428360e-01)*S286+(-6.093407e-03)*S287+(-7.795331e-01)*S288+1.772682e-02*S289'
.param V8_part30='V8_part29+1.319540e-03*S290+3.206776e-02*S291+1.506260e-02*S292+(-1.595673e-01)*S293+1.825514e-01*S294+2.044256e-02*S295+(-2.083695e-01)*S296+2.070268e-02*S297+1.448428e-02*S298+(-2.411541e-01)*S299'
.param V8_part31='V8_part30+9.621032e-02*S300+(-1.016309e-01)*S301+(-3.144191e-03)*S302+5.309436e-02*S303+2.207482e-01*S304+(-7.995258e-04)*S305+5.374045e-02*S306+2.003678e-02*S307+(-7.424655e-01)*S308+5.938815e-02*S309'
.param V8='V8_part31+1.913391e-02*S310+(-8.099868e-01)*S311+6.459528e-02*S312+1.787137e-02*S313+(-1.102357e+00)*S314'
.param V9_part1='(-1.103531e-04)*S0+(-9.116171e-03)*S1+(-3.949051e-03)*S2+1.310722e-02*S3+(-1.824389e-04)*S4+3.687375e-03*S5+(-7.234246e-04)*S6+2.334114e-03*S7+1.583127e-02*S8+4.656063e-03*S9'
.param V9_part2='V9_part1+8.628856e-03*S10+1.010653e-02*S11+3.789717e-03*S12+1.450393e-02*S13+1.858733e-02*S14+1.474039e-01*S15+1.163108e-02*S16+(-7.185458e-02)*S17+1.018957e-02*S18+2.478814e-02*S19'
.param V9_part3='V9_part2+1.195556e-02*S20+(-6.086241e-03)*S21+(-1.223061e-03)*S22+2.923100e-02*S23+1.476580e-03*S24+3.810900e-02*S25+4.027790e-02*S26+3.347056e-04*S27+9.503484e-04*S28+(-5.126153e-03)*S29'
.param V9_part4='V9_part3+(-3.731492e-03)*S30+(-7.126897e-01)*S31+1.503840e-02*S32+(-7.279279e-03)*S33+6.133871e-03*S34+1.416606e-02*S35+(-1.855938e+00)*S36+(-1.439062e-02)*S37+(-1.035429e+00)*S38+(-3.009138e+00)*S39'
.param V9_part5='V9_part4+3.482029e-04*S40+(-1.482441e-02)*S41+(-4.881811e+00)*S42+(-5.444432e-02)*S43+(-4.831391e-02)*S44+4.303738e-03*S45+6.912986e-02*S46+1.637843e-03*S47+(-3.788976e-02)*S48+2.475261e+00*S49'
.param V9_part6='V9_part5+1.672380e-03*S50+3.178882e+00*S51+(-8.760918e+00)*S52+1.720941e-01*S53+5.922523e-01*S54+(-5.358659e+00)*S55+9.621347e-02*S56+(-3.036341e-01)*S57+(-3.892713e-03)*S58+8.739250e-02*S59'
.param V9_part7='V9_part6+1.381326e-03*S60+(-1.479931e-02)*S61+(-1.334120e-01)*S62+6.742231e-02*S63+1.067772e+00*S64+(-1.968767e-01)*S65+5.725937e-01*S66+(-1.795730e-01)*S67+(-1.353496e-01)*S68+(-1.278647e-01)*S69'
.param V9_part8='V9_part7+(-8.765998e-03)*S70+(-1.033099e-01)*S71+(-1.405252e-01)*S72+(-5.823832e-03)*S73+(-2.775687e-01)*S74+1.166219e-02*S75+2.203805e-01*S76+5.005901e+00*S77+(-2.396715e-03)*S78+(-3.055010e-01)*S79'
.param V9_part9='V9_part8+(-1.780385e-01)*S80+4.601033e-01*S81+(-6.710494e-02)*S82+(-2.376489e-01)*S83+2.626819e-01*S84+2.806819e-01*S85+(-6.258980e-01)*S86+1.839874e-03*S87+(-4.129698e-01)*S88+(-3.753198e-01)*S89'
.param V9_part10='V9_part9+1.871199e-01*S90+(-1.993232e+00)*S91+(-9.131006e-01)*S92+3.932375e+00*S93+(-1.208752e+00)*S94+(-2.113789e+00)*S95+1.045689e+01*S96+(-2.619392e+00)*S97+(-2.104558e-01)*S98+1.799737e+01*S99'
.param V9_part11='V9_part10+(-7.114552e-01)*S100+(-1.855217e-01)*S101+5.167786e+01*S102+(-3.067889e-01)*S103+(-2.124614e-01)*S104+(-1.504374e+00)*S105+(-3.490505e+00)*S106+(-2.103497e-01)*S107+4.327665e+00*S108+(-4.773065e-01)*S109'
.param V9_part12='V9_part11+(-4.479502e-01)*S110+3.953373e+02*S111+(-5.624328e-01)*S112+(-3.114326e-01)*S113+9.565585e+02*S114+3.908464e-03*S115+(-4.731193e-01)*S116+1.921350e-02*S117+(-1.343923e-01)*S118+(-6.019688e-01)*S119'
.param V9_part13='V9_part12+(-6.522477e-01)*S120+(-4.448525e+00)*S121+(-3.930442e-01)*S122+9.321596e+00*S123+(-2.310177e+00)*S124+(-1.185292e-03)*S125+2.590048e-02*S126+4.397980e-03*S127+(-7.678320e-04)*S128+2.369477e-02*S129'
.param V9_part14='V9_part13+6.194353e-03*S130+(-3.454108e-04)*S131+2.599133e-02*S132+5.945958e-04*S133+9.475811e-04*S134+(-1.390536e-01)*S135+7.208494e-01*S136+(-1.232946e+00)*S137+(-7.200838e-02)*S138+(-7.646534e-02)*S139'
.param V9_part15='V9_part14+(-3.478926e-02)*S140+(-7.999252e-02)*S141+(-7.072228e-01)*S142+(-1.971776e+00)*S143+(-2.140466e-03)*S144+(-3.744468e-01)*S145+(-3.707661e-01)*S146+(-5.218024e-02)*S147+(-3.899529e-01)*S148+(-1.982322e-01)*S149'
.param V9_part16='V9_part15+3.382991e-03*S150+(-1.193552e-03)*S151+(-1.030587e+00)*S152+(-3.702397e-01)*S153+(-2.532890e-02)*S154+(-9.563264e-01)*S155+7.559500e-03*S156+6.119879e-03*S157+(-3.055382e-01)*S158+4.998080e-02*S159'
.param V9_part17='V9_part16+4.144121e-03*S160+(-7.940932e-03)*S161+(-1.503356e-02)*S162+(-8.005456e-03)*S163+(-5.281199e-01)*S164+(-6.766265e-02)*S165+(-4.249066e-02)*S166+(-6.677271e-03)*S167+1.504410e+01*S168+6.491033e-03*S169'
.param V9_part18='V9_part17+(-5.810820e-03)*S170+7.213166e-02*S171+1.691029e-02*S172+6.709514e-02*S173+5.680279e-02*S174+5.705206e-02*S175+(-2.321147e-02)*S176+9.627932e-03*S177+1.927847e-02*S178+3.871758e-02*S179'
.param V9_part19='V9_part18+(-1.056763e+00)*S180+3.049887e-03*S181+(-7.619697e-01)*S182+2.774802e-02*S183+(-4.000624e-03)*S184+(-2.907759e-03)*S185+4.111854e-02*S186+2.634791e-03*S187+6.402420e-02*S188+7.086046e-02*S189'
.param V9_part20='V9_part19+2.514831e-02*S190+1.810480e-01*S191+(-1.964158e-01)*S192+1.195662e-02*S193+4.025701e-01*S194+(-1.061936e+00)*S195+(-1.429633e+00)*S196+(-9.481102e-03)*S197+(-1.111772e-01)*S198+(-4.666805e-02)*S199'
.param V9_part21='V9_part20+(-1.409707e-02)*S200+7.232079e-02*S201+(-3.900729e-02)*S202+(-1.686780e-02)*S203+(-9.315844e-02)*S204+(-5.434843e-01)*S205+(-2.153103e-03)*S206+(-7.983659e-01)*S207+(-5.583870e-01)*S208+9.860874e-03*S209'
.param V9_part22='V9_part21+5.819234e-02*S210+(-6.182872e-01)*S211+(-4.987309e-01)*S212+8.504888e-02*S213+5.438387e-01*S214+(-4.913371e-01)*S215+4.870649e-02*S216+2.828751e-02*S217+(-9.303362e-01)*S218+1.907056e+00*S219'
.param V9_part23='V9_part22+2.560773e-02*S220+3.835259e-02*S221+7.587081e-02*S222+3.055652e-02*S223+1.214987e-02*S224+1.747267e-02*S225+(-7.636779e-01)*S226+6.168573e-02*S227+4.913464e-02*S228+1.062741e-01*S229'
.param V9_part24='V9_part23+1.304164e-01*S230+1.521209e-01*S231+(-3.296420e-01)*S232+3.107964e-01*S233+(-4.634104e-01)*S234+2.166578e-02*S235+3.765636e-01*S236+8.267601e-02*S237+2.049082e-02*S238+4.575711e-01*S239'
.param V9_part25='V9_part24+9.585830e-02*S240+1.621535e-01*S241+1.603309e-01*S242+2.166044e-01*S243+1.605046e-01*S244+4.283609e-03*S245+9.482619e-01*S246+4.133388e-02*S247+1.745968e-01*S248+(-2.355133e-01)*S249'
.param V9_part26='V9_part25+3.162291e-02*S250+1.681764e-01*S251+2.913777e-01*S252+2.809931e-02*S253+1.625134e-01*S254+(-9.943406e-01)*S255+(-1.443427e+00)*S256+(-1.069698e+00)*S257+(-7.854581e-01)*S258+(-1.267050e+00)*S259'
.param V9_part27='V9_part26+(-1.587957e+00)*S260+6.609816e-02*S261+1.051002e-02*S262+(-1.002857e-03)*S263+(-1.411400e+00)*S264+2.072437e-02*S265+5.719105e-01*S266+2.548512e-02*S267+1.510468e-02*S268+3.240714e-01*S269'
.param V9_part28='V9_part27+2.054318e-01*S270+(-5.696906e-01)*S271+1.628288e-02*S272+(-1.829157e+00)*S273+(-3.006011e+00)*S274+1.941057e-01*S275+(-8.827527e-01)*S276+1.903386e-01*S277+5.716082e-01*S278+7.260444e-02*S279'
.param V9_part29='V9_part28+7.281833e-02*S280+5.709753e-01*S281+2.834645e-01*S282+5.750559e-02*S283+2.886685e-01*S284+1.516835e-01*S285+(-1.024907e+00)*S286+4.972704e-03*S287+(-7.369623e-01)*S288+3.883173e-02*S289'
.param V9_part30='V9_part29+1.823483e-02*S290+2.139589e+00*S291+5.908608e-02*S292+2.668346e-01*S293+1.693831e+00*S294+6.023535e-02*S295+2.386734e-01*S296+(-7.524492e-03)*S297+4.134533e-02*S298+2.669901e-01*S299'
.param V9_part31='V9_part30+1.893379e-01*S300+(-2.910648e-01)*S301+7.435513e-03*S302+4.200636e-02*S303+(-1.690614e+00)*S304+1.423730e-02*S305+8.263583e-02*S306+2.209357e-02*S307+6.861541e-01*S308+5.765257e-02*S309'
.param V9='V9_part31+2.792018e-02*S310+7.555751e-01*S311+4.290443e-02*S312+2.977914e-02*S313+1.043746e+00*S314'
.param V10_part1='1.803836e-02*S0+3.348002e-02*S1+7.019264e-02*S2+8.467276e-01*S3+2.475219e-02*S4+6.226767e-02*S5+8.937601e-02*S6+4.083229e-02*S7+5.895818e-02*S8+1.551991e-01*S9'
.param V10_part2='V10_part1+7.531741e-02*S10+1.848411e-01*S11+3.364482e-02*S12+4.138637e-02*S13+4.447140e-02*S14+6.890835e-05*S15+4.936495e-02*S16+3.699359e-01*S17+9.259455e-02*S18+5.047758e-02*S19'
.param V10_part3='V10_part2+1.095220e-01*S20+1.521455e-01*S21+(-1.197497e-03)*S22+1.268573e-01*S23+2.725601e-01*S24+1.044503e-01*S25+1.092056e-02*S26+3.087964e-02*S27+9.202150e-03*S28+1.158187e-01*S29'
.param V10_part4='V10_part3+1.585941e-02*S30+2.564755e+00*S31+1.142425e-02*S32+1.725080e-02*S33+(-5.044872e-04)*S34+2.790402e-01*S35+4.735854e-01*S36+1.652297e-01*S37+2.793447e+00*S38+8.053506e-01*S39'
.param V10_part5='V10_part4+4.130690e-02*S40+7.719695e-02*S41+2.314562e+00*S42+1.205944e-01*S43+1.811917e-01*S44+7.468037e-02*S45+8.928758e-01*S46+2.983027e-02*S47+2.755406e-02*S48+1.652573e-01*S49'
.param V10_part6='V10_part5+3.918450e-02*S50+1.767588e-01*S51+2.064830e+00*S52+2.029806e+00*S53+2.568502e-01*S54+1.996476e+00*S55+2.287444e+00*S56+3.420783e-01*S57+6.752336e-01*S58+2.750242e+00*S59'
.param V10_part7='V10_part6+7.803664e-02*S60+1.276251e-02*S61+2.979075e-02*S62+2.623309e-01*S63+4.033068e-02*S64+3.125484e-02*S65+4.641976e-01*S66+4.859730e-01*S67+1.164203e-01*S68+1.139887e+00*S69'
.param V10_part8='V10_part7+(-9.546846e-03)*S70+1.319041e-01*S71+2.152718e-03*S72+3.570121e-02*S73+2.616669e-01*S74+3.965052e-02*S75+(-2.640718e-03)*S76+(-4.977824e-02)*S77+5.735308e-02*S78+1.548850e-02*S79'
.param V10_part9='V10_part8+9.473546e-02*S80+(-1.109650e-01)*S81+1.130495e-01*S82+1.764645e-01*S83+(-3.303922e-02)*S84+(-4.411344e-03)*S85+1.656683e-01*S86+(-9.451784e-02)*S87+6.736807e-02*S88+(-4.965946e-02)*S89'
.param V10_part10='V10_part9+(-1.418825e-01)*S90+1.875455e-01*S91+(-1.504741e-01)*S92+8.684345e-01*S93+(-1.043568e-01)*S94+4.840438e-01*S95+1.840542e+00*S96+4.314021e-01*S97+2.635371e-01*S98+7.503308e+00*S99'
.param V10_part11='V10_part10+5.777723e-01*S100+3.806844e-01*S101+3.675422e+00*S102+4.751219e-01*S103+5.080641e-01*S104+2.182244e-01*S105+2.085248e-01*S106+5.150938e-01*S107+6.123708e-01*S108+(-7.731254e-01)*S109'
.param V10_part12='V10_part11+(-6.222670e-02)*S110+(-6.871870e+01)*S111+(-1.322083e+00)*S112+(-2.515023e-02)*S113+(-1.434240e+02)*S114+2.696990e-02*S115+7.336526e-01*S116+4.024890e-03*S117+9.907187e-02*S118+1.189323e+00*S119'
.param V10_part13='V10_part12+3.785055e-02*S120+2.129009e+00*S121+(-5.597181e-02)*S122+(-6.920900e-02)*S123+(-7.044672e-01)*S124+9.942094e-03*S125+2.118092e-02*S126+(-4.000934e-03)*S127+2.386982e-03*S128+(-7.638527e-03)*S129'
.param V10_part14='V10_part13+(-1.684617e-02)*S130+(-4.368476e-02)*S131+(-4.986111e-02)*S132+1.010237e-02*S133+(-5.294529e-02)*S134+1.168190e-01*S135+(-6.213942e-02)*S136+(-6.403770e-02)*S137+2.873900e-01*S138+(-1.950588e-02)*S139'
.param V10_part15='V10_part14+(-5.467793e-03)*S140+3.094125e-02*S141+4.898545e-01*S142+7.809619e-01*S143+8.508805e-01*S144+9.824456e-01*S145+(-6.223437e-03)*S146+7.665503e-01*S147+(-2.521435e-01)*S148+(-1.180202e-01)*S149'
.param V10_part16='V10_part15+(-8.023409e-03)*S150+2.410869e-02*S151+4.021801e-01*S152+1.061674e+00*S153+1.174902e-01*S154+1.854922e+00*S155+(-2.839584e-02)*S156+(-5.237736e-02)*S157+2.057453e-01*S158+1.282899e-02*S159'
.param V10_part17='V10_part16+(-7.855343e-02)*S160+(-4.761299e-02)*S161+(-9.096912e-03)*S162+(-9.341747e-02)*S163+1.272277e+00*S164+1.751591e-03*S165+1.128177e-01*S166+1.615368e-02*S167+(-1.370589e+00)*S168+(-4.587959e-02)*S169'
.param V10_part18='V10_part17+(-3.048796e-03)*S170+(-3.523315e-02)*S171+3.692868e-03*S172+2.500236e-01*S173+(-8.515814e-03)*S174+(-5.249474e-03)*S175+5.369489e-01*S176+(-2.281302e-02)*S177+(-1.903434e-02)*S178+9.367662e-01*S179'
.param V10_part19='V10_part18+1.104336e+00*S180+2.911904e-02*S181+(-2.111816e-01)*S182+(-1.560547e-02)*S183+(-4.486744e-02)*S184+(-4.318655e-02)*S185+(-1.571165e-02)*S186+(-8.363121e-02)*S187+3.220000e-01*S188+(-2.133472e-02)*S189'
.param V10_part20='V10_part19+(-2.203950e-02)*S190+7.431437e-01*S191+2.468831e-01*S192+(-1.246486e-01)*S193+9.479614e-01*S194+4.052810e-02*S195+(-1.626925e-01)*S196+(-1.843409e-02)*S197+4.156778e-01*S198+7.516490e-02*S199'
.param V10_part21='V10_part20+(-6.233790e-02)*S200+(-7.237627e-02)*S201+1.372515e-01*S202+(-5.421931e-02)*S203+(-8.695694e-03)*S204+1.505243e+00*S205+(-9.618714e-02)*S206+2.747367e-02*S207+2.928507e+00*S208+(-6.869506e-02)*S209'
.param V10_part22='V10_part21+2.718154e-03*S210+1.188851e+00*S211+1.640347e+00*S212+(-1.561415e-03)*S213+(-6.959011e-02)*S214+2.181438e+00*S215+(-7.181307e-03)*S216+1.399588e-02*S217+2.445289e+00*S218+3.716096e-01*S219'
.param V10_part23='V10_part22+(-4.792294e-02)*S220+4.745128e-02*S221+(-1.565596e-02)*S222+(-3.011842e-02)*S223+(-5.134796e-02)*S224+6.487872e-03*S225+1.320943e+00*S226+7.558543e-02*S227+(-3.172861e-03)*S228+2.364677e-02*S229'
.param V10_part24='V10_part23+1.741194e-01*S230+6.129276e-01*S231+(-6.927268e-01)*S232+9.848693e-01*S233+9.890963e-01*S234+(-1.187366e-01)*S235+1.048193e+00*S236+(-3.175542e-02)*S237+(-1.156875e-01)*S238+4.807298e-01*S239'
.param V10_part25='V10_part24+9.245962e-04*S240+4.725932e-02*S241+1.032745e-01*S242+(-6.744339e-02)*S243+2.158450e-02*S244+(-3.903558e-02)*S245+(-3.856984e-02)*S246+4.927832e-03*S247+5.292193e-01*S248+5.283059e-01*S249'
.param V10_part26='V10_part25+(-1.351632e-01)*S250+7.773386e-01*S251+(-1.457092e-01)*S252+(-1.509710e-01)*S253+8.375383e-01*S254+1.124978e+00*S255+(-1.039280e+00)*S256+4.068256e-01*S257+1.168179e+00*S258+1.959684e+00*S259'
.param V10_part27='V10_part26+3.398175e-01*S260+(-2.978959e-02)*S261+(-2.497999e-02)*S262+(-1.141510e-01)*S263+6.833679e-01*S264+(-4.954435e-02)*S265+1.820307e+00*S266+(-1.962823e-02)*S267+(-1.669201e-01)*S268+1.316421e+00*S269'
.param V10_part28='V10_part27+(-6.185118e-02)*S270+(-3.365185e-01)*S271+1.368287e-01*S272+3.379491e-01*S273+(-1.642054e+00)*S274+2.220960e-01*S275+1.028407e+00*S276+3.980912e-03*S277+1.919125e+00*S278+(-3.006426e-02)*S279'
.param V10_part29='V10_part28+(-3.858290e-02)*S280+2.338247e+00*S281+2.742772e+00*S282+(-9.935775e-02)*S283+1.652799e+00*S284+2.285417e-02*S285+1.846757e+00*S286+(-4.525073e-02)*S287+1.039400e-01*S288+(-2.363336e-02)*S289'
.param V10_part30='V10_part29+5.714831e-02*S290+4.003821e-01*S291+1.229242e-02*S292+4.488961e-01*S293+2.940482e-01*S294+(-6.307744e-03)*S295+8.740221e-01*S296+4.909495e-02*S297+(-9.814243e-02)*S298+9.030913e-01*S299'
.param V10_part31='V10_part30+(-5.797051e-02)*S300+(-7.547741e-02)*S301+(-9.852222e-02)*S302+(-2.300035e-02)*S303+2.604221e+00*S304+(-1.194346e-01)*S305+(-5.086564e-03)*S306+(-1.023135e-01)*S307+1.621533e+00*S308+(-2.466375e-02)*S309'
.param V10='V10_part31+(-1.280753e-01)*S310+1.667636e+00*S311+(-2.087482e-02)*S312+(-1.179157e-01)*S313+1.729570e+00*S314'
.param V11_part1='1.128795e-01*S0+1.880726e-01*S1+1.729492e-01*S2+8.749661e-02*S3+1.711577e-01*S4+7.593981e-02*S5+1.465082e-01*S6+1.363331e-01*S7+1.562691e-01*S8+1.517298e-01*S9'
.param V11_part2='V11_part1+1.575155e-01*S10+3.673415e-02*S11+1.303696e-01*S12+1.258415e-01*S13+1.106604e-01*S14+1.261340e+00*S15+2.539743e-01*S16+(-1.076107e-01)*S17+1.786619e-01*S18+2.258811e-01*S19'
.param V11_part3='V11_part2+2.364282e-01*S20+2.365323e-01*S21+4.495339e-01*S22+1.185885e-01*S23+2.807503e-01*S24+2.129036e-01*S25+3.312961e-01*S26+2.032026e-01*S27+1.755820e-01*S28+1.832524e-01*S29'
.param V11_part4='V11_part3+3.176661e-01*S30+(-8.375515e-01)*S31+3.437044e-01*S32+3.516817e-01*S33+4.070379e-01*S34+2.893612e-01*S35+7.801402e+00*S36+3.001211e-01*S37+3.682594e+00*S38+7.105164e+00*S39'
.param V11_part5='V11_part4+3.487808e-01*S40+2.629565e-01*S41+7.873413e+00*S42+3.568619e-01*S43+2.920455e-01*S44+4.328564e-01*S45+(-2.074707e-01)*S46+3.516624e-01*S47+4.780031e-01*S48+3.498717e+00*S49'
.param V11_part6='V11_part5+3.757849e-01*S50+1.329800e+00*S51+2.476764e+00*S52+7.632096e-01*S53+6.169927e-01*S54+2.325129e+00*S55+7.840737e-01*S56+1.133767e+00*S57+3.236578e-01*S58+7.660924e-01*S59'
.param V11_part7='V11_part6+5.623305e-01*S60+4.903095e-01*S61+7.700316e-01*S62+7.611919e-01*S63+1.510324e+00*S64+9.163399e-01*S65+9.165675e-01*S66+2.080073e+00*S67+5.720610e-01*S68+1.157898e+00*S69'
.param V11_part8='V11_part7+6.490988e-01*S70+6.107881e-01*S71+7.463001e-01*S72+6.765131e-01*S73+6.427154e-01*S74+2.094249e-01*S75+2.024735e-01*S76+2.257278e+00*S77+2.420879e-01*S78+2.007836e-01*S79'
.param V11_part9='V11_part8+1.969724e-01*S80+9.647100e-01*S81+2.025226e-01*S82+1.781892e-01*S83+6.649532e-01*S84+4.822298e-01*S85+1.546589e-01*S86+7.435916e-01*S87+2.207713e-01*S88+9.966722e-01*S89'
.param V11_part10='V11_part9+3.668433e+00*S90+6.251719e+00*S91+8.573021e+00*S92+1.494715e+01*S93+4.790204e+00*S94+6.660493e+00*S95+1.886704e+01*S96+7.891589e+00*S97+7.436024e-01*S98+1.749604e+01*S99'
.param V11_part11='V11_part10+1.059473e+00*S100+8.030211e-01*S101+2.546285e+01*S102+9.434939e-01*S103+8.531347e-01*S104+1.506566e+01*S105+9.298333e+00*S106+6.688715e+00*S107+2.125238e+01*S108+1.143987e+01*S109'
.param V11_part12='V11_part11+2.384538e+00*S110+4.879141e+01*S111+1.353932e+01*S112+1.880907e+00*S113+1.205131e+02*S114+1.199419e+00*S115+9.246224e-01*S116+1.406297e+00*S117+1.223234e+00*S118+8.045547e-01*S119'
.param V11_part13='V11_part12+1.203307e+00*S120+1.003341e+01*S121+2.166686e+00*S122+4.025016e+00*S123+7.830550e+00*S124+1.157387e+00*S125+1.463633e+00*S126+1.357374e+00*S127+1.231068e+00*S128+1.606526e+00*S129'
.param V11_part14='V11_part13+1.434803e+00*S130+1.327081e+00*S131+1.782705e+00*S132+1.473639e+00*S133+1.389737e+00*S134+7.185694e-01*S135+2.382069e+00*S136+4.266454e+00*S137+9.260820e-01*S138+2.746127e+00*S139'
.param V11_part15='V11_part14+6.389932e-01*S140+7.830539e-01*S141+2.327127e+00*S142+1.696794e+00*S143+1.058556e+00*S144+1.500804e+00*S145+1.377111e+00*S146+1.082278e+00*S147+1.521389e+00*S148+1.267197e+00*S149'
.param V11_part16='V11_part15+1.747036e+00*S150+1.618867e+00*S151+1.030531e+01*S152+1.966542e+00*S153+1.854772e+00*S154+1.074179e+01*S155+2.136051e+00*S156+1.856187e+00*S157+4.266391e+00*S158+2.138623e+00*S159'
.param V11_part17='V11_part16+1.962750e+00*S160+1.844235e+00*S161+2.205307e+00*S162+2.057202e+00*S163+1.377646e+00*S164+1.865929e+00*S165+2.067623e+00*S166+1.607795e+00*S167+2.759534e+01*S168+1.956999e+00*S169'
.param V11_part18='V11_part17+1.770696e+00*S170+2.468903e+00*S171+2.058410e+00*S172+2.176161e+00*S173+2.513701e+00*S174+2.130776e+00*S175+2.594976e+00*S176+2.634667e+00*S177+2.272007e+00*S178+2.360651e+00*S179'
.param V11_part19='V11_part18+2.152339e+00*S180+2.089345e+00*S181+5.089037e+00*S182+2.458753e+00*S183+2.313689e+00*S184+2.107009e+00*S185+2.634878e+00*S186+2.472797e+00*S187+2.162679e+00*S188+2.833461e+00*S189'
.param V11_part20='V11_part19+2.453348e+00*S190+2.608595e+00*S191+3.191742e+00*S192+2.640212e+00*S193+2.493979e+00*S194+1.366988e+00*S195+5.754586e+00*S196+1.281156e+00*S197+1.794752e+00*S198+1.644474e+00*S199'
.param V11_part21='V11_part20+1.490070e+00*S200+2.088798e+00*S201+1.665131e+00*S202+1.566074e+00*S203+1.792200e+00*S204+2.399779e+00*S205+1.672386e+00*S206+1.930211e+00*S207+2.484102e+00*S208+1.778205e+00*S209'
.param V11_part22='V11_part21+2.627276e+00*S210+2.128539e+00*S211+1.358860e+01*S212+2.951047e+00*S213+3.076565e+00*S214+1.152979e+01*S215+3.323184e+00*S216+2.881040e+00*S217+1.047820e+01*S218+3.365811e+00*S219'
.param V11_part23='V11_part22+3.080716e+00*S220+2.638475e+00*S221+3.608349e+00*S222+3.188684e+00*S223+3.134152e+00*S224+2.970833e+00*S225+3.037030e+00*S226+2.635630e+00*S227+3.430673e+00*S228+2.912905e+00*S229'
.param V11_part24='V11_part23+2.775659e+00*S230+3.682310e+00*S231+5.058730e+00*S232+2.909004e+00*S233+4.077530e+00*S234+3.471443e+00*S235+3.235241e+00*S236+4.013349e+00*S237+3.604222e+00*S238+3.204353e+00*S239'
.param V11_part25='V11_part24+3.770144e+00*S240+2.899984e+00*S241+2.893143e+00*S242+4.043001e+00*S243+3.223311e+00*S244+3.322325e+00*S245+5.286631e+00*S246+3.515561e+00*S247+3.331794e+00*S248+4.693826e+00*S249'
.param V11_part26='V11_part25+3.798799e+00*S250+3.478461e+00*S251+4.799100e+00*S252+3.964573e+00*S253+3.682184e+00*S254+2.460227e+00*S255+1.370780e+01*S256+4.378496e+00*S257+2.696767e+00*S258+3.398262e+00*S259'
.param V11_part27='V11_part26+5.918616e+00*S260+2.979663e+00*S261+2.602022e+00*S262+2.707559e+00*S263+3.261303e+00*S264+2.741260e+00*S265+3.443578e+00*S266+3.167647e+00*S267+2.941738e+00*S268+2.853134e+00*S269'
.param V11_part28='V11_part27+4.365234e+00*S270+4.606821e+00*S271+3.414272e+00*S272+4.812828e+00*S273+7.138224e+00*S274+3.620599e+00*S275+5.064450e+00*S276+4.122409e+00*S277+4.469792e+00*S278+5.219227e+00*S279'
.param V11_part29='V11_part28+4.341149e+00*S280+4.705433e+00*S281+5.491576e+00*S282+4.577846e+00*S283+4.364401e+00*S284+4.837372e+00*S285+4.727275e+00*S286+3.911757e+00*S287+5.346268e+00*S288+4.282252e+00*S289'
.param V11_part30='V11_part29+4.028407e+00*S290+5.123603e+00*S291+4.599376e+00*S292+4.306722e+00*S293+5.280983e+00*S294+4.823075e+00*S295+4.616363e+00*S296+5.887839e+00*S297+5.066289e+00*S298+4.702329e+00*S299'
.param V11_part31='V11_part30+3.948510e+00*S300+4.323327e+00*S301+3.510723e+00*S302+4.101878e+00*S303+5.049982e+00*S304+3.741202e+00*S305+4.320538e+00*S306+3.901767e+00*S307+4.400754e+00*S308+4.667243e+00*S309'
.param V11='V11_part31+4.124292e+00*S310+4.321145e+00*S311+4.906854e+00*S312+4.285597e+00*S313+4.357766e+00*S314'
.param V12_part1='(-1.855148e-02)*S0+7.341833e-03*S1+5.673249e-03*S2+(-1.099841e+00)*S3+(-6.775772e-03)*S4+(-8.245281e-03)*S5+(-1.432541e-01)*S6+(-2.298255e-02)*S7+(-1.464793e-02)*S8+(-2.195376e-01)*S9'
.param V12_part2='V12_part1+(-4.533423e-02)*S10+(-2.299287e-02)*S11+(-7.974861e-02)*S12+(-4.059443e-02)*S13+(-1.982818e-02)*S14+6.956115e-01*S15+(-1.641553e-02)*S16+(-3.875601e-02)*S17+(-1.237029e-01)*S18+(-3.124405e-02)*S19'
.param V12_part3='V12_part2+(-2.676701e-02)*S20+(-2.707824e-01)*S21+(-2.505351e-02)*S22+(-1.969165e-02)*S23+(-4.894747e-01)*S24+(-6.900062e-02)*S25+(-1.468135e-02)*S26+(-1.297309e-01)*S27+(-3.839092e-02)*S28+(-3.955582e-02)*S29'
.param V12_part4='V12_part3+(-2.190599e-02)*S30+(-6.588157e-01)*S31+2.418053e-02*S32+(-5.899558e-02)*S33+1.852327e-03*S34+(-3.936046e-02)*S35+(-2.615931e+00)*S36+(-8.224347e-02)*S37+(-1.651436e+00)*S38+(-2.075839e+00)*S39'
.param V12_part5='V12_part4+(-5.443105e-02)*S40+(-2.901621e-02)*S41+(-5.552713e+00)*S42+(-8.375759e-02)*S43+(-4.121588e-02)*S44+(-5.568571e-02)*S45+(-1.232543e-01)*S46+2.991389e-02*S47+(-6.585423e-02)*S48+(-1.847502e-02)*S49'
.param V12_part6='V12_part5+1.057332e-02*S50+2.153148e+00*S51+(-5.734061e-01)*S52+5.890114e-02*S53+(-3.706964e-01)*S54+(-6.726732e-01)*S55+5.560207e-02*S56+2.182457e-01*S57+(-1.036132e-01)*S58+2.413933e-02*S59'
.param V12_part7='V12_part6+(-5.731645e-02)*S60+3.638362e-02*S61+1.024548e-01*S62+(-3.939651e-01)*S63+(-1.769647e-03)*S64+1.503718e-01*S65+(-8.096639e-01)*S66+(-5.931836e-01)*S67+2.334116e-02*S68+(-1.305863e+00)*S69'
.param V12_part8='V12_part7+(-5.186807e-02)*S70+1.453910e-02*S71+(-3.023365e-01)*S72+(-9.390626e-02)*S73+(-1.890641e-03)*S74+(-5.618126e-02)*S75+6.648412e-03*S76+2.989483e-01*S77+(-1.080584e-01)*S78+(-8.832174e-03)*S79'
.param V12_part9='V12_part8+(-4.971323e-03)*S80+1.527201e+00*S81+(-5.587199e-02)*S82+(-3.224073e-02)*S83+1.004229e+00*S84+(-3.648171e-02)*S85+(-2.871603e-02)*S86+1.335015e+00*S87+(-4.562078e-02)*S88+(-2.399830e-02)*S89'
.param V12_part10='V12_part9+1.954772e+00*S90+3.171756e-01*S91+3.379096e-01*S92+(-4.157632e+00)*S93+1.604377e-01*S94+(-4.424666e-02)*S95+(-1.257914e+01)*S96+8.548652e-01*S97+1.553278e-02*S98+(-2.652781e+01)*S99'
.param V12_part11='V12_part10+(-4.022645e-03)*S100+(-6.290672e-03)*S101+(-2.696356e+01)*S102+(-1.852973e-01)*S103+(-6.519213e-02)*S104+(-2.709435e-01)*S105+5.594548e+00*S106+2.684953e+00*S107+(-4.192512e+00)*S108+1.838583e+00*S109'
.param V12_part12='V12_part11+2.679447e-01*S110+8.194353e+02*S111+1.932578e+00*S112+1.696854e-01*S113+9.766771e+02*S114+(-7.362284e-02)*S115+2.761762e-02*S116+(-4.515414e-01)*S117+(-1.075532e-01)*S118+1.117162e-01*S119'
.param V12_part13='V12_part12+1.192972e-01*S120+(-2.148788e+00)*S121+3.376311e-01*S122+7.056878e+00*S123+1.418491e+00*S124+1.655742e-01*S125+(-1.883205e-01)*S126+3.984220e-02*S127+1.279578e-01*S128+(-3.172886e-01)*S129'
.param V12_part14='V12_part13+(-3.936839e-02)*S130+1.012999e-01*S131+(-4.752977e-01)*S132+(-1.555618e-01)*S133+5.050747e-02*S134+(-9.511821e-02)*S135+1.198584e-01*S136+2.640776e-01*S137+(-4.355731e-01)*S138+(-2.097959e-02)*S139'
.param V12_part15='V12_part14+3.963438e-02*S140+(-1.724044e-01)*S141+(-7.187960e-01)*S142+(-8.833400e-02)*S143+(-1.427775e+00)*S144+(-1.073100e+00)*S145+2.364016e-02*S146+(-1.112217e+00)*S147+9.845659e-01*S148+3.590203e-02*S149'
.param V12_part16='V12_part15+2.851437e-01*S150+3.219509e-01*S151+4.450777e-01*S152+(-9.386854e-01)*S153+1.892703e-01*S154+(-9.855516e-01)*S155+(-6.986701e-02)*S156+1.900574e-01*S157+3.308065e-01*S158+(-3.457138e-01)*S159'
.param V12_part17='V12_part16+9.425377e-02*S160+2.418016e-01*S161+(-7.502139e-01)*S162+(-1.237497e-02)*S163+(-9.224830e-02)*S164+2.696886e-01*S165+3.942702e-01*S166+4.293620e-01*S167+(-4.699743e+00)*S168+2.843675e-01*S169'
.param V12_part18='V12_part17+4.020472e-01*S170+1.133123e-02*S171+1.935075e-01*S172+8.459652e-02*S173+(-3.453352e-01)*S174+7.484485e-05*S175+(-1.429588e-01)*S176+(-6.050224e-01)*S177+(-5.863048e-02)*S178+(-3.229361e-01)*S179'
.param V12_part19='V12_part18+(-5.480732e-01)*S180+5.323992e-01*S181+1.029002e+00*S182+2.622252e-01*S183+4.626575e-01*S184+5.593545e-01*S185+(-1.924875e-02)*S186+3.544151e-01*S187+9.950720e-02*S188+(-3.278596e-01)*S189'
.param V12_part20='V12_part19+1.397414e-01*S190+(-2.213819e-01)*S191+(-7.749767e-01)*S192+9.711227e-02*S193+(-3.816304e-01)*S194+1.686466e-01*S195+8.694701e-01*S196+2.906572e-01*S197+(-5.228062e-01)*S198+1.069471e-01*S199'
.param V12_part21='V12_part20+2.768491e-01*S200+(-9.771587e-03)*S201+(-3.141646e-02)*S202+2.497790e-01*S203+(-4.300483e-01)*S204+(-1.368328e+00)*S205+2.395119e-01*S206+(-5.010642e-01)*S207+(-2.701117e+00)*S208+1.808366e-01*S209'
.param V12_part22='V12_part21+5.562879e-01*S210+8.799976e-02*S211+5.873931e-01*S212+2.642387e-01*S213+4.913636e-01*S214+(-1.336826e-01)*S215+1.144660e-01*S216+4.577519e-01*S217+(-7.315378e-01)*S218+(-1.392057e+00)*S219'
.param V12_part23='V12_part22+3.255754e-01*S220+4.616016e-01*S221+(-6.637405e-01)*S222+1.049144e-01*S223+5.651660e-01*S224+6.359521e-01*S225+1.436336e-01*S226+6.976284e-01*S227+6.073385e-01*S228+6.165080e-01*S229'
.param V12_part24='V12_part23+5.477751e-01*S230+1.575981e+00*S231+6.040899e+00*S232+3.367608e-02*S233+5.066461e-01*S234+5.772879e-01*S235+(-2.031234e-01)*S236+(-6.146080e-01)*S237+3.477620e-01*S238+(-1.131446e-02)*S239'
.param V12_part25='V12_part24+1.397716e+00*S240+8.819275e-01*S241+8.119128e-01*S242+1.075813e+00*S243+7.430785e-01*S244+1.299201e+00*S245+6.292459e-01*S246+7.261524e-01*S247+3.214342e-01*S248+(-1.693344e-01)*S249'
.param V12_part26='V12_part25+7.132511e-01*S250+3.689842e-02*S251+(-2.170416e-01)*S252+4.963459e-01*S253+(-7.317844e-02)*S254+(-5.689207e-01)*S255+2.731511e+00*S256+1.162082e+00*S257+(-8.191740e-01)*S258+(-8.825085e-01)*S259'
.param V12_part27='V12_part26+1.567149e+00*S260+2.611795e-02*S261+3.346517e-01*S262+7.820898e-01*S263+1.607750e-01*S264+2.040607e-01*S265+(-6.620242e-01)*S266+(-7.819861e-01)*S267+1.717612e-01*S268+(-5.850609e-01)*S269'
.param V12_part28='V12_part27+1.900560e+00*S270+4.634524e+00*S271+1.126769e+00*S272+1.437147e+00*S273+1.212915e+01*S274+9.464944e-01*S275+1.525541e+00*S276+8.511796e-01*S277+(-2.606159e-01)*S278+1.657073e-01*S279'
.param V12_part29='V12_part28+6.719064e-01*S280+(-6.990474e-01)*S281+(-1.032230e-02)*S282+6.541491e-01*S283+(-3.540014e-01)*S284+2.246708e+00*S285+6.634454e-01*S286+1.987918e+00*S287+1.246031e+00*S288+1.632886e+00*S289'
.param V12_part30='V12_part29+1.770572e+00*S290+(-8.714068e-01)*S291+1.257595e+00*S292+8.518901e-01*S293+(-1.159634e+00)*S294+1.032045e+00*S295+3.735214e-01*S296+(-2.640875e-01)*S297+9.331956e-01*S298+1.921187e-01*S299'
.param V12_part31='V12_part30+1.653865e+00*S300+1.198993e+00*S301+1.641296e+00*S302+9.165653e-01*S303+(-5.147545e-01)*S304+1.574133e+00*S305+3.585570e-01*S306+1.035513e+00*S307+(-1.668585e-02)*S308+(-1.033914e-02)*S309'
.param V12='V12_part31+8.376967e-01*S310+(-2.839322e-01)*S311+(-5.225133e-01)*S312+5.805843e-01*S313+(-4.231050e-01)*S314'
.param V13_part1='3.960489e-02*S0+5.748354e-02*S1+9.604912e-02*S2+6.060503e-02*S3+5.022459e-02*S4+3.220476e-02*S5+4.318907e-02*S6+6.426914e-02*S7+7.990330e-02*S8+4.389363e-02*S9'
.param V13_part2='V13_part1+8.768085e-02*S10+3.500020e-02*S11+5.061981e-02*S12+5.724133e-02*S13+5.551171e-02*S14+2.298835e-01*S15+6.607915e-02*S16+1.745002e-02*S17+3.445773e-02*S18+6.048187e-02*S19'
.param V13_part3='V13_part2+8.837784e-02*S20+4.037769e-02*S21+6.565139e-02*S22+2.442877e-02*S23+4.348406e-02*S24+8.506799e-02*S25+5.214976e-02*S26+3.512781e-02*S27+3.187936e-02*S28+6.911768e-02*S29'
.param V13_part4='V13_part3+3.185480e-02*S30+1.263718e-04*S31+3.754624e-02*S32+3.204911e-02*S33+3.590562e-02*S34+1.414713e-01*S35+8.882395e-01*S36+1.057436e-01*S37+1.412554e+00*S38+8.832397e-01*S39'
.param V13_part5='V13_part4+6.407781e-02*S40+4.993658e-02*S41+1.208685e+00*S42+9.284427e-02*S43+1.146678e-01*S44+3.427244e-02*S45+3.335106e-02*S46+3.244046e-02*S47+4.106986e-02*S48+4.088420e-01*S49'
.param V13_part6='V13_part5+3.260223e-02*S50+1.240918e-01*S51+1.165295e-01*S52+(-2.738250e+00)*S53+1.391091e-01*S54+9.515984e-02*S55+(-3.112243e+00)*S56+3.131277e-01*S57+(-1.660475e-01)*S58+(-3.663873e+00)*S59'
.param V13_part7='V13_part6+2.913924e-02*S60+3.051679e-02*S61+5.889744e-02*S62+3.440635e-02*S63+9.044552e-02*S64+8.603363e-02*S65+3.620240e-02*S66+1.037726e-01*S67+7.539601e-02*S68+(-1.378276e-03)*S69'
.param V13_part8='V13_part7+4.269333e-02*S70+9.500768e-02*S71+3.786848e-02*S72+6.946728e-02*S73+1.455536e-01*S74+8.143597e-03*S75+8.877253e-04*S76+3.124582e-01*S77+8.132006e-03*S78+1.568908e-02*S79'
.param V13_part9='V13_part8+3.511568e-03*S80+7.589921e-02*S81+7.822147e-03*S82+2.277726e-03*S83+4.460959e-02*S84+3.516906e-02*S85+4.656692e-02*S86+4.965388e-02*S87+3.518913e-02*S88+7.442814e-02*S89'
.param V13_part10='V13_part9+1.759162e-01*S90+2.898815e-01*S91+2.664791e-01*S92+5.769747e-01*S93+1.470320e-01*S94+3.615491e-01*S95+7.404366e-01*S96+5.785472e-01*S97+1.252078e-01*S98+1.696483e+00*S99'
.param V13_part11='V13_part10+2.847900e-01*S100+1.835163e-01*S101+3.998270e+00*S102+2.257554e-01*S103+2.655683e-01*S104+5.417682e-01*S105+3.950771e-01*S106+1.615248e-01*S107+6.419514e-01*S108+4.601176e-01*S109'
.param V13_part12='V13_part11+1.042617e-01*S110+2.231339e+00*S111+8.037192e-01*S112+1.219388e-01*S113+8.042377e+00*S114+4.643999e-02*S115+2.760448e-01*S116+4.016061e-02*S117+1.199380e-01*S118+4.514785e-01*S119'
.param V13_part13='V13_part12+3.476602e-02*S120+2.486837e-01*S121+5.910757e-02*S122+1.670633e-01*S123+1.997423e-01*S124+3.493189e-02*S125+3.239425e-02*S126+3.384059e-02*S127+3.584141e-02*S128+3.563162e-02*S129'
.param V13_part14='V13_part13+3.503896e-02*S130+3.635181e-02*S131+4.258419e-02*S132+3.520563e-02*S133+3.672185e-02*S134+6.761806e-03*S135+(-5.328974e-04)*S136+(-8.225685e-03)*S137+6.369909e-03*S138+(-3.995070e-03)*S139'
.param V13_part15='V13_part14+1.156828e-02*S140+2.204411e-02*S141+8.364531e-02*S142+3.353506e-02*S143+(-1.512513e-02)*S144+4.808247e-02*S145+3.649015e-02*S146+6.764976e-03*S147+1.718228e-02*S148+3.668863e-02*S149'
.param V13_part16='V13_part15+3.555005e-02*S150+3.599149e-02*S151+2.978796e-01*S152+(-5.060431e-03)*S153+4.002455e-02*S154+4.038182e-01*S155+3.940486e-02*S156+3.762644e-02*S157+1.571113e-01*S158+3.433033e-02*S159'
.param V13_part17='V13_part16+3.842394e-02*S160+4.226956e-02*S161+4.474036e-02*S162+3.592844e-02*S163+3.841746e-01*S164+3.937050e-02*S165+5.099781e-02*S166+4.031255e-02*S167+6.413623e-01*S168+4.187245e-02*S169'
.param V13_part18='V13_part17+4.230355e-02*S170+4.648042e-02*S171+4.071201e-02*S172+4.037482e-02*S173+4.175263e-02*S174+4.670394e-02*S175+3.691789e-02*S176+4.365986e-02*S177+4.319444e-02*S178+(-8.366571e-03)*S179'
.param V13_part19='V13_part18+2.632651e-02*S180+3.957444e-02*S181+9.270948e-02*S182+3.568034e-02*S183+3.967483e-02*S184+4.088929e-02*S185+3.403724e-02*S186+3.951136e-02*S187+4.355588e-02*S188+3.602037e-02*S189'
.param V13_part20='V13_part19+3.596597e-02*S190+2.848026e-02*S191+(-1.588040e-02)*S192+3.861102e-02*S193+1.600954e-02*S194+6.406173e-03*S195+1.055892e-02*S196+1.679166e-02*S197+(-7.570454e-03)*S198+1.562091e-02*S199'
.param V13_part21='V13_part20+2.281880e-02*S200+2.171640e-02*S201+1.345151e-02*S202+2.269556e-02*S203+1.498183e-02*S204+4.202394e-02*S205+1.938006e-02*S206+2.955171e-02*S207+3.594859e-02*S208+1.477832e-02*S209'
.param V13_part22='V13_part21+3.448660e-02*S210+(-6.373160e-03)*S211+3.020690e-01*S212+3.727957e-02*S213+3.234144e-02*S214+2.902483e-01*S215+3.759707e-02*S216+3.629576e-02*S217+2.942174e-01*S218+6.356081e-02*S219'
.param V13_part23='V13_part22+3.944514e-02*S220+4.969010e-02*S221+3.660523e-02*S222+3.963768e-02*S223+4.193595e-02*S224+4.199687e-02*S225+1.512093e-02*S226+4.883689e-02*S227+4.289285e-02*S228+4.477876e-02*S229'
.param V13_part24='V13_part23+4.273586e-02*S230+(-3.790022e-02)*S231+3.390964e-03*S232+5.273591e-02*S233+(-1.699697e-02)*S234+4.227894e-02*S235+3.799721e-02*S236+4.344457e-02*S237+4.318153e-02*S238+4.762516e-02*S239'
.param V13_part25='V13_part24+3.981538e-02*S240+3.853144e-02*S241+4.590756e-02*S242+4.777092e-02*S243+3.850521e-02*S244+3.732788e-02*S245+1.044886e-01*S246+3.715420e-02*S247+3.861545e-02*S248+(-3.197486e-02)*S249'
.param V13_part26='V13_part25+3.822600e-02*S250+4.427839e-02*S251+6.451423e-02*S252+3.959309e-02*S253+4.535238e-02*S254+(-2.155158e-02)*S255+3.611420e-02*S256+4.645822e-02*S257+(-1.529930e-02)*S258+2.499973e-02*S259'
.param V13_part27='V13_part26+6.417003e-02*S260+1.473721e-02*S261+1.701813e-02*S262+1.572285e-02*S263+6.125634e-02*S264+1.582918e-02*S265+(-1.891628e-02)*S266+2.428579e-02*S267+1.686511e-02*S268+(-2.844433e-02)*S269'
.param V13_part28='V13_part27+4.580054e-02*S270+4.673119e-02*S271+5.450241e-02*S272+6.362985e-04*S273+6.210074e-02*S274+4.977779e-02*S275+(-3.877198e-02)*S276+4.780439e-02*S277+7.155991e-03*S278+3.945401e-02*S279'
.param V13_part29='V13_part28+5.082258e-02*S280+(-2.749515e-03)*S281+(-4.600781e-02)*S282+4.814300e-02*S283+5.184397e-02*S284+4.850321e-02*S285+9.705874e-06*S286+5.489131e-02*S287+(-2.001233e-03)*S288+4.142426e-02*S289'
.param V13_part30='V13_part29+4.457650e-02*S290+7.297393e-02*S291+4.525315e-02*S292+6.565408e-02*S293+6.847901e-02*S294+4.369713e-02*S295+7.875598e-02*S296+2.847740e-02*S297+4.536213e-02*S298+8.085934e-02*S299'
.param V13_part31='V13_part30+1.201912e-02*S300+2.249367e-02*S301+2.595160e-02*S302+1.789343e-02*S303+4.746002e-02*S304+2.709832e-02*S305+1.657944e-02*S306+1.626163e-02*S307+(-2.383277e-02)*S308+1.543612e-02*S309'
.param V13='V13_part31+1.702611e-02*S310+(-2.964585e-02)*S311+6.264390e-03*S312+1.896933e-02*S313+(-5.376300e-02)*S314'
.param V14_part1='1.221134e-05*S0+(-1.077907e-04)*S1+(-3.212642e-04)*S2+1.759319e-03*S3+(-6.596567e-06)*S4+1.194755e-05*S5+7.432501e-05*S6+4.551625e-05*S7+5.140437e-04*S8+(-2.382235e-05)*S9'
.param V14_part2='V14_part1+5.530057e-05*S10+4.689811e-05*S11+5.184544e-05*S12+8.246008e-05*S13+(-4.869638e-05)*S14+2.914462e-03*S15+7.386763e-04*S16+(-1.085081e-03)*S17+7.007694e-04*S18+9.089244e-04*S19'
.param V14_part3='V14_part2+1.527104e-03*S20+7.762183e-04*S21+1.352756e-03*S22+1.154527e-03*S23+1.207024e-03*S24+8.921236e-04*S25+5.632960e-04*S26+5.450559e-04*S27+4.942579e-04*S28+3.575938e-04*S29'
.param V14_part4='V14_part3+1.914047e-03*S30+6.861553e-04*S31+3.012729e-03*S32+9.616584e-04*S33+1.759919e-03*S34+4.796770e-03*S35+(-3.794371e-02)*S36+1.764447e-03*S37+1.864844e-02*S38+(-1.326347e-01)*S39'
.param V14_part5='V14_part4+2.063698e-03*S40+1.512111e-03*S41+(-3.665700e-01)*S42+(-3.788041e-03)*S43+1.540746e-03*S44+1.797389e-03*S45+1.195687e-02*S46+3.659522e-03*S47+5.467217e-04*S48+2.035543e-02*S49'
.param V14_part6='V14_part5+3.532774e-03*S50+4.612995e-02*S51+(-5.390050e-01)*S52+1.280788e-02*S53+(-6.119951e-03)*S54+(-6.270840e-01)*S55+1.151089e-02*S56+(-1.366259e-02)*S57+(-1.257439e-03)*S58+1.100291e-02*S59'
.param V14_part7='V14_part6+2.325808e-03*S60+5.196962e-03*S61+1.076719e-02*S62+(-2.243207e-03)*S63+2.197506e-02*S64+1.678618e-02*S65+(-1.073740e-02)*S66+(-5.381734e-02)*S67+4.818561e-03*S68+(-1.019880e-01)*S69'
.param V14_part8='V14_part7+2.351123e-03*S70+6.129462e-03*S71+(-7.745230e-03)*S72+2.197150e-03*S73+(-5.680590e-03)*S74+1.521078e-03*S75+9.141175e-03*S76+1.813126e-01*S77+1.038904e-03*S78+(-2.413396e-03)*S79'
.param V14_part9='V14_part8+(-6.046292e-03)*S80+1.547980e-02*S81+(-2.076859e-03)*S82+(-7.699971e-03)*S83+1.037978e-02*S84+1.293443e-02*S85+(-1.398728e-02)*S86+3.976767e-03*S87+(-7.036913e-03)*S88+2.894974e-03*S89'
.param V14_part10='V14_part9+7.612496e-02*S90+1.966268e-01*S91+3.071068e-01*S92+5.823638e-01*S93+1.709759e-01*S94+2.338101e-01*S95+1.051976e+00*S96+2.688857e-01*S97+6.185844e-03*S98+1.691065e+00*S99'
.param V14_part11='V14_part10+8.539599e-04*S100+7.462503e-03*S101+1.100296e+00*S102+3.380211e-03*S103+9.122969e-03*S104+3.118455e-01*S105+2.893878e-02*S106+2.864954e-01*S107+3.170126e-01*S108+3.405495e-01*S109'
.param V14_part12='V14_part11+1.078705e-01*S110+1.632091e+01*S111+6.558399e-01*S112+8.582938e-02*S113+2.913392e+01*S114+2.926694e-03*S115+6.062788e-03*S116+(-1.488585e-02)*S117+4.808595e-03*S118+1.218314e-02*S119'
.param V14_part13='V14_part12+4.856689e-03*S120+(-2.964722e-01)*S121+1.064380e-01*S122+3.041313e-01*S123+3.383510e-01*S124+1.644940e-02*S125+(-1.253451e-03)*S126+8.539418e-03*S127+1.425795e-02*S128+(-1.265505e-02)*S129'
.param V14_part14='V14_part13+4.137266e-03*S130+1.234730e-02*S131+(-2.298788e-02)*S132+1.575394e-03*S133+9.184626e-03*S134+6.267503e-04*S135+6.188706e-02*S136+1.913322e-01*S137+(-4.243519e-03)*S138+7.628463e-02*S139'
.param V14_part15='V14_part14+1.046211e-02*S140+2.015641e-03*S141+(-3.096072e-02)*S142+(-1.753936e-01)*S143+(-2.376022e-02)*S144+(-1.466533e-02)*S145+(-9.891953e-03)*S146+(-2.239685e-02)*S147+(-1.662744e-02)*S148+(-4.504365e-04)*S149'
.param V14_part16='V14_part15+2.416757e-02*S150+3.082962e-02*S151+7.679358e-01*S152+(-6.722645e-02)*S153+1.632785e-02*S154+8.042230e-01*S155+(-5.132428e-03)*S156+1.681899e-02*S157+3.563575e-01*S158+(-2.966272e-02)*S159'
.param V14_part17='V14_part16+1.134866e-02*S160+2.075256e-02*S161+(-1.481086e-02)*S162+(-1.482500e-03)*S163+(-1.518454e-04)*S164+3.504105e-02*S165+2.517002e-02*S166+3.880422e-02*S167+1.428291e+00*S168+3.479955e-02*S169'
.param V14_part18='V14_part17+3.665475e-02*S170+1.095810e-04*S171+1.811583e-02*S172+1.517712e-01*S173+(-2.661918e-02)*S174+1.802153e-02*S175+2.096050e-01*S176+(-3.778869e-02)*S177+3.692162e-03*S178+2.308389e-01*S179'
.param V14_part19='V14_part18+(-5.674300e-02)*S180+4.430653e-02*S181+3.694184e-01*S182+1.420403e-02*S183+3.736580e-02*S184+3.757173e-02*S185+(-4.084874e-03)*S186+2.678398e-02*S187+1.319322e-01*S188+(-2.920250e-02)*S189'
.param V14_part20='V14_part19+9.426980e-03*S190+2.292759e-01*S191+(-1.112175e-01)*S192+7.797597e-03*S193+2.579420e-01*S194+3.787328e-03*S195+2.800011e-01*S196+2.668305e-02*S197+(-3.025714e-03)*S198+7.555298e-03*S199'
.param V14_part21='V14_part20+2.801315e-02*S200+(-9.282728e-04)*S201+(-1.530698e-03)*S202+2.489453e-02*S203+(-2.860276e-03)*S204+(-7.067150e-02)*S205+2.080482e-02*S206+(-7.864425e-02)*S207+(-1.075206e-01)*S208+2.165460e-02*S209'
.param V14_part22='V14_part21+5.426601e-02*S210+(-4.280566e-02)*S211+1.254832e+00*S212+3.400299e-02*S213+1.455114e-01*S214+1.200502e+00*S215+(-3.805505e-03)*S216+2.556973e-02*S217+9.709367e-01*S218+1.419187e-01*S219'
.param V14_part23='V14_part22+2.088781e-02*S220+4.651654e-02*S221+(-4.802696e-02)*S222+1.098025e-02*S223+5.149157e-02*S224+5.875194e-02*S225+(-7.066305e-02)*S226+1.520288e-01*S227+3.001284e-02*S228+6.478009e-02*S229'
.param V14_part24='V14_part23+1.503518e-01*S230+(-1.281637e-01)*S231+8.587953e-02*S232+3.029763e-01*S233+(-3.106768e-01)*S234+2.971485e-02*S235+3.163669e-01*S236+(-5.152758e-02)*S237+2.061118e-02*S238+2.316022e-01*S239'
.param V14_part25='V14_part24+7.559985e-02*S240+8.309155e-02*S241+1.760772e-01*S242+5.170002e-02*S243+7.367976e-02*S244+8.353136e-02*S245+(-1.140664e-04)*S246+4.573749e-02*S247+2.444753e-01*S248+(-1.886461e-01)*S249'
.param V14_part26='V14_part25+3.548980e-02*S250+2.345794e-01*S251+(-5.529461e-02)*S252+2.491965e-02*S253+2.741416e-01*S254+(-7.932662e-02)*S255+8.033528e-01*S256+(-8.744692e-02)*S257+(-1.218159e-01)*S258+(-1.121568e-01)*S259'
.param V14_part27='V14_part26+(-1.451815e-01)*S260+(-1.061063e-02)*S261+2.757908e-02*S262+5.054520e-02*S263+(-2.617307e-01)*S264+1.148491e-02*S265+5.342974e-01*S266+(-4.033823e-02)*S267+1.096540e-02*S268+3.073977e-01*S269'
.param V14_part28='V14_part27+1.026794e-01*S270+9.479285e-02*S271+2.082248e-01*S272+(-5.450150e-02)*S273+1.428858e-01*S274+2.274028e-01*S275+(-2.683899e-01)*S276+8.784171e-02*S277+5.995787e-01*S278+(-3.997633e-02)*S279'
.param V14_part29='V14_part28+7.687227e-02*S280+6.380245e-01*S281+(-7.251844e-01)*S282+4.254726e-02*S283+4.726755e-01*S284+1.157071e-01*S285+(-9.356888e-02)*S286+1.361104e-01*S287+7.505768e-02*S288+1.002053e-01*S289'
.param V14_part30='V14_part29+1.100804e-01*S290+2.554960e-01*S291+7.485360e-02*S292+3.422690e-01*S293+1.728388e-01*S294+5.578171e-02*S295+3.960472e-01*S296+(-9.385697e-02)*S297+4.595755e-02*S298+3.560313e-01*S299'
.param V14_part31='V14_part30+9.251578e-02*S300+2.764541e-01*S301+1.129829e-01*S302+3.904776e-02*S303+(-1.822542e-01)*S304+1.045279e-01*S305+6.195081e-03*S306+6.172763e-02*S307+6.977217e-01*S308+(-3.650312e-02)*S309'
.param V14='V14_part31+4.389882e-02*S310+6.560937e-01*S311+(-7.865064e-02)*S312+2.756327e-02*S313+7.103966e-01*S314'
.param V15_part1='1.427259e+00*S0+(-2.276345e-02)*S1+(-1.353969e-02)*S2+(-6.884894e-02)*S3+(-4.282060e-02)*S4+(-2.820995e-02)*S5+(-1.146172e-01)*S6+(-6.266566e-02)*S7+(-3.635169e-02)*S8+(-1.366961e-01)*S9'
.param V15_part2='V15_part1+(-8.100232e-02)*S10+(-4.655659e-02)*S11+(-1.714841e-01)*S12+(-1.013946e-01)*S13+(-6.350675e-02)*S14+(-5.445192e-02)*S15+(-2.021783e-02)*S16+(-4.284864e-03)*S17+(-1.182379e-01)*S18+(-4.862078e-02)*S19'
.param V15_part3='V15_part2+(-2.025959e-02)*S20+(-1.557935e-01)*S21+(-8.055074e-02)*S22+(-4.131776e-02)*S23+(-1.900249e-01)*S24+(-1.087795e-01)*S25+(-5.089089e-02)*S26+(-5.477265e-01)*S27+(-2.284957e-01)*S28+(-6.947858e-02)*S29'
.param V15_part4='V15_part3+(-1.503978e-01)*S30+3.090608e-02*S31+1.082005e-01*S32+(-2.629831e-01)*S33+1.632410e-02*S34+4.898271e-02*S35+(-1.623662e-01)*S36+(-7.621451e-02)*S37+4.531077e-02*S38+(-2.046532e-01)*S39'
.param V15_part5='V15_part4+(-1.440232e-01)*S40+(-8.496538e-02)*S41+(-2.634916e-01)*S42+(-1.365338e-01)*S43+(-5.657114e-02)*S44+(-1.734958e-01)*S45+4.836418e-02*S46+6.398777e+02*S47+(-2.007217e-01)*S48+(-8.520322e-03)*S49'
.param V15_part6='V15_part5+1.209769e+02*S50+(-2.186946e-01)*S51+(-5.982084e-02)*S52+(-1.267367e-02)*S53+(-2.580829e-01)*S54+(-1.079699e-01)*S55+(-5.207383e-02)*S56+(-3.095413e-01)*S57+(-2.057898e-01)*S58+(-9.594991e-02)*S59'
.param V15_part7='V15_part6+(-1.368236e-01)*S60+1.280531e-01*S61+1.529022e-01*S62+(-1.698469e-01)*S63+1.034602e-02*S64+9.286019e-02*S65+(-2.469546e-01)*S66+(-3.285701e-02)*S67+3.860714e-02*S68+(-3.125797e-01)*S69'
.param V15_part8='V15_part7+(-2.906542e-01)*S70+6.776376e-03*S71+(-8.936541e-01)*S72+(-3.092975e-01)*S73+(-2.549209e-02)*S74+(-1.141258e-01)*S75+3.035808e-03*S76+3.251604e-02*S77+(-1.777633e-01)*S78+(-4.571653e-02)*S79'
.param V15_part9='V15_part8+4.491990e-03*S80+(-1.697000e-01)*S81+(-1.010000e-01)*S82+(-1.373488e-02)*S83+(-2.237655e-01)*S84+(-1.126028e-01)*S85+(-1.933799e-02)*S86+(-2.923155e-01)*S87+(-1.615892e-01)*S88+(-3.953406e-02)*S89'
.param V15_part10='V15_part9+8.691925e-03*S90+1.829374e-01*S91+2.751051e-01*S92+(-3.708808e-02)*S93+1.685798e-01*S94+2.315429e-01*S95+(-1.917919e-01)*S96+5.440731e-02*S97+9.020732e-02*S98+(-2.996023e-01)*S99'
.param V15_part11='V15_part10+(-9.244580e-02)*S100+3.419088e-02*S101+(-4.355834e-01)*S102+(-1.742448e-01)*S103+(-7.349577e-03)*S104+1.068453e-01*S105+2.155047e-01*S106+2.345915e-01*S107+(-1.675280e-02)*S108+1.773385e-01*S109'
.param V15_part12='V15_part11+2.515329e-01*S110+(-2.065444e-01)*S111+6.914535e-02*S112+2.382941e-01*S113+(-4.762178e-01)*S114+7.472982e+03*S115+8.157292e-02*S116+(-4.874755e-01)*S117+(-3.383670e-01)*S118+1.756195e-01*S119'
.param V15_part13='V15_part12+(-1.088868e-02)*S120+2.945810e-01*S121+3.193873e-01*S122+(-1.105283e-01)*S123+1.901078e-01*S124+4.868236e+01*S125+(-6.862351e+00)*S126+1.173556e+01*S127+1.926574e+01*S128+1.000000e+04*S129'
.param V15_part14='V15_part13+7.802592e+00*S130+1.182647e+01*S131+3.534004e-02*S132+(-1.559770e+00)*S133+1.133661e+01*S134+(-7.911131e-02)*S135+1.240627e-01*S136+2.341412e-01*S137+(-1.598502e-01)*S138+5.769132e-02*S139'
.param V15_part15='V15_part14+1.706137e-01*S140+(-4.083705e-01)*S141+1.121504e-02*S142+1.037954e-01*S143+(-4.404469e-01)*S144+(-8.843283e-02)*S145+9.811839e-02*S146+(-5.997807e-01)*S147+(-3.123117e-01)*S148+3.757227e-03*S149'
.param V15_part16='V15_part15+3.943069e+01*S150+6.576160e+00*S151+4.699481e-01*S152+(-2.643845e-01)*S153+4.141205e-01*S154+3.720407e-01*S155+1.233824e-01*S156+1.434027e+02*S157+2.953031e-01*S158+1.000000e+04*S159'
.param V15_part17='V15_part16+2.318993e+02*S160+3.763089e+00*S161+(-2.186919e+00)*S162+4.184735e+02*S163+(-1.249687e-02)*S164+(-4.884243e-01)*S165+1.137300e+00*S166+8.980473e+00*S167+(-7.896137e-02)*S168+2.730002e-01*S169'
.param V15_part18='V15_part17+1.861045e+01*S170+(-1.004882e-01)*S171+2.443281e+00*S172+3.142474e-01*S173+1.840253e+01*S174+(-5.678811e-01)*S175+2.160429e-01*S176+(-4.991400e+00)*S177+(-2.401610e-01)*S178+4.320718e-02*S179'
.param V15_part19='V15_part18+3.217544e-02*S180+6.040135e+00*S181+4.986156e-01*S182+(-2.913027e+02)*S183+5.716269e+01*S184+1.876206e+01*S185+(-7.049640e+02)*S186+4.807767e+01*S187+2.121156e-01*S188+1.771119e+01*S189'
.param V15_part20='V15_part19+(-3.662008e+00)*S190+1.408761e-01*S191+(-1.219461e+00)*S192+4.002998e+02*S193+2.270510e-02*S194+2.558875e-02*S195+3.210654e-01*S196+6.313931e+00*S197+(-9.776244e-02)*S198+4.930204e-01*S199'
.param V15_part21='V15_part20+2.148725e+00*S200+(-4.290786e-01)*S201+(-2.049049e-01)*S202+4.086893e-01*S203+(-1.211336e+00)*S204+(-2.457390e-02)*S205+5.272036e-02*S206+(-1.001657e+00)*S207+(-1.306796e-01)*S208+(-1.065102e-01)*S209'
.param V15_part22='V15_part21+(-9.530980e-01)*S210+5.772626e-01*S211+5.394858e-01*S212+(-3.325055e+00)*S213+6.728252e-01*S214+4.448302e-01*S215+(-1.112536e+01)*S216+2.832497e-01*S217+2.912421e-01*S218+(-1.139574e+00)*S219'
.param V15_part23='V15_part22+(-1.438680e+00)*S220+1.018119e+00*S221+(-9.384872e+03)*S222+(-2.716782e+00)*S223+6.570189e+00*S224+(-4.770343e-01)*S225+6.006889e-01*S226+6.574812e-01*S227+(-7.503867e+00)*S228+5.522399e-01*S229'
.param V15_part24='V15_part23+5.895975e-01*S230+(-7.938983e-01)*S231+3.020950e-02*S232+3.457478e-01*S233+(-1.220714e+00)*S234+2.324500e+02*S235+2.615568e-01*S236+(-2.447471e+03)*S237+2.741728e+02*S238+1.686700e-01*S239'
.param V15_part25='V15_part24+3.662869e-01*S240+3.530249e-01*S241+8.096822e-01*S242+1.084774e-01*S243+1.147902e-01*S244+2.463063e+00*S245+(-6.810391e-01)*S246+(-3.455547e+00)*S247+3.836674e-01*S248+(-1.347824e+00)*S249'
.param V15_part26='V15_part25+1.102712e+02*S250+3.356171e-01*S251+(-3.258307e-02)*S252+5.229479e+02*S253+1.418836e-01*S254+4.770216e-03*S255+4.854676e-01*S256+4.977941e-01*S257+(-3.987809e-01)*S258+2.804073e-01*S259'
.param V15_part27='V15_part26+3.660115e-01*S260+1.428674e+01*S261+8.109203e+00*S262+3.948696e-01*S263+(-9.788662e-01)*S264+(-2.071206e-01)*S265+1.891444e-01*S266+(-1.784344e+01)*S267+4.786638e+02*S268+9.106482e-02*S269'
.param V15_part28='V15_part27+1.078159e+00*S270+3.662804e-01*S271+8.052004e-01*S272+(-5.311175e-01)*S273+3.205421e-01*S274+7.855876e-01*S275+(-1.040359e+00)*S276+1.142342e-01*S277+5.177416e-01*S278+(-1.335910e-01)*S279'
.param V15_part29='V15_part28+1.747342e-02*S280+4.567540e-01*S281+(-2.128075e+00)*S282+1.231736e+00*S283+2.955953e-01*S284+1.445824e-01*S285+7.524134e-01*S286+3.697072e+01*S287+(-6.175718e-01)*S288+2.800092e+01*S289'
.param V15_part30='V15_part29+(-5.740480e+03)*S290+(-1.287577e+00)*S291+(-7.150757e-01)*S292+5.477470e-01*S293+(-2.346239e+00)*S294+(-6.390659e+00)*S295+4.784003e-01*S296+(-4.620025e+00)*S297+1.736563e+02*S298+2.582959e-01*S299'
.param V15_part31='V15_part30+1.054616e+00*S300+7.387272e-01*S301+2.353119e+00*S302+(-8.829782e+00)*S303+5.524882e-01*S304+1.900487e+00*S305+6.022440e+01*S306+6.233877e+01*S307+4.341253e-01*S308+(-8.421050e+00)*S309'
.param V15='V15_part31+1.524709e+02*S310+3.829438e-01*S311+(-6.700946e+00)*S312+3.560490e+02*S313+2.878953e-01*S314'
.param V16_part1='(-1.017960e+00)*S0+1.278695e-01*S1+7.179593e-02*S2+1.905858e-01*S3+1.338456e-01*S4+8.059350e-02*S5+2.136647e-01*S6+1.413000e-01*S7+7.843385e-02*S8+2.004597e-01*S9'
.param V16_part2='V16_part1+1.399236e-01*S10+7.882016e-02*S11+1.996150e-01*S12+1.387240e-01*S13+8.429696e-02*S14+2.937463e-01*S15+1.911509e-01*S16+1.045217e-01*S17+3.461281e-01*S18+1.952646e-01*S19'
.param V16_part3='V16_part2+1.062286e-01*S20+3.109629e-01*S21+2.001495e-01*S22+1.172042e-01*S23+2.906724e-01*S24+2.049041e-01*S25+1.055760e-01*S26+1.540122e+00*S27+4.524961e-01*S28+1.047687e-01*S29'
.param V16_part4='V16_part3+7.956761e-01*S30+3.387344e-01*S31+9.209225e-02*S32+7.229933e-01*S33+2.340583e-01*S34+1.644337e-01*S35+4.087755e-01*S36+3.690313e-01*S37+7.543904e-02*S38+3.868949e-01*S39'
.param V16_part5='V16_part4+4.070255e-01*S40+2.667089e-01*S41+3.950224e-01*S42+3.198843e-01*S43+1.783570e-01*S44+1.349353e+00*S45+4.215921e-01*S46+7.808136e+01*S47+7.621582e-01*S48+4.075465e-01*S49'
.param V16_part6='V16_part5+2.892404e+01*S50+5.523205e-01*S51+3.667679e-01*S52+2.678486e-01*S53+5.195959e-01*S54+3.302678e-01*S55+2.707915e-01*S56+4.503864e-01*S57+3.981388e-01*S58+2.657314e-01*S59'
.param V16_part7='V16_part6+1.455540e+00*S60+9.380974e-01*S61+1.558976e-01*S62+7.877578e-01*S63+4.721589e-01*S64+1.471435e-01*S65+7.089359e-01*S66+3.682248e-01*S67+2.198549e-01*S68+6.280125e-01*S69'
.param V16_part8='V16_part7+7.474173e-01*S70+2.076554e-01*S71+1.299354e+00*S72+5.583976e-01*S73+2.117116e-01*S74+6.972599e-01*S75+2.983445e-01*S76+1.335879e-01*S77+5.860123e-01*S78+2.968871e-01*S79'
.param V16_part9='V16_part8+1.500966e-01*S80+3.598315e-01*S81+3.225396e-01*S82+1.518252e-01*S83+3.582663e-01*S84+2.640156e-01*S85+1.211202e-01*S86+3.693480e-01*S87+2.669715e-01*S88+9.760706e-02*S89'
.param V16_part10='V16_part9+9.347740e-01*S90+3.721213e-01*S91+1.176624e-01*S92+5.966148e-01*S93+3.456816e-01*S94+1.479068e-01*S95+6.114750e-01*S96+3.583991e-01*S97+3.571116e-01*S98+5.617340e-01*S99'
.param V16_part11='V16_part10+5.330334e-01*S100+3.164786e-01*S101+6.749498e-01*S102+6.056617e-01*S103+3.611670e-01*S104+6.200244e-01*S105+4.249085e-01*S106+2.873019e-01*S107+6.607728e-01*S108+3.093153e-01*S109'
.param V16_part12='V16_part11+1.463920e-01*S110+6.570440e-01*S111+3.516748e-01*S112+1.055672e-01*S113+8.142720e-01*S114+1.251937e+02*S115+3.446549e-01*S116+1.987085e+01*S117+8.797579e-01*S118+8.091983e-02*S119'
.param V16_part13='V16_part12+1.403899e+00*S120+2.592613e-01*S121+1.947937e-01*S122+8.508787e-01*S123+4.237424e-01*S124+(-1.630319e+01)*S125+(-8.308189e+00)*S126+(-3.221632e+01)*S127+6.797488e+00*S128+(-1.777051e+02)*S129'
.param V16_part14='V16_part13+(-1.684318e+01)*S130+(-5.619362e+00)*S131+3.347721e-01*S132+4.596333e+00*S133+(-2.503620e+00)*S134+1.211071e+00*S135+6.111783e-01*S136+5.326507e-02*S137+8.945487e-01*S138+4.925013e-01*S139'
.param V16_part15='V16_part14+3.219980e-01*S140+1.132065e+00*S141+3.468865e-01*S142+1.913223e-01*S143+8.407319e-01*S144+4.143564e-01*S145+1.608258e-01*S146+8.545087e-01*S147+5.221152e-01*S148+2.505778e-01*S149'
.param V16_part16='V16_part15+(-4.519008e+01)*S150+8.972497e-01*S151+6.698432e-02*S152+1.478490e+00*S153+3.071399e+00*S154+1.329575e-01*S155+6.694830e-01*S156+(-8.467541e+01)*S157+9.909563e-02*S158+4.236387e+03*S159'
.param V16_part17='V16_part16+(-9.886933e+01)*S160+(-1.251900e+00)*S161+2.906580e+00*S162+(-1.621215e+02)*S163+4.453604e-01*S164+3.787118e+00*S165+1.384457e+00*S166+(-1.768944e+01)*S167+9.265271e-01*S168+9.115314e-01*S169'
.param V16_part18='V16_part17+(-2.706173e+01)*S170+1.539660e+00*S171+(-1.104046e+01)*S172+2.130428e-01*S173+(-1.256674e+01)*S174+9.236060e-03*S175+3.173976e-01*S176+1.127485e+00*S177+(-9.127712e+00)*S178+4.308891e-01*S179'
.param V16_part19='V16_part18+1.712112e+00*S180+2.163723e+00*S181+6.918666e-02*S182+4.311827e+02*S183+4.265399e+01*S184+7.746829e+00*S185+7.435695e+02*S186+5.866747e+01*S187+4.912463e-01*S188+(-1.147007e+01)*S189'
.param V16_part20='V16_part19+(-1.768743e+00)*S190+4.477610e-01*S191+1.797445e+00*S192+(-1.612138e+02)*S193+5.182092e-01*S194+1.552893e+00*S195+3.422258e-01*S196+(-1.069176e+00)*S197+1.380943e+00*S198+2.010849e+00*S199'
.param V16_part21='V16_part20+(-6.204316e-02)*S200+1.640997e+00*S201+3.189161e+00*S202+9.022013e-01*S203+2.344963e+00*S204+6.511608e-01*S205+9.068842e-01*S206+1.579808e+00*S207+5.662272e-01*S208+7.686773e-01*S209'
.param V16_part22='V16_part21+6.559897e+00*S210+1.619522e+00*S211+4.500714e-02*S212+8.946789e+00*S213+9.821173e-01*S214+1.550161e-01*S215+1.921248e+00*S216+(-6.370229e+00)*S217+3.867418e-01*S218+2.399611e+00*S219'
.param V16_part23='V16_part22+(-7.989227e+00)*S220+9.783844e-01*S221+1.000000e+04*S222+(-8.114452e+00)*S223+(-4.338947e+00)*S224+5.295087e+00*S225+1.256970e+00*S226+3.568181e-01*S227+5.379419e+00*S228+(-6.309608e-01)*S229'
.param V16_part24='V16_part23+5.692967e-01*S230+2.173065e+00*S231+7.934860e-01*S232+6.194904e-01*S233+2.212151e+00*S234+(-6.862314e+01)*S235+5.743984e-01*S236+1.000000e+04*S237+(-6.720848e+01)*S238+6.992474e-01*S239'
.param V16_part25='V16_part24+3.297568e+00*S240+(-4.311792e-02)*S241+2.402436e-01*S242+2.371815e+00*S243+2.018763e-01*S244+(-5.877123e-01)*S245+2.333550e+00*S246+(-9.022001e-01)*S247+6.832901e-01*S248+2.403539e+00*S249'
.param V16_part26='V16_part25+(-3.938316e+01)*S250+5.999365e-01*S251+1.080294e+00*S252+(-1.810099e+02)*S253+6.857261e-01*S254+1.862249e+00*S255+6.040492e-01*S256+2.302742e-02*S257+2.170355e+00*S258+8.893067e-01*S259'
.param V16_part27='V16_part26+1.544904e-01*S260+(-7.877489e+00)*S261+(-7.608274e+00)*S262+7.182167e-01*S263+1.876261e+00*S264+(-3.318485e+00)*S265+4.377078e-01*S266+1.722681e+01*S267+(-2.151940e+02)*S268+5.395454e-01*S269'
.param V16_part28='V16_part27+5.602362e-02*S270+1.174276e+00*S271+7.690858e-01*S272+2.687671e+00*S273+8.955747e-01*S274+6.914746e-01*S275+2.681476e+00*S276+(-2.846834e-01)*S277+6.185714e-01*S278+(-9.511529e-01)*S279'
.param V16_part29='V16_part28+(-3.329800e-01)*S280+5.715653e-01*S281+2.783619e+00*S282+7.369513e+00*S283+6.773141e-01*S284+4.169821e+00*S285+1.565780e+00*S286+2.666324e+01*S287+2.947552e+00*S288+3.148431e+00*S289'
.param V16_part30='V16_part29+1.000000e+04*S290+3.556654e+00*S291+(-4.635022e+00)*S292+7.237254e-01*S293+4.284452e+00*S294+1.995145e-01*S295+6.705390e-01*S296+5.195978e+00*S297+7.221675e+00*S298+7.988724e-01*S299'
.param V16_part31='V16_part30+1.402696e+00*S300+6.294158e-01*S301+1.191418e-01*S302+4.971974e+00*S303+1.139657e+00*S304+1.050005e-01*S305+7.418662e+03*S306+1.586511e-01*S307+5.736889e-01*S308+3.567734e+00*S309'
.param V16='V16_part31+5.748044e+00*S310+5.625139e-01*S311+5.935917e+00*S312+(-2.988694e+00)*S313+5.925902e-01*S314'
.param V17_part1='5.383229e-01*S0+2.702273e-02*S1+3.151458e-02*S2+3.428720e-02*S3+3.651668e-02*S4+4.372626e-02*S5+4.695733e-02*S6+4.285318e-02*S7+5.022888e-02*S8+5.441872e-02*S9'
.param V17_part2='V17_part1+5.134690e-02*S10+5.971482e-02*S11+6.844851e-02*S12+6.285372e-02*S13+7.143449e-02*S14+3.178800e-02*S15+3.056162e-02*S16+3.578119e-02*S17+4.784403e-02*S18+4.344848e-02*S19'
.param V17_part3='V17_part2+5.030545e-02*S20+6.140104e-02*S21+5.752189e-02*S22+6.549873e-02*S23+7.392530e-02*S24+6.885403e-02*S25+8.021798e-02*S26+1.552114e-01*S27+7.006830e-02*S28+9.745740e-02*S29'
.param V17_part4='V17_part3+8.347493e-02*S30+4.190375e-02*S31+7.548774e-02*S32+1.179716e-01*S33+1.272331e-01*S34+7.097107e-02*S35+1.050559e-01*S36+8.909804e-02*S37+1.122758e-01*S38+1.264952e-01*S39'
.param V17_part5='V17_part4+1.154246e-01*S40+1.406139e-01*S41+1.466545e-01*S42+1.372465e-01*S43+1.536891e-01*S44+7.812618e-02*S45+4.670098e-02*S46+(-2.534382e+00)*S47+1.099279e-01*S48+7.430811e-02*S49'
.param V17_part6='V17_part5+1.954320e+00*S50+1.208962e-01*S51+1.064423e-01*S52+9.784519e-02*S53+1.467609e-01*S54+1.378059e-01*S55+1.209648e-01*S56+1.799512e-01*S57+1.593301e-01*S58+1.538936e-01*S59'
.param V17_part7='V17_part6+8.306793e-02*S60+2.269699e-02*S61+6.082579e-02*S62+1.054401e-01*S63+8.277008e-02*S64+1.157156e-01*S65+1.340373e-01*S66+1.255476e-01*S67+1.354172e-01*S68+1.650532e-01*S69'
.param V17_part8='V17_part7+1.774456e-01*S70+1.694149e-01*S71+2.403980e-01*S72+2.040604e-01*S73+1.991863e-01*S74+4.091883e-02*S75+2.977433e-02*S76+3.460283e-02*S77+6.116109e-02*S78+5.027849e-02*S79'
.param V17_part9='V17_part8+5.803036e-02*S80+7.623509e-02*S81+6.810476e-02*S82+7.095371e-02*S83+9.523888e-02*S84+8.641184e-02*S85+9.282460e-02*S86+1.131743e-01*S87+1.098188e-01*S88+1.249804e-01*S89'
.param V17_part10='V17_part9+8.387487e-02*S90+7.760110e-02*S91+5.705091e-02*S92+1.257188e-01*S93+8.926593e-02*S94+1.024775e-01*S95+1.704412e-01*S96+1.449994e-01*S97+1.422189e-01*S98+2.140352e-01*S99'
.param V17_part11='V17_part10+1.713567e-01*S100+2.005950e-01*S101+2.455917e-01*S102+1.868692e-01*S103+2.332269e-01*S104+9.533055e-02*S105+8.519967e-02*S106+8.279732e-02*S107+1.388456e-01*S108+1.224664e-01*S109'
.param V17_part12='V17_part11+1.347918e-01*S110+1.951161e-01*S111+1.656793e-01*S112+1.821773e-01*S113+2.427215e-01*S114+(-2.569216e+00)*S115+2.088555e-01*S116+1.075237e+01*S117+2.225581e-01*S118+3.021608e-01*S119'
.param V17_part13='V17_part12+1.068770e-01*S120+8.515232e-02*S121+9.465311e-02*S122+1.552699e-01*S123+1.217128e-01*S124+7.583955e+01*S125+8.224064e+00*S126+2.166582e+01*S127+4.874616e+01*S128+(-9.623450e+01)*S129'
.param V17_part14='V17_part13+1.845841e+01*S130+2.348712e+01*S131+1.688265e+00*S132+2.140747e+01*S133+2.385582e+01*S134+8.170512e-02*S135+4.206570e-02*S136+7.242243e-02*S137+1.140213e-01*S138+9.135734e-02*S139'
.param V17_part15='V17_part14+9.934579e-02*S140+1.632013e-01*S141+1.409711e-01*S142+1.370011e-01*S143+1.894568e-01*S144+1.688633e-01*S145+1.872050e-01*S146+2.284695e-01*S147+2.329449e-01*S148+2.331882e-01*S149'
.param V17_part16='V17_part15+4.139105e+01*S150+1.125401e+00*S151+9.186423e-02*S152+1.818402e-01*S153+(-7.028898e-02)*S154+1.571122e-01*S155+1.898392e+00*S156+(-8.388644e+00)*S157+2.678996e-01*S158+(-7.595167e+01)*S159'
.param V17_part17='V17_part16+(-1.354706e+01)*S160+4.817846e+00*S161+4.899744e-01*S162+(-3.316893e+01)*S163+3.438625e-01*S164+2.276223e-01*S165+(-1.165089e-01)*S166+4.178388e+00*S167+2.019567e-01*S168+2.067185e-01*S169'
.param V17_part18='V17_part17+9.893370e+00*S170+1.188705e+00*S171+1.071509e+01*S172+2.677858e-01*S173+7.096541e+00*S174+1.529893e+00*S175+2.756502e-01*S176+7.186550e+00*S177+1.529993e+01*S178+3.469476e-01*S179'
.param V17_part19='V17_part18+1.377569e-01*S180+1.295263e+00*S181+1.719318e-01*S182+1.265875e+02*S183+1.516289e+01*S184+3.648188e+01*S185+2.180867e+02*S186+2.617255e+01*S187+2.594547e-01*S188+7.672028e+00*S189'
.param V17_part20='V17_part19+1.145023e+01*S190+3.052289e-01*S191+4.238368e-01*S192+(-1.294395e+01)*S193+3.681733e-01*S194+1.058233e-01*S195+1.061426e-01*S196+4.218702e+00*S197+1.596539e-01*S198+(-3.931268e-02)*S199'
.param V17_part21='V17_part20+1.047479e+00*S200+3.131360e-01*S201+(-4.071760e-02)*S202+9.161137e-01*S203+3.210489e-01*S204+2.077922e-01*S205+9.893638e-01*S206+3.433357e-01*S207+2.851789e-01*S208+7.279458e-01*S209'
.param V17_part22='V17_part21+4.311779e-01*S210+(-7.219956e-03)*S211+1.930173e-01*S212+8.103549e-01*S213+2.635000e-02*S214+2.599538e-01*S215+1.050660e+01*S216+1.089670e+01*S217+3.027243e-01*S218+4.042978e-01*S219'
.param V17_part23='V17_part22+1.704668e+01*S220+3.968056e-01*S221+1.441064e+03*S222+1.753951e+01*S223+3.035678e+00*S224+2.232641e-01*S225+4.135780e-02*S226+1.732606e-01*S227+7.708852e+00*S228+9.328381e-01*S229'
.param V17_part24='V17_part23+1.720276e-01*S230+3.361898e-01*S231+3.554973e-01*S232+2.535125e-01*S233+4.232130e-01*S234+(-1.043765e+01)*S235+3.512759e-01*S236+6.051407e+02*S237+(-7.967690e+00)*S238+4.223469e-01*S239'
.param V17_part25='V17_part24+2.431009e-01*S240+6.829427e-01*S241+1.425866e-01*S242+6.219423e-01*S243+1.016353e+00*S244+2.563636e+00*S245+3.849100e-01*S246+1.165757e+01*S247+2.802719e-01*S248+4.556198e-01*S249'
.param V17_part26='V17_part25+1.390708e+00*S250+3.655709e-01*S251+1.169124e+00*S252+(-4.320627e+00)*S253+4.617616e-01*S254+1.476679e-01*S255+8.687870e-02*S256+2.249502e-01*S257+2.188529e-01*S258+1.382691e-01*S259'
.param V17_part27='V17_part26+2.973606e-01*S260+6.771511e+00*S261+1.691999e+01*S262+9.845281e-01*S263+3.722306e-01*S264+9.601755e+00*S265+3.235331e-01*S266+3.574141e+00*S267+(-2.092717e+01)*S268+3.685245e-01*S269'
.param V17_part28='V17_part27+7.490151e-01*S270+2.689206e-01*S271+1.163898e-01*S272+3.044821e-01*S273+3.021164e-01*S274+1.920821e-01*S275+4.024262e-01*S276+1.450667e+00*S277+2.966422e-01*S278+3.488075e+00*S279'
.param V17_part29='V17_part28+1.731969e+00*S280+3.866994e-01*S281+6.052011e-01*S282+1.286149e+00*S283+4.946891e-01*S284+3.142095e-01*S285+6.595707e-02*S286+5.094268e+01*S287+3.275607e-01*S288+(-2.197162e+00)*S289'
.param V17_part30='V17_part29+6.698562e+03*S290+4.444558e-01*S291+1.278925e+01*S292+3.706378e-01*S293+6.623709e-01*S294+1.671356e+01*S295+4.387341e-01*S296+2.562269e+00*S297+1.328494e+00*S298+5.526411e-01*S299'
.param V17_part31='V17_part30+4.420970e-01*S300+1.008333e-01*S301+1.500109e+00*S302+8.605900e+00*S303+1.247159e-01*S304+1.832884e+00*S305+1.454991e+03*S306+(-3.552274e+00)*S307+3.007252e-01*S308+8.208234e+00*S309'
.param V17='V17_part31+(-1.362469e+01)*S310+3.725625e-01*S311+5.297618e+00*S312+(-3.363101e+01)*S313+4.516544e-01*S314'
.param V18_part1='(-6.783411e-01)*S0+3.367653e-02*S1+2.178060e-02*S2+4.801476e-02*S3+3.428821e-02*S4+2.295463e-02*S5+5.597623e-02*S6+3.131378e-02*S7+1.935487e-02*S8+5.118245e-02*S9'
.param V18_part2='V18_part1+2.971054e-02*S10+1.957820e-02*S11+4.583315e-02*S12+2.868454e-02*S13+1.838607e-02*S14+5.209283e-02*S15+3.386786e-02*S16+2.175268e-02*S17+6.254162e-02*S18+3.316312e-02*S19'
.param V18_part3='V18_part2+2.078402e-02*S20+5.595052e-02*S21+3.258061e-02*S22+2.177362e-02*S23+4.983553e-02*S24+3.069625e-02*S25+2.058587e-02*S26+3.843935e-01*S27+6.982623e-02*S28+1.970801e-02*S29'
.param V18_part4='V18_part3+8.150715e-02*S30+2.812192e-02*S31+7.835276e-03*S32+6.667955e-02*S33+2.105989e-02*S34+1.197550e-02*S35+2.926283e-02*S36+1.852851e-02*S37+5.347470e-03*S38+2.337664e-02*S39'
.param V18_part5='V18_part4+1.276744e-02*S40+(-9.865688e-03)*S41+2.045630e-02*S42+(-1.209413e-02)*S43+(-8.074885e-03)*S44+1.152638e-01*S45+2.948741e-02*S46+2.518990e+03*S47+4.698445e-02*S48+2.460710e-02*S49'
.param V18_part6='V18_part5+4.482096e+02*S50+3.733601e-02*S51+1.758394e-02*S52+3.371493e-02*S53+3.432545e-02*S54+1.382441e-02*S55+3.314659e-02*S56+2.139045e-02*S57+2.139812e-02*S58+3.496855e-02*S59'
.param V18_part7='V18_part6+1.217807e-01*S60+6.121248e-02*S61+1.437013e-02*S62+5.484318e-02*S63+2.657433e-02*S64+3.870692e-03*S65+4.691601e-02*S66+1.647197e-02*S67+5.200984e-03*S68+3.742498e-02*S69'
.param V18_part8='V18_part7+(-5.539277e-03)*S70+(-1.444684e-03)*S71+6.982895e-02*S72+(-5.091063e-03)*S73+(-5.852970e-03)*S74+1.054111e-01*S75+4.191615e-02*S76+2.848271e-02*S77+9.513086e-02*S78+4.039596e-02*S79'
.param V18_part9='V18_part8+3.047848e-02*S80+5.505069e-02*S81+4.471343e-02*S82+2.790368e-02*S83+5.203051e-02*S84+3.859407e-02*S85+2.705130e-02*S86+5.860641e-02*S87+4.043885e-02*S88+2.443072e-02*S89'
.param V18_part10='V18_part9+4.417641e-02*S90+1.154405e-02*S91+(-7.687134e-03)*S92+2.656730e-02*S93+8.187410e-03*S94+(-1.861281e-03)*S95+2.254812e-02*S96+(-6.795789e-04)*S97+(-2.053054e-02)*S98+3.271256e-02*S99'
.param V18_part11='V18_part10+(-2.647096e-03)*S100+(-2.092718e-02)*S101+4.489607e-02*S102+(-1.388793e-02)*S103+(-2.899134e-02)*S104+2.510818e-02*S105+1.045965e-02*S106+4.486968e-03*S107+2.295512e-02*S108+6.168501e-04*S109'
.param V18_part12='V18_part11+3.602672e-03*S110+2.379037e-02*S111+(-2.292108e-04)*S112+1.243377e-03*S113+3.983030e-02*S114+(-1.000000e+04)*S115+(-1.206474e-02)*S116+4.415551e+00*S117+(-3.029217e-02)*S118+(-2.805867e-02)*S119'
.param V18_part13='V18_part12+5.505465e-02*S120+1.690017e-02*S121+5.418513e-03*S122+4.240357e-02*S123+5.428060e-03*S124+2.825926e+00*S125+(-3.305082e-01)*S126+2.009258e-01*S127+5.625354e-01*S128+(-4.826627e+02)*S129'
.param V18_part14='V18_part13+9.780629e-01*S130+2.428074e-01*S131+(-2.654454e-01)*S132+7.501766e-01*S133+8.215482e-01*S134+8.257631e-02*S135+3.112872e-02*S136+1.963170e-02*S137+6.322507e-02*S138+2.751883e-02*S139'
.param V18_part15='V18_part14+1.874710e-02*S140+4.153952e-02*S141+2.068729e-02*S142+1.114928e-02*S143+5.706307e-02*S144+2.040456e-02*S145+6.358995e-03*S146+5.409125e-02*S147+2.680870e-02*S148+1.104601e-02*S149'
.param V18_part16='V18_part15+(-1.015761e+01)*S150+(-4.156302e-01)*S151+(-1.383771e-02)*S152+6.870327e-02*S153+4.333329e-02*S154+(-8.399167e-03)*S155+(-1.637648e-01)*S156+(-5.166669e+00)*S157+(-2.217196e-03)*S158+(-7.582176e+02)*S159'
.param V18_part17='V18_part16+(-3.409123e+00)*S160+(-6.139039e-01)*S161+2.300806e-01*S162+(-7.406503e+00)*S163+(-2.248247e-02)*S164+1.508784e-01*S165+(-4.853904e-03)*S166+(-3.151027e-01)*S167+3.071939e-02*S168+4.453865e-02*S169'
.param V18_part18='V18_part17+(-7.233613e-01)*S170+(-3.176374e-01)*S171+(-6.610171e-01)*S172+1.939708e-02*S173+(-2.834164e+00)*S174+(-8.801604e-02)*S175+1.984204e-02*S176+(-4.998839e-01)*S177+(-3.666712e-01)*S178+2.440898e-02*S179'
.param V18_part19='V18_part18+6.196603e-02*S180+(-5.333248e-01)*S181+5.477968e-03*S182+1.042228e+01*S183+(-1.341765e+00)*S184+2.855991e-01*S185+4.149452e+01*S186+2.800974e+00*S187+1.733790e-03*S188+(-1.448481e+00)*S189'
.param V18_part20='V18_part19+4.071221e-01*S190+2.533556e-02*S191+9.300494e-02*S192+(-3.101667e-01)*S193+2.001990e-02*S194+6.168898e-02*S195+2.385332e-02*S196+(-2.747137e-01)*S197+8.781099e-02*S198+1.145873e-01*S199'
.param V18_part21='V18_part20+(-4.473790e-02)*S200+7.160570e-02*S201+1.602160e-01*S202+6.536025e-02*S203+1.425419e-01*S204+3.018064e-02*S205+7.447276e-02*S206+9.699253e-02*S207+3.095905e-02*S208+8.939184e-02*S209'
.param V18_part22='V18_part21+1.983604e-01*S210+4.291665e-02*S211+(-2.058530e-02)*S212+4.694422e-01*S213+3.907434e-02*S214+(-5.798549e-03)*S215+(-1.055490e+00)*S216+(-4.881597e-01)*S217+(-2.601525e-04)*S218+7.478681e-02*S219'
.param V18_part23='V18_part22+(-4.125276e-01)*S220+(-2.235361e-03)*S221+9.059208e+02*S222+(-7.537854e-01)*S223+(-1.392387e-01)*S224+1.472264e-01*S225+4.106025e-02*S226+2.676623e-02*S227+(-6.598963e-01)*S228+(-5.536253e-02)*S229'
.param V18_part24='V18_part23+1.416841e-02*S230+8.348975e-02*S231+3.041294e-02*S232+4.067266e-03*S233+7.072713e-02*S234+(-4.009019e+00)*S235+5.656290e-03*S236+1.236501e+03*S237+(-5.321685e+00)*S238+2.222048e-02*S239'
.param V18_part25='V18_part24+1.439417e-01*S240+1.311366e-02*S241+1.421830e-02*S242+(-9.993752e-03)*S243+(-8.314176e-02)*S244+(-2.506223e-02)*S245+4.401162e-02*S246+(-8.114555e-02)*S247+8.673820e-03*S248+8.995547e-02*S249'
.param V18_part26='V18_part25+(-1.297731e-01)*S250+5.763349e-03*S251+(-1.824776e-01)*S252+(-2.895924e+00)*S253+1.786807e-02*S254+8.594476e-02*S255+1.580022e-02*S256+1.633697e-03*S257+1.128143e-01*S258+2.676693e-02*S259'
.param V18_part27='V18_part26+1.079296e-02*S260+9.113332e-01*S261+6.041436e-01*S262+1.359013e-01*S263+8.836391e-02*S264+6.918545e-01*S265+1.203207e-02*S266+2.295132e+00*S267+(-9.987382e+00)*S268+1.454081e-02*S269'
.param V18_part28='V18_part27+(-4.528619e-02)*S270+1.872709e-02*S271+1.315896e-02*S272+7.691683e-02*S273+1.897919e-02*S274+1.147383e-02*S275+7.935846e-02*S276+(-4.979104e-02)*S277+(-1.585065e-03)*S278+(-1.655171e-01)*S279'
.param V18_part29='V18_part28+(-1.348573e-01)*S280+(-1.655584e-03)*S281+1.004624e-01*S282+5.497925e-01*S283+1.005064e-02*S284+1.075864e-01*S285+4.449611e-02*S286+(-2.404046e+00)*S287+9.408718e-02*S288+1.225966e+00*S289'
.param V18_part30='V18_part29+(-1.226718e+02)*S290+1.069806e-01*S291+(-3.065439e-01)*S292+6.304725e-03*S293+1.170219e-01*S294+(-5.509467e-01)*S295+(-9.213296e-04)*S296+1.194012e+00*S297+3.969736e+00*S298+(-2.302217e-04)*S299'
.param V18_part31='V18_part30+1.579611e-01*S300+9.099449e-03*S301+7.409695e-02*S302+6.421105e-01*S303+3.111535e-02*S304+5.870708e-02*S305+1.318875e+03*S306+8.826412e-01*S307+7.082599e-03*S308+1.422076e+00*S309'
.param V18='V18_part31+1.170042e+00*S310+6.145509e-03*S311+3.052326e+00*S312+4.401622e+00*S313+7.652998e-03*S314'
.param V19_part1='(-2.529116e-02)*S0+(-2.184641e-06)*S1+6.474573e-05*S2+(-1.485644e-04)*S3+(-1.355118e-04)*S4+3.263156e-05*S5+(-6.498499e-05)*S6+(-1.923465e-05)*S7+2.374623e-05*S8+6.464345e-06*S9'
.param V19_part2='V19_part1+(-7.818356e-06)*S10+4.607088e-05*S11+2.550662e-05*S12+4.215751e-05*S13+1.188495e-04*S14+1.081763e-03*S15+4.377581e-04*S16+2.943141e-04*S17+8.009727e-04*S18+4.578297e-04*S19'
.param V19_part3='V19_part2+2.707510e-04*S20+7.436520e-04*S21+4.530896e-04*S22+3.553312e-04*S23+5.161431e-04*S24+5.308797e-04*S25+3.954935e-04*S26+7.897841e-03*S27+7.872552e-04*S28+2.941734e-04*S29'
.param V19_part4='V19_part3+1.689124e-02*S30+5.684494e-03*S31+4.922249e-03*S32+1.300902e-02*S33+6.425720e-03*S34+3.725144e-03*S35+3.801183e-03*S36+6.076746e-03*S37+2.995352e-03*S38+1.181975e-03*S39'
.param V19_part5='V19_part4+6.201816e-03*S40+5.355306e-03*S41+(-2.656129e-03)*S42+(-9.126909e-04)*S43+2.405719e-03*S44+1.545380e-02*S45+4.839699e-03*S46+1.718110e+00*S47+1.191513e-02*S48+4.705361e-03*S49'
.param V19_part6='V19_part5+7.343131e-01*S50+8.418544e-03*S51+4.425468e-03*S52+4.183670e-03*S53+1.285982e-03*S54+6.668297e-03*S55+3.557873e-03*S56+(-1.766270e-03)*S57+4.456538e-03*S58+3.385233e-03*S59'
.param V19_part7='V19_part6+1.604616e-02*S60+1.852169e-02*S61+2.670526e-03*S62+9.027162e-03*S63+3.908299e-03*S64+2.800523e-04*S65+9.562524e-03*S66+4.847765e-03*S67+1.142075e-03*S68+1.025194e-02*S69'
.param V19_part8='V19_part7+1.026276e-02*S70+2.547704e-03*S71+5.525348e-02*S72+6.077411e-03*S73+(-1.592404e-03)*S74+1.430254e-02*S75+(-2.685783e-03)*S76+(-1.714878e-03)*S77+7.781279e-03*S78+1.613276e-03*S79'
.param V19_part9='V19_part8+(-1.596877e-03)*S80+(-6.538483e-05)*S81+(-9.399530e-05)*S82+(-1.485652e-03)*S83+(-1.450166e-03)*S84+(-2.656678e-03)*S85+(-1.797226e-03)*S86+(-1.784709e-03)*S87+(-1.243724e-03)*S88+(-3.810973e-03)*S89'
.param V19_part10='V19_part9+1.050188e-02*S90+(-2.800762e-03)*S91+(-6.417465e-03)*S92+1.572340e-02*S93+(-5.893730e-03)*S94+(-1.058040e-02)*S95+2.124794e-02*S96+(-5.700173e-03)*S97+7.445414e-03*S98+2.855637e-02*S99'
.param V19_part11='V19_part10+(-1.506103e-03)*S100+6.597688e-03*S101+2.461302e-02*S102+2.757021e-04*S103+2.332730e-03*S104+2.612573e-03*S105+2.445916e-03*S106+1.855043e-03*S107+4.710546e-03*S108+(-1.335233e-02)*S109'
.param V19_part12='V19_part11+(-1.180276e-02)*S110+1.208485e-02*S111+(-1.911972e-03)*S112+(-1.192240e-02)*S113+3.233119e-02*S114+4.917993e+00*S115+2.125065e-03*S116+9.299497e+00*S117+1.326679e-02*S118+(-1.676473e-02)*S119'
.param V19_part13='V19_part12+5.463454e-02*S120+1.275817e-02*S121+(-1.466139e-02)*S122+3.587588e-02*S123+(-1.529853e-02)*S124+(-1.929490e+01)*S125+(-2.990751e-02)*S126+(-3.615231e+00)*S127+(-1.063488e+01)*S128+9.209811e+02*S129'
.param V19_part14='V19_part13+(-2.096577e+00)*S130+(-4.057117e+00)*S131+(-2.654384e-01)*S132+(-3.034791e+00)*S133+(-3.881901e+00)*S134+2.119374e-02*S135+5.278607e-03*S136+(-1.055574e-02)*S137+1.550394e-02*S138+5.515797e-04*S139'
.param V19_part15='V19_part14+(-5.393146e-03)*S140+1.427324e-02*S141+2.416161e-03*S142+(-1.959367e-03)*S143+1.358216e-02*S144+1.090548e-03*S145+(-5.440452e-03)*S146+2.194457e-02*S147+(-5.936322e-04)*S148+(-3.289454e-03)*S149'
.param V19_part16='V19_part15+(-3.061912e+00)*S150+(-3.177234e-01)*S151+(-1.843799e-02)*S152+8.536310e-02*S153+1.491308e-01*S154+(-2.962574e-03)*S155+(-2.102480e-01)*S156+(-5.981018e-02)*S157+(-3.983769e-03)*S158+1.057918e+03*S159'
.param V19_part17='V19_part16+(-6.038072e-01)*S160+5.088795e-01*S161+1.713157e-01*S162+(-1.812426e+00)*S163+8.759208e-03*S164+2.578513e-01*S165+1.401798e-01*S166+(-8.015803e-01)*S167+3.315548e-02*S168+3.311519e-02*S169'
.param V19_part18='V19_part17+(-1.319390e+00)*S170+(-1.711590e-01)*S171+(-1.968806e+00)*S172+(-4.990268e-03)*S173+2.920019e-01*S174+(-7.474071e-02)*S175+(-4.956902e-03)*S176+4.769160e+00*S177+(-1.939314e+00)*S178+1.194942e-02*S179'
.param V19_part19='V19_part18+7.643851e-02*S180+(-4.936643e-01)*S181+(-2.292433e-02)*S182+5.759932e+01*S183+(-1.777945e+00)*S184+4.224376e-01*S185+1.266742e+02*S186+3.811922e+00*S187+1.672530e-02*S188+(-6.716591e-01)*S189'
.param V19_part20='V19_part19+(-1.342543e+00)*S190+9.645135e-03*S191+1.212800e-01*S192+3.917075e+00*S193+1.054454e-02*S194+6.553149e-02*S195+(-3.018036e-02)*S196+(-7.061182e-01)*S197+2.372330e-02*S198+1.273442e-01*S199'
.param V19_part21='V19_part20+(-3.853890e-02)*S200+4.379671e-02*S201+1.850272e-01*S202+2.423155e-02*S203+9.277664e-02*S204+2.057199e-02*S205+1.982247e-02*S206+9.555088e-02*S207+1.850511e-02*S208+3.664951e-03*S209'
.param V19_part22='V19_part21+3.069188e-01*S210+1.027571e-01*S211+(-5.521138e-03)*S212+4.274351e-01*S213+3.076658e-02*S214+1.484580e-02*S215+6.717061e+00*S216+(-2.497405e+00)*S217+1.694422e-02*S218+7.021090e-02*S219'
.param V19_part23='V19_part22+(-2.495896e+00)*S220+(-1.489392e-01)*S221+1.818351e+03*S222+(-1.874724e+00)*S223+(-1.384482e-01)*S224+1.776762e-01*S225+9.102448e-02*S226+(-1.276027e-02)*S227+3.910541e+00*S228+(-1.095367e-01)*S229'
.param V19_part24='V19_part23+(-1.406087e-02)*S230+2.037621e-01*S231+4.456473e-02*S232+1.563151e-02*S233+2.136744e-01*S234+1.621139e+00*S235+1.674504e-02*S236+4.699582e+03*S237+2.319227e-01*S238+4.416189e-03*S239'
.param V19_part25='V19_part24+2.415795e-01*S240+(-1.078406e-01)*S241+(-3.508621e-02)*S242+7.064807e-02*S243+(-1.225516e-01)*S244+1.562269e-01*S245+1.986549e-01*S246+(-2.560512e+00)*S247+1.607775e-02*S248+2.469714e-01*S249'
.param V19_part26='V19_part25+2.574315e+00*S250+1.980621e-02*S251+1.598181e-01*S252+8.662536e+00*S253+1.561873e-02*S254+1.221239e-01*S255+(-1.447742e-02)*S256+2.431529e-03*S257+1.592883e-01*S258+4.274192e-02*S259'
.param V19_part27='V19_part26+4.383993e-03*S260+(-3.817040e+00)*S261+(-5.705404e+00)*S262+6.685580e-02*S263+1.406519e-01*S264+(-1.597101e+00)*S265+9.212581e-03*S266+2.338289e+00*S267+9.294855e+00*S268+7.495498e-03*S269'
.param V19_part28='V19_part27+7.921658e-02*S270+6.771677e-02*S271+1.668306e-02*S272+2.736958e-01*S273+1.313512e-02*S274+(-1.506645e-02)*S275+2.963112e-01*S276+(-1.984615e-02)*S277+2.450607e-02*S278+4.047274e+00*S279'
.param V19_part29='V19_part28+9.296228e-02*S280+2.091787e-02*S281+3.249863e-01*S282+4.409850e-02*S283+1.199152e-02*S284+3.763167e-01*S285+1.588141e-01*S286+(-2.397918e+00)*S287+3.104869e-01*S288+(-1.492544e+00)*S289'
.param V19_part30='V19_part29+(-2.097969e+02)*S290+1.884996e-01*S291+(-3.372909e+00)*S292+8.829363e-03*S293+5.330690e-02*S294+(-3.067265e+00)*S295+1.612528e-02*S296+4.731041e+00*S297+(-2.642256e-01)*S298+2.168514e-02*S299'
.param V19_part31='V19_part30+4.701480e-02*S300+1.239429e-02*S301+9.068469e-03*S302+4.034962e+00*S303+8.064913e-02*S304+3.365675e-02*S305+2.555120e+03*S306+(-4.969846e+00)*S307+1.403405e-02*S308+7.886585e+00*S309'
.param V19='V19_part31+(-9.678763e+00)*S310+1.279819e-02*S311+7.699923e+00*S312+(-1.722442e+01)*S313+8.955176e-03*S314'
.param V20_part1='1.653721e-01*S0+4.352813e-02*S1+4.613418e-02*S2+5.213018e-02*S3+4.358407e-02*S4+4.871265e-02*S5+5.294844e-02*S6+4.475889e-02*S7+5.051357e-02*S8+5.169480e-02*S9'
.param V20_part2='V20_part1+4.526819e-02*S10+5.199859e-02*S11+5.152010e-02*S12+4.774266e-02*S13+5.488632e-02*S14+3.938332e-02*S15+3.671463e-02*S16+3.883040e-02*S17+4.040672e-02*S18+3.538403e-02*S19'
.param V20_part3='V20_part2+4.091568e-02*S20+4.068739e-02*S21+3.044798e-02*S22+3.920995e-02*S23+4.069466e-02*S24+3.084639e-02*S25+4.247075e-02*S26+3.603107e-02*S27+1.753690e-02*S28+3.857763e-02*S29'
.param V20_part4='V20_part3+3.904082e-02*S30+3.513978e-02*S31+3.439356e-02*S32+3.884594e-02*S33+1.725395e-02*S34+5.188941e-02*S35+3.078294e-02*S36+2.221151e-02*S37+1.526378e-03*S38+2.861662e-02*S39'
.param V20_part5='V20_part4+8.918167e-03*S40+3.462702e-02*S41+2.972288e-02*S42+1.958339e-02*S43+4.587704e-02*S44+4.407724e-02*S45+4.387816e-02*S46+2.295153e+01*S47+3.703584e-02*S48+3.454136e-02*S49'
.param V20_part6='V20_part5+5.414111e+00*S50+4.069053e-02*S51+2.595218e-02*S52+8.251084e-02*S53+2.630775e-02*S54+1.565695e-02*S55+8.703454e-02*S56+7.448356e-03*S57+2.192229e-02*S58+8.401657e-02*S59'
.param V20_part7='V20_part6+3.275742e-02*S60+3.702253e-02*S61+3.994346e-02*S62+3.387417e-02*S63+2.167959e-02*S64+3.893804e-02*S65+3.635294e-02*S66+7.900194e-03*S67+3.471595e-02*S68+2.493835e-02*S69'
.param V20_part8='V20_part7+(-4.130460e-02)*S70+1.958119e-02*S71+(-4.613807e-02)*S72+(-2.299429e-02)*S73+3.756213e-03*S74+2.888947e-03*S75+7.364047e-03*S76+7.852767e-03*S77+8.367145e-04*S78+2.831725e-03*S79'
.param V20_part9='V20_part8+9.167897e-03*S80+4.677319e-04*S81+(-2.687175e-03)*S82+1.069953e-02*S83+(-1.571950e-03)*S84+(-6.396063e-03)*S85+5.009364e-03*S86+(-7.743864e-03)*S87+(-1.150542e-02)*S88+8.529871e-03*S89'
.param V20_part10='V20_part9+2.817059e-02*S90+1.693840e-02*S91+3.637593e-02*S92+(-1.624888e-04)*S93+(-7.517043e-03)*S94+2.523887e-02*S95+(-1.163913e-02)*S96+(-4.074484e-02)*S97+1.740070e-02*S98+(-2.539857e-02)*S99'
.param V20_part11='V20_part10+(-5.085496e-02)*S100+5.577368e-03*S101+(-1.415099e-03)*S102+9.729731e-03*S103+3.467201e-02*S104+1.977574e-02*S105+2.994316e-02*S106+6.115382e-02*S107+1.371530e-02*S108+(-1.369030e-02)*S109'
.param V20_part12='V20_part11+1.203928e-02*S110+2.812802e-03*S111+(-4.622092e-02)*S112+(-4.072027e-02)*S113+3.593475e-02*S114+8.978142e+02*S115+2.951304e-02*S116+1.100582e-01*S117+5.511235e-02*S118+(-1.261654e-01)*S119'
.param V20_part13='V20_part12+3.297631e-02*S120+2.913531e-02*S121+2.182725e-02*S122+8.495805e-03*S123+(-1.592318e-02)*S124+6.281266e+00*S125+2.533949e+00*S126+7.272180e+00*S127+3.827386e+00*S128+(-6.759086e+02)*S129'
.param V20_part14='V20_part13+7.001381e+00*S130+(-9.732048e-01)*S131+8.247628e-02*S132+1.181075e+01*S133+(-6.537941e-01)*S134+(-1.753638e-03)*S135+6.854329e-03*S136+(-7.191107e-03)*S137+(-9.610039e-03)*S138+(-2.731636e-02)*S139'
.param V20_part15='V20_part14+(-1.769707e-02)*S140+(-5.158924e-02)*S141+(-4.195251e-02)*S142+1.540146e-02*S143+(-7.970351e-03)*S144+(-4.498319e-02)*S145+7.217762e-04*S146+(-1.149036e-02)*S147+(-4.857035e-02)*S148+5.891646e-05*S149'
.param V20_part16='V20_part15+4.744183e-01*S150+(-4.926342e-02)*S151+(-5.780244e-03)*S152+4.509927e-02*S153+(-3.135958e-02)*S154+(-2.849188e-02)*S155+1.054082e-01*S156+(-4.357344e+00)*S157+(-1.256428e-01)*S158+(-1.026425e+03)*S159'
.param V20_part17='V20_part16+(-7.927003e+00)*S160+8.612483e-01*S161+(-1.748244e-01)*S162+(-2.338827e+01)*S163+(-2.730704e-02)*S164+(-1.713398e-02)*S165+5.287387e-02*S166+1.220352e+00*S167+(-1.969628e-02)*S168+5.364627e-02*S169'
.param V20_part18='V20_part17+3.878161e+00*S170+(-6.323499e-06)*S171+5.389201e+00*S172+(-1.074568e-01)*S173+8.309388e-01*S174+7.843256e-01*S175+(-5.985940e-02)*S176+7.168485e-01*S177+7.207314e+00*S178+(-3.694461e-02)*S179'
.param V20_part19='V20_part18+4.950299e-02*S180+(-6.700094e-02)*S181+(-6.283147e-02)*S182+(-1.235828e+00)*S183+(-5.979222e+00)*S184+2.539690e+00*S185+1.017976e+00*S186+(-9.561427e+00)*S187+(-8.788025e-02)*S188+1.006065e+00*S189'
.param V20_part20='V20_part19+5.453028e+00*S190+(-1.262970e-02)*S191+(-7.600577e-02)*S192+(-2.083128e+01)*S193+(-3.211972e-02)*S194+(-7.178562e-03)*S195+(-3.241014e-02)*S196+(-1.097855e-01)*S197+(-4.699388e-03)*S198+(-4.507573e-02)*S199'
.param V20_part21='V20_part20+(-8.199935e-02)*S200+(-5.054534e-02)*S201+(-1.229753e-01)*S202+(-1.541215e-02)*S203+(-1.185474e-01)*S204+(-6.954652e-02)*S205+(-6.395003e-03)*S206+(-1.652753e-01)*S207+(-1.189626e-01)*S208+(-2.460015e-03)*S209'
.param V20_part22='V20_part21+(-2.811965e-02)*S210+1.817959e-01*S211+(-7.351157e-02)*S212+(-1.023864e-01)*S213+1.864085e-01*S214+(-1.598867e-01)*S215+1.185821e+00*S216+6.009576e+00*S217+(-6.967064e-02)*S218+(-3.732779e-02)*S219'
.param V20_part23='V20_part22+7.422395e+00*S220+(-3.460072e-01)*S221+(-8.705519e+02)*S222+9.251003e+00*S223+1.265400e+00*S224+(-4.202544e-02)*S225+1.860545e-01*S226+(-9.208360e-02)*S227+4.588598e-01*S228+5.733897e-01*S229'
.param V20_part24='V20_part23+(-5.840284e-02)*S230+9.934306e-03*S231+(-1.272957e-01)*S232+2.256714e-02*S233+(-3.110364e-03)*S234+(-1.224099e+01)*S235+2.907024e-02*S236+(-1.468534e+03)*S237+(-1.707562e+01)*S238+(-6.028376e-04)*S239'
.param V20_part25='V20_part24+1.319480e-02*S240+5.394599e-01*S241+(-9.661444e-02)*S242+(-5.845773e-02)*S243+7.623743e-01*S244+4.025545e-01*S245+3.895108e-02*S246+6.301886e+00*S247+3.021207e-03*S248+(-2.579039e-02)*S249'
.param V20_part26='V20_part25+(-4.286092e+00)*S250+1.804080e-03*S251+(-3.784780e-02)*S252+(-3.716460e+01)*S253+3.362430e-02*S254+1.604517e-02*S255+1.694656e-02*S256+(-6.184515e-02)*S257+3.390949e-02*S258+1.813733e-02*S259'
.param V20_part27='V20_part26+(-1.097384e-01)*S260+8.065623e-01*S261+7.488538e+00*S262+(-1.674279e-02)*S263+(-3.576349e-02)*S264+4.840428e+00*S265+(-7.689553e-02)*S266+(-5.699672e-01)*S267+(-2.582536e+01)*S268+(-3.635742e-02)*S269'
.param V20_part28='V20_part27+(-9.806146e-03)*S270+1.856113e-02*S271+(-1.439512e-01)*S272+(-6.069635e-03)*S273+(-4.238318e-02)*S274+(-9.374224e-02)*S275+9.171757e-03*S276+1.127021e+00*S277+7.368040e-02*S278+7.439079e-01*S279'
.param V20_part29='V20_part28+1.028152e+00*S280+2.902571e-02*S281+9.810586e-02*S282+(-1.555953e+00)*S283+(-1.134777e-01)*S284+4.446400e-02*S285+2.661702e-01*S286+5.242690e+00*S287+3.456844e-03*S288+(-1.543414e+00)*S289'
.param V20_part30='V20_part29+1.028485e+03*S290+2.091776e-02*S291+7.175273e+00*S292+(-9.968577e-02)*S293+(-5.137883e-02)*S294+9.379513e+00*S295+(-3.673377e-02)*S296+4.342691e-01*S297+(-1.444688e+01)*S298+(-5.637114e-02)*S299'
.param V20_part31='V20_part30+(-4.636881e-02)*S300+(-5.242199e-02)*S301+8.311439e-02*S302+5.506013e-01*S303+6.613275e-02*S304+1.447445e-01*S305+(-6.755819e+02)*S306+(-3.729787e+00)*S307+(-1.590590e-02)*S308+1.049762e+00*S309'
.param V20='V20_part31+(-1.003542e+01)*S310+(-1.111029e-02)*S311+7.198847e-01*S312+(-3.160606e+01)*S313+(-3.016846e-02)*S314'
.param V21_part1='2.634329e-01*S0+1.804554e-01*S1+1.564633e-01*S2+2.265885e-01*S3+2.003538e-01*S4+1.681072e-01*S5+2.400458e-01*S6+2.211461e-01*S7+1.849238e-01*S8+2.562347e-01*S9'
.param V21_part2='V21_part1+2.332625e-01*S10+1.930647e-01*S11+2.792324e-01*S12+2.417366e-01*S13+2.077288e-01*S14+3.052762e-01*S15+2.724233e-01*S16+2.342417e-01*S17+3.302953e-01*S18+3.062659e-01*S19'
.param V21_part3='V21_part2+2.621423e-01*S20+3.606629e-01*S21+3.263345e-01*S22+2.808145e-01*S23+3.795559e-01*S24+3.493405e-01*S25+2.945219e-01*S26+3.842920e-01*S27+3.904214e-01*S28+3.224380e-01*S29'
.param V21_part4='V21_part3+6.998551e-01*S30+5.773707e-01*S31+5.075786e-01*S32+7.772356e-01*S33+6.360626e-01*S34+5.542961e-01*S35+7.932768e-01*S36+7.045893e-01*S37+6.588537e-01*S38+8.367595e-01*S39'
.param V21_part5='V21_part4+7.581533e-01*S40+6.903237e-01*S41+8.670452e-01*S42+7.864061e-01*S43+6.985317e-01*S44+8.602591e-01*S45+7.897257e-01*S46+3.027719e+00*S47+1.052982e+00*S48+8.973121e-01*S49'
.param V21_part6='V21_part5+1.910849e+00*S50+1.067557e+00*S51+9.656591e-01*S52+8.127949e-01*S53+1.173012e+00*S54+1.023881e+00*S55+8.603048e-01*S56+1.223517e+00*S57+1.083276e+00*S58+9.186880e-01*S59'
.param V21_part7='V21_part6+1.090112e+00*S60+1.058406e+00*S61+9.360383e-01*S62+1.243209e+00*S63+1.149112e+00*S64+1.029624e+00*S65+1.335907e+00*S66+1.231530e+00*S67+1.123092e+00*S68+1.443123e+00*S69'
.param V21_part8='V21_part7+1.430557e+00*S70+1.202866e+00*S71+1.652080e+00*S72+1.454583e+00*S73+1.276923e+00*S74+3.938843e-01*S75+3.747682e-01*S76+3.313172e-01*S77+4.453988e-01*S78+4.198670e-01*S79'
.param V21_part9='V21_part8+3.581108e-01*S80+4.820957e-01*S81+4.317036e-01*S82+3.826079e-01*S83+5.083997e-01*S84+4.591491e-01*S85+4.204645e-01*S86+5.336779e-01*S87+4.973155e-01*S88+4.308094e-01*S89'
.param V21_part10='V21_part9+1.726188e+00*S90+1.625413e+00*S91+1.482889e+00*S92+2.011307e+00*S93+1.854428e+00*S94+1.623133e+00*S95+2.158470e+00*S96+1.988234e+00*S97+1.778700e+00*S98+2.285417e+00*S99'
.param V21_part11='V21_part10+2.112892e+00*S100+1.868971e+00*S101+2.378226e+00*S102+2.187277e+00*S103+1.911781e+00*S104+2.179959e+00*S105+1.926418e+00*S106+1.734817e+00*S107+2.418026e+00*S108+2.237134e+00*S109'
.param V21_part12='V21_part11+2.016941e+00*S110+2.593143e+00*S111+2.408614e+00*S112+2.222068e+00*S113+2.703648e+00*S114+1.537317e+01*S115+2.215648e+00*S116+6.372746e+00*S117+2.676817e+00*S118+2.479736e+00*S119'
.param V21_part13='V21_part12+2.579815e+00*S120+2.295041e+00*S121+2.165428e+00*S122+2.781581e+00*S123+2.615275e+00*S124+3.519100e+01*S125+3.203628e+00*S126+6.400877e+00*S127+2.385572e+01*S128+7.587129e+02*S129'
.param V21_part14='V21_part13+5.965391e+00*S130+1.493878e+01*S131+3.265846e+00*S132+5.099027e+00*S133+1.501607e+01*S134+1.322194e+00*S135+1.236995e+00*S136+1.191556e+00*S137+1.509866e+00*S138+1.420454e+00*S139'
.param V21_part15='V21_part14+1.359614e+00*S140+1.764027e+00*S141+1.519747e+00*S142+1.331674e+00*S143+1.737565e+00*S144+1.593535e+00*S145+1.401065e+00*S146+1.817002e+00*S147+1.640402e+00*S148+1.470504e+00*S149'
.param V21_part16='V21_part15+3.334143e+01*S150+4.040873e+00*S151+3.002820e+00*S152+3.619281e+00*S153+3.309523e+00*S154+3.240977e+00*S155+3.975983e+00*S156+1.023962e+01*S157+3.523207e+00*S158+1.286102e+03*S159'
.param V21_part17='V21_part16+1.361486e+01*S160+3.701396e+00*S161+4.904987e+00*S162+2.104550e+01*S163+3.758717e+00*S164+4.216314e+00*S165+3.373581e+00*S166+2.967700e+00*S167+4.403450e+00*S168+4.357346e+00*S169'
.param V21_part18='V21_part17+2.773999e+00*S170+4.552678e+00*S171+5.189631e+00*S172+4.066869e+00*S173+5.140792e+00*S174+4.753283e+00*S175+4.164398e+00*S176+5.381462e+00*S177+6.072103e+00*S178+4.346788e+00*S179'
.param V21_part19='V21_part18+4.179655e+00*S180+4.883601e+00*S181+3.925902e+00*S182+8.698186e+01*S183+3.484716e+01*S184+2.113056e+01*S185+1.167033e+02*S186+3.918555e+01*S187+4.511477e+00*S188+5.930191e+00*S189'
.param V21_part20='V21_part19+7.203916e+00*S190+4.613966e+00*S191+5.929575e+00*S192+2.134846e+01*S193+4.876623e+00*S194+2.953869e+00*S195+2.726240e+00*S196+3.906618e+00*S197+3.103957e+00*S198+2.832486e+00*S199'
.param V21_part21='V21_part20+2.900387e+00*S200+3.403203e+00*S201+3.106738e+00*S202+2.820280e+00*S203+3.907339e+00*S204+3.273422e+00*S205+2.926722e+00*S206+4.049038e+00*S207+3.445650e+00*S208+3.012476e+00*S209'
.param V21_part22='V21_part21+6.188472e+00*S210+4.658511e+00*S211+4.949920e+00*S212+7.178843e+00*S213+5.678017e+00*S214+5.389437e+00*S215+7.069557e+00*S216+8.180714e+00*S217+5.472090e+00*S218+7.123481e+00*S219'
.param V21_part23='V21_part22+9.658110e+00*S220+6.671183e+00*S221+1.503590e+03*S222+7.715708e+00*S223+4.944993e+00*S224+6.615600e+00*S225+5.284026e+00*S226+5.802948e+00*S227+7.393899e+00*S228+6.507531e+00*S229'
.param V21_part24='V21_part23+6.093538e+00*S230+7.321677e+00*S231+6.478006e+00*S232+6.132218e+00*S233+7.750971e+00*S234+2.105091e+01*S235+6.397860e+00*S236+1.760297e+03*S237+2.536368e+01*S238+6.861290e+00*S239'
.param V21_part25='V21_part24+6.488473e+00*S240+6.448302e+00*S241+6.341752e+00*S242+7.297452e+00*S243+7.088532e+00*S244+6.011039e+00*S245+7.760622e+00*S246+9.122162e+00*S247+6.761787e+00*S248+8.534098e+00*S249'
.param V21_part26='V21_part25+1.528642e+01*S250+7.069032e+00*S251+8.638025e+00*S252+3.464109e+01*S253+7.362365e+00*S254+4.660445e+00*S255+4.545600e+00*S256+4.226842e+00*S257+5.212845e+00*S258+4.791792e+00*S259'
.param V21_part27='V21_part26+4.547150e+00*S260+6.201933e+00*S261+9.090799e+00*S262+4.602304e+00*S263+6.255394e+00*S264+7.706909e+00*S265+5.104900e+00*S266+8.781144e+00*S267+2.276730e+01*S268+5.396520e+00*S269'
.param V21_part28='V21_part27+7.809805e+00*S270+7.078992e+00*S271+7.645129e+00*S272+9.007491e+00*S273+7.896522e+00*S274+8.034383e+00*S275+9.612719e+00*S276+8.790553e+00*S277+7.965525e+00*S278+9.725516e+00*S279'
.param V21_part29='V21_part28+9.041672e+00*S280+8.389308e+00*S281+1.045519e+01*S282+1.189245e+01*S283+8.957219e+00*S284+8.454457e+00*S285+7.661169e+00*S286+3.699469e+01*S287+9.816520e+00*S288+1.281318e+01*S289'
.param V21_part30='V21_part29+4.404174e+03*S290+1.059789e+01*S291+1.209966e+01*S292+8.997383e+00*S293+1.145670e+01*S294+1.242169e+01*S295+9.289503e+00*S296+1.126075e+01*S297+3.121242e+01*S298+9.721625e+00*S299'
.param V21_part31='V21_part30+7.130301e+00*S300+7.039185e+00*S301+6.202491e+00*S302+8.652095e+00*S303+7.171925e+00*S304+6.593706e+00*S305+1.626245e+03*S306+1.594776e+01*S307+7.230593e+00*S308+9.568930e+00*S309'
.param V21='V21_part31+2.362470e+01*S310+7.590528e+00*S311+9.784945e+00*S312+4.140940e+01*S313+8.005540e+00*S314'
.param V22_part1='(-1.850389e-01)*S0+(-2.897106e-03)*S1+4.952485e-03*S2+(-6.643579e-02)*S3+(-1.747339e-02)*S4+(-3.444890e-03)*S5+(-9.645728e-02)*S6+(-3.690558e-02)*S7+(-1.406192e-02)*S8+(-1.256411e-01)*S9'
.param V22_part2='V22_part1+(-5.486663e-02)*S10+(-2.324546e-02)*S11+(-1.706498e-01)*S12+(-7.352144e-02)*S13+(-3.840445e-02)*S14+(-3.185441e-02)*S15+4.604370e-04*S16+1.148544e-02*S17+(-7.043219e-02)*S18+(-2.078903e-02)*S19'
.param V22_part3='V22_part2+(-1.057211e-03)*S20+(-1.196201e-01)*S21+(-3.812391e-02)*S22+(-1.274720e-02)*S23+(-1.651031e-01)*S24+(-6.513923e-02)*S25+(-2.698213e-02)*S26+(-1.915896e-01)*S27+(-8.661798e-02)*S28+(-4.579356e-02)*S29'
.param V22_part4='V22_part3+(-4.145937e-02)*S30+1.453623e-02*S31+2.888113e-02*S32+(-1.421517e-01)*S33+(-7.787711e-03)*S34+2.480210e-04*S35+(-2.056270e-01)*S36+(-6.698407e-02)*S37+(-1.083200e-02)*S38+(-2.963597e-01)*S39'
.param V22_part5='V22_part4+(-1.132492e-01)*S40+(-6.010016e-02)*S41+(-3.775316e-01)*S42+(-1.651218e-01)*S43+(-9.492416e-02)*S44+(-6.079598e-03)*S45+5.317471e-02*S46+3.537962e-01*S47+(-1.239037e-01)*S48+5.925338e-03*S49'
.param V22_part6='V22_part5+1.539414e-01*S50+(-2.330664e-01)*S51+(-5.185964e-02)*S52+(-9.581705e-03)*S53+(-3.860558e-01)*S54+(-1.085844e-01)*S55+(-4.619180e-02)*S56+(-4.833316e-01)*S57+(-2.024348e-01)*S58+(-9.321804e-02)*S59'
.param V22_part7='V22_part6+1.562548e-02*S60+9.282533e-02*S61+1.021465e-01*S62+(-1.253238e-01)*S63+2.123592e-02*S64+6.684106e-02*S65+(-2.781560e-01)*S66+(-5.312090e-02)*S67+2.280376e-02*S68+(-4.551675e-01)*S69'
.param V22_part8='V22_part7+(-1.217220e-01)*S70+(-2.218485e-02)*S71+(-6.019683e-01)*S72+(-2.402513e-01)*S73+(-7.872757e-02)*S74+(-1.608796e-02)*S75+8.984068e-03*S76+1.987139e-02*S77+(-6.372762e-02)*S78+(-1.492743e-02)*S79'
.param V22_part9='V22_part8+6.236976e-03*S80+(-1.094581e-01)*S81+(-3.353172e-02)*S82+(-9.143378e-03)*S83+(-1.629040e-01)*S84+(-6.003983e-02)*S85+(-2.563170e-02)*S86+(-2.097688e-01)*S87+(-9.247567e-02)*S88+(-4.239585e-02)*S89'
.param V22_part10='V22_part9+1.064291e-01*S90+1.895261e-01*S91+2.078474e-01*S92+(-9.403890e-02)*S93+8.508177e-02*S94+1.587231e-01*S95+(-2.882296e-01)*S96+1.939787e-03*S97+1.088050e-01*S98+(-5.043705e-01)*S99'
.param V22_part11='V22_part10+(-1.250383e-01)*S100+4.772578e-02*S101+(-8.086700e-01)*S102+(-3.540067e-01)*S103+(-6.162995e-02)*S104+2.004515e-01*S105+2.875616e-01*S106+3.038177e-01*S107+(-4.318566e-02)*S108+1.955551e-01*S109'
.param V22_part12='V22_part11+2.659013e-01*S110+(-2.807121e-01)*S111+7.383766e-02*S112+2.040868e-01*S113+(-5.703263e-01)*S114+1.505710e+00*S115+1.110594e-01*S116+5.863055e+00*S117+(-4.075636e-01)*S118+6.275527e-02*S119'
.param V22_part13='V22_part12+2.431014e-01*S120+3.444800e-01*S121+4.333389e-01*S122+1.415210e-05*S123+2.528640e-01*S124+(-1.137362e+00)*S125+(-3.011698e+00)*S126+(-6.792976e+00)*S127+(-1.491967e+00)*S128+3.469699e+03*S129'
.param V22_part14='V22_part13+(-6.700211e+00)*S130+6.355188e-01*S131+(-1.236269e+00)*S132+(-1.071218e+01)*S133+7.876700e-02*S134+5.778873e-02*S135+1.159529e-01*S136+1.455849e-01*S137+(-9.785758e-02)*S138+5.986397e-02*S139'
.param V22_part15='V22_part14+1.267133e-01*S140+(-2.457795e-01)*S141+(-2.637501e-02)*S142+4.368019e-02*S143+(-4.825204e-01)*S144+(-1.212312e-01)*S145+(-3.499988e-03)*S146+(-6.637819e-01)*S147+(-1.949228e-01)*S148+(-7.257912e-02)*S149'
.param V22_part16='V22_part15+(-8.082380e-01)*S150+6.203021e-01*S151+7.149697e-01*S152+8.980872e-02*S153+3.687873e-01*S154+6.414201e-01*S155+(-5.717089e-01)*S156+2.944095e+01*S157+5.950593e-01*S158+4.704838e+03*S159'
.param V22_part17='V22_part16+4.888664e+01*S160+(-3.473510e-01)*S161+(-1.109954e+00)*S162+9.894495e+01*S163+3.498631e-01*S164+1.027533e+00*S165+6.524616e-01*S166+2.151162e+00*S167+3.681062e-01*S168+6.629446e-01*S169'
.param V22_part18='V22_part17+2.490608e+00*S170+(-4.664889e-01)*S171+(-3.559789e+00)*S172+8.254351e-01*S173+1.106631e+00*S174+(-5.213829e-01)*S175+6.861819e-01*S176+(-2.975436e+00)*S177+(-5.927406e+00)*S178+4.646271e-01*S179'
.param V22_part19='V22_part18+8.052159e-01*S180+9.448479e-01*S181+1.204109e+00*S182+(-3.521400e+01)*S183+8.801845e+00*S184+(-2.064986e-01)*S185+(-9.104820e+01)*S186+1.097693e+01*S187+1.078127e+00*S188+6.329423e-01*S189'
.param V22_part20='V22_part19+(-4.275309e+00)*S190+8.647198e-01*S191+(-1.176914e+00)*S192+1.047961e+02*S193+6.421806e-01*S194+3.620059e-01*S195+5.106836e-01*S196+5.674010e-01*S197+(-8.132131e-03)*S198+2.615708e-01*S199'
.param V22_part21='V22_part20+3.294648e-01*S200+(-3.956213e-01)*S201+1.344896e-01*S202+2.121105e-01*S203+(-5.549611e-01)*S204+(-3.114279e-02)*S205+1.166424e-01*S206+(-9.979143e-01)*S207+(-1.932524e-01)*S208+2.698674e-02*S209'
.param V22_part22='V22_part21+2.012009e+00*S210+1.251403e+00*S211+1.772327e+00*S212+1.479513e+00*S213+1.111488e+00*S214+1.675108e+00*S215+(-2.943484e+00)*S216+(-3.625498e+00)*S217+1.523393e+00*S218+(-4.411249e-01)*S219'
.param V22_part23='V22_part22+(-5.367000e+00)*S220+2.009404e+00*S221+1.027856e+02*S222+(-6.663021e+00)*S223+8.780521e-02*S224+2.277335e+00*S225+1.586011e+00*S226+2.323565e+00*S227+(-6.396187e-01)*S228+1.382975e+00*S229'
.param V22_part24='V22_part23+2.171077e+00*S230+4.180592e-01*S231+1.416292e+00*S232+1.862857e+00*S233+(-3.570969e-01)*S234+7.522933e+01*S235+1.663421e+00*S236+3.135732e+03*S237+9.114716e+01*S238+1.402180e+00*S239'
.param V22_part25='V22_part24+1.633028e+00*S240+2.165610e+00*S241+2.726092e+00*S242+8.750121e-01*S243+1.569838e+00*S244+1.338151e+00*S245+1.907039e-01*S246+(-2.736771e+00)*S247+2.281195e+00*S248+(-1.554383e-01)*S249'
.param V22_part26='V22_part25+3.873836e+01*S250+2.042877e+00*S251+(-1.955906e+00)*S252+1.814304e+02*S253+1.704063e+00*S254+1.002149e+00*S255+1.266550e+00*S256+1.299712e+00*S257+4.011009e-01*S258+9.262909e-01*S259'
.param V22_part27='V22_part26+1.245824e+00*S260+5.620303e-01*S261+(-5.152854e+00)*S262+8.101426e-01*S263+(-6.398945e-01)*S264+(-3.672629e+00)*S265+1.076450e+00*S266+(-9.359405e-01)*S267+1.208026e+02*S268+8.008450e-01*S269'
.param V22_part28='V22_part27+2.186624e+00*S270+3.032234e+00*S271+3.745570e+00*S272+2.203813e+00*S273+2.825739e+00*S274+3.486315e+00*S275+1.232385e+00*S276+1.771378e+00*S277+3.002996e+00*S278+(-2.801195e+00)*S279'
.param V22_part29='V22_part28+1.888067e+00*S280+2.726155e+00*S281+(-8.093431e-01)*S282+7.361802e+00*S283+2.420533e+00*S284+2.743481e+00*S285+3.079074e+00*S286+4.889601e+00*S287+2.703880e+00*S288+1.586382e+01*S289'
.param V22_part30='V22_part29+(-1.359527e+03)*S290+1.814413e+00*S291+(-1.823370e+00)*S292+3.732353e+00*S293+6.931431e-01*S294+(-3.906768e+00)*S295+3.335850e+00*S296+(-3.659607e+00)*S297+7.548759e+01*S298+2.980002e+00*S299'
.param V22_part31='V22_part30+1.882916e+00*S300+2.899933e+00*S301+2.018144e+00*S302+(-6.215395e-01)*S303+2.008844e+00*S304+1.795868e+00*S305+2.184598e+03*S306+2.461132e+01*S307+2.584119e+00*S308+(-3.873783e+00)*S309'
.param V22='V22_part31+5.543974e+01*S310+2.320673e+00*S311+(-4.408530e+00)*S312+1.300371e+02*S313+1.943219e+00*S314'
.param V23_part1='8.873534e-02*S0+6.717388e-02*S1+6.217666e-02*S2+7.474084e-02*S3+6.907641e-02*S4+6.313403e-02*S5+7.559562e-02*S6+7.121460e-02*S7+6.488967e-02*S8+7.696281e-02*S9'
.param V23_part2='V23_part1+7.202659e-02*S10+6.581620e-02*S11+8.105558e-02*S12+7.253811e-02*S13+6.685574e-02*S14+6.489406e-02*S15+5.955973e-02*S16+5.345174e-02*S17+6.478381e-02*S18+6.141530e-02*S19'
.param V23_part3='V23_part2+5.554584e-02*S20+6.704419e-02*S21+6.140213e-02*S22+5.540492e-02*S23+6.835938e-02*S24+6.401048e-02*S25+5.696163e-02*S26+7.298076e-02*S27+6.753435e-02*S28+5.821431e-02*S29'
.param V23_part4='V23_part3+6.976762e-02*S30+5.872902e-02*S31+5.693335e-02*S32+6.975886e-02*S33+5.911296e-02*S34+6.008678e-02*S35+6.644217e-02*S36+6.564229e-02*S37+6.186612e-02*S38+6.745955e-02*S39'
.param V23_part5='V23_part4+6.697033e-02*S40+6.329058e-02*S41+6.799048e-02*S42+6.954163e-02*S43+6.593922e-02*S44+7.114676e-02*S45+6.943204e-02*S46+9.262788e+01*S47+8.074051e-02*S48+7.225893e-02*S49'
.param V23_part6='V23_part5+2.158315e+01*S50+7.696253e-02*S51+7.288801e-02*S52+7.507631e-02*S53+7.733730e-02*S54+7.397374e-02*S55+7.925911e-02*S56+8.011948e-02*S57+8.123003e-02*S58+8.361462e-02*S59'
.param V23_part7='V23_part6+6.316661e-02*S60+6.625290e-02*S61+5.912775e-02*S62+6.588340e-02*S63+6.413590e-02*S64+6.313350e-02*S65+6.761326e-02*S66+6.412575e-02*S67+6.421832e-02*S68+6.942654e-02*S69'
.param V23_part8='V23_part7+7.850516e-02*S70+6.821704e-02*S71+7.842285e-02*S72+7.766110e-02*S73+6.875545e-02*S74+1.925882e-02*S75+2.368165e-02*S76+1.863390e-02*S77+2.045552e-02*S78+2.363645e-02*S79'
.param V23_part9='V23_part8+1.767082e-02*S80+2.234724e-02*S81+1.961594e-02*S82+1.858108e-02*S83+2.286170e-02*S84+2.213718e-02*S85+2.164909e-02*S86+2.784199e-02*S87+2.954290e-02*S88+2.610437e-02*S89'
.param V23_part10='V23_part9+6.624501e-02*S90+6.736021e-02*S91+6.930447e-02*S92+7.249369e-02*S93+7.217747e-02*S94+6.828610e-02*S95+7.379918e-02*S96+7.383552e-02*S97+7.375734e-02*S98+7.367901e-02*S99'
.param V23_part11='V23_part10+7.765369e-02*S100+7.794408e-02*S101+6.625468e-02*S102+7.886624e-02*S103+8.526626e-02*S104+7.820615e-02*S105+7.334598e-02*S106+7.268900e-02*S107+7.773844e-02*S108+7.839322e-02*S109'
.param V23_part12='V23_part11+7.796951e-02*S110+7.909722e-02*S111+7.987230e-02*S112+8.381117e-02*S113+7.908906e-02*S114+(-1.204166e+03)*S115+9.251509e-02*S116+5.087074e-01*S117+8.827393e-02*S118+9.450486e-02*S119'
.param V23_part13='V23_part12+7.315157e-02*S120+6.453293e-02*S121+6.562550e-02*S122+6.790619e-02*S123+7.125207e-02*S124+2.074320e+00*S125+(-1.058847e-02)*S126+2.846862e-01*S127+9.660230e-01*S128+1.611373e+01*S129'
.param V23_part14='V23_part13+2.597277e-01*S130+3.121915e-01*S131+7.852800e-02*S132+2.074031e-01*S133+4.761414e-01*S134+1.972454e-02*S135+2.354272e-02*S136+2.187483e-02*S137+2.103447e-02*S138+2.473646e-02*S139'
.param V23_part15='V23_part14+3.164495e-02*S140+2.923579e-02*S141+2.388349e-02*S142+2.453747e-02*S143+2.139973e-02*S144+2.411931e-02*S145+2.656170e-02*S146+2.404951e-02*S147+2.429445e-02*S148+2.800845e-02*S149'
.param V23_part16='V23_part15+4.611743e-01*S150+6.358847e-02*S151+8.111834e-02*S152+6.339026e-02*S153+7.620038e-02*S154+8.286508e-02*S155+7.960384e-02*S156+1.196807e-01*S157+8.403448e-02*S158+5.554926e+01*S159'
.param V23_part17='V23_part16+5.090285e-01*S160+5.899590e-02*S161+9.160041e-02*S162+1.277571e+00*S163+7.842831e-02*S164+9.070748e-02*S165+7.700800e-02*S166+8.391180e-02*S167+7.989029e-02*S168+1.044691e-01*S169'
.param V23_part18='V23_part17+5.708021e-02*S170+7.810870e-02*S171+5.987869e-02*S172+8.644322e-02*S173+(-3.726900e-02)*S174+7.819788e-02*S175+8.040956e-02*S176+1.636705e-01*S177+(-4.372361e-03)*S178+7.958220e-02*S179'
.param V23_part19='V23_part18+6.732617e-02*S180+7.258522e-02*S181+7.868191e-02*S182+2.207273e+00*S183+6.553347e-01*S184+4.773702e-01*S185+4.693511e+00*S186+1.223205e+00*S187+8.616178e-02*S188+(-3.436438e-02)*S189'
.param V23_part20='V23_part19+1.030084e-01*S190+7.448396e-02*S191+8.329222e-02*S192+1.142185e+00*S193+8.296761e-02*S194+2.826235e-02*S195+2.678498e-02*S196+4.403077e-02*S197+2.021286e-02*S198+2.358347e-02*S199'
.param V23_part21='V23_part20+3.600640e-02*S200+2.591704e-02*S201+3.134372e-02*S202+3.801290e-02*S203+3.471079e-02*S204+2.883971e-02*S205+4.112145e-02*S206+4.002712e-02*S207+2.963883e-02*S208+4.189329e-02*S209'
.param V23_part22='V23_part21+9.401144e-02*S210+6.403536e-02*S211+9.212002e-02*S212+1.147999e-01*S213+7.645700e-02*S214+9.193354e-02*S215+1.176554e-01*S216+(-2.379721e-03)*S217+8.928784e-02*S218+7.316040e-02*S219'
.param V23_part23='V23_part22+(-6.915638e-02)*S220+9.374396e-02*S221+1.129227e+02*S222+(-1.134379e-01)*S223+1.410243e-01*S224+9.335860e-02*S225+7.501028e-02*S226+9.204190e-02*S227+9.010114e-02*S228+7.655795e-02*S229'
.param V23_part24='V23_part23+8.449653e-02*S230+8.574273e-02*S231+8.398719e-02*S232+9.426918e-02*S233+8.264773e-02*S234+(-2.185036e-01)*S235+9.444385e-02*S236+1.258354e+02*S237+5.835205e-01*S238+9.533170e-02*S239'
.param V23_part25='V23_part24+6.953744e-02*S240+9.263208e-02*S241+9.925441e-02*S242+7.942421e-02*S243+6.026390e-02*S244+9.303305e-02*S245+8.149508e-02*S246+(-1.233305e-03)*S247+9.215612e-02*S248+7.606364e-02*S249'
.param V23_part26='V23_part25+(-1.047153e-03)*S250+9.666965e-02*S251+1.024461e-01*S252+1.220413e+00*S253+8.531796e-02*S254+2.055237e-02*S255+2.955719e-02*S256+3.496155e-02*S257+2.353931e-02*S258+2.728938e-02*S259'
.param V23_part27='V23_part26+3.565715e-02*S260+7.335677e-02*S261+2.183232e-01*S262+4.252341e-02*S263+3.306655e-02*S264+9.497729e-02*S265+4.927117e-02*S266+9.628978e-02*S267+(-5.714213e-01)*S268+5.276828e-02*S269'
.param V23_part28='V23_part27+7.458328e-02*S270+7.458381e-02*S271+9.408970e-02*S272+7.140562e-02*S273+7.481739e-02*S274+9.688557e-02*S275+7.375016e-02*S276+1.549300e-02*S277+9.030114e-02*S278+1.238470e-01*S279'
.param V23_part29='V23_part28+2.134836e-03*S280+8.797272e-02*S281+7.640543e-02*S282+8.029597e-02*S283+7.715906e-02*S284+8.109767e-02*S285+7.694467e-02*S286+5.708717e-01*S287+8.592844e-02*S288+1.595392e-01*S289'
.param V23_part30='V23_part29+(-3.423783e+01)*S290+9.020493e-02*S291+(-7.399734e-03)*S292+9.733223e-02*S293+7.393888e-02*S294+(-1.036756e-01)*S295+9.647315e-02*S296+1.930722e-01*S297+8.205944e-01*S298+9.387343e-02*S299'
.param V23_part31='V23_part30+3.014246e-02*S300+3.857198e-02*S301+5.623065e-02*S302+4.666083e-02*S303+3.125234e-02*S304+6.428806e-02*S305+3.857661e+01*S306+7.646266e-02*S307+5.908234e-02*S308+9.423914e-02*S309'
.param V23='V23_part31+1.802421e-01*S310+6.451593e-02*S311+1.860444e-01*S312+8.931737e-01*S313+6.794773e-02*S314'
.param V24_part1='3.501397e-04*S0+2.035471e-05*S1+(-2.791545e-05)*S2+5.492250e-06*S3+7.582563e-06*S4+(-7.197464e-06)*S5+(-5.091308e-05)*S6+1.439267e-05*S7+(-3.563259e-07)*S8+(-1.375060e-05)*S9'
.param V24_part2='V24_part1+(-2.662826e-05)*S10+2.344627e-05*S11+(-1.301520e-05)*S12+2.579646e-06*S13+2.814706e-07*S14+8.541288e-04*S15+7.836751e-04*S16+7.017070e-04*S17+9.120667e-04*S18+8.434185e-04*S19'
.param V24_part3='V24_part2+7.759162e-04*S20+1.011995e-03*S21+9.085404e-04*S22+8.606146e-04*S23+1.048869e-03*S24+9.154379e-04*S25+7.965512e-04*S26+1.133143e-03*S27+1.043400e-03*S28+8.757843e-04*S29'
.param V24_part4='V24_part3+4.647173e-03*S30+4.285505e-03*S31+4.660501e-03*S32+2.630017e-03*S33+2.588313e-03*S34+4.715124e-03*S35+(-1.712441e-04)*S36+3.968614e-03*S37+6.180704e-03*S38+(-3.712300e-03)*S39'
.param V24_part5='V24_part4+3.959211e-03*S40+5.076579e-03*S41+(-8.653660e-03)*S42+(-1.797331e-03)*S43+4.137959e-03*S44+4.903550e-03*S45+5.857020e-03*S46+5.310077e-02*S47+2.715081e-03*S48+3.498593e-03*S49'
.param V24_part6='V24_part5+3.754954e-02*S50+(-3.547596e-04)*S51+1.370168e-03*S52+6.418641e-03*S53+(-4.025407e-03)*S54+(-1.457210e-03)*S55+5.654249e-03*S56+(-6.937781e-03)*S57+1.955431e-03*S58+4.770255e-03*S59'
.param V24_part7='V24_part6+7.269526e-03*S60+1.039769e-02*S61+1.145546e-02*S62+3.255489e-03*S63+6.720038e-03*S64+1.061588e-02*S65+3.955942e-04*S66+5.384342e-03*S67+9.350906e-03*S68+(-5.261770e-03)*S69'
.param V24_part8='V24_part7+3.401969e-03*S70+7.934345e-03*S71+(-9.560444e-03)*S72+7.163684e-04*S73+2.887618e-03*S74+6.128677e-03*S75+4.662839e-03*S76+4.569916e-03*S77+5.271106e-03*S78+4.449960e-03*S79'
.param V24_part9='V24_part8+3.632025e-03*S80+4.265290e-03*S81+3.907377e-03*S82+3.182034e-03*S83+4.115424e-03*S84+3.134263e-03*S85+2.745685e-03*S86+3.123999e-03*S87+2.492320e-03*S88+8.883623e-04*S89'
.param V24_part10='V24_part9+1.611836e-02*S90+2.363669e-02*S91+2.386941e-02*S92+1.196190e-02*S93+2.057401e-02*S94+2.318576e-02*S95+1.558684e-04*S96+1.412137e-02*S97+1.811359e-02*S98+(-1.191212e-02)*S99'
.param V24_part11='V24_part10+1.041104e-02*S100+1.476505e-02*S101+(-3.623788e-02)*S102+6.054949e-03*S103+1.275924e-02*S104+2.301354e-02*S105+2.511937e-02*S106+2.852314e-02*S107+7.342945e-03*S108+2.221483e-02*S109'
.param V24_part12='V24_part11+3.064993e-02*S110+(-1.233956e-02)*S111+1.668634e-02*S112+3.025833e-02*S113+(-3.923994e-02)*S114+5.534645e-01*S115+2.103173e-02*S116+2.136644e-01*S117+4.340069e-03*S118+1.476929e-02*S119'
.param V24_part13='V24_part12+2.895181e-02*S120+3.246428e-02*S121+4.128896e-02*S122+1.144291e-02*S123+3.234161e-02*S124+(-1.121930e+00)*S125+(-1.389443e-01)*S126+(-2.681637e-01)*S127+(-8.676290e-01)*S128+2.624712e+01*S129'
.param V24_part14='V24_part13+(-2.393823e-01)*S130+(-3.807893e-01)*S131+(-3.870444e-02)*S132+(-3.037224e-01)*S133+(-4.590157e-01)*S134+1.273160e-02*S135+1.631620e-02*S136+1.949781e-02*S137+9.886460e-03*S138+1.421498e-02*S139'
.param V24_part15='V24_part14+1.736532e-02*S140+3.442261e-03*S141+8.219974e-03*S142+1.038611e-02*S143+(-5.973368e-03)*S144+4.396510e-03*S145+1.010787e-02*S146+(-1.578181e-02)*S147+1.183406e-03*S148+7.616254e-03*S149'
.param V24_part16='V24_part15+1.135760e+00*S150+1.589998e-01*S151+6.840274e-02*S152+2.194256e-02*S153+5.637739e-02*S154+5.891779e-02*S155+(-7.010066e-03)*S156+1.009678e+00*S157+5.739685e-02*S158+2.237295e+01*S159'
.param V24_part17='V24_part16+1.255558e+00*S160+2.781060e-01*S161+(-6.415802e-02)*S162+2.135269e+00*S163+2.748632e-02*S164+7.346520e-02*S165+7.200634e-02*S166+1.871589e-01*S167+2.000953e-02*S168+4.862675e-02*S169'
.param V24_part18='V24_part17+3.779592e-01*S170+2.261625e-02*S171+(-2.135550e-01)*S172+7.132328e-02*S173+(-2.321112e-01)*S174+(-1.758697e-02)*S175+5.582146e-02*S176+3.746638e-01*S177+(-3.524286e-01)*S178+4.290584e-02*S179'
.param V24_part19='V24_part18+6.321993e-02*S180+1.965777e-01*S181+1.021721e-01*S182+5.782109e+00*S183+2.278408e+00*S184+1.949046e+00*S185+1.048021e+01*S186+3.100909e+00*S187+7.527312e-02*S188+(-3.572660e-01)*S189'
.param V24_part20='V24_part19+(-3.514188e-01)*S190+6.608701e-02*S191+(-9.856282e-02)*S192+3.106360e+00*S193+4.356087e-02*S194+3.972230e-02*S195+5.015728e-02*S196+1.936366e-01*S197+2.234881e-02*S198+4.055023e-02*S199'
.param V24_part21='V24_part20+1.049920e-01*S200+6.266976e-03*S201+3.796093e-02*S202+6.870407e-02*S203+(-2.176924e-02)*S204+1.040152e-02*S205+5.834877e-02*S206+(-6.622203e-02)*S207+1.530622e-03*S208+3.995009e-02*S209'
.param V24_part22='V24_part21+1.203477e-01*S210+9.827674e-02*S211+1.345267e-01*S212+6.462251e-02*S213+7.996539e-02*S214+1.200409e-01*S215+5.566434e-01*S216+(-3.419390e-01)*S217+1.075041e-01*S218+(-7.516582e-02)*S219'
.param V24_part23='V24_part22+(-4.632597e-01)*S220+1.136258e-01*S221+1.359146e+02*S222+(-3.599872e-01)*S223+2.028171e-01*S224+9.993902e-02*S225+1.125739e-01*S226+1.753137e-01*S227+4.965423e-01*S228+9.153549e-02*S229'
.param V24_part24='V24_part23+1.406581e-01*S230+(-6.063884e-03)*S231+8.238264e-02*S232+1.181834e-01*S233+(-6.893980e-02)*S234+1.995410e+00*S235+1.006615e-01*S236+2.637842e+02*S237+2.382986e+00*S238+6.599075e-02*S239'
.param V24_part25='V24_part24+1.404215e-01*S240+1.154952e-01*S241+1.813407e-01*S242+1.122399e-01*S243+7.423831e-02*S244+3.229962e-01*S245+3.664192e-02*S246+(-3.811712e-01)*S247+1.418660e-01*S248+(-7.276717e-02)*S249'
.param V24_part26='V24_part25+1.019406e+00*S250+1.160790e-01*S251+(-2.571189e-02)*S252+5.072491e+00*S253+1.096599e-01*S254+7.366141e-02*S255+1.034531e-01*S256+9.824740e-02*S257+3.517138e-02*S258+6.876561e-02*S259'
.param V24_part27='V24_part26+9.089728e-02*S260+(-3.150934e-01)*S261+(-5.031835e-01)*S262+1.193914e-01*S263+(-7.107510e-02)*S264+(-3.071341e-01)*S265+7.138813e-02*S266+(-2.667856e-02)*S267+3.261671e+00*S268+5.431279e-02*S269'
.param V24_part28='V24_part27+2.157841e-01*S270+2.012094e-01*S271+2.604441e-01*S272+9.085470e-02*S273+1.745561e-01*S274+2.226736e-01*S275+4.930056e-03*S276+7.428547e-02*S277+1.841463e-01*S278+3.897407e-01*S279'
.param V24_part29='V24_part28+1.253896e-01*S280+1.654541e-01*S281+(-1.509322e-01)*S282+7.058188e-02*S283+1.583557e-01*S284+2.182980e-01*S285+2.044542e-01*S286+4.610689e+00*S287+1.096937e-01*S288+2.133593e-01*S289'
.param V24_part30='V24_part29+1.369540e+02*S290+1.747409e-02*S291+(-4.800767e-01)*S292+2.387912e-01*S293+(-8.356098e-02)*S294+(-5.906502e-01)*S295+2.104346e-01*S296+3.989502e-01*S297+1.208527e+00*S298+1.693454e-01*S299'
.param V24_part31='V24_part30+1.744073e-01*S300+2.033634e-01*S301+3.123136e-01*S302+5.533890e-01*S303+1.374676e-01*S304+2.952638e-01*S305+2.239212e+02*S306+2.820222e-01*S307+1.612589e-01*S308+6.957204e-01*S309'
.param V24='V24_part31+5.266777e-01*S310+1.420579e-01*S311+6.180228e-01*S312+1.164871e+00*S313+1.182852e-01*S314'
.param V25_part1='2.849438e-01*S0+1.049474e+00*S1+(-1.902125e-01)*S2+(-1.950716e-01)*S3+1.678460e+00*S4+3.697373e-01*S5+1.964893e-01*S6+1.105831e-01*S7+(-9.564616e-03)*S8+6.984743e-02*S9'
.param V25_part2='V25_part1+(-1.041074e-01)*S10+(-1.252792e-02)*S11+6.425509e-01*S12+2.013233e-01*S13+2.492582e-01*S14+1.273965e-01*S15+(-1.496201e-01)*S16+(-8.123309e-02)*S17+4.299507e-02*S18+(-7.642753e-02)*S19'
.param V25_part3='V25_part2+(-2.944498e-01)*S20+7.191066e-02*S21+7.318687e-01*S22+1.317643e-01*S23+1.078204e-02*S24+(-1.938190e-01)*S25+9.136284e-01*S26+2.228069e+00*S27+1.845358e-01*S28+(-9.026789e-02)*S29'
.param V25_part4='V25_part3+9.635630e-01*S30+(-1.816440e-01)*S31+2.695700e+00*S32+1.217199e+00*S33+2.896082e+00*S34+(-4.886265e-01)*S35+1.230061e+02*S36+(-2.971129e-01)*S37+(-1.622307e+00)*S38+3.168320e+00*S39'
.param V25_part5='V25_part4+1.066488e-01*S40+(-2.046140e-01)*S41+1.758910e+02*S42+3.239191e-02*S43+(-9.569657e-02)*S44+(-6.428997e-02)*S45+(-4.889219e-02)*S46+(-2.727632e-01)*S47+7.163005e-01*S48+(-1.773314e+00)*S49'
.param V25_part6='V25_part5+(-1.506729e-01)*S50+1.788312e-01*S51+(-1.129551e-01)*S52+3.275538e-02*S53+(-8.707845e-02)*S54+(-1.099135e-01)*S55+2.654738e-02*S56+(-2.098269e-01)*S57+(-5.347763e-01)*S58+(-2.063384e-02)*S59'
.param V25_part7='V25_part6+(-9.345900e-02)*S60+(-1.456882e-01)*S61+7.022399e-02*S62+5.584985e-02*S63+(-2.838348e-01)*S64+(-8.082099e-04)*S65+7.382216e-02*S66+1.403221e-01*S67+9.425511e-02*S68+(-4.744385e-03)*S69'
.param V25_part8='V25_part7+1.429992e+00*S70+1.685856e-01*S71+1.872919e+00*S72+4.568137e-01*S73+1.213375e-02*S74+1.157705e-02*S75+4.951536e-02*S76+1.008275e-01*S77+(-1.286993e-01)*S78+(-2.468464e-01)*S79'
.param V25_part9='V25_part8+2.898669e-01*S80+1.834674e-01*S81+1.580214e-03*S82+7.791418e-02*S83+2.827996e-01*S84+7.467703e-01*S85+(-3.982838e-01)*S86+2.864555e-01*S87+(-2.076123e-01)*S88+2.345361e-01*S89'
.param V25_part10='V25_part9+2.801433e-01*S90+(-1.566361e+00)*S91+(-9.539024e+00)*S92+1.124756e+01*S93+(-9.032578e-01)*S94+(-2.781398e+00)*S95+6.913069e+01*S96+(-2.417505e+00)*S97+(-1.036912e-01)*S98+2.644733e+02*S99'
.param V25_part11='V25_part10+(-3.326249e-01)*S100+(-1.057335e-01)*S101+2.299381e+01*S102+(-2.751616e-01)*S103+(-1.677322e-01)*S104+9.999454e+02*S105+(-1.863384e-02)*S106+1.088276e-01*S107+9.189730e+02*S108+2.267173e+00*S109'
.param V25_part12='V25_part11+(-8.555646e-02)*S110+(-4.784560e-01)*S111+4.493848e+00*S112+1.274536e-01*S113+(-4.186366e-01)*S114+(-2.020712e-01)*S115+(-2.533523e-01)*S116+3.224751e-01*S117+2.209305e-02*S118+(-1.835397e-01)*S119'
.param V25_part13='V25_part12+2.169980e-01*S120+(-3.006102e-02)*S121+(-6.395255e-02)*S122+1.524753e-01*S123+(-7.897660e-01)*S124+(-7.301730e-02)*S125+(-2.183067e-02)*S126+(-7.871711e-02)*S127+(-4.332277e-02)*S128+(-4.304463e-01)*S129'
.param V25_part14='V25_part13+(-6.792009e-02)*S130+7.168459e-02*S131+6.136781e-01*S132+(-8.547002e-02)*S133+4.567251e-02*S134+(-4.186258e-02)*S135+(-7.051558e-01)*S136+(-1.170493e+00)*S137+1.203270e-02*S138+(-6.363645e-01)*S139'
.param V25_part15='V25_part14+1.164172e+00*S140+1.762255e-01*S141+1.569478e-01*S142+1.753191e-01*S143+(-1.481790e-02)*S144+6.780155e-02*S145+7.948537e-01*S146+1.472187e-01*S147+7.618881e-01*S148+1.271391e+00*S149'
.param V25_part16='V25_part15+2.480907e-01*S150+1.360049e-01*S151+(-2.989941e+00)*S152+2.135538e-02*S153+2.648802e+00*S154+(-3.369899e+00)*S155+7.247906e-01*S156+1.320371e-01*S157+(-2.210286e-01)*S158+(-3.361504e-01)*S159'
.param V25_part17='V25_part16+5.144325e-02*S160+1.044661e-01*S161+1.483985e+00*S162+(-6.632591e-02)*S163+(-2.661864e-01)*S164+2.542286e+00*S165+2.592465e+00*S166+4.662997e-01*S167+(-4.604936e-03)*S168+1.835071e+00*S169'
.param V25_part18='V25_part17+9.476592e-02*S170+1.331142e+00*S171+(-5.708673e-02)*S172+1.943561e-01*S173+9.241700e-02*S174+1.985211e+00*S175+8.620200e-03*S176+2.371901e-01*S177+(-6.442173e-02)*S178+(-1.129521e-01)*S179'
.param V25_part19='V25_part18+(-2.185284e-03)*S180+2.546025e-01*S181+(-1.815757e-01)*S182+1.362924e+01*S183+1.390349e+00*S184+(-1.018970e+00)*S185+2.583625e+01*S186+1.060824e+00*S187+1.326188e-01*S188+6.106728e-02*S189'
.param V25_part20='V25_part19+(-5.910053e-03)*S190+(-6.166316e-02)*S191+3.330881e-01*S192+(-2.578029e-03)*S193+(-8.679183e-02)*S194+(-5.016830e-02)*S195+(-6.982303e-01)*S196+8.855596e-02*S197+1.316339e-01*S198+2.706718e+00*S199'
.param V25_part21='V25_part20+1.034850e+00*S200+3.019879e+00*S201+2.627208e+00*S202+1.456273e+00*S203+1.069965e+00*S204+6.467735e-02*S205+1.615963e+00*S206+7.005100e-01*S207+(-1.014803e-01)*S208+1.819429e+00*S209'
.param V25_part22='V25_part21+2.771091e+00*S210+2.174793e-01*S211+(-2.690334e+00)*S212+2.703759e+00*S213+3.694565e-01*S214+(-1.353816e+00)*S215+6.884655e-03*S216+(-2.039133e-02)*S217+(-1.089848e+00)*S218+2.070437e-01*S219'
.param V25_part23='V25_part22+1.383966e-02*S220+1.784534e+00*S221+(-2.048510e-01)*S222+(-1.377822e-01)*S223+(-7.280082e-01)*S224+1.628489e+00*S225+2.006031e-01*S226+5.566500e-01*S227+1.478770e-01*S228+2.782317e+00*S229'
.param V25_part24='V25_part23+4.114732e-01*S230+3.576086e-03*S231+7.017625e-01*S232+(-1.339101e-01)*S233+(-3.365694e-02)*S234+1.271593e-01*S235+(-5.862757e-02)*S236+(-2.956534e-01)*S237+1.209902e-01*S238+1.944842e-01*S239'
.param V25_part25='V25_part24+3.222161e+00*S240+2.642399e+00*S241+5.558611e-01*S242+2.435983e+00*S243+2.420121e+00*S244+3.037021e-01*S245+2.172863e+00*S246+(-9.176187e-04)*S247+1.024785e-01*S248+1.759168e-01*S249'
.param V25_part26='V25_part25+2.753620e-01*S250+6.342070e-02*S251+2.941569e-01*S252+4.011326e-02*S253+7.572934e-02*S254+(-8.765219e-03)*S255+(-1.722667e+00)*S256+5.374524e-01*S257+1.183013e-02*S258+8.411479e-02*S259'
.param V25_part27='V25_part26+4.021775e-01*S260+4.635265e-02*S261+3.344367e-02*S262+1.469020e+00*S263+1.385921e-03*S264+2.302799e-02*S265+(-3.392553e-01)*S266+2.270110e+00*S267+1.057522e-02*S268+(-1.653908e-01)*S269'
.param V25_part28='V25_part27+1.516325e+00*S270+1.422447e+00*S271+4.213668e-01*S272+1.233480e-01*S273+6.132152e-01*S274+4.690594e-01*S275+(-3.448135e-02)*S276+2.497979e+00*S277+(-2.202067e-01)*S278+2.870194e-01*S279'
.param V25_part29='V25_part28+2.928014e+00*S280+(-1.932665e-01)*S281+(-1.640054e-01)*S282+1.986972e+00*S283+(-4.463166e-02)*S284+3.278852e+00*S285+1.445181e-01*S286+(-1.930694e+00)*S287+3.746069e-01*S288+9.427534e-01*S289'
.param V25_part30='V25_part29+(-2.421490e-01)*S290+2.942148e-01*S291+4.352833e-02*S292+3.325614e-01*S293+5.402501e-01*S294+1.942676e-02*S295+1.625250e-01*S296+7.645933e-01*S297+2.980726e-01*S298+1.613094e-01*S299'
.param V25_part31='V25_part30+2.443663e+00*S300+2.015069e-01*S301+7.371943e-01*S302+1.545708e-01*S303+1.289123e-01*S304+7.371566e-01*S305+(-2.657136e-01)*S306+5.228137e-01*S307+(-2.151582e-01)*S308+2.126995e-01*S309'
.param V25='V25_part31+2.951713e-01*S310+(-1.289608e-01)*S311+4.244807e-01*S312+1.621914e-01*S313+(-8.750553e-02)*S314'
.param V26_part1='1.113257e+00*S0+(-2.911594e-01)*S1+1.461206e-01*S2+3.461068e-01*S3+(-4.548247e-01)*S4+2.178603e+00*S5+1.015977e+00*S6+2.226041e-01*S7+8.659483e-02*S8+7.031853e-01*S9'
.param V26_part2='V26_part1+2.175564e-01*S10+9.502280e-01*S11+4.650893e-01*S12+3.220201e-01*S13+2.939002e-01*S14+(-9.681680e-03)*S15+1.793275e-01*S16+7.024386e-01*S17+1.693432e+00*S18+2.413924e-01*S19'
.param V26_part3='V26_part2+2.568284e-01*S20+7.093988e-01*S21+(-2.044514e-01)*S22+1.222679e+00*S23+4.296925e-01*S24+3.101419e-01*S25+(-1.617880e-01)*S26+3.161346e-01*S27+1.228416e+00*S28+2.423829e-01*S29'
.param V26_part4='V26_part3+2.147224e+00*S30+2.921890e-01*S31+(-7.927213e-01)*S32+1.315536e+00*S33+(-5.767175e-01)*S34+6.754582e-01*S35+1.662237e+00*S36+7.287944e-01*S37+(-6.142435e+01)*S38+7.568456e-01*S39'
.param V26_part5='V26_part4+9.066289e-01*S40+1.483233e+00*S41+1.573209e+00*S42+4.191882e-01*S43+4.486147e-01*S44+5.018053e+00*S45+7.196048e-01*S46+(-1.271401e-01)*S47+1.478270e+00*S48+1.039758e+00*S49'
.param V26_part6='V26_part5+6.644376e-02*S50+2.049746e-01*S51+9.989577e-02*S52+7.160346e-02*S53+3.526736e-01*S54+1.088872e-01*S55+7.859844e-02*S56+2.040129e-01*S57+5.830449e-01*S58+1.049472e-01*S59'
.param V26_part7='V26_part6+4.740077e+00*S60+5.113158e+00*S61+2.250297e-01*S62+1.160125e+00*S63+2.281335e-01*S64+2.290119e-01*S65+5.774271e-01*S66+3.040229e-02*S67+4.650403e-01*S68+3.590596e-01*S69'
.param V26_part8='V26_part7+2.307763e-01*S70+3.094918e-01*S71+3.759535e-01*S72+4.307833e-01*S73+2.837310e-01*S74+2.986113e+00*S75+1.249941e+00*S76+(-2.069737e-01)*S77+2.362218e+00*S78+1.316754e+00*S79'
.param V26_part9='V26_part8+9.951736e-01*S80+1.186459e-01*S81+1.604488e+00*S82+8.827100e-01*S83+1.702527e-01*S84+(-1.035994e-02)*S85+6.071032e-01*S86+1.177064e-01*S87+6.547734e-01*S88+(-1.303242e-02)*S89'
.param V26_part10='V26_part9+(-6.478738e-02)*S90+4.273863e+00*S91+1.705897e+01*S92+5.754393e+00*S93+2.100067e-01*S94+2.490993e+00*S95+3.820737e-02*S96+3.916431e+00*S97+6.850283e-01*S98+2.168290e-01*S99'
.param V26_part11='V26_part10+4.634804e-01*S100+4.957865e-01*S101+(-1.302776e+00)*S102+4.925616e-01*S103+4.625966e-01*S104+(-7.042313e-02)*S105+(-1.261304e-02)*S106+(-1.936362e-01)*S107+(-6.630054e-02)*S108+7.962857e-01*S109'
.param V26_part12='V26_part11+6.491920e-02*S110+2.249797e-02*S111+2.732022e-01*S112+(-1.518858e-02)*S113+(-9.830883e-02)*S114+(-2.351219e-01)*S115+5.179173e-01*S116+1.247908e-01*S117+6.893180e-01*S118+3.425734e-01*S119'
.param V26_part13='V26_part12+2.147477e+00*S120+(-1.534098e-01)*S121+2.286544e-01*S122+1.978764e-01*S123+6.353913e-01*S124+(-1.320604e-01)*S125+7.130934e-01*S126+1.817832e-01*S127+(-6.342908e-02)*S128+(-8.923948e-02)*S129'
.param V26_part14='V26_part13+2.027627e-01*S130+6.990589e-03*S131+1.195655e+00*S132+1.638828e-01*S133+3.043547e-02*S134+2.948000e+00*S135+7.464779e-01*S136+1.168995e+00*S137+1.238358e+00*S138+4.301225e-01*S139'
.param V26_part15='V26_part14+3.364491e-01*S140+1.809334e+00*S141+3.960611e-02*S142+4.324344e-02*S143+5.275457e-01*S144+1.990068e-01*S145+(-1.275505e-01)*S146+5.182383e-01*S147+2.813552e-02*S148+(-2.353488e-01)*S149'
.param V26_part16='V26_part15+2.406212e+00*S150+3.108167e-01*S151+6.165803e+00*S152+9.168691e-01*S153+(-1.605821e+00)*S154+3.863262e+00*S155+1.125914e+00*S156+1.901025e-01*S157+1.389861e-01*S158+(-2.342710e-01)*S159'
.param V26_part17='V26_part16+1.497891e-01*S160+2.357481e-01*S161+7.512082e-01*S162+1.763696e-01*S163+5.123157e-01*S164+9.140885e-01*S165+(-1.177418e+00)*S166+7.360861e-01*S167+6.375880e-01*S168+(-7.485858e-01)*S169'
.param V26_part18='V26_part17+4.985574e-01*S170+1.383070e+00*S171+4.475935e-01*S172+1.942171e-01*S173+5.409133e-01*S174+(-9.386189e-02)*S175+1.361305e-01*S176+4.659254e-01*S177+3.291305e-01*S178+2.785074e-01*S179'
.param V26_part19='V26_part18+1.246832e+00*S180+2.607630e-01*S181+1.595482e-01*S182+(-8.925961e-02)*S183+(-5.677656e-01)*S184+6.933471e-01*S185+(-6.648162e-03)*S186+(-5.758966e-01)*S187+4.382275e-01*S188+5.190062e-01*S189'
.param V26_part20='V26_part19+3.189690e-01*S190+2.749066e-01*S191+3.600470e-01*S192+1.374821e-01*S193+3.189630e-01*S194+2.325758e+00*S195+1.206772e+00*S196+1.947207e-01*S197+1.376788e+00*S198+(-1.551028e+00)*S199'
.param V26_part21='V26_part20+(-2.610610e-01)*S200+(-6.171880e-01)*S201+(-1.326793e+00)*S202+(-3.007915e-01)*S203+1.279326e+00*S204+3.351182e-01*S205+(-3.078578e-01)*S206+5.969519e-01*S207+3.230605e-01*S208+(-1.953815e-01)*S209'
.param V26_part22='V26_part21+4.455513e-01*S210+1.240727e+00*S211+4.685969e+00*S212+2.226935e-01*S213+2.799726e-01*S214+1.220397e+00*S215+6.244136e-01*S216+3.925713e-01*S217+7.505018e-01*S218+9.342587e-01*S219'
.param V26_part23='V26_part22+2.676670e-01*S220+(-1.559091e-01)*S221+(-2.957316e-01)*S222+4.553938e-01*S223+1.453958e+00*S224+2.779747e+00*S225+6.938514e-01*S226+3.255607e-01*S227+7.711397e-01*S228+(-8.122487e-01)*S229'
.param V26_part24='V26_part23+3.587394e-01*S230+7.298938e-01*S231+3.054236e-01*S232+4.976477e-01*S233+5.667720e-01*S234+1.199445e-01*S235+3.488890e-01*S236+(-2.399193e-01)*S237+9.191087e-02*S238+4.018955e-01*S239'
.param V26_part25='V26_part24+(-6.208505e-01)*S240+(-9.933660e-01)*S241+2.496189e-01*S242+2.036609e+00*S243+(-3.205042e-01)*S244+5.930569e-01*S245+(-5.271774e-01)*S246+4.281866e-01*S247+4.223198e-01*S248+4.865972e-01*S249'
.param V26_part26='V26_part25+1.849315e-01*S250+3.487035e-01*S251+2.659877e+00*S252+7.497005e-02*S253+3.369933e-01*S254+1.224353e+00*S255+3.015170e+00*S256+(-2.411724e-01)*S257+1.109752e+00*S258+3.544834e-01*S259'
.param V26_part27='V26_part26+(-1.278474e-01)*S260+6.810472e-01*S261+2.295231e-01*S262+(-1.353309e-02)*S263+5.608967e-01*S264+3.472711e-01*S265+3.307956e-01*S266+(-4.571147e-01)*S267+1.343610e-01*S268+3.164286e-01*S269'
.param V26_part28='V26_part27+4.215905e+00*S270+5.130057e-01*S271+5.476786e-01*S272+8.146739e-01*S273+1.981886e-01*S274+3.998477e-01*S275+6.809750e-01*S276+8.147857e-02*S277+3.515740e-01*S278+1.275433e+00*S279'
.param V26_part29='V26_part28+7.520518e-02*S280+2.793786e-01*S281+5.056044e-01*S282+1.645080e-01*S283+3.230321e-01*S284+(-2.021706e-01)*S285+5.278328e-01*S286+2.380030e+00*S287+7.089973e-01*S288+2.806072e-01*S289'
.param V26_part30='V26_part29+(-2.824628e-01)*S290+1.113642e+00*S291+4.340901e-01*S292+3.483710e-01*S293+1.507338e+00*S294+3.671998e-01*S295+2.913325e-01*S296+1.094598e+00*S297+5.308663e-02*S298+3.487071e-01*S299'
.param V26_part31='V26_part30+2.976805e+00*S300+2.505146e-01*S301+4.181331e-01*S302+8.805976e-01*S303+3.688532e-01*S304+3.670637e-01*S305+(-3.339393e-01)*S306+1.371823e-01*S307+3.553454e-01*S308+6.613229e-01*S309'
.param V26='V26_part31+7.579627e-02*S310+2.944902e-01*S311+6.506690e-01*S312+2.423712e-02*S313+2.796268e-01*S314'
.param V27_part1='1.031988e+00*S0+(-3.096385e-01)*S1+8.466600e-02*S2+2.962866e-01*S3+(-4.314940e-01)*S4+8.035026e-02*S5+1.490769e+00*S6+1.545952e-01*S7+9.255146e-02*S8+6.495367e-01*S9'
.param V27_part2='V27_part1+1.234421e-01*S10+(-9.768383e-02)*S11+6.508156e-02*S12+2.251586e-01*S13+1.145028e-01*S14+(-3.488320e-01)*S15+2.443829e-01*S16+1.740011e-02*S17+1.263183e+00*S18+2.257582e-01*S19'
.param V27_part3='V27_part2+1.572462e-01*S20+1.106537e+00*S21+(-1.698513e-01)*S22+(-5.495351e-02)*S23+7.501748e-01*S24+1.650695e-01*S25+(-1.565892e-01)*S26+(-3.325616e-01)*S27+5.128466e+00*S28+7.814963e-02*S29'
.param V27_part4='V27_part3+(-3.518555e-01)*S30+7.142536e-03*S31+(-7.085974e-02)*S32+(-7.557705e-01)*S33+1.699867e-02*S34+6.714980e-02*S35+(-1.294058e+03)*S36+1.661533e-01*S37+2.559905e+01*S38+(-6.806592e+01)*S39'
.param V27_part5='V27_part4+1.405453e-01*S40+2.756353e-02*S41+(-1.813086e+03)*S42+4.478021e-02*S43+(-3.245201e-02)*S44+3.517399e+00*S45+5.369390e-02*S46+(-3.641749e-02)*S47+3.448303e-01*S48+4.126008e-01*S49'
.param V27_part6='V27_part5+(-2.752314e-02)*S50+(-5.053228e-01)*S51+(-4.341101e-03)*S52+(-5.819187e-02)*S53+1.010790e-01*S54+1.568079e-02*S55+(-6.536836e-02)*S56+(-5.535081e-01)*S57+1.221001e-02*S58+(-5.878292e-02)*S59'
.param V27_part7='V27_part6+3.577410e+00*S60+2.228803e+00*S61+(-7.804689e-02)*S62+1.323292e+00*S63+6.739925e-02*S64+(-1.513112e-01)*S65+9.710552e-01*S66+1.527754e-01*S67+(-5.551356e-02)*S68+1.796193e-01*S69'
.param V27_part8='V27_part7+(-1.481521e-01)*S70+(-9.262512e-02)*S71+3.478200e-01*S72+(-3.464351e-02)*S73+(-8.021139e-02)*S74+2.417612e+00*S75+2.248451e-01*S76+(-5.702891e-02)*S77+2.258758e+00*S78+2.928549e-01*S79'
.param V27_part9='V27_part8+4.413597e-02*S80+(-4.844995e-01)*S81+1.832217e-01*S82+4.718079e-02*S83+(-6.071253e-01)*S84+(-1.810714e-01)*S85+7.362812e-02*S86+(-6.199036e-01)*S87+9.117316e-02*S88+(-3.921278e-02)*S89'
.param V27_part10='V27_part9+(-2.270292e-01)*S90+(-4.079521e+00)*S91+(-2.743184e+00)*S92+(-1.718966e+02)*S93+(-8.771512e-02)*S94+(-6.206276e-01)*S95+(-6.935538e+02)*S96+(-6.131390e+00)*S97+(-3.869812e-02)*S98+(-2.648968e+03)*S99'
.param V27_part11='V27_part10+(-8.124851e-02)*S100+(-8.062386e-02)*S101+(-2.377760e+02)*S102+9.706973e-02*S103+(-4.733559e-02)*S104+(-1.000000e+04)*S105+1.199724e-02*S106+2.518455e-02*S107+(-9.191139e+03)*S108+(-1.264254e+01)*S109'
.param V27_part12='V27_part11+(-1.292103e-01)*S110+1.552991e-01*S111+(-1.976663e+01)*S112+(-1.265349e-01)*S113+2.186101e-01*S114+(-9.125696e-02)*S115+(-6.260229e-02)*S116+(-3.556361e-01)*S117+1.377344e-01*S118+(-1.690420e-01)*S119'
.param V27_part13='V27_part12+(-3.966596e-01)*S120+3.649740e-01*S121+(-1.116898e-01)*S122+(-3.161368e-01)*S123+(-1.117630e+00)*S124+1.393699e-01*S125+9.483173e-01*S126+4.188844e-01*S127+1.485713e-01*S128+2.064721e-01*S129'
.param V27_part14='V27_part13+4.080270e-01*S130+1.412149e-01*S131+(-5.393168e-01)*S132+3.252892e-01*S133+1.393794e-01*S134+2.577305e+00*S135+1.373190e-01*S136+(-6.097183e-01)*S137+1.389743e+00*S138+4.078640e-02*S139'
.param V27_part15='V27_part14+(-5.658459e-02)*S140+5.052591e-02*S141+2.665190e-01*S142+6.896795e-02*S143+9.372550e-01*S144+3.827755e-01*S145+9.510363e-03*S146+4.571299e-01*S147+(-5.483490e-01)*S148+(-1.195046e-01)*S149'
.param V27_part16='V27_part15+(-2.318424e+01)*S150+1.552411e-02*S151+(-2.143615e+00)*S152+1.398357e+00*S153+(-6.904579e-01)*S154+(-1.462175e+00)*S155+(-4.539491e-01)*S156+(-1.923429e-01)*S157+(-2.420769e-01)*S158+4.151914e-01*S159'
.param V27_part17='V27_part16+(-1.907791e-01)*S160+9.684708e-02*S161+(-1.000461e+00)*S162+(-2.167228e-01)*S163+(-6.251227e-02)*S164+(-2.596730e+00)*S165+(-8.285677e-01)*S166+1.739711e-01*S167+(-1.310371e+01)*S168+(-5.189270e-01)*S169'
.param V27_part18='V27_part17+2.081970e-01*S170+(-1.046271e+00)*S171+7.863607e-01*S172+1.214847e-02*S173+(-9.672650e-01)*S174+(-2.912854e-02)*S175+3.113924e-02*S176+1.146845e-02*S177+7.126778e-01*S178+2.371722e-02*S179'
.param V27_part19='V27_part18+1.700255e+00*S180+2.768924e-02*S181+(-2.280451e-01)*S182+(-1.374623e+02)*S183+(-6.177768e+00)*S184+(-6.705369e-01)*S185+(-2.607602e+02)*S186+(-4.772955e+00)*S187+1.165528e-01*S188+(-8.270552e-01)*S189'
.param V27_part20='V27_part19+8.443653e-01*S190+7.175712e-02*S191+(-6.512609e-01)*S192+(-2.012219e-01)*S193+8.127585e-02*S194+(-2.321994e-01)*S195+(-8.891774e-01)*S196+(-7.161539e-02)*S197+2.077925e+00*S198+(-4.932377e-01)*S199'
.param V27_part21='V27_part20+(-1.244648e-01)*S200+(-2.031202e+00)*S201+(-3.811179e-01)*S202+7.940512e-02*S203+(-9.606546e-01)*S204+6.820723e-01*S205+(-1.419271e-02)*S206+(-1.210097e+00)*S207+5.981689e-01*S208+(-5.400359e-03)*S209'
.param V27_part22='V27_part21+(-1.483189e+00)*S210+1.590055e+00*S211+(-1.709143e+00)*S212+(-1.208787e+00)*S213+1.694546e-01*S214+(-6.863557e-01)*S215+2.327274e-01*S216+1.020864e+00*S217+(-3.175317e-01)*S218+4.914242e-01*S219'
.param V27_part23='V27_part22+8.176189e-01*S220+2.569268e-01*S221+5.500365e-01*S222+8.706493e-01*S223+4.251671e-01*S224+(-1.191329e+00)*S225+1.684885e+00*S226+1.828967e-01*S227+1.274965e-01*S228+(-6.066822e-01)*S229'
.param V27_part24='V27_part23+3.090467e-01*S230+(-9.757711e-01)*S231+(-4.016530e-01)*S232+1.751102e-01*S233+(-7.828546e-01)*S234+(-1.666926e-01)*S235+1.686530e-01*S236+4.628073e-01*S237+(-1.989231e-01)*S238+2.588180e-01*S239'
.param V27_part25='V27_part24+(-1.884583e+00)*S240+(-1.019536e+00)*S241+2.259078e-01*S242+(-1.813727e+00)*S243+(-4.536764e-01)*S244+3.517670e-01*S245+(-1.547025e-04)*S246+1.175631e+00*S247+2.147548e-01*S248+(-7.710081e-01)*S249'
.param V27_part26='V27_part25+(-2.263172e-01)*S250+2.328047e-01*S251+(-1.489555e-01)*S252+(-1.761734e-01)*S253+1.371996e-01*S254+2.070547e+00*S255+(-1.509905e+00)*S256+4.579254e-01*S257+2.036369e+00*S258+1.012676e+00*S259'
.param V27_part27='V27_part26+2.965036e-01*S260+(-7.493438e-01)*S261+6.081867e-01*S262+3.022588e-01*S263+(-7.561178e-01)*S264+9.751850e-01*S265+4.517751e-02*S266+(-2.714764e-01)*S267+(-2.166301e-01)*S268+1.159592e-01*S269'
.param V27_part28='V27_part27+(-6.869723e-01)*S270+(-5.844251e-01)*S271+2.930200e-01*S272+(-8.518357e-01)*S273+(-3.250022e-01)*S274+3.395205e-01*S275+(-8.369266e-01)*S276+(-4.770197e-01)*S277+1.881721e-01*S278+6.396013e-01*S279'
.param V27_part29='V27_part28+(-1.189345e+00)*S280+1.737842e-01*S281+(-6.997404e-01)*S282+(-1.086022e+00)*S283+1.688633e-01*S284+(-1.264941e+00)*S285+2.183933e+00*S286+(-5.221974e-01)*S287+(-9.109058e-01)*S288+(-4.443372e-01)*S289'
.param V27_part30='V27_part29+2.485024e-01*S290+6.038349e-01*S291+1.297322e+00*S292+1.893208e-01*S293+8.289778e-01*S294+1.148116e+00*S295+2.165301e-01*S296+6.522562e-01*S297+(-2.374706e-01)*S298+2.248001e-01*S299'
.param V27_part31='V27_part30+(-2.020809e+00)*S300+(-1.152322e-02)*S301+3.055499e-01*S302+2.458993e-01*S303+1.170974e+00*S304+3.896156e-01*S305+5.011047e-01*S306+(-2.858187e-01)*S307+9.080653e-02*S308+2.107246e-01*S309'
.param V27='V27_part31+(-2.270294e-01)*S310+1.043826e-01*S311+1.855216e-01*S312+(-2.072712e-01)*S313+8.440672e-02*S314'
.param V28_part1='3.176421e-01*S0+(-5.966692e-05)*S1+2.121181e-03*S2+6.402812e-02*S3+(-2.061850e-02)*S4+4.719145e-01*S5+2.564453e-01*S6+(-4.609226e-02)*S7+(-2.552946e-02)*S8+1.537709e-01*S9'
.param V28_part2='V28_part1+(-3.303477e-02)*S10+1.242861e-01*S11+(-2.573202e-01)*S12+(-1.075769e-01)*S13+(-1.178837e-01)*S14+(-4.425077e-03)*S15+3.320033e-03*S16+9.333769e-02*S17+2.730497e-01*S18+(-9.287324e-03)*S19'
.param V28_part3='V28_part2+(-2.320389e-02)*S20+1.089077e-01*S21+(-9.683666e-03)*S22+1.892217e-01*S23+7.057333e-02*S24+(-5.074615e-02)*S25+(-8.911364e-03)*S26+(-3.890743e-01)*S27+(-1.499828e-01)*S28+(-3.209492e-02)*S29'
.param V28_part4='V28_part3+1.948490e-01*S30+1.052122e-02*S31+(-9.480468e-02)*S32+1.080106e-01*S33+(-1.665523e-01)*S34+(-5.384798e-02)*S35+(-1.116188e-01)*S36+(-1.074950e-01)*S37+(-9.070666e+00)*S38+(-1.173597e-01)*S39'
.param V28_part5='V28_part4+(-2.408301e-01)*S40+(-2.481059e-01)*S41+(-1.517546e-01)*S42+(-1.719800e-01)*S43+(-1.307045e-01)*S44+3.711951e-01*S45+2.934417e-02*S46+(-1.566955e-01)*S47+(-1.168048e-01)*S48+6.003735e-02*S49'
.param V28_part6='V28_part5+(-2.012299e-01)*S50+(-3.282449e-04)*S51+9.233587e-04*S52+2.360536e-01*S53+(-8.479006e-02)*S54+1.131979e-03*S55+2.418109e-01*S56+(-6.593441e-02)*S57+2.039589e-01*S58+2.405876e-01*S59'
.param V28_part7='V28_part6+3.079081e-01*S60+1.338243e-01*S61+(-5.015516e-03)*S62+7.261742e-02*S63+1.029694e-02*S64+(-2.382763e-02)*S65+3.974614e-02*S66+(-4.486993e-03)*S67+(-7.226430e-02)*S68+2.864245e-02*S69'
.param V28_part8='V28_part7+(-3.886601e-01)*S70+(-9.133465e-02)*S71+(-2.606862e-01)*S72+(-2.211729e-01)*S73+(-9.232784e-02)*S74+2.948160e-01*S75+1.970128e-01*S76+5.026365e-03*S77+2.324110e-01*S78+(-1.673318e-01)*S79'
.param V28_part9='V28_part8+1.604884e-01*S80+1.602241e-02*S81+1.260331e-01*S82+1.079057e-01*S83+1.178542e-02*S84+(-1.674051e-02)*S85+(-1.030802e-01)*S86+3.654105e-03*S87+(-1.295546e-01)*S88+(-6.251608e-04)*S89'
.param V28_part10='V28_part9+(-8.791384e-03)*S90+1.630311e-01*S91+1.447748e+00*S92+1.712359e-01*S93+7.574330e-02*S94+2.153432e-01*S95+(-5.179958e-03)*S96+9.168260e-02*S97+(-1.106272e-01)*S98+(-2.488224e-02)*S99'
.param V28_part11='V28_part10+(-8.196082e-02)*S100+(-1.068417e-01)*S101+(-2.708081e-01)*S102+(-1.083126e-01)*S103+(-1.277774e-01)*S104+(-1.567884e-03)*S105+(-2.677458e-03)*S106+(-4.318517e-03)*S107+(-6.595823e-04)*S108+(-6.341211e-02)*S109'
.param V28_part12='V28_part11+1.028653e-02*S110+(-5.700084e-03)*S111+(-2.348324e-01)*S112+(-1.053415e-02)*S113+(-2.557784e-02)*S114+4.794250e-03*S115+(-8.704813e-02)*S116+(-3.132356e-02)*S117+(-1.880418e-01)*S118+(-1.126896e-01)*S119'
.param V28_part13='V28_part12+1.960864e-02*S120+(-6.456208e-03)*S121+1.095141e-02*S122+(-4.873968e-03)*S123+1.702951e-02*S124+(-1.528273e-02)*S125+2.560726e-02*S126+(-1.084652e-02)*S127+(-1.252450e-02)*S128+(-1.325927e-02)*S129'
.param V28_part14='V28_part13+(-1.426377e-02)*S130+(-8.781266e-03)*S131+1.002438e-02*S132+(-1.322980e-02)*S133+(-1.711800e-02)*S134+1.235243e-01*S135+7.378758e-03*S136+2.432843e-03*S137+5.496019e-02*S138+3.868848e-03*S139'
.param V28_part15='V28_part14+(-1.069569e-01)*S140+(-2.643618e-01)*S141+(-1.003100e-02)*S142+4.226170e-03*S143+2.377788e-02*S144+(-9.556132e-03)*S145+(-1.451983e-02)*S146+(-2.967862e-03)*S147+(-7.470450e-03)*S148+(-2.504830e-02)*S149'
.param V28_part16='V28_part15+3.100818e-03*S150+3.640843e-02*S151+2.060443e-01*S152+3.095090e-02*S153+(-6.033314e-02)*S154+2.172451e-01*S155+(-4.566165e-02)*S156+(-1.087896e-02)*S157+1.560318e-02*S158+(-2.152848e-02)*S159'
.param V28_part17='V28_part16+(-1.919255e-02)*S160+3.949235e-02*S161+6.603078e-02*S162+(-2.196431e-02)*S163+(-1.055961e-01)*S164+(-3.244662e-03)*S165+(-6.184787e-02)*S166+3.846067e-03*S167+(-1.101404e-02)*S168+2.738983e-02*S169'
.param V28_part18='V28_part17+(-8.249597e-05)*S170+1.157545e-01*S171+(-1.111177e-02)*S172+3.327154e-02*S173+5.618563e-02*S174+(-8.920703e-02)*S175+3.159400e-02*S176+(-3.875734e-03)*S177+(-9.573264e-03)*S178+4.516146e-02*S179'
.param V28_part19='V28_part18+1.461769e-02*S180+1.722299e-02*S181+1.370355e-02*S182+(-1.512590e-02)*S183+(-1.344916e-02)*S184+6.029815e-02*S185+(-2.584404e-02)*S186+(-1.994244e-02)*S187+1.662485e-02*S188+4.626861e-02*S189'
.param V28_part20='V28_part19+(-2.009923e-02)*S190+3.022427e-02*S191+7.932687e-02*S192+(-1.808490e-02)*S193+3.170900e-02*S194+9.559038e-03*S195+1.319350e-02*S196+(-7.021272e-03)*S197+5.395374e-02*S198+(-1.808833e-01)*S199'
.param V28_part21='V28_part20+(-4.135742e-02)*S200+(-8.493699e-02)*S201+(-1.561473e-01)*S202+(-8.849055e-02)*S203+6.545348e-02*S204+(-1.621761e-02)*S205+(-6.010604e-02)*S206+1.042575e-02*S207+(-1.431717e-02)*S208+(-9.513144e-02)*S209'
.param V28_part22='V28_part21+(-8.252510e-02)*S210+2.572621e-02*S211+1.545045e-01*S212+(-1.003389e-01)*S213+5.160800e-02*S214+8.660206e-02*S215+7.342973e-03*S216+(-1.549662e-02)*S217+5.223628e-02*S218+(-3.813663e-03)*S219'
.param V28_part23='V28_part22+(-9.793491e-03)*S220+(-4.062006e-02)*S221+(-5.259278e-02)*S222+(-1.448368e-02)*S223+1.659251e-02*S224+(-5.519443e-03)*S225+3.762038e-03*S226+3.456428e-02*S227+1.458112e-02*S228+(-7.217638e-02)*S229'
.param V28_part24='V28_part23+5.002087e-02*S230+5.013584e-02*S231+(-7.280663e-03)*S232+1.978537e-02*S233+3.686668e-02*S234+(-1.008313e-02)*S235+2.738949e-02*S236+(-3.665153e-02)*S237+(-1.687775e-02)*S238+4.870267e-02*S239'
.param V28_part25='V28_part24+(-9.522430e-02)*S240+(-3.013140e-02)*S241+2.271937e-02*S242+(-2.177402e-02)*S243+(-6.967582e-02)*S244+2.162384e-02*S245+(-1.380782e-01)*S246+(-7.963266e-03)*S247+2.736239e-02*S248+5.465567e-02*S249'
.param V28_part26='V28_part25+(-1.198256e-02)*S250+2.361418e-02*S251+6.731263e-02*S252+(-1.833777e-02)*S253+2.929897e-02*S254+2.097437e-02*S255+(-7.570956e-05)*S256+(-3.225435e-03)*S257+(-1.238560e-02)*S258+(-7.715422e-03)*S259'
.param V28_part27='V28_part26+(-8.594722e-03)*S260+5.863682e-03*S261+(-1.894958e-02)*S262+(-1.280847e-01)*S263+1.576803e-03*S264+(-2.290604e-02)*S265+1.525139e-02*S266+(-6.063190e-02)*S267+(-9.994483e-03)*S268+2.330884e-02*S269'
.param V28_part28='V28_part27+(-2.269033e-02)*S270+(-2.407921e-02)*S271+2.425373e-02*S272+4.075843e-02*S273+(-1.598628e-02)*S274+3.808139e-02*S275+3.759537e-02*S276+(-6.318547e-02)*S277+2.609878e-02*S278+5.784966e-03*S279'
.param V28_part29='V28_part28+(-1.072652e-01)*S280+2.723514e-02*S281+3.432324e-02*S282+(-4.956792e-02)*S283+2.732799e-02*S284+(-8.320804e-02)*S285+3.494148e-03*S286+8.781397e-02*S287+6.030297e-02*S288+(-2.231838e-02)*S289'
.param V28_part30='V28_part29+(-1.240173e-02)*S290+(-8.669835e-03)*S291+(-8.251430e-03)*S292+2.283907e-02*S293+(-1.959711e-02)*S294+(-1.148616e-02)*S295+1.601123e-02*S296+(-7.056967e-02)*S297+(-1.792452e-02)*S298+1.622530e-02*S299'
.param V28_part31='V28_part30+(-4.086674e-02)*S300+(-1.304135e-03)*S301+(-3.953682e-02)*S302+1.463507e-02*S303+(-2.057053e-02)*S304+(-4.955375e-02)*S305+(-2.403018e-02)*S306+(-1.243617e-02)*S307+1.565051e-02*S308+1.640651e-02*S309'
.param V28='V28_part31+(-1.224859e-02)*S310+1.804230e-02*S311+(-6.064183e-03)*S312+(-1.441457e-02)*S313+2.225241e-02*S314'
.param V29_part1='(-2.438024e-03)*S0+2.310671e-03*S1+1.894479e-03*S2+(-8.285987e-04)*S3+(-6.080612e-04)*S4+(-1.470431e-03)*S5+(-3.895173e-03)*S6+(-4.742663e-04)*S7+(-2.138819e-03)*S8+(-4.181323e-05)*S9'
.param V29_part2='V29_part1+(-6.674100e-06)*S10+(-1.115851e-04)*S11+(-1.978814e-03)*S12+(-1.153996e-03)*S13+1.726530e-03*S14+(-3.026604e-05)*S15+(-1.358358e-05)*S16+2.890826e-03*S17+1.108483e-03*S18+(-9.192129e-04)*S19'
.param V29_part3='V29_part2+(-1.484053e-03)*S20+9.599336e-04*S21+(-1.006527e-03)*S22+(-3.665818e-03)*S23+(-3.829147e-04)*S24+3.663919e-05*S25+1.618150e-03*S26+(-5.552203e-03)*S27+2.330811e-04*S28+1.260375e-03*S29'
.param V29_part4='V29_part3+1.820744e-02*S30+1.498921e-03*S31+(-2.792562e-03)*S32+1.445759e-02*S33+(-2.946971e-02)*S34+2.386593e-03*S35+(-2.092994e-01)*S36+4.777735e-03*S37+(-1.636958e-01)*S38+(-1.686597e-01)*S39'
.param V29_part5='V29_part4+3.528340e-03*S40+1.597359e-02*S41+(-5.628414e-01)*S42+(-9.147006e-04)*S43+6.073634e-04*S44+5.196890e-02*S45+(-2.913632e-03)*S46+(-8.677236e-03)*S47+5.476962e-02*S48+1.894706e-02*S49'
.param V29_part6='V29_part5+(-5.807481e-03)*S50+(-9.919627e-03)*S51+4.717986e-02*S52+(-4.147151e-03)*S53+8.596434e-04*S54+5.902908e-02*S55+(-3.392008e-03)*S56+(-4.726153e-03)*S57+5.467690e-03*S58+(-3.210517e-03)*S59'
.param V29_part7='V29_part6+7.597451e-02*S60+1.094991e-01*S61+1.340222e-02*S62+2.026031e-02*S63+(-4.448622e-03)*S64+1.316564e-03*S65+2.524673e-02*S66+2.065063e-02*S67+8.811731e-03*S68+3.512318e-02*S69'
.param V29_part8='V29_part7+2.070188e-02*S70+3.963286e-03*S71+2.715756e-01*S72+4.393835e-03*S73+7.994607e-03*S74+4.037810e-02*S75+(-1.073913e-01)*S76+(-4.724428e-02)*S77+2.928220e-02*S78+1.637866e-01*S79'
.param V29_part9='V29_part8+5.271497e-02*S80+(-1.018302e-02)*S81+3.206735e-02*S82+3.057861e-02*S83+(-6.834235e-03)*S84+(-3.933954e-02)*S85+6.325115e-02*S86+(-4.498655e-03)*S87+6.987721e-02*S88+(-5.923090e-03)*S89'
.param V29_part10='V29_part9+(-1.747725e-02)*S90+(-1.154942e-01)*S91+1.813811e-02*S92+(-5.395111e-03)*S93+(-8.120076e-02)*S94+(-8.975542e-02)*S95+(-3.544285e-02)*S96+(-2.950943e-01)*S97+2.314411e-02*S98+(-4.448958e-02)*S99'
.param V29_part11='V29_part10+4.954448e-03*S100+1.396748e-02*S101+(-9.868896e-01)*S102+2.538668e-03*S103+9.643087e-03*S104+(-3.968399e-03)*S105+(-1.442632e-02)*S106+(-3.183978e-02)*S107+3.474088e-03*S108+(-7.799899e-01)*S109'
.param V29_part12='V29_part11+(-2.229327e-02)*S110+(-2.709616e-02)*S111+(-5.377048e-01)*S112+(-2.704070e-02)*S113+(-4.417318e-02)*S114+(-2.616213e-02)*S115+1.847106e-02*S116+(-3.831720e-02)*S117+1.236661e-02*S118+(-3.707796e-03)*S119'
.param V29_part13='V29_part12+2.330962e-01*S120+2.471339e-03*S121+(-1.978627e-02)*S122+(-3.875891e-02)*S123+(-9.092167e-02)*S124+(-8.855018e-03)*S125+2.497327e-03*S126+(-1.597762e-03)*S127+(-1.721506e-03)*S128+(-6.582864e-02)*S129'
.param V29_part14='V29_part13+(-3.460632e-03)*S130+1.737756e-03*S131+8.391403e-02*S132+(-4.008069e-04)*S133+1.623720e-03*S134+4.810695e-02*S135+8.638790e-03*S136+(-5.566916e-02)*S137+1.499292e-02*S138+(-3.894348e-03)*S139'
.param V29_part15='V29_part14+(-5.840688e-02)*S140+3.467017e-02*S141+2.000054e-03*S142+4.152617e-02*S143+(-7.036236e-03)*S144+(-2.728854e-03)*S145+5.366471e-03*S146+(-3.668836e-02)*S147+(-1.868347e-03)*S148+(-1.196759e-02)*S149'
.param V29_part16='V29_part15+(-2.846396e-01)*S150+(-3.624970e-02)*S151+(-2.888373e-01)*S152+3.134705e-03*S153+(-2.164407e-01)*S154+(-5.337553e-02)*S155+(-1.827263e-02)*S156+(-3.112077e-02)*S157+(-4.198214e-02)*S158+(-9.020101e-02)*S159'
.param V29_part17='V29_part16+(-2.419269e-02)*S160+(-7.466224e-02)*S161+1.848618e-01*S162+(-1.508124e-02)*S163+2.031391e-02*S164+(-3.318514e-02)*S165+(-2.617103e-01)*S166+(-7.171487e-02)*S167+(-2.894822e-01)*S168+(-4.751380e-02)*S169'
.param V29_part18='V29_part17+(-4.206528e-02)*S170+4.746974e-02*S171+(-4.900960e-03)*S172+(-6.246928e-02)*S173+9.425889e-02*S174+(-1.239036e-01)*S175+(-4.992208e-02)*S176+(-1.371539e-01)*S177+(-7.534733e-04)*S178+(-4.324756e-02)*S179'
.param V29_part19='V29_part18+1.979992e-02*S180+(-3.216118e-02)*S181+(-2.716185e-02)*S182+(-3.960144e-02)*S183+(-2.475788e-01)*S184+(-1.051883e-01)*S185+(-3.814313e-02)*S186+(-1.799082e-01)*S187+(-6.701305e-02)*S188+1.270552e-01*S189'
.param V29_part20='V29_part19+1.893779e-03*S190+(-4.781387e-02)*S191+1.258376e-01*S192+(-3.211287e-02)*S193+(-5.786503e-02)*S194+2.491544e-01*S195+(-9.526220e-02)*S196+(-2.424603e-02)*S197+(-1.542014e-02)*S198+(-2.008683e-01)*S199'
.param V29_part21='V29_part20+(-1.201427e-01)*S200+(-1.588725e-01)*S201+(-1.852420e-01)*S202+(-1.722818e-01)*S203+8.852813e-02*S204+(-3.629131e-03)*S205+(-1.330823e-01)*S206+4.495462e-01*S207+(-3.678903e-03)*S208+(-1.334410e-01)*S209'
.param V29_part22='V29_part21+(-3.324131e-01)*S210+(-2.799038e-02)*S211+(-1.873058e-02)*S212+(-3.031227e-01)*S213+(-7.555559e-02)*S214+(-3.819237e-02)*S215+(-9.297569e-02)*S216+(-3.348965e-03)*S217+(-1.451518e-02)*S218+(-1.909251e-01)*S219'
.param V29_part23='V29_part22+4.656673e-03*S220+(-2.593947e-01)*S221+(-8.586834e-02)*S222+(-1.043447e-02)*S223+(-7.985622e-02)*S224+(-1.883229e-01)*S225+1.839308e-02*S226+(-1.437706e-01)*S227+(-1.074435e-01)*S228+(-3.039520e-01)*S229'
.param V29_part24='V29_part23+(-1.463025e-01)*S230+1.087841e-01*S231+(-5.003983e-02)*S232+(-6.095915e-02)*S233+1.385815e-01*S234+(-3.512286e-02)*S235+(-6.298117e-02)*S236+(-8.640735e-02)*S237+(-3.158317e-02)*S238+(-1.358944e-01)*S239'
.param V29_part25='V29_part24+(-4.647873e-01)*S240+(-3.246078e-01)*S241+(-1.644638e-01)*S242+(-3.291868e-01)*S243+(-2.844640e-01)*S244+(-1.235632e-01)*S245+(-1.469683e-01)*S246+5.408966e-04*S247+(-7.938928e-02)*S248+1.525219e-01*S249'
.param V29_part26='V29_part25+(-4.079525e-02)*S250+(-6.024545e-02)*S251+(-1.707594e-01)*S252+(-3.558699e-02)*S253+(-6.537056e-02)*S254+2.059840e-02*S255+(-4.099920e-03)*S256+2.408382e-03*S257+5.676347e-02*S258+(-3.166704e-03)*S259'
.param V29_part27='V29_part26+(-2.443186e-03)*S260+1.549378e-01*S261+4.783049e-03*S262+(-2.166631e-01)*S263+1.445204e-01*S264+1.764383e-03*S265+(-4.991786e-02)*S266+(-1.524317e-01)*S267+(-3.172722e-02)*S268+(-4.898441e-02)*S269'
.param V29_part28='V29_part27+(-2.430991e-01)*S270+(-1.061076e-01)*S271+(-1.209169e-01)*S272+1.527915e-01*S273+(-3.686188e-02)*S274+(-1.849169e-01)*S275+1.399192e-01*S276+(-2.722188e-01)*S277+(-5.224736e-02)*S278+(-2.814411e-01)*S279'
.param V29_part29='V29_part28+(-2.571581e-01)*S280+(-5.204262e-02)*S281+1.349654e-01*S282+(-1.245020e-01)*S283+(-7.087996e-02)*S284+(-5.768218e-01)*S285+6.369000e-03*S286+(-2.937283e-02)*S287+1.175687e-01*S288+(-6.158035e-02)*S289'
.param V29_part30='V29_part29+(-5.129249e-02)*S290+(-2.108962e-01)*S291+2.938791e-03*S292+(-1.244194e-01)*S293+(-4.370892e-01)*S294+(-2.179115e-03)*S295+(-8.917253e-02)*S296+(-4.784649e-01)*S297+(-3.266720e-02)*S298+(-9.178486e-02)*S299'
.param V29_part31='V29_part30+(-3.511427e-01)*S300+(-5.292666e-02)*S301+(-1.561886e-01)*S302+(-1.248760e-01)*S303+9.304320e-03*S304+(-1.608261e-01)*S305+(-9.752707e-02)*S306+(-4.109810e-02)*S307+(-6.074309e-02)*S308+(-1.650295e-01)*S309'
.param V29='V29_part31+(-3.339348e-02)*S310+(-6.630719e-02)*S311+(-2.417971e-01)*S312+(-3.077769e-02)*S313+(-7.534622e-02)*S314'
.param V30_part1='(-6.973486e-02)*S0+(-2.406125e-01)*S1+(-6.171013e-01)*S2+7.095994e-02*S3+1.146587e-01*S4+(-7.132130e-01)*S5+3.100055e-01*S6+3.534901e-01*S7+(-3.026525e-01)*S8+7.457825e-01*S9'
.param V30_part2='V30_part1+(-7.219060e-01)*S10+(-5.011659e-01)*S11+(-9.331898e-01)*S12+(-4.735059e-01)*S13+(-3.666661e-01)*S14+(-2.818549e-01)*S15+3.781832e-01*S16+(-1.672865e-01)*S17+2.456079e-01*S18+(-4.549502e-01)*S19'
.param V30_part3='V30_part2+(-9.873977e-01)*S20+(-6.460895e-01)*S21+(-6.842169e-01)*S22+(-5.874915e-01)*S23+5.386418e-02*S24+1.837613e-03*S25+(-1.860954e+00)*S26+(-1.651581e+00)*S27+(-9.776842e-01)*S28+(-1.964423e+00)*S29'
.param V30_part4='V30_part3+(-7.525420e-01)*S30+(-1.407304e+00)*S31+(-1.642546e-01)*S32+(-1.151749e+00)*S33+(-1.741465e+00)*S34+(-1.609511e+00)*S35+(-1.635677e+00)*S36+(-1.445378e+00)*S37+(-4.926015e+00)*S38+(-1.745265e+00)*S39'
.param V30_part5='V30_part4+(-1.486207e+00)*S40+(-7.117255e+00)*S41+(-1.056998e+00)*S42+(-3.166853e+00)*S43+(-6.548193e+00)*S44+9.805615e-01*S45+(-2.878613e-01)*S46+8.707433e-01*S47+(-7.698895e-01)*S48+(-1.475229e+00)*S49'
.param V30_part6='V30_part5+1.427457e+00*S50+(-1.408912e+00)*S51+(-2.569960e+00)*S52+(-5.057652e+00)*S53+(-8.571628e-01)*S54+(-2.923321e+00)*S55+(-5.032642e+00)*S56+(-8.813115e-01)*S57+(-1.800393e+00)*S58+(-4.592971e+00)*S59'
.param V30_part7='V30_part6+2.922447e-02*S60+1.533951e-02*S61+(-4.782363e+00)*S62+(-2.383466e-01)*S63+(-1.293842e+00)*S64+(-4.532466e+00)*S65+(-6.205196e-01)*S66+(-3.430237e+00)*S67+(-8.719195e+00)*S68+(-4.894396e-01)*S69'
.param V30_part8='V30_part7+(-5.024957e+00)*S70+(-1.003238e+01)*S71+(-1.268216e-01)*S72+(-4.415581e+00)*S73+(-8.533438e+00)*S74+(-2.548665e-01)*S75+(-3.740046e-01)*S76+(-2.595397e+00)*S77+(-9.773900e-02)*S78+(-1.352056e-01)*S79'
.param V30_part9='V30_part8+(-1.632743e+00)*S80+(-1.283011e+00)*S81+(-7.931586e-01)*S82+(-2.631303e+00)*S83+(-1.139212e+00)*S84+(-1.331397e+00)*S85+(-3.362369e+00)*S86+(-7.128524e-01)*S87+(-1.688621e+00)*S88+(-2.823818e+00)*S89'
.param V30_part10='V30_part9+(-9.163697e-01)*S90+(-2.662194e+00)*S91+(-7.399514e+00)*S92+(-1.802958e+00)*S93+(-3.220403e+00)*S94+(-8.362811e+00)*S95+(-2.226815e+00)*S96+(-4.481136e+00)*S97+(-1.227199e+01)*S98+(-2.036106e+00)*S99'
.param V30_part11='V30_part10+(-2.090197e+00)*S100+(-1.397603e+01)*S101+(-8.836820e-01)*S102+(-3.713988e+00)*S103+(-4.936081e+00)*S104+(-1.092000e+00)*S105+(-3.483458e+00)*S106+(-8.341774e+00)*S107+(-1.135737e+00)*S108+(-3.121135e+00)*S109'
.param V30_part12='V30_part11+(-1.172491e+01)*S110+(-1.454194e+00)*S111+(-4.667064e+00)*S112+(-1.309441e+01)*S113+(-1.352127e+00)*S114+(-3.700698e-01)*S115+(-2.403362e+00)*S116+(-7.644561e-01)*S117+(-1.511334e+00)*S118+(-1.110760e+01)*S119'
.param V30_part13='V30_part12+(-4.438420e-01)*S120+(-4.119067e+00)*S121+(-8.626638e+00)*S122+(-1.008770e+00)*S123+(-4.375852e+00)*S124+(-6.541263e+00)*S125+(-1.451778e+00)*S126+(-2.954638e+00)*S127+(-2.658082e+00)*S128+(-6.152282e-01)*S129'
.param V30_part14='V30_part13+(-2.107703e+00)*S130+(-1.433895e+01)*S131+(-5.893736e-01)*S132+(-9.772588e-01)*S133+(-1.366438e+01)*S134+8.379467e-01*S135+(-1.016143e+00)*S136+(-5.433409e+00)*S137+1.297294e-01*S138+(-1.343303e+00)*S139'
.param V30_part15='V30_part14+(-6.689864e+00)*S140+(-6.594298e-01)*S141+(-4.819581e+00)*S142+(-4.954985e+00)*S143+(-1.955260e+00)*S144+(-4.350173e+00)*S145+(-5.803317e+00)*S146+(-3.334465e+00)*S147+(-4.918254e+00)*S148+(-7.780804e+00)*S149'
.param V30_part16='V30_part15+(-9.442533e-01)*S150+(-5.193506e+00)*S151+(-9.038110e+00)*S152+(-2.163443e+00)*S153+(-5.972441e+00)*S154+(-1.001588e+01)*S155+(-1.562313e+00)*S156+(-8.161449e+00)*S157+(-1.759211e+01)*S158+(-2.461732e+00)*S159'
.param V30_part17='V30_part16+(-5.703250e+00)*S160+(-1.367030e+01)*S161+(-1.089040e+00)*S162+(-8.113084e+00)*S163+(-1.522800e+01)*S164+(-4.411560e-01)*S165+(-4.503315e+00)*S166+(-1.589424e+01)*S167+(-1.101565e+00)*S168+(-5.146619e+00)*S169'
.param V30_part18='V30_part17+(-1.743804e+01)*S170+(-1.099370e+00)*S171+(-2.937707e+00)*S172+(-7.076628e+00)*S173+(-1.409348e+00)*S174+(-3.131489e+00)*S175+(-1.736964e+01)*S176+(-1.429266e+00)*S177+(-5.491591e+00)*S178+(-1.258439e+01)*S179'
.param V30_part19='V30_part18+(-8.732806e-01)*S180+(-6.134945e+00)*S181+(-1.060281e+01)*S182+(-9.300840e-01)*S183+(-2.285860e+00)*S184+(-1.256094e+01)*S185+(-1.148824e+00)*S186+(-2.620661e+00)*S187+(-1.041722e+01)*S188+(-1.315406e+00)*S189'
.param V30_part20='V30_part19+(-3.653497e+00)*S190+(-9.469621e+00)*S191+(-1.311468e+00)*S192+(-6.428232e+00)*S193+(-8.143148e+00)*S194+(-1.395592e-01)*S195+(-1.782666e+00)*S196+(-1.140102e+01)*S197+(-3.256082e-02)*S198+(-3.674435e+00)*S199'
.param V30_part21='V30_part20+(-1.074554e+01)*S200+(-1.711329e+00)*S201+(-2.888567e+00)*S202+(-5.088684e+00)*S203+(-4.434860e-01)*S204+(-2.973649e+00)*S205+(-5.770022e+00)*S206+3.324777e-01*S207+(-4.944674e+00)*S208+(-7.692839e+00)*S209'
.param V30_part22='V30_part21+(-1.028724e+00)*S210+(-7.628731e+00)*S211+(-1.167616e+01)*S212+(-9.619040e-01)*S213+3.494210e-01*S214+(-1.522695e+01)*S215+(-1.626000e+00)*S216+(-8.075644e+00)*S217+(-1.385421e+01)*S218+(-2.092714e+00)*S219'
.param V30_part23='V30_part22+(-6.744952e+00)*S220+(-2.363775e+01)*S221+(-2.325122e+00)*S222+(-7.178478e+00)*S223+(-1.207391e+01)*S224+(-1.211563e+00)*S225+(-7.044399e+00)*S226+(-1.840092e+01)*S227+(-1.336274e+00)*S228+(-6.452246e+00)*S229'
.param V30_part24='V30_part23+(-1.800998e+01)*S230+(-1.558501e+00)*S231+(-6.621262e+00)*S232+(-1.411801e+01)*S233+(-1.477021e+00)*S234+(-6.634309e+00)*S235+(-1.538502e+01)*S236+(-1.584190e+00)*S237+(-8.168119e+00)*S238+(-1.578683e+01)*S239'
.param V30_part25='V30_part24+(-8.588643e-01)*S240+(-5.508863e+00)*S241+(-1.429908e+01)*S242+(-9.305821e-01)*S243+(-4.609640e+00)*S244+(-1.410842e+01)*S245+(-1.761273e+00)*S246+(-5.383663e+00)*S247+(-1.415408e+01)*S248+(-1.971226e+00)*S249'
.param V30_part26='V30_part25+(-6.903028e+00)*S250+(-1.631575e+01)*S251+(-1.187977e+00)*S252+(-8.543045e+00)*S253+(-1.333735e+01)*S254+(-1.233513e+00)*S255+(-4.012749e+00)*S256+(-1.548145e+01)*S257+(-4.465137e-01)*S258+(-6.320009e+00)*S259'
.param V30_part27='V30_part26+(-1.629996e+01)*S260+(-5.529923e-01)*S261+(-3.110749e+00)*S262+(-9.581453e+00)*S263+(-5.416796e-01)*S264+(-2.721672e+00)*S265+(-9.547553e+00)*S266+(-8.851898e-01)*S267+(-5.251032e+00)*S268+(-9.470300e+00)*S269'
.param V30_part28='V30_part27+(-7.191631e-01)*S270+(-5.563566e+00)*S271+(-2.486304e+01)*S272+(-1.808900e+00)*S273+(-9.842041e+00)*S274+(-2.303974e+01)*S275+(-1.836392e+00)*S276+(-7.633550e+00)*S277+(-1.922870e+01)*S278+(-2.300011e+00)*S279'
.param V30_part29='V30_part28+(-9.642447e+00)*S280+(-2.296105e+01)*S281+(-2.835434e+00)*S282+(-1.090547e+01)*S283+(-1.823683e+01)*S284+(-1.354233e+00)*S285+(-6.768524e+00)*S286+(-1.437460e+01)*S287+(-1.683360e+00)*S288+(-7.088452e+00)*S289'
.param V30_part30='V30_part29+(-1.808070e+01)*S290+(-2.296627e+00)*S291+(-8.452461e+00)*S292+(-1.848387e+01)*S293+(-2.387500e+00)*S294+(-9.646474e+00)*S295+(-2.022028e+01)*S296+(-2.587679e+00)*S297+(-1.073146e+01)*S298+(-1.973219e+01)*S299'
.param V30_part31='V30_part30+3.533701e-02*S300+(-5.608275e+00)*S301+(-6.612966e+00)*S302+(-4.991904e-01)*S303+(-3.302165e+00)*S304+(-7.597001e+00)*S305+(-1.239658e+00)*S306+(-5.434746e+00)*S307+(-1.159722e+01)*S308+(-1.208109e+00)*S309'
.param V30='V30_part31+(-6.623529e+00)*S310+(-1.390984e+01)*S311+(-1.259124e+00)*S312+(-8.604755e+00)*S313+(-1.205162e+01)*S314'
.param V31_part1='2.490824e+00*S0+2.577129e+00*S1+2.859299e+00*S2+2.289713e+00*S3+1.932649e+00*S4+1.694346e+00*S5+4.995996e-01*S6+1.265045e+00*S7+1.875599e+00*S8+1.113857e-01*S9'
.param V31_part2='V31_part1+1.505278e+00*S10+1.733038e+00*S11+1.358916e+00*S12+1.359359e+00*S13+1.781298e+00*S14+3.918042e+00*S15+1.975629e+00*S16+2.106821e+00*S17+2.070718e+00*S18+1.733343e+00*S19'
.param V31_part3='V31_part2+2.980570e+00*S20+2.303558e+00*S21+1.773517e+00*S22+1.782338e+00*S23+1.092815e+00*S24+6.399897e-01*S25+2.846088e+00*S26+2.695714e+00*S27+1.972849e+00*S28+2.718697e+00*S29'
.param V31_part4='V31_part3+5.885969e+00*S30+7.324912e+00*S31+4.868624e+00*S32+6.227266e+00*S33+7.099755e+00*S34+6.997124e+00*S35+6.915436e+00*S36+5.318938e+00*S37+9.069592e+00*S38+6.782629e+00*S39'
.param V31_part5='V31_part4+4.353308e+00*S40+1.079295e+01*S41+5.445198e+00*S42+6.735380e+00*S43+8.932401e+00*S44+3.572768e+00*S45+5.093373e+00*S46+2.315804e+00*S47+5.653708e+00*S48+6.789555e+00*S49'
.param V31_part6='V31_part5+2.160263e+00*S50+7.299608e+00*S51+7.261898e+00*S52+7.739077e+00*S53+4.862297e+00*S54+7.392732e+00*S55+6.935611e+00*S56+5.093468e+00*S57+4.113092e+00*S58+6.492562e+00*S59'
.param V31_part7='V31_part6+9.335181e+00*S60+(-3.056791e-02)*S61+1.144951e+01*S62+6.357798e+00*S63+6.921250e+00*S64+7.468492e+00*S65+6.359083e+00*S66+8.722515e+00*S67+1.116200e+01*S68+4.859110e+00*S69'
.param V31_part8='V31_part7+5.371585e+00*S70+9.870019e+00*S71+4.376088e+00*S72+4.625597e+00*S73+1.027997e+01*S74+3.793015e+00*S75+3.103391e+00*S76+5.553863e+00*S77+2.511466e+00*S78+2.461693e+00*S79'
.param V31_part9='V31_part8+4.373404e+00*S80+5.308086e+00*S81+3.121758e+00*S82+4.686738e+00*S83+4.014415e+00*S84+3.923953e+00*S85+4.922822e+00*S86+3.567597e+00*S87+3.882150e+00*S88+4.345835e+00*S89'
.param V31_part10='V31_part9+1.050421e+01*S90+1.090596e+01*S91+1.595854e+01*S92+7.711988e+00*S93+1.056138e+01*S94+1.528925e+01*S95+7.408194e+00*S96+1.031888e+01*S97+1.639425e+01*S98+6.214172e+00*S99'
.param V31_part11='V31_part10+5.292843e+00*S100+1.626988e+01*S101+6.868270e+00*S102+6.285336e+00*S103+6.339811e+00*S104+9.624138e+00*S105+1.143134e+01*S106+1.610228e+01*S107+8.143041e+00*S108+9.835749e+00*S109'
.param V31_part12='V31_part11+1.812030e+01*S110+8.527188e+00*S111+9.386383e+00*S112+1.851708e+01*S113+7.659662e+00*S114+5.163491e+00*S115+5.402260e+00*S116+4.346539e+00*S117+3.925886e+00*S118+1.119059e+01*S119'
.param V31_part13='V31_part12+8.034516e+00*S120+1.327016e+01*S121+1.506930e+01*S122+8.478315e+00*S123+9.630726e+00*S124+1.257878e+01*S125+3.217495e+00*S126+4.829620e+00*S127+4.744346e+00*S128+1.259469e+00*S129'
.param V31_part14='V31_part13+3.074162e+00*S130+1.450211e+01*S131+5.322943e+00*S132+2.373401e+00*S133+1.201924e+01*S134+9.022160e+00*S135+4.878044e+00*S136+1.281455e+01*S137+1.101004e+00*S138+5.289994e+00*S139'
.param V31_part15='V31_part14+8.413021e+00*S140+2.429032e+00*S141+8.161966e+00*S142+8.637613e+00*S143+4.220660e+00*S144+6.857027e+00*S145+8.148207e+00*S146+4.509226e+00*S147+5.912449e+00*S148+7.376475e+00*S149'
.param V31_part16='V31_part15+9.677345e+00*S150+1.486236e+01*S151+2.225129e+01*S152+8.711056e+00*S153+1.062059e+01*S154+2.065457e+01*S155+7.058690e+00*S156+1.314024e+01*S157+2.057414e+01*S158+7.533487e+00*S159'
.param V31_part17='V31_part16+9.734948e+00*S160+1.367856e+01*S161+5.626816e+00*S162+9.802952e+00*S163+1.324464e+01*S164+4.933218e+00*S165+8.125082e+00*S166+2.677037e+01*S167+8.677674e+00*S168+1.118782e+01*S169'
.param V31_part18='V31_part17+2.302598e+01*S170+6.521754e+00*S171+3.893796e+00*S172+5.965885e+00*S173+6.591603e+00*S174+4.915071e+00*S175+1.557263e+01*S176+6.352038e+00*S177+7.379079e+00*S178+1.087617e+01*S179'
.param V31_part19='V31_part18+6.033617e+00*S180+9.541093e+00*S181+1.761754e+01*S182+8.236320e+00*S183+5.627439e+00*S184+1.325985e+01*S185+7.274002e+00*S186+3.240303e+00*S187+1.121168e+01*S188+6.426957e+00*S189'
.param V31_part20='V31_part19+7.277779e+00*S190+1.066257e+01*S191+6.509125e+00*S192+7.432706e+00*S193+9.696236e+00*S194+3.254177e+00*S195+1.049160e+01*S196+2.015417e+01*S197+3.096476e+00*S198+7.737340e+00*S199'
.param V31_part21='V31_part20+1.784226e+01*S200+2.242851e+00*S201+5.117432e+00*S202+4.880945e+00*S203+2.521601e+00*S204+5.206815e+00*S205+4.697928e+00*S206+5.449035e+00*S207+6.933121e+00*S208+6.171105e+00*S209'
.param V31_part22='V31_part21+5.202559e+00*S210+1.572972e+01*S211+2.081076e+01*S212+2.398817e+00*S213+3.770233e+00*S214+2.087677e+01*S215+7.224209e+00*S216+1.091157e+01*S217+2.055356e+01*S218+7.242857e+00*S219'
.param V31_part23='V31_part22+9.216351e+00*S220+1.960369e+01*S221+7.529453e+00*S222+7.660699e+00*S223+9.466546e+00*S224+7.729786e+00*S225+1.419825e+01*S226+2.467343e+01*S227+7.103627e+00*S228+1.124457e+01*S229'
.param V31_part24='V31_part23+1.913339e+01*S230+5.174514e+00*S231+9.653942e+00*S232+1.476999e+01*S233+6.989729e+00*S234+8.787984e+00*S235+1.383186e+01*S236+7.103668e+00*S237+9.108146e+00*S238+1.282361e+01*S239'
.param V31_part25='V31_part24+7.053202e+00*S240+1.193854e+01*S241+1.528996e+01*S242+6.572753e+00*S243+9.908178e+00*S244+1.425593e+01*S245+5.321823e+00*S246+8.325295e+00*S247+1.393618e+01*S248+7.369686e+00*S249'
.param V31_part26='V31_part25+8.903989e+00*S250+1.485409e+01*S251+6.048910e+00*S252+9.450713e+00*S253+1.129592e+01*S254+8.661490e+00*S255+1.074946e+01*S256+2.318657e+01*S257+9.053216e+00*S258+1.105213e+01*S259'
.param V31_part27='V31_part26+1.736126e+01*S260+6.563993e+00*S261+7.809885e+00*S262+7.511929e+00*S263+6.441803e+00*S264+7.497319e+00*S265+1.232127e+01*S266+6.427022e+00*S267+8.436622e+00*S268+1.107154e+01*S269'
.param V31_part28='V31_part27+6.128958e+00*S270+5.589083e+00*S271+3.039994e+01*S272+7.911292e+00*S273+1.288733e+01*S274+2.165219e+01*S275+7.847291e+00*S276+1.053898e+01*S277+1.684711e+01*S278+7.544276e+00*S279'
.param V31_part29='V31_part28+1.003413e+01*S280+1.891828e+01*S281+8.302886e+00*S282+1.000360e+01*S283+1.493618e+01*S284+8.592092e+00*S285+1.193238e+01*S286+1.449926e+01*S287+7.740955e+00*S288+1.006696e+01*S289'
.param V31_part30='V31_part29+1.778570e+01*S290+8.318359e+00*S291+1.062405e+01*S292+1.773179e+01*S293+7.455132e+00*S294+1.066064e+01*S295+1.743156e+01*S296+7.431641e+00*S297+1.034300e+01*S298+1.645576e+01*S299'
.param V31_part31='V31_part30+7.673238e+00*S300+4.510279e+00*S301+8.412294e+00*S302+6.988857e+00*S303+8.634492e+00*S304+1.002708e+01*S305+7.607230e+00*S306+8.413851e+00*S307+1.445751e+01*S308+7.074555e+00*S309'
.param V31='V31_part31+8.875177e+00*S310+1.544332e+01*S311+6.851247e+00*S312+9.635428e+00*S313+1.346554e+01*S314'
.param V32_part1='2.019112e+00*S0+2.454617e+00*S1+1.564126e+00*S2+2.398981e+00*S3+1.123231e+00*S4+1.705049e+00*S5+2.014882e+00*S6+7.397942e-01*S7+1.122584e+00*S8+2.732079e+00*S9'
.param V32_part2='V32_part1+1.959437e+00*S10+1.389643e+00*S11+3.421709e+00*S12+1.280771e+00*S13+1.264981e+00*S14+1.699186e+00*S15+8.894707e-01*S16+1.622372e+00*S17+1.500884e+00*S18+1.629161e+00*S19'
.param V32_part3='V32_part2+1.554451e+00*S20+1.705289e+00*S21+2.137476e+00*S22+2.800599e+00*S23+1.591701e+00*S24+1.825829e+00*S25+3.530238e+00*S26+3.332726e+00*S27+3.236913e+00*S28+3.815019e+00*S29'
.param V32_part4='V32_part3+5.201661e+00*S30+6.261195e+00*S31+2.552761e+00*S32+6.353765e+00*S33+7.458634e+00*S34+4.622556e+00*S35+7.637817e+00*S36+4.648145e+00*S37+9.888472e+00*S38+8.573498e+00*S39'
.param V32_part5='V32_part4+5.431283e+00*S40+1.089265e+01*S41+9.940592e+00*S42+1.224467e+01*S43+1.196801e+01*S44+4.357440e-01*S45+4.011193e+00*S46+1.191313e+00*S47+5.151287e+00*S48+5.750565e+00*S49'
.param V32_part6='V32_part5+1.659814e+00*S50+6.320463e+00*S51+8.509104e+00*S52+9.522304e+00*S53+7.791238e+00*S54+9.728247e+00*S55+1.038900e+01*S56+8.371537e+00*S57+8.238693e+00*S58+1.074615e+01*S59'
.param V32_part7='V32_part6+2.336406e+00*S60+3.341841e+00*S61+6.493210e+00*S62+4.060818e+00*S63+5.967890e+00*S64+8.265002e+00*S65+4.925507e+00*S66+1.089396e+01*S67+1.266231e+01*S68+7.418908e+00*S69'
.param V32_part8='V32_part7+1.193403e+01*S70+1.513090e+01*S71+8.464004e+00*S72+1.390946e+01*S73+1.598565e+01*S74+2.792113e+00*S75+3.966277e+00*S76+4.739478e+00*S77+3.064317e+00*S78+3.467405e+00*S79'
.param V32_part9='V32_part8+4.692916e+00*S80+3.439671e+00*S81+4.697219e+00*S82+5.924703e+00*S83+3.274652e+00*S84+5.174172e+00*S85+6.685825e+00*S86+4.106481e+00*S87+5.542365e+00*S88+6.993049e+00*S89'
.param V32_part10='V32_part9+9.994484e+00*S90+9.323096e+00*S91+1.429783e+01*S92+8.254181e+00*S93+1.035649e+01*S94+1.538631e+01*S95+1.105224e+01*S96+1.337576e+01*S97+2.103098e+01*S98+1.342508e+01*S99'
.param V32_part11='V32_part10+1.288476e+01*S100+2.292093e+01*S101+1.653687e+01*S102+1.810455e+01*S103+1.443795e+01*S104+8.751622e+00*S105+1.420834e+01*S106+1.671195e+01*S107+1.061084e+01*S108+1.603368e+01*S109'
.param V32_part12='V32_part11+2.095156e+01*S110+1.347769e+01*S111+1.571639e+01*S112+2.210385e+01*S113+1.546264e+01*S114+9.806475e+00*S115+1.337708e+01*S116+1.331223e+01*S117+1.442654e+01*S118+2.789287e+01*S119'
.param V32_part13='V32_part12+7.614508e+00*S120+1.638863e+01*S121+1.752064e+01*S122+1.116160e+01*S123+1.514972e+01*S124+1.640805e+01*S125+1.535485e+01*S126+1.583150e+01*S127+1.641097e+01*S128+1.782812e+01*S129'
.param V32_part14='V32_part13+1.647770e+01*S130+2.549389e+01*S131+1.486751e+01*S132+1.709306e+01*S133+2.703731e+01*S134+4.348700e+00*S135+4.706359e+00*S136+8.882820e+00*S137+4.020617e+00*S138+5.709703e+00*S139'
.param V32_part15='V32_part14+1.241775e+01*S140+6.300853e+00*S141+1.111047e+01*S142+1.073630e+01*S143+1.035117e+01*S144+1.161592e+01*S145+1.171455e+01*S146+1.117259e+01*S147+1.452482e+01*S148+1.394660e+01*S149'
.param V32_part16='V32_part15+1.689799e+01*S150+1.989993e+01*S151+2.156090e+01*S152+1.746971e+01*S153+2.302579e+01*S154+2.316918e+01*S155+2.028818e+01*S156+2.637935e+01*S157+3.399508e+01*S158+2.240460e+01*S159'
.param V32_part17='V32_part16+2.054529e+01*S160+3.886325e+01*S161+1.537600e+01*S162+3.475614e+01*S163+4.104094e+01*S164+9.455258e+00*S165+2.155438e+01*S166+3.158807e+01*S167+1.641112e+01*S168+2.698699e+01*S169'
.param V32_part18='V32_part17+3.434126e+01*S170+1.816593e+01*S171+2.204303e+01*S172+2.833819e+01*S173+1.967132e+01*S174+2.023550e+01*S175+4.148463e+01*S176+2.026865e+01*S177+3.098775e+01*S178+3.839956e+01*S179'
.param V32_part19='V32_part18+1.341321e+01*S180+2.504216e+01*S181+2.594065e+01*S182+1.548248e+01*S183+2.016124e+01*S184+3.900817e+01*S185+1.669592e+01*S186+2.105708e+01*S187+3.599880e+01*S188+1.871525e+01*S189'
.param V32_part20='V32_part19+2.824453e+01*S190+3.711884e+01*S191+1.819741e+01*S192+3.125957e+01*S193+3.385522e+01*S194+7.110832e+00*S195+1.690303e+01*S196+2.272945e+01*S197+9.481752e+00*S198+1.492302e+01*S199'
.param V32_part21='V32_part20+2.020188e+01*S200+1.726875e+01*S201+1.566245e+01*S202+1.916264e+01*S203+9.440066e+00*S204+1.652614e+01*S205+2.347889e+01*S206+1.453300e+01*S207+2.014864e+01*S208+2.529308e+01*S209'
.param V32_part22='V32_part21+1.785484e+01*S210+3.078444e+01*S211+3.415787e+01*S212+1.665059e+01*S213+1.805000e+01*S214+3.774345e+01*S215+2.445342e+01*S216+3.960497e+01*S217+3.637066e+01*S218+2.581135e+01*S219'
.param V32_part23='V32_part22+3.836106e+01*S220+5.522080e+01*S221+2.676150e+01*S222+4.188839e+01*S223+4.867519e+01*S224+2.087897e+01*S225+3.561691e+01*S226+4.514225e+01*S227+2.159282e+01*S228+3.317529e+01*S229'
.param V32_part24='V32_part23+5.067868e+01*S230+1.595576e+01*S231+3.747995e+01*S232+4.617894e+01*S233+2.310427e+01*S234+3.841345e+01*S235+4.780372e+01*S236+2.340818e+01*S237+4.022836e+01*S238+4.856807e+01*S239'
.param V32_part25='V32_part24+1.793402e+01*S240+3.420434e+01*S241+4.832283e+01*S242+2.009568e+01*S243+3.177007e+01*S244+4.867140e+01*S245+1.796172e+01*S246+3.356494e+01*S247+4.567113e+01*S248+2.338904e+01*S249'
.param V32_part26='V32_part25+3.710098e+01*S250+4.674414e+01*S251+2.475948e+01*S252+4.125402e+01*S253+4.690163e+01*S254+1.727176e+01*S255+1.911120e+01*S256+3.428067e+01*S257+1.735917e+01*S258+2.596172e+01*S259'
.param V32_part27='V32_part26+3.743972e+01*S260+1.839106e+01*S261+2.478058e+01*S262+3.076622e+01*S263+1.910331e+01*S264+2.742339e+01*S265+3.529870e+01*S266+2.043261e+01*S267+3.313449e+01*S268+3.488934e+01*S269'
.param V32_part28='V32_part27+2.540527e+01*S270+3.443154e+01*S271+5.947898e+01*S272+2.825707e+01*S273+4.831438e+01*S274+6.497065e+01*S275+2.851388e+01*S276+4.443796e+01*S277+6.015198e+01*S278+3.157451e+01*S279'
.param V32_part29='V32_part28+4.866703e+01*S280+6.183555e+01*S281+3.067541e+01*S282+5.243804e+01*S283+6.025576e+01*S284+2.509506e+01*S285+4.115785e+01*S286+4.510460e+01*S287+2.593064e+01*S288+4.183677e+01*S289'
.param V32_part30='V32_part29+5.699306e+01*S290+2.944475e+01*S291+4.288322e+01*S292+5.839732e+01*S293+3.259399e+01*S294+4.524933e+01*S295+5.874683e+01*S296+3.159669e+01*S297+4.708364e+01*S298+5.883179e+01*S299'
.param V32_part31='V32_part30+1.838307e+01*S300+3.341268e+01*S301+3.441993e+01*S302+2.102585e+01*S303+2.999044e+01*S304+3.463009e+01*S305+2.300336e+01*S306+3.445331e+01*S307+4.430747e+01*S308+2.458665e+01*S309'
.param V32='V32_part31+3.619488e+01*S310+4.460851e+01*S311+2.567443e+01*S312+3.910178e+01*S313+4.344410e+01*S314'
.param V33_part1='4.564196e-01*S0+4.512050e-01*S1+1.906270e-01*S2+4.321754e-01*S3+(-1.366535e-02)*S4+3.145881e-01*S5+(-1.156561e-01)*S6+1.578042e-01*S7+7.519878e-03*S8+(-5.418250e-01)*S9'
.param V33_part2='V33_part1+2.705829e-01*S10+(-2.718241e-01)*S11+(-1.257356e-02)*S12+(-2.702635e-01)*S13+(-3.947750e-01)*S14+7.520452e-01*S15+2.860370e-01*S16+7.806366e-01*S17+2.216258e-01*S18+5.056576e-01*S19'
.param V33_part3='V33_part2+8.130007e-01*S20+8.585173e-01*S21+6.423373e-01*S22+2.106892e-01*S23+(-6.640768e-02)*S24+3.887241e-01*S25+(-1.055613e-01)*S26+7.409932e-01*S27+3.350507e-01*S28+(-5.151509e-02)*S29'
.param V33_part4='V33_part3+4.993303e-01*S30+(-7.940744e-02)*S31+(-8.442497e-01)*S32+1.675078e-01*S33+(-3.303110e-01)*S34+(-7.739461e-01)*S35+(-5.317058e-01)*S36+(-1.535773e+00)*S37+(-1.397559e-01)*S38+(-1.019931e+00)*S39'
.param V33_part5='V33_part4+(-1.478062e-01)*S40+(-7.851257e-02)*S41+(-1.216475e+00)*S42+(-1.186786e+00)*S43+(-9.448669e-02)*S44+(-3.561643e-02)*S45+4.935274e-02*S46+(-4.206435e-01)*S47+(-8.014177e-02)*S48+(-3.692484e-01)*S49'
.param V33_part6='V33_part5+(-5.049426e-01)*S50+(-8.505731e-02)*S51+(-2.885976e-01)*S52+(-2.021746e+00)*S53+(-2.758361e-01)*S54+(-2.708010e-01)*S55+(-2.018215e+00)*S56+(-3.311002e-01)*S57+(-1.019104e+00)*S58+(-2.055765e+00)*S59'
.param V33_part7='V33_part6+6.035636e-01*S60+(-9.743508e-02)*S61+8.460499e-01*S62+1.245543e-02*S63+(-7.652710e-02)*S64+8.737072e-01*S65+(-8.901521e-02)*S66+2.460701e-01*S67+1.419112e+00*S68+4.516778e-02*S69'
.param V33_part8='V33_part7+1.000869e+00*S70+2.200068e+00*S71+1.025269e-01*S72+1.985894e+00*S73+1.139954e+00*S74+9.276224e-01*S75+1.042094e+00*S76+1.600956e+00*S77+7.246927e-02*S78+2.335736e-01*S79'
.param V33_part9='V33_part8+1.441458e+00*S80+5.084894e-01*S81+8.505286e-01*S82+1.363550e+00*S83+6.500734e-01*S84+8.465754e-01*S85+1.442615e+00*S86+5.150648e-01*S87+5.854370e-01*S88+6.852397e-01*S89'
.param V33_part10='V33_part9+(-4.734464e-01)*S90+(-1.253029e-01)*S91+1.120532e-01*S92+1.999892e-01*S93+(-2.770179e-01)*S94+3.718628e-01*S95+1.273710e-01*S96+2.114543e-01*S97+3.830807e-01*S98+1.655375e-01*S99'
.param V33_part11='V33_part10+4.494441e-01*S100+3.667362e-01*S101+(-5.299673e-01)*S102+(-5.556114e-02)*S103+(-1.158567e+00)*S104+(-2.867344e-02)*S105+(-3.557313e-01)*S106+3.950515e-01*S107+(-8.454779e-02)*S108+(-3.118368e-01)*S109'
.param V33_part12='V33_part11+8.016391e-01*S110+4.238596e-02*S111+4.718229e-02*S112+8.121109e-01*S113+(-2.571802e-02)*S114+(-5.672880e-01)*S115+6.481606e-03*S116+(-1.389198e-01)*S117+1.118165e-01*S118+1.867085e-01*S119'
.param V33_part13='V33_part12+1.189321e-01*S120+1.936674e-01*S121+1.649958e+00*S122+2.117805e-01*S123+7.619699e-01*S124+1.218734e+00*S125+3.153079e-01*S126+6.610743e-01*S127+1.006339e+00*S128+5.216299e-02*S129'
.param V33_part14='V33_part13+4.229158e-01*S130+(-9.271309e-02)*S131+1.874738e-01*S132+1.301823e-01*S133+(-1.071335e-01)*S134+8.868628e-01*S135+3.234912e-02*S136+5.710823e-01*S137+(-2.987467e-01)*S138+2.189231e-01*S139'
.param V33_part15='V33_part14+2.003205e+00*S140+1.547214e-02*S141+7.566115e-01*S142+1.675342e+00*S143+8.191524e-01*S144+1.167559e+00*S145+1.918412e+00*S146+3.699357e-01*S147+7.257416e-01*S148+1.497569e-01*S149'
.param V33_part16='V33_part15+(-1.709348e-01)*S150+(-2.852767e-01)*S151+3.043307e-01*S152+8.261717e-02*S153+(-3.075657e-02)*S154+3.762437e-01*S155+(-2.298631e-01)*S156+2.929704e-01*S157+(-1.175603e-01)*S158+(-2.295414e-01)*S159'
.param V33_part17='V33_part16+(-9.688508e-01)*S160+(-1.157059e+00)*S161+(-5.415013e-01)*S162+(-4.202536e-01)*S163+(-8.086881e-01)*S164+(-9.229602e-03)*S165+4.155652e-01*S166+7.773903e-01*S167+7.101898e-02*S168+2.191068e-01*S169'
.param V33_part18='V33_part17+5.406265e-01*S170+(-2.989646e-02)*S171+(-4.233875e-02)*S172+(-5.025764e-01)*S173+6.947161e-02*S174+(-4.542089e-01)*S175+(-9.881028e-03)*S176+(-4.937208e-02)*S177+(-2.407411e-01)*S178+(-6.966191e-02)*S179'
.param V33_part19='V33_part18+6.813174e-03*S180+1.167819e+00*S181+1.018982e+00*S182+3.333116e-01*S183+4.785768e-01*S184+1.036069e+00*S185+3.590161e-01*S186+(-3.662558e-02)*S187+8.161852e-01*S188+2.600882e-01*S189'
.param V33_part20='V33_part19+2.906646e-01*S190+1.145951e+00*S191+2.385597e-01*S192+6.240279e-01*S193+1.087686e+00*S194+(-3.351512e-01)*S195+1.556451e+00*S196+1.001018e+00*S197+3.328344e-01*S198+1.698672e+00*S199'
.param V33_part21='V33_part20+2.106077e+00*S200+3.213960e-01*S201+1.376500e+00*S202+1.582622e+00*S203+(-8.902360e-02)*S204+2.970235e-02*S205+9.015700e-01*S206+1.052703e+00*S207+(-7.550722e-02)*S208+1.072880e+00*S209'
.param V33_part22='V33_part21+(-9.176398e-02)*S210+2.238010e-01*S211+3.698284e-01*S212+(-6.759626e-02)*S213+(-1.756937e+00)*S214+4.828637e-01*S215+(-1.438154e-01)*S216+4.778773e-02*S217+4.253649e-01*S218+(-2.640164e-01)*S219'
.param V33_part23='V33_part22+(-8.437424e-01)*S220+(-6.469387e-01)*S221+(-3.415175e-01)*S222+(-7.369436e-01)*S223+(-1.405173e+00)*S224+5.773452e-02*S225+4.275108e-01*S226+3.520287e-01*S227+3.877365e-02*S228+4.478003e-02*S229'
.param V33_part24='V33_part23+(-1.219015e-01)*S230+(-3.651773e-01)*S231+(-3.351318e-01)*S232+(-1.097958e-01)*S233+(-2.586084e-03)*S234+(-3.405900e-01)*S235+1.392168e-01*S236+(-4.377991e-02)*S237+2.441130e-01*S238+(-1.354183e-01)*S239'
.param V33_part25='V33_part24+2.277203e-01*S240+6.077543e-01*S241+1.469012e+00*S242+3.877348e-01*S243+5.577661e-01*S244+5.549250e-01*S245+(-1.198807e-01)*S246+6.178520e-01*S247+1.146918e+00*S248+2.325760e-01*S249'
.param V33_part26='V33_part25+8.004849e-01*S250+1.233202e+00*S251+3.081938e-01*S252+5.738728e-01*S253+1.220008e+00*S254+3.016343e-01*S255+8.774190e-01*S256+1.683798e+00*S257+1.246976e+00*S258+7.738080e-01*S259'
.param V33_part27='V33_part26+1.963894e+00*S260+9.614736e-01*S261+1.375265e+00*S262+1.535292e+00*S263+9.721742e-01*S264+1.115658e+00*S265+2.619768e+00*S266+1.004641e+00*S267+1.561920e+00*S268+2.333487e+00*S269'
.param V33_part28='V33_part27+(-8.110834e-02)*S270+(-1.158503e-01)*S271+8.442874e-02*S272+7.995880e-04*S273+1.943975e-01*S274+(-5.341554e-01)*S275+(-1.747182e-01)*S276+(-4.292103e-01)*S277+(-7.532970e-01)*S278+(-2.469500e-01)*S279'
.param V33_part29='V33_part28+(-7.209179e-01)*S280+(-6.686274e-01)*S281+(-2.689247e-01)*S282+(-5.513051e-01)*S283+(-7.337089e-01)*S284+1.656800e-01*S285+4.723322e-01*S286+1.192903e-01*S287+4.350373e-02*S288+(-4.075891e-02)*S289'
.param V33_part30='V33_part29+2.626582e-01*S290+1.128016e-01*S291+9.484509e-02*S292+3.684010e-01*S293+8.675868e-03*S294+2.415922e-01*S295+3.873939e-01*S296+1.443635e-01*S297+(-6.397840e-02)*S298+4.974673e-01*S299'
.param V33_part31='V33_part30+1.036220e+00*S300+1.000237e+00*S301+2.821401e+00*S302+8.921825e-01*S303+1.343680e+00*S304+2.933442e+00*S305+9.782705e-01*S306+1.502476e+00*S307+2.832926e+00*S308+9.942521e-01*S309'
.param V33='V33_part31+1.572419e+00*S310+2.661982e+00*S311+1.003235e+00*S312+1.576108e+00*S313+2.691934e+00*S314'
.param V34_part1='3.369285e-02*S0+8.850252e-03*S1+1.391211e-02*S2+(-2.560429e-03)*S3+1.952589e-04*S4+(-2.946895e-04)*S5+5.840332e-02*S6+(-1.763431e-02)*S7+2.302937e-02*S8+(-3.611385e-03)*S9'
.param V34_part2='V34_part1+(-5.268719e-03)*S10+(-1.057784e-02)*S11+(-5.379216e-03)*S12+(-1.344607e-02)*S13+(-1.507509e-02)*S14+1.791381e-02*S15+7.055144e-03*S16+6.831194e-03*S17+9.656603e-03*S18+1.583439e-02*S19'
.param V34_part3='V34_part2+1.284295e-02*S20+2.685526e-03*S21+9.878208e-03*S22+(-2.068983e-02)*S23+2.762492e-02*S24+6.603214e-04*S25+1.223811e-02*S26+7.666218e-03*S27+7.020231e-03*S28+1.355503e-02*S29'
.param V34_part4='V34_part3+9.324870e-02*S30+1.263915e-01*S31+5.229081e-02*S32+1.074415e-02*S33+2.122635e-02*S34+1.431577e-01*S35+(-1.127999e-01)*S36+7.724419e-02*S37+1.429521e-01*S38+(-2.732407e-01)*S39'
.param V34_part5='V34_part4+1.460188e-01*S40+1.783863e-01*S41+(-4.329955e-01)*S42+(-6.379315e-01)*S43+3.085557e-02*S44+(-1.155123e-01)*S45+(-3.037091e-02)*S46+(-6.138087e-02)*S47+(-3.266524e-01)*S48+(-2.769772e-01)*S49'
.param V34_part6='V34_part5+(-6.910229e-02)*S50+(-6.082737e-01)*S51+(-5.787591e-01)*S52+3.568511e-01*S53+(-7.682563e-01)*S54+(-8.175762e-01)*S55+3.819999e-01*S56+(-8.446798e-01)*S57+1.157882e-01*S58+3.854331e-01*S59'
.param V34_part7='V34_part6+(-4.479292e-01)*S60+(-4.629047e-02)*S61+(-6.277797e-02)*S62+(-5.170203e-01)*S63+(-5.605200e-01)*S64+2.516274e-01*S65+(-8.802942e-01)*S66+(-1.060449e+00)*S67+2.139724e-01*S68+(-9.439891e-01)*S69'
.param V34_part8='V34_part7+1.704375e-01*S70+3.479172e-01*S71+(-1.176436e+00)*S72+2.151456e-01*S73+(-1.052383e+00)*S74+1.662111e-01*S75+(-1.317350e-02)*S76+1.115269e-01*S77+(-1.747193e-02)*S78+5.908718e-03*S79'
.param V34_part9='V34_part8+2.647762e-02*S80+(-7.049034e-03)*S81+(-5.802943e-02)*S82+(-7.002440e-02)*S83+(-1.931950e-01)*S84+(-1.132757e-01)*S85+(-1.610423e-01)*S86+(-2.090518e-01)*S87+(-2.615707e-01)*S88+(-1.417168e-01)*S89'
.param V34_part10='V34_part9+(-1.413508e-01)*S90+4.826347e-01*S91+6.316394e-01*S92+4.707911e-01*S93+6.187587e-01*S94+7.284107e-01*S95+5.500192e-01*S96+5.295711e-01*S97+7.259852e-01*S98+5.910825e-01*S99'
.param V34_part11='V34_part10+4.986395e-01*S100+7.708110e-01*S101+(-1.019546e+00)*S102+5.759310e-01*S103+3.023524e-01*S104+(-2.397153e-01)*S105+(-2.356381e-01)*S106+6.305538e-01*S107+(-3.577139e-01)*S108+(-6.309254e-01)*S109'
.param V34_part12='V34_part11+7.943662e-01*S110+(-5.779846e-01)*S111+5.803945e-01*S112+8.771339e-01*S113+(-1.032284e+00)*S114+1.123743e-01*S115+4.201067e-01*S116+(-5.280822e-01)*S117+7.221093e-01*S118+(-2.948949e-01)*S119'
.param V34_part13='V34_part12+(-3.443938e-01)*S120+(-6.278481e-01)*S121+7.251376e-01*S122+(-4.971631e-01)*S123+6.095438e-01*S124+5.465202e-01*S125+2.664562e-01*S126+3.577915e-01*S127+1.268651e-01*S128+3.223723e-01*S129'
.param V34_part14='V34_part13+3.258697e-01*S130+7.596758e-01*S131+(-1.114314e+00)*S132+4.565051e-01*S133+7.243083e-01*S134+(-8.159844e-01)*S135+2.640300e-01*S136+3.798987e-01*S137+1.981108e-01*S138+1.871425e-01*S139'
.param V34_part15='V34_part14+3.871873e-01*S140+7.813415e-02*S141+4.098665e-01*S142+2.322434e-01*S143+3.804489e-01*S144+4.573266e-01*S145+5.383889e-01*S146+6.352843e-01*S147+4.473807e-01*S148+5.371582e-01*S149'
.param V34_part16='V34_part15+(-3.661482e-01)*S150+9.332827e-01*S151+1.195569e+00*S152+7.398785e-01*S153+1.095038e+00*S154+1.359557e+00*S155+(-3.251344e-01)*S156+8.738415e-01*S157+1.398992e+00*S158+(-9.395118e-03)*S159'
.param V34_part17='V34_part16+7.144685e-01*S160+(-6.369716e-01)*S161+1.853036e-02*S162+(-2.433606e-01)*S163+(-3.502468e-01)*S164+4.634980e-01*S165+9.482555e-01*S166+1.428666e+00*S167+(-3.867635e-01)*S168+(-5.278138e-01)*S169'
.param V34_part18='V34_part17+1.462013e+00*S170+(-5.993322e-01)*S171+7.304246e-01*S172+6.745458e-01*S173+(-7.819156e-01)*S174+6.661063e-01*S175+(-2.722822e-02)*S176+(-7.640802e-01)*S177+(-9.472043e-01)*S178+(-5.410772e-01)*S179'
.param V34_part19='V34_part18+5.205098e-01*S180+8.970631e-01*S181+9.681882e-01*S182+(-4.755306e-01)*S183+5.865806e-01*S184+(-9.571719e-01)*S185+(-4.714921e-01)*S186+4.006286e-01*S187+(-1.205670e+00)*S188+(-7.219595e-01)*S189'
.param V34_part20='V34_part19+(-8.875459e-01)*S190+(-2.020073e+00)*S191+(-8.640513e-01)*S192+(-8.422930e-01)*S193+(-1.513891e+00)*S194+4.428216e-02*S195+(-1.122212e+00)*S196+1.015658e+00*S197+5.474477e-01*S198+5.606303e-01*S199'
.param V34_part21='V34_part20+9.480802e-01*S200+2.021690e-01*S201+5.446084e-01*S202+3.851640e-01*S203+1.510037e-01*S204+5.848455e-01*S205+4.852126e-01*S206+(-1.588806e+00)*S207+7.612432e-01*S208+7.404229e-01*S209'
.param V34_part22='V34_part21+7.102466e-01*S210+1.360839e+00*S211+1.930361e+00*S212+5.215452e-01*S213+6.037875e-01*S214+2.188701e+00*S215+(-2.915839e-01)*S216+3.435074e-01*S217+2.235869e+00*S218+(-1.798732e-01)*S219'
.param V34_part23='V34_part22+(-9.551312e-01)*S220+9.044393e-01*S221+(-5.238046e-01)*S222+(-7.592391e-01)*S223+(-9.384382e-01)*S224+3.128130e-01*S225+(-1.810522e-01)*S226+2.138142e+00*S227+(-1.143059e-01)*S228+(-2.484625e-01)*S229'
.param V34_part24='V34_part23+1.281751e-01*S230+5.005426e-01*S231+(-3.681773e-01)*S232+(-1.236267e+00)*S233+(-5.490947e-01)*S234+(-5.472479e-01)*S235+(-1.118318e+00)*S236+(-6.895196e-01)*S237+(-7.481145e-01)*S238+(-5.403846e-01)*S239'
.param V34_part25='V34_part24+5.484036e-01*S240+2.246849e-02*S241+(-2.795589e-01)*S242+(-1.077181e-01)*S243+(-5.090279e-01)*S244+(-6.057637e-01)*S245+6.483463e-01*S246+(-4.449705e-01)*S247+(-9.492478e-01)*S248+(-5.010438e-01)*S249'
.param V34_part26='V34_part25+(-9.258197e-01)*S250+(-9.467923e-01)*S251+(-5.055915e-01)*S252+(-1.062025e+00)*S253+(-7.000262e-01)*S254+8.892627e-01*S255+8.682066e-01*S256+1.332020e+00*S257+(-6.377300e-01)*S258+1.041291e+00*S259'
.param V34_part27='V34_part26+1.538840e+00*S260+(-8.467019e-01)*S261+(-1.137173e+00)*S262+8.285037e-01*S263+(-1.099033e+00)*S264+(-1.267461e+00)*S265+(-1.901356e+00)*S266+(-1.100109e+00)*S267+(-2.095685e+00)*S268+(-1.662745e+00)*S269'
.param V34_part28='V34_part27+1.458120e-01*S270+9.758414e-01*S271+2.978006e+00*S272+3.326544e-02*S273+9.946705e-01*S274+7.801380e-01*S275+(-1.680427e-01)*S276+(-4.031222e-01)*S277+(-5.611271e-01)*S278+(-7.068745e-02)*S279'
.param V34_part29='V34_part28+(-7.822455e-02)*S280+(-2.925869e-01)*S281+(-3.829377e-01)*S282+(-3.029078e-01)*S283+(-7.719678e-01)*S284+3.214926e-01*S285+(-1.055899e-01)*S286+1.005045e+00*S287+1.060924e-01*S288+(-1.904864e-01)*S289'
.param V34_part30='V34_part29+(-5.924396e-01)*S290+(-1.253477e-01)*S291+(-6.233447e-02)*S292+(-5.637512e-01)*S293+(-5.812120e-02)*S294+(-1.520103e-02)*S295+(-6.785916e-01)*S296+(-1.502145e-01)*S297+(-4.367238e-01)*S298+(-6.976365e-01)*S299'
.param V34_part31='V34_part30+(-3.129403e-01)*S300+9.102925e-01*S301+1.904585e+00*S302+(-4.720029e-01)*S303+(-9.867907e-01)*S304+1.915319e+00*S305+(-5.951869e-01)*S306+(-6.116967e-01)*S307+(-1.565443e+00)*S308+(-7.166944e-01)*S309'
.param V34='V34_part31+(-5.230807e-01)*S310+(-1.364000e+00)*S311+(-8.515691e-01)*S312+(-5.529055e-01)*S313+(-1.488116e+00)*S314'
.param V35_part1='8.757545e+00*S0+1.441707e+01*S1+2.226123e+01*S2+7.926967e+00*S3+1.063695e+01*S4+3.626481e+01*S5+7.660282e+00*S6+1.599878e+01*S7+9.667559e+00*S8+1.126024e+02*S9'
.param V35_part2='V35_part1+2.186051e+01*S10+9.930422e+00*S11+1.161031e+01*S12+(-1.839677e+00)*S13+9.131773e+00*S14+4.570961e+00*S15+1.000000e+04*S16+1.102167e+02*S17+3.630613e+01*S18+9.705668e+01*S19'
.param V35_part3='V35_part2+1.000000e+04*S20+4.860850e+01*S21+1.382365e+02*S22+4.918867e+02*S23+1.369531e+01*S24+1.753185e+02*S25+1.000000e+04*S26+4.191391e+01*S27+(-5.421949e+02)*S28+1.966061e+03*S29'
.param V35_part4='V35_part3+8.066178e+00*S30+(-5.229468e-02)*S31+3.082255e+00*S32+7.793189e+00*S33+4.516804e+00*S34+2.529175e+00*S35+9.697993e+00*S36+1.724130e+00*S37+8.293753e+00*S38+1.139056e+01*S39'
.param V35_part5='V35_part4+1.880546e+00*S40+5.124742e+00*S41+1.125262e+01*S42+2.388630e+01*S43+4.290430e+00*S44+1.667990e+01*S45+1.411135e+01*S46+8.626889e+00*S47+4.001039e+00*S48+4.401422e+00*S49'
.param V35_part6='V35_part5+6.596178e+00*S50+3.026867e+01*S51+4.438228e+00*S52+3.169994e+00*S53+2.190192e+00*S54+3.635169e+00*S55+2.940588e+00*S56+2.839396e+00*S57+3.042436e+00*S58+3.098920e+00*S59'
.param V35_part7='V35_part6+3.888131e+01*S60+3.737555e+01*S61+4.203582e+00*S62+8.131656e+01*S63+4.207562e+00*S64+7.863002e+00*S65+9.641612e+00*S66+(-2.404974e+01)*S67+7.722537e+00*S68+8.498240e-01*S69'
.param V35_part8='V35_part7+(-2.316343e+01)*S70+2.034538e+01*S71+1.186933e+01*S72+2.399618e+03*S73+5.257538e+01*S74+2.313473e+01*S75+1.296475e+01*S76+5.196113e+01*S77+(-5.867923e+01)*S78+1.100602e+02*S79'
.param V35_part9='V35_part8+5.022187e+01*S80+8.325861e+00*S81+1.573000e+01*S82+3.288187e+00*S83+1.363142e+01*S84+8.142428e+00*S85+6.697946e+01*S86+7.355186e+00*S87+(-1.084408e+02)*S88+7.763164e+00*S89'
.param V35_part10='V35_part9+1.199490e+02*S90+4.128897e+00*S91+3.264568e+00*S92+3.840859e+00*S93+3.526534e+00*S94+3.169154e+00*S95+3.938294e+00*S96+3.447937e+00*S97+7.677122e+00*S98+3.874110e+00*S99'
.param V35_part11='V35_part10+3.808333e+00*S100+3.739209e+00*S101+7.529099e+03*S102+2.721324e+00*S103+3.319573e+00*S104+5.908609e+00*S105+5.109621e+00*S106+3.414971e+00*S107+5.882270e+00*S108+4.696721e+00*S109'
.param V35_part12='V35_part11+3.390409e+00*S110+6.677360e+00*S111+4.005689e+00*S112+3.425621e+00*S113+1.115567e+01*S114+4.446019e+00*S115+2.958453e+00*S116+2.726806e+00*S117+3.005181e+00*S118+5.674141e+00*S119'
.param V35_part13='V35_part12+4.678223e+00*S120+(-5.089858e+00)*S121+5.179585e+00*S122+6.455337e+00*S123+4.350645e+00*S124+4.390399e+00*S125+8.493853e+00*S126+5.678174e+00*S127+4.286197e+00*S128+6.716834e+00*S129'
.param V35_part14='V35_part13+6.143492e+00*S130+4.238448e+00*S131+2.946879e+00*S132+4.192029e+00*S133+4.108718e+00*S134+2.610179e+01*S135+8.238803e+00*S136+4.282584e+00*S137+7.062143e+02*S138+6.295707e+00*S139'
.param V35_part15='V35_part14+8.322923e+00*S140+6.978423e+00*S141+1.011733e+01*S142+5.833433e+00*S143+3.030053e+01*S144+9.351452e+00*S145+5.408128e+00*S146+6.434613e+00*S147+7.603027e+00*S148+9.008420e+00*S149'
.param V35_part16='V35_part15+8.330909e+00*S150+3.941057e+00*S151+3.806811e+00*S152+5.815388e+00*S153+1.337858e+02*S154+3.877872e+00*S155+4.158763e+00*S156+1.456723e+01*S157+3.198600e+00*S158+6.822253e+00*S159'
.param V35_part17='V35_part16+2.527114e+00*S160+2.686899e+00*S161+2.904558e+00*S162+7.081622e+00*S163+2.767078e+00*S164+6.327437e+00*S165+4.692868e+00*S166+1.993432e+01*S167+4.955683e+00*S168+1.371041e+01*S169'
.param V35_part18='V35_part17+2.204102e+01*S170+2.651324e+00*S171+3.927341e+00*S172+2.889505e+00*S173+2.184469e+00*S174+2.711516e+00*S175+2.863845e+00*S176+4.993988e+00*S177+3.836837e+00*S178+2.719147e+00*S179'
.param V35_part19='V35_part18+8.791442e+00*S180+1.539871e+01*S181+3.545902e+00*S182+5.120559e+00*S183+3.786605e+00*S184+3.731668e+00*S185+4.687480e+00*S186+5.718248e+00*S187+4.975485e+00*S188+7.001737e+00*S189'
.param V35_part20='V35_part19+4.251448e+00*S190+2.495853e+00*S191+1.912203e+00*S192+3.096014e+00*S193+2.951701e+00*S194+7.272748e+00*S195+8.225363e+00*S196+7.758460e+00*S197+6.122762e+01*S198+6.737462e+00*S199'
.param V35_part21='V35_part20+5.540036e+00*S200+1.010365e+01*S201+6.902141e+00*S202+6.186983e+00*S203+2.846816e+00*S204+5.787011e+00*S205+4.822726e+00*S206+1.968704e+01*S207+5.123136e+00*S208+4.552104e+00*S209'
.param V35_part22='V35_part21+3.980032e+00*S210+2.344963e+02*S211+3.544242e+00*S212+3.298337e+00*S213+2.916209e+00*S214+2.952700e+00*S215+7.680707e+00*S216+3.350607e+00*S217+2.229612e+00*S218+3.367979e+00*S219'
.param V35_part23='V35_part22+2.225984e+00*S220+2.367944e+00*S221+5.906714e+00*S222+2.407569e+00*S223+1.932346e+00*S224+4.085648e+00*S225+1.783586e+01*S226+3.536441e+00*S227+4.562085e+00*S228+9.313936e+00*S229'
.param V35_part24='V35_part23+4.135183e+00*S230+1.450121e+00*S231+4.357769e+00*S232+2.810671e+00*S233+2.189240e+00*S234+4.513751e+00*S235+2.464858e+00*S236+2.103071e+00*S237+2.554323e+00*S238+2.185271e+00*S239'
.param V35_part25='V35_part24+4.280104e+00*S240+5.428542e+00*S241+3.510588e+00*S242+2.496946e+03*S243+4.339251e+00*S244+3.651237e+00*S245+1.408094e+00*S246+3.369816e+00*S247+2.718497e+00*S248+2.405777e+00*S249'
.param V35_part26='V35_part25+3.070497e+00*S250+2.325764e+00*S251+2.643171e+00*S252+4.105770e+00*S253+2.142791e+00*S254+2.948323e+01*S255+4.270379e+00*S256+4.768982e+00*S257+1.152948e+01*S258+6.024820e+00*S259'
.param V35_part27='V35_part26+4.759706e+00*S260+7.446526e+00*S261+4.474349e+00*S262+2.616020e+00*S263+2.874434e+00*S264+8.277954e+00*S265+3.069373e+00*S266+2.906853e+00*S267+4.156751e+00*S268+2.723348e+00*S269'
.param V35_part28='V35_part27+4.327204e+00*S270+3.691568e+00*S271+3.003237e+00*S272+2.729558e+00*S273+3.806284e+00*S274+2.983694e+00*S275+2.415065e+00*S276+2.827871e+00*S277+2.315153e+00*S278+3.152608e+00*S279'
.param V35_part29='V35_part28+4.386137e+00*S280+2.091544e+00*S281+2.102183e+00*S282+2.252583e+00*S283+2.234663e+00*S284+1.001758e+01*S285+3.418237e+00*S286+2.944755e+00*S287+2.853198e+00*S288+2.638141e+00*S289'
.param V35_part30='V35_part29+2.441015e+00*S290+2.988737e+00*S291+2.805474e+00*S292+2.297531e+00*S293+9.041007e+00*S294+2.500498e+00*S295+2.219193e+00*S296+2.402378e+00*S297+2.029828e+00*S298+2.225623e+00*S299'
.param V35_part31='V35_part30+9.095574e+01*S300+5.315699e+00*S301+3.541126e+00*S302+3.476751e+00*S303+3.790739e+00*S304+3.713270e+00*S305+1.236343e+01*S306+3.213262e+00*S307+2.554474e+00*S308+5.052984e+00*S309'
.param V35='V35_part31+2.726335e+00*S310+2.240524e+00*S311+1.369040e+01*S312+2.418457e+00*S313+2.123751e+00*S314'
.param V36_part1='(-6.575238e+00)*S0+(-4.356105e+00)*S1+(-7.539212e+00)*S2+(-5.065140e+00)*S3+(-6.868337e+00)*S4+(-6.737713e+00)*S5+(-4.042629e-01)*S6+1.012173e+01*S7+(-1.467535e+01)*S8+(-3.955507e+01)*S9'
.param V36_part2='V36_part1+1.044108e+01*S10+(-4.651721e+00)*S11+9.573955e+01*S12+6.318204e+01*S13+(-3.504429e+00)*S14+1.123499e+01*S15+5.648982e+03*S16+4.908180e+01*S17+(-3.156325e+01)*S18+(-1.396063e+01)*S19'
.param V36_part3='V36_part2+4.575260e+02*S20+8.117392e+02*S21+(-1.321480e+02)*S22+1.327447e+01*S23+(-4.596736e-01)*S24+(-2.800096e+01)*S25+1.000000e+04*S26+(-1.258976e+01)*S27+(-1.620414e+02)*S28+(-2.172491e+02)*S29'
.param V36_part4='V36_part3+(-1.196592e+01)*S30+1.454796e+01*S31+(-1.598428e+00)*S32+(-6.681320e+00)*S33+8.533544e-01*S34+(-7.857648e-01)*S35+(-3.312634e+00)*S36+(-2.111617e-01)*S37+(-4.282333e+00)*S38+(-3.634116e+00)*S39'
.param V36_part5='V36_part4+(-1.235867e-01)*S40+(-1.413750e+00)*S41+(-4.891181e+00)*S42+(-1.555620e-01)*S43+(-8.867185e-01)*S44+(-1.203164e+01)*S45+(-8.598345e+00)*S46+(-4.395618e+00)*S47+(-2.137665e+00)*S48+(-1.537171e+00)*S49'
.param V36_part6='V36_part5+(-4.000219e+00)*S50+1.643186e+01*S51+(-1.820520e+00)*S52+(-3.079267e-01)*S53+(-1.144444e+00)*S54+(-7.629880e-01)*S55+(-3.072884e-01)*S56+(-7.187920e-01)*S57+(-1.250722e-01)*S58+(-5.735655e-01)*S59'
.param V36_part7='V36_part6+(-2.707563e+00)*S60+(-4.246096e+01)*S61+(-1.901758e+00)*S62+(-8.632083e+01)*S63+(-1.240225e+00)*S64+(-1.633791e+00)*S65+(-1.787127e+00)*S66+2.313996e+01*S67+(-1.077466e+00)*S68+1.700122e+00*S69'
.param V36_part8='V36_part7+1.925458e+01*S70+(-4.598922e-01)*S71+(-6.290358e+00)*S72+2.214008e+01*S73+(-8.739490e+00)*S74+(-5.747019e+00)*S75+1.590775e+01*S76+(-6.791098e+01)*S77+(-1.846277e+00)*S78+(-2.064885e+02)*S79'
.param V36_part9='V36_part8+(-3.086983e+00)*S80+(-1.560765e+00)*S81+(-1.314969e+01)*S82+(-4.262996e+00)*S83+(-3.555310e+00)*S84+(-2.110312e+00)*S85+(-2.636257e+01)*S86+(-1.094860e+00)*S87+(-4.851001e+01)*S88+(-2.794454e+00)*S89'
.param V36_part10='V36_part9+8.964754e+01*S90+1.007576e+00*S91+1.032557e-01*S92+(-4.112747e-01)*S93+1.982813e+00*S94+(-1.655518e-01)*S95+(-1.790634e-01)*S96+1.950805e-01*S97+(-5.442272e-01)*S98+(-7.325559e-01)*S99'
.param V36_part11='V36_part10+1.396858e-02*S100+(-7.865048e-01)*S101+(-4.961159e+00)*S102+(-1.205156e-01)*S103+(-4.134299e-01)*S104+(-2.543115e+00)*S105+(-2.808091e+00)*S106+(-8.911789e-03)*S107+(-1.890388e+00)*S108+(-9.847928e-01)*S109'
.param V36_part12='V36_part11+(-5.380926e-01)*S110+(-8.461483e-01)*S111+(-1.107321e+00)*S112+(-4.122919e-01)*S113+(-1.943481e+00)*S114+(-1.727589e+00)*S115+(-2.600699e-01)*S116+(-6.527619e-01)*S117+(-1.082222e+00)*S118+(-1.304091e+00)*S119'
.param V36_part13='V36_part12+(-1.281516e+00)*S120+4.323435e+01*S121+(-9.851248e-01)*S122+(-7.605992e-01)*S123+3.710562e-02*S124+(-1.696642e-03)*S125+(-8.836161e-01)*S126+4.461245e-01*S127+4.965417e-01*S128+2.508589e-01*S129'
.param V36_part14='V36_part13+(-4.510246e-01)*S130+(-8.112566e-01)*S131+(-1.081222e+00)*S132+(-1.051693e-01)*S133+(-6.862083e-01)*S134+(-6.848394e+00)*S135+(-5.257935e+00)*S136+(-5.972651e-01)*S137+1.025407e+02*S138+(-1.430671e+00)*S139'
.param V36_part15='V36_part14+(-1.468640e+00)*S140+(-3.052428e+00)*S141+(-3.675060e+00)*S142+(-1.902641e+00)*S143+(-9.716232e+00)*S144+(-3.207390e+00)*S145+(-1.189412e+00)*S146+(-1.763875e+00)*S147+(-6.493212e-01)*S148+(-2.383943e+00)*S149'
.param V36_part16='V36_part15+(-3.608104e+00)*S150+1.455834e+00*S151+2.880084e-02*S152+3.858449e-01*S153+8.234572e+00*S154+(-3.911483e-01)*S155+6.020421e-01*S156+(-2.330780e+00)*S157+(-4.770457e-01)*S158+(-1.615938e+00)*S159'
.param V36_part17='V36_part16+(-2.634943e-01)*S160+(-2.555085e-01)*S161+(-6.680984e-01)*S162+(-1.850200e+00)*S163+(-6.204358e-01)*S164+3.331405e+00*S165+1.483965e+00*S166+(-5.224837e+00)*S167+(-1.189325e+00)*S168+1.866040e+00*S169'
.param V36_part18='V36_part17+(-2.167775e+00)*S170+(-8.462903e-01)*S171+(-5.087932e-01)*S172+(-9.160824e-01)*S173+(-5.198319e-01)*S174+(-1.100084e+00)*S175+(-5.595016e-01)*S176+(-5.510652e-01)*S177+(-1.203515e+00)*S178+(-5.858718e-01)*S179'
.param V36_part19='V36_part18+2.661031e+00*S180+1.066882e-01*S181+(-8.699479e-01)*S182+(-1.917329e+00)*S183+2.297188e+00*S184+(-8.595589e-01)*S185+(-1.416550e+00)*S186+(-3.488033e-01)*S187+(-2.010220e+00)*S188+(-1.719665e+00)*S189'
.param V36_part20='V36_part19+(-1.128859e+00)*S190+1.488456e-01*S191+(-2.327542e-01)*S192+(-1.000980e+00)*S193+(-6.099468e-01)*S194+3.939879e-01*S195+(-3.767124e+00)*S196+(-1.992002e+00)*S197+(-1.322654e+01)*S198+5.893926e-01*S199'
.param V36_part21='V36_part20+(-1.032368e+00)*S200+1.441460e+00*S201+1.477631e-02*S202+(-4.520183e-01)*S203+(-1.528415e+00)*S204+(-8.682226e-01)*S205+(-4.428435e-01)*S206+(-7.932497e+00)*S207+(-1.140127e+00)*S208+(-4.229895e-01)*S209'
.param V36_part22='V36_part21+(-2.892984e-01)*S210+9.856324e+00*S211+(-4.977332e-01)*S212+(-1.691329e+00)*S213+(-2.464509e-02)*S214+(-2.031771e-01)*S215+(-3.202541e-01)*S216+(-1.111665e+00)*S217+(-9.219162e-02)*S218+(-5.211292e-01)*S219'
.param V36_part23='V36_part22+(-2.198251e-01)*S220+(-1.427488e-01)*S221+(-9.951044e-01)*S222+(-4.183990e-01)*S223+(-1.376860e-01)*S224+(-1.266556e+00)*S225+5.630854e+00*S226+(-8.730020e-01)*S227+(-1.093748e+00)*S228+(-2.987802e+00)*S229'
.param V36_part24='V36_part23+(-9.952303e-01)*S230+(-8.327534e-02)*S231+(-1.250506e+00)*S232+(-6.110993e-01)*S233+(-4.356536e-01)*S234+(-1.295119e+00)*S235+(-5.089353e-01)*S236+(-3.772516e-01)*S237+(-6.173287e-01)*S238+(-4.557094e-01)*S239'
.param V36_part25='V36_part24+1.982440e+00*S240+(-2.307584e+00)*S241+(-1.042838e+00)*S242+1.155706e+00*S243+(-1.182552e-01)*S244+(-2.718362e-01)*S245+(-3.754836e-01)*S246+(-1.270515e+00)*S247+(-6.852495e-01)*S248+(-3.925290e-01)*S249'
.param V36_part26='V36_part25+(-6.697425e-01)*S250+(-4.469839e-01)*S251+(-7.330171e-01)*S252+(-8.809025e-01)*S253+(-3.920711e-01)*S254+3.655676e-01*S255+9.765067e-03*S256+(-7.773316e-01)*S257+(-9.426764e-01)*S258+(-8.520273e-01)*S259'
.param V36_part27='V36_part26+(-1.036417e+00)*S260+6.359188e-01*S261+9.498451e-01*S262+(-9.441989e-01)*S263+(-6.630235e-01)*S264+(-2.709662e+00)*S265+(-6.624352e-01)*S266+(-6.110861e-01)*S267+(-9.169452e-01)*S268+(-5.313512e-01)*S269'
.param V36_part28='V36_part27+(-4.553103e+00)*S270+7.423281e-01*S271+(-6.752281e-01)*S272+(-2.007937e-01)*S273+(-1.854317e+00)*S274+(-6.999662e-01)*S275+(-3.347436e-01)*S276+(-3.881497e-01)*S277+(-4.164288e-01)*S278+(-5.834486e-01)*S279'
.param V36_part29='V36_part28+(-1.003781e+00)*S280+(-3.078916e-01)*S281+(-3.272208e-01)*S282+(-4.179054e-01)*S283+(-1.154522e-01)*S284+(-7.877856e+00)*S285+(-8.895728e-01)*S286+(-9.665724e-01)*S287+(-9.817236e-01)*S288+(-1.076972e+00)*S289'
.param V36_part30='V36_part29+(-5.937751e-01)*S290+(-7.162634e-01)*S291+(-8.846024e-01)*S292+1.010126e-01*S293+(-5.220985e-01)*S294+(-6.443209e-01)*S295+8.710733e-03*S296+(-5.041976e-01)*S297+(-3.127203e-01)*S298+1.402416e-02*S299'
.param V36_part31='V36_part30+(-1.954654e+01)*S300+2.141842e-01*S301+1.708327e-01*S302+(-9.909542e-01)*S303+(-1.275219e+00)*S304+6.473269e-02*S305+(-6.907722e-01)*S306+(-1.292838e+00)*S307+(-4.891088e-01)*S308+(-3.321407e-01)*S309'
.param V36='V36_part31+(-8.444963e-01)*S310+(-2.978586e-01)*S311+(-7.346233e-02)*S312+(-5.849216e-01)*S313+(-2.286461e-01)*S314'
.param V37_part1='(-6.050891e+00)*S0+(-9.082311e+00)*S1+(-6.671672e+00)*S2+(-6.828123e+00)*S3+5.559771e+00*S4+(-1.222586e+01)*S5+3.898836e-01*S6+2.479829e+01*S7+9.034198e+00*S8+(-2.776166e+00)*S9'
.param V37_part2='V37_part1+(-8.547437e+00)*S10+1.903161e+00*S11+2.060813e+02*S12+1.648586e+02*S13+(-8.273371e-01)*S14+2.305767e+01*S15+4.051635e+03*S16+(-1.685905e+01)*S17+(-2.417384e+01)*S18+(-1.904991e+00)*S19'
.param V37_part3='V37_part2+3.591346e+00*S20+(-4.733085e+01)*S21+(-2.033981e+01)*S22+9.456683e+00*S23+(-1.504675e+01)*S24+(-5.686766e+01)*S25+1.000000e+04*S26+(-3.385198e+01)*S27+2.427008e+03*S28+(-1.472448e+03)*S29'
.param V37_part4='V37_part3+(-3.901091e-01)*S30+1.013713e+01*S31+(-1.308404e+00)*S32+(-2.656422e+00)*S33+7.675031e-02*S34+3.720521e-03*S35+(-1.003754e+01)*S36+2.637854e-01*S37+(-1.312336e+00)*S38+(-1.197467e+01)*S39'
.param V37_part5='V37_part4+(-7.379442e-01)*S40+(-8.584720e-01)*S41+(-7.212313e+00)*S42+1.809916e+00*S43+(-2.296980e-01)*S44+(-1.547972e+01)*S45+(-5.492390e+00)*S46+(-3.447546e+00)*S47+(-2.850920e+00)*S48+(-1.611873e+00)*S49'
.param V37_part6='V37_part5+(-2.154545e+00)*S50+(-3.333358e+01)*S51+(-1.622110e+00)*S52+(-7.953337e-01)*S53+3.728081e+00*S54+(-1.278009e+00)*S55+(-6.674382e-01)*S56+(-1.323496e+00)*S57+(-4.555612e-01)*S58+(-7.338815e-01)*S59'
.param V37_part7='V37_part6+(-6.180357e+01)*S60+(-8.829708e+00)*S61+(-2.791532e-01)*S62+(-2.079773e+01)*S63+(-2.611062e+00)*S64+(-3.273260e+00)*S65+(-1.203872e+01)*S66+6.952423e+01*S67+1.267918e-01*S68+3.908283e+00*S69'
.param V37_part8='V37_part7+1.084966e+02*S70+1.306753e+01*S71+(-9.334031e+00)*S72+2.647695e+02*S73+(-3.461406e+01)*S74+(-2.904231e+01)*S75+(-8.648372e+00)*S76+(-1.003859e+01)*S77+5.993108e+02*S78+6.725905e+01*S79'
.param V37_part9='V37_part8+(-2.250563e+01)*S80+(-5.090718e+00)*S81+1.001134e+01*S82+1.428893e+01*S83+(-6.559614e+00)*S84+(-3.012731e+00)*S85+(-2.895831e+01)*S86+(-5.181016e+00)*S87+4.773458e+02*S88+(-1.436779e+00)*S89'
.param V37_part10='V37_part9+6.611137e+01*S90+(-3.016331e+00)*S91+(-1.275344e+00)*S92+(-4.083977e+00)*S93+(-3.001887e+00)*S94+(-1.122365e+00)*S95+(-4.235999e+00)*S96+(-2.313044e+00)*S97+(-7.505889e-01)*S98+(-3.061311e+00)*S99'
.param V37_part11='V37_part10+(-2.240101e+00)*S100+(-1.167652e+00)*S101+(-2.268726e+01)*S102+(-1.018519e+00)*S103+(-1.019517e+00)*S104+(-6.345228e+00)*S105+(-3.215587e+00)*S106+(-1.571454e+00)*S107+(-5.832886e+00)*S108+(-2.336219e+00)*S109'
.param V37_part12='V37_part11+(-1.289291e+00)*S110+(-7.705550e+00)*S111+(-1.915668e+00)*S112+(-1.405733e+00)*S113+(-1.512246e+01)*S114+(-2.184495e+00)*S115+(-7.724964e-01)*S116+(-1.233389e+00)*S117+(-8.650921e-01)*S118+(-8.010627e-01)*S119'
.param V37_part13='V37_part12+(-5.689292e+00)*S120+3.312673e+01*S121+(-2.580141e+00)*S122+(-8.841835e+00)*S123+(-3.008842e+00)*S124+(-1.958637e+00)*S125+(-1.029941e+01)*S126+(-4.262724e+00)*S127+(-2.127834e+00)*S128+(-9.851646e+00)*S129'
.param V37_part14='V37_part13+(-4.495516e+00)*S130+(-1.598997e+00)*S131+(-1.262115e+00)*S132+(-2.167857e+00)*S133+(-1.659330e+00)*S134+(-2.976911e+01)*S135+(-4.625752e+00)*S136+(-1.880834e+00)*S137+8.933320e+01*S138+(-3.213166e+00)*S139'
.param V37_part15='V37_part14+(-3.820948e+00)*S140+(-7.155398e+00)*S141+(-3.903797e+00)*S142+(-1.344836e+00)*S143+(-2.177234e+01)*S144+(-3.368504e+00)*S145+(-8.331804e-01)*S146+(-4.007752e+00)*S147+(-3.591248e+00)*S148+(-3.393424e+00)*S149'
.param V37_part16='V37_part15+(-9.638082e+00)*S150+(-3.350622e+00)*S151+(-2.038619e+00)*S152+(-7.978306e+00)*S153+(-4.159778e+01)*S154+(-1.999378e+00)*S155+5.115077e+00*S156+(-2.505200e-02)*S157+(-1.419490e+00)*S158+(-1.333810e+00)*S159'
.param V37_part17='V37_part16+(-4.387958e-01)*S160+(-1.271219e+00)*S161+(-1.668421e+00)*S162+(-3.629489e-01)*S163+(-8.831411e-01)*S164+(-1.096667e+01)*S165+(-4.042978e+00)*S166+(-1.254261e+01)*S167+(-5.547076e+00)*S168+(-2.193613e+00)*S169'
.param V37_part18='V37_part17+(-1.238266e+01)*S170+(-1.191291e+00)*S171+(-1.103438e+00)*S172+(-1.008531e+00)*S173+(-4.422901e-01)*S174+(-1.018189e+00)*S175+(-9.211774e-01)*S176+5.784918e+00*S177+(-8.568134e-01)*S178+(-9.218377e-01)*S179'
.param V37_part19='V37_part18+(-1.460272e+01)*S180+(-7.588032e+00)*S181+(-1.539611e+00)*S182+(-5.697686e+00)*S183+(-3.326566e+00)*S184+(-1.641350e+00)*S185+(-4.664543e+00)*S186+(-4.378412e+00)*S187+(-1.869264e+00)*S188+(-8.882409e+00)*S189'
.param V37_part20='V37_part19+(-2.459146e+00)*S190+(-1.345219e+00)*S191+(-3.569477e-01)*S192+(-6.674140e-01)*S193+(-1.202526e+00)*S194+(-1.140423e+01)*S195+(-5.832226e+00)*S196+(-4.363870e+00)*S197+(-6.701643e+01)*S198+(-4.528327e+00)*S199'
.param V37_part21='V37_part20+(-2.391186e+00)*S200+(-1.747955e+01)*S201+(-5.235962e+00)*S202+(-3.148012e+00)*S203+4.182286e-01*S204+(-3.759723e+00)*S205+(-2.155240e+00)*S206+(-8.700199e+00)*S207+(-2.502148e+00)*S208+(-2.082199e+00)*S209'
.param V37_part22='V37_part21+(-4.709108e+00)*S210+(-6.479966e-01)*S211+(-1.730106e+00)*S212+(-2.498589e+00)*S213+(-1.452674e+00)*S214+(-1.299024e+00)*S215+9.051051e+00*S216+(-1.564814e+00)*S217+(-6.914327e-01)*S218+2.773743e+00*S219'
.param V37_part23='V37_part22+(-1.124733e+00)*S220+(-1.067879e+00)*S221+5.103189e+00*S222+(-5.717882e-01)*S223+(-7.824684e-01)*S224+(-4.058083e+00)*S225+(-1.735268e-02)*S226+(-1.797546e+00)*S227+(-5.682822e+00)*S228+(-5.652305e+00)*S229'
.param V37_part24='V37_part23+(-2.144103e+00)*S230+(-7.515044e-01)*S231+(-2.954530e+00)*S232+(-1.244621e+00)*S233+(-9.389327e-01)*S234+(-2.882317e+00)*S235+(-1.014792e+00)*S236+(-8.896418e-01)*S237+(-1.028995e+00)*S238+(-7.925712e-01)*S239'
.param V37_part25='V37_part24+(-5.585110e+00)*S240+(-3.544048e+00)*S241+(-1.659587e+00)*S242+5.907516e+01*S243+(-3.530370e+00)*S244+(-2.050269e+00)*S245+(-6.802561e-01)*S246+(-1.909386e+00)*S247+(-1.180504e+00)*S248+(-1.040274e+00)*S249'
.param V37_part26='V37_part25+(-1.777568e+00)*S250+(-9.674093e-01)*S251+(-1.767686e+00)*S252+(-2.651563e+00)*S253+(-8.155709e-01)*S254+(-4.460181e+01)*S255+(-2.683198e+00)*S256+(-2.458769e+00)*S257+(-1.697342e+01)*S258+(-4.309807e+00)*S259'
.param V37_part27='V37_part26+(-2.361948e+00)*S260+6.903953e+00*S261+3.516855e+00*S262+(-9.638304e-01)*S263+(-1.985372e+00)*S264+(-4.369113e+00)*S265+(-1.327027e+00)*S266+(-2.019284e+00)*S267+(-2.313253e+00)*S268+(-1.041403e+00)*S269'
.param V37_part28='V37_part27+(-2.711936e+00)*S270+(-2.881486e+00)*S271+(-1.410076e+00)*S272+2.683700e+00*S273+(-2.243936e+00)*S274+(-1.383955e+00)*S275+(-1.796819e+00)*S276+(-1.369742e+00)*S277+(-1.039490e+00)*S278+(-2.923065e+00)*S279'
.param V37_part29='V37_part28+(-2.992039e+00)*S280+(-8.966525e-01)*S281+(-9.159951e-01)*S282+(-1.006817e+00)*S283+(-1.077931e+00)*S284+(-4.438468e+00)*S285+(-1.591828e+00)*S286+(-1.404568e+00)*S287+(-2.537993e+00)*S288+(-1.440037e+00)*S289'
.param V37_part30='V37_part29+(-1.156178e+00)*S290+(-2.522604e+00)*S291+(-1.519419e+00)*S292+(-1.146933e+00)*S293+(-1.251526e+01)*S294+(-1.278680e+00)*S295+(-1.128198e+00)*S296+(-1.853261e+00)*S297+(-8.621553e-01)*S298+(-1.130260e+00)*S299'
.param V37_part31='V37_part30+2.133204e+01*S300+(-4.122343e+00)*S301+(-1.777525e+00)*S302+(-3.620531e+00)*S303+(-2.680854e+00)*S304+(-1.978671e+00)*S305+8.947509e+00*S306+(-1.624277e+00)*S307+(-1.201736e+00)*S308+4.304947e+00*S309'
.param V37='V37_part31+(-1.296283e+00)*S310+(-1.027554e+00)*S311+1.051287e+01*S312+(-1.034362e+00)*S313+(-9.673971e-01)*S314'
.param V38_part1='1.309073e+00*S0+(-1.437563e+00)*S1+4.305014e-01*S2+2.888052e+00*S3+3.666180e+00*S4+(-6.533658e+00)*S5+(-2.476755e+00)*S6+(-1.238398e+01)*S7+3.491007e+00*S8+(-6.846481e+01)*S9'
.param V38_part2='V38_part1+(-5.348842e+00)*S10+2.717481e+00*S11+(-1.385436e+02)*S12+(-1.136457e+02)*S13+4.164001e+00*S14+(-2.518177e+00)*S15+(-4.118809e+03)*S16+(-4.964097e+01)*S17+1.201283e+01*S18+(-1.959880e+01)*S19'
.param V38_part3='V38_part2+2.099323e+02*S20+9.213572e+00*S21+6.112610e-02*S22+(-5.357090e+01)*S23+2.036302e-01*S24+(-7.495682e+01)*S25+4.681534e+03*S26+7.794471e+00*S27+1.137404e+02*S28+(-1.652501e+02)*S29'
.param V38_part4='V38_part3+4.638861e+00*S30+(-3.188974e+00)*S31+7.293103e-01*S32+5.829167e+00*S33+(-1.252735e+00)*S34+2.769145e+00*S35+3.407468e+00*S36+2.116618e+00*S37+6.520860e+00*S38+3.071213e+00*S39'
.param V38_part5='V38_part4+1.034779e+00*S40+4.273985e+00*S41+4.232212e+00*S42+7.570850e+01*S43+4.594033e+00*S44+8.496382e-01*S45+7.841794e+00*S46+3.871868e+00*S47+1.311303e+00*S48+1.597488e+00*S49'
.param V38_part6='V38_part5+2.746111e+00*S50+4.211836e+01*S51+9.184466e-01*S52+1.595392e+00*S53+9.245042e-01*S54+8.139266e-01*S55+1.489036e+00*S56+5.139086e-01*S57+2.043903e+00*S58+1.365880e+00*S59'
.param V38_part7='V38_part6+2.648998e+00*S60+9.768696e-01*S61+1.932124e+00*S62+(-4.303111e+01)*S63+2.174620e-01*S64+2.582625e-01*S65+(-1.643618e-01)*S66+8.193313e+00*S67+4.709120e+00*S68+1.294162e+00*S69'
.param V38_part8='V38_part7+6.030101e+01*S70+4.799124e+01*S71+(-3.700561e-01)*S72+1.000000e+04*S73+(-3.984048e+00)*S74+3.366087e-03*S75+(-4.173149e+00)*S76+4.462212e+00*S77+(-5.777153e-02)*S78+1.221207e+01*S79'
.param V38_part9='V38_part8+(-1.730879e+01)*S80+(-9.500193e-01)*S81+1.069664e+00*S82+3.525052e+00*S83+(-1.097665e+00)*S84+(-7.214844e-01)*S85+(-5.248507e-01)*S86+5.369000e-01*S87+(-1.026125e+02)*S88+5.406301e-02*S89'
.param V38_part10='V38_part9+(-1.733588e+02)*S90+1.713278e+00*S91+1.005908e+00*S92+1.278810e+00*S93+1.578816e+00*S94+7.924310e-01*S95+1.171667e+00*S96+1.036818e+00*S97+1.157034e+01*S98+1.149539e+00*S99'
.param V38_part11='V38_part10+1.465949e+00*S100+4.304098e-01*S101+(-1.000000e+04)*S102+1.388393e+00*S103+1.267578e+00*S104+8.152959e-01*S105+6.374421e-01*S106+6.149699e-01*S107+7.148751e-01*S108+5.920902e-01*S109'
.param V38_part12='V38_part11+5.313116e-01*S110+5.041308e-01*S111+5.915454e-01*S112+5.624196e-01*S113+1.330160e+00*S114+1.680126e+00*S115+1.026356e+00*S116+1.429658e+00*S117+9.347138e-01*S118+4.838015e+00*S119'
.param V38_part13='V38_part12+4.179291e-01*S120+8.780549e+00*S121+2.455300e-01*S122+2.586330e-01*S123+3.694688e-01*S124+3.038029e-01*S125+1.150895e-01*S126+3.623547e-01*S127+2.658627e-01*S128+4.291032e-01*S129'
.param V38_part14='V38_part13+1.358294e-01*S130+2.174046e-01*S131+1.012870e+00*S132+1.799307e-01*S133+2.501850e-01*S134+(-5.116244e-01)*S135+5.025494e-01*S136+3.133834e-01*S137+3.075976e+01*S138+7.190296e-01*S139'
.param V38_part15='V38_part14+(-1.607648e-01)*S140+1.401013e-01*S141+(-1.020201e-01)*S142+2.803511e-01*S143+(-6.641604e+00)*S144+(-1.990505e-01)*S145+6.948995e-02*S146+3.233236e-01*S147+(-2.613232e-01)*S148+(-2.037089e-01)*S149'
.param V38_part16='V38_part15+1.103994e+00*S150+1.153342e+00*S151+6.490480e-01*S152+8.564397e-01*S153+(-1.275801e+02)*S154+5.960513e-01*S155+2.714107e+00*S156+3.201121e+01*S157+3.933096e-01*S158+9.484182e+00*S159'
.param V38_part17='V38_part16+1.470692e+00*S160+3.863665e-01*S161+2.459609e-01*S162+7.940435e+00*S163+2.465717e-01*S164+1.214504e+00*S165+4.442851e-01*S166+(-1.561026e+00)*S167+7.287767e-01*S168+2.225396e+01*S169'
.param V38_part18='V38_part17+(-4.397929e+00)*S170+1.444596e+00*S171+3.142411e+00*S172+5.042213e-01*S173+1.369781e+00*S174+6.942089e-01*S175+7.615002e-01*S176+1.241594e+01*S177+2.024807e+00*S178+6.690394e-01*S179'
.param V38_part19='V38_part18+4.433755e-01*S180+(-5.934738e+00)*S181+4.059589e-01*S182+6.910315e-01*S183+1.983899e-01*S184+2.895049e-01*S185+1.813265e-01*S186+2.996385e-01*S187+9.370407e-01*S188+6.704371e-01*S189'
.param V38_part20='V38_part19+1.963864e-01*S190+4.074825e-01*S191+1.280707e+00*S192+1.377337e+00*S193+5.909524e-01*S194+(-1.146857e-02)*S195+1.334161e-01*S196+5.605957e-02*S197+1.952104e-01*S198+(-5.557528e-01)*S199'
.param V38_part21='V38_part20+3.008884e-03*S200+3.296680e-02*S201+(-7.593905e-02)*S202+(-3.459867e-03)*S203+1.357441e+00*S204+4.916800e-02*S205+7.860912e-03*S206+(-1.041751e+00)*S207+5.708423e-02*S208+7.897221e-02*S209'
.param V38_part22='V38_part21+1.095421e+00*S210+8.993410e+02*S211+4.450877e-01*S212+5.152440e-01*S213+1.376869e+00*S214+4.335418e-01*S215+2.076496e+01*S216+1.233068e+00*S217+4.555265e-01*S218+5.255487e+00*S219'
.param V38_part23='V38_part22+8.620001e-01*S220+3.841339e-01*S221+1.291309e+01*S222+1.186172e+00*S223+4.309745e-01*S224+7.553476e-01*S225+4.718812e+01*S226+3.748276e-01*S227+9.441393e-01*S228+(-1.813348e+00)*S229'
.param V38_part24='V38_part23+1.990516e-01*S230+6.126834e-01*S231+2.761440e-01*S232+4.975373e-01*S233+1.208908e+00*S234+2.651501e-01*S235+4.272503e-01*S236+1.104785e+00*S237+8.695775e-01*S238+3.940330e-01*S239'
.param V38_part25='V38_part24+2.930502e-01*S240+7.551373e-01*S241+4.352088e-01*S242+1.000000e+04*S243+8.313263e-01*S244+1.429392e-01*S245+5.888028e-01*S246+8.826269e-01*S247+4.503494e-01*S248+1.402706e+00*S249'
.param V38_part26='V38_part25+8.149944e-01*S250+4.166919e-01*S251+2.387565e-01*S252+2.936658e-01*S253+4.039692e-01*S254+(-2.011124e+00)*S255+3.854260e-02*S256+3.666911e-02*S257+(-1.307620e-01)*S258+(-1.057608e-01)*S259'
.param V38_part27='V38_part26+9.016943e-02*S260+1.864233e+01*S261+1.299719e+01*S262+2.542396e-01*S263+8.492215e-01*S264+(-9.772098e-01)*S265+5.055755e-01*S266+2.892554e-01*S267+(-6.686946e-02)*S268+5.497257e-01*S269'
.param V38_part28='V38_part27+1.287037e+00*S270+8.407111e-01*S271+2.732290e-01*S272+3.813098e+00*S273+8.291826e-01*S274+1.907202e-01*S275+1.048247e+00*S276+1.264776e+00*S277+2.862405e-01*S278+1.292392e-01*S279'
.param V38_part29='V38_part28+7.342267e-02*S280+2.772429e-01*S281+9.489142e-01*S282+6.024037e-01*S283+4.013241e-01*S284+9.217753e+00*S285+1.839483e+00*S286+5.497028e-01*S287+6.292718e-01*S288+4.805026e-01*S289'
.param V38_part30='V38_part29+3.476175e-01*S290+1.121499e+00*S291+8.522388e-01*S292+5.198874e-01*S293+(-3.504027e-01)*S294+7.565252e-01*S295+4.456397e-01*S296+2.041812e-01*S297+6.654458e-01*S298+4.454496e-01*S299'
.param V38_part31='V38_part30+2.677657e+02*S300+3.165728e-02*S301+1.141668e-01*S302+7.642425e-01*S303+2.942477e-01*S304+1.315979e-01*S305+3.763997e+01*S306+9.136201e-01*S307+3.725654e-01*S308+1.136895e+01*S309'
.param V38='V38_part31+7.719110e-01*S310+3.720044e-01*S311+4.632490e+01*S312+6.793828e-01*S313+3.765211e-01*S314'
.param V39_part1='(-1.014344e-01)*S0+5.002863e-03*S1+2.756826e-01*S2+(-5.772197e-04)*S3+(-1.709639e-01)*S4+5.791262e-01*S5+(-1.986108e-01)*S6+2.587193e-01*S7+(-6.282044e-02)*S8+7.626644e-02*S9'
.param V39_part2='V39_part1+8.741465e-02*S10+1.405763e-02*S11+(-3.880231e-01)*S12+(-7.902545e-01)*S13+1.021442e-02*S14+(-4.210212e-02)*S15+4.263056e+03*S16+(-1.524927e+00)*S17+1.654545e-01*S18+1.916501e+00*S19'
.param V39_part3='V39_part2+1.684383e+00*S20+3.413298e+00*S21+(-1.669118e-01)*S22+1.109954e+01*S23+3.129728e-02*S24+2.252264e-01*S25+1.000000e+04*S26+(-7.159435e-02)*S27+1.226193e+01*S28+(-6.621650e+00)*S29'
.param V39_part4='V39_part3+2.576378e-03*S30+2.902337e-02*S31+(-3.073035e-02)*S32+(-9.067894e-03)*S33+(-1.055995e-01)*S34+4.197766e-03*S35+(-1.126122e-01)*S36+(-1.388899e-02)*S37+(-7.951149e-03)*S38+(-4.381108e-01)*S39'
.param V39_part5='V39_part4+(-3.196415e-02)*S40+(-1.212516e-02)*S41+(-5.231680e-01)*S42+(-1.756292e+00)*S43+2.110062e-02*S44+(-1.301035e-01)*S45+(-2.152060e-01)*S46+4.097905e-02*S47+(-7.127226e-02)*S48+1.990905e-01*S49'
.param V39_part6='V39_part5+6.870003e-02*S50+(-6.142018e+00)*S51+(-1.024858e-01)*S52+(-9.768219e-03)*S53+(-3.412381e-01)*S54+(-1.869474e-01)*S55+(-1.830756e-02)*S56+(-2.492263e-01)*S57+(-3.351396e-02)*S58+(-3.424576e-02)*S59'
.param V39_part7='V39_part6+3.273148e-01*S60+(-9.428286e-01)*S61+1.052115e-01*S62+4.510023e+01*S63+2.581819e-02*S64+8.956566e-02*S65+(-3.945497e-01)*S66+(-4.220954e+00)*S67+5.677781e-02*S68+(-6.280087e-01)*S69'
.param V39_part8='V39_part7+2.881811e+00*S70+1.102069e+00*S71+3.470248e+00*S72+8.273272e+00*S73+1.517144e+00*S74+(-1.019736e+00)*S75+1.087757e+00*S76+(-1.418641e+00)*S77+7.191535e-03*S78+1.996234e+00*S79'
.param V39_part9='V39_part8+2.168851e+00*S80+3.083898e-01*S81+1.696939e+00*S82+3.233642e+00*S83+3.011044e+00*S84+3.974776e-01*S85+(-6.016671e-01)*S86+5.101182e-01*S87+9.898682e+02*S88+2.925657e-01*S89'
.param V39_part10='V39_part9+(-5.401716e+00)*S90+(-4.982746e-02)*S91+4.876857e-03*S92+(-6.557598e-02)*S93+1.250356e-01*S94+(-5.276677e-03)*S95+(-7.482953e-02)*S96+(-3.233822e-02)*S97+2.837413e-02*S98+(-1.216758e-01)*S99'
.param V39_part11='V39_part10+7.118265e-03*S100+(-1.858557e-02)*S101+(-4.191733e+00)*S102+(-2.137943e-02)*S103+(-3.540078e-04)*S104+(-1.304290e-01)*S105+(-2.253945e-01)*S106+(-1.792543e-02)*S107+(-5.363074e-01)*S108+(-4.749612e-01)*S109'
.param V39_part12='V39_part11+4.834791e-03*S110+(-6.059204e-01)*S111+(-1.210343e-01)*S112+(-1.025255e-02)*S113+(-8.142534e-01)*S114+(-1.129524e-01)*S115+(-3.072453e-02)*S116+2.102326e-01*S117+(-2.230723e-02)*S118+1.646479e-01*S119'
.param V39_part13='V39_part12+(-2.954582e-01)*S120+(-3.273113e+00)*S121+(-3.115821e-04)*S122+(-4.682870e-02)*S123+(-1.098796e-02)*S124+2.265119e-02*S125+(-3.652869e-01)*S126+(-3.031779e-02)*S127+1.151711e-01*S128+(-1.113753e-01)*S129'
.param V39_part14='V39_part13+(-5.860581e-02)*S130+1.606516e-02*S131+4.101516e-01*S132+(-1.166632e-02)*S133+1.982408e-04*S134+(-3.665239e+00)*S135+(-3.000737e-01)*S136+7.723500e-02*S137+(-4.810982e+02)*S138+4.758588e-02*S139'
.param V39_part15='V39_part14+8.086291e-04*S140+2.202276e-01*S141+(-1.562826e-01)*S142+2.148653e-01*S143+(-1.312277e+00)*S144+(-2.148468e-01)*S145+1.890872e-02*S146+3.926390e-02*S147+(-2.461147e-01)*S148+(-4.247459e-02)*S149'
.param V39_part16='V39_part15+(-8.241380e-01)*S150+4.696094e-02*S151+3.458804e-02*S152+(-2.874877e-01)*S153+(-2.461152e-01)*S154+2.896385e-02*S155+(-1.918805e+00)*S156+3.696576e-03*S157+9.284091e-03*S158+7.707036e-02*S159'
.param V39_part17='V39_part16+(-8.607627e-03)*S160+3.728699e-02*S161+(-2.048145e-01)*S162+(-2.252919e-01)*S163+(-1.955161e-02)*S164+1.461489e-02*S165+5.047952e-03*S166+(-1.437916e-02)*S167+(-2.663354e-01)*S168+(-1.727548e+00)*S169'
.param V39_part18='V39_part17+2.072482e-01*S170+1.334036e-01*S171+4.473433e-02*S172+(-2.451218e-02)*S173+1.683302e-01*S174+(-5.347374e-02)*S175+3.457710e-02*S176+2.784422e-01*S177+(-1.327928e-01)*S178+(-9.605159e-03)*S179'
.param V39_part19='V39_part18+(-9.950944e-02)*S180+(-2.991631e-02)*S181+6.988927e-05*S182+1.471475e-02*S183+6.669208e-02*S184+(-1.136287e-01)*S185+(-2.636056e-01)*S186+(-7.721434e-02)*S187+(-1.449452e-01)*S188+(-1.158032e-01)*S189'
.param V39_part20='V39_part19+1.772560e-01*S190+1.702243e-01*S191+4.569354e-02*S192+(-9.199518e-02)*S193+(-8.799583e-02)*S194+2.357601e-01*S195+(-4.062646e-01)*S196+(-1.789474e-02)*S197+(-1.085913e+01)*S198+(-1.267275e-02)*S199'
.param V39_part21='V39_part20+1.624688e-02*S200+7.192470e-02*S201+(-1.671491e-01)*S202+8.116297e-02*S203+(-3.940703e-02)*S204+(-1.369891e-01)*S205+4.701977e-02*S206+(-2.669996e+00)*S207+(-1.304238e-01)*S208+1.835063e-03*S209'
.param V39_part22='V39_part21+(-1.678152e-01)*S210+2.092727e-01*S211+(-2.254404e-02)*S212+(-1.390198e-01)*S213+(-9.861190e-02)*S214+(-2.743411e-02)*S215+(-2.715504e-01)*S216+(-3.628897e-03)*S217+(-1.224119e-02)*S218+7.519663e-02*S219'
.param V39_part23='V39_part22+9.491098e-02*S220+8.854902e-03*S221+4.368207e-01*S222+5.922358e-02*S223+9.248792e-02*S224+(-4.260896e-01)*S225+(-8.401545e-02)*S226+(-3.193657e-02)*S227+5.227006e-03*S228+(-1.301901e-01)*S229'
.param V39_part24='V39_part23+(-8.488055e-02)*S230+(-2.102135e-01)*S231+2.185708e-02*S232+(-1.041036e-01)*S233+1.030625e-01*S234+4.885790e-03*S235+(-7.657554e-02)*S236+9.427022e-02*S237+(-6.380227e-02)*S238+(-4.117943e-02)*S239'
.param V39_part25='V39_part24+8.925512e-03*S240+(-3.187035e-01)*S241+(-1.295016e-01)*S242+1.049557e+00*S243+1.368420e-01*S244+4.759738e-02*S245+(-1.391706e-01)*S246+(-1.020132e-01)*S247+(-8.752893e-02)*S248+(-1.647779e-01)*S249'
.param V39_part26='V39_part25+1.858211e-01*S250+(-6.497970e-02)*S251+(-1.377911e-01)*S252+1.044669e-01*S253+(-4.082867e-02)*S254+(-1.273238e+00)*S255+(-5.310509e-02)*S256+(-8.277755e-03)*S257+(-7.893859e-01)*S258+(-1.415173e-01)*S259'
.param V39_part27='V39_part26+(-3.685188e-02)*S260+(-6.654233e-01)*S261+5.965811e-01*S262+(-5.101262e-02)*S263+1.070859e-01*S264+(-9.695626e-02)*S265+(-5.358089e-02)*S266+(-2.314343e-01)*S267+1.799825e-01*S268+(-4.102892e-02)*S269'
.param V39_part28='V39_part27+(-4.128841e-02)*S270+5.836875e-02*S271+(-3.745777e-02)*S272+1.558307e-01*S273+2.520814e-02*S274+(-3.250318e-02)*S275+4.365646e-02*S276+(-1.634981e-02)*S277+(-7.081344e-02)*S278+(-2.064526e-01)*S279'
.param V39_part29='V39_part28+(-6.464430e-02)*S280+(-5.177554e-02)*S281+6.727612e-04*S282+(-4.530528e-02)*S283+7.443384e-02*S284+(-5.153167e-02)*S285+8.069297e-02*S286+(-1.021600e-01)*S287+(-1.858868e-01)*S288+(-1.239180e-01)*S289'
.param V39_part30='V39_part29+(-8.343573e-02)*S290+(-2.997293e-01)*S291+(-1.005514e-01)*S292+9.414408e-02*S293+(-7.036939e-01)*S294+(-7.241040e-02)*S295+8.398840e-02*S296+(-1.376998e-01)*S297+6.966028e-02*S298+6.364446e-02*S299'
.param V39_part31='V39_part30+(-8.027495e+00)*S300+(-2.734469e-02)*S301+1.343740e-02*S302+6.725230e-02*S303+1.009951e-01*S304+1.334124e-02*S305+3.430936e-01*S306+(-6.473468e-02)*S307+(-5.192988e-02)*S308+1.607160e-01*S309'
.param V39='V39_part31+(-3.247000e-02)*S310+(-2.067426e-02)*S311+4.048434e-01*S312+(-2.349408e-02)*S313+(-3.388787e-03)*S314'
.param V40_part1='7.967792e+00*S0+0.000000e+00*S1+1.323951e+00*S2+1.816164e+01*S3+1.087824e+01*S4+0.000000e+00*S5+1.526525e+01*S6+1.567321e+01*S7+1.260145e+01*S8+0.000000e+00*S9'
.param V40_part2='V40_part1+0.000000e+00*S10+7.000266e+00*S11+(-1.671873e-01)*S12+0.000000e+00*S13+9.749795e+00*S14+0.000000e+00*S15+1.517429e+01*S16+1.179852e+01*S17+1.528232e+01*S18+0.000000e+00*S19'
.param V40_part3='V40_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+7.366731e+00*S23+1.265528e+01*S24+0.000000e+00*S25+(-9.546248e-01)*S26+(-4.876070e+00)*S27+4.383356e+00*S28+4.849514e+00*S29'
.param V40_part4='V40_part3+0.000000e+00*S30+0.000000e+00*S31+1.041467e+01*S32+0.000000e+00*S33+0.000000e+00*S34+2.776958e+01*S35+0.000000e+00*S36+3.814750e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V40_part5='V40_part4+2.179939e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+2.002855e+00*S47+0.000000e+00*S48+1.894941e+01*S49'
.param V40_part6='V40_part5+1.221001e+01*S50+0.000000e+00*S51+2.567470e+01*S52+2.616557e+01*S53+0.000000e+00*S54+2.495750e+01*S55+2.356629e+01*S56+0.000000e+00*S57+2.937862e+01*S58+1.164698e+01*S59'
.param V40_part7='V40_part6+0.000000e+00*S60+(-2.682358e+00)*S61+0.000000e+00*S62+1.274363e+01*S63+9.139091e+00*S64+1.129499e+01*S65+2.774385e+01*S66+0.000000e+00*S67+0.000000e+00*S68+8.079928e+01*S69'
.param V40_part8='V40_part7+0.000000e+00*S70+0.000000e+00*S71+2.307426e+01*S72+0.000000e+00*S73+0.000000e+00*S74+1.410524e+01*S75+2.684718e+01*S76+1.669597e+00*S77+6.089124e+00*S78+5.717519e+00*S79'
.param V40_part9='V40_part8+2.014841e+01*S80+1.792644e+01*S81+1.361454e+01*S82+1.931685e+01*S83+1.429458e+01*S84+1.436710e+01*S85+2.357470e+01*S86+1.878251e+01*S87+1.779434e+01*S88+1.705273e+01*S89'
.param V40_part10='V40_part9+0.000000e+00*S90+3.708201e+01*S91+1.720486e+01*S92+2.912814e+01*S93+2.702039e+01*S94+2.357634e+01*S95+3.006295e+01*S96+3.019666e+01*S97+0.000000e+00*S98+3.179618e+01*S99'
.param V40_part11='V40_part10+3.328004e+01*S100+0.000000e+00*S101+0.000000e+00*S102+4.144404e+01*S103+(-2.884633e+01)*S104+2.182762e+01*S105+1.371705e+01*S106+1.754635e+01*S107+2.214035e+01*S108+2.102865e+01*S109'
.param V40_part12='V40_part11+0.000000e+00*S110+2.470541e+01*S111+2.112801e+01*S112+0.000000e+00*S113+0.000000e+00*S114+3.069802e+01*S115+1.579633e+01*S116+4.814171e+01*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V40_part13='V40_part12+2.536518e+01*S120+0.000000e+00*S121+1.882749e+01*S122+2.823052e+01*S123+2.208345e+01*S124+1.749257e+01*S125+9.621290e+00*S126+1.334750e+01*S127+4.318749e+01*S128+2.184128e+01*S129'
.param V40_part14='V40_part13+(-3.617874e-01)*S130+1.814414e+01*S131+6.244295e+01*S132+3.927987e+01*S133+1.205996e+01*S134+1.129257e+01*S135+2.038663e-01*S136+8.996752e+00*S137+1.844308e+01*S138+1.053593e+01*S139'
.param V40_part15='V40_part14+9.506395e+00*S140+2.299783e+01*S141+(-4.161581e+00)*S142+(-4.141344e+00)*S143+6.974739e+00*S144+(-2.596842e+00)*S145+(-3.090286e+00)*S146+1.117988e+01*S147+(-8.241400e+00)*S148+(-2.459263e+01)*S149'
.param V40_part16='V40_part15+0.000000e+00*S150+0.000000e+00*S151+1.777212e+01*S152+3.231342e+01*S153+0.000000e+00*S154+2.345393e+01*S155+0.000000e+00*S156+0.000000e+00*S157+3.306217e+01*S158+0.000000e+00*S159'
.param V40_part17='V40_part16+4.608031e+01*S160+1.320508e+02*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+3.514334e+01*S165+0.000000e+00*S166+0.000000e+00*S167+2.744826e+01*S168+0.000000e+00*S169'
.param V40_part18='V40_part17+0.000000e+00*S170+6.059673e+01*S171+0.000000e+00*S172+0.000000e+00*S173+5.833879e+01*S174+7.549101e+01*S175+0.000000e+00*S176+2.895229e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V40_part19='V40_part18+1.410809e+01*S180+4.028000e+01*S181+5.213736e+00*S182+2.897860e+01*S183+2.119142e+01*S184+4.573865e+01*S185+2.744422e+01*S186+7.212148e+00*S187+1.300045e+02*S188+6.730450e+01*S189'
.param V40_part20='V40_part19+1.183927e+01*S190+7.831596e+01*S191+6.800853e+01*S192+0.000000e+00*S193+0.000000e+00*S194+1.637016e+01*S195+1.028989e+01*S196+0.000000e+00*S197+2.737854e+01*S198+1.746160e+01*S199'
.param V40_part21='V40_part20+1.319840e+01*S200+1.062280e+01*S201+9.155887e+00*S202+(-1.981520e+00)*S203+0.000000e+00*S204+(-1.853340e+01)*S205+(-2.065109e+00)*S206+(-4.034868e+01)*S207+(-2.647638e+01)*S208+(-6.356390e+00)*S209'
.param V40_part22='V40_part21+3.468063e+01*S210+5.912761e+01*S211+1.575281e+01*S212+0.000000e+00*S213+5.218928e+01*S214+(-7.516034e+00)*S215+0.000000e+00*S216+9.796279e+01*S217+(-4.866975e+01)*S218+0.000000e+00*S219'
.param V40_part23='V40_part22+6.123812e+01*S220+1.675337e+02*S221+1.825195e+01*S222+3.364618e+01*S223+1.446206e+02*S224+3.126093e+01*S225+0.000000e+00*S226+0.000000e+00*S227+5.940730e+01*S228+3.288710e+01*S229'
.param V40_part24='V40_part23+6.235488e+01*S230+8.572159e+01*S231+(-2.595070e+01)*S232+0.000000e+00*S233+5.111506e+01*S234+(-3.217531e+01)*S235+0.000000e+00*S236+5.412256e+01*S237+9.710625e+01*S238+0.000000e+00*S239'
.param V40_part25='V40_part24+3.735181e+01*S240+6.758455e+01*S241+0.000000e+00*S242+0.000000e+00*S243+4.203564e+01*S244+(-2.068996e+01)*S245+1.170775e+02*S246+4.705180e+01*S247+0.000000e+00*S248+2.857978e+01*S249'
.param V40_part26='V40_part25+1.819920e+01*S250+0.000000e+00*S251+2.962815e+01*S252+(-5.240108e+00)*S253+0.000000e+00*S254+0.000000e+00*S255+2.494543e+01*S256+2.171348e+01*S257+6.904761e+00*S258+1.464620e+01*S259'
.param V40_part27='V40_part26+(-1.345591e+01)*S260+3.788023e+01*S261+0.000000e+00*S262+8.638716e+01*S263+7.281051e+01*S264+0.000000e+00*S265+6.428734e+01*S266+0.000000e+00*S267+(-4.082586e+01)*S268+0.000000e+00*S269'
.param V40_part28='V40_part27+3.961295e+01*S270+6.173409e+00*S271+0.000000e+00*S272+0.000000e+00*S273+6.277964e+01*S274+0.000000e+00*S275+5.002713e+01*S276+4.685461e+01*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V40_part29='V40_part28+(-2.944315e+01)*S280+0.000000e+00*S281+1.566369e+01*S282+1.183783e+02*S283+1.418207e+02*S284+2.583300e+01*S285+6.702835e+01*S286+0.000000e+00*S287+5.729934e+01*S288+6.350383e+01*S289'
.param V40_part30='V40_part29+0.000000e+00*S290+2.332761e+01*S291+0.000000e+00*S292+5.514520e+01*S293+(-2.719608e+00)*S294+0.000000e+00*S295+8.800237e+01*S296+2.287698e+01*S297+4.648937e+01*S298+1.141898e+02*S299'
.param V40_part31='V40_part30+2.516119e+01*S300+6.511478e-01*S301+3.382326e+00*S302+6.068096e+01*S303+2.159987e+01*S304+(-1.877077e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+1.370918e+02*S308+0.000000e+00*S309'
.param V40='V40_part31+0.000000e+00*S310+1.328734e+02*S311+0.000000e+00*S312+0.000000e+00*S313+1.311228e+02*S314'
.param V41_part1='5.938035e+01*S0+0.000000e+00*S1+1.716485e+01*S2+3.133694e+01*S3+8.637592e+00*S4+0.000000e+00*S5+(-1.122317e+01)*S6+(-5.663721e+00)*S7+8.171133e+00*S8+0.000000e+00*S9'
.param V41_part2='V41_part1+0.000000e+00*S10+(-2.057935e+00)*S11+(-1.761515e+00)*S12+0.000000e+00*S13+(-2.905655e+00)*S14+0.000000e+00*S15+(-1.137169e+01)*S16+(-1.068787e+01)*S17+9.085676e+00*S18+0.000000e+00*S19'
.param V41_part3='V41_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+(-1.914457e+00)*S23+(-2.556150e+00)*S24+0.000000e+00*S25+4.804869e+00*S26+1.343413e+01*S27+2.022898e+00*S28+4.308609e-01*S29'
.param V41_part4='V41_part3+0.000000e+00*S30+0.000000e+00*S31+2.835099e+01*S32+0.000000e+00*S33+0.000000e+00*S34+1.660907e+01*S35+0.000000e+00*S36+3.475103e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V41_part5='V41_part4+(-2.331800e+01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+1.354250e+01*S47+0.000000e+00*S48+4.641401e+01*S49'
.param V41_part6='V41_part5+5.775294e+00*S50+0.000000e+00*S51+2.454417e+01*S52+2.415974e+01*S53+0.000000e+00*S54+2.745407e+01*S55+2.881106e+01*S56+0.000000e+00*S57+1.781784e+01*S58+4.279794e+01*S59'
.param V41_part7='V41_part6+0.000000e+00*S60+1.035167e+01*S61+0.000000e+00*S62+4.316372e+01*S63+3.152722e+01*S64+1.255697e+01*S65+3.387522e+01*S66+0.000000e+00*S67+0.000000e+00*S68+(-3.910252e-01)*S69'
.param V41_part8='V41_part7+0.000000e+00*S70+0.000000e+00*S71+8.026520e+00*S72+0.000000e+00*S73+0.000000e+00*S74+8.007543e+00*S75+(-4.171379e+01)*S76+2.424992e+01*S77+1.029855e+01*S78+2.446416e+01*S79'
.param V41_part9='V41_part8+(-8.896680e+00)*S80+1.534103e+01*S81+1.244745e+01*S82+6.131847e+00*S83+3.690335e+00*S84+9.521171e+00*S85+6.389493e+00*S86+1.308028e+01*S87+1.443216e+01*S88+1.252956e+01*S89'
.param V41_part10='V41_part9+0.000000e+00*S90+1.695854e+01*S91+5.107441e+01*S92+2.502086e+01*S93+2.568363e+01*S94+2.327913e+01*S95+2.566028e+01*S96+2.063412e+01*S97+0.000000e+00*S98+2.780765e+01*S99'
.param V41_part11='V41_part10+9.821236e+00*S100+0.000000e+00*S101+0.000000e+00*S102+(-8.045195e+00)*S103+6.251821e+01*S104+4.678128e+01*S105+5.227187e+01*S106+3.384286e+01*S107+4.097317e+01*S108+3.384231e+01*S109'
.param V41_part12='V41_part11+0.000000e+00*S110+1.213036e-01*S111+3.672766e+01*S112+0.000000e+00*S113+0.000000e+00*S114+2.682211e+01*S115+4.232508e+01*S116+1.892019e+01*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V41_part13='V41_part12+4.243867e+01*S120+0.000000e+00*S121+1.938526e+00*S122+2.473346e+01*S123+1.018283e+01*S124+2.196996e+01*S125+5.643465e+00*S126+(-2.569076e+00)*S127+(-1.929352e+01)*S128+6.474775e+00*S129'
.param V41_part14='V41_part13+1.771211e+01*S130+(-2.065870e+01)*S131+3.246677e+01*S132+(-5.461625e+00)*S133+(-1.436195e+01)*S134+2.285255e+01*S135+7.357715e+01*S136+2.716767e+01*S137+4.455099e+01*S138+2.156157e+01*S139'
.param V41_part15='V41_part14+1.275526e+01*S140+4.978493e+01*S141+2.398577e+01*S142+3.788926e+01*S143+1.922475e+01*S144+1.948943e+01*S145+2.729944e+01*S146+2.855819e+01*S147+1.001190e+01*S148+2.211862e+01*S149'
.param V41_part16='V41_part15+0.000000e+00*S150+0.000000e+00*S151+4.104484e+01*S152+1.049219e+00*S153+0.000000e+00*S154+2.103721e+01*S155+0.000000e+00*S156+0.000000e+00*S157+(-4.157710e+01)*S158+0.000000e+00*S159'
.param V41_part17='V41_part16+8.126531e+00*S160+(-1.020702e+02)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+8.410262e+00*S165+0.000000e+00*S166+0.000000e+00*S167+4.494150e+01*S168+0.000000e+00*S169'
.param V41_part18='V41_part17+0.000000e+00*S170+2.050354e+01*S171+0.000000e+00*S172+0.000000e+00*S173+1.411565e+01*S174+(-3.854619e+01)*S175+0.000000e+00*S176+5.060283e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V41_part19='V41_part18+3.932488e+01*S180+(-2.474708e+01)*S181+8.385616e+01*S182+5.048435e+01*S183+3.054243e+01*S184+(-3.301322e+01)*S185+5.104666e+01*S186+2.911384e+01*S187+(-6.696157e+01)*S188+1.673204e+01*S189'
.param V41_part20='V41_part19+(-3.732707e+00)*S190+(-2.881750e+01)*S191+2.958432e+01*S192+0.000000e+00*S193+0.000000e+00*S194+1.417449e+01*S195+3.265049e+01*S196+0.000000e+00*S197+(-3.710618e+00)*S198+(-6.945844e+00)*S199'
.param V41_part21='V41_part20+(-1.657529e+01)*S200+(-4.572660e+00)*S201+4.885118e-01*S202+1.570641e+01*S203+0.000000e+00*S204+4.462071e+01*S205+(-7.673664e+00)*S206+4.659835e+01*S207+3.519558e+01*S208+(-1.942507e+01)*S209'
.param V41_part22='V41_part21+7.396569e+00*S210+(-5.701509e+01)*S211+3.226281e+01*S212+0.000000e+00*S213+5.706084e+00*S214+4.085171e+01*S215+0.000000e+00*S216+(-5.880229e+01)*S217+5.040317e+01*S218+0.000000e+00*S219'
.param V41_part23='V41_part22+1.288127e+01*S220+(-1.012068e+02)*S221+4.949296e+01*S222+3.375720e+01*S223+(-2.083462e+01)*S224+4.713142e+01*S225+0.000000e+00*S226+0.000000e+00*S227+4.490001e-01*S228+(-1.650297e+01)*S229'
.param V41_part24='V41_part23+(-6.155979e+01)*S230+6.193858e+01*S231+7.165293e+01*S232+0.000000e+00*S233+3.843496e+01*S234+7.014649e+01*S235+0.000000e+00*S236+4.556082e+01*S237+(-2.717661e+01)*S238+0.000000e+00*S239'
.param V41_part25='V41_part24+6.272166e-01*S240+(-1.055748e+02)*S241+0.000000e+00*S242+0.000000e+00*S243+(-2.540212e+01)*S244+4.130980e+01*S245+(-3.286270e+01)*S246+(-9.743268e+00)*S247+0.000000e+00*S248+6.793716e+01*S249'
.param V41_part26='V41_part25+6.884511e+01*S250+0.000000e+00*S251+6.609478e+01*S252+6.109188e+01*S253+0.000000e+00*S254+0.000000e+00*S255+2.325770e+01*S256+(-9.962505e+00)*S257+3.408662e+01*S258+1.251789e+01*S259'
.param V41_part27='V41_part26+6.969265e+00*S260+5.802600e+01*S261+0.000000e+00*S262+(-6.321975e+01)*S263+3.440649e+01*S264+0.000000e+00*S265+4.034459e+01*S266+0.000000e+00*S267+3.620294e+01*S268+0.000000e+00*S269'
.param V41_part28='V41_part27+3.877070e+01*S270+8.692938e+01*S271+0.000000e+00*S272+0.000000e+00*S273+(-3.440778e+01)*S274+0.000000e+00*S275+3.684295e+01*S276+3.372927e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V41_part29='V41_part28+7.695966e+01*S280+0.000000e+00*S281+8.617200e+01*S282+(-6.511422e+01)*S283+(-4.769262e+01)*S284+6.864032e+01*S285+(-4.403536e+01)*S286+0.000000e+00*S287+1.117275e+01*S288+1.634433e+01*S289'
.param V41_part30='V41_part29+0.000000e+00*S290+5.882477e+01*S291+0.000000e+00*S292+(-3.830390e+01)*S293+6.583246e+01*S294+0.000000e+00*S295+(-2.989989e+01)*S296+6.862468e+01*S297+5.074137e+01*S298+(-5.767496e+01)*S299'
.param V41_part31='V41_part30+6.720117e+01*S300+2.232185e+01*S301+2.428385e+01*S302+3.369542e+01*S303+6.973484e+01*S304+1.999058e+01*S305+0.000000e+00*S306+0.000000e+00*S307+1.740697e+00*S308+0.000000e+00*S309'
.param V41='V41_part31+0.000000e+00*S310+3.318131e+00*S311+0.000000e+00*S312+0.000000e+00*S313+2.115390e+01*S314'
.param V42_part1='1.146505e+01*S0+0.000000e+00*S1+3.199026e+00*S2+1.201544e+01*S3+(-5.435574e+00)*S4+0.000000e+00*S5+5.505309e-01*S6+(-1.103464e+01)*S7+(-1.194563e+01)*S8+0.000000e+00*S9'
.param V42_part2='V42_part1+0.000000e+00*S10+(-8.874793e-02)*S11+1.185639e+01*S12+0.000000e+00*S13+8.094756e-01*S14+0.000000e+00*S15+(-7.142163e+00)*S16+(-3.051108e+00)*S17+(-2.189327e+01)*S18+0.000000e+00*S19'
.param V42_part3='V42_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+(-4.500291e+00)*S23+(-1.357161e+01)*S24+0.000000e+00*S25+9.514087e-01*S26+(-5.200567e+00)*S27+(-2.291891e+00)*S28+(-6.492501e-01)*S29'
.param V42_part4='V42_part3+0.000000e+00*S30+0.000000e+00*S31+1.735634e+00*S32+0.000000e+00*S33+0.000000e+00*S34+5.171845e+00*S35+0.000000e+00*S36+1.281361e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V42_part5='V42_part4+4.963395e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+6.491368e+00*S47+0.000000e+00*S48+2.290984e+01*S49'
.param V42_part6='V42_part5+7.830773e+00*S50+0.000000e+00*S51+2.080832e+01*S52+2.083400e+01*S53+0.000000e+00*S54+2.345254e+01*S55+2.382945e+01*S56+0.000000e+00*S57+1.226074e+01*S58+2.729430e+01*S59'
.param V42_part7='V42_part6+0.000000e+00*S60+5.789518e+00*S61+0.000000e+00*S62+2.548782e+01*S63+1.923341e+01*S64+1.444063e+01*S65+2.512825e+01*S66+0.000000e+00*S67+0.000000e+00*S68+(-3.579203e+01)*S69'
.param V42_part8='V42_part7+0.000000e+00*S70+0.000000e+00*S71+1.363559e+01*S72+0.000000e+00*S73+0.000000e+00*S74+8.914628e+00*S75+(-1.031088e+00)*S76+4.522468e+00*S77+8.097344e+00*S78+1.881870e+01*S79'
.param V42_part9='V42_part8+3.431937e+00*S80+(-5.704635e+00)*S81+5.852802e-01*S82+1.340312e+00*S83+(-3.934369e+00)*S84+5.634214e+00*S85+9.085472e-01*S86+(-7.066594e+00)*S87+(-1.037848e-01)*S88+1.837436e+00*S89'
.param V42_part10='V42_part9+0.000000e+00*S90+7.874137e+00*S91+2.251818e+01*S92+1.888425e+01*S93+1.974103e+01*S94+2.592862e+01*S95+2.554909e+01*S96+2.704210e+01*S97+0.000000e+00*S98+2.584452e+01*S99'
.param V42_part11='V42_part10+2.137923e+01*S100+0.000000e+00*S101+0.000000e+00*S102+1.611791e+01*S103+4.254875e+01*S104+4.040419e+01*S105+5.120469e+01*S106+3.933423e+01*S107+4.417182e+01*S108+4.132507e+01*S109'
.param V42_part12='V42_part11+0.000000e+00*S110+2.160631e+01*S111+3.793140e+01*S112+0.000000e+00*S113+0.000000e+00*S114+3.923571e+01*S115+2.797098e+01*S116+2.852032e+01*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V42_part13='V42_part12+6.714205e+01*S120+0.000000e+00*S121+2.135360e+01*S122+5.783180e+01*S123+4.097492e+01*S124+3.284736e+01*S125+6.743624e+01*S126+4.114815e+01*S127+3.357784e+01*S128+7.954055e+01*S129'
.param V42_part14='V42_part13+6.499173e+01*S130+5.166741e+01*S131+(-1.304646e+00)*S132+3.436593e+01*S133+5.795294e+01*S134+3.082445e+01*S135+6.212121e+01*S136+2.623271e+01*S137+5.471414e+01*S138+1.510186e+01*S139'
.param V42_part15='V42_part14+(-7.018691e+00)*S140+4.037757e+01*S141+3.417530e+01*S142+2.365004e+01*S143+5.116194e+01*S144+4.041564e+01*S145+1.671898e+01*S146+2.046984e+01*S147+5.253380e+01*S148+4.472850e+01*S149'
.param V42_part16='V42_part15+0.000000e+00*S150+0.000000e+00*S151+4.026583e+01*S152+4.090156e+01*S153+0.000000e+00*S154+4.667771e+01*S155+0.000000e+00*S156+0.000000e+00*S157+3.430149e+01*S158+0.000000e+00*S159'
.param V42_part17='V42_part16+2.062175e+01*S160+3.963525e+01*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+2.361619e+01*S165+0.000000e+00*S166+0.000000e+00*S167+5.961829e+01*S168+0.000000e+00*S169'
.param V42_part18='V42_part17+0.000000e+00*S170+1.424457e+01*S171+0.000000e+00*S172+0.000000e+00*S173+2.235518e+01*S174+(-2.631596e+01)*S175+0.000000e+00*S176+7.149156e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V42_part19='V42_part18+5.377403e+01*S180+(-8.509058e+00)*S181+5.834052e+01*S182+5.581053e+01*S183+5.316506e+01*S184+2.560061e+01*S185+8.528520e+01*S186+7.831950e+01*S187+(-5.745492e+01)*S188+2.207239e+00*S189'
.param V42_part20='V42_part19+6.334667e+01*S190+2.840294e+01*S191+(-3.253465e+00)*S192+0.000000e+00*S193+0.000000e+00*S194+4.523448e+01*S195+4.577490e+01*S196+0.000000e+00*S197+3.965635e+01*S198+3.256212e+01*S199'
.param V42_part21='V42_part20+2.886664e+01*S200+6.614983e+01*S201+4.443739e+01*S202+4.072927e+01*S203+0.000000e+00*S204+7.291981e+01*S205+4.198499e+01*S206+1.663580e+01*S207+8.711059e+01*S208+6.865376e+01*S209'
.param V42_part22='V42_part21+5.015979e+01*S210+(-2.775473e+01)*S211+6.354845e+01*S212+0.000000e+00*S213+1.744352e+01*S214+8.934829e+01*S215+0.000000e+00*S216+2.983921e+01*S217+1.303767e+02*S218+0.000000e+00*S219'
.param V42_part23='V42_part22+1.531084e+01*S220+(-7.329879e+00)*S221+8.646235e+01*S222+(-7.905219e+00)*S223+(-5.570310e+01)*S224+6.607643e+01*S225+0.000000e+00*S226+0.000000e+00*S227+2.618696e+01*S228+(-1.311495e+01)*S229'
.param V42_part24='V42_part23+3.399573e+01*S230+(-5.929476e+01)*S231+9.822181e+01*S232+0.000000e+00*S233+1.127009e+01*S234+1.000374e+02*S235+0.000000e+00*S236+(-1.581411e+01)*S237+6.194716e+00*S238+0.000000e+00*S239'
.param V42_part25='V42_part24+5.385444e+01*S240+(-2.495639e+01)*S241+0.000000e+00*S242+0.000000e+00*S243+5.551558e+01*S244+4.290989e+01*S245+(-2.079638e+01)*S246+3.244518e+01*S247+0.000000e+00*S248+1.272871e+02*S249'
.param V42_part26='V42_part25+6.149463e+01*S250+0.000000e+00*S251+1.326644e+02*S252+8.817180e+01*S253+0.000000e+00*S254+0.000000e+00*S255+2.528589e+01*S256+3.079803e+01*S257+8.258863e+01*S258+5.151237e+01*S259'
.param V42_part27='V42_part26+4.395338e+01*S260+3.939958e+01*S261+0.000000e+00*S262+(-3.515583e+01)*S263+(-2.155697e+01)*S264+0.000000e+00*S265+(-7.626111e+01)*S266+0.000000e+00*S267+7.953097e+01*S268+0.000000e+00*S269'
.param V42_part28='V42_part27+6.445297e+01*S270+8.601027e+01*S271+0.000000e+00*S272+0.000000e+00*S273+6.938497e+01*S274+0.000000e+00*S275+2.586276e+01*S276+5.855758e+01*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V42_part29='V42_part28+9.629160e+01*S280+0.000000e+00*S281+(-2.254253e+01)*S282+3.471012e+01*S283+(-5.332724e+01)*S284+8.951253e+01*S285+7.775505e+00*S286+0.000000e+00*S287+4.519814e+01*S288+5.891717e+01*S289'
.param V42_part30='V42_part29+0.000000e+00*S290+1.474297e+02*S291+0.000000e+00*S292+2.544609e+01*S293+1.273116e+02*S294+0.000000e+00*S295+5.133178e+00*S296+1.463396e+02*S297+1.711339e+01*S298+1.282678e+00*S299'
.param V42_part31='V42_part30+9.739601e+01*S300+5.751820e+01*S301+7.267126e+01*S302+7.772365e+00*S303+5.752739e+01*S304+8.585329e+01*S305+0.000000e+00*S306+0.000000e+00*S307+(-9.015595e+01)*S308+0.000000e+00*S309'
.param V42='V42_part31+0.000000e+00*S310+(-9.292879e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+(-9.417191e+01)*S314'
.param V43_part1='(-5.021761e+00)*S0+0.000000e+00*S1+(-3.431619e+00)*S2+(-1.594228e+01)*S3+(-7.726221e+00)*S4+0.000000e+00*S5+2.660720e+00*S6+(-1.618376e+00)*S7+(-2.526694e+00)*S8+0.000000e+00*S9'
.param V43_part2='V43_part1+0.000000e+00*S10+(-3.431139e+00)*S11+6.063002e-01*S12+0.000000e+00*S13+(-8.145603e+00)*S14+0.000000e+00*S15+(-5.918643e+00)*S16+(-6.738716e-01)*S17+(-1.040372e+01)*S18+0.000000e+00*S19'
.param V43_part3='V43_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+1.322373e+00*S23+1.593732e+00*S24+0.000000e+00*S25+(-7.973343e-01)*S26+1.326857e-01*S27+(-2.018205e-01)*S28+(-2.347272e-01)*S29'
.param V43_part4='V43_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.237678e+01)*S32+0.000000e+00*S33+0.000000e+00*S34+(-1.735098e+01)*S35+0.000000e+00*S36+(-2.328545e+01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V43_part5='V43_part4+(-2.326161e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-9.408095e+00)*S47+0.000000e+00*S48+(-1.760107e+01)*S49'
.param V43_part6='V43_part5+(-1.193164e+01)*S50+0.000000e+00*S51+(-2.127674e+01)*S52+(-3.693127e+01)*S53+0.000000e+00*S54+(-2.364466e+01)*S55+(-3.957912e+01)*S56+0.000000e+00*S57+(-2.978885e+01)*S58+(-4.155941e+01)*S59'
.param V43_part7='V43_part6+0.000000e+00*S60+(-1.024653e+00)*S61+0.000000e+00*S62+(-8.710244e+00)*S63+(-1.849324e+01)*S64+(-5.635657e+00)*S65+(-2.136770e+01)*S66+0.000000e+00*S67+0.000000e+00*S68+(-2.733085e+01)*S69'
.param V43_part8='V43_part7+0.000000e+00*S70+0.000000e+00*S71+4.052486e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.203576e+00)*S75+(-7.058049e-02)*S76+8.616855e+00*S77+(-7.055497e-02)*S78+(-1.451894e+00)*S79'
.param V43_part9='V43_part8+1.805970e-01*S80+(-6.351233e-01)*S81+3.117832e+00*S82+1.877079e-01*S83+(-1.510518e+00)*S84+3.701878e-01*S85+(-1.742783e+00)*S86+1.323204e+00*S87+(-1.218123e-01)*S88+5.630320e-01*S89'
.param V43_part10='V43_part9+0.000000e+00*S90+(-1.838521e+01)*S91+(-1.848112e+01)*S92+(-1.986737e+01)*S93+(-2.080622e+01)*S94+(-1.812311e+01)*S95+(-2.262488e+01)*S96+(-2.213038e+01)*S97+0.000000e+00*S98+(-2.545288e+01)*S99'
.param V43_part11='V43_part10+(-2.102498e+01)*S100+0.000000e+00*S101+0.000000e+00*S102+(-1.914582e+01)*S103+(-2.066083e+01)*S104+(-1.760836e+01)*S105+(-2.047619e+01)*S106+(-2.192186e+01)*S107+(-2.130000e+01)*S108+(-2.179605e+01)*S109'
.param V43_part12='V43_part11+0.000000e+00*S110+2.564081e+00*S111+(-2.387040e+01)*S112+0.000000e+00*S113+0.000000e+00*S114+(-3.092519e+01)*S115+(-3.037392e+01)*S116+(-3.638325e+01)*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V43_part13='V43_part12+(-1.917724e+01)*S120+0.000000e+00*S121+(-9.395144e-01)*S122+(-1.563688e+01)*S123+(-9.630418e+00)*S124+(-1.332735e+01)*S125+(-7.664848e+00)*S126+(-4.557245e+00)*S127+(-1.757005e+01)*S128+(-2.080668e+01)*S129'
.param V43_part14='V43_part13+(-1.224995e+01)*S130+1.198522e+00*S131+(-4.190770e+01)*S132+(-1.837635e+01)*S133+2.563604e-01*S134+(-2.666951e+00)*S135+(-8.284656e+00)*S136+(-6.888253e+00)*S137+(-1.238277e+01)*S138+(-7.235787e+00)*S139'
.param V43_part15='V43_part14+(-1.476481e+00)*S140+(-2.177054e+01)*S141+(-1.476548e+00)*S142+(-9.176077e+00)*S143+1.567594e+00*S144+2.169253e+00*S145+(-5.372932e+00)*S146+(-1.725708e+01)*S147+(-1.416369e+00)*S148+(-3.246890e+00)*S149'
.param V43_part16='V43_part15+0.000000e+00*S150+0.000000e+00*S151+(-2.184313e+01)*S152+(-1.463345e+01)*S153+0.000000e+00*S154+(-2.639224e+01)*S155+0.000000e+00*S156+0.000000e+00*S157+(-6.872007e+00)*S158+0.000000e+00*S159'
.param V43_part17='V43_part16+(-2.947653e+01)*S160+(-3.780576e+01)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+(-1.532953e+01)*S165+0.000000e+00*S166+0.000000e+00*S167+(-2.383440e+01)*S168+0.000000e+00*S169'
.param V43_part18='V43_part17+0.000000e+00*S170+(-3.731258e+01)*S171+0.000000e+00*S172+0.000000e+00*S173+(-3.629915e+01)*S174+(-1.744764e+01)*S175+0.000000e+00*S176+(-4.247793e+01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V43_part19='V43_part18+(-1.243964e+01)*S180+1.064223e+01*S181+(-2.558673e+01)*S182+(-2.290598e+01)*S183+(-1.726638e+01)*S184+7.776704e+00*S185+(-3.573491e+01)*S186+(-2.644892e+01)*S187+3.664892e+00*S188+(-3.525515e+01)*S189'
.param V43_part20='V43_part19+4.413456e-01*S190+(-4.543920e+01)*S191+(-4.563386e+01)*S192+0.000000e+00*S193+0.000000e+00*S194+(-1.169923e+01)*S195+(-4.567655e+00)*S196+0.000000e+00*S197+(-8.583756e+00)*S198+3.301302e+00*S199'
.param V43_part21='V43_part20+6.862647e+00*S200+(-7.092469e+00)*S201+9.648567e-01*S202+(-7.787645e+00)*S203+0.000000e+00*S204+(-1.594382e+01)*S205+2.725643e+00*S206+9.933773e-01*S207+(-8.114763e+00)*S208+1.100324e+00*S209'
.param V43_part22='V43_part21+(-2.193331e+01)*S210+3.889265e+00*S211+(-2.943904e+01)*S212+0.000000e+00*S213+(-3.230493e+01)*S214+(-3.624126e+01)*S215+0.000000e+00*S216+(-4.817984e+01)*S217+(-3.956467e+01)*S218+0.000000e+00*S219'
.param V43_part23='V43_part22+(-4.255769e+01)*S220+(-4.867639e+01)*S221+(-3.145317e+01)*S222+(-4.659954e+01)*S223+(-5.259769e+01)*S224+(-2.358639e+01)*S225+0.000000e+00*S226+0.000000e+00*S227+(-4.083755e+01)*S228+1.270283e+01*S229'
.param V43_part24='V43_part23+4.243373e-01*S230+(-5.121541e+01)*S231+(-1.214039e+01)*S232+0.000000e+00*S233+(-3.821663e+01)*S234+(-1.653464e+01)*S235+0.000000e+00*S236+(-3.916881e+01)*S237+(-3.085728e+01)*S238+0.000000e+00*S239'
.param V43_part25='V43_part24+(-1.598177e+01)*S240+(-1.628155e+00)*S241+0.000000e+00*S242+0.000000e+00*S243+(-2.942186e+01)*S244+8.648312e+00*S245+(-4.756039e+01)*S246+(-2.371249e+01)*S247+0.000000e+00*S248+(-4.812743e+01)*S249'
.param V43_part26='V43_part25+(-4.745683e+01)*S250+0.000000e+00*S251+(-3.726835e+01)*S252+(-3.936138e+01)*S253+0.000000e+00*S254+0.000000e+00*S255+(-8.436802e+00)*S256+4.332018e+00*S257+(-9.309879e+00)*S258+(-5.979118e-01)*S259'
.param V43_part27='V43_part26+1.951937e+01*S260+(-3.807122e+01)*S261+0.000000e+00*S262+1.810501e+00*S263+(-3.701613e+01)*S264+0.000000e+00*S265+1.310508e-01*S266+0.000000e+00*S267+(-1.333966e+01)*S268+0.000000e+00*S269'
.param V43_part28='V43_part27+(-2.887792e+01)*S270+(-2.387173e+01)*S271+0.000000e+00*S272+0.000000e+00*S273+(-2.879748e+01)*S274+0.000000e+00*S275+(-3.317025e+01)*S276+(-4.339383e+01)*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V43_part29='V43_part28+(-1.507753e+01)*S280+0.000000e+00*S281+(-3.185602e+01)*S282+(-2.175809e+01)*S283+(-6.884978e+01)*S284+(-2.688613e+01)*S285+(-3.939114e+01)*S286+0.000000e+00*S287+(-3.833109e+01)*S288+(-4.422783e+01)*S289'
.param V43_part30='V43_part29+0.000000e+00*S290+(-4.189006e+01)*S291+0.000000e+00*S292+(-6.736323e+01)*S293+(-2.777142e+01)*S294+0.000000e+00*S295+(-7.097609e+01)*S296+(-3.552706e+01)*S297+(-5.214365e+01)*S298+(-8.125659e+01)*S299'
.param V43_part31='V43_part30+(-2.613744e+01)*S300+(-6.291005e+00)*S301+(-2.651626e+01)*S302+(-2.888834e+01)*S303+(-2.900705e+01)*S304+(-2.969101e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+(-5.837455e+00)*S308+0.000000e+00*S309'
.param V43='V43_part31+0.000000e+00*S310+(-1.190694e+00)*S311+0.000000e+00*S312+0.000000e+00*S313+(-4.507658e-01)*S314'
.param V44_part1='7.681001e-02*S0+0.000000e+00*S1+1.027838e-01*S2+(-9.941095e-02)*S3+1.399213e-01*S4+0.000000e+00*S5+1.306784e+00*S6+(-1.540652e-01)*S7+2.996460e-01*S8+0.000000e+00*S9'
.param V44_part2='V44_part1+0.000000e+00*S10+1.145426e-02*S11+2.483987e-02*S12+0.000000e+00*S13+9.375860e-02*S14+0.000000e+00*S15+9.492090e-02*S16+(-1.367781e-01)*S17+5.396205e-02*S18+0.000000e+00*S19'
.param V44_part3='V44_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+(-2.158585e-01)*S23+3.418753e-01*S24+0.000000e+00*S25+1.367645e-01*S26+5.858971e-04*S27+(-4.411268e-02)*S28+(-1.221478e-02)*S29'
.param V44_part4='V44_part3+0.000000e+00*S30+0.000000e+00*S31+1.900814e-01*S32+0.000000e+00*S33+0.000000e+00*S34+3.326689e-01*S35+0.000000e+00*S36+2.348508e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V44_part5='V44_part4+9.804427e-01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-2.825667e-01)*S47+0.000000e+00*S48+(-2.131172e-01)*S49'
.param V44_part6='V44_part5+(-9.902611e-01)*S50+0.000000e+00*S51+(-2.791811e+00)*S52+1.076526e+00*S53+0.000000e+00*S54+(-2.691525e+00)*S55+1.095673e+00*S56+0.000000e+00*S57+(-5.697863e-01)*S58+8.764276e-01*S59'
.param V44_part7='V44_part6+0.000000e+00*S60+(-2.833972e-01)*S61+0.000000e+00*S62+(-5.069157e+00)*S63+(-4.018219e+00)*S64+(-6.233890e-01)*S65+(-3.789911e+00)*S66+0.000000e+00*S67+0.000000e+00*S68+(-1.334659e+01)*S69'
.param V44_part8='V44_part7+0.000000e+00*S70+0.000000e+00*S71+(-1.472121e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-2.670706e-01)*S75+(-1.386969e+00)*S76+(-1.387352e-02)*S77+(-7.232210e-01)*S78+3.287646e-01*S79'
.param V44_part9='V44_part8+(-2.173848e+00)*S80+(-1.817368e+00)*S81+(-3.021435e+00)*S82+(-3.847461e+00)*S83+(-3.504719e+00)*S84+(-3.009880e+00)*S85+(-5.556158e+00)*S86+(-4.903955e+00)*S87+(-5.482650e+00)*S88+(-4.249024e+00)*S89'
.param V44_part10='V44_part9+0.000000e+00*S90+1.404648e+00*S91+1.846378e+00*S92+1.317281e+00*S93+8.926937e-01*S94+1.891113e-01*S95+6.354618e-01*S96+(-2.996551e-01)*S97+0.000000e+00*S98+1.090508e-01*S99'
.param V44_part11='V44_part10+7.225693e-02*S100+0.000000e+00*S101+0.000000e+00*S102+(-2.347513e+00)*S103+8.028841e-01*S104+(-2.696703e+00)*S105+(-4.570359e-01)*S106+7.793182e-01*S107+(-6.021103e-01)*S108+1.228125e+00*S109'
.param V44_part12='V44_part11+0.000000e+00*S110+(-5.231844e+00)*S111+1.931449e+00*S112+0.000000e+00*S113+0.000000e+00*S114+(-3.640251e-01)*S115+1.168511e+00*S116+(-9.457853e+00)*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V44_part13='V44_part12+4.032751e+00*S120+0.000000e+00*S121+1.635667e-01*S122+(-5.176137e+00)*S123+9.705333e-01*S124+5.805366e-01*S125+5.267997e-01*S126+1.187723e-01*S127+(-3.254931e+00)*S128+1.330613e+00*S129'
.param V44_part14='V44_part13+7.438155e-01*S130+(-2.765093e+00)*S131+(-1.157282e+01)*S132+(-3.502264e-01)*S133+(-7.125990e-01)*S134+(-2.622907e+00)*S135+7.248147e-02*S136+2.276862e-01*S137+2.171890e+00*S138+(-1.586167e-02)*S139'
.param V44_part15='V44_part14+3.598966e-01*S140+3.696132e+00*S141+2.119705e+00*S142+1.015499e-01*S143+4.878135e-01*S144+1.835852e+00*S145+(-2.241425e-02)*S146+8.118551e-01*S147+1.621799e+00*S148+(-9.144923e-02)*S149'
.param V44_part16='V44_part15+0.000000e+00*S150+0.000000e+00*S151+1.124206e+00*S152+1.477489e+00*S153+0.000000e+00*S154+(-1.339478e+00)*S155+0.000000e+00*S156+0.000000e+00*S157+(-5.423533e+00)*S158+0.000000e+00*S159'
.param V44_part17='V44_part16+1.406078e-01*S160+(-2.462954e+01)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+1.871337e+00*S165+0.000000e+00*S166+0.000000e+00*S167+(-2.823919e+00)*S168+0.000000e+00*S169'
.param V44_part18='V44_part17+0.000000e+00*S170+(-7.478716e+00)*S171+0.000000e+00*S172+0.000000e+00*S173+(-2.698846e+00)*S174+(-2.856881e+00)*S175+0.000000e+00*S176+9.922844e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V44_part19='V44_part18+2.265915e+00*S180+(-1.353105e+00)*S181+4.937924e+00*S182+(-4.521992e+00)*S183+2.355127e+00*S184+(-1.080811e+01)*S185+8.715647e+00*S186+2.928152e+00*S187+(-1.717790e+01)*S188+9.319138e+00*S189'
.param V44_part20='V44_part19+2.055822e+00*S190+2.572074e+00*S191+(-9.841934e+00)*S192+0.000000e+00*S193+0.000000e+00*S194+(-4.661135e-01)*S195+4.301086e-01*S196+0.000000e+00*S197+1.771095e-01*S198+(-1.023127e+00)*S199'
.param V44_part21='V44_part20+(-1.585112e+00)*S200+(-9.931983e-01)*S201+5.103091e-01*S202+(-8.262424e-01)*S203+0.000000e+00*S204+3.109294e+00*S205+(-3.967401e+00)*S206+(-1.102767e+00)*S207+3.426251e+00*S208+(-1.557185e+00)*S209'
.param V44_part22='V44_part21+2.661944e+00*S210+(-6.329219e+00)*S211+3.329628e-01*S212+0.000000e+00*S213+9.921771e-01*S214+(-1.848594e+00)*S215+0.000000e+00*S216+(-1.775409e+01)*S217+1.185904e+00*S218+0.000000e+00*S219'
.param V44_part23='V44_part22+1.664175e+00*S220+(-1.829675e+01)*S221+1.236664e+01*S222+9.526895e+00*S223+7.442095e+00*S224+4.644909e-02*S225+0.000000e+00*S226+0.000000e+00*S227+(-6.272352e+00)*S228+(-8.010420e+00)*S229'
.param V44_part24='V44_part23+(-1.747326e+01)*S230+4.693698e+00*S231+1.884469e+01*S232+0.000000e+00*S233+(-6.038717e+00)*S234+2.058260e+01*S235+0.000000e+00*S236+(-1.259787e+01)*S237+(-2.948516e+01)*S238+0.000000e+00*S239'
.param V44_part25='V44_part24+(-1.066713e+00)*S240+(-9.305173e+00)*S241+0.000000e+00*S242+0.000000e+00*S243+2.782532e+00*S244+9.838410e+00*S245+1.423618e+00*S246+(-9.703090e+00)*S247+0.000000e+00*S248+4.157379e+00*S249'
.param V44_part26='V44_part25+1.392755e+01*S250+0.000000e+00*S251+1.015922e+01*S252+2.448594e+01*S253+0.000000e+00*S254+0.000000e+00*S255+1.968760e+00*S256+(-1.673421e+00)*S257+4.167227e+00*S258+9.295551e-01*S259'
.param V44_part27='V44_part26+(-2.560297e+00)*S260+6.237756e+00*S261+0.000000e+00*S262+(-4.745894e+00)*S263+(-1.412011e+01)*S264+0.000000e+00*S265+(-1.099367e+01)*S266+0.000000e+00*S267+8.791524e+00*S268+0.000000e+00*S269'
.param V44_part28='V44_part27+7.501448e-01*S270+8.260502e+00*S271+0.000000e+00*S272+0.000000e+00*S273+(-1.764982e+01)*S274+0.000000e+00*S275+(-5.328022e+00)*S276+9.058599e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V44_part29='V44_part28+2.118171e+01*S280+0.000000e+00*S281+(-1.031963e+01)*S282+(-3.551810e+01)*S283+2.294596e+01*S284+5.996703e+00*S285+1.230114e+00*S286+0.000000e+00*S287+8.793229e+00*S288+(-4.102615e+00)*S289'
.param V44_part30='V44_part29+0.000000e+00*S290+7.945886e+00*S291+0.000000e+00*S292+1.502119e+01*S293+1.763910e+01*S294+0.000000e+00*S295+2.101222e+01*S296+1.242204e+01*S297+(-2.875919e+00)*S298+2.249164e+01*S299'
.param V44_part31='V44_part30+4.360410e+00*S300+4.106442e+00*S301+(-1.995172e+00)*S302+(-9.167420e+00)*S303+(-3.355557e+00)*S304+(-3.732859e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+(-3.245284e+01)*S308+0.000000e+00*S309'
.param V44='V44_part31+0.000000e+00*S310+(-3.124320e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+(-3.780020e+01)*S314'
.param V45_part1='(-8.902446e-03)*S0+1.635902e-02*S1+2.180406e-01*S2+(-1.769772e-01)*S3+(-4.343019e-03)*S4+(-1.376844e+00)*S5+4.246227e-01*S6+2.103447e-01*S7+(-9.241779e-02)*S8+5.962042e-01*S9'
.param V45_part2='V45_part1+(-6.188680e-01)*S10+(-1.733175e-01)*S11+(-1.122852e+00)*S12+(-5.114260e-01)*S13+1.256769e+00*S14+1.643119e-03*S15+1.335103e-01*S16+(-5.689143e-01)*S17+2.796990e-01*S18+(-9.893871e-02)*S19'
.param V45_part3='V45_part2+(-3.681620e-01)*S20+6.371084e-02*S21+(-3.206481e-01)*S22+(-1.901960e+00)*S23+2.153349e-02*S24+(-5.576985e-02)*S25+(-2.729377e+00)*S26+(-1.502758e+00)*S27+(-9.023959e-01)*S28+(-2.949641e+00)*S29'
.param V45_part4='V45_part3+(-8.854254e-01)*S30+(-1.072439e+00)*S31+(-1.181790e-01)*S32+(-1.396528e+00)*S33+(-1.896284e+00)*S34+(-1.093328e+00)*S35+(-1.526357e+00)*S36+(-1.308265e+00)*S37+(-5.282372e+00)*S38+(-1.506215e+00)*S39'
.param V45_part5='V45_part4+(-9.845506e-01)*S40+(-5.360120e+00)*S41+(-1.616998e+00)*S42+(-3.317718e+00)*S43+(-5.433729e+00)*S44+(-1.312336e-01)*S45+(-1.657669e+00)*S46+2.521130e+00*S47+(-9.010754e-01)*S48+(-1.865873e+00)*S49'
.param V45_part6='V45_part5+2.903941e+00*S50+(-1.476360e+00)*S51+(-3.300645e+00)*S52+(-3.500173e+00)*S53+(-7.602132e-01)*S54+(-2.852318e+00)*S55+(-3.219869e+00)*S56+(-6.712826e-01)*S57+(-1.373896e+00)*S58+(-3.623763e+00)*S59'
.param V45_part7='V45_part6+(-5.673025e-02)*S60+(-5.221472e-01)*S61+(-5.640692e+00)*S62+(-2.897541e-01)*S63+(-1.574373e+00)*S64+(-6.822276e+00)*S65+(-7.311391e-01)*S66+(-3.260427e+00)*S67+(-8.213760e+00)*S68+(-4.972392e-01)*S69'
.param V45_part8='V45_part7+(-5.249873e+00)*S70+(-9.932196e+00)*S71+(-3.644275e-01)*S72+(-4.322275e+00)*S73+(-7.864691e+00)*S74+(-5.016573e-01)*S75+(-5.013081e-01)*S76+(-2.270083e+00)*S77+4.143802e-01*S78+(-2.381310e-01)*S79'
.param V45_part9='V45_part8+(-2.120155e+00)*S80+(-1.091452e+00)*S81+(-8.408356e-01)*S82+(-2.204530e+00)*S83+(-8.368241e-01)*S84+(-1.563928e+00)*S85+(-2.909264e+00)*S86+(-1.292539e+00)*S87+(-1.367533e+00)*S88+(-8.465304e+00)*S89'
.param V45_part10='V45_part9+(-1.220650e+00)*S90+(-3.910018e+00)*S91+(-6.694595e+00)*S92+(-2.085057e+00)*S93+(-3.730914e+00)*S94+(-7.992122e+00)*S95+(-2.559172e+00)*S96+(-4.784218e+00)*S97+(-1.028961e+01)*S98+(-2.028628e+00)*S99'
.param V45_part11='V45_part10+(-1.673411e+00)*S100+(-1.242019e+01)*S101+(-9.254303e-01)*S102+(-2.374432e+00)*S103+(-4.520729e+00)*S104+(-1.273633e+00)*S105+(-4.678889e+00)*S106+(-9.561063e+00)*S107+(-1.302092e+00)*S108+(-3.599222e+00)*S109'
.param V45_part12='V45_part11+(-1.050353e+01)*S110+(-1.944058e+00)*S111+(-4.801518e+00)*S112+(-1.196583e+01)*S113+(-1.440087e+00)*S114+3.161613e-01*S115+(-2.357290e+00)*S116+(-7.432838e-01)*S117+(-8.515386e-01)*S118+(-1.026532e+01)*S119'
.param V45_part13='V45_part12+(-4.272155e-01)*S120+(-4.431407e+00)*S121+(-1.224556e+01)*S122+(-1.278061e+00)*S123+(-5.184468e+00)*S124+(-6.806426e+00)*S125+(-1.691331e+00)*S126+(-2.730953e+00)*S127+(-3.875003e+00)*S128+(-4.719522e-01)*S129'
.param V45_part14='V45_part13+(-2.482478e+00)*S130+(-1.515187e+01)*S131+(-7.448978e-01)*S132+(-1.149331e+00)*S133+(-1.430891e+01)*S134+5.033319e-01*S135+(-1.101284e+00)*S136+(-8.081765e+00)*S137+3.271312e-01*S138+(-2.033807e+00)*S139'
.param V45_part15='V45_part14+(-8.215323e+00)*S140+(-8.906241e-01)*S141+(-5.709302e+00)*S142+(-6.446400e+00)*S143+(-2.148923e+00)*S144+(-5.024547e+00)*S145+(-6.959109e+00)*S146+(-3.563464e+00)*S147+(-5.539103e+00)*S148+(-8.134004e+00)*S149'
.param V45_part16='V45_part15+(-1.533344e+00)*S150+(-7.736875e+00)*S151+(-9.222533e+00)*S152+(-2.272092e+00)*S153+(-5.188310e+00)*S154+(-1.071784e+01)*S155+(-1.750231e+00)*S156+(-7.822291e+00)*S157+(-1.792287e+01)*S158+(-2.666885e+00)*S159'
.param V45_part17='V45_part16+(-5.626590e+00)*S160+(-1.313501e+01)*S161+(-1.009101e+00)*S162+(-7.817965e+00)*S163+(-1.418713e+01)*S164+(-8.881330e-01)*S165+(-6.007641e+00)*S166+(-1.535954e+01)*S167+(-1.065565e+00)*S168+(-6.006403e+00)*S169'
.param V45_part18='V45_part17+(-1.754825e+01)*S170+(-1.321104e+00)*S171+(-1.559160e+00)*S172+(-4.624093e+00)*S173+(-1.656451e+00)*S174+(-2.833243e+00)*S175+(-1.683271e+01)*S176+(-1.275692e+00)*S177+(-5.596858e+00)*S178+(-1.404435e+01)*S179'
.param V45_part19='V45_part18+(-1.301360e+00)*S180+(-7.485895e+00)*S181+(-1.187110e+01)*S182+(-1.111542e+00)*S183+(-1.783049e+00)*S184+(-1.207236e+01)*S185+(-7.286483e-01)*S186+(-3.356643e+00)*S187+(-1.247526e+01)*S188+(-1.384792e+00)*S189'
.param V45_part20='V45_part19+(-4.618413e+00)*S190+(-1.075586e+01)*S191+(-1.672120e+00)*S192+(-6.674008e+00)*S193+(-7.108638e+00)*S194+(-4.869992e-01)*S195+(-3.242392e+00)*S196+(-1.316477e+01)*S197+(-2.847740e-01)*S198+(-4.645684e+00)*S199'
.param V45_part21='V45_part20+(-1.119866e+01)*S200+(-1.946510e+00)*S201+(-3.141792e+00)*S202+(-7.417643e+00)*S203+(-3.849455e-01)*S204+(-3.722495e+00)*S205+(-8.101587e+00)*S206+1.457249e-02*S207+(-5.846429e+00)*S208+(-8.703047e+00)*S209'
.param V45_part22='V45_part21+(-1.091999e+00)*S210+(-7.547036e+00)*S211+(-1.335503e+01)*S212+(-7.338952e-01)*S213+(-2.783294e-01)*S214+(-1.634723e+01)*S215+(-1.699716e+00)*S216+(-7.604141e+00)*S217+(-1.382854e+01)*S218+(-1.689022e+00)*S219'
.param V45_part23='V45_part22+(-7.250874e+00)*S220+(-2.246853e+01)*S221+(-2.138833e+00)*S222+(-6.779149e+00)*S223+(-1.349324e+01)*S224+(-1.280116e+00)*S225+(-7.304377e+00)*S226+(-1.951910e+01)*S227+(-1.719320e+00)*S228+(-7.018144e+00)*S229'
.param V45_part24='V45_part23+(-1.732445e+01)*S230+(-1.789550e+00)*S231+(-7.159643e+00)*S232+(-1.414962e+01)*S233+(-1.726700e+00)*S234+(-7.370885e+00)*S235+(-1.452322e+01)*S236+(-1.686153e+00)*S237+(-7.806863e+00)*S238+(-1.323987e+01)*S239'
.param V45_part25='V45_part24+(-1.231727e+00)*S240+(-6.307489e+00)*S241+(-1.500874e+01)*S242+(-9.868155e-01)*S243+(-5.630871e+00)*S244+(-1.553333e+01)*S245+(-2.053637e+00)*S246+(-5.739894e+00)*S247+(-1.422243e+01)*S248+(-2.018340e+00)*S249'
.param V45_part26='V45_part25+(-7.250992e+00)*S250+(-1.435535e+01)*S251+(-1.185406e+00)*S252+(-9.859625e+00)*S253+(-6.798462e+00)*S254+(-1.332503e+00)*S255+(-6.191597e+00)*S256+(-1.650739e+01)*S257+(-5.454832e-01)*S258+(-6.362498e+00)*S259'
.param V45_part27='V45_part26+(-1.798407e+01)*S260+(-8.830090e-01)*S261+(-2.825871e+00)*S262+(-8.260038e+00)*S263+(-1.176274e+00)*S264+(-3.368922e+00)*S265+(-1.007568e+01)*S266+(-1.135065e+00)*S267+(-6.802115e+00)*S268+(-8.433734e+00)*S269'
.param V45_part28='V45_part27+(-7.024190e-01)*S270+(-5.894468e+00)*S271+(-2.818059e+01)*S272+(-1.869246e+00)*S273+(-9.676969e+00)*S274+(-2.439720e+01)*S275+(-2.039081e+00)*S276+(-7.912819e+00)*S277+(-1.846865e+01)*S278+(-1.982963e+00)*S279'
.param V45_part29='V45_part28+(-9.948402e+00)*S280+(-2.168384e+01)*S281+(-2.710117e+00)*S282+(-1.061339e+01)*S283+(-1.720571e+01)*S284+(-1.336154e+00)*S285+(-7.232870e+00)*S286+(-1.403325e+01)*S287+(-2.058428e+00)*S288+(-6.972016e+00)*S289'
.param V45_part30='V45_part29+(-1.696726e+01)*S290+(-2.045527e+00)*S291+(-8.505792e+00)*S292+(-1.857219e+01)*S293+(-1.956660e+00)*S294+(-9.276425e+00)*S295+(-2.066188e+01)*S296+(-2.529558e+00)*S297+(-1.089077e+01)*S298+(-1.568416e+01)*S299'
.param V45_part31='V45_part30+7.919454e-02*S300+(-8.073707e+00)*S301+(-7.741876e+00)*S302+(-1.234771e+00)*S303+(-4.313564e+00)*S304+(-9.773583e+00)*S305+(-1.567173e+00)*S306+(-6.048919e+00)*S307+(-1.116636e+01)*S308+(-1.448863e+00)*S309'
.param V45='V45_part31+(-6.697469e+00)*S310+(-1.257590e+01)*S311+(-1.526603e+00)*S312+(-8.351067e+00)*S313+(-9.721858e+00)*S314'
.param V46_part1='1.885764e+00*S0+1.914460e+00*S1+1.485562e+00*S2+2.364353e+00*S3+2.128812e+00*S4+2.366316e+00*S5+5.587860e-01*S6+1.385087e+00*S7+1.457689e+00*S8+(-2.004330e-01)*S9'
.param V46_part2='V46_part1+1.330731e+00*S10+2.022180e+00*S11+1.395350e+00*S12+1.023430e+00*S13+7.024202e-03*S14+3.193295e+00*S15+2.635105e+00*S16+3.422076e+00*S17+2.707727e+00*S18+1.995574e+00*S19'
.param V46_part3='V46_part2+2.885354e+00*S20+1.636957e+00*S21+2.075376e+00*S22+3.717306e+00*S23+1.337444e+00*S24+1.500539e+00*S25+4.007077e+00*S26+2.846007e+00*S27+2.147165e+00*S28+3.523280e+00*S29'
.param V46_part4='V46_part3+5.175543e+00*S30+4.988151e+00*S31+3.434012e+00*S32+5.790236e+00*S33+6.078712e+00*S34+4.618854e+00*S35+5.821835e+00*S36+3.876862e+00*S37+8.323349e+00*S38+5.380569e+00*S39'
.param V46_part5='V46_part4+2.725445e+00*S40+7.072061e+00*S41+5.055376e+00*S42+6.112880e+00*S43+6.298663e+00*S44+6.561069e+00*S45+7.132105e+00*S46+(-1.937443e+00)*S47+5.564150e+00*S48+7.322727e+00*S49'
.param V46_part6='V46_part5+(-1.410043e+00)*S50+7.234402e+00*S51+7.803505e+00*S52+5.932138e+00*S53+4.319965e+00*S54+7.038273e+00*S55+5.113178e+00*S56+4.964515e+00*S57+3.145903e+00*S58+5.255862e+00*S59'
.param V46_part7='V46_part6+9.157096e+00*S60+8.839176e-01*S61+1.217363e+01*S62+6.624862e+00*S63+7.857264e+00*S64+9.076605e+00*S65+6.392884e+00*S66+8.864762e+00*S67+9.193417e+00*S68+4.716429e+00*S69'
.param V46_part8='V46_part7+5.592512e+00*S70+9.354150e+00*S71+4.454244e+00*S72+4.507003e+00*S73+9.497760e+00*S74+5.420830e+00*S75+3.423145e+00*S76+6.928724e+00*S77+2.062796e+00*S78+3.272253e+00*S79'
.param V46_part9='V46_part8+5.783032e+00*S80+5.125917e+00*S81+4.241637e+00*S82+5.981201e+00*S83+3.996411e+00*S84+4.382350e+00*S85+5.663070e+00*S86+3.991586e+00*S87+4.027106e+00*S88+9.877910e+00*S89'
.param V46_part10='V46_part9+1.031232e+01*S90+1.344759e+01*S91+1.096602e+01*S92+7.754631e+00*S93+1.167494e+01*S94+1.153517e+01*S95+7.291186e+00*S96+9.828490e+00*S97+1.217990e+01*S98+5.633725e+00*S99'
.param V46_part11='V46_part10+3.422243e+00*S100+1.342407e+01*S101+6.448624e+00*S102+4.295185e+00*S103+4.640288e+00*S104+9.429332e+00*S105+1.248370e+01*S106+1.181891e+01*S107+8.443618e+00*S108+9.797496e+00*S109'
.param V46_part12='V46_part11+1.449188e+01*S110+8.927453e+00*S111+8.425466e+00*S112+1.563847e+01*S113+7.330827e+00*S114+4.134170e+00*S115+3.853435e+00*S116+3.858306e+00*S117+3.280284e+00*S118+9.863414e+00*S119'
.param V46_part13='V46_part12+8.617354e+00*S120+1.362464e+01*S121+1.513989e+01*S122+9.206661e+00*S123+1.042456e+01*S124+1.109427e+01*S125+3.301247e+00*S126+3.797482e+00*S127+4.802530e+00*S128+8.378443e-01*S129'
.param V46_part14='V46_part13+2.859985e+00*S130+1.414392e+01*S131+5.268693e+00*S132+2.099184e+00*S133+1.181785e+01*S134+1.143950e+01*S135+4.898828e+00*S136+1.601392e+01*S137+6.949974e-01*S138+6.305567e+00*S139'
.param V46_part15='V46_part14+1.023787e+01*S140+2.798928e+00*S141+9.379754e+00*S142+9.315683e+00*S143+4.762403e+00*S144+7.630745e+00*S145+9.124873e+00*S146+4.994448e+00*S147+6.563072e+00*S148+7.857874e+00*S149'
.param V46_part16='V46_part15+1.087637e+01*S150+1.790692e+01*S151+1.693448e+01*S152+7.814640e+00*S153+8.386515e+00*S154+1.628148e+01*S155+6.279744e+00*S156+1.175743e+01*S157+1.841639e+01*S158+6.885326e+00*S159'
.param V46_part17='V46_part16+8.555098e+00*S160+1.188699e+01*S161+4.878131e+00*S162+8.604541e+00*S163+1.086498e+01*S164+5.894713e+00*S165+7.335531e+00*S166+2.290404e+01*S167+8.169762e+00*S168+1.161898e+01*S169'
.param V46_part18='V46_part17+2.050950e+01*S170+6.192133e+00*S171+1.504458e+00*S172+1.653514e+00*S173+6.316110e+00*S174+4.091699e+00*S175+1.344359e+01*S176+5.820719e+00*S177+6.864089e+00*S178+1.076004e+01*S179'
.param V46_part19='V46_part18+6.256675e+00*S180+7.620926e+00*S181+1.431289e+01*S182+7.774095e+00*S183+3.042992e+00*S184+1.124950e+01*S185+6.892068e+00*S186+3.112369e+00*S187+1.136228e+01*S188+6.221647e+00*S189'
.param V46_part20='V46_part19+7.357920e+00*S190+9.757414e+00*S191+6.688520e+00*S192+7.385574e+00*S193+8.539337e+00*S194+4.075299e+00*S195+1.283707e+01*S196+1.877140e+01*S197+3.769744e+00*S198+8.627318e+00*S199'
.param V46_part21='V46_part20+1.612798e+01*S200+2.491331e+00*S201+4.989345e+00*S202+6.282748e+00*S203+3.126223e+00*S204+5.535015e+00*S205+5.959621e+00*S206+5.901029e+00*S207+7.255234e+00*S208+6.474839e+00*S209'
.param V46_part22='V46_part21+4.219215e+00*S210+1.193301e+01*S211+1.628424e+01*S212+8.888154e-01*S213+2.930992e+00*S214+1.764375e+01*S215+6.461402e+00*S216+9.485564e+00*S217+1.713946e+01*S218+6.208029e+00*S219'
.param V46_part23='V46_part22+8.671189e+00*S220+1.600392e+01*S221+6.796948e+00*S222+6.018950e+00*S223+8.889528e+00*S224+6.195901e+00*S225+1.203206e+01*S226+2.193929e+01*S227+6.750750e+00*S228+1.031140e+01*S229'
.param V46_part24='V46_part23+1.452976e+01*S230+4.902490e+00*S231+9.087394e+00*S232+1.340994e+01*S233+6.654644e+00*S234+8.475374e+00*S235+1.209165e+01*S236+6.635231e+00*S237+8.187813e+00*S238+9.451790e+00*S239'
.param V46_part25='V46_part24+6.885923e+00*S240+1.027008e+01*S241+1.002674e+01*S242+5.764372e+00*S243+9.089649e+00*S244+1.169053e+01*S245+5.355388e+00*S246+7.899207e+00*S247+1.257982e+01*S248+7.204182e+00*S249'
.param V46_part26='V46_part25+8.447727e+00*S250+1.234427e+01*S251+5.907801e+00*S252+9.250510e+00*S253+5.353063e+00*S254+8.597200e+00*S255+1.279215e+01*S256+1.939850e+01*S257+9.479882e+00*S258+9.287931e+00*S259'
.param V46_part27='V46_part26+1.550966e+01*S260+6.777939e+00*S261+7.285377e+00*S262+4.851903e+00*S263+6.876810e+00*S264+7.330345e+00*S265+1.164236e+01*S266+6.714662e+00*S267+9.098276e+00*S268+1.009802e+01*S269'
.param V46_part28='V46_part27+4.251084e+00*S270+3.033971e+00*S271+2.836654e+01*S272+7.054344e+00*S273+1.105265e+01*S274+1.876478e+01*S275+7.134345e+00*S276+9.719746e+00*S277+1.466220e+01*S278+6.526381e+00*S279'
.param V46_part29='V46_part28+8.929816e+00*S280+1.669170e+01*S281+7.411696e+00*S282+8.677889e+00*S283+1.264888e+01*S284+8.454137e+00*S285+9.752727e+00*S286+1.124871e+01*S287+7.502059e+00*S288+8.777589e+00*S289'
.param V46_part30='V46_part29+1.486406e+01*S290+7.348745e+00*S291+9.702166e+00*S292+1.474164e+01*S293+6.784819e+00*S294+9.584779e+00*S295+1.598298e+01*S296+7.013940e+00*S297+9.944135e+00*S298+1.237060e+01*S299'
.param V46_part31='V46_part30+8.484163e+00*S300+4.814575e+00*S301+3.794564e+00*S302+7.375109e+00*S303+8.233413e+00*S304+7.363668e+00*S305+7.766777e+00*S306+8.030629e+00*S307+1.113471e+01*S308+7.207278e+00*S309'
.param V46='V46_part31+8.262107e+00*S310+1.241296e+01*S311+7.092270e+00*S312+9.034284e+00*S313+1.061974e+01*S314'
.param V47_part1='1.648979e+00*S0+1.806978e+00*S1+1.156452e+00*S2+8.376090e-01*S3+1.028032e+00*S4+2.250875e+00*S5+1.764636e+00*S6+8.822709e-01*S7+1.259675e+00*S8+3.544255e+00*S9'
.param V47_part2='V47_part1+2.169585e+00*S10+9.023210e-01*S11+3.820972e+00*S12+1.587950e+00*S13+1.055481e+00*S14+2.833939e+00*S15+1.784016e+00*S16+2.305971e+00*S17+(-3.664879e-01)*S18+1.805713e+00*S19'
.param V47_part3='V47_part2+1.790919e+00*S20+1.739347e+00*S21+1.871304e+00*S22+3.924972e+00*S23+2.519727e+00*S24+1.974613e+00*S25+4.731843e+00*S26+4.182882e+00*S27+4.306793e+00*S28+5.503500e+00*S29'
.param V47_part4='V47_part3+4.418603e+00*S30+4.757193e+00*S31+1.680618e+00*S32+5.037808e+00*S33+5.859146e+00*S34+4.056317e+00*S35+5.743466e+00*S36+3.574779e+00*S37+8.969717e+00*S38+6.465736e+00*S39'
.param V47_part5='V47_part4+2.483224e+00*S40+1.007117e+01*S41+7.167995e+00*S42+9.151426e+00*S43+1.070072e+01*S44+1.247527e+00*S45+6.203960e+00*S46+7.681928e-01*S47+5.156213e+00*S48+6.182837e+00*S49'
.param V47_part6='V47_part5+1.286240e+00*S50+5.687846e+00*S51+9.825027e+00*S52+8.713382e+00*S53+7.092447e+00*S54+1.049452e+01*S55+9.260159e+00*S56+7.192036e+00*S57+7.699492e+00*S58+9.979809e+00*S59'
.param V47_part7='V47_part6+2.374528e+00*S60+4.114190e+00*S61+8.336544e+00*S62+4.261996e+00*S63+7.195736e+00*S64+1.119396e+01*S65+5.076382e+00*S66+1.070966e+01*S67+1.428130e+01*S68+8.012978e+00*S69'
.param V47_part8='V47_part7+1.256049e+01*S70+1.611580e+01*S71+9.130606e+00*S72+1.434535e+01*S73+1.631571e+01*S74+3.387162e+00*S75+3.880368e+00*S76+4.431142e+00*S77+3.093880e+00*S78+3.919404e+00*S79'
.param V47_part9='V47_part8+6.076583e+00*S80+5.209444e+00*S81+5.241159e+00*S82+6.350014e+00*S83+5.072648e+00*S84+7.099926e+00*S85+7.490437e+00*S86+7.291635e+00*S87+6.952566e+00*S88+9.577011e+00*S89'
.param V47_part10='V47_part9+8.422446e+00*S90+9.886700e+00*S91+1.419223e+01*S92+7.489310e+00*S93+8.907643e+00*S94+1.506599e+01*S95+9.259236e+00*S96+1.194777e+01*S97+1.894990e+01*S98+1.076676e+01*S99'
.param V47_part11='V47_part10+1.113010e+01*S100+2.025786e+01*S101+1.299087e+01*S102+1.453447e+01*S103+1.199762e+01*S104+8.605655e+00*S105+1.581380e+01*S106+1.966195e+01*S107+1.029306e+01*S108+1.786722e+01*S109'
.param V47_part12='V47_part11+2.057353e+01*S110+1.222456e+01*S111+1.597939e+01*S112+2.127845e+01*S113+1.283126e+01*S114+7.597312e+00*S115+1.306031e+01*S116+1.125777e+01*S117+1.166712e+01*S118+2.665496e+01*S119'
.param V47_part13='V47_part12+7.053851e+00*S120+1.765089e+01*S121+2.277260e+01*S122+1.085991e+01*S123+1.613900e+01*S124+1.767640e+01*S125+1.530348e+01*S126+1.628966e+01*S127+1.750807e+01*S128+1.762723e+01*S129'
.param V47_part14='V47_part13+1.682898e+01*S130+2.615617e+01*S131+1.444208e+01*S132+1.705365e+01*S133+2.734281e+01*S134+4.988493e+00*S135+5.630915e+00*S136+1.236241e+01*S137+4.639082e+00*S138+7.155393e+00*S139'
.param V47_part15='V47_part14+1.542202e+01*S140+7.892006e+00*S141+1.338926e+01*S142+1.426223e+01*S143+1.158932e+01*S144+1.409791e+01*S145+1.423000e+01*S146+1.342353e+01*S147+1.698950e+01*S148+1.605762e+01*S149'
.param V47_part16='V47_part15+1.516563e+01*S150+2.176507e+01*S151+2.182734e+01*S152+1.472137e+01*S153+2.034489e+01*S154+2.355890e+01*S155+1.775159e+01*S156+2.337236e+01*S157+3.228289e+01*S158+1.902690e+01*S159'
.param V47_part17='V47_part16+1.769783e+01*S160+3.597912e+01*S161+1.142062e+01*S162+3.189366e+01*S163+3.846484e+01*S164+9.117188e+00*S165+2.430756e+01*S166+3.151578e+01*S167+1.499325e+01*S168+2.651832e+01*S169'
.param V47_part18='V47_part17+3.412992e+01*S170+1.623737e+01*S171+1.941461e+01*S172+2.635722e+01*S173+1.809305e+01*S174+1.766514e+01*S175+4.076462e+01*S176+1.760297e+01*S177+2.934338e+01*S178+3.795083e+01*S179'
.param V47_part19='V47_part18+1.398965e+01*S180+2.883781e+01*S181+2.901438e+01*S182+1.517155e+01*S183+2.042483e+01*S184+3.952941e+01*S185+1.518531e+01*S186+2.113324e+01*S187+3.768267e+01*S188+1.796500e+01*S189'
.param V47_part20='V47_part19+2.804823e+01*S190+3.831048e+01*S191+1.722488e+01*S192+3.082016e+01*S193+3.365225e+01*S194+7.441478e+00*S195+2.250905e+01*S196+2.750854e+01*S197+9.992124e+00*S198+1.754613e+01*S199'
.param V47_part21='V47_part20+2.343071e+01*S200+1.839391e+01*S201+1.755000e+01*S202+2.225632e+01*S203+9.054917e+00*S204+1.865560e+01*S205+2.634516e+01*S206+1.458935e+01*S207+2.238663e+01*S208+2.756069e+01*S209'
.param V47_part22='V47_part21+1.532167e+01*S210+2.961882e+01*S211+3.513768e+01*S212+1.317786e+01*S213+1.560468e+01*S214+3.721220e+01*S215+2.079017e+01*S216+3.574469e+01*S217+3.469102e+01*S218+2.170299e+01*S219'
.param V47_part23='V47_part22+3.455048e+01*S220+5.291947e+01*S221+2.187087e+01*S222+3.805517e+01*S223+4.563559e+01*S224+1.953889e+01*S225+3.535789e+01*S226+4.570660e+01*S227+1.977482e+01*S228+3.155775e+01*S229'
.param V47_part24='V47_part23+5.017216e+01*S230+1.371816e+01*S231+3.527775e+01*S232+4.498583e+01*S233+2.073730e+01*S234+3.605523e+01*S235+4.617308e+01*S236+2.076654e+01*S237+3.776997e+01*S238+4.693448e+01*S239'
.param V47_part25='V47_part24+1.821143e+01*S240+3.577080e+01*S241+5.101727e+01*S242+1.935991e+01*S243+3.229379e+01*S244+5.065293e+01*S245+1.655877e+01*S246+3.316457e+01*S247+4.644904e+01*S248+2.115626e+01*S249'
.param V47_part26='V47_part25+3.631661e+01*S250+4.644226e+01*S251+2.200038e+01*S252+4.138581e+01*S253+4.542021e+01*S254+1.597972e+01*S255+2.395245e+01*S256+3.866323e+01*S257+1.740324e+01*S258+2.785576e+01*S259'
.param V47_part27='V47_part26+4.148233e+01*S260+1.945819e+01*S261+2.537315e+01*S262+3.252304e+01*S263+2.041713e+01*S264+2.888656e+01*S265+3.850667e+01*S266+2.023938e+01*S267+3.445057e+01*S268+3.640748e+01*S269'
.param V47_part28='V47_part27+2.241547e+01*S270+3.177798e+01*S271+6.017890e+01*S272+2.366139e+01*S273+4.487196e+01*S274+6.387979e+01*S275+2.457071e+01*S276+3.983550e+01*S277+5.728136e+01*S278+2.638819e+01*S279'
.param V47_part29='V47_part28+4.440167e+01*S280+5.864338e+01*S281+2.647898e+01*S282+4.862567e+01*S283+5.608464e+01*S284+2.206789e+01*S285+3.987111e+01*S286+4.346577e+01*S287+2.374238e+01*S288+3.950326e+01*S289'
.param V47_part30='V47_part29+5.555193e+01*S290+2.547549e+01*S291+4.046189e+01*S292+5.721910e+01*S293+2.686658e+01*S294+4.248930e+01*S295+5.696976e+01*S296+2.684545e+01*S297+4.277189e+01*S298+5.427346e+01*S299'
.param V47_part31='V47_part30+1.872967e+01*S300+3.760014e+01*S301+3.885517e+01*S302+2.240392e+01*S303+3.198596e+01*S304+3.960442e+01*S305+2.307395e+01*S306+3.650684e+01*S307+4.779673e+01*S308+2.410332e+01*S309'
.param V47='V47_part31+3.780362e+01*S310+4.719226e+01*S311+2.501120e+01*S312+4.046497e+01*S313+4.490447e+01*S314'
.param V48_part1='6.701270e-01*S0+8.509381e-01*S1+2.754855e-01*S2+9.014660e-01*S3+1.498404e-01*S4+7.639403e-01*S5+(-2.639800e-01)*S6+4.227546e-01*S7+4.540159e-01*S8+(-3.447520e-01)*S9'
.param V48_part2='V48_part1+1.031717e+00*S10+9.273683e-02*S11+1.253786e-01*S12+4.552254e-02*S13+(-2.703704e-01)*S14+4.773889e-01*S15+(-5.731113e-02)*S16+3.146315e-02*S17+4.453931e-01*S18+(-4.467438e-02)*S19'
.param V48_part3='V48_part2+(-5.643383e-02)*S20+(-1.385246e-02)*S21+9.174521e-02*S22+2.395322e-01*S23+(-4.879079e-01)*S24+(-2.831780e-01)*S25+(-1.854261e-01)*S26+5.144379e-01*S27+1.425547e-01*S28+(-2.026142e-01)*S29'
.param V48_part4='V48_part3+6.402870e-01*S30+1.458868e+00*S31+(-3.607090e-01)*S32+6.470141e-01*S33+1.094679e+00*S34+1.109046e-01*S35+5.353615e-01*S36+(-8.883464e-02)*S37+2.095774e+00*S38+3.965406e-01*S39'
.param V48_part5='V48_part4+1.056869e+00*S40+2.087819e+00*S41+4.090012e-01*S42+8.322155e-01*S43+2.023956e+00*S44+5.137172e-01*S45+8.190385e-01*S46+1.115197e-01*S47+1.046998e-01*S48+(-5.004580e-02)*S49'
.param V48_part6='V48_part5+2.765781e-01*S50+1.775653e-01*S51+1.433115e-01*S52+(-7.897982e-01)*S53+1.427213e-01*S54+1.266083e-01*S55+(-8.934444e-01)*S56+3.340876e-02*S57+(-2.459873e-01)*S58+(-9.573779e-01)*S59'
.param V48_part7='V48_part6+5.484494e-01*S60+8.673282e-02*S61+7.179900e-01*S62+8.096512e-02*S63+(-3.268874e-02)*S64+1.372293e+00*S65+(-1.337795e-01)*S66+3.214164e-01*S67+1.248953e+00*S68+1.015163e-02*S69'
.param V48_part8='V48_part7+8.371907e-01*S70+1.708741e+00*S71+5.241766e-02*S72+1.652738e+00*S73+8.456380e-01*S74+9.524065e-02*S75+7.991335e-02*S76+4.706029e-01*S77+5.887040e-03*S78+(-1.262814e-01)*S79'
.param V48_part9='V48_part8+2.913851e-01*S80+2.583623e-01*S81+4.015371e-01*S82+2.551921e-01*S83+1.444289e-01*S84+9.950924e-04*S85+2.110593e-01*S86+6.582211e-01*S87+2.360237e-01*S88+2.669764e-01*S89'
.param V48_part10='V48_part9+3.041673e-01*S90+6.275715e-01*S91+1.831663e+00*S92+6.081458e-01*S93+8.296218e-01*S94+2.027776e+00*S95+8.067792e-01*S96+1.317056e+00*S97+1.637803e+00*S98+9.507034e-01*S99'
.param V48_part11='V48_part10+1.570893e+00*S100+1.661420e+00*S101+6.220017e-01*S102+1.030364e+00*S103+1.018848e+00*S104+2.129292e-01*S105+3.073145e-02*S106+1.621220e+00*S107+1.949594e-01*S108+(-7.165371e-03)*S109'
.param V48_part12='V48_part11+1.053515e+00*S110+1.537541e-01*S111+4.326441e-01*S112+1.152450e+00*S113+2.088568e-01*S114+(-3.525898e-02)*S115+1.148763e+00*S116+3.739043e-01*S117+4.813609e-01*S118+9.370104e-01*S119'
.param V48_part13='V48_part12+2.687434e-01*S120+1.440984e-01*S121+1.702201e+00*S122+2.428607e-01*S123+7.163731e-01*S124+1.218493e+00*S125+3.659364e-01*S126+4.272612e-01*S127+1.125410e+00*S128+1.134677e-01*S129'
.param V48_part14='V48_part13+5.576023e-01*S130+1.907551e-01*S131+1.849862e-01*S132+4.227881e-01*S133+2.273243e-01*S134+7.785658e-01*S135+(-2.020219e-02)*S136+2.388727e-01*S137+(-5.653415e-01)*S138+(-6.024461e-02)*S139'
.param V48_part15='V48_part14+1.013520e+00*S140+(-3.203239e-01)*S141+1.302217e-01*S142+6.723001e-01*S143+3.448375e-01*S144+3.914330e-01*S145+5.320254e-01*S146+2.225425e-02*S147+6.833365e-02*S148+(-8.758460e-01)*S149'
.param V48_part16='V48_part15+3.215636e-01*S150+6.128864e-01*S151+1.889665e+00*S152+4.796932e-01*S153+7.669580e-01*S154+1.734358e+00*S155+3.087279e-01*S156+1.050326e+00*S157+1.478647e+00*S158+4.024364e-01*S159'
.param V48_part17='V48_part16+3.314566e-02*S160+7.205336e-01*S161+1.964546e-01*S162+7.010212e-01*S163+9.589517e-01*S164+2.417078e-01*S165+9.840639e-01*S166+5.755225e-01*S167+3.022860e-01*S168+3.798733e-01*S169'
.param V48_part18='V48_part17+8.877323e-01*S170+2.850266e-01*S171+1.135733e-01*S172+(-1.515136e-02)*S173+2.565793e-01*S174+(-4.899853e-02)*S175+6.895938e-01*S176+2.875154e-01*S177+1.366517e-01*S178+3.762757e-01*S179'
.param V48_part19='V48_part18+2.094616e-01*S180+1.133689e+00*S181+7.481477e-01*S182+3.940468e-01*S183+4.104388e-01*S184+9.264040e-01*S185+2.825368e-01*S186+2.282372e-01*S187+6.356164e-01*S188+1.942529e-01*S189'
.param V48_part20='V48_part19+5.939180e-01*S190+9.419850e-01*S191+1.667570e-01*S192+2.934112e-01*S193+6.534349e-01*S194+(-2.625153e-01)*S195+1.232193e+00*S196+4.406292e-01*S197+1.295239e-02*S198+1.264301e+00*S199'
.param V48_part21='V48_part20+1.082072e+00*S200+2.591167e-02*S201+6.261346e-01*S202+6.670341e-01*S203+(-5.611134e-01)*S204+(-2.104880e-01)*S205+2.570274e-01*S206+4.476145e-01*S207+(-2.516464e-01)*S208+3.315004e-01*S209'
.param V48_part22='V48_part21+2.723271e-01*S210+6.866219e-01*S211+1.672086e+00*S212+1.782916e-01*S213+(-6.215643e-01)*S214+1.953149e+00*S215+3.033127e-01*S216+6.866618e-01*S217+1.875324e+00*S218+3.034254e-01*S219'
.param V48_part23='V48_part22+3.420030e-01*S220+8.110161e-01*S221+3.431313e-01*S222+4.936521e-01*S223+5.230827e-01*S224+2.877798e-01*S225+5.128027e-01*S226+1.171238e+00*S227+2.585829e-01*S228+2.841268e-01*S229'
.param V48_part24='V48_part23+7.601904e-01*S230+(-8.075409e-02)*S231+5.401239e-01*S232+2.518834e-01*S233+2.727815e-01*S234+4.762015e-01*S235+4.490866e-01*S236+2.567148e-01*S237+7.011247e-01*S238+1.152560e-01*S239'
.param V48_part25='V48_part24+3.025017e-01*S240+4.314155e-01*S241+1.179945e+00*S242+1.991494e-01*S243+5.675160e-01*S244+8.411480e-01*S245+(-1.147509e-01)*S246+4.306176e-01*S247+5.732237e-01*S248+1.654082e-01*S249'
.param V48_part26='V48_part25+6.282817e-01*S250+6.366363e-01*S251+5.275356e-02*S252+7.596160e-01*S253+4.354923e-01*S254+(-9.474382e-02)*S255+1.140719e-01*S256+5.645168e-01*S257+9.192476e-01*S258+2.754382e-01*S259'
.param V48_part27='V48_part26+1.066867e+00*S260+6.910954e-01*S261+7.783631e-01*S262+2.617374e-01*S263+6.542451e-01*S264+7.672291e-01*S265+1.403655e+00*S266+4.600134e-01*S267+1.250093e+00*S268+1.218492e+00*S269'
.param V48_part28='V48_part27+3.379367e-01*S270+6.929257e-01*S271+1.567561e+00*S272+1.897904e-01*S273+7.800532e-01*S274+1.254557e+00*S275+3.265291e-01*S276+4.595859e-01*S277+2.668308e-01*S278+2.653276e-01*S279'
.param V48_part29='V48_part28+5.053269e-01*S280+3.457148e-01*S281+3.258281e-01*S282+4.534945e-01*S283+8.612400e-01*S284+3.102128e-01*S285+5.423088e-01*S286+2.877809e-01*S287+2.626755e-01*S288+3.736403e-01*S289'
.param V48_part30='V48_part29+3.729536e-01*S290+3.294964e-01*S291+3.205458e-01*S292+9.016362e-01*S293+2.805894e-01*S294+4.524406e-01*S295+9.333505e-01*S296+2.153482e-01*S297+4.258985e-01*S298+9.231956e-01*S299'
.param V48_part31='V48_part30+1.065523e+00*S300+6.080741e-01*S301+1.807423e+00*S302+7.042484e-01*S303+9.023956e-01*S304+1.969721e+00*S305+6.244636e-01*S306+7.795092e-01*S307+1.788558e+00*S308+5.102472e-01*S309'
.param V48='V48_part31+8.506523e-01*S310+1.648010e+00*S311+4.758113e-01*S312+8.471457e-01*S313+1.818885e+00*S314'
.param V49_part1='(-1.956521e-02)*S0+(-1.427142e-02)*S1+1.292733e-02*S2+(-3.282430e-03)*S3+1.558596e-02*S4+1.239070e-03*S5+2.149867e-02*S6+(-4.928364e-03)*S7+8.027149e-03*S8+(-3.710071e-06)*S9'
.param V49_part2='V49_part1+2.387938e-03*S10+(-2.637086e-02)*S11+(-8.556920e-04)*S12+(-8.753538e-03)*S13+(-5.198736e-03)*S14+4.664265e-04*S15+1.417399e-02*S16+9.445440e-03*S17+2.186144e-02*S18+1.035456e-02*S19'
.param V49_part3='V49_part2+3.588876e-03*S20+1.130527e-02*S21+5.915687e-03*S22+(-4.985793e-03)*S23+2.228076e-02*S24+2.467724e-02*S25+2.655195e-02*S26+1.207243e-02*S27+5.891765e-03*S28+2.108994e-02*S29'
.param V49_part4='V49_part3+6.739357e-02*S30+9.801376e-02*S31+(-3.303861e-02)*S32+(-1.490203e-02)*S33+1.610530e-02*S34+9.644798e-02*S35+(-2.118836e-01)*S36+6.440110e-02*S37+1.878721e-01*S38+(-3.528521e-01)*S39'
.param V49_part5='V49_part4+1.532679e-01*S40+1.724944e-01*S41+(-4.578442e-01)*S42+(-4.248325e-01)*S43+7.418374e-02*S44+5.719926e-03*S45+2.235941e-02*S46+(-8.542048e-02)*S47+(-3.869936e-01)*S48+(-3.445431e-01)*S49'
.param V49_part6='V49_part5+2.415132e-04*S50+(-6.860641e-01)*S51+(-8.609188e-01)*S52+2.363007e-01*S53+(-8.526698e-01)*S54+(-1.280637e+00)*S55+2.905974e-01*S56+(-1.168809e+00)*S57+1.542467e-01*S58+3.300389e-01*S59'
.param V49_part7='V49_part6+(-4.140471e-01)*S60+4.974820e-02*S61+6.237879e-02*S62+(-5.365365e-01)*S63+(-7.600253e-01)*S64+4.705269e-01*S65+(-8.041874e-01)*S66+(-9.955883e-01)*S67+3.819069e-01*S68+(-9.375518e-01)*S69'
.param V49_part8='V49_part7+2.102094e-01*S70+4.216744e-01*S71+(-1.119811e+00)*S72+2.527364e-01*S73+(-8.952575e-01)*S74+2.528092e-03*S75+1.786147e-01*S76+2.332599e-01*S77+9.111635e-02*S78+8.409375e-02*S79'
.param V49_part9='V49_part8+(-7.775255e-02)*S80+1.929584e-02*S81+(-6.161812e-02)*S82+(-1.449138e-01)*S83+(-1.993080e-01)*S84+(-8.960775e-02)*S85+(-1.851226e-01)*S86+(-8.246847e-02)*S87+(-1.438883e-01)*S88+4.726389e-02*S89'
.param V49_part10='V49_part9+(-1.604710e-01)*S90+4.907648e-01*S91+6.546005e-01*S92+4.558975e-01*S93+7.862736e-01*S94+7.187128e-01*S95+5.755379e-01*S96+5.340632e-01*S97+5.859741e-01*S98+5.717598e-01*S99'
.param V49_part11='V49_part10+5.150916e-01*S100+6.557886e-01*S101+(-1.256242e+00)*S102+5.336237e-01*S103+2.838228e-01*S104+(-2.907927e-01)*S105+(-3.573308e-01)*S106+9.261710e-01*S107+(-6.582755e-01)*S108+(-1.099966e+00)*S109'
.param V49_part12='V49_part11+8.009536e-01*S110+(-5.973757e-01)*S111+5.923638e-01*S112+8.667857e-01*S113+(-7.913345e-01)*S114+1.007873e-01*S115+4.971894e-01*S116+(-4.742694e-01)*S117+6.592961e-01*S118+(-5.851131e-01)*S119'
.param V49_part13='V49_part12+(-5.043477e-01)*S120+(-6.899689e-01)*S121+8.653848e-01*S122+(-5.659293e-01)*S123+8.367188e-01*S124+6.598781e-01*S125+2.478614e-01*S126+3.682812e-01*S127+2.127064e-01*S128+2.845815e-01*S129'
.param V49_part14='V49_part13+3.566428e-01*S130+7.692239e-01*S131+(-1.029695e+00)*S132+4.521327e-01*S133+7.580129e-01*S134+(-8.114838e-01)*S135+3.503402e-01*S136+6.589929e-01*S137+2.337548e-01*S138+2.558219e-01*S139'
.param V49_part15='V49_part14+5.285028e-01*S140+1.081315e-01*S141+4.472155e-01*S142+2.193189e-01*S143+4.147365e-01*S144+4.832147e-01*S145+5.349668e-01*S146+5.702040e-01*S147+5.687514e-01*S148+5.891624e-01*S149'
.param V49_part16='V49_part15+(-1.984434e-01)*S150+1.517157e+00*S151+1.202860e+00*S152+6.570134e-01*S153+1.012464e+00*S154+1.162284e+00*S155+(-4.060356e-01)*S156+7.296720e-01*S157+1.365002e+00*S158+(-2.054309e-02)*S159'
.param V49_part17='V49_part16+6.294124e-01*S160+(-9.169851e-01)*S161+(-1.919273e-01)*S162+(-4.946885e-01)*S163+(-5.483367e-01)*S164+4.388871e-01*S165+1.265683e+00*S166+1.475738e+00*S167+(-5.372733e-01)*S168+(-6.417065e-01)*S169'
.param V49_part18='V49_part17+1.540853e+00*S170+(-6.524352e-01)*S171+5.858545e-01*S172+4.358125e-01*S173+(-8.602901e-01)*S174+5.814999e-01*S175+(-3.195431e-01)*S176+(-9.354360e-01)*S177+(-1.161024e+00)*S178+(-7.877848e-01)*S179'
.param V49_part19='V49_part18+5.149685e-01*S180+1.124310e+00*S181+1.126780e+00*S182+(-4.094057e-01)*S183+5.185839e-01*S184+(-1.209778e+00)*S185+(-7.372055e-01)*S186+4.707988e-01*S187+(-1.199149e+00)*S188+(-8.158110e-01)*S189'
.param V49_part20='V49_part19+(-7.905904e-01)*S190+(-1.716416e+00)*S191+(-8.566801e-01)*S192+(-9.075505e-01)*S193+(-1.895670e+00)*S194+1.094445e-01*S195+(-1.553814e+00)*S196+1.182444e+00*S197+5.838293e-01*S198+7.394313e-01*S199'
.param V49_part21='V49_part20+9.936732e-01*S200+1.905922e-01*S201+5.621768e-01*S202+5.729785e-01*S203+1.549820e-01*S204+6.878781e-01*S205+6.193931e-01*S206+(-1.444497e+00)*S207+8.726990e-01*S208+8.797854e-01*S209'
.param V49_part22='V49_part21+5.828504e-01*S210+1.310128e+00*S211+1.563068e+00*S212+2.734480e-01*S213+5.423882e-01*S214+2.079423e+00*S215+(-4.605769e-01)*S216+8.866484e-02*S217+2.161467e+00*S218+(-5.956053e-01)*S219'
.param V49_part23='V49_part22+(-9.972153e-01)*S220+5.834706e-01*S221+(-7.894416e-01)*S222+(-7.946285e-01)*S223+(-8.127556e-01)*S224+2.749839e-01*S225+(-2.291669e-01)*S226+2.112167e+00*S227+(-2.247997e-01)*S228+(-1.693564e-01)*S229'
.param V49_part24='V49_part23+(-2.978231e-01)*S230+3.003803e-01*S231+(-4.984806e-01)*S232+(-1.546444e+00)*S233+(-6.271575e-01)*S234+(-5.783179e-01)*S235+(-1.655382e+00)*S236+(-7.646361e-01)*S237+(-1.064044e+00)*S238+(-1.147277e+00)*S239'
.param V49_part25='V49_part24+5.133683e-01*S240+(-1.525891e-02)*S241+(-3.639660e-01)*S242+(-1.469804e-01)*S243+(-2.738625e-01)*S244+(-6.078030e-01)*S245+5.623228e-01*S246+(-5.535017e-01)*S247+(-1.334296e+00)*S248+(-5.678940e-01)*S249'
.param V49_part26='V49_part25+(-8.832054e-01)*S250+(-1.567962e+00)*S251+(-5.914093e-01)*S252+(-9.093122e-01)*S253+(-1.412882e+00)*S254+7.503195e-01*S255+1.366154e+00*S256+1.408578e+00*S257+(-8.734127e-01)*S258+1.068685e+00*S259'
.param V49_part27='V49_part26+1.686151e+00*S260+(-8.882840e-01)*S261+(-1.189361e+00)*S262+7.498906e-01*S263+(-1.006011e+00)*S264+(-1.064406e+00)*S265+(-2.331553e+00)*S266+(-1.070578e+00)*S267+(-1.654324e+00)*S268+(-1.944046e+00)*S269'
.param V49_part28='V49_part27+(-3.490330e-02)*S270+8.926611e-01*S271+3.217459e+00*S272+(-2.060354e-01)*S273+5.833974e-01*S274+4.866690e-01*S275+(-3.277735e-01)*S276+(-4.579489e-01)*S277+(-1.245374e+00)*S278+(-3.838614e-01)*S279'
.param V49_part29='V49_part28+(-2.158893e-01)*S280+(-1.174996e+00)*S281+(-5.924661e-01)*S282+(-7.288624e-01)*S283+(-7.345411e-01)*S284+5.166670e-02*S285+(-7.050539e-03)*S286+8.231362e-01*S287+(-1.147874e-01)*S288+(-5.052552e-01)*S289'
.param V49_part30='V49_part29+(-1.190982e+00)*S290+(-2.494938e-01)*S291+(-2.901648e-01)*S292+(-3.540591e-01)*S293+(-2.917095e-01)*S294+(-3.616075e-01)*S295+(-5.334513e-01)*S296+(-3.578039e-01)*S297+(-4.082796e-01)*S298+(-6.038421e-01)*S299'
.param V49_part31='V49_part30+(-6.084943e-01)*S300+1.205482e+00*S301+2.149486e+00*S302+(-4.506577e-01)*S303+(-6.905912e-01)*S304+2.196751e+00*S305+(-5.771600e-01)*S306+(-6.113717e-01)*S307+(-1.895657e+00)*S308+(-7.366894e-01)*S309'
.param V49='V49_part31+(-6.288881e-01)*S310+(-1.661768e+00)*S311+(-8.617737e-01)*S312+(-7.709402e-01)*S313+(-1.648808e+00)*S314'
.param V50_part1='7.651908e+00*S0+8.507003e+00*S1+1.633250e+01*S2+1.135433e+01*S3+2.293290e+01*S4+1.145308e+02*S5+1.874259e+01*S6+1.755862e+02*S7+1.172278e+02*S8+5.193617e+01*S9'
.param V50_part2='V50_part1+3.874706e+01*S10+1.115396e+02*S11+9.951429e+03*S12+6.900027e+02*S13+5.039086e+00*S14+4.645307e+00*S15+2.064561e+01*S16+7.276451e+00*S17+5.071957e+00*S18+1.724300e+01*S19'
.param V50_part3='V50_part2+8.628343e+00*S20+2.001573e+01*S21+1.419128e+01*S22+1.952389e+01*S23+7.045377e+00*S24+1.067061e+01*S25+1.143679e+01*S26+1.018954e+01*S27+1.829078e+01*S28+1.032500e+01*S29'
.param V50_part4='V50_part3+6.954565e+00*S30+1.333558e+01*S31+1.854604e+01*S32+7.881000e+00*S33+1.858785e+03*S34+4.151793e+01*S35+8.534845e+00*S36+9.808630e+00*S37+6.329650e+00*S38+7.723699e+00*S39'
.param V50_part5='V50_part4+5.169607e+00*S40+6.501387e+00*S41+6.026552e+00*S42+4.147947e+02*S43+7.650902e+00*S44+5.458418e+01*S45+(-1.884247e+01)*S46+2.904665e+01*S47+9.399149e+00*S48+1.983303e+01*S49'
.param V50_part6='V50_part5+1.740107e+01*S50+1.029585e+01*S51+9.533216e+00*S52+6.658931e+00*S53+9.265199e+00*S54+3.015796e+01*S55+5.984823e+00*S56+7.328433e+00*S57+4.450082e+00*S58+4.925086e+00*S59'
.param V50_part7='V50_part6+2.631707e+01*S60+2.836396e+01*S61+2.252652e+01*S62+4.012520e+01*S63+1.028649e+01*S64+4.277467e+01*S65+2.965021e+03*S66+1.802843e+01*S67+8.473241e+00*S68+8.013469e+00*S69'
.param V50_part8='V50_part7+1.177324e+01*S70+6.583208e+00*S71+4.236169e+01*S72+6.462459e+00*S73+1.711014e+03*S74+6.489342e+00*S75+6.984754e+00*S76+4.276517e+00*S77+3.251374e+02*S78+3.249451e+00*S79'
.param V50_part9='V50_part8+3.368613e+01*S80+4.593501e+01*S81+6.039645e+00*S82+8.761552e+00*S83+2.514699e+03*S84+4.873279e+00*S85+1.053184e+01*S86+2.500303e+03*S87+4.653265e+00*S88+1.693742e+02*S89'
.param V50_part10='V50_part9+2.336942e+01*S90+2.467783e+01*S91+1.712991e+02*S92+(-2.293936e+03)*S93+(-4.730264e+03)*S94+(-4.503922e+03)*S95+1.785846e+01*S96+2.479926e+01*S97+5.987871e+00*S98+1.276980e+01*S99'
.param V50_part11='V50_part10+(-4.738785e+03)*S100+8.499335e+03*S101+1.431478e+01*S102+(-4.988066e+03)*S103+4.044490e+00*S104+1.275617e+01*S105+2.546236e+01*S106+5.282347e+00*S107+1.384040e+01*S108+1.397514e+01*S109'
.param V50_part12='V50_part11+5.629199e+00*S110+4.696289e+02*S111+7.556141e+00*S112+5.709266e+02*S113+1.090041e+02*S114+7.506813e+00*S115+4.149870e+00*S116+5.402884e+00*S117+5.935007e+00*S118+4.603815e+00*S119'
.param V50_part13='V50_part12+1.334733e+01*S120+1.023340e+01*S121+2.916496e+01*S122+1.562483e+01*S123+1.999101e+03*S124+2.658401e+02*S125+3.368637e+01*S126+4.675187e+01*S127+1.600971e+02*S128+1.940534e+01*S129'
.param V50_part14='V50_part13+4.186932e+01*S130+3.703678e+01*S131+1.462973e+02*S132+1.740309e+01*S133+2.584363e+01*S134+3.590910e+01*S135+6.436808e+00*S136+5.812072e+00*S137+1.037107e+01*S138+4.107174e+00*S139'
.param V50_part15='V50_part14+8.869103e+00*S140+9.808540e+00*S141+7.063550e+00*S142+5.561346e+00*S143+1.006207e+01*S144+6.277584e+00*S145+6.235844e+00*S146+5.094046e+00*S147+6.736350e+00*S148+1.470479e+01*S149'
.param V50_part16='V50_part15+2.319698e+01*S150+2.305099e+01*S151+3.823326e+01*S152+(-4.663274e+03)*S153+8.115306e+00*S154+1.430523e+01*S155+1.385350e+01*S156+6.613424e+00*S157+5.767880e+01*S158+8.920584e+00*S159'
.param V50_part17='V50_part16+(-4.292100e+01)*S160+9.573522e+01*S161+1.592688e+01*S162+5.204839e+00*S163+4.791294e+00*S164+1.578682e+01*S165+8.693297e+00*S166+5.459964e+00*S167+1.412770e+01*S168+6.961927e+00*S169'
.param V50_part18='V50_part17+5.039756e+00*S170+5.997129e+03*S171+6.937120e+00*S172+5.262593e+00*S173+5.200043e+01*S174+7.710866e+00*S175+4.247832e+00*S176+1.498187e+01*S177+5.145577e+00*S178+4.017618e+00*S179'
.param V50_part19='V50_part18+8.671136e+01*S180+7.283485e+00*S181+5.059681e+00*S182+8.643422e+00*S183+1.752978e+01*S184+1.114239e+01*S185+1.170468e+01*S186+2.012040e+01*S187+3.723373e+00*S188+2.611283e+01*S189'
.param V50_part20='V50_part19+2.048518e+01*S190+2.319897e+02*S191+1.642656e+01*S192+5.357509e+00*S193+2.605206e+00*S194+9.650947e+00*S195+1.721701e+01*S196+4.902133e+00*S197+1.140052e+02*S198+1.781753e+01*S199'
.param V50_part21='V50_part20+3.475067e+01*S200+2.014593e+01*S201+2.857425e+01*S202+3.271862e+01*S203+8.906233e+00*S204+1.243181e+01*S205+4.768769e+01*S206+1.875153e+01*S207+1.165688e+01*S208+2.575285e+01*S209'
.param V50_part22='V50_part21+(-9.253856e+02)*S210+7.416642e+00*S211+6.889974e+01*S212+3.522425e+01*S213+2.141172e+02*S214+1.386736e+01*S215+5.461172e+01*S216+1.945445e+01*S217+1.138499e+01*S218+1.952505e+01*S219'
.param V50_part23='V50_part22+5.165276e+01*S220+1.000000e+04*S221+1.708603e+01*S222+1.903524e+02*S223+5.834669e+01*S224+1.025523e+01*S225+8.281670e+00*S226+3.209358e+01*S227+4.660632e+01*S228+1.383867e+01*S229'
.param V50_part24='V50_part23+9.769238e+00*S230+5.977395e+00*S231+1.255864e+01*S232+3.166140e+00*S233+1.326533e+02*S234+1.302496e+01*S235+3.360007e+00*S236+4.344266e+02*S237+5.480364e+00*S238+4.021560e+00*S239'
.param V50_part25='V50_part24+(-3.323975e+02)*S240+3.125702e+03*S241+1.257456e+01*S242+3.903034e+01*S243+(-3.912998e+02)*S244+1.315029e+01*S245+3.779489e+00*S246+5.792778e+00*S247+3.260394e+00*S248+2.138249e+01*S249'
.param V50_part26='V50_part25+1.171329e+01*S250+3.667744e+00*S251+1.287821e+01*S252+1.359663e+01*S253+3.470591e+00*S254+1.793829e+01*S255+6.669014e+00*S256+9.228587e+00*S257+1.773988e+01*S258+1.230198e+01*S259'
.param V50_part27='V50_part26+1.159138e+01*S260+1.726577e+01*S261+5.834734e+00*S262+4.801027e+00*S263+8.365245e+00*S264+4.733382e+01*S265+2.949594e+00*S266+1.175455e+01*S267+5.444462e+01*S268+2.820292e+00*S269'
.param V50_part28='V50_part27+7.838438e+03*S270+1.243805e+01*S271+1.717118e+01*S272+1.361505e+02*S273+9.383693e+00*S274+1.711178e+01*S275+7.641145e+01*S276+3.247399e+01*S277+3.868248e+00*S278+1.918186e+01*S279'
.param V50_part29='V50_part28+1.842946e+01*S280+4.486934e+00*S281+1.822289e+01*S282+6.491216e+00*S283+6.562131e+01*S284+1.844769e+01*S285+5.565686e+02*S286+4.426373e+00*S287+1.735691e+01*S288+7.314765e+00*S289'
.param V50_part30='V50_part29+3.528531e+00*S290+1.583172e+01*S291+7.226273e+00*S292+6.080788e+01*S293+2.298607e+01*S294+7.297722e+00*S295+1.000000e+04*S296+1.691597e+01*S297+2.759320e+02*S298+2.498798e+03*S299'
.param V50_part31='V50_part30+3.389963e+01*S300+2.313667e+01*S301+1.411917e+01*S302+3.822562e+01*S303+2.462464e+01*S304+1.589293e+01*S305+3.779706e+01*S306+5.855530e+00*S307+3.395785e+00*S308+1.615642e+01*S309'
.param V50='V50_part31+6.206304e+00*S310+3.904375e+00*S311+1.146539e+01*S312+5.799873e+00*S313+4.268463e+00*S314'
.param V51_part1='9.230933e+00*S0+3.613062e+00*S1+1.107682e+02*S2+4.815374e+00*S3+(-1.176848e+01)*S4+(-4.158525e+01)*S5+(-1.054265e+01)*S6+8.508544e+02*S7+4.661576e-01*S8+(-9.953362e+00)*S9'
.param V51_part2='V51_part1+(-2.660647e+00)*S10+(-2.363332e+00)*S11+(-6.800796e+02)*S12+2.612194e+02*S13+1.111904e+00*S14+2.567519e+00*S15+(-2.650017e+01)*S16+(-5.247183e+00)*S17+5.656743e+00*S18+(-1.455657e+01)*S19'
.param V51_part3='V51_part2+(-3.418218e+00)*S20+(-1.210390e+01)*S21+(-1.000787e+01)*S22+(-5.082217e+00)*S23+(-3.502092e+00)*S24+3.649952e+00*S25+(-3.333594e+00)*S26+4.925299e-01*S27+(-5.409090e+00)*S28+(-2.216369e+00)*S29'
.param V51_part4='V51_part3+2.209547e+00*S30+(-1.090817e+01)*S31+(-8.065495e+00)*S32+(-1.935023e+00)*S33+4.993349e+03*S34+(-2.936160e+01)*S35+(-1.838791e+00)*S36+(-4.304518e+00)*S37+(-1.549872e+00)*S38+(-1.335483e+00)*S39'
.param V51_part5='V51_part4+7.905734e-01*S40+(-3.098932e+00)*S41+(-5.696364e-01)*S42+(-7.220398e+01)*S43+(-4.551432e+00)*S44+1.179716e+01*S45+5.704996e+01*S46+(-1.330631e+01)*S47+(-6.366663e+00)*S48+(-1.478311e-01)*S49'
.param V51_part6='V51_part5+(-1.447529e+01)*S50+(-1.085369e+00)*S51+(-3.370849e+00)*S52+(-1.792753e+00)*S53+(-5.250044e+00)*S54+(-1.231522e+01)*S55+(-1.752548e+00)*S56+(-3.185368e+00)*S57+(-1.658054e+00)*S58+(-1.298347e+00)*S59'
.param V51_part7='V51_part6+(-5.899681e+00)*S60+(-4.567181e+00)*S61+(-1.245759e+01)*S62+(-4.890943e+00)*S63+(-1.671178e+00)*S64+(-1.205125e+01)*S65+(-1.924553e+03)*S66+3.629607e+00*S67+(-2.831303e+00)*S68+(-4.037613e+00)*S69'
.param V51_part8='V51_part7+(-3.422842e+00)*S70+(-1.392318e+00)*S71+(-8.360881e+00)*S72+(-6.956427e-01)*S73+5.591654e-01*S74+(-2.695561e+00)*S75+(-2.634641e+00)*S76+(-2.603537e+00)*S77+(-6.782088e+01)*S78+(-1.615520e+00)*S79'
.param V51_part9='V51_part8+2.664054e+00*S80+(-1.526394e+01)*S81+(-1.841095e+00)*S82+(-1.848835e+00)*S83+(-8.228667e+00)*S84+(-1.835292e+00)*S85+(-2.946995e+00)*S86+2.734195e-01*S87+(-1.015628e+00)*S88+(-3.081122e+00)*S89'
.param V51_part10='V51_part9+(-1.059285e+01)*S90+1.461840e+01*S91+(-3.820407e+01)*S92+(-8.842846e+02)*S93+(-1.542773e+02)*S94+(-6.788240e+02)*S95+(-8.298391e+00)*S96+(-1.128288e+01)*S97+(-2.416673e+00)*S98+(-5.335214e+00)*S99'
.param V51_part11='V51_part10+(-2.920836e+02)*S100+2.261050e+03*S101+(-1.596940e+00)*S102+(-2.120280e+02)*S103+(-1.447772e+00)*S104+(-3.415434e+00)*S105+(-1.714041e+00)*S106+(-3.703360e+00)*S107+(-4.259228e+00)*S108+(-4.965972e+00)*S109'
.param V51_part12='V51_part11+(-2.184932e+00)*S110+1.116345e+01*S111+(-2.678800e+00)*S112+2.794833e+00*S113+(-1.484778e+01)*S114+(-3.125239e+00)*S115+(-1.916322e+00)*S116+(-2.324515e+00)*S117+(-1.316785e+00)*S118+(-1.516917e+00)*S119'
.param V51_part13='V51_part12+(-8.022322e+00)*S120+(-4.279873e+00)*S121+(-6.143085e+00)*S122+(-2.347460e+00)*S123+(-7.506794e+01)*S124+(-6.790689e+01)*S125+(-1.167567e+01)*S126+(-1.264777e+01)*S127+(-5.181326e+01)*S128+(-9.793776e+00)*S129'
.param V51_part14='V51_part13+(-1.911258e+01)*S130+(-1.356387e+01)*S131+(-4.215545e+01)*S132+(-4.794208e+00)*S133+(-7.317791e+00)*S134+5.324675e+00*S135+1.525232e+00*S136+(-1.713045e+00)*S137+(-9.769856e-01)*S138+8.396910e-02*S139'
.param V51_part15='V51_part14+(-1.663366e+00)*S140+(-1.565899e+00)*S141+(-2.081466e+00)*S142+(-2.139501e+00)*S143+(-3.294654e+00)*S144+(-1.487936e+00)*S145+(-2.182040e+00)*S146+(-2.177918e+00)*S147+(-1.165255e+00)*S148+(-4.630942e+00)*S149'
.param V51_part16='V51_part15+(-1.138152e+01)*S150+3.972521e+00*S151+(-6.166893e+01)*S152+(-3.280968e+02)*S153+(-1.058392e+00)*S154+(-1.654240e+01)*S155+(-5.411548e+00)*S156+(-2.784726e+00)*S157+(-2.311013e+01)*S158+(-3.340207e+00)*S159'
.param V51_part17='V51_part16+(-4.249221e+01)*S160+(-3.626792e+01)*S161+(-1.217945e+01)*S162+(-1.761809e+00)*S163+(-1.510288e+00)*S164+8.331703e+00*S165+8.326784e-01*S166+(-1.407686e+00)*S167+(-1.050819e+01)*S168+(-2.208971e+00)*S169'
.param V51_part18='V51_part17+(-1.769590e+00)*S170+1.013833e+02*S171+(-1.872127e-01)*S172+(-1.216978e-01)*S173+(-2.626828e+01)*S174+(-1.657533e+00)*S175+(-1.183437e+00)*S176+(-9.231445e+00)*S177+(-1.290088e+00)*S178+(-6.910411e-01)*S179'
.param V51_part19='V51_part18+2.505756e+00*S180+4.253567e-01*S181+(-1.617057e+00)*S182+(-4.992690e+00)*S183+(-8.292517e+00)*S184+(-3.246875e+00)*S185+(-1.083714e+01)*S186+(-8.127366e+00)*S187+(-5.171208e-01)*S188+(-1.281730e+01)*S189'
.param V51_part20='V51_part19+(-7.506791e+00)*S190+(-5.945684e+01)*S191+(-8.466467e+00)*S192+(-1.101512e+00)*S193+(-5.361608e-01)*S194+(-8.789296e+00)*S195+(-1.283479e+00)*S196+(-2.085954e+00)*S197+3.147674e+01*S198+(-3.610577e+00)*S199'
.param V51_part21='V51_part20+(-9.682005e+00)*S200+(-6.193562e+00)*S201+(-1.065246e+01)*S202+(-1.293733e+01)*S203+(-2.745654e+00)*S204+(-5.225013e+00)*S205+(-1.621277e+01)*S206+(-1.091468e+01)*S207+(-4.032353e+00)*S208+(-6.380010e+00)*S209'
.param V51_part22='V51_part21+(-6.656254e+02)*S210+(-4.269969e+00)*S211+1.001878e+01*S212+(-1.227172e+01)*S213+2.497594e+02*S214+(-6.627523e+00)*S215+(-6.388272e+01)*S216+(-8.973700e+00)*S217+(-8.784902e+00)*S218+(-1.564450e+01)*S219'
.param V51_part23='V51_part22+(-5.881380e+01)*S220+9.434035e+03*S221+(-1.207257e+01)*S222+(-2.205719e+00)*S223+3.297029e-01*S224+(-1.063097e+01)*S225+(-4.981976e+00)*S226+(-8.448430e+00)*S227+(-2.600809e+01)*S228+(-8.267255e+00)*S229'
.param V51_part24='V51_part23+(-3.164059e+00)*S230+7.358941e-01*S231+(-5.217321e+00)*S232+(-7.223324e-01)*S233+(-9.267051e+01)*S234+(-4.794271e+00)*S235+(-7.189117e-01)*S236+(-1.185478e+01)*S237+(-1.781930e+00)*S238+(-7.094572e-01)*S239'
.param V51_part25='V51_part24+(-8.673289e+01)*S240+(-7.574621e+01)*S241+(-1.174170e+01)*S242+(-4.497790e+01)*S243+8.429647e+01*S244+(-3.505105e+00)*S245+(-6.980147e-01)*S246+(-2.095305e+00)*S247+(-5.086102e-01)*S248+(-2.034642e+01)*S249'
.param V51_part26='V51_part25+(-5.576448e+00)*S250+(-1.065883e+00)*S251+(-8.406279e+00)*S252+(-4.206907e+00)*S253+(-7.572139e-01)*S254+(-2.091745e+00)*S255+1.583319e+00*S256+(-4.513057e+00)*S257+(-1.043919e+01)*S258+(-5.414967e+00)*S259'
.param V51_part27='V51_part26+(-3.592932e+00)*S260+(-1.388112e+01)*S261+(-1.121290e+00)*S262+(-5.932871e-01)*S263+(-3.542891e+00)*S264+(-1.535771e+01)*S265+(-7.516576e-01)*S266+(-7.606736e+00)*S267+(-1.642186e+01)*S268+(-6.651893e-01)*S269'
.param V51_part28='V51_part27+(-8.160879e+02)*S270+(-7.326130e+00)*S271+(-6.858889e+00)*S272+(-4.973145e+01)*S273+(-3.274658e+00)*S274+(-5.057389e+00)*S275+(-7.358103e+01)*S276+(-4.044029e+01)*S277+(-1.035565e+00)*S278+(-1.709058e+01)*S279'
.param V51_part29='V51_part28+(-8.010349e+00)*S280+(-1.600642e+00)*S281+(-8.534176e+00)*S282+(-2.188923e+00)*S283+(-4.510809e+01)*S284+(-2.812138e+01)*S285+(-1.157686e+03)*S286+1.941259e-01*S287+(-1.162299e+01)*S288+(-1.723079e+00)*S289'
.param V51_part30='V51_part29+(-3.715761e-01)*S290+(-1.520552e+01)*S291+(-2.922261e+00)*S292+(-9.519705e+01)*S293+(-1.492817e+01)*S294+(-3.027695e+00)*S295+1.501789e+03*S296+(-1.243714e+01)*S297+(-8.247886e+01)*S298+3.752668e+02*S299'
.param V51_part31='V51_part30+(-3.172026e+01)*S300+(-6.155401e+00)*S301+(-3.540892e+00)*S302+(-1.806955e+01)*S303+(-1.286644e+01)*S304+(-3.891969e+00)*S305+(-4.352316e+01)*S306+(-1.001301e+00)*S307+(-1.070011e+00)*S308+(-1.436098e+01)*S309'
.param V51='V51_part31+(-1.646576e+00)*S310+(-1.532454e+00)*S311+(-8.213099e+00)*S312+(-1.531725e+00)*S313+(-1.612416e+00)*S314'
.param V52_part1='(-7.950199e+00)*S0+(-3.012703e+00)*S1+(-1.931154e+01)*S2+(-1.248614e+01)*S3+(-3.055692e+00)*S4+(-5.944038e+01)*S5+(-1.084275e+01)*S6+2.255243e+01*S7+6.472109e+00*S8+(-3.962591e+01)*S9'
.param V52_part2='V52_part1+(-2.166335e+01)*S10+(-1.801396e+01)*S11+(-2.872776e+03)*S12+(-2.531901e+02)*S13+4.993902e+00*S14+(-6.157771e+00)*S15+2.491052e+00*S16+(-9.812697e-01)*S17+(-2.456957e+00)*S18+(-1.857352e+00)*S19'
.param V52_part3='V52_part2+(-2.467258e+00)*S20+(-1.004459e+01)*S21+(-2.396062e+00)*S22+(-7.425330e+00)*S23+(-7.257291e-01)*S24+(-9.250775e-01)*S25+(-3.210560e+00)*S26+(-3.448399e-01)*S27+(-8.135782e+00)*S28+(-2.930289e+00)*S29'
.param V52_part4='V52_part3+(-1.789312e+00)*S30+(-8.229463e+00)*S31+(-9.548191e+00)*S32+(-3.999582e+00)*S33+(-2.170789e+03)*S34+(-1.776847e+01)*S35+(-6.992606e+00)*S36+(-4.427039e+00)*S37+(-1.635605e+00)*S38+(-6.824134e+00)*S39'
.param V52_part5='V52_part4+(-3.597106e+00)*S40+(-2.785804e-01)*S41+(-5.055374e+00)*S42+5.695697e+02*S43+3.584581e+00*S44+(-8.664244e+01)*S45+6.732930e+01*S46+6.470227e-01*S47+(-6.281709e+00)*S48+(-5.948607e+00)*S49'
.param V52_part6='V52_part5+(-8.751914e-02)*S50+(-1.297790e+01)*S51+(-4.314225e+00)*S52+(-2.741674e+00)*S53+(-3.368856e+00)*S54+(-1.933949e+01)*S55+(-2.194093e+00)*S56+(-3.889636e+00)*S57+(-1.314061e+00)*S58+(-1.643734e+00)*S59'
.param V52_part7='V52_part6+(-3.531000e+01)*S60+(-7.320564e+00)*S61+(-1.080740e+01)*S62+(-3.647471e+01)*S63+(-3.512803e+00)*S64+(-2.104137e+01)*S65+(-1.410809e+02)*S66+7.411615e+00*S67+(-3.044456e+00)*S68+(-1.743128e+00)*S69'
.param V52_part8='V52_part7+(-6.120584e+00)*S70+(-2.422413e+00)*S71+(-5.953912e+00)*S72+(-3.325228e+00)*S73+1.117752e+02*S74+(-6.752575e+00)*S75+(-3.275403e+00)*S76+(-1.025992e+00)*S77+(-4.429247e+02)*S78+3.588713e-01*S79'
.param V52_part9='V52_part8+(-3.862699e+00)*S80+(-2.797010e+00)*S81+1.236756e+00*S82+3.176803e-01*S83+(-7.824326e+00)*S84+1.671476e-01*S85+(-5.591491e-01)*S86+7.972369e+00*S87+(-1.272498e+00)*S88+4.042167e+00*S89'
.param V52_part10='V52_part9+(-2.131896e+01)*S90+(-1.597645e+01)*S91+(-8.530241e+01)*S92+(-3.667129e+01)*S93+(-1.952275e+02)*S94+(-4.924153e+01)*S95+(-1.954799e+01)*S96+(-1.983303e+01)*S97+(-1.419979e+00)*S98+(-1.199279e+01)*S99'
.param V52_part11='V52_part10+9.592885e+01*S100+1.531298e+03*S101+(-7.648147e+00)*S102+5.953626e+02*S103+(-9.681491e-01)*S104+(-1.193082e+01)*S105+(-2.076528e-01)*S106+(-5.813372e-01)*S107+(-1.138388e+01)*S108+(-8.012130e+00)*S109'
.param V52_part12='V52_part11+(-1.594676e+00)*S110+(-4.320241e+01)*S111+(-4.140147e+00)*S112+(-5.231335e+02)*S113+(-2.659456e+01)*S114+(-2.224810e+00)*S115+(-6.362459e-01)*S116+(-1.596561e+00)*S117+(-1.257069e+00)*S118+(-8.447418e-01)*S119'
.param V52_part13='V52_part12+(-1.390604e+01)*S120+(-6.593244e+00)*S121+(-7.251506e+00)*S122+(-2.074114e+01)*S123+(-3.557128e+01)*S124+(-9.847238e+01)*S125+(-8.463962e+00)*S126+(-3.025342e+00)*S127+(-5.405923e+01)*S128+(-7.761653e+00)*S129'
.param V52_part14='V52_part13+(-1.507175e+01)*S130+(-1.202955e+01)*S131+(-2.204429e+01)*S132+(-6.536448e+00)*S133+(-9.252360e+00)*S134+(-4.901268e+01)*S135+1.189414e+00*S136+(-1.943177e+00)*S137+(-7.528365e+00)*S138+(-3.580427e-01)*S139'
.param V52_part15='V52_part14+(-3.706233e+00)*S140+(-8.825206e+00)*S141+(-2.837870e+00)*S142+(-7.354405e-01)*S143+(-8.875443e+00)*S144+(-2.548746e+00)*S145+(-5.795993e-01)*S146+(-2.364517e+00)*S147+(-3.064226e+00)*S148+(-4.757249e+00)*S149'
.param V52_part16='V52_part15+(-2.213281e+01)*S150+(-1.138498e+01)*S151+1.185876e+00*S152+(-3.163068e+02)*S153+(-6.083899e+00)*S154+6.461459e+00*S155+(-2.464936e-01)*S156+(-2.568775e+00)*S157+(-1.286141e+01)*S158+(-3.183740e+00)*S159'
.param V52_part17='V52_part16+2.737456e+02*S160+(-3.301814e+01)*S161+3.038842e+00*S162+(-1.294373e+00)*S163+(-8.679070e-01)*S164+(-2.538196e+01)*S165+(-7.098949e+00)*S166+(-2.157702e+00)*S167+(-8.710406e+00)*S168+(-2.061687e+00)*S169'
.param V52_part18='V52_part17+(-1.658249e+00)*S170+1.000000e+04*S171+(-4.081872e+00)*S172+(-2.094970e+00)*S173+(-1.231578e+01)*S174+(-3.859682e+00)*S175+(-1.151100e+00)*S176+(-1.034108e+00)*S177+(-1.986998e+00)*S178+(-1.121109e+00)*S179'
.param V52_part19='V52_part18+(-7.546008e+01)*S180+(-5.220403e+00)*S181+(-2.213401e+00)*S182+(-4.887767e+00)*S183+(-8.417845e+00)*S184+(-4.862221e+00)*S185+7.936305e-01*S186+(-1.037011e+01)*S187+(-1.173093e+00)*S188+(-9.526153e+00)*S189'
.param V52_part20='V52_part19+(-8.840496e+00)*S190+(-6.763567e+01)*S191+(-6.386305e+00)*S192+(-2.527175e+00)*S193+1.663923e-01*S194+(-7.317825e+00)*S195+(-7.017440e+00)*S196+(-8.641740e-01)*S197+2.785091e+00*S198+(-1.150728e+01)*S199'
.param V52_part21='V52_part20+(-1.031658e+01)*S200+(-1.301991e+01)*S201+(-9.864798e+00)*S202+(-1.046447e+01)*S203+(-6.402183e-01)*S204+(-6.241920e+00)*S205+(-1.533937e+01)*S206+(-8.348244e+00)*S207+(-5.484285e+00)*S208+(-9.188398e+00)*S209'
.param V52_part22='V52_part21+(-7.520826e+01)*S210+(-3.440719e+00)*S211+(-2.383980e+00)*S212+(-2.222795e+01)*S213+(-1.301172e+02)*S214+(-6.053785e-01)*S215+5.384531e+00*S216+(-6.330031e+00)*S217+1.393282e+00*S218+6.697984e-01*S219'
.param V52_part23='V52_part22+1.210707e+02*S220+1.000000e+04*S221+1.099671e-02*S222+(-9.090584e+00)*S223+1.586714e+01*S224+(-4.270743e+00)*S225+(-3.628661e+00)*S226+(-1.549566e+01)*S227+(-2.520431e+01)*S228+(-7.232345e+00)*S229'
.param V52_part24='V52_part23+(-3.307646e+00)*S230+(-6.940328e+00)*S231+(-5.058326e+00)*S232+(-2.574335e-01)*S233+1.732762e+00*S234+(-4.608455e+00)*S235+(-2.921019e-01)*S236+4.014999e+01*S237+(-9.946734e-01)*S238+(-8.931188e-01)*S239'
.param V52_part25='V52_part24+(-2.869102e+02)*S240+1.665987e+03*S241+(-2.194290e+00)*S242+(-1.668493e+01)*S243+8.301115e+02*S244+(-5.620059e+00)*S245+(-2.307600e+00)*S246+(-1.783632e+00)*S247+(-5.515710e-01)*S248+2.856730e+00*S249'
.param V52_part26='V52_part25+(-1.391130e+00)*S250+(-4.120686e-01)*S251+3.969565e+00*S252+(-5.205329e+00)*S253+(-5.172175e-01)*S254+(-2.147830e+01)*S255+(-4.220987e+00)*S256+(-2.600196e+00)*S257+(-1.260879e+01)*S258+(-5.519611e+00)*S259'
.param V52_part27='V52_part26+(-3.509984e+00)*S260+(-9.408152e+00)*S261+(-1.601485e+00)*S262+(-1.822954e+00)*S263+(-5.029898e+00)*S264+(-2.050860e+01)*S265+(-1.664588e-01)*S266+(-1.556517e+00)*S267+(-2.102723e+01)*S268+1.991303e-01*S269'
.param V52_part28='V52_part27+(-4.518224e+03)*S270+(-7.119728e+00)*S271+(-6.540911e+00)*S272+(-4.303027e+01)*S273+(-4.840723e+00)*S274+(-6.870857e+00)*S275+(-2.662830e+00)*S276+3.153101e+01*S277+(-5.349527e-01)*S278+2.792693e+00*S279'
.param V52_part29='V52_part28+(-5.795086e+00)*S280+(-5.396382e-01)*S281+(-7.229468e+00)*S282+(-1.627774e+00)*S283+5.033193e+01*S284+(-3.842427e+00)*S285+3.683686e+01*S286+(-1.461205e+00)*S287+(-1.241989e+01)*S288+(-4.420837e+00)*S289'
.param V52_part30='V52_part29+(-7.328197e-01)*S290+1.532456e+00*S291+(-2.326695e+00)*S292+3.052359e+01*S293+(-6.077577e+00)*S294+(-1.979469e+00)*S295+6.909472e+03*S296+4.717442e+00*S297+(-2.323345e+02)*S298+1.726538e+03*S299'
.param V52_part31='V52_part30+(-1.232274e+01)*S300+(-1.241153e+01)*S301+(-5.499261e+00)*S302+(-4.836012e+01)*S303+(-1.174380e+01)*S304+(-4.967863e+00)*S305+(-4.364333e+00)*S306+(-2.753919e+00)*S307+(-4.402121e-01)*S308+1.594172e+00*S309'
.param V52='V52_part31+(-2.585622e+00)*S310+(-2.873612e-01)*S311+2.726347e+00*S312+(-2.072581e+00)*S313+(-3.688509e-01)*S314'
.param V53_part1='(-1.686687e+00)*S0+(-2.388621e+00)*S1+6.864785e-01*S2+(-4.709339e+00)*S3+7.196679e+00*S4+(-6.488217e+00)*S5+3.359676e+00*S6+(-3.208560e+00)*S7+3.741810e+00*S8+(-1.079620e+01)*S9'
.param V53_part2='V53_part1+(-2.997735e+00)*S10+(-2.151568e+01)*S11+2.128718e+02*S12+2.209557e+01*S13+1.108718e+00*S14+1.312399e+00*S15+3.598139e+00*S16+2.559463e+00*S17+4.869501e+00*S18+6.394490e+00*S19'
.param V53_part3='V53_part2+3.596143e+00*S20+6.348997e+00*S21+4.299759e+00*S22+2.042003e+00*S23+1.466512e+00*S24+4.187749e-01*S25+4.060768e+00*S26+2.321277e+01*S27+4.713513e+00*S28+3.907218e+00*S29'
.param V53_part4='V53_part3+(-3.774486e-02)*S30+1.348064e+00*S31+(-3.182565e-01)*S32+(-2.908018e-01)*S33+2.842685e+01*S34+(-1.941835e+00)*S35+(-3.976265e-01)*S36+(-1.490109e+00)*S37+(-1.634681e-01)*S38+(-5.962332e-01)*S39'
.param V53_part5='V53_part4+1.330851e-01*S40+(-1.882773e-01)*S41+(-5.452499e-01)*S42+1.303225e+00*S43+(-7.628153e-02)*S44+(-1.729088e+00)*S45+8.156079e+00*S46+7.001120e-01*S47+1.427699e-01*S48+(-9.662189e+00)*S49'
.param V53_part6='V53_part5+2.353952e-01*S50+4.534023e-01*S51+(-2.460035e-01)*S52+(-1.396115e-01)*S53+(-5.917574e-01)*S54+(-5.561299e-02)*S55+(-9.306066e-02)*S56+3.125618e-01*S57+(-7.274127e-02)*S58+(-4.002185e-02)*S59'
.param V53_part7='V53_part6+8.914920e-01*S60+1.017789e+01*S61+4.596502e-01*S62+2.707634e+01*S63+3.658446e+00*S64+(-6.439498e+00)*S65+6.613492e+03*S66+3.636833e+01*S67+1.237737e-01*S68+1.449077e+00*S69'
.param V53_part8='V53_part7+(-6.597305e-02)*S70+(-8.919291e-02)*S71+9.287343e+01*S72+(-3.789242e-01)*S73+7.083930e+03*S74+1.207580e-01*S75+(-1.896635e-01)*S76+2.266700e+00*S77+1.483228e+01*S78+3.200727e+00*S79'
.param V53_part9='V53_part8+(-2.712673e+01)*S80+1.117709e+02*S81+9.835643e+00*S82+1.451988e+01*S83+1.000000e+04*S84+4.687810e+00*S85+1.421441e+01*S86+1.000000e+04*S87+2.911892e+00*S88+6.607533e+02*S89'
.param V53_part10='V53_part9+(-4.708739e+00)*S90+(-8.614966e+00)*S91+(-6.263929e+01)*S92+1.482302e+01*S93+(-9.228239e+00)*S94+3.103841e+00*S95+(-2.507143e-01)*S96+1.795056e-01*S97+(-1.239473e-01)*S98+(-1.137474e-01)*S99'
.param V53_part11='V53_part10+1.195771e+01*S100+9.476734e+01*S101+(-3.742065e-01)*S102+1.664677e+01*S103+(-1.156694e-01)*S104+(-4.959301e-01)*S105+(-1.575629e+01)*S106+5.886027e-01*S107+(-7.005941e-01)*S108+(-1.510865e-01)*S109'
.param V53_part12='V53_part11+3.731418e-02*S110+(-5.728075e+02)*S111+1.162008e-01*S112+(-2.379432e+01)*S113+(-8.859154e+01)*S114+1.097545e-01*S115+3.701479e-01*S116+2.018640e-01*S117+3.250482e-01*S118+7.378321e-02*S119'
.param V53_part13='V53_part12+3.132541e-01*S120+3.063557e-01*S121+7.504231e+00*S122+2.849895e+00*S123+7.503005e+03*S124+(-1.304988e+02)*S125+(-1.312651e+01)*S126+(-2.483181e+01)*S127+(-6.323403e+01)*S128+(-2.801394e+00)*S129'
.param V53_part14='V53_part13+(-1.183035e+01)*S130+(-7.292832e+00)*S131+(-1.115831e+02)*S132+(-3.526679e+00)*S133+(-4.712451e+00)*S134+(-8.695467e-01)*S135+4.830766e+00*S136+1.016710e+00*S137+4.137348e+00*S138+1.668191e+00*S139'
.param V53_part15='V53_part14+(-2.034022e-01)*S140+1.607235e+00*S141+1.144494e+00*S142+7.704877e-01*S143+6.420079e-01*S144+7.244052e-01*S145+9.448741e-01*S146+8.093609e-01*S147+1.135138e+00*S148+(-2.003923e+00)*S149'
.param V53_part16='V53_part15+(-5.721023e+00)*S150+(-7.374229e+00)*S151+(-6.743804e-01)*S152+2.049621e+01*S153+(-1.730935e-01)*S154+(-9.265477e-01)*S155+(-4.679180e+00)*S156+(-9.117448e-02)*S157+(-1.144355e+01)*S158+(-6.714908e-01)*S159'
.param V53_part17='V53_part16+2.218462e+01*S160+(-2.093386e+01)*S161+(-1.162608e+00)*S162+(-4.452148e-02)*S163+(-1.142163e-01)*S164+(-1.089349e-01)*S165+(-5.463722e-01)*S166+3.129119e-03*S167+(-2.433337e-01)*S168+(-1.818082e-01)*S169'
.param V53_part18='V53_part17+3.145010e-02*S170+(-1.000000e+04)*S171+3.275077e-01*S172+1.971155e-01*S173+5.513481e+00*S174+4.232036e-01*S175+5.350005e-02*S176+(-2.153799e+00)*S177+1.268118e-01*S178+9.576590e-02*S179'
.param V53_part19='V53_part18+(-4.466749e+01)*S180+(-3.664002e-01)*S181+5.577224e-02*S182+1.089262e-01*S183+(-3.689517e+00)*S184+(-7.509451e-01)*S185+1.057989e-01*S186+(-3.662599e+00)*S187+1.799672e-01*S188+(-6.820845e+00)*S189'
.param V53_part20='V53_part19+(-4.504923e+00)*S190+(-1.112430e+02)*S191+2.190668e+00*S192+1.516536e-01*S193+1.343633e-01*S194+6.575385e-01*S195+(-2.477334e+00)*S196+8.637958e-01*S197+(-1.443199e+02)*S198+9.444172e-01*S199'
.param V53_part21='V53_part20+(-1.012452e+01)*S200+3.455925e-02*S201+(-8.128753e+00)*S202+(-6.668543e+00)*S203+2.235533e+00*S204+(-1.115077e+00)*S205+(-1.084613e+01)*S206+(-1.646157e+00)*S207+(-1.072898e+00)*S208+(-5.014664e+00)*S209'
.param V53_part22='V53_part21+(-2.683786e+00)*S210+(-1.757046e-01)*S211+(-3.647747e+00)*S212+(-8.755870e+00)*S213+(-6.545588e+01)*S214+(-3.417656e-01)*S215+(-4.365895e+00)*S216+1.055475e+00*S217+(-4.117111e-03)*S218+(-2.592516e+00)*S219'
.param V53_part23='V53_part22+3.044551e+01*S220+4.790639e+03*S221+(-2.055073e+00)*S222+2.236831e+01*S223+1.609895e+01*S224+(-2.312211e-01)*S225+(-4.842320e-02)*S226+(-4.239210e+00)*S227+(-1.548900e+01)*S228+(-7.067369e-03)*S229'
.param V53_part24='V53_part23+(-1.086808e+00)*S230+1.980627e-01*S231+(-2.131181e+00)*S232+5.346022e-03*S233+6.107554e+01*S234+(-2.292023e+00)*S235+(-4.771298e-02)*S236+1.320825e+03*S237+(-6.411077e-02)*S238+4.340101e-02*S239'
.param V53_part25='V53_part24+9.664032e+00*S240+(-4.664620e+03)*S241+(-1.283751e-01)*S242+8.749231e-01*S243+2.064751e+01*S244+(-1.594665e+00)*S245+(-2.709070e-02)*S246+2.775581e-01*S247+6.403783e-02*S248+4.746438e-01*S249'
.param V53_part26='V53_part25+(-1.013234e+00)*S250+7.499167e-02*S251+(-2.202628e+00)*S252+(-2.479899e+00)*S253+1.494596e-01*S254+1.062493e+00*S255+7.647143e-02*S256+(-6.726708e-01)*S257+(-4.851121e-01)*S258+(-1.665533e+00)*S259'
.param V53_part27='V53_part26+(-1.725347e+00)*S260+7.166731e-01*S261+(-1.147114e-01)*S262+1.301705e-01*S263+4.954419e-02*S264+(-9.088468e+00)*S265+1.275491e-01*S266+(-3.087998e-01)*S267+(-1.055781e+01)*S268+1.139150e-01*S269'
.param V53_part28='V53_part27+(-7.092090e+03)*S270+(-1.640834e+00)*S271+(-1.676687e+00)*S272+(-1.049554e+02)*S273+(-7.282314e-01)*S274+(-1.660191e+00)*S275+1.058187e+01*S276+4.060349e+00*S277+(-1.240072e-01)*S278+(-1.592297e+00)*S279'
.param V53_part29='V53_part28+(-3.377657e+00)*S280+(-1.071234e-01)*S281+(-1.315478e+00)*S282+(-1.647872e-01)*S283+5.418823e+01*S284+(-1.569819e+00)*S285+2.817149e+01*S286+1.206332e-01*S287+(-1.955498e+00)*S288+(-3.055616e-01)*S289'
.param V53_part30='V53_part29+(-9.149479e-02)*S290+(-9.656609e-02)*S291+(-1.616645e-01)*S292+1.020746e+01*S293+(-4.318723e+00)*S294+(-1.815065e-01)*S295+1.000000e+04*S296+(-1.946089e+00)*S297+(-8.651741e+01)*S298+1.000000e+04*S299'
.param V53_part31='V53_part30+(-4.268606e-01)*S300+(-6.067856e+00)*S301+(-2.021195e+00)*S302+1.611194e+00*S303+(-3.524574e+00)*S304+(-3.077850e+00)*S305+1.775262e+00*S306+9.530674e-02*S307+1.345910e-01*S308+(-7.372107e-01)*S309'
.param V53='V53_part31+1.658816e-01*S310+2.164306e-01*S311+(-6.297923e-01)*S312+2.310455e-01*S313+3.186684e-01*S314'
.param V54_part1='(-2.172668e-02)*S0+(-1.561014e-02)*S1+(-3.676842e-01)*S2+(-7.192647e-02)*S3+4.133686e-01*S4+7.849821e-01*S5+7.191960e-02*S6+(-2.960816e-01)*S7+3.546156e+00*S8+(-1.265097e-02)*S9'
.param V54_part2='V54_part1+5.145742e-05*S10+(-2.460040e-01)*S11+1.001702e+01*S12+2.192641e-01*S13+(-1.717228e-05)*S14+5.343675e-03*S15+5.186504e-02*S16+(-4.058706e-02)*S17+(-2.357006e-01)*S18+4.602420e-02*S19'
.param V54_part3='V54_part2+(-3.743149e-03)*S20+(-9.312489e-02)*S21+(-5.884758e-02)*S22+8.112503e-03*S23+(-1.257450e-01)*S24+(-1.768097e-01)*S25+(-3.300305e-02)*S26+(-1.065961e-01)*S27+(-1.134170e-01)*S28+(-6.550239e-02)*S29'
.param V54_part4='V54_part3+1.317639e-01*S30+2.217041e-01*S31+8.120849e-02*S32+2.635934e-01*S33+(-1.262408e+03)*S34+(-4.185418e-02)*S35+6.813111e-02*S36+(-1.083561e-01)*S37+(-6.068872e-02)*S38+(-4.830727e-03)*S39'
.param V54_part5='V54_part4+6.574606e-02*S40+(-7.794279e-02)*S41+(-5.512960e-02)*S42+(-5.368864e+01)*S43+1.947550e-01*S44+1.417578e+00*S45+1.358569e+01*S46+(-3.011464e+00)*S47+8.185756e-01*S48+(-1.894659e-01)*S49'
.param V54_part6='V54_part5+9.303621e-01*S50+3.619560e-01*S51+(-8.293283e-01)*S52+(-7.682951e-02)*S53+8.670958e-01*S54+(-8.490157e-01)*S55+(-6.078318e-02)*S56+4.323967e-01*S57+(-9.276352e-02)*S58+(-5.144051e-02)*S59'
.param V54_part7='V54_part6+8.443785e-01*S60+(-3.910489e-01)*S61+(-2.250700e-01)*S62+(-4.778617e+00)*S63+(-8.100181e-01)*S64+(-1.763690e-01)*S65+1.133656e+02*S66+(-1.308922e+00)*S67+(-6.284063e-02)*S68+5.775356e-02*S69'
.param V54_part8='V54_part7+(-2.471878e-01)*S70+(-8.568083e-02)*S71+(-1.376617e+00)*S72+(-1.075075e-01)*S73+5.508127e+00*S74+(-4.039043e-02)*S75+(-1.369122e-01)*S76+8.160100e-02*S77+(-5.151280e+01)*S78+3.369931e-02*S79'
.param V54_part9='V54_part8+1.029412e-01*S80+(-6.661108e-01)*S81+(-9.583261e-03)*S82+(-2.162778e-01)*S83+(-3.057072e-01)*S84+2.724634e-02*S85+(-2.031857e-01)*S86+1.541433e-01*S87+1.219924e-02*S88+(-9.113540e-02)*S89'
.param V54_part10='V54_part9+(-6.619042e-02)*S90+(-7.032949e-02)*S91+1.856292e-01*S92+5.708924e+03*S93+1.000000e+04*S94+1.000000e+04*S95+3.952872e+00*S96+6.007985e+00*S97+(-1.265496e-01)*S98+1.295186e+00*S99'
.param V54_part11='V54_part10+1.000000e+04*S100+2.013532e+03*S101+(-4.091661e+00)*S102+1.000000e+04*S103+(-6.064262e-02)*S104+(-1.464393e+00)*S105+(-1.651526e+00)*S106+(-1.599355e-04)*S107+(-2.099289e+00)*S108+(-1.621332e+00)*S109'
.param V54_part12='V54_part11+(-1.300070e-01)*S110+(-2.405924e-03)*S111+(-2.495998e-01)*S112+(-5.205535e+00)*S113+(-5.255913e+00)*S114+(-1.381270e-01)*S115+(-6.088896e-02)*S116+(-3.695085e-01)*S117+(-2.494342e-01)*S118+(-2.264377e-01)*S119'
.param V54_part13='V54_part12+(-4.512777e-01)*S120+(-6.316962e-01)*S121+(-1.094600e+00)*S122+(-2.489936e-01)*S123+2.572720e+00*S124+(-6.427929e+00)*S125+(-2.145723e+00)*S126+(-1.079940e+00)*S127+(-3.873335e+00)*S128+(-1.215723e+00)*S129'
.param V54_part14='V54_part13+(-1.162174e+00)*S130+(-1.177972e+00)*S131+(-1.576213e+00)*S132+(-6.819892e-01)*S133+(-6.704477e-01)*S134+(-5.719204e+00)*S135+(-5.439940e-01)*S136+(-1.802916e-01)*S137+(-8.825721e-01)*S138+(-1.448834e-01)*S139'
.param V54_part15='V54_part14+(-1.494028e-01)*S140+(-6.953570e-01)*S141+(-3.067569e-01)*S142+(-1.625985e-02)*S143+(-2.508002e-01)*S144+(-2.578071e-01)*S145+(-1.611438e-01)*S146+(-1.998541e-01)*S147+(-2.018893e-01)*S148+(-3.051018e-01)*S149'
.param V54_part16='V54_part15+3.530754e-01*S150+5.271281e-01*S151+7.087885e-01*S152+1.000000e+04*S153+7.498289e-02*S154+(-3.652165e-01)*S155+(-1.749931e+00)*S156+(-2.925425e-01)*S157+(-5.558072e+00)*S158+(-9.985270e-01)*S159'
.param V54_part17='V54_part16+(-2.709959e+00)*S160+(-9.380377e-01)*S161+3.237915e+00*S162+(-2.580772e-01)*S163+(-2.491435e-01)*S164+(-1.406141e-01)*S165+4.715522e-01*S166+(-1.529355e-01)*S167+(-1.112199e+00)*S168+(-8.432980e-01)*S169'
.param V54_part18='V54_part17+(-1.655208e-01)*S170+1.000000e+04*S171+(-2.497458e-01)*S172+(-7.252218e-02)*S173+(-1.056965e+01)*S174+(-1.098696e-01)*S175+(-1.893668e-01)*S176+1.976754e+00*S177+5.043212e-01*S178+(-2.746417e-03)*S179'
.param V54_part19='V54_part18+(-5.228250e+00)*S180+(-9.916732e-02)*S181+(-1.525408e-01)*S182+(-1.122191e+00)*S183+(-6.515551e-01)*S184+(-5.399720e-01)*S185+2.660133e-01*S186+(-9.607799e-01)*S187+1.363722e-01*S188+(-1.189968e+00)*S189'
.param V54_part20='V54_part19+(-6.239533e-01)*S190+(-5.069498e+00)*S191+(-5.612024e-01)*S192+3.008830e-01*S193+2.280635e-01*S194+(-7.909154e-01)*S195+(-3.302821e+00)*S196+(-1.789753e-01)*S197+1.399446e+01*S198+(-1.064444e+00)*S199'
.param V54_part21='V54_part20+(-9.245821e-01)*S200+(-2.706323e+00)*S201+(-1.061027e+00)*S202+(-1.181687e+00)*S203+(-7.469045e-01)*S204+(-5.258393e-01)*S205+(-1.673119e+00)*S206+2.665471e+00*S207+(-4.344200e-01)*S208+(-8.665371e-01)*S209'
.param V54_part22='V54_part21+2.445132e+03*S210+(-3.024193e-01)*S211+(-2.971723e+01)*S212+(-1.509820e+00)*S213+(-9.151159e+01)*S214+(-1.728594e+00)*S215+3.831657e+00*S216+(-3.082559e+00)*S217+(-7.995900e-01)*S218+1.453801e+00*S219'
.param V54_part23='V54_part22+(-1.927915e+01)*S220+(-3.175115e+03)*S221+2.763357e+00*S222+(-1.870160e+01)*S223+(-2.967741e+01)*S224+(-9.000543e-01)*S225+(-7.375521e-01)*S226+(-2.135360e+00)*S227+(-3.234859e+00)*S228+(-6.102244e-01)*S229'
.param V54_part24='V54_part23+(-5.963255e-01)*S230+(-4.671568e-01)*S231+(-8.199193e-01)*S232+2.329277e-01*S233+(-1.537176e+01)*S234+(-7.562488e-01)*S235+1.390303e-01*S236+(-5.142277e+01)*S237+1.201210e-01*S238+(-6.741345e-02)*S239'
.param V54_part25='V54_part24+1.013479e+03*S240+(-7.664766e+01)*S241+(-9.229286e-01)*S242+(-5.720172e-02)*S243+1.276049e+02*S244+(-6.811351e-01)*S245+(-3.110114e-01)*S246+(-5.777659e-02)*S247+9.182750e-02*S248+2.163080e+00*S249'
.param V54_part26='V54_part25+(-1.261745e-01)*S250+2.830343e-02*S251+3.088405e+00*S252+(-7.660577e-01)*S253+(-2.778986e-02)*S254+(-9.176631e-01)*S255+(-3.834514e-01)*S256+(-5.611194e-01)*S257+(-1.934979e+00)*S258+(-7.667555e-01)*S259'
.param V54_part27='V54_part26+(-6.790684e-01)*S260+1.039544e+00*S261+9.005399e-01*S262+(-1.337997e-01)*S263+(-8.772387e-01)*S264+(-4.311772e+00)*S265+8.503046e-02*S266+1.414579e+00*S267+(-7.137136e+00)*S268+9.507927e-02*S269'
.param V54_part28='V54_part27+1.329930e+02*S270+(-6.249601e-01)*S271+(-1.341729e+00)*S272+8.871923e+00*S273+(-5.213087e-01)*S274+(-1.499017e+00)*S275+(-8.385210e+00)*S276+(-1.643559e+00)*S277+4.774195e-02*S278+2.680059e+00*S279'
.param V54_part29='V54_part28+(-9.817554e-01)*S280+(-5.085372e-02)*S281+(-8.920626e-01)*S282+(-1.047213e-01)*S283+(-1.485367e+01)*S284+4.648906e-01*S285+(-6.694097e+01)*S286+2.346760e-03*S287+(-5.595989e-01)*S288+(-5.558103e-01)*S289'
.param V54_part30='V54_part29+4.802370e-02*S290+(-8.177309e-02)*S291+2.660603e-01*S292+2.044930e+00*S293+7.126184e-01*S294+2.083870e-02*S295+1.000000e+04*S296+2.529178e+00*S297+8.751252e+01*S298+2.498798e+03*S299'
.param V54_part31='V54_part30+(-7.714522e+00)*S300+(-1.167149e+00)*S301+(-8.950676e-01)*S302+(-9.007803e-01)*S303+(-3.154104e+00)*S304+(-8.351235e-01)*S305+2.227806e+00*S306+(-2.347779e-02)*S307+(-5.964897e-02)*S308+2.171234e+00*S309'
.param V54='V54_part31+(-1.972272e-01)*S310+(-1.555662e-01)*S311+2.293787e+00*S312+(-1.737073e-01)*S313+(-1.918025e-01)*S314'
.param V55_part1='8.831877e+00*S0+1.864716e+01*S1+1.719859e+01*S2+0.000000e+00*S3+6.999875e+00*S4+0.000000e+00*S5+7.210211e+00*S6+1.475285e+01*S7+1.139603e+01*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+0.000000e+00*S10+0.000000e+00*S11+1.315272e+00*S12+0.000000e+00*S13+2.775763e+01*S14+0.000000e+00*S15+1.165792e+01*S16+9.018019e+00*S17+0.000000e+00*S18+8.429580e+00*S19'
.param V55_part3='V55_part2+1.040006e+01*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.611605e+01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V55_part4='V55_part3+1.449634e+01*S30+1.860832e+00*S31+(-1.853741e+01)*S32+1.379404e+01*S33+3.851348e-02*S34+(-4.735709e+00)*S35+1.494253e+01*S36+0.000000e+00*S37+2.050989e+01*S38+2.001544e+01*S39'
.param V55_part5='V55_part4+6.974913e+00*S40+3.024215e+00*S41+2.671673e+01*S42+1.843245e+01*S43+2.309709e+01*S44+0.000000e+00*S45+1.491956e+01*S46+0.000000e+00*S47+1.216206e+01*S48+9.425961e+00*S49'
.param V55_part6='V55_part5+(-1.469900e+00)*S50+1.475178e+01*S51+2.095731e+01*S52+6.016504e+00*S53+1.644387e+01*S54+1.592130e+01*S55+3.637560e+00*S56+1.016618e+01*S57+1.492269e+00*S58+7.993103e+00*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+0.000000e+00*S61+8.867850e+00*S62+1.466746e+01*S63+1.847758e+01*S64+0.000000e+00*S65+1.100431e+01*S66+0.000000e+00*S67+(-2.550089e+00)*S68+2.163424e+01*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+(-2.948065e+00)*S71+0.000000e+00*S72+9.876852e+00*S73+1.961821e+01*S74+9.150597e+00*S75+1.769987e+01*S76+9.231266e+00*S77+0.000000e+00*S78+2.638703e+01*S79'
.param V55_part9='V55_part8+0.000000e+00*S80+1.832111e+01*S81+0.000000e+00*S82+0.000000e+00*S83+4.154669e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V55_part10='V55_part9+8.868942e+00*S90+5.248672e+00*S91+2.756596e-01*S92+1.067775e+01*S93+6.184169e+00*S94+(-7.697769e+00)*S95+1.054419e+01*S96+3.334291e+00*S97+9.426379e+00*S98+8.409335e+00*S99'
.param V55_part11='V55_part10+(-5.291011e+00)*S100+(-2.820233e+01)*S101+1.259833e+01*S102+8.493252e-01*S103+(-2.000553e+01)*S104+1.616540e+01*S105+1.200100e+01*S106+0.000000e+00*S107+1.114364e+01*S108+4.779542e+00*S109'
.param V55_part12='V55_part11+1.233974e+01*S110+1.652116e-01*S111+0.000000e+00*S112+(-1.759110e+01)*S113+5.502644e+00*S114+1.512845e+01*S115+0.000000e+00*S116+(-1.233587e-01)*S117+2.184112e+01*S118+7.966826e+01*S119'
.param V55_part13='V55_part12+1.085873e+01*S120+0.000000e+00*S121+(-4.651691e-01)*S122+1.173669e+01*S123+2.136867e+00*S124+(-4.656672e+00)*S125+3.076097e+00*S126+6.764509e+00*S127+6.354322e+01*S128+9.910712e+00*S129'
.param V55_part14='V55_part13+8.781131e-01*S130+(-1.100112e+01)*S131+3.307092e+00*S132+3.833923e+01*S133+3.420850e-01*S134+9.625299e+00*S135+1.890414e+01*S136+6.433238e+00*S137+1.555518e+01*S138+1.118105e+01*S139'
.param V55_part15='V55_part14+0.000000e+00*S140+1.256232e+01*S141+4.005623e-01*S142+2.519645e+00*S143+1.170535e+01*S144+5.379225e+00*S145+5.875912e+00*S146+3.181019e+01*S147+(-5.677966e+00)*S148+(-4.020532e-02)*S149'
.param V55_part16='V55_part15+2.560927e+00*S150+0.000000e+00*S151+(-6.249813e+00)*S152+9.299531e+00*S153+9.308117e+00*S154+2.783213e+01*S155+1.950435e+01*S156+2.733689e+01*S157+(-1.646386e+01)*S158+1.823254e+01*S159'
.param V55_part17='V55_part16+5.287489e-01*S160+(-1.575088e+01)*S161+9.015874e+00*S162+4.916939e+01*S163+6.207181e+01*S164+1.652370e+01*S165+0.000000e+00*S166+1.324178e+01*S167+5.714205e+00*S168+1.372838e+01*S169'
.param V55_part18='V55_part17+6.413092e+01*S170+6.216168e+00*S171+4.391925e+01*S172+3.952132e+01*S173+(-4.350193e+00)*S174+(-5.240524e+00)*S175+9.393638e+01*S176+1.400589e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V55_part19='V55_part18+1.256586e+01*S180+9.279106e+00*S181+2.189138e+01*S182+6.870142e+00*S183+2.433184e+00*S184+1.078272e+01*S185+1.775062e+01*S186+1.255496e+01*S187+0.000000e+00*S188+(-2.617593e+01)*S189'
.param V55_part20='V55_part19+3.249194e+01*S190+(-1.078871e+01)*S191+(-1.416605e+01)*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+4.064624e+00*S196+0.000000e+00*S197+1.919072e+01*S198+1.011482e+01*S199'
.param V55_part21='V55_part20+(-4.907460e-01)*S200+4.152322e+00*S201+6.220142e+00*S202+2.001290e+01*S203+7.648180e+00*S204+7.158014e+00*S205+4.456522e+01*S206+0.000000e+00*S207+4.720917e+00*S208+5.144833e+01*S209'
.param V55_part22='V55_part21+1.129563e+01*S210+8.075344e+00*S211+(-3.047755e+00)*S212+4.835094e+00*S213+(-1.805382e+01)*S214+1.060946e+01*S215+0.000000e+00*S216+7.394116e+00*S217+2.585594e+01*S218+1.791142e+01*S219'
.param V55_part23='V55_part22+(-1.430507e+01)*S220+1.961805e+01*S221+1.478550e+01*S222+1.677581e+01*S223+(-6.487529e+01)*S224+1.177015e+01*S225+1.494459e+01*S226+(-1.348677e+01)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V55_part24='V55_part23+1.870258e+01*S230+8.812136e+00*S231+2.909697e+01*S232+0.000000e+00*S233+0.000000e+00*S234+3.678593e+01*S235+0.000000e+00*S236+(-3.495226e+01)*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V55_part25='V55_part24+1.235015e+01*S240+(-4.874875e+00)*S241+5.954102e+00*S242+0.000000e+00*S243+6.862985e+00*S244+4.316682e+01*S245+2.666626e+01*S246+0.000000e+00*S247+0.000000e+00*S248+2.236921e+00*S249'
.param V55_part26='V55_part25+(-2.402793e-01)*S250+0.000000e+00*S251+0.000000e+00*S252+4.377497e-03*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+(-9.102685e+00)*S257+1.022110e-01*S258+5.484951e+00*S259'
.param V55_part27='V55_part26+5.484764e+00*S260+8.169939e+00*S261+2.841678e+01*S262+1.870274e+00*S263+0.000000e+00*S264+5.065355e+01*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V55_part28='V55_part27+3.158128e+00*S270+7.175485e-01*S271+(-2.933553e+01)*S272+0.000000e+00*S273+1.838419e+01*S274+(-1.522458e+00)*S275+(-1.734740e+01)*S276+(-1.289575e+00)*S277+0.000000e+00*S278+1.217165e+01*S279'
.param V55_part29='V55_part28+3.233267e+01*S280+0.000000e+00*S281+(-2.046257e+01)*S282+0.000000e+00*S283+4.614678e+00*S284+1.004102e+01*S285+3.406461e+00*S286+0.000000e+00*S287+(-2.004155e+01)*S288+(-2.067457e+01)*S289'
.param V55_part30='V55_part29+0.000000e+00*S290+7.202012e+00*S291+0.000000e+00*S292+1.631889e+01*S293+1.755466e+01*S294+0.000000e+00*S295+(-2.393252e+01)*S296+0.000000e+00*S297+0.000000e+00*S298+(-2.377563e+01)*S299'
.param V55_part31='V55_part30+2.603965e-01*S300+(-1.127013e+01)*S301+5.759660e+01*S302+(-1.565583e+01)*S303+0.000000e+00*S304+5.345347e+01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V55='V55_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V56_part1='4.887100e+00*S0+(-5.638198e+00)*S1+(-1.515656e+01)*S2+0.000000e+00*S3+1.255083e+01*S4+0.000000e+00*S5+7.422706e+00*S6+(-4.012958e+00)*S7+6.056616e-01*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+0.000000e+00*S10+0.000000e+00*S11+1.743764e+00*S12+0.000000e+00*S13+(-1.436232e+01)*S14+0.000000e+00*S15+1.292213e+01*S16+2.352447e+01*S17+0.000000e+00*S18+3.325520e+00*S19'
.param V56_part3='V56_part2+5.462381e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+3.119286e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V56_part4='V56_part3+2.041526e+01*S30+3.929950e+01*S31+4.517536e+01*S32+2.774484e+01*S33+3.989006e+01*S34+3.440922e+01*S35+2.325047e+01*S36+0.000000e+00*S37+5.651815e+00*S38+1.713188e+01*S39'
.param V56_part5='V56_part4+3.195079e+00*S40+2.945218e+01*S41+1.455295e+01*S42+1.990779e+01*S43+9.973918e+00*S44+0.000000e+00*S45+5.653253e+00*S46+0.000000e+00*S47+2.092943e+01*S48+3.071062e+01*S49'
.param V56_part6='V56_part5+8.461395e-01*S50+2.418715e+01*S51+1.962536e+01*S52+4.633072e+01*S53+2.392268e+01*S54+2.283093e+01*S55+4.837334e+01*S56+2.895896e+01*S57+5.254966e+01*S58+4.476118e+01*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+0.000000e+00*S61+(-2.819619e+00)*S62+1.768685e+01*S63+(-4.528166e+00)*S64+0.000000e+00*S65+1.403059e+01*S66+0.000000e+00*S67+2.624051e+00*S68+9.896005e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+7.716769e-03*S71+0.000000e+00*S72+(-1.009505e+01)*S73+1.538422e+01*S74+6.957421e+01*S75+7.664466e+00*S76+4.980000e+01*S77+0.000000e+00*S78+1.846562e+01*S79'
.param V56_part9='V56_part8+0.000000e+00*S80+1.666327e+01*S81+0.000000e+00*S82+0.000000e+00*S83+1.082930e+01*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part10='V56_part9+7.782860e+00*S90+2.570084e+01*S91+3.418192e+01*S92+1.705769e+01*S93+2.404081e+01*S94+1.802627e+01*S95+1.792447e+01*S96+2.201067e+01*S97+1.743609e+01*S98+2.389521e+01*S99'
.param V56_part11='V56_part10+3.128663e+01*S100+5.817662e+01*S101+1.391363e+01*S102+2.634787e+01*S103+4.177597e+01*S104+4.416825e-01*S105+1.000394e+01*S106+0.000000e+00*S107+1.169395e+01*S108+2.742541e+01*S109'
.param V56_part12='V56_part11+1.714706e+01*S110+1.411639e+01*S111+0.000000e+00*S112+5.534938e+01*S113+3.392382e+01*S114+7.366546e+00*S115+0.000000e+00*S116+3.650957e+01*S117+4.155159e+00*S118+(-3.778806e+01)*S119'
.param V56_part13='V56_part12+1.489691e+01*S120+0.000000e+00*S121+6.731096e-01*S122+1.518698e+01*S123+8.047104e+00*S124+2.652698e+01*S125+(-1.392763e+00)*S126+(-9.507621e+00)*S127+(-7.181821e+01)*S128+(-5.694036e-01)*S129'
.param V56_part14='V56_part13+4.950046e-01*S130+4.568379e+00*S131+1.729188e+01*S132+(-1.636403e+01)*S133+2.710940e+00*S134+5.710721e+00*S135+(-4.087389e+00)*S136+2.028652e+01*S137+(-8.289222e+00)*S138+1.315233e+01*S139'
.param V56_part15='V56_part14+0.000000e+00*S140+8.641272e+00*S141+1.758852e+01*S142+2.176070e+01*S143+1.013810e+01*S144+1.261655e+01*S145+1.487086e+01*S146+2.883138e+01*S147+2.907110e+00*S148+4.301996e+00*S149'
.param V56_part16='V56_part15+9.960487e+00*S150+0.000000e+00*S151+1.256637e+01*S152+1.081331e+01*S153+(-1.436103e+01)*S154+(-4.994538e+00)*S155+(-1.023876e+01)*S156+(-7.998393e+00)*S157+5.146652e+01*S158+(-2.499961e+00)*S159'
.param V56_part17='V56_part16+2.973312e+01*S160+5.585145e+01*S161+1.162710e+01*S162+(-2.333222e+01)*S163+(-3.172391e+01)*S164+(-1.744534e+00)*S165+0.000000e+00*S166+6.693604e+00*S167+2.049277e+01*S168+8.108988e+00*S169'
.param V56_part18='V56_part17+(-6.134483e+01)*S170+1.249065e+01*S171+(-4.251896e+01)*S172+(-2.880920e+01)*S173+2.825135e+01*S174+2.259190e+01*S175+(-6.022188e+01)*S176+4.226179e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V56_part19='V56_part18+2.326091e+01*S180+(-2.755524e+01)*S181+(-2.696036e+00)*S182+1.859683e+01*S183+3.157066e+01*S184+1.505442e+01*S185+1.203190e+01*S186+(-9.293114e+00)*S187+0.000000e+00*S188+3.685525e+01*S189'
.param V56_part20='V56_part19+(-1.043515e+01)*S190+3.997667e+01*S191+1.066576e+01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+9.869723e+00*S196+0.000000e+00*S197+(-9.636271e+00)*S198+(-7.329432e+00)*S199'
.param V56_part21='V56_part20+2.112820e+01*S200+8.305007e-02*S201+(-4.200172e+00)*S202+(-2.572533e+01)*S203+1.029584e+01*S204+7.003065e+00*S205+(-4.424996e+01)*S206+0.000000e+00*S207+1.064020e+01*S208+(-4.702368e+01)*S209'
.param V56_part22='V56_part21+1.896643e+01*S210+8.519589e+00*S211+1.021188e+01*S212+(-7.381318e+00)*S213+5.170374e+01*S214+1.541562e+01*S215+0.000000e+00*S216+2.108873e+01*S217+7.360534e+00*S218+(-4.732452e+00)*S219'
.param V56_part23='V56_part22+3.009227e+01*S220+(-4.495691e+00)*S221+1.024625e+00*S222+(-6.913149e-01)*S223+5.830765e+01*S224+4.350726e+00*S225+2.365282e+00*S226+3.872155e+01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V56_part24='V56_part23+(-8.105043e-01)*S230+6.552594e+01*S231+3.896336e+00*S232+0.000000e+00*S233+0.000000e+00*S234+1.144080e+00*S235+0.000000e+00*S236+2.309964e+01*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V56_part25='V56_part24+(-3.390331e-01)*S240+2.002565e+01*S241+(-1.072863e+01)*S242+0.000000e+00*S243+3.404231e+01*S244+(-2.213225e+01)*S245+1.745801e+01*S246+0.000000e+00*S247+0.000000e+00*S248+(-1.134448e-01)*S249'
.param V56_part26='V56_part25+1.155394e+01*S250+0.000000e+00*S251+0.000000e+00*S252+1.203116e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+2.239497e+01*S257+2.465462e+01*S258+2.029746e+01*S259'
.param V56_part27='V56_part26+(-1.782763e+01)*S260+3.463507e+00*S261+(-1.910831e+01)*S262+1.529305e+01*S263+0.000000e+00*S264+(-3.650380e+00)*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V56_part28='V56_part27+1.235884e+01*S270+4.299052e+01*S271+3.122033e+01*S272+0.000000e+00*S273+6.145303e+00*S274+7.252008e+00*S275+2.421361e+01*S276+3.324983e+01*S277+0.000000e+00*S278+(-6.293075e+00)*S279'
.param V56_part29='V56_part28+(-8.789094e+00)*S280+0.000000e+00*S281+7.899825e-02*S282+0.000000e+00*S283+2.352757e+01*S284+(-5.787670e+00)*S285+3.610080e+01*S286+0.000000e+00*S287+4.769041e+01*S288+3.366271e+01*S289'
.param V56_part30='V56_part29+0.000000e+00*S290+9.385041e-01*S291+0.000000e+00*S292+8.890762e+00*S293+3.991412e-01*S294+0.000000e+00*S295+5.602000e+01*S296+0.000000e+00*S297+0.000000e+00*S298+2.298003e+01*S299'
.param V56_part31='V56_part30+1.607461e+01*S300+2.582114e+01*S301+(-4.262574e+01)*S302+2.330452e+01*S303+0.000000e+00*S304+(-3.546349e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V56='V56_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V57_part1='1.158303e+01*S0+3.273960e+00*S1+(-3.391597e+00)*S2+0.000000e+00*S3+(-3.575075e+00)*S4+0.000000e+00*S5+7.572774e-02*S6+(-1.055527e+01)*S7+(-8.179864e+00)*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+0.000000e+00*S10+0.000000e+00*S11+1.996855e+00*S12+0.000000e+00*S13+(-8.254745e+00)*S14+0.000000e+00*S15+7.720238e-01*S16+3.203589e+00*S17+0.000000e+00*S18+(-2.069463e+00)*S19'
.param V57_part3='V57_part2+7.675771e-01*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-1.102914e+01)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V57_part4='V57_part3+(-1.955110e+00)*S30+1.572575e+01*S31+2.166879e+01*S32+2.982733e+00*S33+2.659720e+01*S34+3.369601e+01*S35+1.761347e+01*S36+0.000000e+00*S37+1.148798e+01*S38+2.648457e+01*S39'
.param V57_part5='V57_part4+2.299618e+01*S40+1.411142e+01*S41+2.340075e+01*S42+4.035626e+01*S43+1.457867e+01*S44+0.000000e+00*S45+(-7.960654e+00)*S46+0.000000e+00*S47+1.356192e+01*S48+2.599537e+01*S49'
.param V57_part6='V57_part5+4.984435e+00*S50+1.139821e+01*S51+1.115367e+01*S52+1.956144e+01*S53+(-3.780712e+00)*S54+1.404519e+01*S55+1.824809e+01*S56+4.226061e+00*S57+2.494637e+01*S58+1.353064e+01*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+0.000000e+00*S61+1.911980e-01*S62+4.178105e+00*S63+(-1.859387e+00)*S64+0.000000e+00*S65+3.374156e+01*S66+0.000000e+00*S67+7.245764e+00*S68+(-1.084781e+01)*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+2.046351e+01*S71+0.000000e+00*S72+1.935324e+01*S73+2.584291e+01*S74+1.667836e+01*S75+1.225588e+01*S76+9.878349e+00*S77+0.000000e+00*S78+6.651924e+00*S79'
.param V57_part9='V57_part8+0.000000e+00*S80+(-2.721123e+00)*S81+0.000000e+00*S82+0.000000e+00*S83+8.765124e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part10='V57_part9+2.051592e+01*S90+2.709878e+01*S91+2.562816e+01*S92+2.801047e+01*S93+2.448500e+01*S94+4.244511e+01*S95+2.307516e+01*S96+3.095370e+01*S97+1.387379e+01*S98+2.255829e+01*S99'
.param V57_part11='V57_part10+4.228723e+01*S100+3.475620e+01*S101+(-1.256206e+01)*S102+3.217650e+01*S103+1.269698e+01*S104+1.728417e+01*S105+1.545764e+01*S106+0.000000e+00*S107+1.433024e+01*S108+2.042229e+01*S109'
.param V57_part12='V57_part11+1.371996e+01*S110+4.365096e+01*S111+0.000000e+00*S112+3.116147e+01*S113+2.234990e+01*S114+1.309071e+01*S115+0.000000e+00*S116+1.886554e+00*S117+(-1.109725e+01)*S118+(-2.805033e+01)*S119'
.param V57_part13='V57_part12+1.224936e+01*S120+0.000000e+00*S121+1.392197e+01*S122+2.034440e+01*S123+2.795416e+01*S124+3.074190e+01*S125+3.422839e+01*S126+1.744842e+01*S127+2.121982e+01*S128+4.686077e+01*S129'
.param V57_part14='V57_part13+3.529278e+01*S130+5.778710e+01*S131+3.061308e+01*S132+1.112438e-01*S133+5.031787e+01*S134+1.657920e+01*S135+(-5.123892e+00)*S136+9.064424e+00*S137+2.725635e+00*S138+4.187114e+00*S139'
.param V57_part15='V57_part14+0.000000e+00*S140+9.770964e+00*S141+1.497646e+01*S142+1.104072e+01*S143+1.444466e+01*S144+1.265518e+01*S145+2.800379e+00*S146+1.449016e+01*S147+3.446258e+01*S148+1.945440e+01*S149'
.param V57_part16='V57_part15+1.859859e+01*S150+0.000000e+00*S151+4.405626e+01*S152+2.043036e+01*S153+2.692048e+01*S154+6.803980e+00*S155+4.194692e+00*S156+(-4.651686e+00)*S157+4.136691e+01*S158+4.393779e+00*S159'
.param V57_part17='V57_part16+3.563062e+01*S160+2.988133e+01*S161+(-1.312449e+01)*S162+(-3.320847e+01)*S163+(-2.249093e+01)*S164+(-6.207933e-01)*S165+0.000000e+00*S166+1.868833e+01*S167+1.388201e+01*S168+1.017190e+01*S169'
.param V57_part18='V57_part17+(-1.154717e+01)*S170+5.202459e+00*S171+(-1.113835e+01)*S172+(-4.881884e+00)*S173+3.712120e+01*S174+1.062760e+01*S175+(-3.712690e+01)*S176+(-4.168964e+00)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V57_part19='V57_part18+3.274606e+01*S180+2.938405e+01*S181+3.732611e+01*S182+2.254311e+01*S183+3.014104e+01*S184+3.777885e+01*S185+(-1.863130e+01)*S186+3.499216e+01*S187+0.000000e+00*S188+8.309935e+01*S189'
.param V57_part20='V57_part19+1.540814e+01*S190+3.638853e+01*S191+4.550731e+01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+1.435637e+01*S196+0.000000e+00*S197+2.411679e+00*S198+1.107879e+01*S199'
.param V57_part21='V57_part20+1.713194e+01*S200+3.042292e+01*S201+1.993414e+01*S202+1.701978e+01*S203+(-1.035114e+01)*S204+1.972274e+01*S205+1.448626e+01*S206+0.000000e+00*S207+1.968183e+01*S208+2.195724e+01*S209'
.param V57_part22='V57_part21+1.557894e+01*S210+2.267148e+01*S211+4.692504e+01*S212+9.575631e+00*S213+6.579361e+01*S214+2.749924e+01*S215+0.000000e+00*S216+3.294594e+01*S217+1.440620e+01*S218+5.761293e+00*S219'
.param V57_part23='V57_part22+4.802355e+01*S220+5.098447e+01*S221+(-4.781240e+00)*S222+6.034023e+01*S223+7.840575e+01*S224+1.261881e+01*S225+9.392472e+00*S226+5.888790e+01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V57_part24='V57_part23+4.096817e+01*S230+2.913888e+01*S231+2.872664e+00*S232+0.000000e+00*S233+0.000000e+00*S234+(-3.598740e+00)*S235+0.000000e+00*S236+1.268226e+02*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V57_part25='V57_part24+4.057896e+01*S240+5.348175e+01*S241+5.712158e+01*S242+0.000000e+00*S243+3.037799e+01*S244+2.885276e+01*S245+(-1.100699e+01)*S246+0.000000e+00*S247+0.000000e+00*S248+4.779220e-01*S249'
.param V57_part26='V57_part25+4.444873e+01*S250+0.000000e+00*S251+0.000000e+00*S252+4.524033e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+3.786787e+01*S257+2.220867e+01*S258+2.364799e+01*S259'
.param V57_part27='V57_part26+3.965942e+01*S260+1.979950e+01*S261+(-4.286336e+00)*S262+1.003686e+01*S263+0.000000e+00*S264+(-1.939937e+01)*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V57_part28='V57_part27+1.264132e+01*S270+3.814264e+01*S271+7.916199e+01*S272+0.000000e+00*S273+1.488440e+01*S274+5.609260e+01*S275+7.090572e+01*S276+1.065094e+01*S277+0.000000e+00*S278+1.325647e+00*S279'
.param V57_part29='V57_part28+3.081390e+00*S280+0.000000e+00*S281+1.554125e+02*S282+0.000000e+00*S283+5.565157e+01*S284+8.345837e+00*S285+4.191841e+01*S286+0.000000e+00*S287+6.460638e+01*S288+4.529150e+01*S289'
.param V57_part30='V57_part29+0.000000e+00*S290+9.109314e+00*S291+0.000000e+00*S292+4.960209e+01*S293+5.366777e+00*S294+0.000000e+00*S295+6.197903e+01*S296+0.000000e+00*S297+0.000000e+00*S298+6.436075e+01*S299'
.param V57_part31='V57_part30+7.401307e+00*S300+2.560188e+01*S301+(-9.885746e-01)*S302+7.025752e+01*S303+0.000000e+00*S304+(-4.862496e-01)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V57='V57_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V58_part1='5.740320e+00*S0+6.295799e+00*S1+(-5.680365e+00)*S2+0.000000e+00*S3+(-7.466078e+00)*S4+0.000000e+00*S5+(-4.446822e+00)*S6+(-5.753478e+00)*S7+(-2.390770e+00)*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+0.000000e+00*S10+0.000000e+00*S11+(-2.844318e+00)*S12+0.000000e+00*S13+(-5.790395e+00)*S14+0.000000e+00*S15+(-9.571944e+00)*S16+(-8.500394e+00)*S17+0.000000e+00*S18+(-7.010983e+00)*S19'
.param V58_part3='V58_part2+(-7.622230e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-6.175991e+00)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V58_part4='V58_part3+(-6.949051e-01)*S30+(-1.119914e+00)*S31+(-1.149541e+00)*S32+(-4.008745e+00)*S33+(-4.181258e+00)*S34+7.503791e+00*S35+(-5.899416e+00)*S36+0.000000e+00*S37+(-3.112677e-01)*S38+(-7.324614e+00)*S39'
.param V58_part5='V58_part4+1.332855e+00*S40+(-2.263795e-01)*S41+(-9.231459e+00)*S42+(-1.207643e+01)*S43+(-3.376091e+00)*S44+0.000000e+00*S45+(-4.347775e+00)*S46+0.000000e+00*S47+(-3.422145e+00)*S48+2.710357e+00*S49'
.param V58_part6='V58_part5+1.258580e+00*S50+(-4.472777e+00)*S51+(-4.674257e+00)*S52+3.230342e+00*S53+(-2.157656e+00)*S54+(-5.584417e+00)*S55+1.947094e+00*S56+(-4.461831e+00)*S57+(-5.152252e+00)*S58+1.993242e+00*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+0.000000e+00*S61+(-1.976876e+00)*S62+(-4.249473e+00)*S63+(-5.918247e+00)*S64+0.000000e+00*S65+(-2.651519e+00)*S66+0.000000e+00*S67+9.236434e+00*S68+(-3.657363e+00)*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+7.474251e+00*S71+0.000000e+00*S72+9.327796e+00*S73+(-2.210135e+00)*S74+(-1.027510e+01)*S75+(-1.078380e+01)*S76+(-8.050639e+00)*S77+0.000000e+00*S78+(-1.738151e+01)*S79'
.param V58_part9='V58_part8+0.000000e+00*S80+(-1.904003e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+(-1.247940e+01)*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part10='V58_part9+2.181035e+00*S90+2.219034e+00*S91+3.983789e+00*S92+(-1.367995e-01)*S93+3.244732e+00*S94+(-3.636440e-01)*S95+(-1.439404e+00)*S96+(-5.618904e-01)*S97+3.283033e+00*S98+(-2.227557e+00)*S99'
.param V58_part11='V58_part10+(-3.199990e+00)*S100+5.393896e+00*S101+(-2.181928e+00)*S102+(-3.136280e-02)*S103+(-1.206952e+01)*S104+(-9.356345e-01)*S105+1.764259e+00*S106+0.000000e+00*S107+1.055667e+00*S108+6.886837e-01*S109'
.param V58_part12='V58_part11+1.706985e+00*S110+8.043046e+00*S111+0.000000e+00*S112+2.983777e+00*S113+2.412410e+00*S114+1.875644e+01*S115+0.000000e+00*S116+6.598429e+00*S117+2.212675e+00*S118+3.985742e+00*S119'
.param V58_part13='V58_part12+3.942949e-01*S120+0.000000e+00*S121+1.159529e+01*S122+1.051642e+00*S123+9.206362e+00*S124+4.965806e+00*S125+1.808817e+00*S126+7.732566e+00*S127+1.336492e-01*S128+(-5.802501e+00)*S129'
.param V58_part14='V58_part13+5.244076e-01*S130+(-3.322804e+00)*S131+3.195350e+00*S132+(-7.278897e+00)*S133+(-6.655377e+00)*S134+(-3.400113e+00)*S135+(-8.140738e+00)*S136+(-3.913861e+00)*S137+(-7.879837e+00)*S138+(-6.418515e+00)*S139'
.param V58_part15='V58_part14+0.000000e+00*S140+(-5.649610e+00)*S141+(-2.695734e-01)*S142+(-3.918454e+00)*S143+8.335551e-01*S144+3.597586e+00*S145+(-4.657419e-02)*S146+(-1.965619e+01)*S147+8.185703e-01*S148+(-4.657885e+00)*S149'
.param V58_part16='V58_part15+4.604349e+00*S150+0.000000e+00*S151+1.638705e+00*S152+2.428922e+00*S153+3.172463e+00*S154+4.830766e-02*S155+7.144260e+00*S156+3.633018e+00*S157+3.396878e+00*S158+6.739493e+00*S159'
.param V58_part17='V58_part16+6.189931e+00*S160+9.129577e+00*S161+3.738969e+00*S162+4.701586e+00*S163+1.460750e+01*S164+2.451548e+00*S165+0.000000e+00*S166+1.681717e+00*S167+1.376445e+00*S168+3.554292e+00*S169'
.param V58_part18='V58_part17+3.535416e+00*S170+1.052549e+01*S171+1.240285e+00*S172+5.040505e+00*S173+2.826036e-02*S174+5.015061e+00*S175+4.969939e+00*S176+1.056427e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V58_part19='V58_part18+(-6.466287e-01)*S180+8.777690e+00*S181+(-1.071776e+01)*S182+(-2.211685e+00)*S183+2.255787e+00*S184+7.659014e-01*S185+3.843519e+00*S186+(-8.984663e+00)*S187+0.000000e+00*S188+6.591573e+00*S189'
.param V58_part20='V58_part19+(-1.532997e+00)*S190+6.624320e+00*S191+1.803869e-01*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+3.215581e+00*S196+0.000000e+00*S197+2.485482e-01*S198+1.090079e+01*S199'
.param V58_part21='V58_part20+1.003740e+01*S200+5.344387e-02*S201+1.076756e+01*S202+2.564989e+00*S203+(-2.954366e-01)*S204+(-8.932123e+00)*S205+(-9.489743e-01)*S206+0.000000e+00*S207+(-1.208314e+01)*S208+(-2.238807e+00)*S209'
.param V58_part22='V58_part21+3.074795e+00*S210+3.266374e+00*S211+1.327044e+00*S212+1.924962e+00*S213+1.159997e+01*S214+6.161324e+00*S215+0.000000e+00*S216+1.229549e+01*S217+9.662197e+00*S218+7.936543e+00*S219'
.param V58_part23='V58_part22+1.574897e+01*S220+1.278430e+01*S221+9.790463e+00*S222+1.819261e+01*S223+2.406903e+01*S224+4.387618e+00*S225+3.141214e+00*S226+4.933566e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V58_part24='V58_part23+1.439624e+00*S230+(-9.554301e-02)*S231+1.475038e+00*S232+0.000000e+00*S233+0.000000e+00*S234+1.922242e+00*S235+0.000000e+00*S236+9.847585e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V58_part25='V58_part24+1.567722e+00*S240+1.370129e+01*S241+4.679307e+00*S242+0.000000e+00*S243+3.492428e+00*S244+1.898304e+00*S245+1.358550e+00*S246+0.000000e+00*S247+0.000000e+00*S248+9.779106e+00*S249'
.param V58_part26='V58_part25+6.302736e+00*S250+0.000000e+00*S251+0.000000e+00*S252+6.389542e+00*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+6.946954e+00*S257+4.216156e+00*S258+2.272065e+00*S259'
.param V58_part27='V58_part26+1.154220e+01*S260+7.664228e+00*S261+7.456535e+00*S262+9.266179e+00*S263+0.000000e+00*S264+(-1.868789e+00)*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V58_part28='V58_part27+7.353449e+00*S270+9.238190e-01*S271+5.709706e+00*S272+0.000000e+00*S273+6.225464e+00*S274+5.558494e+00*S275+8.009472e+00*S276+1.577314e+01*S277+0.000000e+00*S278+8.870080e+00*S279'
.param V58_part29='V58_part28+7.265181e+00*S280+0.000000e+00*S281+1.112659e-01*S282+0.000000e+00*S283+3.018811e+01*S284+4.617221e+00*S285+6.985540e+00*S286+0.000000e+00*S287+9.838699e+00*S288+1.271850e+01*S289'
.param V58_part30='V58_part29+0.000000e+00*S290+6.649069e+00*S291+0.000000e+00*S292+2.063248e+01*S293+7.990775e+00*S294+0.000000e+00*S295+2.071325e+01*S296+0.000000e+00*S297+0.000000e+00*S298+6.453284e+00*S299'
.param V58_part31='V58_part30+3.850855e+00*S300+3.401774e+00*S301+2.330992e+00*S302+(-3.451299e-01)*S303+0.000000e+00*S304+2.014687e+00*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V58='V58_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V59_part1='(-5.242723e-01)*S0+(-4.263749e-01)*S1+1.780992e-01*S2+0.000000e+00*S3+6.208141e-02*S4+0.000000e+00*S5+4.121718e-02*S6+(-4.743470e-02)*S7+(-3.585436e-02)*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+0.000000e+00*S10+0.000000e+00*S11+(-2.657095e-02)*S12+0.000000e+00*S13+1.002390e-01*S14+0.000000e+00*S15+9.142941e-02*S16+(-3.085553e-01)*S17+0.000000e+00*S18+(-1.009030e-02)*S19'
.param V59_part3='V59_part2+(-2.339533e-01)*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+4.564378e-01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V59_part4='V59_part3+(-6.071943e-02)*S30+(-7.597170e-02)*S31+(-4.707122e-01)*S32+(-2.020920e+00)*S33+(-7.538309e-01)*S34+4.611152e-02*S35+(-3.711558e+00)*S36+0.000000e+00*S37+6.654492e-01*S38+(-4.751108e+00)*S39'
.param V59_part5='V59_part4+1.008524e+00*S40+4.751052e-01*S41+(-5.342642e+00)*S42+(-4.776399e+00)*S43+(-1.575206e+00)*S44+0.000000e+00*S45+(-2.268358e+00)*S46+0.000000e+00*S47+(-3.689519e+00)*S48+5.036871e-01*S49'
.param V59_part6='V59_part5+(-4.870857e-01)*S50+(-8.720688e+00)*S51+2.569983e+00*S52+2.971614e-01*S53+(-8.071573e+00)*S54+3.238801e+00*S55+5.064768e-01*S56+(-6.218834e+00)*S57+1.438027e+00*S58+9.573545e-02*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+0.000000e+00*S61+(-3.487283e-01)*S62+(-3.686643e+00)*S63+(-2.150923e+00)*S64+0.000000e+00*S65+7.841355e+00*S66+0.000000e+00*S67+(-1.834276e-01)*S68+(-5.854653e+00)*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+3.757682e-01*S71+0.000000e+00*S72+(-1.633835e-01)*S73+(-1.648626e+01)*S74+(-1.521119e-01)*S75+2.552415e+00*S76+3.889455e-01*S77+0.000000e+00*S78+(-1.814678e-03)*S79'
.param V59_part9='V59_part8+0.000000e+00*S80+3.136071e+00*S81+0.000000e+00*S82+0.000000e+00*S83+(-1.151023e-01)*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part10='V59_part9+(-3.008037e+00)*S90+7.263100e-01*S91+1.001472e+00*S92+4.340323e-01*S93+7.271699e-01*S94+(-1.260771e-02)*S95+5.003529e-01*S96+2.665827e-01*S97+9.483189e-01*S98+3.442492e-01*S99'
.param V59_part11='V59_part10+1.015974e+00*S100+2.130407e+00*S101+(-7.064535e-02)*S102+2.166856e-01*S103+(-3.035871e+00)*S104+1.792120e+00*S105+2.508512e+00*S106+0.000000e+00*S107+3.780284e+00*S108+3.349792e+00*S109'
.param V59_part12='V59_part11+9.821928e-01*S110+(-3.319815e+00)*S111+0.000000e+00*S112+2.128269e+00*S113+(-5.228049e+00)*S114+(-9.637634e-01)*S115+0.000000e+00*S116+1.060643e+01*S117+(-3.448665e-01)*S118+1.103746e-01*S119'
.param V59_part13='V59_part12+(-2.192436e+00)*S120+0.000000e+00*S121+2.639062e-02*S122+(-2.230051e+00)*S123+1.556516e+00*S124+8.916757e-01*S125+(-5.222060e-02)*S126+(-1.558125e-01)*S127+(-7.523946e+00)*S128+2.353615e-01*S129'
.param V59_part14='V59_part13+(-5.488437e-01)*S130+(-1.492844e+00)*S131+6.477814e+00*S132+(-1.567423e+00)*S133+(-1.559396e+00)*S134+6.283136e-01*S135+6.406307e-01*S136+1.946573e+00*S137+9.580867e-01*S138+1.314783e+00*S139'
.param V59_part15='V59_part14+0.000000e+00*S140+(-1.184094e+00)*S141+2.077490e+00*S142+1.024453e+00*S143+1.198735e+00*S144+1.619423e+00*S145+4.482061e-01*S146+8.740464e-01*S147+(-2.326466e-01)*S148+1.675495e-01*S149'
.param V59_part16='V59_part15+5.130515e-01*S150+0.000000e+00*S151+1.898742e-01*S152+1.502163e+00*S153+1.066470e+00*S154+2.033299e-01*S155+(-7.375392e+00)*S156+(-2.741316e-01)*S157+2.726882e+00*S158+(-3.178558e+00)*S159'
.param V59_part17='V59_part16+1.088786e+00*S160+1.535816e+00*S161+(-3.384487e+00)*S162+(-2.629795e+00)*S163+(-3.378439e+00)*S164+1.236059e+00*S165+0.000000e+00*S166+1.117597e+00*S167+4.918627e+00*S168+5.459087e-01*S169'
.param V59_part18='V59_part17+(-3.258707e+00)*S170+(-4.025759e+00)*S171+(-2.638678e+00)*S172+(-3.289898e+00)*S173+6.349727e+00*S174+1.391648e-03*S175+(-4.832768e+00)*S176+(-7.183051e+00)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V59_part19='V59_part18+1.882828e+00*S180+(-3.128273e-01)*S181+1.349590e+00*S182+8.044934e+00*S183+2.239467e+00*S184+(-1.733105e+00)*S185+(-6.728281e+00)*S186+(-2.664981e-01)*S187+0.000000e+00*S188+(-4.139911e+00)*S189'
.param V59_part20='V59_part19+(-6.700387e+00)*S190+3.184416e+00*S191+1.879370e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+3.468829e+00*S196+0.000000e+00*S197+(-3.098193e-01)*S198+(-4.049717e-01)*S199'
.param V59_part21='V59_part20+1.333864e+00*S200+(-1.524700e+00)*S201+8.347946e-01*S202+(-2.143193e+00)*S203+(-5.646988e-01)*S204+8.872256e-01*S205+(-3.614034e+00)*S206+0.000000e+00*S207+6.837891e-01*S208+(-2.229890e+00)*S209'
.param V59_part22='V59_part21+9.341459e-01*S210+9.765031e-01*S211+4.215649e-01*S212+(-9.087521e-01)*S213+3.160275e+00*S214+8.841263e-01*S215+0.000000e+00*S216+(-2.025856e+00)*S217+3.291455e-01*S218+(-8.007095e+00)*S219'
.param V59_part23='V59_part22+2.369681e+00*S220+(-7.012999e+00)*S221+(-5.914355e+00)*S222+(-3.901332e+00)*S223+(-1.465836e+00)*S224+(-7.479355e-01)*S225+(-7.353279e-01)*S226+2.580362e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V59_part24='V59_part23+(-3.919055e+00)*S230+8.086807e+00*S231+(-5.297820e+00)*S232+0.000000e+00*S233+0.000000e+00*S234+(-7.327916e+00)*S235+0.000000e+00*S236+2.166787e+01*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V59_part25='V59_part24+1.277972e-01*S240+(-6.616834e+00)*S241+(-1.642840e+00)*S242+0.000000e+00*S243+(-2.020211e+00)*S244+(-9.309766e+00)*S245+(-5.569614e-01)*S246+0.000000e+00*S247+0.000000e+00*S248+1.048995e+01*S249'
.param V59_part26='V59_part25+1.269745e+00*S250+0.000000e+00*S251+0.000000e+00*S252+(-1.086279e+00)*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+1.849803e+00*S257+1.361683e+00*S258+1.977882e+00*S259'
.param V59_part27='V59_part26+1.400801e+00*S260+(-7.043856e+00)*S261+(-5.439640e+00)*S262+(-1.776545e-02)*S263+0.000000e+00*S264+(-1.591484e+01)*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V59_part28='V59_part27+8.054004e-01*S270+3.371715e+00*S271+2.880171e+00*S272+0.000000e+00*S273+(-2.923882e-01)*S274+(-1.189928e+00)*S275+1.378694e+01*S276+9.975603e-02*S277+0.000000e+00*S278+(-3.376887e+00)*S279'
.param V59_part29='V59_part28+(-7.622393e+00)*S280+0.000000e+00*S281+9.289624e+00*S282+0.000000e+00*S283+(-6.833952e+00)*S284+(-1.187687e+00)*S285+(-3.112097e+00)*S286+0.000000e+00*S287+(-1.154073e-01)*S288+1.119698e+01*S289'
.param V59_part30='V59_part29+0.000000e+00*S290+5.161731e+00*S291+0.000000e+00*S292+(-6.084493e+00)*S293+(-6.374677e+00)*S294+0.000000e+00*S295+(-4.563685e+00)*S296+0.000000e+00*S297+0.000000e+00*S298+(-8.240787e+00)*S299'
.param V59_part31='V59_part30+9.645310e-01*S300+5.564813e+00*S301+(-2.048887e+00)*S302+1.142065e+01*S303+0.000000e+00*S304+(-2.995546e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V59='V59_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V60_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.140839e+00)*S2+0.000000e+00*S3+(-7.490295e-01)*S4+(-4.269134e-01)*S5+(-1.319823e+00)*S6+(-1.759723e+00)*S7+(-2.715355e+00)*S8+2.039473e+00*S9'
.param V60_part2='V60_part1+(-2.340391e-01)*S10+(-3.047657e+00)*S11+5.948072e-01*S12+(-1.441910e+00)*S13+(-5.872390e+00)*S14+0.000000e+00*S15+(-1.250276e+00)*S16+(-2.135471e+00)*S17+(-1.110087e+00)*S18+(-8.505663e-01)*S19'
.param V60_part3='V60_part2+(-2.790189e+00)*S20+(-1.090355e+00)*S21+(-1.171272e+00)*S22+(-2.776330e+00)*S23+(-2.316848e+00)*S24+(-2.113352e+00)*S25+(-2.075211e+00)*S26+(-4.472747e-01)*S27+(-2.175657e+00)*S28+(-3.251825e+00)*S29'
.param V60_part4='V60_part3+0.000000e+00*S30+0.000000e+00*S31+(-6.604053e+00)*S32+0.000000e+00*S33+0.000000e+00*S34+(-5.912603e+00)*S35+0.000000e+00*S36+(-2.469565e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V60_part5='V60_part4+(-3.195682e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+(-2.499007e+00)*S44+(-9.397262e-01)*S45+(-1.232359e+00)*S46+(-1.161182e+01)*S47+(-1.944343e-01)*S48+(-1.385175e+00)*S49'
.param V60_part6='V60_part5+(-1.480902e+01)*S50+(-2.660012e-01)*S51+3.209697e-01*S52+(-3.938015e+00)*S53+(-1.069031e+00)*S54+(-2.650625e-01)*S55+(-6.841763e+00)*S56+(-1.361151e+00)*S57+(-5.156066e+00)*S58+(-9.410076e+00)*S59'
.param V60_part7='V60_part6+(-5.513373e-01)*S60+(-3.093942e+00)*S61+3.791815e-01*S62+(-1.191787e+00)*S63+(-2.442180e+00)*S64+(-2.533307e+00)*S65+(-1.526790e+00)*S66+(-7.456080e-01)*S67+4.268641e-02*S68+(-2.570624e+00)*S69'
.param V60_part8='V60_part7+(-1.217320e-01)*S70+2.286353e-01*S71+(-3.204632e+00)*S72+(-1.155230e+00)*S73+(-5.151780e+00)*S74+0.000000e+00*S75+(-1.258800e+00)*S76+(-5.539326e-01)*S77+(-2.023165e+00)*S78+(-2.532198e+00)*S79'
.param V60_part9='V60_part8+(-2.966979e+00)*S80+0.000000e+00*S81+(-2.049688e+00)*S82+(-3.607666e+00)*S83+1.654398e-03*S84+(-1.727790e+00)*S85+(-3.841176e+00)*S86+(-1.056246e+00)*S87+(-3.068271e+00)*S88+(-3.759685e-01)*S89'
.param V60_part10='V60_part9+0.000000e+00*S90+3.120628e-01*S91+(-1.751180e-01)*S92+4.241577e-01*S93+(-9.150408e-01)*S94+(-2.573427e+00)*S95+(-7.752957e-02)*S96+(-7.115245e-01)*S97+0.000000e+00*S98+(-3.134103e-01)*S99'
.param V60_part11='V60_part10+(-5.641690e+00)*S100+0.000000e+00*S101+0.000000e+00*S102+(-5.081312e+00)*S103+(-2.217619e+01)*S104+3.051140e-01*S105+7.199906e-01*S106+(-9.838994e-01)*S107+2.193510e-01*S108+(-3.006095e-01)*S109'
.param V60_part12='V60_part11+0.000000e+00*S110+0.000000e+00*S111+(-1.830247e-01)*S112+0.000000e+00*S113+0.000000e+00*S114+(-6.627495e+00)*S115+(-2.532386e+01)*S116+(-4.534266e+00)*S117+(-1.142897e+01)*S118+0.000000e+00*S119'
.param V60_part13='V60_part12+(-7.470873e-01)*S120+4.187880e-01*S121+(-8.306944e-01)*S122+(-8.386562e-01)*S123+(-8.310483e-01)*S124+(-9.811045e+00)*S125+(-1.550746e+00)*S126+(-4.877715e+00)*S127+(-2.075555e+01)*S128+(-3.897966e+00)*S129'
.param V60_part14='V60_part13+(-8.590871e+00)*S130+(-4.670556e+00)*S131+(-5.737587e+00)*S132+(-1.306021e+01)*S133+(-6.882426e+00)*S134+0.000000e+00*S135+(-2.981657e+00)*S136+4.318347e-01*S137+(-2.248638e+00)*S138+(-4.664433e+00)*S139'
.param V60_part15='V60_part14+(-1.881908e+00)*S140+(-1.550928e+00)*S141+(-5.801740e-01)*S142+(-8.070297e+00)*S143+(-1.054693e+00)*S144+(-1.800859e+00)*S145+(-1.001703e+01)*S146+(-4.497494e-01)*S147+(-2.591668e+00)*S148+(-1.045310e+01)*S149'
.param V60_part16='V60_part15+0.000000e+00*S150+0.000000e+00*S151+(-4.222674e+00)*S152+0.000000e+00*S153+(-9.207009e-01)*S154+(-5.762195e+00)*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V60_part17='V60_part16+(-8.329553e+00)*S160+0.000000e+00*S161+(-6.633736e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+(-1.695293e+00)*S165+(-1.263140e+00)*S166+0.000000e+00*S167+(-8.804130e-01)*S168+0.000000e+00*S169'
.param V60_part18='V60_part17+0.000000e+00*S170+(-4.032892e+00)*S171+(-1.075250e+01)*S172+(-2.681064e+01)*S173+(-5.587419e+00)*S174+(-1.541145e+01)*S175+0.000000e+00*S176+(-7.429778e+00)*S177+(-1.372627e+01)*S178+(-2.161287e+01)*S179'
.param V60_part19='V60_part18+(-1.157093e+00)*S180+(-7.159153e-01)*S181+(-7.971400e+00)*S182+(-2.347297e+00)*S183+(-9.348041e+00)*S184+0.000000e+00*S185+(-3.704544e+00)*S186+(-1.201554e+01)*S187+(-2.047645e+01)*S188+(-6.715196e+00)*S189'
.param V60_part20='V60_part19+(-1.146914e+01)*S190+(-2.751021e+01)*S191+(-8.355266e+00)*S192+(-1.421373e+01)*S193+(-4.156719e+01)*S194+(-1.802774e+00)*S195+(-1.280322e+00)*S196+0.000000e+00*S197+(-2.309565e+00)*S198+(-2.624782e+00)*S199'
.param V60_part21='V60_part20+(-4.422215e+00)*S200+(-1.699088e+00)*S201+(-6.062682e+00)*S202+(-1.894401e+01)*S203+(-5.856083e+00)*S204+(-8.938638e+00)*S205+(-1.989039e+01)*S206+(-6.466338e+00)*S207+(-8.157788e+00)*S208+(-1.987929e+01)*S209'
.param V60_part22='V60_part21+(-9.216340e-01)*S210+0.000000e+00*S211+(-8.745259e+00)*S212+(-3.403063e+00)*S213+(-1.643723e+01)*S214+(-1.277329e+01)*S215+(-5.083294e+00)*S216+0.000000e+00*S217+(-2.429649e+01)*S218+(-6.572507e+00)*S219'
.param V60_part23='V60_part22+(-1.281893e+01)*S220+0.000000e+00*S221+(-8.832760e+00)*S222+(-1.699057e+01)*S223+(-3.482084e+01)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-3.411839e+00)*S228+(-5.724108e+00)*S229'
.param V60_part24='V60_part23+0.000000e+00*S230+(-4.811621e+00)*S231+(-9.797935e+00)*S232+(-3.270051e+01)*S233+(-8.304946e+00)*S234+(-1.413665e+01)*S235+(-3.626412e+01)*S236+(-1.063796e+01)*S237+(-1.889841e+01)*S238+(-3.485023e+01)*S239'
.param V60_part25='V60_part24+(-3.687164e+00)*S240+0.000000e+00*S241+0.000000e+00*S242+(-4.522959e+00)*S243+(-1.063462e+01)*S244+(-1.816666e+01)*S245+(-4.119956e+00)*S246+(-1.534715e+01)*S247+(-3.600582e+01)*S248+(-7.043397e+00)*S249'
.param V60_part26='V60_part25+(-1.635480e+01)*S250+(-3.967161e+01)*S251+(-9.670867e+00)*S252+(-1.818498e+01)*S253+(-5.660310e+01)*S254+(-3.154385e+00)*S255+(-2.321028e+00)*S256+(-2.174640e+00)*S257+(-2.432683e+00)*S258+(-3.336285e+00)*S259'
.param V60_part27='V60_part26+(-5.403183e+00)*S260+(-6.155443e+00)*S261+(-1.437136e+01)*S262+(-3.214808e+01)*S263+(-7.883203e+00)*S264+(-1.692365e+01)*S265+(-3.685597e+01)*S266+(-9.279708e+00)*S267+(-1.689781e+01)*S268+(-4.323089e+01)*S269'
.param V60_part28='V60_part27+(-3.190226e+00)*S270+(-1.093332e+01)*S271+0.000000e+00*S272+(-5.227888e+00)*S273+0.000000e+00*S274+0.000000e+00*S275+(-6.682462e+00)*S276+(-1.557986e+01)*S277+(-3.553810e+01)*S278+(-8.358966e+00)*S279'
.param V60_part29='V60_part28+(-1.638052e+01)*S280+(-3.518361e+01)*S281+(-9.971065e+00)*S282+(-1.997924e+01)*S283+(-3.900635e+01)*S284+(-3.319391e+00)*S285+(-8.577081e+00)*S286+(-3.841346e+01)*S287+(-4.882817e+00)*S288+(-1.495620e+01)*S289'
.param V60_part30='V60_part29+(-3.681293e+01)*S290+(-5.488186e+00)*S291+(-1.692017e+01)*S292+(-3.902757e+01)*S293+(-8.411176e+00)*S294+(-1.906542e+01)*S295+(-4.439817e+01)*S296+(-1.005991e+01)*S297+(-2.216139e+01)*S298+(-4.438594e+01)*S299'
.param V60_part31='V60_part30+(-3.422805e+00)*S300+(-7.749323e+00)*S301+(-2.570528e+01)*S302+(-5.899236e+00)*S303+(-1.575380e+01)*S304+(-3.454318e+01)*S305+(-8.183903e+00)*S306+(-1.801719e+01)*S307+(-4.692002e+01)*S308+(-9.938395e+00)*S309'
.param V60='V60_part31+(-1.988696e+01)*S310+(-4.951981e+01)*S311+(-1.251335e+01)*S312+(-2.203376e+01)*S313+(-6.071287e+01)*S314'
.param V61_part1='0.000000e+00*S0+0.000000e+00*S1+2.696231e+00*S2+0.000000e+00*S3+6.908870e-01*S4+3.130123e+00*S5+3.510189e+00*S6+2.375398e+00*S7+4.011495e+00*S8+1.379202e+00*S9'
.param V61_part2='V61_part1+2.173085e+00*S10+3.474482e+00*S11+1.511648e+00*S12+3.541212e+00*S13+5.881150e+00*S14+0.000000e+00*S15+2.776148e+00*S16+5.425459e+00*S17+2.258458e+00*S18+3.755678e+00*S19'
.param V61_part3='V61_part2+5.449195e+00*S20+4.008851e+00*S21+3.741944e+00*S22+5.264903e+00*S23+4.921836e+00*S24+4.949108e+00*S25+4.258842e+00*S26+2.445108e+00*S27+4.171051e+00*S28+4.974059e+00*S29'
.param V61_part4='V61_part3+0.000000e+00*S30+0.000000e+00*S31+9.343945e+00*S32+0.000000e+00*S33+0.000000e+00*S34+6.053416e+00*S35+0.000000e+00*S36+3.467749e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V61_part5='V61_part4+4.763986e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+2.586652e+00*S44+4.846561e+00*S45+2.006809e+00*S46+1.936965e+01*S47+(-9.057039e-01)*S48+2.729486e+00*S49'
.param V61_part6='V61_part5+1.895051e+01*S50+(-2.512135e-01)*S51+4.442181e-01*S52+6.820115e+00*S53+(-8.908667e-03)*S54+1.214964e+00*S55+8.478062e+00*S56+1.934709e-01*S57+6.619860e+00*S58+9.300732e+00*S59'
.param V61_part7='V61_part6+(-1.141426e+00)*S60+1.086700e+01*S61+(-1.185139e+00)*S62+2.375280e+00*S63+3.543403e+00*S64+6.979680e+00*S65+8.145720e-01*S66+8.322201e-01*S67+2.845723e+00*S68+1.860123e+00*S69'
.param V61_part8='V61_part7+3.663298e+00*S70+3.881485e+00*S71+1.523102e+00*S72+4.628194e+00*S73+4.230800e+00*S74+0.000000e+00*S75+3.783440e+00*S76+2.487738e+00*S77+4.271881e+00*S78+4.327267e+00*S79'
.param V61_part9='V61_part8+4.836269e+00*S80+0.000000e+00*S81+2.795816e+00*S82+4.153467e+00*S83+1.400181e+00*S84+2.526053e+00*S85+4.543852e+00*S86+1.850191e+00*S87+3.683466e+00*S88+1.110625e+00*S89'
.param V61_part10='V61_part9+0.000000e+00*S90+1.223158e+00*S91+9.234930e-01*S92+(-1.056107e-01)*S93+3.428550e+00*S94+1.955995e+00*S95+6.216321e-01*S96+1.769056e+00*S97+0.000000e+00*S98+8.218081e-01*S99'
.param V61_part11='V61_part10+7.144508e+00*S100+0.000000e+00*S101+0.000000e+00*S102+5.429581e+00*S103+1.964903e+01*S104+(-1.174213e+00)*S105+(-8.008699e-03)*S106+3.614805e+00*S107+3.076857e-02*S108+1.516080e+00*S109'
.param V61_part12='V61_part11+0.000000e+00*S110+0.000000e+00*S111+1.018520e+00*S112+0.000000e+00*S113+0.000000e+00*S114+4.191451e+00*S115+2.362804e+01*S116+3.988187e+00*S117+1.065160e+01*S118+0.000000e+00*S119'
.param V61_part13='V61_part12+(-1.466578e+00)*S120+(-9.120519e-01)*S121+4.177388e+00*S122+1.066047e+00*S123+2.404144e+00*S124+1.360697e+01*S125+5.927380e+00*S126+9.643320e+00*S127+2.612133e+01*S128+9.201070e+00*S129'
.param V61_part14='V61_part13+1.285995e+01*S130+7.210902e+00*S131+2.506824e+00*S132+1.378229e+01*S133+8.645440e+00*S134+0.000000e+00*S135+6.717451e+00*S136+(-4.002429e+00)*S137+8.163244e+00*S138+6.205598e+00*S139'
.param V61_part15='V61_part14+6.641486e+00*S140+6.146720e+00*S141+2.130127e+00*S142+8.017442e+00*S143+2.945608e+00*S144+3.408188e+00*S145+9.099260e+00*S146+2.810852e+00*S147+4.992889e+00*S148+1.031503e+01*S149'
.param V61_part16='V61_part15+0.000000e+00*S150+0.000000e+00*S151+4.517741e+00*S152+0.000000e+00*S153+5.470259e+00*S154+3.858882e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V61_part17='V61_part16+5.432889e+00*S160+0.000000e+00*S161+3.986990e+00*S162+0.000000e+00*S163+0.000000e+00*S164+4.154970e+00*S165+8.207568e+00*S166+0.000000e+00*S167+4.813559e-01*S168+0.000000e+00*S169'
.param V61_part18='V61_part17+0.000000e+00*S170+2.360665e+00*S171+1.733304e+01*S172+3.304600e+01*S173+2.915686e+00*S174+1.710142e+01*S175+0.000000e+00*S176+3.811310e+00*S177+1.075072e+01*S178+1.825785e+01*S179'
.param V61_part19='V61_part18+5.295410e+00*S180+7.617218e+00*S181+8.625476e+00*S182+(-3.833614e-01)*S183+1.626199e+01*S184+0.000000e+00*S185+8.728673e-01*S186+1.883940e+01*S187+2.006303e+01*S188+4.331325e+00*S189'
.param V61_part20='V61_part19+9.808278e+00*S190+2.130504e+01*S191+3.868395e+00*S192+1.201703e+01*S193+2.561937e+01*S194+7.435341e+00*S195+2.760608e+00*S196+0.000000e+00*S197+5.801549e+00*S198+6.822973e+00*S199'
.param V61_part21='V61_part20+5.749207e+00*S200+7.767214e+00*S201+1.028188e+01*S202+2.528500e+01*S203+8.029136e+00*S204+1.055696e+01*S205+2.194894e+01*S206+3.973904e+00*S207+7.110052e+00*S208+1.889071e+01*S209'
.param V61_part22='V61_part21+4.661937e+00*S210+0.000000e+00*S211+5.713790e+00*S212+1.040405e+01*S213+1.828139e+01*S214+9.811582e+00*S215+3.970706e+00*S216+0.000000e+00*S217+1.047121e+01*S218+4.421197e+00*S219'
.param V61_part23='V61_part22+1.078520e+01*S220+0.000000e+00*S221+4.495048e+00*S222+1.460355e+01*S223+2.746852e+01*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+3.399828e+00*S228+6.045235e+00*S229'
.param V61_part24='V61_part23+0.000000e+00*S230+7.144371e+00*S231+1.046643e+01*S232+2.444535e+01*S233+5.500381e+00*S234+1.264702e+01*S235+2.668590e+01*S236+5.536647e+00*S237+1.370370e+01*S238+2.425478e+01*S239'
.param V61_part25='V61_part24+7.694663e+00*S240+0.000000e+00*S241+0.000000e+00*S242+4.754181e+00*S243+1.084805e+01*S244+2.249634e+01*S245+5.559986e+00*S246+1.415742e+01*S247+2.903920e+01*S248+4.147303e+00*S249'
.param V61_part26='V61_part25+1.333434e+01*S250+2.760047e+01*S251+5.786652e+00*S252+1.292623e+01*S253+3.575283e+01*S254+6.160444e+00*S255+4.206394e+00*S256+3.161819e+00*S257+3.261663e+00*S258+6.029614e+00*S259'
.param V61_part27='V61_part26+1.100794e+01*S260+4.534666e+00*S261+1.235486e+01*S262+3.726042e+01*S263+4.456242e+00*S264+1.264769e+01*S265+2.401778e+01*S266+4.289922e+00*S267+1.047417e+01*S268+2.446684e+01*S269'
.param V61_part28='V61_part27+5.427336e+00*S270+2.426449e+01*S271+0.000000e+00*S272+6.202722e+00*S273+0.000000e+00*S274+0.000000e+00*S275+5.518389e+00*S276+1.348782e+01*S277+2.904378e+01*S278+6.095752e+00*S279'
.param V61_part29='V61_part28+1.508032e+01*S280+2.372128e+01*S281+5.548283e+00*S282+1.508876e+01*S283+2.300808e+01*S284+1.717499e+00*S285+1.096225e+01*S286+4.341188e+01*S287+5.326474e+00*S288+1.629269e+01*S289'
.param V61_part30='V61_part29+3.262916e+01*S290+3.310042e+00*S291+1.514727e+01*S292+2.802477e+01*S293+6.250845e+00*S294+1.495377e+01*S295+2.860535e+01*S296+6.255487e+00*S297+1.544253e+01*S298+2.419441e+01*S299'
.param V61_part31='V61_part30+2.308206e+00*S300+1.813279e+01*S301+2.977161e+01*S302+5.239846e+00*S303+1.544651e+01*S304+3.172887e+01*S305+5.317660e+00*S306+1.628563e+01*S307+3.252612e+01*S308+5.776593e+00*S309'
.param V61='V61_part31+1.540409e+01*S310+2.979103e+01*S311+6.554275e+00*S312+1.451753e+01*S313+3.138396e+01*S314'
.param V62_part1='0.000000e+00*S0+0.000000e+00*S1+2.466524e+00*S2+0.000000e+00*S3+2.940592e+00*S4+2.238035e+00*S5+1.728906e+00*S6+4.415066e+00*S7+4.388981e+00*S8+1.669893e+00*S9'
.param V62_part2='V62_part1+2.564292e+00*S10+5.268437e+00*S11+2.304308e+00*S12+4.493198e+00*S13+6.209860e+00*S14+0.000000e+00*S15+3.301096e+00*S16+3.732190e+00*S17+3.929544e+00*S18+3.918103e+00*S19'
.param V62_part3='V62_part2+5.568073e+00*S20+3.158118e+00*S21+4.679319e+00*S22+3.717800e+00*S23+5.383623e+00*S24+5.881061e+00*S25+3.463714e+00*S26+3.471657e+00*S27+3.951206e+00*S28+3.959468e+00*S29'
.param V62_part4='V62_part3+0.000000e+00*S30+0.000000e+00*S31+1.092039e+01*S32+0.000000e+00*S33+0.000000e+00*S34+8.301183e+00*S35+0.000000e+00*S36+7.223341e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V62_part5='V62_part4+9.626959e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+4.728048e-01*S44+4.233519e+00*S45+3.201259e+00*S46+1.641037e+01*S47+1.997206e+00*S48+4.054777e+00*S49'
.param V62_part6='V62_part5+1.790438e+01*S50+8.837643e-01*S51+1.487384e+00*S52+4.517654e+00*S53+3.797444e+00*S54+1.893188e+00*S55+5.860606e+00*S56+2.737842e+00*S57+8.226852e+00*S58+7.096602e+00*S59'
.param V62_part7='V62_part6+5.202523e+00*S60+1.002761e+01*S61+7.335814e+00*S62+3.446647e+00*S63+6.046193e+00*S64+6.293208e+00*S65+5.461447e+00*S66+1.570629e+00*S67+2.152865e+00*S68+5.174273e+00*S69'
.param V62_part8='V62_part7+3.657017e+00*S70+8.902852e-01*S71+7.759212e+00*S72+1.467240e+00*S73+1.775385e+00*S74+0.000000e+00*S75+1.330077e+00*S76+2.728495e+00*S77+3.342193e+00*S78+3.591669e+00*S79'
.param V62_part9='V62_part8+2.583809e+00*S80+0.000000e+00*S81+2.554600e+00*S82+3.007488e+00*S83+1.162063e+00*S84+1.614360e+00*S85+2.709064e+00*S86+1.675686e+00*S87+3.117655e+00*S88+1.921364e+00*S89'
.param V62_part10='V62_part9+0.000000e+00*S90+2.936492e+00*S91+2.967070e+00*S92+1.500562e+00*S93+3.637190e+00*S94+5.497235e+00*S95+1.705169e+00*S96+2.550397e+00*S97+0.000000e+00*S98+2.073839e+00*S99'
.param V62_part11='V62_part10+9.824870e+00*S100+0.000000e+00*S101+0.000000e+00*S102+4.305331e+00*S103+2.110240e+01*S104+1.450690e+00*S105+2.734651e-01*S106+2.167005e+00*S107+1.262158e+00*S108+2.469198e+00*S109'
.param V62_part12='V62_part11+0.000000e+00*S110+0.000000e+00*S111+2.170931e+00*S112+0.000000e+00*S113+0.000000e+00*S114+1.809683e+01*S115+2.281357e+01*S116+1.120235e+01*S117+1.651964e+01*S118+0.000000e+00*S119'
.param V62_part13='V62_part12+2.747749e+00*S120+(-3.773855e-01)*S121+3.666237e+00*S122+9.704278e-01*S123+2.153436e+00*S124+1.065565e+01*S125+2.737552e+00*S126+7.218186e+00*S127+1.575610e+01*S128+3.203498e+00*S129'
.param V62_part14='V62_part13+1.089237e+01*S130+5.121341e+00*S131+1.198762e+01*S132+1.529229e+01*S133+5.703875e+00*S134+0.000000e+00*S135+9.236285e+00*S136+6.801914e+00*S137+7.360872e+00*S138+1.122104e+01*S139'
.param V62_part15='V62_part14+3.811229e+00*S140+5.959352e+00*S141+3.109930e+00*S142+9.316906e+00*S143+3.097422e+00*S144+4.063571e+00*S145+1.147250e+01*S146+6.911417e+00*S147+3.097349e+00*S148+1.176846e+01*S149'
.param V62_part16='V62_part15+0.000000e+00*S150+0.000000e+00*S151+7.722042e+00*S152+0.000000e+00*S153+(-1.007332e+00)*S154+9.603324e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V62_part17='V62_part16+1.975217e+01*S160+0.000000e+00*S161+2.269421e+01*S162+0.000000e+00*S163+0.000000e+00*S164+1.402260e+01*S165+7.512942e-01*S166+0.000000e+00*S167+2.454977e+00*S168+0.000000e+00*S169'
.param V62_part18='V62_part17+0.000000e+00*S170+7.410263e+00*S171+1.221164e+01*S172+1.888689e+01*S173+1.199297e+01*S174+2.315064e+01*S175+0.000000e+00*S176+1.702821e+01*S177+1.018415e+01*S178+7.879799e+00*S179'
.param V62_part19='V62_part18+6.854748e+00*S180+4.844297e-02*S181+1.519087e+01*S182+8.280202e+00*S183+1.265639e+01*S184+0.000000e+00*S185+1.299093e+01*S186+1.888573e+01*S187+9.456892e+00*S188+1.770357e+01*S189'
.param V62_part20='V62_part19+1.080577e+01*S190+1.352167e+01*S191+2.444631e+01*S192+1.486055e+01*S193+2.876660e+01*S194+5.050369e+00*S195+3.125052e+00*S196+0.000000e+00*S197+5.627966e+00*S198+5.135563e+00*S199'
.param V62_part21='V62_part20+7.922435e+00*S200+2.284422e+00*S201+9.569995e+00*S202+1.700154e+01*S203+2.050158e+01*S204+1.363073e+01*S205+1.436348e+01*S206+1.751064e+01*S207+1.356314e+01*S208+1.521275e+01*S209'
.param V62_part22='V62_part21+5.311197e+00*S210+0.000000e+00*S211+1.496705e+01*S212+1.874657e+01*S213+3.077461e+01*S214+1.737194e+01*S215+1.024343e+01*S216+0.000000e+00*S217+2.914778e+01*S218+1.507001e+01*S219'
.param V62_part23='V62_part22+1.048017e+01*S220+0.000000e+00*S221+2.139554e+01*S222+1.268052e+01*S223+1.711432e+01*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+1.028638e+01*S228+8.736057e+00*S229'
.param V62_part24='V62_part23+0.000000e+00*S230+3.033161e+01*S231+8.196407e+00*S232+2.181394e+01*S233+2.330304e+01*S234+1.410330e+01*S235+2.450808e+01*S236+3.114823e+01*S237+2.247763e+01*S238+2.574651e+01*S239'
.param V62_part25='V62_part24+1.041296e+01*S240+0.000000e+00*S241+0.000000e+00*S242+1.605484e+01*S243+1.509989e+01*S244+9.394767e+00*S245+2.973038e+01*S246+2.183320e+01*S247+2.874584e+01*S248+2.725102e+01*S249'
.param V62_part26='V62_part25+2.358270e+01*S250+3.461664e+01*S251+3.224452e+01*S252+2.540265e+01*S253+4.446879e+01*S254+9.576462e+00*S255+7.540412e+00*S256+5.756614e+00*S257+6.893608e+00*S258+5.854985e+00*S259'
.param V62_part27='V62_part26+5.167081e+00*S260+1.242386e+01*S261+1.631059e+01*S262+2.743139e+01*S263+1.738009e+01*S264+1.689435e+01*S265+2.557972e+01*S266+2.286412e+01*S267+1.684415e+01*S268+3.464887e+01*S269'
.param V62_part28='V62_part27+7.195849e+00*S270+2.053641e+01*S271+0.000000e+00*S272+1.353002e+01*S273+0.000000e+00*S274+0.000000e+00*S275+2.034364e+01*S276+1.924472e+01*S277+2.424518e+01*S278+2.426663e+01*S279'
.param V62_part29='V62_part28+2.014200e+01*S280+2.891472e+01*S281+3.390572e+01*S282+2.483162e+01*S283+3.455803e+01*S284+1.222328e+01*S285+1.136245e+01*S286+4.800695e+01*S287+1.939685e+01*S288+2.092044e+01*S289'
.param V62_part30='V62_part29+3.161648e+01*S290+2.442678e+01*S291+2.834093e+01*S292+3.497793e+01*S293+2.826598e+01*S294+3.260862e+01*S295+4.358112e+01*S296+3.731875e+01*S297+4.179916e+01*S298+4.776954e+01*S299'
.param V62_part31='V62_part30+1.513605e+01*S300+1.336216e+01*S301+3.248905e+01*S302+1.572079e+01*S303+2.350839e+01*S304+4.274638e+01*S305+2.246332e+01*S306+2.528708e+01*S307+3.985931e+01*S308+2.799165e+01*S309'
.param V62='V62_part31+3.021478e+01*S310+4.684869e+01*S311+3.476067e+01*S312+3.565870e+01*S313+5.941160e+01*S314'
.param V63_part1='0.000000e+00*S0+0.000000e+00*S1+1.426272e+00*S2+0.000000e+00*S3+1.134580e+00*S4+8.709949e-01*S5+1.430984e+00*S6+6.625324e-01*S7+1.430797e+00*S8+(-4.020767e-01)*S9'
.param V63_part2='V63_part1+3.134942e-01*S10+2.045969e+00*S11+3.201820e-01*S12+1.281381e+00*S13+2.558826e+00*S14+0.000000e+00*S15+1.031192e+00*S16+1.099955e+00*S17+7.183528e-01*S18+7.467575e-01*S19'
.param V63_part3='V63_part2+1.110253e+00*S20+6.005779e-01*S21+6.126733e-01*S22+1.522750e+00*S23+1.942783e+00*S24+1.141141e+00*S25+2.253700e+00*S26+5.556360e-01*S27+1.210072e+00*S28+2.198910e+00*S29'
.param V63_part4='V63_part3+0.000000e+00*S30+0.000000e+00*S31+3.176498e+00*S32+0.000000e+00*S33+0.000000e+00*S34+2.676218e+00*S35+0.000000e+00*S36+3.535955e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V63_part5='V63_part4+6.091444e-01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+1.234516e-01*S44+3.033798e-01*S45+4.109057e-01*S46+2.212082e+00*S47+6.910448e-01*S48+1.115663e+00*S49'
.param V63_part6='V63_part5+2.147752e+00*S50+1.839465e-01*S51+(-7.120919e-02)*S52+4.689979e+00*S53+5.055202e-01*S54+(-3.050719e-01)*S55+4.727345e+00*S56+4.077444e-01*S57+1.589695e+00*S58+4.705687e+00*S59'
.param V63_part7='V63_part6+1.781063e-01*S60+9.794192e-01*S61+2.492036e-01*S62+2.676458e-01*S63+8.869142e-01*S64+(-1.687204e-01)*S65+6.601841e-01*S66+(-4.607479e-02)*S67+(-5.587249e-01)*S68+4.564489e-01*S69'
.param V63_part8='V63_part7+(-5.538751e-01)*S70+(-1.632654e+00)*S71+3.052553e-01*S72+(-1.653637e+00)*S73+(-2.485386e-01)*S74+0.000000e+00*S75+3.546806e-02*S76+(-4.147596e-01)*S77+7.002189e-01*S78+1.033029e+00*S79'
.param V63_part9='V63_part8+(-1.257629e-01)*S80+0.000000e+00*S81+(-1.316894e-01)*S82+2.630967e-02*S83+1.565573e-01*S84+5.315018e-03*S85+1.038788e-02*S86+4.949139e-01*S87+6.807210e-01*S88+7.973092e-01*S89'
.param V63_part10='V63_part9+0.000000e+00*S90+1.059955e-01*S91+(-9.925940e-02)*S92+(-1.027522e-01)*S93+3.266174e-01*S94+(-5.478992e-01)*S95+(-1.032410e-01)*S96+(-2.916220e-01)*S97+0.000000e+00*S98+(-1.341080e-01)*S99'
.param V63_part11='V63_part10+(-6.367136e-01)*S100+0.000000e+00*S101+0.000000e+00*S102+3.274105e-01*S103+2.240516e+00*S104+1.262430e-04*S105+(-5.429868e-02)*S106+(-1.685259e-01)*S107+(-2.772262e-02)*S108+(-1.720458e-01)*S109'
.param V63_part12='V63_part11+0.000000e+00*S110+0.000000e+00*S111+(-3.259523e-01)*S112+0.000000e+00*S113+0.000000e+00*S114+1.254013e+00*S115+7.496473e-01*S116+7.113506e-01*S117+1.074635e+00*S118+0.000000e+00*S119'
.param V63_part13='V63_part12+1.043955e-01*S120+(-1.638240e-01)*S121+(-1.183992e+00)*S122+(-8.276615e-02)*S123+(-2.769960e-01)*S124+(-6.505083e-01)*S125+1.286345e-01*S126+(-1.459575e-01)*S127+(-4.406454e-01)*S128+8.173526e-01*S129'
.param V63_part14='V63_part13+3.023083e-02*S130+9.424419e-01*S131+4.535013e-01*S132+5.303005e-01*S133+1.358518e+00*S134+0.000000e+00*S135+7.793063e-01*S136+6.478360e-01*S137+6.938169e-01*S138+2.555668e-01*S139'
.param V63_part15='V63_part14+(-1.208252e+00)*S140+1.258401e-01*S141+(-8.078756e-02)*S142+(-6.163632e-01)*S143+(-3.813587e-01)*S144+(-4.602349e-01)*S145+(-7.648161e-01)*S146+3.048268e-02*S147+(-1.423773e-01)*S148+2.500971e+00*S149'
.param V63_part16='V63_part15+0.000000e+00*S150+0.000000e+00*S151+(-5.165400e-01)*S152+0.000000e+00*S153+(-7.428651e-02)*S154+(-6.000160e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V63_part17='V63_part16+2.187429e+00*S160+0.000000e+00*S161+1.540479e+00*S162+0.000000e+00*S163+0.000000e+00*S164+1.955393e-01*S165+(-7.351243e-01)*S166+0.000000e+00*S167+(-1.221068e-01)*S168+0.000000e+00*S169'
.param V63_part18='V63_part17+0.000000e+00*S170+5.558725e-01*S171+1.297299e+00*S172+2.192619e+00*S173+3.342227e-01*S174+2.033532e+00*S175+0.000000e+00*S176+1.029216e+00*S177+1.417479e+00*S178+1.282294e+00*S179'
.param V63_part19='V63_part18+3.636257e-01*S180+(-1.333551e+00)*S181+(-1.271641e+00)*S182+(-1.984481e-01)*S183+(-4.746383e-01)*S184+0.000000e+00*S185+3.380233e-01*S186+8.001192e-01*S187+(-9.955278e-02)*S188+8.201721e-01*S189'
.param V63_part20='V63_part19+3.479315e-01*S190+(-8.323943e-01)*S191+8.301584e-01*S192+5.984880e-01*S193+(-1.203900e-01)*S194+4.228403e-01*S195+(-6.252931e-01)*S196+0.000000e+00*S197+(-2.229017e-01)*S198+(-1.493910e+00)*S199'
.param V63_part21='V63_part20+(-1.645892e+00)*S200+3.439008e-01*S201+(-8.300336e-01)*S202+(-6.417758e-01)*S203+1.277138e+00*S204+1.001953e+00*S205+(-9.005411e-03)*S206+(-4.434586e-01)*S207+1.209252e+00*S208+2.014877e-01*S209'
.param V63_part22='V63_part21+2.234612e-01*S210+0.000000e+00*S211+(-1.241879e+00)*S212+7.409836e-01*S213+3.600886e+00*S214+(-1.133935e+00)*S215+1.122853e+00*S216+0.000000e+00*S217+(-5.854619e-01)*S218+1.216371e+00*S219'
.param V63_part23='V63_part22+1.742514e+00*S220+0.000000e+00*S221+1.270419e+00*S222+1.545242e+00*S223+2.603983e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+9.805875e-01*S228+1.496832e+00*S229'
.param V63_part24='V63_part23+0.000000e+00*S230+1.413411e+00*S231+1.317493e+00*S232+1.377287e+00*S233+9.193163e-01*S234+1.467227e+00*S235+9.199582e-01*S236+9.930789e-01*S237+5.200976e-01*S238+1.988368e+00*S239'
.param V63_part25='V63_part24+(-3.522668e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+5.931922e-01*S243+(-3.180884e-01)*S244+(-1.760957e-01)*S245+1.607606e+00*S246+2.360488e-01*S247+(-1.211124e-01)*S248+7.156630e-01*S249'
.param V63_part26='V63_part25+9.327973e-02*S250+4.494752e-02*S251+6.891469e-01*S252+3.537721e-01*S253+7.467960e-01*S254+1.060286e-01*S255+(-1.123257e+00)*S256+(-1.464650e+00)*S257+(-4.553634e-01)*S258+(-5.008400e-01)*S259'
.param V63_part27='V63_part26+(-1.604683e+00)*S260+(-2.323514e-01)*S261+(-6.889761e-01)*S262+4.383262e-02*S263+(-5.001729e-01)*S264+(-6.718612e-01)*S265+(-2.412052e+00)*S266+(-3.093201e-01)*S267+(-1.597283e+00)*S268+(-1.780691e+00)*S269'
.param V63_part28='V63_part27+3.752432e-01*S270+1.314718e-01*S271+0.000000e+00*S272+1.291430e+00*S273+0.000000e+00*S274+0.000000e+00*S275+7.653649e-01*S276+1.419069e+00*S277+1.580887e+00*S278+1.285926e+00*S279'
.param V63_part29='V63_part28+2.033287e+00*S280+1.899904e+00*S281+9.721789e-01*S282+1.464751e+00*S283+1.771639e+00*S284+2.574379e-01*S285+2.658480e-01*S286+1.637156e+00*S287+6.514217e-01*S288+1.201893e+00*S289'
.param V63_part30='V63_part29+4.621975e-01*S290+3.869097e-01*S291+1.048066e+00*S292+5.455672e-01*S293+8.264437e-01*S294+1.129317e+00*S295+5.521135e-01*S296+7.477866e-01*S297+1.387935e+00*S298+1.317881e+00*S299'
.param V63_part31='V63_part30+(-6.512361e-01)*S300+(-1.157070e+00)*S301+(-3.759071e+00)*S302+(-9.561662e-01)*S303+(-8.746842e-01)*S304+(-3.629351e+00)*S305+(-4.868441e-01)*S306+(-1.085792e+00)*S307+(-2.931896e+00)*S308+(-3.541052e-02)*S309'
.param V63='V63_part31+(-1.121790e+00)*S310+(-2.189898e+00)*S311+(-3.178937e-01)*S312+(-1.053715e+00)*S313+(-2.406866e+00)*S314'
.param V64_part1='0.000000e+00*S0+0.000000e+00*S1+(-2.542580e-02)*S2+0.000000e+00*S3+(-1.265655e-02)*S4+3.798505e-03*S5+(-8.280315e-02)*S6+2.111400e-02*S7+(-2.809956e-02)*S8+9.031369e-03*S9'
.param V64_part2='V64_part1+3.498502e-03*S10+3.589837e-02*S11+8.287836e-03*S12+1.800520e-02*S13+1.981686e-02*S14+0.000000e+00*S15+(-1.237552e-03)*S16+8.109172e-03*S17+(-9.221355e-03)*S18+(-4.823477e-03)*S19'
.param V64_part3='V64_part2+4.652657e-03*S20+2.989835e-04*S21+3.935946e-03*S22+4.573555e-02*S23+(-2.852633e-02)*S24+2.378835e-03*S25+(-6.022277e-03)*S26+1.260230e-04*S27+1.696343e-03*S28+(-5.633202e-03)*S29'
.param V64_part4='V64_part3+0.000000e+00*S30+0.000000e+00*S31+2.602407e-01*S32+0.000000e+00*S33+0.000000e+00*S34+6.293591e-02*S35+0.000000e+00*S36+6.355752e-02*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V64_part5='V64_part4+(-3.852389e-02)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+2.588948e-01*S44+1.528897e-01*S45+2.339660e-01*S46+5.945238e-01*S47+8.500945e-01*S48+5.057398e-01*S49'
.param V64_part6='V64_part5+5.999884e-01*S50+6.338383e-01*S51+2.801960e-01*S52+(-1.216903e-01)*S53+1.513816e+00*S54+1.964990e-01*S55+(-1.392087e-01)*S56+1.604214e+00*S57+8.577843e-02*S58+(-1.940857e-01)*S59'
.param V64_part7='V64_part6+5.567587e-01*S60+3.461631e-01*S61+6.864741e-01*S62+3.478035e-01*S63+1.047798e+00*S64+7.483376e-02*S65+1.305186e+00*S66+7.509906e-01*S67+1.800703e-01*S68+1.433442e+00*S69'
.param V64_part8='V64_part7+9.217999e-02*S70+1.080584e-01*S71+2.355916e+00*S72+1.503789e-01*S73+2.298367e+00*S74+0.000000e+00*S75+1.750787e-02*S76+(-1.484610e-01)*S77+1.046180e-02*S78+3.180289e-02*S79'
.param V64_part9='V64_part8+1.746220e-01*S80+0.000000e+00*S81+2.395727e-01*S82+3.617639e-01*S83+2.410588e-01*S84+2.466743e-01*S85+4.704112e-01*S86+1.220490e-01*S87+2.802788e-01*S88+1.606686e-01*S89'
.param V64_part10='V64_part9+0.000000e+00*S90+(-1.069982e-01)*S91+(-1.262625e-01)*S92+(-5.979268e-02)*S93+5.024126e-02*S94+(-1.392513e-01)*S95+(-4.003576e-02)*S96+(-2.196891e-02)*S97+0.000000e+00*S98+(-8.113232e-02)*S99'
.param V64_part11='V64_part10+3.650428e-01*S100+0.000000e+00*S101+0.000000e+00*S102+1.515609e-01*S103+1.047873e+00*S104+2.205061e-01*S105+4.355438e-03*S106+(-2.862875e-02)*S107+2.107489e-03*S108+(-1.463571e-01)*S109'
.param V64_part12='V64_part11+0.000000e+00*S110+0.000000e+00*S111+(-9.504178e-02)*S112+0.000000e+00*S113+0.000000e+00*S114+9.896758e-01*S115+8.680905e-01*S116+2.097954e+00*S117+1.377726e-01*S118+0.000000e+00*S119'
.param V64_part13='V64_part12+1.293688e+00*S120+5.284456e-01*S121+1.394281e-01*S122+6.407277e-01*S123+9.417234e-02*S124+6.400860e-01*S125+3.627616e-01*S126+5.303582e-01*S127+1.613330e+00*S128+5.557748e-01*S129'
.param V64_part14='V64_part13+7.599807e-01*S130+6.402338e-01*S131+3.342462e+00*S132+8.396551e-01*S133+8.342010e-01*S134+0.000000e+00*S135+9.577891e-02*S136+(-5.877688e-02)*S137+1.502031e-01*S138+5.593089e-01*S139'
.param V64_part15='V64_part14+1.515125e-01*S140+2.440853e-01*S141+6.152260e-02*S142+6.753643e-01*S143+9.135977e-02*S144+2.582335e-02*S145+2.169005e-01*S146+(-2.381449e-01)*S147+8.744334e-02*S148+2.023967e-01*S149'
.param V64_part16='V64_part15+0.000000e+00*S150+0.000000e+00*S151+3.596257e-02*S152+0.000000e+00*S153+6.676126e-02*S154+(-7.647471e-02)*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V64_part17='V64_part16+7.716855e-01*S160+0.000000e+00*S161+2.087285e+00*S162+0.000000e+00*S163+0.000000e+00*S164+2.203409e-01*S165+3.108851e-01*S166+0.000000e+00*S167+6.753051e-01*S168+0.000000e+00*S169'
.param V64_part18='V64_part17+0.000000e+00*S170+2.971526e+00*S171+8.701829e-01*S172+2.033582e+00*S173+3.548719e+00*S174+1.475299e+00*S175+0.000000e+00*S176+3.697468e+00*S177+4.807341e+00*S178+4.900579e+00*S179'
.param V64_part19='V64_part18+3.361017e-01*S180+3.927634e-01*S181+7.419705e-01*S182+2.282455e+00*S183+1.052813e+00*S184+0.000000e+00*S185+2.694037e+00*S186+1.573473e+00*S187+5.850666e+00*S188+3.325551e+00*S189'
.param V64_part20='V64_part19+3.723797e+00*S190+7.013291e+00*S191+4.108553e+00*S192+4.741051e+00*S193+7.221123e+00*S194+8.681122e-01*S195+3.135122e-01*S196+0.000000e+00*S197+2.304277e-01*S198+3.951449e-01*S199'
.param V64_part21='V64_part20+3.627707e-01*S200+6.704615e-01*S201+5.120238e-01*S202+1.445691e+00*S203+9.977553e-01*S204+5.734772e-01*S205+1.247987e+00*S206+2.882753e+00*S207+3.904417e-01*S208+1.061415e+00*S209'
.param V64_part22='V64_part21+1.396713e-01*S210+0.000000e+00*S211+(-2.691590e-01)*S212+9.384186e-01*S213+1.681728e+00*S214+(-2.779829e-01)*S215+2.820431e+00*S216+0.000000e+00*S217+1.445301e-01*S218+3.229803e+00*S219'
.param V64_part23='V64_part22+5.314260e+00*S220+0.000000e+00*S221+4.303098e+00*S222+5.134728e+00*S223+6.786851e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+2.206547e+00*S228+3.187215e+00*S229'
.param V64_part24='V64_part23+0.000000e+00*S230+1.503069e+00*S231+3.794581e+00*S232+7.804108e+00*S233+3.943620e+00*S234+4.782354e+00*S235+7.801553e+00*S236+4.694578e+00*S237+5.854004e+00*S238+6.896489e+00*S239'
.param V64_part25='V64_part24+9.233472e-01*S240+0.000000e+00*S241+0.000000e+00*S242+2.321312e+00*S243+3.513621e+00*S244+4.772660e+00*S245+1.651380e+00*S246+4.902545e+00*S247+7.707616e+00*S248+3.947401e+00*S249'
.param V64_part26='V64_part25+5.944390e+00*S250+7.858899e+00*S251+4.305530e+00*S252+6.501978e+00*S253+7.837548e+00*S254+8.829165e-01*S255+2.040808e-01*S256+3.680439e-01*S257+1.155478e+00*S258+3.362279e-01*S259'
.param V64_part27='V64_part26+3.871058e-01*S260+3.207447e+00*S261+5.025676e+00*S262+2.919714e+00*S263+4.125012e+00*S264+4.848453e+00*S265+8.009886e+00*S266+4.583410e+00*S267+6.750226e+00*S268+7.807078e+00*S269'
.param V64_part28='V64_part27+1.870198e+00*S270+2.094205e+00*S271+0.000000e+00*S272+2.571217e+00*S273+0.000000e+00*S274+0.000000e+00*S275+3.525706e+00*S276+5.528500e+00*S277+7.991234e+00*S278+3.921442e+00*S279'
.param V64_part29='V64_part28+5.281037e+00*S280+7.864505e+00*S281+4.770985e+00*S282+6.320107e+00*S283+8.481757e+00*S284+2.254592e+00*S285+3.151995e+00*S286+5.574149e+00*S287+2.742996e+00*S288+5.344320e+00*S289'
.param V64_part30='V64_part29+8.369819e+00*S290+3.522101e+00*S291+5.282453e+00*S292+7.760269e+00*S293+3.812569e+00*S294+5.698851e+00*S295+8.560436e+00*S296+4.531032e+00*S297+6.646162e+00*S298+9.101517e+00*S299'
.param V64_part31='V64_part30+2.008292e+00*S300+1.420554e+00*S301+1.055752e+00*S302+3.295978e+00*S303+4.850726e+00*S304+1.572952e+00*S305+4.218784e+00*S306+5.507236e+00*S307+9.326668e+00*S308+4.719125e+00*S309'
.param V64='V64_part31+5.747045e+00*S310+9.184392e+00*S311+5.474851e+00*S312+6.293860e+00*S313+9.547019e+00*S314'
.param V65_part1='3.410937e+01*S0+1.688533e+01*S1+5.621918e+00*S2+0.000000e+00*S3+8.079060e+00*S4+7.565562e-02*S5+1.665595e+01*S6+2.240898e+00*S7+3.627740e+00*S8+7.520398e+03*S9'
.param V65_part2='V65_part1+0.000000e+00*S10+4.198378e+00*S11+3.781565e+00*S12+3.107323e+00*S13+5.454444e+00*S14+0.000000e+00*S15+3.991734e+00*S16+4.697221e+00*S17+0.000000e+00*S18+3.723663e+00*S19'
.param V65_part3='V65_part2+3.412673e+00*S20+0.000000e+00*S21+1.868023e+00*S22+(-6.118507e-02)*S23+7.624607e+00*S24+3.664204e+00*S25+3.620154e-02*S26+4.810909e-03*S27+7.748183e-02*S28+1.469493e-01*S29'
.param V65_part4='V65_part3+1.328658e+01*S30+7.240240e-02*S31+2.864968e+01*S32+1.125116e+01*S33+(-1.151485e-02)*S34+7.621764e+00*S35+6.493383e-01*S36+(-6.998958e+01)*S37+5.427319e+00*S38+2.585816e+00*S39'
.param V65_part5='V65_part4+1.000000e+04*S40+4.618396e-01*S41+5.221241e+00*S42+5.925620e-01*S43+6.252266e-01*S44+0.000000e+00*S45+0.000000e+00*S46+4.486075e+00*S47+5.548934e+01*S48+1.318218e+01*S49'
.param V65_part6='V65_part5+5.574824e+00*S50+1.171087e-01*S51+1.125676e+00*S52+1.223500e+01*S53+2.414705e+01*S54+6.345918e+00*S55+1.255704e+01*S56+3.145352e+02*S57+3.519595e+01*S58+2.099631e+01*S59'
.param V65_part7='V65_part6+2.243941e+00*S60+1.409913e+00*S61+8.268808e+00*S62+1.141374e+00*S63+1.612803e+03*S64+2.310142e+00*S65+3.534883e+00*S66+(-4.773978e-02)*S67+(-9.038823e-02)*S68+9.493108e+00*S69'
.param V65_part8='V65_part7+(-9.929016e-02)*S70+(-1.214690e-01)*S71+3.822925e+00*S72+(-1.706807e-01)*S73+(-8.450071e-02)*S74+4.929307e+01*S75+0.000000e+00*S76+6.678425e+00*S77+1.626232e+00*S78+8.436367e+00*S79'
.param V65_part9='V65_part8+2.052763e-01*S80+4.655620e+00*S81+6.980099e-02*S82+2.767363e-01*S83+4.993689e+00*S84+2.268759e-01*S85+3.328953e-01*S86+2.069679e-01*S87+1.977376e-01*S88+2.246464e-01*S89'
.param V65_part10='V65_part9+(-1.002277e-01)*S90+1.601096e+01*S91+4.828737e+00*S92+9.134302e+00*S93+7.445997e+00*S94+3.051451e+00*S95+1.227826e+01*S96+6.679056e+00*S97+4.570846e+00*S98+1.389178e+01*S99'
.param V65_part11='V65_part10+4.145674e+00*S100+(-5.067352e-01)*S101+4.483566e+00*S102+1.482926e+00*S103+1.329910e+01*S104+2.020764e+01*S105+1.169174e+01*S106+7.851635e+01*S107+2.706277e+01*S108+1.591731e+01*S109'
.param V65_part12='V65_part11+4.885301e+00*S110+1.643071e-01*S111+7.745529e+00*S112+(-5.087818e-01)*S113+(-1.459014e-01)*S114+1.772249e+01*S115+4.164758e+01*S116+1.346400e+03*S117+4.585410e+01*S118+5.380455e+00*S119'
.param V65_part13='V65_part12+3.826323e+00*S120+(-5.952401e-02)*S121+1.066146e-03*S122+4.377713e+00*S123+(-1.133016e-01)*S124+1.310522e+00*S125+9.166878e-01*S126+(-4.931335e-02)*S127+2.036303e+00*S128+3.657377e+00*S129'
.param V65_part14='V65_part13+8.352334e-01*S130+9.168826e-01*S131+4.197379e+00*S132+2.261118e+00*S133+9.810211e-01*S134+2.612541e+01*S135+1.482826e+01*S136+5.515510e+01*S137+4.705499e+00*S138+2.070889e+01*S139'
.param V65_part15='V65_part14+1.265668e-01*S140+9.316619e+00*S141+9.760514e-02*S142+2.054423e+00*S143+7.723752e-01*S144+3.028729e-02*S145+2.445924e-01*S146+(-3.491589e+00)*S147+(-8.744670e-02)*S148+(-1.769847e-01)*S149'
.param V65_part16='V65_part15+(-2.032844e-01)*S150+(-1.357845e-02)*S151+3.036444e+00*S152+5.180409e+00*S153+(-1.049025e-01)*S154+4.081555e+00*S155+6.760856e+00*S156+3.922981e+00*S157+4.062937e-01*S158+5.311929e+00*S159'
.param V65_part17='V65_part16+5.080892e+00*S160+3.717323e+00*S161+4.918735e+00*S162+4.973085e+00*S163+2.511003e+03*S164+1.978109e+01*S165+(-7.948729e-02)*S166+2.895551e+00*S167+3.635979e+01*S168+5.764092e+00*S169'
.param V65_part18='V65_part17+3.391680e+00*S170+7.805933e+00*S171+8.289468e+00*S172+4.824014e+01*S173+8.374472e+00*S174+5.127678e+01*S175+2.497492e+01*S176+3.046250e+00*S177+8.447198e+00*S178+1.791050e+01*S179'
.param V65_part19='V65_part18+9.563741e+00*S180+1.760528e-01*S181+1.586966e+01*S182+1.770133e+02*S183+4.787587e+00*S184+3.908513e-01*S185+1.159028e+01*S186+3.482275e+00*S187+6.826010e+00*S188+1.955236e+00*S189'
.param V65_part20='V65_part19+1.127562e+00*S190+2.655872e+00*S191+1.045543e+01*S192+1.223598e+01*S193+2.187401e+01*S194+1.242360e+01*S195+1.484257e+00*S196+(-2.968755e-02)*S197+1.708781e+00*S198+3.416250e-02*S199'
.param V65_part21='V65_part20+3.733095e-01*S200+3.032547e+00*S201+4.507606e-02*S202+9.632114e-01*S203+2.055434e+01*S204+1.250709e+00*S205+4.156565e-01*S206+1.092685e+00*S207+1.358127e+00*S208+8.463255e-01*S209'
.param V65_part22='V65_part21+1.010295e+01*S210+5.074474e-01*S211+3.216013e+00*S212+2.488529e+03*S213+6.497458e+00*S214+3.555094e+00*S215+3.076399e+00*S216+4.898955e+00*S217+4.561768e+00*S218+4.138095e+00*S219'
.param V65_part23='V65_part22+6.245275e+00*S220+3.405190e+00*S221+2.730153e+00*S222+3.729870e+00*S223+4.231876e+00*S224+7.563990e+03*S225+5.049419e+00*S226+(-4.203329e-01)*S227+5.486175e+00*S228+3.822979e+00*S229'
.param V65_part24='V65_part23+9.781651e-01*S230+1.978283e+01*S231+2.702331e+00*S232+3.591533e+01*S233+8.027550e+00*S234+2.606132e+00*S235+4.024580e+01*S236+6.562359e+00*S237+1.753503e+01*S238+3.475296e+01*S239'
.param V65_part25='V65_part24+5.231976e+00*S240+4.586438e-01*S241+(-3.922119e-01)*S242+2.808473e+00*S243+2.408065e+00*S244+6.699808e-01*S245+8.476500e+01*S246+2.481232e+01*S247+3.810434e+01*S248+1.075187e+01*S249'
.param V65_part26='V65_part25+5.519037e+00*S250+3.217193e+01*S251+1.023628e+01*S252+2.867643e+00*S253+2.804354e+01*S254+2.139659e+00*S255+2.021777e+01*S256+6.648509e-01*S257+4.393649e+00*S258+8.685092e-01*S259'
.param V65_part27='V65_part26+7.421175e-02*S260+4.149865e+00*S261+3.826633e+00*S262+1.942417e+02*S263+6.810734e+01*S264+6.131235e-01*S265+3.543253e+01*S266+1.200032e+01*S267+1.963142e+00*S268+1.958295e+01*S269'
.param V65_part28='V65_part27+6.859572e+00*S270+8.944005e+00*S271+(-3.290257e-01)*S272+4.434186e+00*S273+6.691700e+00*S274+5.432784e-01*S275+1.044732e+01*S276+4.635556e+00*S277+1.141358e+02*S278+5.530637e+00*S279'
.param V65_part29='V65_part28+2.438200e+00*S280+5.869059e+01*S281+1.119781e+01*S282+2.096396e+01*S283+2.881930e+00*S284+4.907029e+00*S285+2.644450e+00*S286+1.891079e+01*S287+2.179504e+03*S288+1.487694e+03*S289'
.param V65_part30='V65_part29+7.955437e+01*S290+1.942403e+01*S291+1.811611e+01*S292+2.316289e+00*S293+2.588323e+00*S294+1.827729e+01*S295+2.528954e+00*S296+1.292908e+01*S297+4.528512e+00*S298+2.313565e+00*S299'
.param V65_part31='V65_part30+5.005509e+00*S300+1.626623e+00*S301+2.296304e+00*S302+1.324055e+01*S303+3.421166e+00*S304+2.277060e+00*S305+2.886373e+00*S306+2.352553e+01*S307+6.100762e+01*S308+3.453892e+00*S309'
.param V65='V65_part31+2.509117e+01*S310+2.641532e+01*S311+2.593877e+00*S312+2.144985e+01*S313+1.497455e+01*S314'
.param V66_part1='(-6.731446e+01)*S0+(-3.809257e+01)*S1+(-4.881285e+00)*S2+0.000000e+00*S3+(-8.503012e+00)*S4+1.271666e-01*S5+(-2.192396e+00)*S6+(-1.527690e+00)*S7+(-2.340935e-01)*S8+(-1.836778e+01)*S9'
.param V66_part2='V66_part1+0.000000e+00*S10+(-1.520427e+00)*S11+(-1.310434e+00)*S12+(-7.772273e-01)*S13+(-4.957374e-03)*S14+0.000000e+00*S15+(-4.932028e+00)*S16+(-2.557783e+00)*S17+0.000000e+00*S18+(-2.333957e+00)*S19'
.param V66_part3='V66_part2+(-1.930700e+00)*S20+0.000000e+00*S21+(-5.417866e-01)*S22+2.261307e-01*S23+(-2.099019e+00)*S24+(-2.029231e+00)*S25+1.529193e-01*S26+1.601375e-01*S27+4.918215e-02*S28+5.351806e-02*S29'
.param V66_part4='V66_part3+(-9.743549e-01)*S30+3.595173e-01*S31+(-4.856005e+00)*S32+5.886368e+00*S33+6.484017e-01*S34+(-8.484689e-01)*S35+1.633636e+01*S36+8.857060e+00*S37+(-1.994949e+00)*S38+9.882983e+00*S39'
.param V66_part5='V66_part4+1.000000e+04*S40+1.367396e-01*S41+3.148427e+00*S42+(-1.556231e-01)*S43+(-6.579466e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+(-1.018363e+00)*S47+(-3.386641e+01)*S48+(-5.844328e+00)*S49'
.param V66_part6='V66_part5+(-6.540710e-01)*S50+1.877129e-01*S51+1.053246e+01*S52+(-1.466697e+01)*S53+(-8.946569e+00)*S54+(-1.256843e+00)*S55+(-1.383435e+01)*S56+(-2.848485e+01)*S57+(-1.873947e+00)*S58+(-2.515996e+01)*S59'
.param V66_part7='V66_part6+(-3.233586e+00)*S60+1.160503e+00*S61+(-4.129784e+00)*S62+1.665544e+00*S63+1.314631e+02*S64+(-1.067259e+00)*S65+(-1.004818e+00)*S66+1.373069e-01*S67+1.587829e-01*S68+(-4.478756e+00)*S69'
.param V66_part8='V66_part7+1.613328e-01*S70+1.708480e-01*S71+(-1.380554e+00)*S72+1.844787e-01*S73+1.617688e-01*S74+(-1.354931e+01)*S75+0.000000e+00*S76+7.491547e-01*S77+(-1.293392e+00)*S78+(-4.043665e+00)*S79'
.param V66_part9='V66_part8+(-1.075000e-03)*S80+(-8.898079e-01)*S81+2.728263e-01*S82+2.210501e-02*S83+(-1.669817e+00)*S84+8.976415e-02*S85+2.140093e-02*S86+2.184780e-01*S87+8.621437e-02*S88+2.171295e-01*S89'
.param V66_part10='V66_part9+5.235809e-01*S90+(-1.307777e+01)*S91+(-2.621216e+00)*S92+(-1.958358e+00)*S93+(-3.110459e+00)*S94+(-3.124248e+00)*S95+(-5.031506e+00)*S96+(-3.100387e+00)*S97+(-1.119972e+00)*S98+(-4.603343e+00)*S99'
.param V66_part11='V66_part10+(-1.966887e+00)*S100+7.996099e-01*S101+(-1.464088e+00)*S102+(-2.942181e-01)*S103+(-8.740216e+00)*S104+1.005085e+02*S105+1.538720e-02*S106+(-9.711141e+00)*S107+4.913222e+01*S108+(-9.535507e+00)*S109'
.param V66_part12='V66_part11+6.406503e+01*S110+3.330566e-01*S111+(-2.691479e+01)*S112+8.231412e-01*S113+5.035369e-01*S114+(-8.379000e+00)*S115+(-3.109707e+00)*S116+6.054659e+01*S117+(-8.780089e+00)*S118+(-1.616886e+00)*S119'
.param V66_part13='V66_part12+2.109131e+02*S120+2.488503e-01*S121+2.204894e-01*S122+(-2.483843e+00)*S123+1.927154e-02*S124+(-9.139978e-02)*S125+(-5.280368e-02)*S126+6.404180e-01*S127+(-7.967645e-01)*S128+(-1.985251e+00)*S129'
.param V66_part14='V66_part13+3.028953e-01*S130+(-3.430497e-01)*S131+(-1.580234e+00)*S132+(-6.748987e-01)*S133+(-2.696374e-01)*S134+8.101047e+00*S135+(-6.717991e+00)*S136+(-4.138798e+01)*S137+(-1.308040e+00)*S138+(-1.148737e+01)*S139'
.param V66_part15='V66_part14+5.354625e-02*S140+1.306443e+00*S141+6.943388e-01*S142+7.026784e-01*S143+(-4.127191e-02)*S144+6.799813e-01*S145+6.599821e-01*S146+5.369039e+00*S147+6.463741e-01*S148+5.647659e-01*S149'
.param V66_part16='V66_part15+6.593056e-01*S150+6.655477e-01*S151+(-1.569686e+00)*S152+(-5.375343e+00)*S153+6.691028e-01*S154+(-2.048241e+00)*S155+(-3.032920e+00)*S156+(-7.391652e-01)*S157+(-4.222872e-02)*S158+(-2.047108e+00)*S159'
.param V66_part17='V66_part16+(-1.997793e+00)*S160+(-2.484570e+00)*S161+7.279403e-03*S162+(-1.422281e+00)*S163+(-1.085545e+01)*S164+(-3.403379e+01)*S165+4.610432e-01*S166+1.269324e-01*S167+3.216097e+01*S168+(-2.478591e+00)*S169'
.param V66_part18='V66_part17+(-8.807657e-01)*S170+(-4.565045e+00)*S171+(-3.380281e+00)*S172+(-1.443448e+01)*S173+(-3.736654e+00)*S174+(-1.204999e+01)*S175+(-5.221423e+00)*S176+(-8.103310e-01)*S177+(-2.547636e+00)*S178+(-3.422856e+00)*S179'
.param V66_part19='V66_part18+(-7.477336e+00)*S180+8.933845e-01*S181+(-1.269096e+00)*S182+8.164892e+00*S183+(-1.914087e+00)*S184+3.156182e-01*S185+(-3.661521e+00)*S186+(-1.283483e+00)*S187+5.289175e-01*S188+(-8.205870e-01)*S189'
.param V66_part20='V66_part19+1.157869e-01*S190+(-1.044085e+00)*S191+(-4.282483e+00)*S192+(-3.821231e+00)*S193+(-2.973992e+00)*S194+1.086125e+01*S195+1.357263e+00*S196+2.405754e-01*S197+(-1.298727e+00)*S198+6.172626e-01*S199'
.param V66_part21='V66_part20+1.128668e-01*S200+(-1.232198e+00)*S201+6.284753e-01*S202+3.459044e-01*S203+(-2.415988e+00)*S204+7.270233e-01*S205+2.998318e-01*S206+(-1.349178e-01)*S207+(-1.180881e-01)*S208+(-1.523844e-01)*S209'
.param V66_part22='V66_part21+(-9.963065e+00)*S210+8.155020e-01*S211+(-1.612080e+00)*S212+5.585518e+00*S213+(-4.102532e+00)*S214+(-1.364396e+00)*S215+(-9.928829e-01)*S216+(-1.716269e+00)*S217+(-1.103320e+00)*S218+(-7.967304e-01)*S219'
.param V66_part23='V66_part22+(-2.504703e+00)*S220+(-1.391854e+00)*S221+(-5.038305e-01)*S222+(-1.035348e+00)*S223+(-1.180010e+00)*S224+(-2.223063e+02)*S225+(-2.098184e+00)*S226+1.202070e+00*S227+(-5.376919e+00)*S228+(-1.467170e+00)*S229'
.param V66_part24='V66_part23+(-1.804653e-01)*S230+(-1.306245e+01)*S231+(-1.690487e-01)*S232+(-3.944392e+00)*S233+(-3.528765e+00)*S234+(-4.010916e-01)*S235+(-5.262034e+00)*S236+(-2.667127e+00)*S237+(-4.488010e+00)*S238+(-7.255681e+00)*S239'
.param V66_part25='V66_part24+(-7.418142e+00)*S240+3.346151e-01*S241+1.445085e+00*S242+(-1.004412e+00)*S243+(-1.111197e+00)*S244+4.272464e-01*S245+(-9.019748e+01)*S246+(-5.949502e+00)*S247+(-4.984215e+00)*S248+(-2.686209e+00)*S249'
.param V66_part26='V66_part25+(-1.678501e+00)*S250+(-3.970410e+00)*S251+(-2.411506e+00)*S252+(-8.161391e-01)*S253+(-5.880261e+00)*S254+(-1.354215e+00)*S255+(-2.661938e+01)*S256+6.174672e-01*S257+(-1.180852e+00)*S258+1.317096e+00*S259'
.param V66_part27='V66_part26+8.892135e-01*S260+(-1.023608e+00)*S261+(-1.371975e+00)*S262+7.520208e-02*S263+(-1.107671e+01)*S264+2.807785e-01*S265+(-5.231325e+00)*S266+(-8.539347e-01)*S267+(-4.767189e-01)*S268+(-3.468632e+00)*S269'
.param V66_part28='V66_part27+1.565475e+00*S270+(-5.750686e+00)*S271+1.228700e+00*S272+(-1.853758e+00)*S273+(-1.623317e+00)*S274+5.229222e-01*S275+(-4.741043e+00)*S276+(-1.480062e+00)*S277+(-6.845370e+00)*S278+(-7.501778e-01)*S279'
.param V66_part29='V66_part28+(-4.441784e-01)*S280+(-3.278633e+00)*S281+(-4.117140e+00)*S282+(-5.630388e+00)*S283+(-7.834111e-01)*S284+(-1.387713e+00)*S285+(-3.237429e-01)*S286+(-4.071068e+00)*S287+2.467725e+01*S288+1.361953e+02*S289'
.param V66_part30='V66_part29+(-9.065928e+00)*S290+(-2.251061e+00)*S291+(-4.010478e+00)*S292+(-6.802678e-01)*S293+(-1.040636e+00)*S294+(-4.126411e+00)*S295+(-7.749859e-01)*S296+(-2.321807e+00)*S297+(-1.389592e+00)*S298+(-6.945737e-01)*S299'
.param V66_part31='V66_part30+(-1.957567e+00)*S300+2.905294e-01*S301+(-8.608831e-01)*S302+(-7.134865e+00)*S303+3.080018e-01*S304+(-8.694177e-01)*S305+(-7.098513e-01)*S306+(-7.894231e+00)*S307+(-5.247264e+00)*S308+(-6.921894e-01)*S309'
.param V66='V66_part31+(-7.773230e+00)*S310+(-3.263324e+00)*S311+(-5.707654e-01)*S312+(-6.880244e+00)*S313+(-2.328436e+00)*S314'
.param V67_part1='(-1.070602e-02)*S0+3.970499e+00*S1+(-1.777088e+00)*S2+0.000000e+00*S3+(-1.934606e+00)*S4+(-5.572277e-03)*S5+(-7.751571e+00)*S6+3.346337e-01*S7+(-1.638987e+00)*S8+(-3.829705e+00)*S9'
.param V67_part2='V67_part1+0.000000e+00*S10+(-1.216196e+00)*S11+(-1.201751e+00)*S12+(-1.513236e+00)*S13+(-2.339343e+00)*S14+0.000000e+00*S15+(-1.597633e+00)*S16+(-1.521569e+00)*S17+0.000000e+00*S18+(-1.304860e+00)*S19'
.param V67_part3='V67_part2+(-3.708974e-01)*S20+0.000000e+00*S21+(-1.336743e-01)*S22+1.269782e-01*S23+(-2.966110e+00)*S24+(-1.329607e+00)*S25+1.038620e-01*S26+(-1.719851e-02)*S27+1.176224e-01*S28+5.567878e-02*S29'
.param V67_part4='V67_part3+1.605327e+00*S30+2.804162e-01*S31+(-2.407724e+00)*S32+2.126676e-01*S33+2.862344e-01*S34+(-1.622679e+00)*S35+9.136196e+00*S36+2.548558e+02*S37+(-4.062245e-01)*S38+6.449352e+00*S39'
.param V67_part5='V67_part4+2.566653e+03*S40+(-1.064534e-01)*S41+3.575953e+00*S42+4.307231e-01*S43+(-9.870572e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+(-1.616995e+00)*S47+(-2.492905e+01)*S48+(-7.560910e+00)*S49'
.param V67_part6='V67_part5+(-2.195524e+00)*S50+(-2.353860e-01)*S51+2.612561e+01*S52+1.080172e+01*S53+(-3.034270e+01)*S54+1.883274e+00*S55+1.287726e+01*S56+(-2.592859e+01)*S57+1.076441e+02*S58+2.272463e+01*S59'
.param V67_part7='V67_part6+(-1.632477e+00)*S60+(-6.759212e-01)*S61+(-3.411916e+00)*S62+(-2.552916e+00)*S63+1.767897e+03*S64+(-9.899652e-02)*S65+(-2.404863e+00)*S66+7.248731e-02*S67+9.389408e-02*S68+(-1.353066e+01)*S69'
.param V67_part8='V67_part7+2.911981e-02*S70+1.319671e-01*S71+(-1.349680e+00)*S72+1.775879e-01*S73+1.817440e-01*S74+(-1.020751e+01)*S75+0.000000e+00*S76+(-2.290177e+00)*S77+(-3.837717e-02)*S78+(-4.400257e+00)*S79'
.param V67_part9='V67_part8+3.344036e-02*S80+(-6.085124e+00)*S81+8.016963e-02*S82+(-1.829057e-02)*S83+(-5.933819e+00)*S84+4.579286e-02*S85+(-6.069526e-02)*S86+(-3.423508e-01)*S87+5.926933e-02*S88+(-3.467431e-03)*S89'
.param V67_part10='V67_part9+4.027961e-01*S90+(-9.671528e+00)*S91+(-7.990978e-01)*S92+(-9.671825e+00)*S93+(-4.208927e+00)*S94+1.343869e+00*S95+(-4.152329e+00)*S96+4.257778e-02*S97+(-1.613259e+00)*S98+1.026548e+00*S99'
.param V67_part11='V67_part10+(-5.805589e-01)*S100+3.926556e-01*S101+(-3.007272e+00)*S102+4.488082e-01*S103+2.722467e+01*S104+5.955016e+01*S105+(-3.639250e+00)*S106+(-5.086991e+01)*S107+4.316978e+01*S108+2.558234e+01*S109'
.param V67_part12='V67_part11+4.849794e+01*S110+4.094536e-01*S111+6.337827e+01*S112+3.772683e-01*S113+5.067187e-01*S114+(-7.218410e+00)*S115+(-2.879380e+01)*S116+3.967876e+03*S117+(-1.951258e+01)*S118+(-1.591486e+00)*S119'
.param V67_part13='V67_part12+(-9.706695e+01)*S120+7.471390e-02*S121+2.425515e-01*S122+3.906683e+00*S123+1.268897e+00*S124+(-1.854274e-02)*S125+3.693356e-01*S126+7.305522e-01*S127+(-2.242004e-01)*S128+6.577680e-01*S129'
.param V67_part14='V67_part13+7.691423e-01*S130+4.424991e-01*S131+(-3.580950e-01)*S132+(-1.247854e-01)*S133+4.457058e-01*S134+(-3.368684e+01)*S135+(-1.197533e+01)*S136+(-2.320141e+01)*S137+(-4.988640e+00)*S138+(-1.155922e+01)*S139'
.param V67_part15='V67_part14+1.105657e-02*S140+(-2.880516e+00)*S141+6.164333e-01*S142+(-9.295591e-02)*S143+7.736735e-01*S144+9.351988e-01*S145+6.045272e-01*S146+2.125793e+01*S147+5.915976e-01*S148+9.849187e-01*S149'
.param V67_part16='V67_part15+4.012909e-01*S150+(-3.712630e-02)*S151+3.559904e-01*S152+(-1.040441e+00)*S153+5.406525e-02*S154+(-2.979883e-01)*S155+(-7.308353e+00)*S156+(-2.180159e+00)*S157+9.241890e-01*S158+(-2.676542e+00)*S159'
.param V67_part17='V67_part16+(-2.174851e+00)*S160+9.273204e-01*S161+6.732066e+00*S162+(-1.820083e+00)*S163+1.637561e+01*S164+(-5.256215e+00)*S165+7.540214e-02*S166+(-9.254753e-01)*S167+(-4.593799e+00)*S168+(-3.339641e+00)*S169'
.param V67_part18='V67_part17+(-1.364317e+00)*S170+(-5.495159e+00)*S171+(-4.406810e+00)*S172+(-1.764293e+01)*S173+(-4.768112e+00)*S174+(-1.891556e+01)*S175+(-1.015865e+01)*S176+(-1.913959e+00)*S177+(-3.637662e+00)*S178+(-4.845807e+00)*S179'
.param V67_part19='V67_part18+(-9.348586e+00)*S180+(-5.612974e-02)*S181+(-3.983689e+00)*S182+6.312398e+01*S183+(-2.077705e+00)*S184+9.409166e-01*S185+(-3.690405e-01)*S186+(-7.858706e-01)*S187+(-2.778667e+00)*S188+3.018821e+00*S189'
.param V67_part20='V67_part19+3.868910e-01*S190+(-4.444912e-01)*S191+(-4.594564e+00)*S192+(-5.431658e+00)*S193+(-9.999029e+00)*S194+(-2.308273e+01)*S195+2.284085e-01*S196+1.658582e-01*S197+(-8.931611e-01)*S198+5.772399e-01*S199'
.param V67_part21='V67_part20+2.733197e-01*S200+(-2.281412e+00)*S201+1.106918e+00*S202+3.535312e-02*S203+(-2.522901e+01)*S204+1.664368e+00*S205+3.162751e-01*S206+5.044222e-01*S207+1.738187e+00*S208+4.292626e-01*S209'
.param V67_part22='V67_part21+(-4.724745e+00)*S210+(-1.754149e-01)*S211+(-6.667329e-01)*S212+1.106135e+02*S213+(-3.453275e+00)*S214+(-6.062683e-01)*S215+(-2.626032e+00)*S216+(-8.185760e-01)*S217+(-1.537902e+00)*S218+(-4.031545e+00)*S219'
.param V67_part23='V67_part22+(-2.500159e+00)*S220+(-5.401642e-01)*S221+(-1.873984e+00)*S222+(-1.760139e+00)*S223+(-1.133026e+00)*S224+(-2.240763e+01)*S225+(-3.610965e+00)*S226+7.079966e-01*S227+6.144393e-01*S228+(-2.048299e+00)*S229'
.param V67_part24='V67_part23+8.551818e-01*S230+(-1.378535e+01)*S231+(-5.666778e-02)*S232+(-1.809171e+01)*S233+(-4.753287e+00)*S234+(-1.370593e-01)*S235+(-1.957975e+01)*S236+(-3.024350e+00)*S237+(-9.673102e+00)*S238+(-1.226148e+01)*S239'
.param V67_part25='V67_part24+(-9.130138e-02)*S240+4.154869e-02*S241+6.981200e-01*S242+(-2.768430e+00)*S243+(-8.306850e-01)*S244+3.149637e-01*S245+(-2.624486e+01)*S246+(-1.341235e+01)*S247+(-2.055302e+01)*S248+(-1.006016e+01)*S249'
.param V67_part26='V67_part25+(-2.631557e+00)*S250+(-1.756476e+01)*S251+8.564968e+00*S252+(-2.710890e-01)*S253+(-1.296762e+01)*S254+(-1.150596e+00)*S255+(-1.260647e+01)*S256+3.784336e-01*S257+(-1.507432e+00)*S258+4.802923e-01*S259'
.param V67_part27='V67_part26+5.559344e-01*S260+(-3.879342e+00)*S261+(-2.241795e+00)*S262+(-1.371870e+01)*S263+1.624773e+01*S264+9.208910e-02*S265+(-1.731073e+01)*S266+8.357774e+00*S267+(-2.854054e-01)*S268+(-1.012110e+01)*S269'
.param V67_part28='V67_part27+(-8.453699e+00)*S270+(-4.516740e+00)*S271+9.754210e-01*S272+(-4.515544e+00)*S273+(-6.412003e-01)*S274+6.571711e-01*S275+(-6.873794e+00)*S276+(-2.725941e+00)*S277+(-5.698793e+01)*S278+4.633209e+00*S279'
.param V67_part29='V67_part28+(-1.013365e-01)*S280+(-3.363047e+01)*S281+(-6.641941e+00)*S282+(-1.136652e+01)*S283+(-7.273585e-01)*S284+(-6.058445e+00)*S285+(-1.818217e+00)*S286+(-1.085440e+01)*S287+3.825199e+02*S288+8.615110e+02*S289'
.param V67_part30='V67_part29+(-4.321491e+01)*S290+(-2.167429e+01)*S291+(-1.021545e+01)*S292+(-6.956036e-01)*S293+(-2.812230e-01)*S294+(-1.040007e+01)*S295+(-7.064831e-01)*S296+9.042766e+00*S297+(-2.043034e+00)*S298+(-5.895458e-01)*S299'
.param V67_part31='V67_part30+(-6.899753e+00)*S300+(-5.232216e-01)*S301+(-4.588084e-01)*S302+(-6.630690e+00)*S303+(-1.041564e+00)*S304+(-4.242552e-01)*S305+(-2.722428e+00)*S306+(-1.172013e+01)*S307+(-3.679391e+01)*S308+(-3.337127e+00)*S309'
.param V67='V67_part31+(-1.158585e+01)*S310+(-1.468783e+01)*S311+(-1.934583e+00)*S312+(-1.013723e+01)*S313+(-6.854571e+00)*S314'
.param V68_part1='8.315175e+00*S0+4.902293e+00*S1+(-8.634140e-01)*S2+0.000000e+00*S3+(-2.506845e+00)*S4+4.888501e-01*S5+(-7.763286e+00)*S6+(-1.149980e+00)*S7+(-6.021706e-01)*S8+(-1.000000e+04)*S9'
.param V68_part2='V68_part1+0.000000e+00*S10+(-1.975136e-01)*S11+(-1.826724e+00)*S12+(-9.029706e-02)*S13+(-3.664368e-01)*S14+0.000000e+00*S15+(-1.237628e+00)*S16+(-9.868634e-01)*S17+0.000000e+00*S18+(-1.201373e+00)*S19'
.param V68_part3='V68_part2+(-8.324679e-01)*S20+0.000000e+00*S21+(-6.458897e-01)*S22+5.487069e-01*S23+9.455120e-02*S24+1.552543e-01*S25+6.312066e-01*S26+2.882224e-01*S27+2.984767e-01*S28+5.671594e-01*S29'
.param V68_part4='V68_part3+(-5.811800e+00)*S30+8.295816e-03*S31+(-1.909021e+01)*S32+(-7.853857e+00)*S33+8.727823e-02*S34+(-2.208092e+00)*S35+(-8.864345e+00)*S36+1.099990e+01*S37+(-1.048340e+00)*S38+(-8.738802e+00)*S39'
.param V68_part5='V68_part4+1.284748e+01*S40+(-1.366655e-01)*S41+(-6.783947e+00)*S42+(-2.148286e-01)*S43+(-1.381189e-01)*S44+0.000000e+00*S45+0.000000e+00*S46+(-3.758777e-02)*S47+(-2.272530e+01)*S48+9.587296e-01*S49'
.param V68_part6='V68_part5+(-2.165387e-01)*S50+8.193352e-02*S51+(-2.408018e+00)*S52+(-1.573924e+00)*S53+2.888974e+00*S54+(-7.090961e-01)*S55+(-8.004862e-01)*S56+1.059567e+03*S57+2.228553e+02*S58+(-4.756542e-01)*S59'
.param V68_part7='V68_part6+3.160242e-02*S60+5.379555e-01*S61+(-5.359421e-01)*S62+3.542155e-01*S63+1.409982e+02*S64+7.608446e-01*S65+8.509437e-01*S66+2.791669e-02*S67+6.279062e-02*S68+8.538154e-01*S69'
.param V68_part8='V68_part7+3.819868e-02*S70+9.535734e-02*S71+3.439676e-02*S72+1.140744e-01*S73+1.214226e-01*S74+1.326475e+02*S75+0.000000e+00*S76+(-2.398248e+00)*S77+(-4.577440e-01)*S78+(-1.091799e+00)*S79'
.param V68_part9='V68_part8+1.042073e-01*S80+9.950763e-01*S81+1.614210e-01*S82+8.411841e-02*S83+5.292379e-01*S84+1.179463e-01*S85+5.296334e-02*S86+4.925119e-01*S87+1.147723e-01*S88+5.343876e-01*S89'
.param V68_part10='V68_part9+2.065997e-01*S90+(-1.959994e-01)*S91+4.143134e-01*S92+(-2.954889e-01)*S93+1.161869e-01*S94+(-6.380754e-02)*S95+(-2.385849e-01)*S96+2.455025e-02*S97+(-1.347291e-01)*S98+5.251495e-01*S99'
.param V68_part11='V68_part10+1.568445e-02*S100+2.020684e-01*S101+9.886754e-01*S102+(-9.914103e-04)*S103+3.879478e+01*S104+(-7.178838e+00)*S105+8.276775e-01*S106+(-1.002962e+01)*S107+(-1.632579e+00)*S108+(-3.895158e+00)*S109'
.param V68_part12='V68_part11+2.321395e+02*S110+9.197175e-01*S111+2.747713e+00*S112+2.021080e-01*S113+2.700488e-01*S114+(-2.185253e+00)*S115+(-3.899836e+00)*S116+(-2.965814e+03)*S117+(-2.248130e+01)*S118+(-2.818973e-01)*S119'
.param V68_part13='V68_part12+1.463311e+01*S120+2.192368e-02*S121+4.354696e-01*S122+7.044856e-01*S123+1.364298e+00*S124+6.143636e-01*S125+1.929004e+00*S126+1.104659e+00*S127+5.057795e-01*S128+2.330825e+00*S129'
.param V68_part14='V68_part13+1.201961e+00*S130+8.917663e-01*S131+9.979155e-01*S132+1.306790e+00*S133+9.290005e-01*S134+1.234049e+01*S135+(-1.537182e+00)*S136+(-2.956045e+00)*S137+(-2.549872e-02)*S138+(-2.588578e+00)*S139'
.param V68_part15='V68_part14+3.829047e-02*S140+1.077849e+00*S141+1.434415e+00*S142+6.196690e-01*S143+1.581143e+00*S144+1.633360e+00*S145+5.962372e-01*S146+4.000671e+00*S147+1.013956e+00*S148+1.578787e+00*S149'
.param V68_part16='V68_part15+9.860928e-02*S150+(-1.165373e-02)*S151+(-6.284909e-02)*S152+9.357914e-01*S153+2.187474e-01*S154+(-3.168550e-03)*S155+8.866076e-01*S156+1.369293e-01*S157+4.182251e-01*S158+(-5.284225e-01)*S159'
.param V68_part17='V68_part16+(-1.952352e-01)*S160+5.971799e-02*S161+1.423086e+01*S162+(-3.050887e-01)*S163+1.000000e+04*S164+3.322317e-01*S165+2.349276e-02*S166+1.421652e+00*S167+(-1.045526e+00)*S168+5.816224e-02*S169'
.param V68_part18='V68_part17+1.013157e+00*S170+(-6.714112e-01)*S171+(-9.746355e-01)*S172+(-1.607295e+01)*S173+(-8.751323e-01)*S174+(-2.560906e+01)*S175+(-7.169245e+00)*S176+3.051194e-01*S177+(-1.273848e+00)*S178+(-7.025635e+00)*S179'
.param V68_part19='V68_part18+9.215248e-01*S180+8.047639e-01*S181+7.539122e+00*S182+5.022026e+02*S183+2.120302e+00*S184+1.483458e+00*S185+1.750682e+01*S186+1.315773e+00*S187+(-1.729126e+00)*S188+1.910117e+00*S189'
.param V68_part20='V68_part19+1.657975e+00*S190+2.074790e-01*S191+(-1.431606e+00)*S192+(-2.409710e+00)*S193+(-5.609410e+00)*S194+2.919609e-01*S195+3.566171e+00*S196+9.365829e-03*S197+6.280768e-01*S198+8.721303e-01*S199'
.param V68_part21='V68_part20+6.386781e-01*S200+1.849659e+00*S201+1.372114e+00*S202+7.278553e-01*S203+(-4.627985e+00)*S204+3.252854e+00*S205+6.836138e-01*S206+8.755358e-01*S207+3.028545e+00*S208+7.736439e-01*S209'
.param V68_part22='V68_part21+(-6.686211e-01)*S210+4.460135e-01*S211+8.496585e-03*S212+1.000000e+04*S213+(-2.760033e-01)*S214+(-2.196771e-02)*S215+1.725658e-01*S216+(-1.133344e+00)*S217+(-8.740742e-02)*S218+1.287393e-01*S219'
.param V68_part23='V68_part22+(-5.749954e-01)*S220+(-1.083075e-01)*S221+2.163682e-01*S222+(-2.634003e-01)*S223+(-2.872830e-01)*S224+(-9.982347e+03)*S225+1.028356e-01*S226+3.571654e-01*S227+3.152805e+00*S228+1.936031e+00*S229'
.param V68_part24='V68_part23+1.287530e+00*S230+6.895763e-01*S231+3.452485e+00*S232+(-1.184688e+01)*S233+(-5.532635e-01)*S234+2.115878e+00*S235+(-1.252506e+01)*S236+(-3.329370e-01)*S237+(-3.806013e+00)*S238+(-1.213433e+01)*S239'
.param V68_part25='V68_part24+7.876284e-01*S240+3.323313e-01*S241+3.265202e-01*S242+1.413531e-01*S243+2.704568e-01*S244+1.020617e+00*S245+4.539875e+00*S246+(-8.663393e+00)*S247+(-1.017615e+01)*S248+(-1.656604e+00)*S249'
.param V68_part26='V68_part25+4.754196e-01*S250+(-6.792251e+00)*S251+2.694640e+01*S252+1.222339e+00*S253+(-5.040062e+00)*S254+8.053682e-01*S255+2.592154e+00*S256+1.260965e+00*S257+4.715292e+00*S258+2.549632e+00*S259'
.param V68_part27='V68_part26+1.104432e+00*S260+2.554943e-01*S261+1.745501e-01*S262+1.340096e+01*S263+1.900248e+02*S264+8.308864e-01*S265+(-9.226303e+00)*S266+3.778089e+01*S267+9.008644e-01*S268+(-2.719599e+00)*S269'
.param V68_part28='V68_part27+(-5.275709e-01)*S270+1.494127e+00*S271+4.117968e-01*S272+1.704486e-01*S273+4.324557e-01*S274+5.715187e-01*S275+(-1.185745e+00)*S276+(-4.411019e-01)*S277+(-5.404949e+01)*S278+1.156614e+01*S279'
.param V68_part29='V68_part28+1.529993e+00*S280+(-1.776867e+01)*S281+(-3.850147e-01)*S282+(-4.257523e+00)*S283+(-1.567252e-01)*S284+1.413061e-01*S285+(-1.895643e-01)*S286+(-3.202098e+00)*S287+8.908099e+03*S288+7.437277e+03*S289'
.param V68_part30='V68_part29+(-2.897207e+01)*S290+(-4.963194e+00)*S291+(-5.625773e+00)*S292+(-5.066219e-02)*S293+1.243059e+00*S294+(-4.689520e+00)*S295+(-2.305497e-02)*S296+3.645197e+01*S297+(-6.358294e-02)*S298+(-5.892523e-03)*S299'
.param V68_part31='V68_part30+4.419931e-01*S300+1.203595e+00*S301+5.999127e-01*S302+1.162444e+00*S303+2.412430e+00*S304+4.888807e-01*S305+1.395749e-01*S306+(-7.185389e+00)*S307+(-1.555608e+01)*S308+1.426707e-01*S309'
.param V68='V68_part31+(-7.529855e+00)*S310+(-4.811568e+00)*S311+2.204665e-01*S312+(-4.314079e+00)*S313+(-2.548394e+00)*S314'
.param V69_part1='9.261508e-01*S0+(-9.087010e-02)*S1+(-4.150331e-02)*S2+0.000000e+00*S3+(-3.258004e-02)*S4+(-3.052942e-03)*S5+1.135673e-01*S6+3.894436e-03*S7+(-1.249543e-02)*S8+1.930988e-02*S9'
.param V69_part2='V69_part1+0.000000e+00*S10+7.543731e-03*S11+(-6.745140e-03)*S12+1.250187e-03*S13+(-2.406705e-02)*S14+0.000000e+00*S15+(-1.949658e-02)*S16+(-9.211585e-03)*S17+0.000000e+00*S18+(-4.288073e-02)*S19'
.param V69_part3='V69_part2+(-1.361893e-02)*S20+0.000000e+00*S21+(-6.135551e-03)*S22+1.413897e-04*S23+3.956628e-02*S24+1.382864e-04*S25+2.589233e-03*S26+(-2.206813e-03)*S27+(-2.392750e-03)*S28+(-1.477713e-03)*S29'
.param V69_part4='V69_part3+(-2.777136e-01)*S30+(-1.621042e-02)*S31+(-4.475653e-01)*S32+(-1.488061e-01)*S33+2.777456e-03*S34+(-1.219226e-01)*S35+(-2.737109e-01)*S36+(-2.635052e+00)*S37+(-3.890194e-02)*S38+(-6.471641e-01)*S39'
.param V69_part5='V69_part4+1.000000e+04*S40+1.545404e-03*S41+(-5.939045e-01)*S42+(-1.150581e-01)*S43+(-1.337160e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+(-5.703558e-03)*S47+(-3.306824e-01)*S48+(-4.878926e-01)*S49'
.param V69_part6='V69_part5+(-2.055974e-01)*S50+(-1.928501e-03)*S51+(-5.037983e+00)*S52+(-3.294664e-01)*S53+(-1.075651e+00)*S54+(-1.895784e+00)*S55+(-3.538120e-01)*S56+(-3.363227e+00)*S57+1.598138e+00*S58+7.477112e-03*S59'
.param V69_part7='V69_part6+2.078797e-01*S60+2.132859e-02*S61+(-1.465429e-01)*S62+(-3.207467e-01)*S63+(-1.525992e+03)*S64+(-1.276095e-01)*S65+(-9.147003e-02)*S66+(-7.258952e-03)*S67+1.059371e-02*S68+1.204253e+00*S69'
.param V69_part8='V69_part7+1.616766e-02*S70+1.075426e-02*S71+(-4.633060e-01)*S72+1.300328e-02*S73+(-2.226215e-02)*S74+(-1.051792e+00)*S75+0.000000e+00*S76+(-5.802121e-02)*S77+(-1.363040e-02)*S78+(-1.047156e-01)*S79'
.param V69_part9='V69_part8+(-2.347614e-02)*S80+(-3.395833e-01)*S81+(-3.000057e-02)*S82+(-2.959649e-02)*S83+(-1.610710e-01)*S84+(-3.035306e-02)*S85+(-3.682881e-02)*S86+(-1.620317e-02)*S87+(-3.032321e-02)*S88+(-3.521415e-02)*S89'
.param V69_part10='V69_part9+8.028425e-02*S90+(-6.084100e-01)*S91+(-1.592584e-01)*S92+(-2.813732e-01)*S93+(-2.847600e-01)*S94+(-2.461459e-01)*S95+(-1.771410e+00)*S96+(-9.534057e-01)*S97+(-1.787219e-02)*S98+(-3.142612e+00)*S99'
.param V69_part11='V69_part10+(-1.044075e-01)*S100+2.926823e-02*S101+(-5.603669e-01)*S102+(-1.296939e-01)*S103+(-7.460714e-01)*S104+(-1.991554e+01)*S105+(-2.672529e+00)*S106+(-3.042198e+00)*S107+(-2.759260e+01)*S108+(-6.304174e+00)*S109'
.param V69_part12='V69_part11+1.590763e+00*S110+1.118655e-01*S111+6.537183e-01*S112+2.548015e-02*S113+(-1.235543e-01)*S114+(-5.416153e-01)*S115+(-4.087350e-01)*S116+1.654209e+03*S117+2.076407e-02*S118+(-7.820344e-02)*S119'
.param V69_part13='V69_part12+2.380435e+01*S120+(-4.737251e-04)*S121+2.315555e-03*S122+(-1.569588e+00)*S123+1.162330e-01*S124+(-4.955741e-02)*S125+6.959820e-02*S126+4.332440e-02*S127+(-9.940449e-02)*S128+4.916126e-02*S129'
.param V69_part14='V69_part13+(-8.685792e-03)*S130+(-3.808231e-02)*S131+(-4.779734e-01)*S132+(-2.650085e-02)*S133+(-1.345174e-02)*S134+(-6.162842e+00)*S135+9.277902e-01*S136+(-2.581042e+00)*S137+(-5.859897e-02)*S138+4.678957e-02*S139'
.param V69_part15='V69_part14+1.654460e-02*S140+(-3.180309e+00)*S141+6.390339e-02*S142+(-1.804043e-01)*S143+(-8.054004e-03)*S144+5.648848e-04*S145+(-5.174150e-02)*S146+(-2.296055e-01)*S147+(-3.066952e-03)*S148+(-8.794698e-03)*S149'
.param V69_part16='V69_part15+1.288370e-01*S150+3.061628e-02*S151+(-3.021786e-01)*S152+(-1.294733e-01)*S153+4.585814e-02*S154+(-3.477272e-01)*S155+(-1.043873e-01)*S156+(-7.875688e-02)*S157+(-4.167859e-02)*S158+(-2.699407e-01)*S159'
.param V69_part17='V69_part16+(-1.546919e-01)*S160+(-6.851359e-01)*S161+3.149973e-01*S162+(-2.306361e-01)*S163+(-1.057325e+00)*S164+(-1.587427e+00)*S165+4.389251e-02*S166+1.156188e-02*S167+(-2.311790e+01)*S168+(-4.626425e-01)*S169'
.param V69_part18='V69_part17+(-3.695600e-02)*S170+(-1.913271e-01)*S171+(-1.617181e-01)*S172+(-8.578777e-01)*S173+(-3.019387e-01)*S174+(-9.165042e-01)*S175+1.194713e-01*S176+(-1.700142e-01)*S177+(-3.663333e-01)*S178+1.750793e-01*S179'
.param V69_part19='V69_part18+(-6.056769e-01)*S180+5.854542e-02*S181+(-4.025184e-01)*S182+(-2.122368e+01)*S183+(-1.972304e-01)*S184+(-1.550675e-01)*S185+(-4.637786e-01)*S186+(-5.811741e-02)*S187+2.459580e-02*S188+1.270884e-01*S189'
.param V69_part20='V69_part19+8.675823e-02*S190+(-1.158723e-01)*S191+(-3.065860e-01)*S192+(-3.397787e-01)*S193+(-7.250115e-01)*S194+1.341230e-01*S195+(-1.016127e-01)*S196+2.114113e-02*S197+(-9.079973e-02)*S198+(-2.233848e-02)*S199'
.param V69_part21='V69_part20+(-1.927503e-02)*S200+9.416257e-02*S201+3.904329e-02*S202+(-1.570592e-02)*S203+(-7.445542e-01)*S204+1.152319e-01*S205+(-2.076399e-02)*S206+8.352707e-02*S207+9.123390e-02*S208+(-1.180028e-02)*S209'
.param V69_part22='V69_part21+(-8.642040e-01)*S210+3.691694e-02*S211+(-7.983460e-02)*S212+4.309855e+00*S213+(-1.272839e-01)*S214+(-8.392397e-02)*S215+(-1.316090e-01)*S216+(-6.588857e-01)*S217+(-9.690709e-02)*S218+(-2.456177e-01)*S219'
.param V69_part23='V69_part22+(-3.151385e-01)*S220+(-2.161668e-01)*S221+(-1.867691e-01)*S222+(-6.898242e-02)*S223+(-2.109064e-01)*S224+4.644497e+01*S225+(-4.294264e-01)*S226+8.523234e-02*S227+(-7.800941e-02)*S228+(-9.325384e-02)*S229'
.param V69_part24='V69_part23+(-1.712850e-01)*S230+(-3.417916e-01)*S231+3.600310e-01*S232+(-8.103290e-01)*S233+(-4.700191e-01)*S234+1.082907e-01*S235+(-1.078341e+00)*S236+(-3.821361e-01)*S237+(-3.356118e-01)*S238+(-6.542620e-01)*S239'
.param V69_part25='V69_part24+(-6.160837e-01)*S240+(-6.930836e-03)*S241+7.923931e-02*S242+(-8.043774e-02)*S243+(-5.161850e-02)*S244+1.010934e-01*S245+1.596309e-01*S246+(-3.992861e-01)*S247+(-8.283413e-01)*S248+(-6.408831e-01)*S249'
.param V69_part26='V69_part25+(-4.588974e-01)*S250+(-1.144895e+00)*S251+8.181374e-01*S252+(-7.282821e-02)*S253+(-1.105313e+00)*S254+4.892693e-02*S255+(-3.577159e-01)*S256+7.497197e-03*S257+(-4.252662e-02)*S258+4.552986e-02*S259'
.param V69_part27='V69_part26+3.199311e-02*S260+(-3.794151e-01)*S261+(-2.186762e-01)*S262+(-5.318368e-01)*S263+(-3.121779e+00)*S264+9.583648e-02*S265+(-7.254486e-01)*S266+5.594265e-01*S267+2.666471e-02*S268+(-4.123864e-01)*S269'
.param V69_part28='V69_part27+(-7.080716e-01)*S270+(-6.068071e-01)*S271+1.327289e-01*S272+(-2.352456e-01)*S273+(-1.891748e+00)*S274+(-3.031076e-02)*S275+(-7.789276e-01)*S276+(-9.604661e-02)*S277+(-1.545448e+00)*S278+2.792095e-01*S279'
.param V69_part29='V69_part28+4.053146e-02*S280+(-1.140555e+00)*S281+(-6.582819e-01)*S282+(-4.409912e-01)*S283+(-1.215405e-01)*S284+(-2.681718e-01)*S285+(-6.413128e-02)*S286+(-3.722770e-01)*S287+1.254961e+01*S288+1.927158e+01*S289'
.param V69_part30='V69_part29+(-1.497639e+00)*S290+(-1.080939e+00)*S291+(-9.356201e-01)*S292+(-9.085722e-02)*S293+1.567319e-03*S294+(-8.323340e-01)*S295+(-1.146961e-01)*S296+9.495502e-01*S297+(-2.905695e-01)*S298+(-7.751234e-02)*S299'
.param V69_part31='V69_part30+(-2.153851e-01)*S300+(-4.108935e-04)*S301+(-1.279643e-01)*S302+(-2.767224e+00)*S303+5.871421e-02*S304+(-1.217616e-01)*S305+(-1.335412e-01)*S306+(-1.061324e+00)*S307+(-9.887297e-01)*S308+(-2.323428e-01)*S309'
.param V69='V69_part31+(-9.711992e-01)*S310+(-5.869777e-01)*S311+(-1.640507e-01)*S312+(-8.766216e-01)*S313+(-3.604667e-01)*S314'
.param V70_part1='0.000000e+00*S0+8.260039e+00*S1+6.004220e+00*S2+0.000000e+00*S3+2.431856e+01*S4+3.411801e+02*S5+7.601168e+00*S6+(-2.987306e+01)*S7+2.198564e+01*S8+(-9.301953e+01)*S9'
.param V70_part2='V70_part1+0.000000e+00*S10+5.598263e+01*S11+(-1.064366e+02)*S12+7.409487e+01*S13+(-3.253699e+00)*S14+0.000000e+00*S15+1.322703e+01*S16+3.403101e+01*S17+7.033198e+03*S18+6.220914e+01*S19'
.param V70_part3='V70_part2+6.907732e+01*S20+0.000000e+00*S21+2.339374e+02*S22+2.348163e+02*S23+1.836032e+01*S24+1.156347e+02*S25+2.668419e+02*S26+2.685867e+02*S27+1.784784e+02*S28+2.360418e+02*S29'
.param V70_part4='V70_part3+3.037253e+01*S30+0.000000e+00*S31+3.229587e+01*S32+3.299564e+01*S33+0.000000e+00*S34+0.000000e+00*S35+6.082279e+01*S36+1.208873e+01*S37+3.744316e+01*S38+5.302336e+01*S39'
.param V70_part5='V70_part4+8.640878e+00*S40+0.000000e+00*S41+5.843862e+01*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+7.694076e+01*S47+2.434884e+01*S48+0.000000e+00*S49'
.param V70_part6='V70_part5+6.201572e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+3.511878e+01*S54+0.000000e+00*S55+0.000000e+00*S56+5.074364e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V70_part7='V70_part6+1.025631e+02*S60+1.192791e+02*S61+2.766209e+01*S62+0.000000e+00*S63+2.429386e+01*S64+4.110676e+01*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+(-3.960191e+01)*S69'
.param V70_part8='V70_part7+0.000000e+00*S70+0.000000e+00*S71+2.783910e+01*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.859465e+01*S77+6.690438e+01*S78+0.000000e+00*S79'
.param V70_part9='V70_part8+0.000000e+00*S80+(-1.479923e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+(-4.513134e+01)*S84+0.000000e+00*S85+0.000000e+00*S86+4.286250e+01*S87+0.000000e+00*S88+5.915228e+01*S89'
.param V70_part10='V70_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+(-4.290905e+01)*S98+0.000000e+00*S99'
.param V70_part11='V70_part10+0.000000e+00*S100+0.000000e+00*S101+(-3.383543e+01)*S102+0.000000e+00*S103+2.256134e+01*S104+0.000000e+00*S105+0.000000e+00*S106+8.253143e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V70_part12='V70_part11+1.537058e+01*S110+0.000000e+00*S111+1.129598e+01*S112+0.000000e+00*S113+0.000000e+00*S114+(-4.476430e+00)*S115+2.154569e+00*S116+0.000000e+00*S117+5.502226e+01*S118+(-6.625281e+01)*S119'
.param V70_part13='V70_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+6.446972e+01*S126+5.088309e+01*S127+(-1.219506e+02)*S128+9.495163e+00*S129'
.param V70_part14='V70_part13+4.630235e+01*S130+4.247187e+01*S131+0.000000e+00*S132+(-3.650467e+01)*S133+4.218648e+01*S134+(-2.781848e+01)*S135+0.000000e+00*S136+8.478606e+00*S137+0.000000e+00*S138+2.190589e+01*S139'
.param V70_part15='V70_part14+0.000000e+00*S140+0.000000e+00*S141+8.016981e+01*S142+3.840037e+01*S143+0.000000e+00*S144+4.934589e+01*S145+6.159943e+01*S146+0.000000e+00*S147+1.342738e+02*S148+7.062995e+01*S149'
.param V70_part16='V70_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+(-4.312310e+01)*S155+1.774182e+01*S156+(-1.628455e+01)*S157+0.000000e+00*S158+(-7.205563e+00)*S159'
.param V70_part17='V70_part16+0.000000e+00*S160+0.000000e+00*S161+3.135429e+01*S162+3.270375e+01*S163+4.375789e+01*S164+(-1.153911e+01)*S165+0.000000e+00*S166+(-3.528200e+01)*S167+0.000000e+00*S168+(-2.546618e+01)*S169'
.param V70_part18='V70_part17+(-5.373684e+01)*S170+(-1.813972e+01)*S171+(-2.878275e+01)*S172+3.479781e+01*S173+0.000000e+00*S174+(-2.412817e+01)*S175+(-5.055502e+01)*S176+0.000000e+00*S177+3.461411e+01*S178+1.935391e+01*S179'
.param V70_part19='V70_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+(-4.389593e+00)*S187+(-2.011037e+01)*S188+0.000000e+00*S189'
.param V70_part20='V70_part19+1.675167e+01*S190+0.000000e+00*S191+(-1.721797e+01)*S192+3.206310e+01*S193+3.729600e+01*S194+9.425849e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V70_part21='V70_part20+0.000000e+00*S200+2.334666e+01*S201+7.580504e+00*S202+(-2.649170e+00)*S203+2.660449e+01*S204+4.034243e+01*S205+2.592699e-01*S206+1.303446e+02*S207+6.438684e+01*S208+5.685687e-01*S209'
.param V70_part22='V70_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+3.028382e+01*S213+0.000000e+00*S214+0.000000e+00*S215+4.953868e+01*S216+0.000000e+00*S217+0.000000e+00*S218+1.911190e+01*S219'
.param V70_part23='V70_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+(-2.819713e+01)*S226+0.000000e+00*S227+(-2.402030e+01)*S228+1.407846e+00*S229'
.param V70_part24='V70_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+4.638248e+01*S233+(-3.013097e+01)*S234+0.000000e+00*S235+6.553339e+01*S236+0.000000e+00*S237+(-6.599888e+01)*S238+9.437042e+01*S239'
.param V70_part25='V70_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+6.356749e+01*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+8.979887e+00*S247+7.768824e+01*S248+0.000000e+00*S249'
.param V70_part26='V70_part25+0.000000e+00*S250+7.957089e+01*S251+0.000000e+00*S252+0.000000e+00*S253+(-1.128661e+01)*S254+5.948760e+01*S255+1.977801e+01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V70_part27='V70_part26+3.911743e+01*S260+0.000000e+00*S261+8.079997e+00*S262+1.748647e+01*S263+(-1.953295e+01)*S264+1.873011e+01*S265+(-5.833711e-01)*S266+6.237450e+01*S267+9.330208e+01*S268+3.903033e+01*S269'
.param V70_part28='V70_part27+0.000000e+00*S270+0.000000e+00*S271+2.336832e+02*S272+4.220082e+01*S273+0.000000e+00*S274+2.802867e+02*S275+0.000000e+00*S276+0.000000e+00*S277+9.016915e+01*S278+1.387184e+01*S279'
.param V70_part29='V70_part28+0.000000e+00*S280+1.028571e+02*S281+7.418935e+00*S282+(-7.791446e+01)*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+2.451890e+01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V70_part30='V70_part29+8.041080e+01*S290+0.000000e+00*S291+3.446276e+01*S292+0.000000e+00*S293+0.000000e+00*S294+3.054755e+01*S295+0.000000e+00*S296+0.000000e+00*S297+(-5.199945e+01)*S298+4.310927e+01*S299'
.param V70_part31='V70_part30+0.000000e+00*S300+6.297341e+01*S301+0.000000e+00*S302+0.000000e+00*S303+3.248214e+01*S304+(-3.689698e+01)*S305+5.170313e+01*S306+4.587320e+01*S307+(-6.006365e+01)*S308+4.063170e+01*S309'
.param V70='V70_part31+4.443221e+01*S310+(-8.270916e+01)*S311+3.210135e+01*S312+3.146359e+01*S313+(-1.512283e+02)*S314'
.param V71_part1='0.000000e+00*S0+4.586102e+01*S1+7.249922e+01*S2+0.000000e+00*S3+8.178019e+01*S4+(-5.588574e+01)*S5+7.242327e+01*S6+1.986770e+02*S7+(-1.083042e+01)*S8+1.522046e+02*S9'
.param V71_part2='V71_part1+0.000000e+00*S10+5.340727e+01*S11+2.707876e+02*S12+6.652727e+01*S13+6.105399e+01*S14+0.000000e+00*S15+2.995844e+02*S16+4.074187e+01*S17+5.487532e+01*S18+1.408609e+02*S19'
.param V71_part3='V71_part2+7.587057e+01*S20+0.000000e+00*S21+4.015878e+01*S22+(-2.434957e+01)*S23+5.571618e+01*S24+5.751756e+01*S25+(-1.622587e+01)*S26+(-9.533702e+01)*S27+1.816170e+00*S28+(-1.676903e+00)*S29'
.param V71_part4='V71_part3+4.577572e+01*S30+0.000000e+00*S31+(-1.841710e+01)*S32+4.429076e+01*S33+0.000000e+00*S34+0.000000e+00*S35+(-5.284888e-01)*S36+3.474081e+01*S37+3.962663e+01*S38+1.428890e+01*S39'
.param V71_part5='V71_part4+4.533350e+01*S40+0.000000e+00*S41+1.705715e+01*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-5.384386e+00)*S47+4.847508e+01*S48+0.000000e+00*S49'
.param V71_part6='V71_part5+4.337817e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+3.532002e+01*S54+0.000000e+00*S55+0.000000e+00*S56+1.944247e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V71_part7='V71_part6+8.864161e+01*S60+(-4.562153e+01)*S61+7.998493e+01*S62+0.000000e+00*S63+1.423202e+01*S64+3.869615e+01*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+4.575125e+01*S69'
.param V71_part8='V71_part7+0.000000e+00*S70+0.000000e+00*S71+8.556015e+01*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-2.243179e+01)*S77+3.391725e+01*S78+0.000000e+00*S79'
.param V71_part9='V71_part8+0.000000e+00*S80+9.655069e+01*S81+0.000000e+00*S82+0.000000e+00*S83+1.600995e+02*S84+0.000000e+00*S85+0.000000e+00*S86+2.770625e+00*S87+0.000000e+00*S88+(-1.447194e+01)*S89'
.param V71_part10='V71_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+1.259131e+02*S98+0.000000e+00*S99'
.param V71_part11='V71_part10+0.000000e+00*S100+0.000000e+00*S101+1.337847e+02*S102+0.000000e+00*S103+4.313978e+00*S104+0.000000e+00*S105+0.000000e+00*S106+7.510177e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V71_part12='V71_part11+5.350567e+01*S110+0.000000e+00*S111+2.629316e+01*S112+0.000000e+00*S113+0.000000e+00*S114+1.817367e+01*S115+3.590246e+01*S116+0.000000e+00*S117+1.131770e+01*S118+1.182250e+02*S119'
.param V71_part13='V71_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+2.017077e+01*S126+6.000598e+01*S127+2.105322e+02*S128+4.585160e+01*S129'
.param V71_part14='V71_part13+3.505361e+01*S130+8.623164e+01*S131+0.000000e+00*S132+7.968946e+01*S133+6.976729e+01*S134+5.169671e+01*S135+0.000000e+00*S136+1.182640e+01*S137+0.000000e+00*S138+(-1.293577e+00)*S139'
.param V71_part15='V71_part14+0.000000e+00*S140+0.000000e+00*S141+(-2.550162e+01)*S142+(-8.607366e-01)*S143+0.000000e+00*S144+(-1.395902e+00)*S145+(-3.992941e+00)*S146+0.000000e+00*S147+(-4.402902e+00)*S148+2.660336e+01*S149'
.param V71_part16='V71_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+4.571576e+01*S155+8.970170e+01*S156+1.069935e+02*S157+0.000000e+00*S158+8.998803e+01*S159'
.param V71_part17='V71_part16+0.000000e+00*S160+0.000000e+00*S161+3.410938e+01*S162+3.783908e+01*S163+2.341550e+01*S164+3.342549e+01*S165+0.000000e+00*S166+1.596625e+02*S167+0.000000e+00*S168+1.317818e+02*S169'
.param V71_part18='V71_part17+1.829955e+02*S170+1.654176e+01*S171+1.197953e+02*S172+3.585009e+01*S173+0.000000e+00*S174+5.924321e+01*S175+1.008207e+02*S176+0.000000e+00*S177+6.067865e+01*S178+6.430568e+01*S179'
.param V71_part19='V71_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+6.799979e+01*S187+7.235161e+01*S188+0.000000e+00*S189'
.param V71_part20='V71_part19+6.808555e+01*S190+0.000000e+00*S191+2.526941e+01*S192+6.105072e+01*S193+5.163069e+01*S194+4.443331e+01*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V71_part21='V71_part20+0.000000e+00*S200+5.420466e+01*S201+6.652405e+01*S202+1.044740e+02*S203+2.828393e+01*S204+1.120444e+01*S205+1.461427e+02*S206+(-1.888186e+01)*S207+7.389936e+00*S208+1.535313e+02*S209'
.param V71_part22='V71_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+6.070542e+01*S213+0.000000e+00*S214+0.000000e+00*S215+7.141644e+01*S216+0.000000e+00*S217+0.000000e+00*S218+5.729105e+01*S219'
.param V71_part23='V71_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+1.655864e+02*S226+0.000000e+00*S227+6.738930e+01*S228+1.001497e+02*S229'
.param V71_part24='V71_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+4.419618e+01*S233+3.403135e+01*S234+0.000000e+00*S235+2.327737e+01*S236+0.000000e+00*S237+7.830431e+01*S238+1.496512e+01*S239'
.param V71_part25='V71_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+5.602481e+01*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+4.703153e+01*S247+1.362708e+01*S248+0.000000e+00*S249'
.param V71_part26='V71_part25+0.000000e+00*S250+1.138594e+01*S251+0.000000e+00*S252+0.000000e+00*S253+7.665662e+01*S254+4.680207e+01*S255+3.930688e+01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V71_part27='V71_part26+1.173083e+02*S260+0.000000e+00*S261+7.924954e+01*S262+2.996634e+01*S263+2.350089e+01*S264+3.064076e+01*S265+(-2.279286e+00)*S266+5.098776e+01*S267+8.684841e+00*S268+4.618113e+01*S269'
.param V71_part28='V71_part27+0.000000e+00*S270+0.000000e+00*S271+(-6.326243e+01)*S272+5.252610e+01*S273+0.000000e+00*S274+(-1.830750e+02)*S275+0.000000e+00*S276+0.000000e+00*S277+(-1.127521e+00)*S278+6.830214e+01*S279'
.param V71_part29='V71_part28+0.000000e+00*S280+(-8.982826e+00)*S281+(-2.967053e+00)*S282+9.864631e+01*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+4.145222e+01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V71_part30='V71_part29+1.029949e+01*S290+0.000000e+00*S291+4.831243e+01*S292+0.000000e+00*S293+0.000000e+00*S294+5.090309e+01*S295+0.000000e+00*S296+0.000000e+00*S297+4.178917e+01*S298+2.225255e+01*S299'
.param V71_part31='V71_part30+0.000000e+00*S300+(-3.655622e+01)*S301+0.000000e+00*S302+0.000000e+00*S303+(-1.697675e+01)*S304+5.818580e+01*S305+6.670952e+01*S306+4.342728e+01*S307+1.189730e+01*S308+5.607212e+01*S309'
.param V71='V71_part31+4.634972e+01*S310+3.087849e+01*S311+5.842813e+01*S312+5.425652e+01*S313+5.287972e+01*S314'
.param V72_part1='0.000000e+00*S0+2.043605e+01*S1+3.479954e+01*S2+0.000000e+00*S3+1.290421e+00*S4+1.928767e+01*S5+3.610231e+00*S6+2.464425e+01*S7+8.215616e+01*S8+1.711755e+02*S9'
.param V72_part2='V72_part1+0.000000e+00*S10+1.815359e+01*S11+7.652587e+00*S12+1.089701e+01*S13+2.491299e+01*S14+0.000000e+00*S15+(-1.545923e+01)*S16+2.013811e+01*S17+6.901070e+02*S18+1.551578e+01*S19'
.param V72_part3='V72_part2+(-1.042415e+01)*S20+0.000000e+00*S21+(-5.318792e+01)*S22+(-1.679931e+01)*S23+3.493377e+01*S24+(-1.538243e+01)*S25+(-5.437214e+01)*S26+(-1.043219e+02)*S27+(-4.261499e+01)*S28+(-3.583602e+01)*S29'
.param V72_part4='V72_part3+(-3.373354e+00)*S30+0.000000e+00*S31+1.903523e+00*S32+1.205245e+01*S33+0.000000e+00*S34+0.000000e+00*S35+5.694663e+00*S36+2.533442e+01*S37+1.319568e+01*S38+1.499059e+01*S39'
.param V72_part5='V72_part4+(-6.566909e+00)*S40+0.000000e+00*S41+9.810821e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-1.369176e+00)*S47+3.291968e+01*S48+0.000000e+00*S49'
.param V72_part6='V72_part5+(-5.052873e-01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+3.108848e+01*S54+0.000000e+00*S55+0.000000e+00*S56+1.159155e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V72_part7='V72_part6+5.171703e+01*S60+(-8.410991e+00)*S61+4.518233e+01*S62+0.000000e+00*S63+2.155164e+01*S64+2.185984e+01*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+7.322742e+01*S69'
.param V72_part8='V72_part7+0.000000e+00*S70+0.000000e+00*S71+6.059187e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.707752e+01*S77+(-5.156283e+01)*S78+0.000000e+00*S79'
.param V72_part9='V72_part8+0.000000e+00*S80+3.143012e+01*S81+0.000000e+00*S82+0.000000e+00*S83+8.259629e+01*S84+0.000000e+00*S85+0.000000e+00*S86+(-4.262142e+00)*S87+0.000000e+00*S88+1.126041e+01*S89'
.param V72_part10='V72_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+7.350329e+01*S98+0.000000e+00*S99'
.param V72_part11='V72_part10+0.000000e+00*S100+0.000000e+00*S101+7.603140e+01*S102+0.000000e+00*S103+8.626839e+00*S104+0.000000e+00*S105+0.000000e+00*S106+6.815871e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V72_part12='V72_part11+4.774754e+01*S110+0.000000e+00*S111+2.132339e+01*S112+0.000000e+00*S113+0.000000e+00*S114+1.333988e+01*S115+3.735227e+01*S116+0.000000e+00*S117+4.673655e+01*S118+1.123695e+02*S119'
.param V72_part13='V72_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+(-8.479650e+01)*S126+(-3.143005e+01)*S127+6.473786e+00*S128+(-6.001626e+01)*S129'
.param V72_part14='V72_part13+(-5.137332e+01)*S130+(-1.023397e+02)*S131+0.000000e+00*S132+2.196754e+01*S133+(-8.936969e+01)*S134+1.246353e+02*S135+0.000000e+00*S136+1.103796e+01*S137+0.000000e+00*S138+1.322575e+01*S139'
.param V72_part15='V72_part14+0.000000e+00*S140+0.000000e+00*S141+(-3.274059e+01)*S142+7.751333e+00*S143+0.000000e+00*S144+(-1.386270e+01)*S145+1.455536e+01*S146+0.000000e+00*S147+(-1.096227e+02)*S148+(-2.810335e+01)*S149'
.param V72_part16='V72_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+3.623589e+01*S155+7.681060e+01*S156+1.012239e+02*S157+0.000000e+00*S158+9.579114e+01*S159'
.param V72_part17='V72_part16+0.000000e+00*S160+0.000000e+00*S161+7.306334e+01*S162+1.485112e+02*S163+9.393738e+01*S164+4.554522e+01*S165+0.000000e+00*S166+1.108582e+02*S167+0.000000e+00*S168+1.253251e+02*S169'
.param V72_part18='V72_part17+1.267530e+02*S170+3.257071e+01*S171+1.155626e+02*S172+6.464684e+01*S173+0.000000e+00*S174+6.243973e+01*S175+1.453975e+02*S176+0.000000e+00*S177+1.002096e+02*S178+9.120795e+01*S179'
.param V72_part19='V72_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+(-1.849522e+01)*S187+1.423388e+02*S188+0.000000e+00*S189'
.param V72_part20='V72_part19+(-3.580895e+01)*S190+0.000000e+00*S191+4.021804e+01*S192+1.037780e+02*S193+9.382354e+01*S194+3.755316e+01*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V72_part21='V72_part20+0.000000e+00*S200+(-1.826127e+01)*S201+(-8.823980e-01)*S202+(-4.031761e+00)*S203+9.075107e+01*S204+(-2.496938e+01)*S205+(-3.495941e+01)*S206+1.073355e+01*S207+(-4.944062e+01)*S208+(-7.411800e+01)*S209'
.param V72_part22='V72_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+7.566484e+01*S213+0.000000e+00*S214+0.000000e+00*S215+7.083770e+01*S216+0.000000e+00*S217+0.000000e+00*S218+6.613616e+01*S219'
.param V72_part23='V72_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+1.517532e+02*S226+0.000000e+00*S227+9.262477e+01*S228+1.924326e+02*S229'
.param V72_part24='V72_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+9.847947e+01*S233+9.341095e+01*S234+0.000000e+00*S235+8.606631e+01*S236+0.000000e+00*S237+1.118122e+02*S238+4.911298e+01*S239'
.param V72_part25='V72_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+1.346383e+02*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+6.239790e+01*S247+8.394679e+01*S248+0.000000e+00*S249'
.param V72_part26='V72_part25+0.000000e+00*S250+7.905416e+01*S251+0.000000e+00*S252+0.000000e+00*S253+1.115433e+02*S254+8.353701e+01*S255+5.477250e+01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V72_part27='V72_part26+(-5.501355e+01)*S260+0.000000e+00*S261+7.988317e+01*S262+4.603059e+01*S263+7.067127e+01*S264+7.204920e+01*S265+1.424480e+02*S266+4.495653e+01*S267+(-1.860740e+01)*S268+8.317696e+01*S269'
.param V72_part28='V72_part27+0.000000e+00*S270+0.000000e+00*S271+(-1.953014e+02)*S272+9.300546e+01*S273+0.000000e+00*S274+(-1.019409e+02)*S275+0.000000e+00*S276+0.000000e+00*S277+6.254708e+01*S278+9.786249e+01*S279'
.param V72_part29='V72_part28+0.000000e+00*S280+5.162398e+01*S281+(-1.186090e+00)*S282+7.711040e+01*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+1.168852e+02*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V72_part30='V72_part29+8.002440e+01*S290+0.000000e+00*S291+1.174343e+02*S292+0.000000e+00*S293+0.000000e+00*S294+1.099625e+02*S295+0.000000e+00*S296+0.000000e+00*S297+1.245647e+02*S298+(-4.733924e+01)*S299'
.param V72_part31='V72_part30+0.000000e+00*S300+(-5.509711e+00)*S301+0.000000e+00*S302+0.000000e+00*S303+2.694047e+01*S304+3.406749e+01*S305+7.963023e+01*S306+8.618054e+01*S307+1.583196e+02*S308+9.383150e+01*S309'
.param V72='V72_part31+7.648302e+01*S310+1.736816e+02*S311+1.111296e+02*S312+8.314379e+01*S313+2.208136e+02*S314'
.param V73_part1='0.000000e+00*S0+(-5.648791e+00)*S1+1.554457e+01*S2+0.000000e+00*S3+5.384497e+01*S4+(-1.987156e+02)*S5+(-2.720863e+01)*S6+3.568196e+01*S7+(-1.291806e+01)*S8+4.578474e+01*S9'
.param V73_part2='V73_part1+0.000000e+00*S10+(-3.104072e+01)*S11+6.414607e+00*S12+(-6.267365e+01)*S13+(-6.454789e-01)*S14+0.000000e+00*S15+4.762480e+01*S16+7.343808e-01*S17+(-1.000000e+04)*S18+3.256083e+00*S19'
.param V73_part3='V73_part2+(-1.773426e+00)*S20+0.000000e+00*S21+(-1.115235e+02)*S22+(-1.075852e+02)*S23+(-3.322055e+01)*S24+(-5.144574e+01)*S25+(-9.991017e+01)*S26+(-4.765350e+01)*S27+(-4.301855e+01)*S28+(-9.267441e+01)*S29'
.param V73_part4='V73_part3+(-1.148273e+01)*S30+0.000000e+00*S31+4.269576e+00*S32+(-2.358883e+01)*S33+0.000000e+00*S34+0.000000e+00*S35+(-2.515446e+01)*S36+2.613894e+00*S37+(-2.672629e+01)*S38+(-2.830718e+01)*S39'
.param V73_part5='V73_part4+(-6.093540e+00)*S40+0.000000e+00*S41+(-3.127547e+01)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-8.509792e+00)*S47+(-1.967117e+01)*S48+0.000000e+00*S49'
.param V73_part6='V73_part5+(-1.104869e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+(-3.480934e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-3.420912e+01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V73_part7='V73_part6+(-3.125972e+01)*S60+(-3.508535e+01)*S61+(-1.951857e+01)*S62+0.000000e+00*S63+1.337949e+00*S64+(-2.191669e+01)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+(-1.054871e+01)*S69'
.param V73_part8='V73_part7+0.000000e+00*S70+0.000000e+00*S71+(-5.692451e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-1.805493e+01)*S77+(-2.279430e+01)*S78+0.000000e+00*S79'
.param V73_part9='V73_part8+0.000000e+00*S80+(-2.128682e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+(-3.785153e+01)*S84+0.000000e+00*S85+0.000000e+00*S86+3.496053e+01*S87+0.000000e+00*S88+2.144749e+01*S89'
.param V73_part10='V73_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+(-2.357498e+01)*S98+0.000000e+00*S99'
.param V73_part11='V73_part10+0.000000e+00*S100+0.000000e+00*S101+(-3.819772e+01)*S102+0.000000e+00*S103+1.109403e+01*S104+0.000000e+00*S105+0.000000e+00*S106+(-6.633261e-01)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V73_part12='V73_part11+(-2.923402e+01)*S110+0.000000e+00*S111+(-3.672907e+00)*S112+0.000000e+00*S113+0.000000e+00*S114+(-1.727951e+01)*S115+(-3.285382e+00)*S116+0.000000e+00*S117+(-2.604543e+01)*S118+(-4.583563e+01)*S119'
.param V73_part13='V73_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+(-1.303827e+01)*S126+(-3.276746e+01)*S127+(-1.568025e+00)*S128+1.049309e+00*S129'
.param V73_part14='V73_part13+(-1.150837e+01)*S130+6.940124e-01*S131+0.000000e+00*S132+1.019694e+00*S133+(-2.119471e+00)*S134+1.274731e+00*S135+0.000000e+00*S136+(-5.662577e+00)*S137+0.000000e+00*S138+(-5.954998e+00)*S139'
.param V73_part15='V73_part14+0.000000e+00*S140+0.000000e+00*S141+(-1.999781e+01)*S142+(-1.349151e+01)*S143+0.000000e+00*S144+(-2.859266e+01)*S145+(-2.373334e+01)*S146+0.000000e+00*S147+(-2.393698e+01)*S148+(-1.585913e+01)*S149'
.param V73_part16='V73_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+4.064205e+00*S155+(-3.796754e+01)*S156+(-2.824616e+01)*S157+0.000000e+00*S158+(-4.238962e+01)*S159'
.param V73_part17='V73_part16+0.000000e+00*S160+0.000000e+00*S161+(-2.420049e+01)*S162+(-3.824320e+01)*S163+(-5.019920e+01)*S164+(-3.310302e+00)*S165+0.000000e+00*S166+(-2.999764e+01)*S167+0.000000e+00*S168+(-2.598725e+01)*S169'
.param V73_part18='V73_part17+(-4.199872e+01)*S170+(-5.188620e+00)*S171+(-2.723415e+01)*S172+(-3.135362e+01)*S173+0.000000e+00*S174+(-7.646032e+00)*S175+(-4.488143e+01)*S176+0.000000e+00*S177+(-3.229792e+01)*S178+(-3.470821e+01)*S179'
.param V73_part19='V73_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+7.944826e+00*S187+(-4.282115e+01)*S188+0.000000e+00*S189'
.param V73_part20='V73_part19+(-1.836463e+01)*S190+0.000000e+00*S191+9.422483e+00*S192+(-2.876828e+01)*S193+(-3.162689e+01)*S194+(-6.494907e+00)*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V73_part21='V73_part20+0.000000e+00*S200+(-2.147294e+01)*S201+(-3.497062e+01)*S202+(-1.786476e+01)*S203+(-1.864430e+01)*S204+(-2.743499e+00)*S205+(-2.468573e+01)*S206+(-2.917306e+01)*S207+(-4.831369e+00)*S208+(-2.293065e+01)*S209'
.param V73_part22='V73_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+(-2.416042e+01)*S213+0.000000e+00*S214+0.000000e+00*S215+(-1.902170e+01)*S216+0.000000e+00*S217+0.000000e+00*S218+(-2.939570e+01)*S219'
.param V73_part23='V73_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+(-2.297246e+01)*S226+0.000000e+00*S227+1.878247e+01*S228+(-5.391438e+01)*S229'
.param V73_part24='V73_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+(-3.177869e+01)*S233+8.640621e+00*S234+0.000000e+00*S235+(-2.915278e+01)*S236+0.000000e+00*S237+7.072125e+00*S238+(-2.069314e+01)*S239'
.param V73_part25='V73_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+(-1.992806e+01)*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+(-3.390968e+00)*S247+(-2.877157e+01)*S248+0.000000e+00*S249'
.param V73_part26='V73_part25+0.000000e+00*S250+(-2.014902e+01)*S251+0.000000e+00*S252+0.000000e+00*S253+(-1.296688e+01)*S254+(-3.209370e+01)*S255+(-1.905093e+01)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V73_part27='V73_part26+(-5.150273e+01)*S260+0.000000e+00*S261+(-3.778697e+01)*S262+(-3.110864e+01)*S263+1.255957e+00*S264+(-1.279044e+01)*S265+(-2.369885e+01)*S266+(-3.398639e+01)*S267+(-1.426934e+01)*S268+(-2.145327e+01)*S269'
.param V73_part28='V73_part27+0.000000e+00*S270+0.000000e+00*S271+(-9.487962e+00)*S272+(-2.002552e+01)*S273+0.000000e+00*S274+(-1.800247e+01)*S275+0.000000e+00*S276+0.000000e+00*S277+(-2.421678e+01)*S278+(-2.981632e+01)*S279'
.param V73_part29='V73_part28+0.000000e+00*S280+(-1.665974e+01)*S281+6.662004e+00*S282+5.974273e+00*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+(-1.786242e+01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V73_part30='V73_part29+(-3.194009e+01)*S290+0.000000e+00*S291+(-1.931840e+01)*S292+0.000000e+00*S293+0.000000e+00*S294+(-9.632537e+00)*S295+0.000000e+00*S296+0.000000e+00*S297+2.003493e+01*S298+4.397680e+01*S299'
.param V73_part31='V73_part30+0.000000e+00*S300+(-1.471027e+01)*S301+0.000000e+00*S302+0.000000e+00*S303+(-6.662089e+00)*S304+(-6.149957e+00)*S305+(-2.290939e+01)*S306+(-2.184088e+01)*S307+(-1.438464e+01)*S308+(-2.591897e+01)*S309'
.param V73='V73_part31+(-1.938981e+01)*S310+(-1.546931e+01)*S311+(-3.090673e+01)*S312+(-1.995883e+01)*S313+(-1.951305e+01)*S314'
.param V74_part1='0.000000e+00*S0+1.873961e-01*S1+4.328550e-01*S2+0.000000e+00*S3+1.810935e-01*S4+(-2.777812e+00)*S5+(-3.417503e-01)*S6+1.343407e-01*S7+(-3.761523e-01)*S8+(-5.755401e-02)*S9'
.param V74_part2='V74_part1+0.000000e+00*S10+(-2.908525e-01)*S11+(-5.027559e-02)*S12+(-3.869543e-01)*S13+(-6.136910e-01)*S14+0.000000e+00*S15+1.867467e-02*S16+1.751788e+00*S17+2.936350e+03*S18+3.025131e+00*S19'
.param V74_part3='V74_part2+1.137452e+00*S20+0.000000e+00*S21+1.617605e+00*S22+8.431656e-01*S23+(-9.070634e-01)*S24+1.123046e-01*S25+(-1.522093e+00)*S26+(-3.449904e-01)*S27+(-1.509108e-01)*S28+(-6.060180e-02)*S29'
.param V74_part4='V74_part3+1.571830e-01*S30+0.000000e+00*S31+5.217592e-01*S32+(-1.678479e+00)*S33+0.000000e+00*S34+0.000000e+00*S35+(-2.303001e+00)*S36+1.195314e-01*S37+6.207735e-01*S38+(-9.345276e-01)*S39'
.param V74_part5='V74_part4+3.755387e-02*S40+0.000000e+00*S41+(-2.425583e-01)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+4.461672e-01*S47+(-2.513702e-01)*S48+0.000000e+00*S49'
.param V74_part6='V74_part5+3.008995e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+5.115896e+00*S54+0.000000e+00*S55+0.000000e+00*S56+4.569200e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V74_part7='V74_part6+(-1.954377e+01)*S60+(-2.292384e-01)*S61+1.548908e+00*S62+0.000000e+00*S63+2.040406e+00*S64+2.641997e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+1.764515e+01*S69'
.param V74_part8='V74_part7+0.000000e+00*S70+0.000000e+00*S71+2.024270e+01*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+3.405254e-01*S77+3.691683e+00*S78+0.000000e+00*S79'
.param V74_part9='V74_part8+0.000000e+00*S80+8.508981e+00*S81+0.000000e+00*S82+0.000000e+00*S83+1.058881e+01*S84+0.000000e+00*S85+0.000000e+00*S86+(-1.900402e+00)*S87+0.000000e+00*S88+4.110675e+00*S89'
.param V74_part10='V74_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+5.518367e+00*S98+0.000000e+00*S99'
.param V74_part11='V74_part10+0.000000e+00*S100+0.000000e+00*S101+1.327057e+01*S102+0.000000e+00*S103+3.787632e+00*S104+0.000000e+00*S105+0.000000e+00*S106+4.144710e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V74_part12='V74_part11+2.303098e+00*S110+0.000000e+00*S111+8.275766e-01*S112+0.000000e+00*S113+0.000000e+00*S114+3.512834e+00*S115+1.122348e+00*S116+0.000000e+00*S117+1.918542e+00*S118+7.866701e+00*S119'
.param V74_part13='V74_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+1.101865e-01*S126+1.521433e+00*S127+1.805919e+01*S128+9.291807e-01*S129'
.param V74_part14='V74_part13+2.227166e+00*S130+7.255358e+00*S131+0.000000e+00*S132+4.448764e+00*S133+5.012672e+00*S134+6.383334e+00*S135+0.000000e+00*S136+(-5.328092e-01)*S137+0.000000e+00*S138+(-2.335761e-01)*S139'
.param V74_part15='V74_part14+0.000000e+00*S140+0.000000e+00*S141+(-8.296353e+00)*S142+(-8.720978e-01)*S143+0.000000e+00*S144+(-5.268066e+00)*S145+(-4.770641e-01)*S146+0.000000e+00*S147+(-2.495306e+00)*S148+4.006222e-01*S149'
.param V74_part16='V74_part15+0.000000e+00*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+2.114301e+00*S155+2.622566e+00*S156+7.252501e+00*S157+0.000000e+00*S158+2.089928e+01*S159'
.param V74_part17='V74_part16+0.000000e+00*S160+0.000000e+00*S161+6.388041e+00*S162+(-1.599554e+01)*S163+(-1.194541e+01)*S164+8.413779e-01*S165+0.000000e+00*S166+1.069050e+01*S167+0.000000e+00*S168+5.234088e+00*S169'
.param V74_part18='V74_part17+1.044591e+01*S170+1.361551e+01*S171+8.418857e+00*S172+3.657676e+00*S173+0.000000e+00*S174+4.902656e+00*S175+7.563264e-01*S176+0.000000e+00*S177+1.242634e-01*S178+3.421686e+00*S179'
.param V74_part19='V74_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+3.106637e+00*S187+9.614616e+00*S188+0.000000e+00*S189'
.param V74_part20='V74_part19+1.224705e+00*S190+0.000000e+00*S191+1.459878e+01*S192+2.396321e-01*S193+(-2.284327e+00)*S194+4.994874e+00*S195+0.000000e+00*S196+0.000000e+00*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V74_part21='V74_part20+0.000000e+00*S200+4.414906e+00*S201+1.554811e+00*S202+7.709996e+00*S203+7.193826e-01*S204+(-1.298614e+00)*S205+1.325945e+01*S206+(-1.219625e+00)*S207+(-3.006435e+00)*S208+6.876966e+00*S209'
.param V74_part22='V74_part21+0.000000e+00*S210+0.000000e+00*S211+0.000000e+00*S212+4.416525e+00*S213+0.000000e+00*S214+0.000000e+00*S215+(-5.020619e+00)*S216+0.000000e+00*S217+0.000000e+00*S218+1.260224e+01*S219'
.param V74_part23='V74_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+1.624910e+01*S226+0.000000e+00*S227+6.193657e+00*S228+3.631577e+00*S229'
.param V74_part24='V74_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+(-3.179673e+00)*S233+1.733576e+01*S234+0.000000e+00*S235+(-3.837276e+00)*S236+0.000000e+00*S237+2.742499e+01*S238+(-9.160335e-01)*S239'
.param V74_part25='V74_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+(-8.896571e+00)*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+8.324713e+00*S247+(-6.493630e+00)*S248+0.000000e+00*S249'
.param V74_part26='V74_part25+0.000000e+00*S250+(-7.927508e+00)*S251+0.000000e+00*S252+0.000000e+00*S253+(-3.758698e+00)*S254+3.852185e+00*S255+1.200514e+00*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V74_part27='V74_part26+3.516584e+00*S260+0.000000e+00*S261+1.080743e+01*S262+2.253712e+00*S263+1.446224e+01*S264+2.082280e+01*S265+5.298466e+00*S266+(-3.263591e+00)*S267+(-2.892068e+00)*S268+(-3.797777e+00)*S269'
.param V74_part28='V74_part27+0.000000e+00*S270+0.000000e+00*S271+(-6.956188e+00)*S272+3.703636e+00*S273+0.000000e+00*S274+(-5.090215e+01)*S275+0.000000e+00*S276+0.000000e+00*S277+(-4.752467e+00)*S278+1.156391e+01*S279'
.param V74_part29='V74_part28+0.000000e+00*S280+(-3.777883e+00)*S281+1.772039e+01*S282+3.176147e+01*S283+0.000000e+00*S284+0.000000e+00*S285+0.000000e+00*S286+3.203067e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V74_part30='V74_part29+(-7.018863e+00)*S290+0.000000e+00*S291+2.149254e+00*S292+0.000000e+00*S293+0.000000e+00*S294+3.178735e-01*S295+0.000000e+00*S296+0.000000e+00*S297+1.995934e+01*S298+1.559731e+01*S299'
.param V74_part31='V74_part30+0.000000e+00*S300+(-9.034376e+00)*S301+0.000000e+00*S302+0.000000e+00*S303+6.915870e+00*S304+7.587189e+00*S305+(-3.457546e+00)*S306+8.409251e-01*S307+2.382998e+01*S308+4.265880e+00*S309'
.param V74='V74_part31+6.197063e-01*S310+2.956490e+01*S311+8.907967e+00*S312+3.419011e+00*S313+4.542594e+01*S314'
.param V75_part1='2.620503e+01*S0+(-1.759897e+02)*S1+4.729381e+03*S2+(-9.993018e+02)*S3+(-2.911059e+02)*S4+1.098952e+01*S5+3.458377e+01*S6+1.201833e+02*S7+4.615768e+01*S8+(-1.000874e+03)*S9'
.param V75_part2='V75_part1+3.520725e+01*S10+9.796439e+01*S11+6.827736e+02*S12+1.237865e+02*S13+3.179961e+03*S14+1.207679e+01*S15+7.435657e+02*S16+5.454892e+03*S17+(-7.879787e+02)*S18+1.888911e+01*S19'
.param V75_part3='V75_part2+1.000000e+04*S20+7.953198e+01*S21+3.001590e+01*S22+4.492293e+01*S23+5.588991e+01*S24+1.130798e+03*S25+5.552636e+01*S26+1.228154e+01*S27+4.372706e+01*S28+9.439939e+01*S29'
.param V75_part4='V75_part3+(-1.703776e+03)*S30+(-4.326181e-01)*S31+1.000000e+04*S32+(-1.851269e+02)*S33+1.201031e+01*S34+1.111882e+02*S35+3.497653e+01*S36+(-1.232881e+01)*S37+9.080059e+02*S38+3.007257e+01*S39'
.param V75_part5='V75_part4+3.777042e+01*S40+2.775556e+03*S41+2.096134e+01*S42+1.641535e+01*S43+3.339309e+02*S44+2.246846e+01*S45+1.310222e+01*S46+8.907340e+03*S47+6.920273e+01*S48+2.161103e+01*S49'
.param V75_part6='V75_part5+7.219168e+02*S50+2.541093e+03*S51+3.741909e+01*S52+(-3.651377e+03)*S53+6.308381e+00*S54+2.919394e+01*S55+(-3.890487e+03)*S56+2.162589e+01*S57+8.750307e+02*S58+(-4.363468e+03)*S59'
.param V75_part7='V75_part6+(-1.109740e+00)*S60+5.251218e+01*S61+7.340740e+02*S62+2.424063e+01*S63+2.055678e+01*S64+(-1.000000e+04)*S65+(-8.336132e+00)*S66+1.395653e+01*S67+(-1.290630e+02)*S68+2.594946e+00*S69'
.param V75_part8='V75_part7+(-2.749189e+03)*S70+(-4.429856e+03)*S71+(-1.245903e+01)*S72+(-4.699305e+03)*S73+(-8.339367e+01)*S74+7.421327e+00*S75+(-1.053986e+01)*S76+(-1.343402e+02)*S77+(-1.280454e+02)*S78+1.251203e+01*S79'
.param V75_part9='V75_part8+2.077865e+01*S80+(-4.124462e+03)*S81+(-2.059526e+01)*S82+(-4.360870e+01)*S83+(-4.626896e+03)*S84+(-1.621831e+01)*S85+(-5.967325e+01)*S86+2.392260e+03*S87+9.218102e+02*S88+3.332733e+03*S89'
.param V75_part10='V75_part9+1.498239e+01*S90+1.693617e+01*S91+(-1.253725e+03)*S92+(-4.428417e+03)*S93+1.000000e+04*S94+9.948296e+03*S95+5.418063e+02*S96+7.557607e+03*S97+7.319057e+03*S98+7.561291e+03*S99'
.param V75_part11='V75_part10+4.124940e+03*S100+1.000000e+04*S101+2.534978e+03*S102+1.054773e+03*S103+2.781104e+02*S104+7.492299e+03*S105+3.024041e+03*S106+1.633128e+03*S107+7.512115e+03*S108+2.585462e+03*S109'
.param V75_part12='V75_part11+(-4.204068e+03)*S110+1.188517e+01*S111+7.713194e+03*S112+(-4.234368e+03)*S113+1.220807e+01*S114+9.663321e+00*S115+1.000000e+04*S116+9.388840e+00*S117+2.952103e+02*S118+9.970347e+03*S119'
.param V75_part13='V75_part12+1.209280e+03*S120+1.508224e+01*S121+(-2.392461e+00)*S122+1.497537e+01*S123+(-4.656739e+03)*S124+1.000000e+04*S125+(-4.722298e+03)*S126+(-4.583294e+03)*S127+1.000000e+04*S128+(-4.789387e+03)*S129'
.param V75_part14='V75_part13+(-4.633814e+03)*S130+1.000000e+04*S131+3.065239e+00*S132+(-2.606675e+01)*S133+1.000000e+04*S134+2.126992e+01*S135+7.425270e+01*S136+(-4.793290e+03)*S137+(-4.808596e+03)*S138+(-1.105595e+02)*S139'
.param V75_part15='V75_part14+(-4.570263e+02)*S140+(-4.034254e+03)*S141+(-4.787570e+03)*S142+(-3.600440e+02)*S143+(-4.906645e+03)*S144+(-4.791572e+03)*S145+(-1.283464e+03)*S146+(-5.011636e+03)*S147+(-4.849786e+03)*S148+(-2.684207e+02)*S149'
.param V75_part16='V75_part15+1.282294e+01*S150+(-5.536259e+01)*S151+(-4.107889e+03)*S152+2.874736e+03*S153+6.229583e+03*S154+(-3.448864e+03)*S155+(-8.341877e+00)*S156+5.730901e+01*S157+1.000000e+04*S158+7.660629e+00*S159'
.param V75_part17='V75_part16+4.955200e+01*S160+1.170878e+01*S161+(-2.244605e+01)*S162+1.113910e+01*S163+8.374266e+02*S164+3.098302e+02*S165+2.802834e+03*S166+9.805613e+03*S167+1.578907e+01*S168+1.836114e+01*S169'
.param V75_part18='V75_part17+9.956367e+03*S170+5.134299e+00*S171+(-1.369794e+02)*S172+(-4.098392e+03)*S173+(-1.459255e+01)*S174+(-3.536559e+01)*S175+(-1.413417e+02)*S176+(-9.667352e+01)*S177+1.640110e+01*S178+(-1.270718e+01)*S179'
.param V75_part19='V75_part18+(-4.771881e+03)*S180+(-4.736674e+03)*S181+2.371025e+03*S182+(-4.743174e+03)*S183+(-4.556162e+03)*S184+(-8.717068e+00)*S185+(-4.753754e+03)*S186+(-4.431639e+03)*S187+3.990700e+02*S188+(-2.786132e+01)*S189'
.param V75_part20='V75_part19+3.936021e+01*S190+4.515940e+03*S191+1.804183e+00*S192+6.274356e+00*S193+3.380791e+03*S194+(-3.411181e+02)*S195+9.710354e+00*S196+(-2.438945e+01)*S197+2.085878e+02*S198+(-4.828736e+03)*S199'
.param V75_part21='V75_part20+(-4.619637e+03)*S200+(-5.080854e+03)*S201+(-4.737671e+03)*S202+(-4.645742e+03)*S203+2.571808e+01*S204+(-4.768425e+03)*S205+(-4.748788e+03)*S206+(-2.472232e-01)*S207+(-4.840927e+03)*S208+(-4.764638e+03)*S209'
.param V75_part22='V75_part21+5.557805e+03*S210+(-2.398061e+03)*S211+7.663000e+03*S212+(-9.250677e+02)*S213+(-2.061700e+00)*S214+7.316610e+03*S215+(-1.429519e+01)*S216+(-5.465624e+02)*S217+7.524515e+03*S218+3.121537e+00*S219'
.param V75_part23='V75_part22+1.191681e+01*S220+3.567073e+02*S221+(-9.995440e+02)*S222+1.436501e+01*S223+8.992778e+00*S224+2.124407e+01*S225+(-6.193812e+02)*S226+7.290855e+01*S227+5.910186e+00*S228+9.968845e+00*S229'
.param V75_part24='V75_part23+(-3.897886e+02)*S230+(-9.975882e+02)*S231+4.140949e+01*S232+2.253780e+01*S233+(-9.981769e+02)*S234+(-4.947902e+03)*S235+2.495055e+01*S236+(-5.215753e+01)*S237+1.548392e+01*S238+2.033629e+01*S239'
.param V75_part25='V75_part24+8.047051e+03*S240+(-2.338180e+00)*S241+5.304401e+00*S242+8.007783e+00*S243+1.784732e+01*S244+(-4.189003e+03)*S245+(-6.353344e+02)*S246+(-4.974060e+03)*S247+5.037554e+01*S248+2.514219e+00*S249'
.param V75_part26='V75_part25+3.063526e+01*S250+5.245763e+01*S251+3.469243e+00*S252+5.966057e+01*S253+4.159347e+02*S254+3.917270e+01*S255+(-1.154001e+03)*S256+(-4.763564e+03)*S257+3.925892e+00*S258+(-4.840166e+03)*S259'
.param V75_part27='V75_part26+(-4.745760e+03)*S260+(-5.637201e+00)*S261+5.599416e+00*S262+2.691172e+03*S263+(-8.546571e+00)*S264+1.530784e+02*S265+(-2.506014e+03)*S266+(-5.793230e+01)*S267+3.485730e+01*S268+2.953799e+01*S269'
.param V75_part28='V75_part27+1.146832e+01*S270+1.349000e+02*S271+1.000000e+04*S272+(-3.488786e+01)*S273+(-4.145108e+02)*S274+3.118501e+01*S275+(-9.965135e+02)*S276+9.875837e+01*S277+1.376282e+01*S278+3.400965e+00*S279'
.param V75_part29='V75_part28+(-2.556935e+03)*S280+1.465223e+01*S281+4.502950e+00*S282+9.816919e+00*S283+3.261289e+01*S284+(-1.670084e+03)*S285+(-4.968920e+03)*S286+1.000000e+04*S287+(-7.437204e+00)*S288+(-1.051838e+03)*S289'
.param V75_part30='V75_part29+2.500335e+01*S290+7.558525e+00*S291+7.316585e+00*S292+(-2.714898e+03)*S293+(-9.934432e+02)*S294+8.149997e+00*S295+7.893504e+01*S296+3.629501e+00*S297+3.705557e+00*S298+8.294583e+01*S299'
.param V75_part31='V75_part30+1.357562e+01*S300+(-4.347121e+03)*S301+3.448135e+03*S302+(-8.695360e+00)*S303+1.397763e+01*S304+2.259615e+03*S305+(-1.189351e+02)*S306+(-3.486961e+00)*S307+(-7.662023e+01)*S308+(-9.993997e+02)*S309'
.param V75='V75_part31+(-6.117839e+00)*S310+(-4.236524e+01)*S311+2.521925e+00*S312+(-1.603834e+01)*S313+(-3.427526e+02)*S314'
.param V76_part1='(-8.525384e+00)*S0+1.068177e+03*S1+4.073610e+02*S2+(-1.140512e+00)*S3+9.943453e+02*S4+1.474853e+01*S5+(-1.528639e+01)*S6+1.201833e+02*S7+4.408142e+01*S8+4.024266e+00*S9'
.param V76_part2='V76_part1+(-7.529241e-01)*S10+4.733959e+01*S11+4.567638e+01*S12+(-4.193987e+01)*S13+(-7.401893e+02)*S14+2.217711e+01*S15+(-5.764791e+02)*S16+1.000000e+04*S17+(-1.262486e+00)*S18+2.774793e+01*S19'
.param V76_part3='V76_part2+(-1.721772e+03)*S20+3.724675e+01*S21+1.995095e+01*S22+2.138038e+01*S23+(-1.349257e+01)*S24+3.056239e+03*S25+9.907319e+00*S26+2.207481e+01*S27+3.632207e-01*S28+(-8.935156e-02)*S29'
.param V76_part4='V76_part3+9.999833e+03*S30+4.682105e+01*S31+1.193972e+03*S32+5.694529e+02*S33+(-1.335434e+00)*S34+(-1.478601e+02)*S35+(-1.600657e+01)*S36+(-1.209364e+02)*S37+(-9.423010e+01)*S38+(-1.469816e+01)*S39'
.param V76_part5='V76_part4+9.609649e+00*S40+(-2.829468e+02)*S41+(-8.033409e+00)*S42+(-2.811942e+00)*S43+(-5.342420e+00)*S44+2.892658e+01*S45+1.013157e+02*S46+(-8.164957e+02)*S47+1.768739e+01*S48+(-1.059487e+01)*S49'
.param V76_part6='V76_part5+(-2.130944e+00)*S50+(-4.112130e-01)*S51+(-3.551023e+01)*S52+(-1.872593e+02)*S53+(-3.527627e+00)*S54+(-1.936720e+01)*S55+(-1.721547e+02)*S56+(-5.414273e+00)*S57+6.093316e+00*S58+(-1.398485e+00)*S59'
.param V76_part7='V76_part6+1.153806e+02*S60+7.226404e+01*S61+(-1.873061e+02)*S62+(-1.573714e+01)*S63+(-8.465228e+00)*S64+6.129253e+03*S65+3.821028e+01*S66+(-6.145330e+00)*S67+(-1.678976e+01)*S68+(-1.071911e+00)*S69'
.param V76_part8='V76_part7+(-5.291035e+02)*S70+(-1.095003e+02)*S71+8.009902e-02*S72+(-2.181658e+02)*S73+3.264894e+01*S74+2.932381e+01*S75+9.075902e+01*S76+7.509601e+00*S77+2.368858e+02*S78+9.373678e+00*S79'
.param V76_part9='V76_part8+5.320349e+00*S80+2.521190e+02*S81+4.381123e+01*S82+7.353477e+01*S83+2.678052e+02*S84+3.676135e+01*S85+3.500445e+00*S86+4.895099e+02*S87+4.600998e+01*S88+1.043359e+03*S89'
.param V76_part10='V76_part9+3.835277e-01*S90+7.556514e+01*S91+9.092393e+03*S92+(-2.767063e+02)*S93+1.000000e+04*S94+1.811898e+02*S95+6.718016e+01*S96+1.087706e+02*S97+1.367504e+02*S98+6.898844e+01*S99'
.param V76_part11='V76_part10+4.945048e+01*S100+1.884011e+01*S101+(-2.861357e+01)*S102+(-2.462471e+01)*S103+5.266287e+01*S104+6.627377e+01*S105+6.834563e+03*S106+1.054132e+03*S107+1.172888e+01*S108+2.502665e+01*S109'
.param V76_part12='V76_part11+(-3.290539e+02)*S110+(-4.094724e+00)*S111+(-5.126525e+01)*S112+(-6.721236e+01)*S113+(-6.396013e+00)*S114+(-2.477696e+02)*S115+(-5.887420e+01)*S116+5.617044e-01*S117+7.473267e+01*S118+4.864610e+01*S119'
.param V76_part13='V76_part12+3.287714e+02*S120+(-9.341848e-01)*S121+(-1.144354e+02)*S122+(-5.436347e+00)*S123+(-2.455435e+02)*S124+1.000000e+04*S125+(-2.439863e+02)*S126+(-1.918661e+02)*S127+1.000000e+04*S128+(-2.416577e+02)*S129'
.param V76_part14='V76_part13+(-1.372808e+02)*S130+1.000000e+04*S131+(-7.140973e-01)*S132+(-3.084135e+02)*S133+1.000000e+04*S134+1.944988e+01*S135+(-2.245335e+01)*S136+(-1.961045e+02)*S137+(-9.821484e+01)*S138+(-1.103103e+02)*S139'
.param V76_part15='V76_part14+6.870822e+00*S140+(-1.220564e+02)*S141+(-1.216531e+02)*S142+1.036921e+01*S143+(-4.688257e+01)*S144+(-1.122784e+02)*S145+(-4.090507e+01)*S146+(-5.080096e-01)*S147+(-7.914306e+01)*S148+(-9.627647e+01)*S149'
.param V76_part16='V76_part15+2.907441e-01*S150+(-3.470411e+01)*S151+8.807511e-01*S152+2.599041e+02*S153+5.875831e+02*S154+(-7.662857e+01)*S155+(-4.884864e-01)*S156+1.759686e+01*S157+(-3.537971e+01)*S158+2.303345e+00*S159'
.param V76_part17='V76_part16+1.253854e+01*S160+8.336106e-01*S161+(-6.697660e-01)*S162+2.223248e+01*S163+1.087229e+01*S164+5.509283e+02*S165+7.142119e+02*S166+1.114954e+03*S167+3.029203e+00*S168+9.313755e+00*S169'
.param V76_part18='V76_part17+1.785997e+02*S170+(-2.637869e-02)*S171+(-8.339161e+01)*S172+(-1.458715e+02)*S173+(-1.447375e-01)*S174+(-1.093622e+01)*S175+(-1.237679e+02)*S176+(-3.404557e-01)*S177+1.952023e+00*S178+(-1.210341e+01)*S179'
.param V76_part19='V76_part18+3.430849e+02*S180+(-7.506652e+01)*S181+9.027987e+01*S182+(-3.926422e+02)*S183+(-2.287987e+02)*S184+1.874528e+01*S185+(-2.927518e+01)*S186+(-2.145435e+02)*S187+(-2.324912e+01)*S188+(-4.249836e-01)*S189'
.param V76_part20='V76_part19+8.711960e+00*S190+1.111919e+01*S191+1.177764e+00*S192+(-3.046220e+00)*S193+5.555372e+02*S194+8.243075e+01*S195+(-2.319068e+00)*S196+(-3.858156e+01)*S197+3.831740e+01*S198+5.309745e+01*S199'
.param V76_part21='V76_part20+(-4.514092e+01)*S200+(-5.400180e+00)*S201+(-8.517025e+01)*S202+(-4.893765e+00)*S203+6.896005e+00*S204+(-8.771997e+01)*S205+9.743802e+00*S206+5.419729e-02*S207+(-6.586447e+01)*S208+(-4.942201e+00)*S209'
.param V76_part22='V76_part21+9.606436e+01*S210+(-1.967238e+01)*S211+(-8.182787e+02)*S212+(-1.330447e+02)*S213+(-6.714892e+01)*S214+6.731204e+01*S215+(-4.903393e-01)*S216+(-7.679185e+01)*S217+2.485562e+01*S218+5.505763e-01*S219'
.param V76_part23='V76_part22+9.600444e-01*S220+1.819897e+01*S221+(-4.035188e-01)*S222+(-3.492769e+01)*S223+(-3.060758e+00)*S224+1.409215e+01*S225+(-3.266477e+01)*S226+(-1.288803e+01)*S227+2.741755e-01*S228+1.030515e+00*S229'
.param V76_part24='V76_part23+6.975948e+00*S230+(-1.624559e+00)*S231+2.742085e+01*S232+3.060565e+00*S233+(-1.724992e+00)*S234+(-8.433119e+01)*S235+2.128150e+00*S236+(-1.444981e+01)*S237+1.119098e+00*S238+1.481436e+00*S239'
.param V76_part25='V76_part24+1.914418e+02*S240+2.601459e+01*S241+8.385321e+00*S242+2.683954e-02*S243+1.768106e+01*S244+(-4.745227e+01)*S245+(-4.358677e+00)*S246+(-8.254772e+01)*S247+5.312589e+00*S248+7.798297e-01*S249'
.param V76_part26='V76_part25+(-2.916958e+00)*S250+4.609352e+00*S251+(-1.271443e+00)*S252+1.877866e+01*S253+1.332610e-01*S254+5.441260e+01*S255+(-7.009007e+01)*S256+(-6.456654e+01)*S257+5.350299e+00*S258+(-4.748971e+01)*S259'
.param V76_part27='V76_part26+(-5.084986e+01)*S260+1.219849e-01*S261+(-2.418991e+00)*S262+1.055553e+03*S263+(-4.811045e-02)*S264+1.530784e+02*S265+1.000347e+02*S266+(-2.675394e-01)*S267+5.597793e+00*S268+1.450232e+00*S269'
.param V76_part28='V76_part27+(-4.683835e+01)*S270+9.223552e+02*S271+3.624298e+00*S272+(-3.743545e-01)*S273+(-2.089617e+01)*S274+6.695846e+00*S275+(-4.143218e+00)*S276+1.619475e+01*S277+2.485153e+00*S278+7.332433e-01*S279'
.param V76_part29='V76_part28+(-4.826130e+01)*S280+2.702674e+00*S281+7.836418e-01*S282+3.065210e+00*S283+1.698594e+00*S284+(-4.483267e+02)*S285+8.782958e+01*S286+9.329165e+00*S287+(-1.229632e+00)*S288+(-1.177563e+01)*S289'
.param V76_part30='V76_part29+1.902698e+00*S290+1.274434e+00*S291+3.009032e+00*S292+(-8.446739e+00)*S293+(-1.024049e+01)*S294+6.680399e+00*S295+6.332118e+00*S296+(-2.355251e-01)*S297+6.680764e-01*S298+4.161385e+00*S299'
.param V76_part31='V76_part30+1.757279e+01*S300+8.465291e+01*S301+4.323998e+02*S302+1.734176e-01*S303+(-2.945891e+00)*S304+5.661321e+02*S305+(-6.185601e-02)*S306+(-9.647236e+00)*S307+2.490184e+01*S308+(-5.462487e-01)*S309'
.param V76='V76_part31+(-9.264244e+00)*S310+4.240697e+00*S311+(-1.372099e-02)*S312+(-1.031302e+01)*S313+(-1.646411e+00)*S314'
.param V77_part1='3.272343e-01*S0+3.669561e+01*S1+1.127656e+03*S2+1.000000e+04*S3+3.365874e+02*S4+2.917132e+01*S5+5.410746e-01*S6+1.000000e+04*S7+1.949353e-01*S8+1.000000e+04*S9'
.param V77_part2='V77_part1+2.309493e+01*S10+(-3.864014e+01)*S11+1.814679e+02*S12+1.693586e+01*S13+1.698016e+02*S14+5.252974e+00*S15+1.293150e+02*S16+9.382912e+03*S17+7.888008e+03*S18+1.073338e+02*S19'
.param V77_part3='V77_part2+(-7.122655e+02)*S20+1.720578e+01*S21+1.778890e+01*S22+2.135336e+01*S23+(-3.288315e+00)*S24+1.889452e+02*S25+1.572426e+01*S26+5.027425e+01*S27+1.840124e+01*S28+1.314397e+00*S29'
.param V77_part4='V77_part3+3.889256e+02*S30+4.439584e+01*S31+1.000000e+04*S32+9.940482e+01*S33+4.201282e-01*S34+(-6.771651e+00)*S35+(-3.671332e+00)*S36+(-6.006469e+01)*S37+(-8.075654e+02)*S38+(-9.391571e+00)*S39'
.param V77_part5='V77_part4+6.678911e+00*S40+1.046440e+01*S41+(-4.712828e+00)*S42+(-4.646697e+00)*S43+(-2.489723e+00)*S44+(-7.422840e+00)*S45+8.338392e+01*S46+(-8.498114e+03)*S47+(-4.999649e+01)*S48+(-1.553768e+01)*S49'
.param V77_part6='V77_part5+(-6.774331e+02)*S50+(-3.428724e+01)*S51+(-2.288151e+01)*S52+(-1.119371e+03)*S53+(-4.024485e+00)*S54+(-1.805817e+01)*S55+(-8.752037e+02)*S56+(-3.433801e+01)*S57+(-4.598197e+02)*S58+(-5.525340e+02)*S59'
.param V77_part7='V77_part6+1.728720e+01*S60+(-3.411647e+01)*S61+(-4.257569e-01)*S62+(-1.605119e+01)*S63+(-1.512923e+01)*S64+6.129253e+03*S65+1.364903e+01*S66+(-6.121451e+00)*S67+(-1.550262e+01)*S68+(-1.615421e+00)*S69'
.param V77_part8='V77_part7+(-3.283614e+02)*S70+(-3.515423e+02)*S71+1.247991e+02*S72+4.188828e+01*S73+8.177506e+01*S74+7.161278e+00*S75+5.609297e+00*S76+3.045569e+02*S77+(-2.659431e+01)*S78+6.317319e-01*S79'
.param V77_part9='V77_part8+2.778542e+00*S80+1.908555e+02*S81+2.000195e+01*S82+2.887042e+01*S83+3.896041e+02*S84+2.779899e+01*S85+1.319652e+02*S86+1.574683e+02*S87+1.041541e+02*S88+4.077952e+02*S89'
.param V77_part10='V77_part9+(-2.324329e+01)*S90+(-1.510053e+02)*S91+(-5.924923e+02)*S92+(-8.869143e+02)*S93+1.000000e+04*S94+(-1.000000e+04)*S95+(-1.370128e+02)*S96+(-1.106035e+02)*S97+(-7.341002e+03)*S98+(-1.600514e+02)*S99'
.param V77_part11='V77_part10+(-6.398506e+03)*S100+(-9.975667e+03)*S101+2.220620e+01*S102+(-1.814351e+03)*S103+8.620683e+02*S104+3.950248e+01*S105+2.937259e+01*S106+6.260912e+02*S107+3.068113e+01*S108+(-5.725496e+01)*S109'
.param V77_part12='V77_part11+(-1.679779e+02)*S110+(-1.991866e+01)*S111+(-1.548710e+02)*S112+(-6.359920e+02)*S113+(-1.412675e+01)*S114+(-2.789550e+02)*S115+3.072313e+02*S116+(-5.969537e+00)*S117+(-4.048859e+01)*S118+(-1.000000e+04)*S119'
.param V77_part13='V77_part12+3.921765e+00*S120+(-1.614901e+01)*S121+(-5.614238e+02)*S122+(-2.603374e+01)*S123+(-2.472047e+02)*S124+1.000000e+04*S125+(-5.026973e+01)*S126+(-3.061606e+02)*S127+1.000000e+04*S128+2.208143e+02*S129'
.param V77_part14='V77_part13+(-2.795806e+02)*S130+1.000000e+04*S131+(-2.509636e+00)*S132+(-1.708794e+02)*S133+1.000000e+04*S134+(-4.222072e+01)*S135+(-9.233769e+01)*S136+(-7.012595e+01)*S137+(-2.358102e+02)*S138+(-7.031366e+01)*S139'
.param V77_part15='V77_part14+(-1.682395e+02)*S140+(-2.352442e+02)*S141+(-9.452487e+01)*S142+3.373277e+01*S143+(-2.064196e+01)*S144+(-6.501974e+01)*S145+(-9.230457e+00)*S146+1.294696e+02*S147+3.763014e+01*S148+(-6.335386e+01)*S149'
.param V77_part16='V77_part15+(-2.306231e+01)*S150+(-9.193421e+01)*S151+(-8.288298e+02)*S152+(-1.838279e+03)*S153+(-1.289725e+03)*S154+(-1.441112e+03)*S155+8.979869e+01*S156+(-9.380136e+01)*S157+(-9.954024e+03)*S158+(-2.067143e+01)*S159'
.param V77_part17='V77_part16+(-7.165965e+01)*S160+(-1.068002e+01)*S161+2.365625e+02*S162+(-4.362748e+01)*S163+(-8.368247e+02)*S164+4.583924e+01*S165+(-6.032165e+02)*S166+(-1.000000e+04)*S167+(-3.246010e+01)*S168+(-2.656906e+01)*S169'
.param V77_part18='V77_part17+(-1.000000e+04)*S170+(-8.360237e+00)*S171+6.001433e+02*S172+6.884943e+03*S173+1.501976e+02*S174+1.494781e+02*S175+3.347010e+02*S176+9.718853e+02*S177+(-2.299775e+01)*S178+(-1.009032e+01)*S179'
.param V77_part19='V77_part18+(-6.253877e+02)*S180+(-2.754765e+02)*S181+(-2.364780e+03)*S182+(-2.927043e+01)*S183+(-4.518568e+02)*S184+(-5.554326e+01)*S185+2.964590e+01*S186+(-4.473099e+02)*S187+(-3.726007e+02)*S188+2.850102e+02*S189'
.param V77_part20='V77_part19+(-5.424007e+01)*S190+(-4.498249e+03)*S191+(-1.689369e+00)*S192+(-5.383700e+00)*S193+1.000000e+04*S194+8.493703e+03*S195+(-9.560876e+00)*S196+(-1.032123e+02)*S197+(-4.156191e+00)*S198+(-1.615965e+02)*S199'
.param V77_part21='V77_part20+(-2.770524e+02)*S200+9.225444e+02*S201+(-1.925216e+02)*S202+(-2.654175e+02)*S203+(-5.760974e+01)*S204+(-1.667884e+02)*S205+(-1.881246e+02)*S206+3.311739e+00*S207+(-5.957118e+01)*S208+(-1.799107e+02)*S209'
.param V77_part22='V77_part21+1.604408e+02*S210+(-2.437425e+02)*S211+1.804575e+02*S212+1.000000e+04*S213+5.083208e+02*S214+2.926639e+02*S215+1.482515e+02*S216+2.749709e+00*S217+(-1.467236e+01)*S218+(-5.857753e+00)*S219'
.param V77_part23='V77_part22+(-1.352757e+01)*S220+(-3.635062e+02)*S221+1.000000e+04*S222+5.649851e+01*S223+(-4.630975e+00)*S224+(-5.120398e+01)*S225+4.355026e+01*S226+(-2.098049e+02)*S227+(-1.107736e+01)*S228+(-1.207769e+01)*S229'
.param V77_part24='V77_part23+(-1.037144e+02)*S230+1.000000e+04*S231+(-6.652291e+01)*S232+(-2.136796e+01)*S233+1.000000e+04*S234+1.609777e+02*S235+(-2.371725e+01)*S236+6.693953e+02*S237+(-1.936422e+01)*S238+(-2.043790e+01)*S239'
.param V77_part25='V77_part24+(-1.061516e+03)*S240+(-3.034724e+01)*S241+(-2.166487e+01)*S242+(-1.529533e+01)*S243+(-1.210059e+02)*S244+(-7.457983e+02)*S245+6.394090e+03*S246+1.334311e+02*S247+(-4.829648e+01)*S248+(-3.026010e+00)*S249'
.param V77_part26='V77_part25+(-3.730953e+01)*S250+(-5.027771e+01)*S251+(-2.272616e+00)*S252+(-1.314099e+02)*S253+(-4.068486e+02)*S254+(-9.305109e+01)*S255+(-2.505141e+02)*S256+(-1.613000e+02)*S257+(-1.003736e+01)*S258+(-1.328183e+02)*S259'
.param V77_part27='V77_part26+(-1.835405e+02)*S260+5.840155e+01*S261+(-3.966296e+00)*S262+2.830872e+02*S263+8.900678e+01*S264+1.530784e+02*S265+(-3.580508e+01)*S266+5.838661e+02*S267+(-4.990413e+01)*S268+(-2.732491e+01)*S269'
.param V77_part28='V77_part27+4.387833e+01*S270+(-4.796521e+02)*S271+(-9.991041e+03)*S272+3.540235e+02*S273+(-2.200911e+01)*S274+(-3.185130e+01)*S275+1.000000e+04*S276+(-8.272608e+01)*S277+(-1.326308e+01)*S278+(-6.281577e+00)*S279'
.param V77_part29='V77_part28+7.451174e+02*S280+(-1.467511e+01)*S281+(-4.190939e+00)*S282+(-1.444938e+01)*S283+(-3.190565e+01)*S284+3.297773e+01*S285+(-3.459552e+01)*S286+(-9.976052e+03)*S287+8.184534e+01*S288+1.000000e+04*S289'
.param V77_part30='V77_part29+(-2.242550e+01)*S290+(-1.534116e+01)*S291+(-9.111653e+00)*S292+(-1.005256e+02)*S293+1.000000e+04*S294+(-1.292662e+01)*S295+(-7.930325e+01)*S296+(-4.693469e+00)*S297+(-1.696938e+00)*S298+(-8.297113e+01)*S299'
.param V77_part31='V77_part30+(-3.292467e+01)*S300+(-1.661235e+02)*S301+2.290136e+03*S302+8.876493e+01*S303+(-1.222263e+01)*S304+(-9.249649e+00)*S305+1.190902e+03*S306+2.594188e+01*S307+(-3.496271e+01)*S308+1.000000e+04*S309'
.param V77='V77_part31+3.227069e+01*S310+(-3.044426e+01)*S311+(-3.113695e+00)*S312+5.859636e+01*S313+(-4.950549e+01)*S314'
.param V78_part1='7.592203e+01*S0+5.375555e+00*S1+1.445844e+03*S2+(-1.975416e-01)*S3+1.605030e+01*S4+1.055592e+02*S5+5.664346e+01*S6+1.000000e+04*S7+1.017328e+02*S8+2.266602e-01*S9'
.param V78_part2='V78_part1+1.163113e+02*S10+2.586292e+02*S11+2.935697e+03*S12+2.668448e+02*S13+1.000000e+04*S14+5.903791e+01*S15+2.269875e+03*S16+1.000000e+04*S17+(-1.345674e-01)*S18+1.816433e+02*S19'
.param V78_part3='V78_part2+(-9.731708e+03)*S20+3.091543e+02*S21+9.660983e+01*S22+1.585042e+02*S23+9.881626e+01*S24+7.676378e+03*S25+1.410092e+02*S26+1.052084e+02*S27+1.025438e+02*S28+1.815854e+02*S29'
.param V78_part4='V78_part3+(-1.905844e+00)*S30+8.037075e+01*S31+2.206010e+01*S32+2.258675e+01*S33+1.866765e+01*S34+3.124396e+01*S35+4.366689e+01*S36+4.643027e+01*S37+2.089849e+01*S38+2.733291e+01*S39'
.param V78_part5='V78_part4+(-5.447799e+01)*S40+1.000000e+04*S41+2.152696e+01*S42+2.481702e+01*S43+1.156471e+03*S44+(-1.763394e+01)*S45+2.010151e+02*S46+(-1.273464e+01)*S47+1.377953e+02*S48+1.219757e+00*S49'
.param V78_part6='V78_part5+8.935152e+00*S50+1.000000e+04*S51+2.129839e+00*S52+(-3.114809e+01)*S53+1.405752e+00*S54+9.954403e-01*S55+(-2.656419e+01)*S56+1.890928e+00*S57+(-5.353335e+02)*S58+(-1.745147e+01)*S59'
.param V78_part7='V78_part6+3.249339e+01*S60+1.080981e+01*S61+(-7.397365e+02)*S62+1.958520e+01*S63+9.837272e+00*S64+9.632966e+02*S65+(-6.659774e+00)*S66+1.423535e+00*S67+3.933945e+01*S68+8.069385e-02*S69'
.param V78_part8='V78_part7+3.390956e+01*S70+2.177238e+01*S71+(-9.894419e-03)*S72+3.136586e+01*S73+3.335937e+00*S74+4.380530e+01*S75+1.174440e+01*S76+4.258509e+01*S77+(-6.682717e+01)*S78+1.630563e+01*S79'
.param V78_part9='V78_part8+(-1.135696e+01)*S80+(-1.338391e+03)*S81+(-8.750949e+00)*S82+(-1.545118e+01)*S83+(-7.480437e+02)*S84+(-1.830003e+01)*S85+5.991563e+01*S86+1.000000e+04*S87+3.756962e+03*S88+(-6.211987e+03)*S89'
.param V78_part10='V78_part9+4.194366e+00*S90+2.333477e+01*S91+2.025134e+03*S92+(-2.442586e+01)*S93+5.916421e+03*S94+1.691576e+00*S95+(-6.473173e+02)*S96+(-1.000000e+04)*S97+4.539655e-01*S98+(-1.000000e+04)*S99'
.param V78_part11='V78_part10+5.144799e+02*S100+(-7.831302e+00)*S101+1.000000e+04*S102+1.331754e+01*S103+(-1.250962e+00)*S104+(-1.000000e+04)*S105+7.604055e+01*S106+(-2.606984e+02)*S107+(-1.000000e+04)*S108+(-3.367714e+03)*S109'
.param V78_part12='V78_part11+1.393715e+01*S110+(-6.614251e-03)*S111+(-1.000000e+04)*S112+(-1.010409e+01)*S113+1.121257e+00*S114+(-7.714479e+00)*S115+2.674117e+01*S116+(-4.532117e+00)*S117+9.865593e-01*S118+(-2.345040e+00)*S119'
.param V78_part13='V78_part12+4.999645e+03*S120+2.713201e-02*S121+2.616126e+00*S122+(-8.088122e-01)*S123+9.652433e+00*S124+1.000000e+04*S125+(-1.646942e+01)*S126+(-1.417971e+01)*S127+1.000000e+04*S128+(-8.015207e+00)*S129'
.param V78_part14='V78_part13+(-3.691480e+01)*S130+8.197000e+03*S131+(-3.941207e-01)*S132+(-8.912856e+02)*S133+1.000000e+04*S134+(-8.013915e+00)*S135+(-9.708143e+00)*S136+(-2.290908e+01)*S137+(-3.085966e+01)*S138+(-2.142749e+01)*S139'
.param V78_part15='V78_part14+(-4.193513e+01)*S140+(-3.653443e+01)*S141+(-3.093528e+01)*S142+(-8.478245e+00)*S143+(-2.770429e+01)*S144+(-2.358757e+01)*S145+(-1.634654e+01)*S146+(-3.302634e-01)*S147+(-1.770532e+01)*S148+(-4.895656e+01)*S149'
.param V78_part16='V78_part15+1.263832e+00*S150+(-1.170853e+00)*S151+(-1.181708e+01)*S152+(-9.538109e+03)*S153+(-9.282293e+03)*S154+(-2.489143e+01)*S155+(-9.898899e-02)*S156+1.250228e+00*S157+(-1.037981e+01)*S158+7.490290e-02*S159'
.param V78_part17='V78_part16+2.619460e+00*S160+(-1.415931e-01)*S161+(-1.539776e-01)*S162+1.705799e+00*S163+1.917158e+00*S164+7.953706e-01*S165+1.000000e+04*S166+(-1.401815e+01)*S167+(-5.400246e-02)*S168+2.833565e-01*S169'
.param V78_part18='V78_part17+(-3.960447e+00)*S170+(-2.366111e-01)*S171+4.770086e+01*S172+1.100885e+03*S173+(-9.677549e-02)*S174+6.773280e+00*S175+1.388649e+01*S176+(-3.451808e-02)*S177+2.161625e-01*S178+8.314504e-01*S179'
.param V78_part19='V78_part18+1.068137e+00*S180+(-4.575159e+00)*S181+(-3.076507e+01)*S182+(-1.056321e+01)*S183+(-9.518981e+00)*S184+(-1.566561e+00)*S185+8.306801e+00*S186+(-1.550501e+01)*S187+(-3.155672e+00)*S188+(-1.918079e-02)*S189'
.param V78_part20='V78_part19+1.215010e+00*S190+(-1.242694e+01)*S191+(-2.693655e-01)*S192+(-2.956138e-01)*S193+(-1.000000e+04)*S194+1.033542e+03*S195+(-1.319110e+00)*S196+(-6.445070e+00)*S197+(-2.639928e-01)*S198+(-3.384203e+01)*S199'
.param V78_part21='V78_part20+(-3.329465e+01)*S200+(-4.811200e+00)*S201+(-3.747441e+01)*S202+(-4.397188e+01)*S203+(-2.900885e+00)*S204+(-3.200898e+01)*S205+(-3.506892e+01)*S206+(-8.705445e-02)*S207+(-2.664120e+01)*S208+(-2.412140e+01)*S209'
.param V78_part22='V78_part21+(-7.379231e+03)*S210+2.671070e+00*S211+(-1.000000e+04)*S212+(-3.675306e+01)*S213+(-2.421725e+00)*S214+(-1.000000e+04)*S215+(-7.727563e-02)*S216+2.476650e+01*S217+(-1.000000e+04)*S218+(-9.638810e-02)*S219'
.param V78_part23='V78_part22+1.027433e+00*S220+(-4.609488e-01)*S221+(-1.018384e-01)*S222+(-1.939899e-01)*S223+(-4.172140e-02)*S224+4.351053e-01*S225+5.681354e+00*S226+(-1.220830e+01)*S227+(-1.086728e-01)*S228+3.622083e-02*S229'
.param V78_part24='V78_part23+(-5.338019e+00)*S230+1.849685e-01*S231+6.178293e+00*S232+(-5.223926e-02)*S233+(-8.716014e-02)*S234+(-3.134980e+01)*S235+(-4.569638e-02)*S236+(-2.376393e-01)*S237+8.518869e-01*S238+(-6.735481e-01)*S239'
.param V78_part25='V78_part24+(-9.968821e+03)*S240+1.544099e-01*S241+(-1.039569e+00)*S242+(-1.967187e-01)*S243+3.917404e+00*S244+(-1.459962e+01)*S245+3.859049e-01*S246+5.959624e-02*S247+(-4.547820e-01)*S248+(-2.402053e-01)*S249'
.param V78_part26='V78_part25+(-5.306959e-01)*S250+(-4.585815e-01)*S251+1.416689e-03*S252+(-6.370772e+00)*S253+(-1.788008e+00)*S254+(-2.135398e+00)*S255+(-2.821839e+01)*S256+(-2.359831e+01)*S257+(-8.369382e-01)*S258+(-3.413124e+01)*S259'
.param V78_part27='V78_part26+(-2.315743e+01)*S260+(-1.722500e-01)*S261+(-5.739139e-01)*S262+(-6.302599e+01)*S263+(-1.969317e-01)*S264+(-4.416169e+03)*S265+(-3.321340e+03)*S266+(-2.196653e-01)*S267+(-7.952240e+00)*S268+(-3.383755e-01)*S269'
.param V78_part28='V78_part27+(-2.030292e-01)*S270+(-4.085503e+00)*S271+(-8.004913e+00)*S272+(-1.320211e-01)*S273+4.326601e+00*S274+(-2.751863e-01)*S275+(-3.763983e-01)*S276+(-2.833310e-01)*S277+(-1.028255e-01)*S278+(-1.435879e-01)*S279'
.param V78_part29='V78_part28+(-1.843192e+00)*S280+(-1.511904e-01)*S281+(-4.809158e-01)*S282+7.115154e-01*S283+(-5.142854e-02)*S284+(-1.292331e+01)*S285+8.149420e+00*S286+(-8.961891e+00)*S287+(-3.319333e-01)*S288+(-7.944639e+00)*S289'
.param V78_part30='V78_part29+6.068222e-02*S290+(-9.134683e-02)*S291+8.385910e-02*S292+(-1.573608e+00)*S293+2.235311e-01*S294+7.527875e-01*S295+3.439993e-01*S296+(-1.762738e-01)*S297+3.192841e-02*S298+3.346157e-01*S299'
.param V78_part31='V78_part30+(-1.598616e+00)*S300+(-2.066662e+01)*S301+(-1.000000e+04)*S302+(-2.925607e-01)*S303+(-3.472938e-01)*S304+(-9.840408e+03)*S305+(-3.524359e-01)*S306+(-1.578296e+00)*S307+(-6.228676e+00)*S308+(-2.579805e-01)*S309'
.param V78='V78_part31+(-1.459558e+00)*S310+(-4.921736e+00)*S311+(-3.341037e-01)*S312+(-1.487173e+00)*S313+(-5.100016e+00)*S314'
.param V79_part1='3.547274e-03*S0+(-2.141017e-01)*S1+4.883690e+01*S2+1.417478e-02*S3+(-3.923593e+01)*S4+3.140874e-01*S5+2.735583e-01*S6+1.201833e+02*S7+7.335263e-01*S8+(-1.402044e-02)*S9'
.param V79_part2='V79_part1+2.576902e-01*S10+(-1.539382e+00)*S11+5.007004e-01*S12+8.509957e-01*S13+2.031726e+02*S14+9.278035e-02*S15+1.768181e+01*S16+1.137687e+03*S17+(-7.888556e-04)*S18+9.590916e-01*S19'
.param V79_part3='V79_part2+1.272522e+02*S20+5.013580e-01*S21+2.666270e-02*S22+1.165772e+00*S23+7.935525e-01*S24+2.455624e+01*S25+6.390146e-01*S26+3.942353e-01*S27+2.251579e-01*S28+1.489188e+00*S29'
.param V79_part4='V79_part3+6.481350e-02*S30+3.967989e-01*S31+4.406229e+03*S32+9.492247e+00*S33+4.705761e-01*S34+1.474230e+00*S35+1.333063e+00*S36+3.255126e+02*S37+1.182596e+01*S38+1.661892e+00*S39'
.param V79_part5='V79_part4+3.610361e-02*S40+1.532499e+01*S41+1.378750e+00*S42+1.053854e+00*S43+1.978669e+01*S44+2.829885e-01*S45+1.890873e+00*S46+1.910676e+01*S47+(-2.215225e+00)*S48+8.672463e-01*S49'
.param V79_part6='V79_part5+2.448942e+01*S50+1.277351e+01*S51+3.510069e+01*S52+1.000000e+04*S53+1.518743e+00*S54+1.754101e+01*S55+1.000000e+04*S56+1.126637e+01*S57+(-7.326589e+01)*S58+1.000000e+04*S59'
.param V79_part7='V79_part6+(-3.132615e+00)*S60+(-1.875559e+00)*S61+(-9.782726e+00)*S62+1.913627e+01*S63+8.462544e+00*S64+7.353189e+03*S65+(-2.768908e+00)*S66+1.071960e+01*S67+5.155631e+02*S68+1.584774e+00*S69'
.param V79_part8='V79_part7+6.995757e+03*S70+1.000000e+04*S71+6.748787e-02*S72+1.000000e+04*S73+3.661194e+01*S74+(-4.764734e-02)*S75+1.897778e-01*S76+(-3.100772e+01)*S77+2.537049e+02*S78+(-1.692260e+00)*S79'
.param V79_part9='V79_part8+3.877360e+00*S80+9.999998e+03*S81+1.475411e+01*S82+1.554344e+01*S83+1.000000e+04*S84+2.643559e+01*S85+1.629281e+01*S86+4.451049e+02*S87+(-8.103224e+00)*S88+4.076681e+02*S89'
.param V79_part10='V79_part9+1.343759e+00*S90+2.171405e+02*S91+2.079842e+03*S92+1.000000e+04*S93+1.000000e+04*S94+2.484870e+01*S95+2.104721e+00*S96+3.297187e+00*S97+4.180390e+00*S98+(-6.974641e+00)*S99'
.param V79_part11='V79_part10+8.110186e+02*S100+1.703893e+01*S101+3.888368e+00*S102+4.885826e+02*S103+3.632062e+02*S104+3.749839e+01*S105+3.768940e+01*S106+(-1.164913e+03)*S107+2.641169e+01*S108+2.966149e+01*S109'
.param V79_part12='V79_part11+9.264135e+03*S110+1.438482e+01*S111+(-1.240002e+01)*S112+1.000000e+04*S113+1.344054e+01*S114+7.677972e+02*S115+(-6.740974e+03)*S116+2.592517e-02*S117+(-7.451747e+01)*S118+1.747222e+01*S119'
.param V79_part13='V79_part12+6.108885e+00*S120+1.089878e+01*S121+1.332551e+03*S122+1.700643e+01*S123+1.000000e+04*S124+1.000000e+04*S125+1.000000e+04*S126+1.000000e+04*S127+1.000000e+04*S128+1.000000e+04*S129'
.param V79_part14='V79_part13+1.000000e+04*S130+1.000000e+04*S131+9.724551e-01*S132+2.384205e+03*S133+1.000000e+04*S134+7.325561e+00*S135+3.069530e+01*S136+1.000000e+04*S137+1.000000e+04*S138+5.060463e+02*S139'
.param V79_part15='V79_part14+1.464810e+03*S140+8.543830e+03*S141+1.000000e+04*S142+8.284503e+02*S143+1.000000e+04*S144+1.000000e+04*S145+2.902198e+03*S146+1.000000e+04*S147+1.000000e+04*S148+1.010479e+03*S149'
.param V79_part16='V79_part15+1.308118e+00*S150+3.624533e+02*S151+1.000000e+04*S152+1.000000e+04*S153+2.981791e+03*S154+1.000000e+04*S155+1.643036e-01*S156+1.961562e+01*S157+1.431934e+01*S158+2.695483e+00*S159'
.param V79_part17='V79_part16+5.695049e+00*S160+1.099128e+00*S161+3.442036e-01*S162+1.274570e+01*S163+9.136379e-01*S164+(-1.918726e+02)*S165+5.132920e+01*S166+3.935224e+01*S167+2.333294e+00*S168+3.808842e+00*S169'
.param V79_part18='V79_part17+3.605175e+01*S170+6.297561e-01*S171+(-8.963768e-01)*S172+(-4.205624e+01)*S173+2.977214e-01*S174+(-1.022217e-01)*S175+1.048827e+02*S176+8.416673e-01*S177+4.857073e+00*S178+9.287716e+01*S179'
.param V79_part19='V79_part18+1.000000e+04*S180+1.000000e+04*S181+5.292863e+01*S182+1.000000e+04*S183+1.000000e+04*S184+1.485466e+02*S185+9.600539e+03*S186+9.783593e+03*S187+5.568519e+00*S188+4.757493e-01*S189'
.param V79_part20='V79_part19+3.333726e+00*S190+5.074480e+00*S191+(-1.999934e-01)*S192+1.357567e+01*S193+6.128114e+02*S194+1.151385e+02*S195+4.113003e+00*S196+3.644748e+02*S197+(-1.301490e+02)*S198+1.000000e+04*S199'
.param V79_part21='V79_part20+1.000000e+04*S200+1.000000e+04*S201+1.000000e+04*S202+1.000000e+04*S203+4.087011e+00*S204+1.000000e+04*S205+1.000000e+04*S206+1.491860e-01*S207+9.999961e+03*S208+1.000000e+04*S209'
.param V79_part22='V79_part21+1.171641e+01*S210+5.218030e+03*S211+1.260385e+02*S212+5.682548e+01*S213+(-9.888022e+01)*S214+3.587024e+01*S215+9.899751e-01*S216+1.246998e+03*S217+4.922616e+01*S218+3.132388e-01*S219'
.param V79_part23='V79_part22+1.100900e-01*S220+5.516576e+00*S221+1.768200e+00*S222+2.942029e+00*S223+7.763197e-01*S224+1.471973e+00*S225+1.300368e+03*S226+3.472751e+02*S227+8.252464e-01*S228+1.130820e+00*S229'
.param V79_part24='V79_part23+1.015733e+03*S230+3.303625e-02*S231+(-4.587108e-01)*S232+1.120474e+00*S233+1.133303e+00*S234+1.000000e+04*S235+1.221420e+00*S236+1.918117e+00*S237+1.284286e+00*S238+4.868922e+00*S239'
.param V79_part25='V79_part24+(-4.990344e+01)*S240+6.044782e+01*S241+5.104588e+01*S242+1.122741e+00*S243+1.508808e+02*S244+1.000000e+04*S245+1.387616e+00*S246+1.000000e+04*S247+1.658658e+00*S248+(-1.940782e-02)*S249'
.param V79_part26='V79_part25+6.891846e+00*S250+3.410048e-01*S251+2.740541e-01*S252+5.534569e+01*S253+1.019853e-01*S254+4.942035e+00*S255+2.779742e+03*S256+1.000000e+04*S257+3.343131e+00*S258+1.000000e+04*S259'
.param V79_part27='V79_part26+1.000000e+04*S260+3.052872e-01*S261+7.125537e-01*S262+1.919787e+01*S263+4.363312e-01*S264+9.978921e+03*S265+1.000000e+04*S266+8.626210e-01*S267+1.358388e+01*S268+6.360489e-01*S269'
.param V79_part28='V79_part27+1.222474e+00*S270+3.280894e+00*S271+3.215915e+01*S272+1.014511e+00*S273+9.281880e+02*S274+5.160840e+00*S275+1.279458e+00*S276+(-3.137598e+01)*S277+6.246341e-01*S278+1.697433e-01*S279'
.param V79_part29='V79_part28+4.613022e+03*S280+5.663997e-01*S281+(-7.452955e-01)*S282+9.969719e-01*S283+6.682218e-01*S284+3.712227e+03*S285+1.000000e+04*S286+6.110476e+00*S287+2.069740e+00*S288+(-1.926995e+03)*S289'
.param V79_part30='V79_part29+6.329592e-01*S290+1.750070e-01*S291+4.960892e-01*S292+5.674428e+03*S293+7.396150e+00*S294+(-3.434339e-01)*S295+1.494908e+00*S296+1.707936e-01*S297+(-2.616316e-02)*S298+8.614479e-01*S299'
.param V79_part31='V79_part30+1.013905e+00*S300+8.969803e+03*S301+9.199582e+03*S302+6.646879e-01*S303+(-2.542660e-01)*S304+1.000000e+04*S305+1.488225e+00*S306+7.095607e+00*S307+2.267125e+02*S308+1.358313e+00*S309'
.param V79='V79_part31+9.753557e+00*S310+1.655810e+02*S311+2.385684e-01*S312+1.407565e+01*S313+8.127122e+02*S314'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V80_part2='V80_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-3.323025e-02)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V80_part3='V80_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V80_part4='V80_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+(-3.406604e-03)*S33+(-1.181751e-01)*S34+0.000000e+00*S35+(-9.846662e-02)*S36+0.000000e+00*S37+(-2.749145e-01)*S38+(-1.592638e-01)*S39'
.param V80_part5='V80_part4+6.172911e-03*S40+(-2.691667e-01)*S41+(-1.861686e-01)*S42+(-2.778676e-01)*S43+(-1.978835e-01)*S44+(-1.263776e-02)*S45+(-7.496192e-02)*S46+7.304963e-02*S47+(-9.396308e-02)*S48+(-1.169357e-01)*S49'
.param V80_part6='V80_part5+1.600396e-01*S50+2.387387e-02*S51+(-8.405745e-02)*S52+(-1.621571e-01)*S53+9.908169e-02*S54+(-1.138468e-01)*S55+(-1.360111e-01)*S56+0.000000e+00*S57+0.000000e+00*S58+(-2.267321e-01)*S59'
.param V80_part7='V80_part6+0.000000e+00*S60+0.000000e+00*S61+(-8.601134e-02)*S62+(-5.209043e-02)*S63+(-3.234738e-02)*S64+0.000000e+00*S65+(-7.612311e-02)*S66+5.158288e-02*S67+(-1.327428e-01)*S68+6.193503e-01*S69'
.param V80_part8='V80_part7+(-1.167098e-01)*S70+(-2.488057e-01)*S71+1.058899e+00*S72+(-9.218370e-02)*S73+(-1.400662e-02)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V80_part9='V80_part8+(-1.560556e-02)*S80+3.033665e-02*S81+6.299992e-02*S82+6.444766e-02*S83+1.260562e-01*S84+1.638810e-02*S85+(-6.862562e-04)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V80_part10='V80_part9+(-3.758000e-02)*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+(-1.565349e-01)*S95+(-1.419584e-01)*S96+(-1.432078e-01)*S97+(-5.712094e-01)*S98+(-2.060973e-01)*S99'
.param V80_part11='V80_part10+(-2.670710e-02)*S100+(-5.421423e-01)*S101+(-4.464222e-02)*S102+3.322342e-03*S103+0.000000e+00*S104+3.141457e-03*S105+(-1.577116e-02)*S106+(-2.739430e-01)*S107+7.575080e-02*S108+(-5.587143e-02)*S109'
.param V80_part12='V80_part11+(-4.464826e-01)*S110+1.957316e-01*S111+0.000000e+00*S112+(-3.228902e-01)*S113+(-2.214217e-02)*S114+(-1.396222e-01)*S115+1.694873e-01*S116+2.609553e-01*S117+(-1.735732e-01)*S118+(-1.032734e+00)*S119'
.param V80_part13='V80_part12+1.115106e-01*S120+(-1.642548e-02)*S121+(-1.980001e-01)*S122+1.489083e-01*S123+(-4.578245e-02)*S124+(-1.308780e-01)*S125+(-5.628742e-02)*S126+(-7.675563e-02)*S127+(-2.370902e-01)*S128+3.775904e-02*S129'
.param V80_part14='V80_part13+(-9.470368e-02)*S130+(-5.770109e-01)*S131+7.174156e-01*S132+(-1.648827e-02)*S133+(-7.024082e-01)*S134+5.578084e-02*S135+0.000000e+00*S136+(-1.935167e-01)*S137+0.000000e+00*S138+9.893263e-02*S139'
.param V80_part15='V80_part14+(-1.036628e-01)*S140+0.000000e+00*S141+(-6.171536e-02)*S142+6.397703e-02*S143+(-1.769258e-02)*S144+(-7.417453e-02)*S145+2.031766e-02*S146+(-1.277713e-01)*S147+(-7.120387e-02)*S148+(-3.375489e-01)*S149'
.param V80_part16='V80_part15+5.525276e-02*S150+(-9.045046e-02)*S151+(-2.022747e-01)*S152+0.000000e+00*S153+(-1.645352e-01)*S154+(-2.608375e-01)*S155+1.818498e-01*S156+(-7.546145e-02)*S157+(-6.261204e-01)*S158+2.051339e-01*S159'
.param V80_part17='V80_part16+0.000000e+00*S160+(-8.501053e-01)*S161+4.775358e-01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+(-9.382571e-02)*S166+(-5.537597e-01)*S167+2.466874e-03*S168+(-2.791567e-01)*S169'
.param V80_part18='V80_part17+(-1.022356e-02)*S170+4.832802e-01*S171+(-2.583847e-01)*S172+(-5.387966e-01)*S173+0.000000e+00*S174+1.836174e-01*S175+(-1.892372e+00)*S176+0.000000e+00*S177+1.670707e+00*S178+(-7.034098e-01)*S179'
.param V80_part19='V80_part18+0.000000e+00*S180+(-1.098010e-01)*S181+0.000000e+00*S182+5.872989e-02*S183+2.586124e-02*S184+(-5.188578e-01)*S185+1.067818e-02*S186+(-9.288943e-02)*S187+7.316739e-01*S188+6.715579e-01*S189'
.param V80_part20='V80_part19+(-1.713173e-01)*S190+0.000000e+00*S191+0.000000e+00*S192+7.465375e-01*S193+1.785927e+00*S194+0.000000e+00*S195+2.116680e-01*S196+(-2.176035e-01)*S197+1.083391e-01*S198+(-2.121897e-02)*S199'
.param V80_part21='V80_part20+(-3.062983e-01)*S200+7.010310e-03*S201+(-1.052662e-01)*S202+(-3.076903e-01)*S203+2.533946e-01*S204+(-1.983813e-01)*S205+(-3.306054e-01)*S206+2.968447e+00*S207+(-6.095560e-01)*S208+(-4.165274e-01)*S209'
.param V80_part22='V80_part21+(-1.816653e-02)*S210+(-2.789883e-01)*S211+0.000000e+00*S212+0.000000e+00*S213+0.000000e+00*S214+(-3.374337e-01)*S215+3.797718e-01*S216+(-4.804932e-01)*S217+(-4.188421e-01)*S218+0.000000e+00*S219'
.param V80_part23='V80_part22+0.000000e+00*S220+0.000000e+00*S221+5.258644e-01*S222+(-2.110596e-02)*S223+0.000000e+00*S224+1.949612e-01*S225+(-3.377913e-01)*S226+(-6.718276e-01)*S227+4.111864e-01*S228+(-1.296089e-01)*S229'
.param V80_part24='V80_part23+(-8.921913e-01)*S230+0.000000e+00*S231+(-2.732370e-01)*S232+2.182860e-01*S233+6.515201e-01*S234+(-2.001866e-01)*S235+(-4.030182e-01)*S236+9.704667e-01*S237+(-9.820849e-02)*S238+6.558738e-01*S239'
.param V80_part25='V80_part24+4.531213e-02*S240+(-8.187181e-02)*S241+(-5.807728e-01)*S242+4.556504e-01*S243+6.227341e-02*S244+(-7.160358e-01)*S245+(-8.350522e-02)*S246+4.582122e-01*S247+1.901142e-01*S248+7.346048e-01*S249'
.param V80_part26='V80_part25+0.000000e+00*S250+(-5.352358e-01)*S251+4.779762e-01*S252+0.000000e+00*S253+4.269171e-01*S254+0.000000e+00*S255+(-5.052610e-02)*S256+(-5.039656e-01)*S257+4.702723e-01*S258+(-2.689737e-01)*S259'
.param V80_part27='V80_part26+(-7.967264e-01)*S260+9.593658e-01*S261+4.525003e-01*S262+(-5.034597e-01)*S263+1.033216e+00*S264+1.187230e-01*S265+1.587943e-01*S266+0.000000e+00*S267+0.000000e+00*S268+(-3.742746e-01)*S269'
.param V80_part28='V80_part27+1.300743e-01*S270+(-1.589825e-01)*S271+(-1.010124e+00)*S272+0.000000e+00*S273+(-6.109478e-01)*S274+(-1.037767e+00)*S275+3.561546e-01*S276+0.000000e+00*S277+(-1.697714e+00)*S278+8.119547e-02*S279'
.param V80_part29='V80_part28+(-2.785964e-01)*S280+(-3.487012e+00)*S281+1.571307e-01*S282+(-2.095352e-01)*S283+0.000000e+00*S284+0.000000e+00*S285+(-4.497851e-02)*S286+(-3.402805e-01)*S287+0.000000e+00*S288+(-5.621893e-01)*S289'
.param V80_part30='V80_part29+(-1.608813e-01)*S290+(-4.123702e-01)*S291+(-4.017977e-01)*S292+(-2.716384e-01)*S293+0.000000e+00*S294+(-7.534593e-01)*S295+0.000000e+00*S296+(-5.598190e-02)*S297+0.000000e+00*S298+4.033670e-02*S299'
.param V80_part31='V80_part30+5.526482e-01*S300+(-3.803269e-01)*S301+(-4.758412e-01)*S302+0.000000e+00*S303+1.962701e-01*S304+(-5.662799e-01)*S305+8.196352e-01*S306+1.235823e+00*S307+1.014854e-01*S308+6.511335e-01*S309'
.param V80='V80_part31+4.208625e-01*S310+8.358328e-02*S311+0.000000e+00*S312+(-1.642039e-01)*S313+(-1.084309e-01)*S314'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V81_part2='V81_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+5.438064e-02*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V81_part3='V81_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V81_part4='V81_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+3.968982e-02*S33+2.803359e-01*S34+0.000000e+00*S35+1.951009e-01*S36+0.000000e+00*S37+3.057837e-01*S38+2.611886e-01*S39'
.param V81_part5='V81_part4+4.062477e-02*S40+2.943418e-01*S41+2.797014e-01*S42+2.833036e-01*S43+1.793884e-01*S44+3.623126e-01*S45+3.639732e-01*S46+1.022425e-02*S47+4.703642e-01*S48+3.523638e-01*S49'
.param V81_part6='V81_part5+(-1.974388e-02)*S50+2.824766e-01*S51+3.496709e-01*S52+7.176480e-02*S53+4.967232e-01*S54+4.178928e-01*S55+7.721402e-02*S56+0.000000e+00*S57+0.000000e+00*S58+1.854062e-01*S59'
.param V81_part7='V81_part6+0.000000e+00*S60+0.000000e+00*S61+4.833019e-01*S62+7.068768e-01*S63+7.341087e-01*S64+0.000000e+00*S65+8.704500e-01*S66+4.297676e-01*S67+3.573863e-01*S68+6.912040e-01*S69'
.param V81_part8='V81_part7+2.088370e-01*S70+3.967547e-01*S71+6.631598e-01*S72+2.249203e-01*S73+5.459681e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V81_part9='V81_part8+4.482545e-02*S80+1.318414e-01*S81+(-2.074761e-03)*S82+(-2.682785e-05)*S83+5.972664e-02*S84+4.339822e-02*S85+4.113559e-02*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V81_part10='V81_part9+8.100084e-01*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+4.846009e-01*S95+3.224810e-01*S96+3.193902e-01*S97+8.659071e-01*S98+3.497014e-01*S99'
.param V81_part11='V81_part10+1.292159e-01*S100+7.646642e-01*S101+9.207620e-01*S102+1.867004e-01*S103+0.000000e+00*S104+7.493903e-01*S105+7.306586e-01*S106+4.352176e-01*S107+6.758636e-01*S108+5.447298e-01*S109'
.param V81_part12='V81_part11+8.606668e-01*S110+4.222711e-01*S111+0.000000e+00*S112+7.843533e-01*S113+7.120494e-01*S114+5.693577e-01*S115+1.249328e-01*S116+5.592287e-01*S117+3.772937e-01*S118+1.114622e+00*S119'
.param V81_part13='V81_part12+9.050223e-01*S120+5.605072e-01*S121+5.567336e-01*S122+4.819024e-01*S123+3.729678e-01*S124+4.041445e-01*S125+2.184227e-01*S126+2.434562e-01*S127+4.831360e-01*S128+(-3.809404e-03)*S129'
.param V81_part14='V81_part13+2.220135e-01*S130+9.357725e-01*S131+9.703656e-01*S132+1.725124e-01*S133+9.176355e-01*S134+1.342029e+00*S135+0.000000e+00*S136+6.052172e-01*S137+0.000000e+00*S138+1.554742e-01*S139'
.param V81_part15='V81_part14+3.460219e-01*S140+0.000000e+00*S141+2.944884e-01*S142+2.533804e-01*S143+2.443496e-01*S144+2.819611e-01*S145+2.705464e-01*S146+3.784361e-01*S147+1.491331e-01*S148+3.919331e-01*S149'
.param V81_part16='V81_part15+6.818239e-01*S150+3.635196e-01*S151+8.454664e-01*S152+0.000000e+00*S153+4.067697e-01*S154+8.105524e-01*S155+1.128040e+00*S156+5.432684e-01*S157+1.080462e+00*S158+1.187211e+00*S159'
.param V81_part17='V81_part16+0.000000e+00*S160+1.057977e+00*S161+5.988972e-01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+3.187228e-01*S166+1.310649e+00*S167+7.109130e-01*S168+9.206756e-01*S169'
.param V81_part18='V81_part17+3.203080e-01*S170+9.212143e-01*S171+5.849721e-01*S172+8.103696e-01*S173+0.000000e+00*S174+2.580957e-01*S175+2.105813e+00*S176+0.000000e+00*S177+(-9.580495e-01)*S178+6.201001e-01*S179'
.param V81_part19='V81_part18+0.000000e+00*S180+3.163329e-01*S181+0.000000e+00*S182+8.814835e-01*S183+7.915561e-02*S184+1.234672e+00*S185+1.170393e+00*S186+2.002919e-01*S187+(-9.778838e-02)*S188+3.005076e-01*S189'
.param V81_part20='V81_part19+7.835513e-01*S190+0.000000e+00*S191+0.000000e+00*S192+(-1.555693e-01)*S193+(-2.459612e-03)*S194+0.000000e+00*S195+5.949868e-01*S196+9.161528e-01*S197+8.459996e-02*S198+2.350357e-01*S199'
.param V81_part21='V81_part20+7.028929e-01*S200+5.664164e-02*S201+2.925233e-01*S202+5.157981e-01*S203+1.013782e-01*S204+4.666217e-01*S205+5.864738e-01*S206+7.263611e-01*S207+9.744242e-01*S208+7.031866e-01*S209'
.param V81_part22='V81_part21+2.726797e-01*S210+8.730011e-01*S211+0.000000e+00*S212+0.000000e+00*S213+0.000000e+00*S214+1.116224e+00*S215+1.100652e+00*S216+1.014122e+00*S217+1.754048e+00*S218+0.000000e+00*S219'
.param V81_part23='V81_part22+0.000000e+00*S220+0.000000e+00*S221+1.310402e+00*S222+4.561778e-01*S223+0.000000e+00*S224+1.328351e+00*S225+9.662680e-01*S226+1.618726e+00*S227+9.135406e-01*S228+1.172591e+00*S229'
.param V81_part24='V81_part23+1.731393e+00*S230+0.000000e+00*S231+6.373160e-01*S232+3.607443e-01*S233+1.099967e+00*S234+6.475664e-01*S235+8.832886e-01*S236+1.289158e+00*S237+4.997751e-01*S238+(-3.084779e-01)*S239'
.param V81_part25='V81_part24+3.207998e-01*S240+5.236512e-01*S241+1.643450e+00*S242+9.984779e-01*S243+2.217481e-01*S244+1.375012e+00*S245+6.333350e-01*S246+(-5.679811e-02)*S247+2.528664e-01*S248+1.069710e+00*S249'
.param V81_part26='V81_part25+0.000000e+00*S250+1.165050e+00*S251+1.501308e+00*S252+0.000000e+00*S253+(-7.335358e-02)*S254+0.000000e+00*S255+4.187843e-01*S256+1.165305e+00*S257+6.381226e-01*S258+6.400816e-01*S259'
.param V81_part27='V81_part26+1.338351e+00*S260+8.273983e-01*S261+1.164873e+00*S262+7.708865e-01*S263+9.967742e-01*S264+6.317656e-01*S265+9.807350e-01*S266+0.000000e+00*S267+0.000000e+00*S268+4.143196e-01*S269'
.param V81_part28='V81_part27+1.334380e+00*S270+2.501881e-02*S271+2.210898e+00*S272+0.000000e+00*S273+1.076400e+00*S274+1.598749e+00*S275+1.155822e+00*S276+0.000000e+00*S277+1.896865e+00*S278+1.400200e+00*S279'
.param V81_part29='V81_part28+8.502944e-01*S280+3.052669e+00*S281+2.017207e+00*S282+3.845021e-02*S283+0.000000e+00*S284+0.000000e+00*S285+6.851898e-02*S286+9.765706e-01*S287+0.000000e+00*S288+(-1.903863e-01)*S289'
.param V81_part30='V81_part29+4.435059e-01*S290+1.431614e+00*S291+(-1.785652e-01)*S292+1.317346e+00*S293+0.000000e+00*S294+8.401083e-02*S295+0.000000e+00*S296+1.842458e+00*S297+0.000000e+00*S298+3.062114e-01*S299'
.param V81_part31='V81_part30+9.053970e-01*S300+8.071944e-01*S301+9.097016e-01*S302+0.000000e+00*S303+1.044648e+00*S304+9.398621e-01*S305+1.221195e+00*S306+(-9.827207e-01)*S307+1.416386e+00*S308+1.465652e+00*S309'
.param V81='V81_part31+(-1.320877e-01)*S310+1.721488e+00*S311+0.000000e+00*S312+4.221253e-01*S313+1.865449e+00*S314'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V82_part2='V82_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-1.035609e-02)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V82_part3='V82_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V82_part4='V82_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.050268e-02*S33+1.409541e-01*S34+0.000000e+00*S35+9.704253e-02*S36+0.000000e+00*S37+1.939288e-01*S38+2.071831e-01*S39'
.param V82_part5='V82_part4+5.228657e-02*S40+1.620782e-01*S41+2.705296e-01*S42+6.335072e-01*S43+1.954759e-01*S44+(-9.316386e-02)*S45+8.534007e-02*S46+(-3.487699e-02)*S47+8.685072e-02*S48+1.975042e-01*S49'
.param V82_part6='V82_part5+(-8.773375e-02)*S50+7.726070e-02*S51+1.841364e-01*S52+1.895551e-01*S53+4.969261e-01*S54+2.691612e-01*S55+2.003755e-01*S56+0.000000e+00*S57+0.000000e+00*S58+2.703384e-01*S59'
.param V82_part7='V82_part6+0.000000e+00*S60+0.000000e+00*S61+8.092602e-02*S62+8.413929e-02*S63+3.380537e-01*S64+0.000000e+00*S65+(-4.095119e-02)*S66+2.708080e-01*S67+2.059280e-01*S68+(-1.021730e-01)*S69'
.param V82_part8='V82_part7+2.606661e-01*S70+3.106979e-01*S71+(-3.555298e-01)*S72+3.239419e-01*S73+3.173652e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V82_part9='V82_part8+3.228577e-02*S80+(-9.015377e-02)*S81+(-1.914102e-03)*S82+3.176020e-04*S83+(-4.486166e-02)*S84+3.070326e-02*S85+2.996197e-02*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V82_part10='V82_part9+3.510284e-01*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+1.179559e-02*S95+1.950564e-01*S96+1.470948e-01*S97+4.242773e-01*S98+3.286641e-01*S99'
.param V82_part11='V82_part10+2.526718e-03*S100+4.000345e-01*S101+1.198320e+00*S102+6.635925e-02*S103+0.000000e+00*S104+2.289933e-01*S105+5.002655e-01*S106+3.023557e-01*S107+2.978504e-01*S108+5.312172e-01*S109'
.param V82_part12='V82_part11+4.711142e-01*S110+2.920974e-01*S111+0.000000e+00*S112+2.976622e-01*S113+3.688110e-01*S114+9.039073e-02*S115+(-2.541337e-01)*S116+2.391481e-02*S117+1.831590e-01*S118+2.082553e-02*S119'
.param V82_part13='V82_part12+3.503615e-01*S120+4.831623e-01*S121+2.556169e-01*S122+2.981481e-01*S123+2.159778e-01*S124+1.413257e-01*S125+4.170786e-01*S126+2.755100e-01*S127+1.837199e-01*S128+7.828296e-01*S129'
.param V82_part14='V82_part13+3.569188e-01*S130+3.461797e-01*S131+(-2.309555e-01)*S132+3.747254e-01*S133+5.208026e-01*S134+1.943453e-01*S135+0.000000e+00*S136+2.366628e-01*S137+0.000000e+00*S138+2.535247e-02*S139'
.param V82_part15='V82_part14+1.358723e-01*S140+0.000000e+00*S141+1.889606e-01*S142+(-1.454191e-02)*S143+3.718307e-01*S144+2.372000e-01*S145+1.702846e-02*S146+1.257720e-01*S147+4.378088e-01*S148+4.251387e-01*S149'
.param V82_part16='V82_part15+7.979194e-01*S150+2.046155e-01*S151+4.821251e-02*S152+0.000000e+00*S153+3.560514e-01*S154+3.650325e-02*S155+8.897068e-01*S156+1.807385e-01*S157+4.330791e-01*S158+9.211595e-01*S159'
.param V82_part17='V82_part16+0.000000e+00*S160+1.790945e+00*S161+(-8.898898e-01)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+2.552553e-01*S166+5.810075e-01*S167+7.487475e-01*S168+1.249528e+00*S169'
.param V82_part18='V82_part17+2.964148e-01*S170+5.136126e-01*S171+3.645105e-01*S172+5.795698e-01*S173+0.000000e+00*S174+(-2.979529e-02)*S175+4.405706e-01*S176+0.000000e+00*S177+(-4.903410e-01)*S178+3.383480e-01*S179'
.param V82_part19='V82_part18+0.000000e+00*S180+4.002608e-01*S181+0.000000e+00*S182+4.938450e-01*S183+2.533668e-01*S184+9.612221e-01*S185+6.993209e-01*S186+3.938473e-01*S187+5.392755e-01*S188+(-6.649075e-01)*S189'
.param V82_part20='V82_part19+9.594416e-01*S190+0.000000e+00*S191+0.000000e+00*S192+(-1.280015e-01)*S193+(-1.147551e+00)*S194+0.000000e+00*S195+6.405290e-01*S196+2.318149e-01*S197+2.489657e-01*S198+2.255645e-01*S199'
.param V82_part21='V82_part20+2.886810e-01*S200+4.512221e-01*S201+3.542269e-01*S202+3.254817e-01*S203+(-3.775349e-01)*S204+4.024865e-01*S205+4.282374e-01*S206+(-3.895444e+00)*S207+4.819810e-01*S208+4.592530e-01*S209'
.param V82_part22='V82_part21+5.315698e-01*S210+5.320554e-01*S211+0.000000e+00*S212+0.000000e+00*S213+0.000000e+00*S214+4.112689e-02*S215+1.198316e+00*S216+1.400650e+00*S217+(-4.230830e-01)*S218+0.000000e+00*S219'
.param V82_part23='V82_part22+0.000000e+00*S220+0.000000e+00*S221+2.431046e-01*S222+8.531165e-01*S223+0.000000e+00*S224+(-1.048870e+00)*S225+1.537118e+00*S226+7.345115e-01*S227+7.999740e-01*S228+1.833031e+00*S229'
.param V82_part24='V82_part23+1.552988e+00*S230+0.000000e+00*S231+1.637598e+00*S232+4.942834e-01*S233+(-6.234296e-01)*S234+1.459693e+00*S235+6.524175e-01*S236+(-1.628761e+00)*S237+1.268780e+00*S238+7.876513e-01*S239'
.param V82_part25='V82_part24+1.621889e-01*S240+8.131203e-01*S241+1.188283e+00*S242+2.787734e-01*S243+8.018998e-01*S244+1.238753e+00*S245+1.424301e-01*S246+7.807476e-01*S247+7.015569e-01*S248+(-4.879824e-01)*S249'
.param V82_part26='V82_part25+0.000000e+00*S250+8.263461e-01*S251+(-6.349508e-01)*S252+0.000000e+00*S253+6.094115e-01*S254+0.000000e+00*S255+1.211882e-01*S256+5.553502e-01*S257+4.791502e-01*S258+7.223920e-01*S259'
.param V82_part27='V82_part26+8.789326e-01*S260+(-2.352311e-01)*S261+9.697025e-01*S262+7.594304e-01*S263+(-5.815504e-01)*S264+1.078440e+00*S265+3.111215e-01*S266+0.000000e+00*S267+0.000000e+00*S268+9.674488e-01*S269'
.param V82_part28='V82_part27+1.125768e+00*S270+6.645571e-01*S271+1.038555e+00*S272+0.000000e+00*S273+2.155744e+00*S274+2.383228e+00*S275+3.712854e-01*S276+0.000000e+00*S277+1.653154e+00*S278+1.132323e+00*S279'
.param V82_part29='V82_part28+2.118169e+00*S280+2.415537e+00*S281+(-2.054239e+00)*S282+2.558659e+00*S283+0.000000e+00*S284+0.000000e+00*S285+1.227657e+00*S286+8.080276e-01*S287+0.000000e+00*S288+1.970466e+00*S289'
.param V82_part30='V82_part29+1.146331e+00*S290+2.079844e+00*S291+1.668419e+00*S292+4.004641e-01*S293+0.000000e+00*S294+1.581761e+00*S295+0.000000e+00*S296+7.366457e-02*S297+0.000000e+00*S298+(-2.467968e-01)*S299'
.param V82_part31='V82_part30+4.464970e-01*S300+5.414458e-01*S301+5.184062e-01*S302+0.000000e+00*S303+1.604816e+00*S304+4.977927e-01*S305+7.080209e-02*S306+3.768245e-02*S307+4.738904e-01*S308+6.294488e-02*S309'
.param V82='V82_part31+3.132616e-01*S310+1.938595e-02*S311+0.000000e+00*S312+4.137396e-01*S313+(-7.526413e-03)*S314'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V83_part2='V83_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+3.241989e-02*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V83_part3='V83_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V83_part4='V83_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+7.105052e-02*S33+4.478532e-02*S34+0.000000e+00*S35+7.714588e-02*S36+0.000000e+00*S37+1.168971e-01*S38+9.105479e-02*S39'
.param V83_part5='V83_part4+2.523277e-01*S40+1.360808e-01*S41+1.151034e-01*S42+1.247820e-01*S43+1.671232e-01*S44+1.157585e-01*S45+2.516961e-02*S46+(-5.576191e-03)*S47+(-8.561061e-03)*S48+(-8.041519e-04)*S49'
.param V83_part6='V83_part5+(-4.415012e-02)*S50+1.940783e-02*S51+3.275431e-02*S52+(-2.058422e-02)*S53+2.480029e-02*S54+5.844359e-02*S55+(-1.159043e-02)*S56+0.000000e+00*S57+0.000000e+00*S58+(-2.167070e-02)*S59'
.param V83_part7='V83_part6+0.000000e+00*S60+0.000000e+00*S61+3.978009e-02*S62+3.150640e-02*S63+4.026460e-03*S64+0.000000e+00*S65+2.425347e-01*S66+1.108458e-02*S67+9.141494e-03*S68+(-6.632447e-03)*S69'
.param V83_part8='V83_part7+1.750964e-02*S70+3.152257e-02*S71+(-8.889231e-02)*S72+5.649173e-02*S73+2.107380e-04*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V83_part9='V83_part8+1.280352e-01*S80+1.716940e-01*S81+1.289508e-01*S82+1.440102e-01*S83+1.809909e-01*S84+1.225790e-01*S85+1.205569e-01*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V83_part10='V83_part9+(-6.380675e-03)*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+1.228646e-01*S95+1.183764e-01*S96+1.084103e-01*S97+6.275569e-02*S98+1.387388e-01*S99'
.param V83_part11='V83_part10+1.304285e-01*S100+2.594281e-02*S101+9.789603e-02*S102+1.164491e-01*S103+0.000000e+00*S104+5.907583e-02*S105+1.571292e-02*S106+5.640047e-02*S107+5.245255e-02*S108+4.797968e-02*S109'
.param V83_part12='V83_part11+8.098516e-03*S110+1.692411e-02*S111+0.000000e+00*S112+(-2.826123e-02)*S113+2.310667e-02*S114+(-7.473276e-02)*S115+6.026045e-03*S116+1.145783e-01*S117+4.732230e-03*S118+(-7.510724e-02)*S119'
.param V83_part13='V83_part12+(-1.569192e-02)*S120+2.231198e-03*S121+(-1.166424e-02)*S122+1.510635e-02*S123+(-1.737684e-02)*S124+8.967658e-03*S125+4.196414e-02*S126+1.071997e-02*S127+3.066214e-02*S128+6.048570e-02*S129'
.param V83_part14='V83_part13+5.513549e-02*S130+(-3.414707e-02)*S131+1.857735e-02*S132+5.848547e-02*S133+(-5.257265e-02)*S134+1.601342e-01*S135+0.000000e+00*S136+1.836906e-02*S137+0.000000e+00*S138+9.534402e-03*S139'
.param V83_part15='V83_part14+1.291045e-02*S140+0.000000e+00*S141+2.897638e-02*S142+2.394754e-02*S143+1.400201e-01*S144+4.530206e-02*S145+2.968725e-02*S146+1.840390e-01*S147+2.817977e-02*S148+4.488911e-02*S149'
.param V83_part16='V83_part15+2.483139e-03*S150+4.319710e-02*S151+1.360721e-02*S152+0.000000e+00*S153+1.363063e-02*S154+(-8.950602e-03)*S155+4.822516e-02*S156+1.556699e-02*S157+(-3.338364e-02)*S158+5.746346e-02*S159'
.param V83_part17='V83_part16+0.000000e+00*S160+(-1.417050e-01)*S161+2.130795e-02*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+1.840339e-03*S166+(-2.554632e-02)*S167+4.149355e-02*S168+(-6.923707e-04)*S169'
.param V83_part18='V83_part17+5.056814e-02*S170+4.918899e-03*S171+(-5.788162e-02)*S172+(-9.795153e-02)*S173+0.000000e+00*S174+(-1.014160e-01)*S175+(-2.458263e-01)*S176+0.000000e+00*S177+(-1.191809e-01)*S178+(-1.759631e-01)*S179'
.param V83_part19='V83_part18+0.000000e+00*S180+1.273958e-02*S181+0.000000e+00*S182+4.133278e-02*S183+2.775278e-02*S184+(-5.899791e-02)*S185+(-4.167029e-03)*S186+3.992695e-02*S187+(-1.594676e-01)*S188+(-1.474240e-01)*S189'
.param V83_part20='V83_part19+(-1.993985e-02)*S190+0.000000e+00*S191+0.000000e+00*S192+(-5.059847e-02)*S193+(-8.194863e-02)*S194+0.000000e+00*S195+1.123371e-01*S196+(-3.364842e-02)*S197+8.218295e-02*S198+3.723716e-02*S199'
.param V83_part21='V83_part20+5.676365e-03*S200+3.041479e-02*S201+3.274105e-02*S202+3.269700e-02*S203+(-9.098066e-02)*S204+4.728198e-02*S205+9.021008e-03*S206+2.042677e-01*S207+4.489757e-02*S208+1.140522e-03*S209'
.param V83_part22='V83_part21+2.591097e-02*S210+4.444898e-04*S211+0.000000e+00*S212+0.000000e+00*S213+0.000000e+00*S214+7.091962e-02*S215+8.095641e-02*S216+(-2.487008e-02)*S217+1.054170e-01*S218+0.000000e+00*S219'
.param V83_part23='V83_part22+0.000000e+00*S220+0.000000e+00*S221+(-2.731649e-02)*S222+(-1.246408e-01)*S223+0.000000e+00*S224+(-1.553319e-03)*S225+(-3.889678e-03)*S226+(-6.427932e-02)*S227+2.615358e-02*S228+3.679857e-02*S229'
.param V83_part24='V83_part23+(-4.499249e-02)*S230+0.000000e+00*S231+(-6.549425e-02)*S232+(-3.709166e-02)*S233+(-8.981177e-03)*S234+(-8.605397e-02)*S235+3.720289e-02*S236+(-5.303872e-02)*S237+(-9.896623e-02)*S238+(-9.034984e-02)*S239'
.param V83_part25='V83_part24+4.286502e-03*S240+3.082007e-02*S241+(-4.809196e-02)*S242+1.329054e-02*S243+(-4.724442e-03)*S244+(-5.325489e-02)*S245+(-6.467349e-02)*S246+(-3.748152e-02)*S247+(-3.401684e-02)*S248+(-5.633444e-03)*S249'
.param V83_part26='V83_part25+0.000000e+00*S250+2.266529e-03*S251+(-8.622911e-02)*S252+0.000000e+00*S253+(-1.096807e-01)*S254+0.000000e+00*S255+3.977518e-02*S256+1.647777e-02*S257+1.483874e-01*S258+4.626227e-02*S259'
.param V83_part27='V83_part26+1.799436e-03*S260+2.068840e-01*S261+1.751900e-01*S262+(-5.046318e-02)*S263+3.019737e-01*S264+1.542030e-01*S265+(-7.369813e-03)*S266+0.000000e+00*S267+0.000000e+00*S268+(-2.290461e-02)*S269'
.param V83_part28='V83_part27+(-1.824353e-03)*S270+1.881219e-02*S271+(-5.398905e-02)*S272+0.000000e+00*S273+1.049224e-02*S274+(-1.188413e-01)*S275+2.153030e-02*S276+0.000000e+00*S277+1.058425e-01*S278+(-6.471006e-02)*S279'
.param V83_part29='V83_part28+(-2.370052e-01)*S280+1.498647e-01*S281+5.837739e-02*S282+(-5.763707e-02)*S283+0.000000e+00*S284+0.000000e+00*S285+(-3.647043e-02)*S286+(-1.133084e-02)*S287+0.000000e+00*S288+1.216410e-01*S289'
.param V83_part30='V83_part29+5.662318e-02*S290+(-3.218923e-02)*S291+1.058917e-02*S292+(-1.212344e-01)*S293+0.000000e+00*S294+(-1.004879e-02)*S295+0.000000e+00*S296+(-3.237258e-02)*S297+0.000000e+00*S298+2.056198e-02*S299'
.param V83_part31='V83_part30+1.816229e-01*S300+2.860257e-03*S301+1.637961e-02*S302+0.000000e+00*S303+1.714930e-01*S304+2.620131e-02*S305+2.794493e-01*S306+(-9.538969e-02)*S307+2.556852e-02*S308+1.717858e-01*S309'
.param V83='V83_part31+(-6.347892e-02)*S310+4.350728e-02*S311+0.000000e+00*S312+(-6.218716e-02)*S313+8.489164e-02*S314'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V84_part2='V84_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-2.735871e-04)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V84_part3='V84_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V84_part4='V84_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.714806e-03*S33+5.461176e-03*S34+0.000000e+00*S35+1.780335e-04*S36+0.000000e+00*S37+1.393310e-03*S38+(-6.980083e-03)*S39'
.param V84_part5='V84_part4+2.528298e-03*S40+2.354359e-03*S41+(-1.482358e-02)*S42+(-6.561983e-02)*S43+(-1.170109e-02)*S44+1.979708e-03*S45+1.333471e-03*S46+(-1.173059e-02)*S47+(-4.816910e-02)*S48+(-3.976022e-02)*S49'
.param V84_part6='V84_part5+(-2.377412e-03)*S50+(-4.696392e-02)*S51+(-6.317845e-02)*S52+1.190185e-02*S53+(-1.972858e-01)*S54+(-8.343174e-02)*S55+1.351977e-02*S56+0.000000e+00*S57+0.000000e+00*S58+1.813006e-02*S59'
.param V84_part7='V84_part6+0.000000e+00*S60+0.000000e+00*S61+(-3.551863e-02)*S62+(-6.762084e-02)*S63+(-1.216835e-01)*S64+0.000000e+00*S65+(-1.920208e-01)*S66+(-9.460366e-02)*S67+(-1.009879e-02)*S68+(-3.321537e-01)*S69'
.param V84_part8='V84_part7+(-1.061794e-03)*S70+(-1.875315e-03)*S71+(-4.851175e-01)*S72+(-7.068525e-03)*S73+(-1.569535e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V84_part9='V84_part8+5.343353e-04*S80+(-1.296544e-02)*S81+(-2.683040e-02)*S82+(-2.633990e-02)*S83+(-2.423393e-02)*S84+(-2.745642e-02)*S85+(-2.249206e-02)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V84_part10='V84_part9+(-2.965441e-02)*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+2.849277e-02*S95+1.718475e-02*S96+1.681871e-02*S97+2.485434e-02*S98+2.845605e-02*S99'
.param V84_part11='V84_part10+9.501147e-03*S100+3.000641e-02*S101+(-2.466942e-01)*S102+1.371516e-02*S103+0.000000e+00*S104+(-8.283158e-02)*S105+(-1.027365e-01)*S106+3.385037e-02*S107+(-1.000978e-01)*S108+(-9.669446e-02)*S109'
.param V84_part12='V84_part11+3.087309e-02*S110+(-1.717783e-01)*S111+0.000000e+00*S112+2.834954e-02*S113+(-8.153397e-02)*S114+1.941266e-03*S115+4.837121e-02*S116+(-2.676925e-01)*S117+7.080443e-02*S118+4.232336e-01*S119'
.param V84_part13='V84_part12+(-1.395575e-01)*S120+(-6.542976e-02)*S121+2.858745e-02*S122+(-1.106250e-01)*S123+1.131487e-02*S124+3.020108e-02*S125+(-1.391067e-03)*S126+5.258366e-03*S127+3.596116e-02*S128+(-8.218232e-03)*S129'
.param V84_part14='V84_part13+6.634685e-03*S130+5.768285e-02*S131+(-4.973348e-01)*S132+2.050734e-02*S133+6.064029e-02*S134+(-1.597955e-01)*S135+0.000000e+00*S136+(-1.876860e-02)*S137+0.000000e+00*S138+(-3.047657e-02)*S139'
.param V84_part15='V84_part14+(-1.146837e-02)*S140+0.000000e+00*S141+(-1.233119e-02)*S142+(-4.609287e-02)*S143+(-2.443337e-02)*S144+(-8.223047e-03)*S145+(-1.748293e-02)*S146+(-2.632039e-02)*S147+(-1.533435e-02)*S148+(-1.482856e-02)*S149'
.param V84_part16='V84_part15+(-6.015311e-02)*S150+2.993322e-03*S151+5.347666e-02*S152+0.000000e+00*S153+4.065933e-02*S154+6.822471e-02*S155+(-7.064746e-02)*S156+2.427324e-02*S157+9.700324e-02*S158+(-2.784776e-01)*S159'
.param V84_part17='V84_part16+0.000000e+00*S160+(-7.379298e-02)*S161+(-1.047850e-01)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+3.570282e-02*S166+8.232265e-02*S167+(-9.239712e-02)*S168+(-9.015695e-02)*S169'
.param V84_part18='V84_part17+1.200210e-02*S170+(-2.779512e-01)*S171+5.512320e-02*S172+8.527113e-02*S173+0.000000e+00*S174+3.964498e-02*S175+5.080951e-01*S176+0.000000e+00*S177+(-1.840190e-01)*S178+4.334664e-01*S179'
.param V84_part19='V84_part18+0.000000e+00*S180+2.282933e-02*S181+0.000000e+00*S182+(-1.803455e-01)*S183+8.930504e-03*S184+(-7.470892e-02)*S185+(-2.237866e-01)*S186+8.775013e-03*S187+(-1.520279e-01)*S188+(-1.259622e-01)*S189'
.param V84_part20='V84_part19+(-1.569069e-01)*S190+0.000000e+00*S191+0.000000e+00*S192+(-1.054533e-01)*S193+(-9.718092e-02)*S194+0.000000e+00*S195+(-2.035558e-01)*S196+6.680315e-03*S197+6.518143e-02*S198+5.361452e-04*S199'
.param V84_part21='V84_part20+1.753294e-02*S200+(-1.588772e-02)*S201+(-2.862073e-04)*S202+7.229840e-03*S203+(-1.103309e-02)*S204+1.341307e-02*S205+1.192968e-02*S206+(-6.851760e-01)*S207+1.274180e-02*S208+1.931898e-02*S209'
.param V84_part22='V84_part21+2.496740e-02*S210+6.182402e-02*S211+0.000000e+00*S212+0.000000e+00*S213+0.000000e+00*S214+1.579042e-01*S215+(-3.097212e-01)*S216+(-2.405945e-02)*S217+2.099600e-01*S218+0.000000e+00*S219'
.param V84_part23='V84_part22+0.000000e+00*S220+0.000000e+00*S221+(-5.230501e-01)*S222+(-2.418190e-01)*S223+0.000000e+00*S224+(-5.363572e-02)*S225+(-3.961792e-02)*S226+1.454647e-01*S227+(-2.056291e-01)*S228+(-2.224470e-01)*S229'
.param V84_part24='V84_part23+(-3.772411e-02)*S230+0.000000e+00*S231+(-1.385458e-01)*S232+(-6.689050e-05)*S233+(-3.905321e-01)*S234+(-1.865298e-01)*S235+2.038906e-02*S236+(-6.321037e-01)*S237+(-1.530711e-01)*S238+(-1.325590e-01)*S239'
.param V84_part25='V84_part24+1.012482e-02*S240+(-9.658554e-02)*S241+(-5.646417e-02)*S242+(-2.411802e-01)*S243+(-8.937398e-02)*S244+(-3.861271e-02)*S245+6.079602e-02*S246+(-1.155331e-01)*S247+(-3.478838e-03)*S248+(-7.721770e-01)*S249'
.param V84_part26='V84_part25+0.000000e+00*S250+(-4.942996e-02)*S251+(-5.109935e-01)*S252+0.000000e+00*S253+1.395075e-01*S254+0.000000e+00*S255+2.063502e-02*S256+6.609004e-02*S257+(-2.762987e-01)*S258+3.471800e-02*S259'
.param V84_part27='V84_part26+1.011602e-01*S260+(-3.497167e-01)*S261+(-4.891497e-01)*S262+8.547942e-02*S263+(-5.542156e-01)*S264+(-2.152946e-01)*S265+(-5.500758e-02)*S266+0.000000e+00*S267+0.000000e+00*S268+2.132276e-01*S269'
.param V84_part28='V84_part27+(-1.047009e-01)*S270+2.264480e-02*S271+2.929961e-01*S272+0.000000e+00*S273+(-3.809783e-02)*S274+(-2.641415e-02)*S275+(-2.625312e-01)*S276+0.000000e+00*S277+1.431041e-01*S278+(-3.511481e-01)*S279'
.param V84_part29='V84_part28+(-2.700385e-01)*S280+2.836186e-01*S281+(-4.350152e-01)*S282+(-1.122816e-01)*S283+0.000000e+00*S284+0.000000e+00*S285+(-3.458950e-02)*S286+7.343312e-02*S287+0.000000e+00*S288+6.992190e-02*S289'
.param V84_part30='V84_part29+(-2.280092e-02)*S290+(-1.776515e-01)*S291+9.246746e-02*S292+(-1.051054e-01)*S293+0.000000e+00*S294+2.997147e-01*S295+0.000000e+00*S296+(-4.459470e-01)*S297+0.000000e+00*S298+(-5.099868e-02)*S299'
.param V84_part31='V84_part30+(-3.071572e-01)*S300+8.434537e-02*S301+1.755356e-01*S302+0.000000e+00*S303+(-2.896049e-01)*S304+1.740456e-01*S305+(-4.664199e-01)*S306+(-1.588621e-01)*S307+(-1.045824e-01)*S308+(-5.468001e-01)*S309'
.param V84='V84_part31+(-2.429228e-02)*S310+(-1.564950e-01)*S311+0.000000e+00*S312+(-1.915167e-02)*S313+(-2.566196e-01)*S314'
.param V85_part1='0.000000e+00*S0+0.000000e+00*S1+3.716409e+00*S2+1.418135e+01*S3+6.689842e+00*S4+8.371424e+01*S5+(-1.433838e+00)*S6+4.180356e+00*S7+5.497091e+00*S8+1.714975e+01*S9'
.param V85_part2='V85_part1+5.177608e+01*S10+2.631498e+01*S11+8.421288e+00*S12+1.159032e+01*S13+1.399002e+01*S14+2.698980e+01*S15+(-6.004077e-01)*S16+2.461902e+00*S17+1.765641e+00*S18+2.692396e+01*S19'
.param V85_part3='V85_part2+1.427414e+01*S20+3.077080e+01*S21+2.041070e+01*S22+1.865364e+01*S23+6.612569e+00*S24+1.334205e+01*S25+1.923752e+01*S26+3.637717e+01*S27+1.743217e+01*S28+1.431948e+01*S29'
.param V85_part4='V85_part3+3.398784e-01*S30+1.280879e+01*S31+8.190371e+00*S32+2.687346e-01*S33+2.184175e+01*S34+1.317553e+01*S35+9.658480e-02*S36+5.892113e+00*S37+2.155509e-01*S38+1.390237e-02*S39'
.param V85_part5='V85_part4+7.343519e+00*S40+5.978246e+00*S41+6.452727e-02*S42+2.667731e+00*S43+5.813726e+00*S44+(-4.361716e+03)*S45+1.296241e+01*S46+2.542212e+01*S47+(-2.847283e-02)*S48+4.077702e+02*S49'
.param V85_part6='V85_part5+2.209904e+01*S50+5.871403e+00*S51+1.363153e+02*S52+7.617118e+03*S53+(-9.156391e-02)*S54+8.873711e+02*S55+7.572713e+03*S56+1.338997e-01*S57+(-4.302430e+03)*S58+7.564012e+03*S59'
.param V85_part7='V85_part6+5.726372e+01*S60+(-2.376708e+03)*S61+1.127749e+01*S62+7.168629e+00*S63+4.012291e+00*S64+(-1.731961e+03)*S65+2.263727e+00*S66+7.014894e+00*S67+1.268613e+01*S68+(-1.259848e+00)*S69'
.param V85_part8='V85_part7+1.069552e+01*S70+6.104421e+00*S71+2.752759e-01*S72+5.659369e+00*S73+2.303549e+00*S74+(-1.148252e+01)*S75+9.331332e+01*S76+5.356962e+00*S77+1.114888e+01*S78+3.288221e+00*S79'
.param V85_part9='V85_part8+8.867755e+00*S80+9.051905e+00*S81+1.700038e+01*S82+1.376329e+01*S83+5.752221e+00*S84+4.561549e+02*S85+4.731609e+00*S86+4.859338e+03*S87+5.653748e+00*S88+5.974815e+01*S89'
.param V85_part10='V85_part9+7.955823e+00*S90+(-7.101185e+00)*S91+1.421038e+03*S92+7.559401e+03*S93+7.513386e+03*S94+7.471611e+03*S95+7.250665e+03*S96+1.000000e+04*S97+(-1.146193e-01)*S98+6.300064e+03*S99'
.param V85_part11='V85_part10+7.507895e+03*S100+5.180831e+00*S101+(-1.155664e-02)*S102+7.401682e+03*S103+3.680649e+02*S104+1.354453e+01*S105+4.845364e+00*S106+3.102062e+02*S107+1.062553e+01*S108+1.744443e+01*S109'
.param V85_part12='V85_part11+(-3.476402e-01)*S110+5.575788e+01*S111+9.852736e+01*S112+3.175700e+02*S113+8.379742e+00*S114+3.475020e+01*S115+1.000000e+04*S116+7.930599e+00*S117+(-1.049696e+00)*S118+(-1.490301e-01)*S119'
.param V85_part13='V85_part12+0.000000e+00*S120+6.846837e+00*S121+3.496327e+02*S122+3.408289e+01*S123+(-6.617448e+01)*S124+9.884158e+03*S125+4.950037e+01*S126+2.070044e+03*S127+1.000000e+04*S128+2.163043e+01*S129'
.param V85_part14='V85_part13+2.503405e+02*S130+8.248057e+03*S131+(-4.424806e+02)*S132+5.184562e+02*S133+1.976126e+03*S134+1.306846e+01*S135+0.000000e+00*S136+2.383376e+01*S137+0.000000e+00*S138+2.835879e+01*S139'
.param V85_part15='V85_part14+(-2.492769e+01)*S140+2.570172e-01*S141+2.013842e+01*S142+2.364388e+02*S143+7.043095e+00*S144+1.458995e+01*S145+7.220870e+02*S146+1.054391e+01*S147+1.907328e+01*S148+(-5.277222e+00)*S149'
.param V85_part16='V85_part15+6.642565e+00*S150+4.214319e+01*S151+2.355802e+03*S152+6.488328e+01*S153+3.469741e+00*S154+2.389852e+03*S155+(-2.682338e-01)*S156+1.536477e-02*S157+2.455094e+03*S158+(-5.257007e-01)*S159'
.param V85_part17='V85_part16+8.321815e+02*S160+6.054291e+00*S161+0.000000e+00*S162+2.005078e-01*S163+1.454896e-01*S164+5.206722e+02*S165+(-4.920682e+03)*S166+(-1.239155e-01)*S167+7.558711e+03*S168+(-2.916176e-01)*S169'
.param V85_part18='V85_part17+3.721409e-01*S170+(-4.738215e+00)*S171+(-1.147942e+00)*S172+(-8.095497e-01)*S173+6.970155e+00*S174+1.747437e+00*S175+(-3.010153e-01)*S176+0.000000e+00*S177+5.060030e-01*S178+(-2.651015e-01)*S179'
.param V85_part19='V85_part18+8.379912e+03*S180+4.790102e+00*S181+1.693987e+03*S182+1.392209e+01*S183+3.488525e+02*S184+(-3.917664e+01)*S185+4.446644e+00*S186+1.332161e+02*S187+2.231609e+00*S188+(-2.464627e+00)*S189'
.param V85_part20='V85_part19+(-4.596102e+02)*S190+(-4.969198e+03)*S191+(-9.157936e+00)*S192+3.239876e-01*S193+8.249538e-01*S194+5.968117e+02*S195+5.233123e+01*S196+2.373384e+00*S197+3.886141e+00*S198+1.753277e+01*S199'
.param V85_part21='V85_part20+9.182140e+01*S200+(-4.218334e+01)*S201+(-1.711815e+00)*S202+4.045485e+03*S203+6.045712e-01*S204+1.000000e+04*S205+1.000000e+04*S206+1.256514e+03*S207+4.499633e+03*S208+7.484841e+03*S209'
.param V85_part22='V85_part21+2.246056e+01*S210+2.807544e+00*S211+1.000000e+04*S212+0.000000e+00*S213+2.341018e+01*S214+1.000000e+04*S215+1.683186e-01*S216+8.172755e+00*S217+1.000000e+04*S218+0.000000e+00*S219'
.param V85_part23='V85_part22+(-4.023170e+00)*S220+(-8.090838e+00)*S221+0.000000e+00*S222+7.179227e+00*S223+4.261045e+03*S224+(-9.811457e+02)*S225+(-9.060902e-02)*S226+(-1.944114e+01)*S227+(-2.375952e+00)*S228+9.199455e-01*S229'
.param V85_part24='V85_part23+(-7.810042e+00)*S230+2.009375e+01*S231+3.061487e-01*S232+4.383768e-01*S233+2.580145e+00*S234+7.872265e+00*S235+2.595581e-01*S236+1.945423e+00*S237+1.618749e+00*S238+3.997420e-01*S239'
.param V85_part25='V85_part24+8.730124e+01*S240+2.036961e+01*S241+6.619618e+02*S242+5.500446e-01*S243+9.418538e+00*S244+1.648462e+00*S245+2.219122e+01*S246+1.882065e+00*S247+5.951417e-01*S248+(-4.993337e+00)*S249'
.param V85_part26='V85_part25+(-2.808012e+01)*S250+3.523032e-01*S251+0.000000e+00*S252+(-1.026194e+02)*S253+7.234656e-01*S254+(-4.945537e+03)*S255+1.853388e+03*S256+1.669294e+01*S257+1.394129e+02*S258+6.526701e+00*S259'
.param V85_part27='V85_part26+2.910865e+01*S260+0.000000e+00*S261+0.000000e+00*S262+1.023373e+00*S263+2.579537e+00*S264+2.449644e+00*S265+1.371625e+00*S266+0.000000e+00*S267+(-5.767611e+01)*S268+(-1.802990e-02)*S269'
.param V85_part28='V85_part27+4.115928e+00*S270+(-4.917048e+03)*S271+2.387646e+03*S272+3.999463e+03*S273+6.738414e+00*S274+3.668786e+01*S275+3.549662e+00*S276+3.157420e+00*S277+(-8.468497e-02)*S278+0.000000e+00*S279'
.param V85_part29='V85_part28+2.574531e+00*S280+(-3.148955e-01)*S281+1.507384e-01*S282+1.948036e+00*S283+6.890910e+02*S284+8.743944e-01*S285+6.092450e+00*S286+1.835402e+00*S287+1.606165e+00*S288+3.348498e+00*S289'
.param V85_part30='V85_part29+5.846871e-01*S290+5.128700e+00*S291+(-7.482772e-02)*S292+3.656198e+01*S293+(-1.578645e+00)*S294+2.257617e-02*S295+6.297431e+01*S296+0.000000e+00*S297+4.035353e+00*S298+6.216281e+01*S299'
.param V85_part31='V85_part30+0.000000e+00*S300+1.413957e+03*S301+1.000000e+04*S302+3.781050e+00*S303+5.747007e-01*S304+9.999939e+03*S305+2.146340e-01*S306+3.408006e-01*S307+2.606727e+00*S308+0.000000e+00*S309'
.param V85='V85_part31+1.142908e-01*S310+1.982152e+00*S311+0.000000e+00*S312+3.621267e-01*S313+1.751258e+00*S314'
.param V86_part1='0.000000e+00*S0+0.000000e+00*S1+(-7.585180e+00)*S2+1.868371e+00*S3+4.193730e+00*S4+(-7.865363e+01)*S5+5.368200e+01*S6+(-5.250207e-01)*S7+5.976078e+00*S8+(-9.388699e+00)*S9'
.param V86_part2='V86_part1+(-3.662645e+01)*S10+(-1.693127e+01)*S11+(-2.569672e+00)*S12+(-6.379374e+00)*S13+(-1.111000e+01)*S14+(-1.769606e+01)*S15+1.613984e+01*S16+7.781454e+00*S17+9.383083e+00*S18+(-1.267081e+01)*S19'
.param V86_part3='V86_part2+(-5.233785e+00)*S20+(-1.409063e+00)*S21+1.945658e+01*S22+(-8.609687e+00)*S23+7.592918e+01*S24+(-4.125389e+00)*S25+(-8.510359e+00)*S26+(-2.172705e+01)*S27+(-5.791922e+00)*S28+(-4.767385e+00)*S29'
.param V86_part4='V86_part3+(-4.486607e-01)*S30+(-1.261394e+01)*S31+(-5.149215e+00)*S32+3.876899e-02*S33+(-1.694165e+01)*S34+1.474815e+01*S35+4.530226e-01*S36+9.658539e-01*S37+3.075783e-01*S38+5.587246e-01*S39'
.param V86_part5='V86_part4+(-4.775332e+00)*S40+(-6.191817e-01)*S41+5.033678e-01*S42+(-5.705678e-01)*S43+(-2.609770e-01)*S44+5.229739e+02*S45+(-1.901820e+01)*S46+(-5.705403e+01)*S47+2.033878e-01*S48+6.873038e+00*S49'
.param V86_part6='V86_part5+(-3.109093e+01)*S50+(-7.682132e-01)*S51+1.063062e+01*S52+6.329454e+00*S53+1.671889e-01*S54+(-4.544794e+00)*S55+(-1.744710e+00)*S56+(-1.722602e-02)*S57+(-4.809249e+02)*S58+(-8.140342e+00)*S59'
.param V86_part7='V86_part6+2.569615e+01*S60+(-1.680581e+02)*S61+(-4.646310e+00)*S62+(-3.205412e+00)*S63+5.391444e+00*S64+(-2.564446e+02)*S65+(-1.682068e+00)*S66+(-2.428005e+00)*S67+(-3.297759e+00)*S68+(-4.669943e-01)*S69'
.param V86_part8='V86_part7+(-3.077903e+00)*S70+(-1.228159e+00)*S71+(-1.768829e-02)*S72+(-6.421282e-01)*S73+(-3.113835e-01)*S74+3.929603e+01*S75+(-3.305047e+02)*S76+3.450452e+00*S77+1.190251e+00*S78+6.322883e-01*S79'
.param V86_part9='V86_part8+(-1.230179e-02)*S80+2.817741e+01*S81+(-5.517277e+00)*S82+(-4.605941e+00)*S83+4.782025e+00*S84+1.688742e+02*S85+(-6.132855e-01)*S86+4.625488e+01*S87+(-1.437802e+00)*S88+8.850072e+01*S89'
.param V86_part10='V86_part9+1.878808e+00*S90+1.949196e+02*S91+5.891463e+00*S92+1.488881e+01*S93+6.354553e+01*S94+(-1.416998e+01)*S95+2.551732e+02*S96+(-1.000000e+04)*S97+6.332428e-01*S98+1.862553e+02*S99'
.param V86_part11='V86_part10+5.539515e+01*S100+2.994870e+00*S101+4.133823e-01*S102+4.420657e+01*S103+1.702073e+01*S104+(-5.485319e+00)*S105+(-1.001224e-02)*S106+(-1.181455e+01)*S107+(-4.573435e+00)*S108+(-8.784402e+00)*S109'
.param V86_part12='V86_part11+6.382744e-01*S110+5.061178e+01*S111+(-3.889685e+02)*S112+9.926836e+01*S113+1.608782e+00*S114+(-1.665528e+01)*S115+9.999940e+03*S116+(-6.163234e+00)*S117+1.239508e+00*S118+2.958025e-01*S119'
.param V86_part13='V86_part12+0.000000e+00*S120+(-3.403394e+00)*S121+(-7.884044e+01)*S122+8.593195e+01*S123+6.727295e+01*S124+1.851521e+02*S125+5.787381e+01*S126+5.393809e+02*S127+5.321454e+01*S128+1.774650e+01*S129'
.param V86_part14='V86_part13+4.279935e+00*S130+(-1.276201e+01)*S131+4.477381e+00*S132+6.786643e+01*S133+(-1.160408e+01)*S134+2.841886e+00*S135+0.000000e+00*S136+(-1.035849e+01)*S137+0.000000e+00*S138+(-4.666240e+00)*S139'
.param V86_part15='V86_part14+(-2.068598e+02)*S140+2.119894e-01*S141+(-6.072325e-01)*S142+(-5.654316e+00)*S143+(-3.428352e-01)*S144+8.057319e+00*S145+2.205244e+01*S146+2.814106e+00*S147+1.861886e+00*S148+3.749356e+01*S149'
.param V86_part16='V86_part15+3.869562e+01*S150+1.306893e+00*S151+4.178817e+01*S152+2.510801e+01*S153+6.838990e-01*S154+(-4.497404e+01)*S155+6.787609e-01*S156+3.717680e-01*S157+3.419025e+01*S158+4.653715e-01*S159'
.param V86_part17='V86_part16+(-7.138358e+00)*S160+1.512309e+00*S161+0.000000e+00*S162+(-1.706853e-02)*S163+4.629186e-03*S164+7.589180e+00*S165+1.771987e+02*S166+6.152912e-01*S167+(-1.537977e+02)*S168+9.667097e-01*S169'
.param V86_part18='V86_part17+4.309140e-03*S170+(-3.094913e+00)*S171+2.099642e+00*S172+1.596768e+00*S173+2.111871e+00*S174+(-1.818930e-01)*S175+5.083424e-01*S176+0.000000e+00*S177+(-1.354746e-01)*S178+4.813532e-01*S179'
.param V86_part19='V86_part18+1.982620e+03*S180+2.337500e+00*S181+1.053519e+03*S182+1.825779e+00*S183+4.231055e+02*S184+5.794490e+00*S185+2.679986e-01*S186+3.965987e+01*S187+(-7.934396e-01)*S188+2.364625e+00*S189'
.param V86_part20='V86_part19+6.271059e+01*S190+8.842353e+01*S191+(-7.351824e-01)*S192+1.142136e-02*S193+3.281427e-01*S194+5.675261e+01*S195+2.274057e+02*S196+1.603020e+00*S197+2.929605e+00*S198+2.884525e+01*S199'
.param V86_part21='V86_part20+5.845341e+01*S200+(-3.946896e+00)*S201+1.055888e+02*S202+6.693673e+02*S203+7.498067e-01*S204+1.000000e+04*S205+1.731414e+00*S206+3.226435e+02*S207+(-5.290284e+03)*S208+(-4.170649e+00)*S209'
.param V86_part22='V86_part21+1.671208e+01*S210+1.305763e-02*S211+(-2.475482e+01)*S212+0.000000e+00*S213+8.049670e-01*S214+(-1.861827e+01)*S215+2.748855e-01*S216+7.225614e+00*S217+2.161949e+00*S218+0.000000e+00*S219'
.param V86_part23='V86_part22+1.159159e-01*S220+8.250701e+00*S221+0.000000e+00*S222+(-3.669455e-01)*S223+5.882943e+02*S224+(-8.043772e+01)*S225+9.544845e-01*S226+2.666510e+02*S227+(-7.945518e+00)*S228+(-3.410483e-01)*S229'
.param V86_part24='V86_part23+1.725238e+01*S230+(-8.453827e+00)*S231+1.297428e+01*S232+4.232269e-01*S233+5.700137e-01*S234+6.356945e+00*S235+5.473928e-01*S236+4.440527e-01*S237+(-2.968158e-01)*S238+(-3.387993e-02)*S239'
.param V86_part25='V86_part24+1.205758e+02*S240+3.557859e+01*S241+(-7.816692e+00)*S242+(-4.324048e-01)*S243+5.548361e+00*S244+1.464480e+01*S245+(-7.384323e+00)*S246+(-7.775016e-01)*S247+3.860193e-01*S248+1.085523e-01*S249'
.param V86_part26='V86_part25+3.713440e+00*S250+6.758244e-01*S251+0.000000e+00*S252+5.555227e+00*S253+(-6.916565e-02)*S254+1.127384e+02*S255+1.461430e+00*S256+1.470026e+02*S257+4.739055e+01*S258+2.266397e+01*S259'
.param V86_part27='V86_part26+5.661438e+01*S260+0.000000e+00*S261+0.000000e+00*S262+3.239475e-01*S263+7.949534e-01*S264+1.828360e+00*S265+7.394709e-01*S266+0.000000e+00*S267+2.979522e+00*S268+2.845841e-01*S269'
.param V86_part28='V86_part27+6.045876e+00*S270+9.268351e+01*S271+1.688158e+02*S272+1.815687e+00*S273+8.364197e+01*S274+7.423136e+01*S275+1.164414e+00*S276+5.157512e+00*S277+9.326130e-01*S278+0.000000e+00*S279'
.param V86_part29='V86_part28+1.410453e+00*S280+9.157167e-01*S281+3.096625e-02*S282+(-8.804319e-01)*S283+(-3.282385e+01)*S284+(-2.437675e+00)*S285+9.457770e+00*S286+3.393939e-01*S287+(-5.022331e-03)*S288+(-3.435328e+00)*S289'
.param V86_part30='V86_part29+3.358287e-01*S290+(-6.536543e+00)*S291+4.376769e-01*S292+9.153419e-02*S293+(-1.061989e+00)*S294+2.951489e-01*S295+2.392570e+00*S296+0.000000e+00*S297+(-5.502549e+00)*S298+2.322815e+00*S299'
.param V86_part31='V86_part30+0.000000e+00*S300+5.351555e+03*S301+(-2.512969e+01)*S302+2.063506e+00*S303+2.284267e+00*S304+(-3.040273e+00)*S305+4.759932e-02*S306+(-1.072235e-01)*S307+8.387944e-01*S308+0.000000e+00*S309'
.param V86='V86_part31+1.464747e-01*S310+8.618035e-01*S311+0.000000e+00*S312+9.984246e-03*S313+8.333711e-01*S314'
.param V87_part1='0.000000e+00*S0+0.000000e+00*S1+5.391724e+00*S2+1.889215e+01*S3+(-2.741878e+00)*S4+(-1.658569e+01)*S5+(-2.846915e+01)*S6+2.143368e+00*S7+2.756132e+00*S8+(-6.551245e+00)*S9'
.param V87_part2='V87_part1+(-1.038077e+01)*S10+(-2.179936e+00)*S11+(-4.788829e+00)*S12+(-1.580396e+00)*S13+1.808609e+00*S14+(-2.312885e+01)*S15+4.056363e+00*S16+2.304178e+00*S17+3.254915e+01*S18+(-9.722995e+00)*S19'
.param V87_part3='V87_part2+(-3.345800e+00)*S20+(-3.545174e+01)*S21+(-1.484969e+01)*S22+(-1.983320e+00)*S23+1.399873e+01*S24+7.296315e-01*S25+(-3.962519e+00)*S26+2.316118e+01*S27+(-4.025335e+00)*S28+(-2.332991e+00)*S29'
.param V87_part4='V87_part3+3.326293e-01*S30+(-7.525625e+00)*S31+(-2.759897e+00)*S32+2.110368e-01*S33+(-6.712035e+00)*S34+(-1.216742e+01)*S35+1.111206e-01*S36+(-3.248165e+00)*S37+2.363671e-02*S38+2.067609e-01*S39'
.param V87_part5='V87_part4+(-2.397365e+00)*S40+(-1.168089e+00)*S41+1.242267e-01*S42+(-4.807612e-01)*S43+(-1.926619e+00)*S44+(-1.251450e+03)*S45+(-3.369536e+00)*S46+1.429054e+00*S47+5.656387e-02*S48+2.258429e+00*S49'
.param V87_part6='V87_part5+2.121915e-01*S50+(-7.763272e+00)*S51+4.052781e+01*S52+(-8.808989e+01)*S53+5.556293e-01*S54+2.086596e+01*S55+(-4.907520e+01)*S56+(-7.906477e-02)*S57+(-2.511232e+02)*S58+(-3.987237e+01)*S59'
.param V87_part7='V87_part6+(-3.812605e+01)*S60+(-6.181203e+02)*S61+(-8.338899e+00)*S62+(-7.647134e+00)*S63+(-4.286697e+00)*S64+(-4.116434e+01)*S65+(-8.162054e-01)*S66+(-3.794295e+00)*S67+(-5.994604e+00)*S68+1.380303e+01*S69'
.param V87_part8='V87_part7+(-6.179077e+00)*S70+(-2.543552e+00)*S71+6.610864e-01*S72+(-3.236832e+00)*S73+(-2.959610e-01)*S74+(-5.197763e+01)*S75+1.454031e+02*S76+(-2.340408e+00)*S77+(-1.384277e+01)*S78+(-1.892828e-01)*S79'
.param V87_part9='V87_part8+(-1.778707e+00)*S80+(-3.128475e+01)*S81+(-5.616402e+00)*S82+(-4.436982e+00)*S83+(-8.909858e+00)*S84+4.093985e+02*S85+2.006578e-01*S86+(-3.522038e+01)*S87+(-1.010973e+00)*S88+1.562745e+00*S89'
.param V87_part10='V87_part9+(-1.164397e+01)*S90+4.655919e+00*S91+(-1.377743e+03)*S92+(-9.011553e+00)*S93+2.900135e+02*S94+1.013969e+02*S95+1.430843e+03*S96+1.000000e+04*S97+7.284948e-02*S98+1.236533e+03*S99'
.param V87_part11='V87_part10+(-1.638904e+01)*S100+5.119036e+00*S101+(-3.759077e-01)*S102+(-9.455838e+00)*S103+(-3.618755e+02)*S104+(-2.081948e+01)*S105+(-3.021909e+00)*S106+(-2.953400e+02)*S107+(-1.376501e+01)*S108+(-1.570560e+01)*S109'
.param V87_part12='V87_part11+3.116201e-01*S110+(-2.733154e+01)*S111+(-3.380034e+02)*S112+9.588457e+01*S113+6.697507e+00*S114+(-2.267178e+01)*S115+(-1.000000e+04)*S116+(-4.909410e+00)*S117+6.297927e-01*S118+(-5.460889e-02)*S119'
.param V87_part13='V87_part12+0.000000e+00*S120+(-5.003455e+00)*S121+3.764032e+01*S122+(-1.193046e+02)*S123+2.631561e+02*S124+(-1.000000e+04)*S125+(-1.899982e+02)*S126+(-3.257396e+03)*S127+(-9.957793e+03)*S128+(-4.656393e+01)*S129'
.param V87_part14='V87_part13+(-1.886315e+02)*S130+(-8.206733e+03)*S131+2.273926e+03*S132+(-8.272513e+02)*S133+(-1.943807e+03)*S134+(-2.377587e+01)*S135+0.000000e+00*S136+(-1.011102e+01)*S137+0.000000e+00*S138+(-2.446517e+01)*S139'
.param V87_part15='V87_part14+2.609964e+02*S140+(-3.231687e-01)*S141+(-1.862825e+01)*S142+(-2.070624e+02)*S143+(-1.075778e+01)*S144+(-2.076558e+01)*S145+(-7.077694e+02)*S146+(-1.110051e+01)*S147+(-2.023906e+01)*S148+(-1.749179e+01)*S149'
.param V87_part16='V87_part15+6.734753e+01*S150+(-3.323392e+00)*S151+2.724020e+02*S152+(-1.698907e+02)*S153+(-2.888658e+00)*S154+2.358312e+02*S155+(-1.516668e-01)*S156+2.136052e-02*S157+6.602469e+01*S158+4.550953e-01*S159'
.param V87_part17='V87_part16+2.332984e+02*S160+4.882447e+00*S161+0.000000e+00*S162+6.208234e-02*S163+1.910043e-02*S164+(-1.398313e+02)*S165+(-1.224591e+02)*S166+1.822231e-01*S167+6.098576e+01*S168+1.593312e-01*S169'
.param V87_part18='V87_part17+(-1.227023e-01)*S170+5.300524e+01*S171+5.407234e-01*S172+4.160755e-01*S173+(-1.528871e+01)*S174+(-5.999089e-01)*S175+7.234788e-02*S176+0.000000e+00*S177+(-2.032646e-01)*S178+4.408089e-04*S179'
.param V87_part19='V87_part18+9.655865e+03*S180+(-4.275017e+00)*S181+7.365743e+02*S182+(-2.627794e+01)*S183+(-3.837780e+02)*S184+7.441550e+01*S185+(-1.118641e+01)*S186+(-1.686669e+02)*S187+(-1.247004e+00)*S188+5.736555e+00*S189'
.param V87_part20='V87_part19+(-7.968941e+00)*S190+(-5.711423e+01)*S191+9.861334e+01*S192+(-6.173928e-02)*S193+(-8.309982e-01)*S194+4.046681e+01*S195+(-2.638812e+01)*S196+3.466466e+00*S197+(-8.355266e+00)*S198+(-3.031586e+01)*S199'
.param V87_part21='V87_part20+(-9.611364e+01)*S200+4.360825e+02*S201+(-6.783233e+01)*S202+(-4.288305e+03)*S203+(-2.145078e+00)*S204+1.000000e+04*S205+(-9.951105e+03)*S206+(-1.038885e+02)*S207+9.358311e+03*S208+(-7.452088e+03)*S209'
.param V87_part22='V87_part21+(-5.344004e+01)*S210+(-2.002920e+00)*S211+(-9.969795e+03)*S212+0.000000e+00*S213+(-2.309354e+01)*S214+(-9.977516e+03)*S215+(-4.728625e-01)*S216+(-1.607779e+01)*S217+(-9.989595e+03)*S218+0.000000e+00*S219'
.param V87_part23='V87_part22+3.366880e+01*S220+(-3.495104e+00)*S221+0.000000e+00*S222+(-7.821984e+00)*S223+(-8.614945e+03)*S224+1.000000e+04*S225+(-6.843914e-02)*S226+1.799073e+02*S227+4.198079e+01*S228+(-2.569411e-01)*S229'
.param V87_part24='V87_part23+5.276844e+00*S230+(-6.694141e+00)*S231+(-1.459430e+01)*S232+(-3.846494e-01)*S233+(-2.978186e+00)*S234+(-1.666328e+01)*S235+(-3.021198e-01)*S236+(-1.799268e+00)*S237+(-6.604031e-01)*S238+1.973364e-01*S239'
.param V87_part25='V87_part24+(-2.505517e+02)*S240+(-3.241382e+01)*S241+(-5.436639e+02)*S242+9.842547e-03*S243+(-1.235080e+01)*S244+(-7.841898e+00)*S245+(-2.188649e+01)*S246+(-1.067734e+00)*S247+(-4.001155e-01)*S248+4.194555e+01*S249'
.param V87_part26='V87_part25+1.112760e+02*S250+(-3.289633e-01)*S251+0.000000e+00*S252+6.382822e+02*S253+(-6.427366e-02)*S254+(-1.409777e+02)*S255+7.355781e+02*S256+(-3.641267e+01)*S257+(-3.540903e+02)*S258+(-1.507489e+01)*S259'
.param V87_part27='V87_part26+(-4.110039e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-1.959971e-01)*S263+(-3.794352e+00)*S264+(-4.249248e+00)*S265+(-1.593445e+00)*S266+0.000000e+00*S267+2.819421e+02*S268+5.728552e-02*S269'
.param V87_part28='V87_part27+(-1.294786e+01)*S270+(-1.173258e+02)*S271+1.181460e+02*S272+(-1.000000e+04)*S273+(-5.523551e+01)*S274+5.401475e+01*S275+(-5.917273e+00)*S276+(-8.300276e+00)*S277+(-1.016877e-01)*S278+0.000000e+00*S279'
.param V87_part29='V87_part28+(-4.528877e+00)*S280+1.137383e-01*S281+7.228906e+00*S282+(-2.232162e-01)*S283+(-2.140689e+02)*S284+(-9.795844e-02)*S285+(-9.504305e+00)*S286+(-9.289798e-01)*S287+(-1.436086e+00)*S288+(-1.007633e+00)*S289'
.param V87_part30='V87_part29+(-3.097573e-01)*S290+3.916261e+00*S291+4.492044e-01*S292+(-3.267359e+01)*S293+2.246282e+01*S294+3.513170e-01*S295+(-4.781839e+01)*S296+0.000000e+00*S297+9.110042e+00*S298+(-5.124416e+01)*S299'
.param V87_part31='V87_part30+0.000000e+00*S300+(-5.708659e+03)*S301+(-9.982464e+03)*S302+(-7.418888e+00)*S303+(-9.253845e-01)*S304+(-9.981282e+03)*S305+(-3.422313e-01)*S306+1.433252e-01*S307+(-2.392327e+00)*S308+0.000000e+00*S309'
.param V87='V87_part31+3.444344e-01*S310+(-1.938599e+00)*S311+0.000000e+00*S312+2.141778e-01*S313+(-1.702744e+00)*S314'
.param V88_part1='0.000000e+00*S0+0.000000e+00*S1+1.040045e+01*S2+6.652339e+01*S3+1.691026e+01*S4+1.566484e+01*S5+1.313524e+01*S6+6.220101e+00*S7+1.607403e+01*S8+6.403260e+00*S9'
.param V88_part2='V88_part1+2.032284e+00*S10+1.461841e+01*S11+3.089577e+00*S12+1.639852e+00*S13+2.140644e+00*S14+3.654623e-01*S15+7.323179e+00*S16+5.224021e+00*S17+1.692005e+01*S18+4.116160e+00*S19'
.param V88_part3='V88_part2+3.553073e+00*S20+(-7.279630e-01)*S21+(-2.903364e-01)*S22+(-2.460177e+00)*S23+(-6.702368e+01)*S24+4.516356e+00*S25+(-8.718275e-01)*S26+(-1.182156e+00)*S27+(-2.359783e-01)*S28+(-4.894939e-01)*S29'
.param V88_part4='V88_part3+(-4.147090e-02)*S30+2.426133e+00*S31+(-3.565314e-01)*S32+1.273040e-01*S33+1.940812e+01*S34+3.929544e+00*S35+4.607875e-02*S36+2.984733e+00*S37+(-9.320158e-02)*S38+8.168279e-04*S39'
.param V88_part5='V88_part4+(-6.716055e-01)*S40+(-1.547943e+00)*S41+(-1.427527e-03)*S42+(-2.026905e-01)*S43+(-1.191967e+00)*S44+7.736778e+02*S45+3.333834e-01*S46+1.912508e+00*S47+5.200208e-02*S48+5.562238e+00*S49'
.param V88_part6='V88_part5+5.096067e+00*S50+8.440976e-01*S51+5.310012e+02*S52+(-1.000000e+04)*S53+4.126591e-02*S54+3.474975e+03*S55+(-1.000000e+04)*S56+(-4.409689e-02)*S57+(-3.591005e-02)*S58+(-1.000000e+04)*S59'
.param V88_part7='V88_part6+(-1.118266e-01)*S60+(-2.884221e+01)*S61+(-1.041838e-01)*S62+2.089134e-02*S63+(-2.125651e+00)*S64+3.681844e+03*S65+3.152522e-01*S66+3.547752e-01*S67+(-4.548252e-01)*S68+1.829505e-02*S69'
.param V88_part8='V88_part7+2.324687e-01*S70+2.040420e-02*S71+6.713369e-01*S72+7.958692e-02*S73+7.564866e-01*S74+(-7.366115e+00)*S75+4.425916e+01*S76+(-7.679307e-02)*S77+6.765008e-01*S78+(-8.366458e-01)*S79'
.param V88_part9='V88_part8+3.122644e-01*S80+(-9.209977e+00)*S81+(-5.478489e+00)*S82+(-2.187308e+00)*S83+(-3.280775e+00)*S84+3.693385e+02*S85+(-9.025105e-01)*S86+(-6.528659e+03)*S87+2.714496e-03*S88+3.142611e+01*S89'
.param V88_part10='V88_part9+1.282180e+00*S90+7.617518e+00*S91+5.306424e-01*S92+(-1.000000e+04)*S93+(-1.000000e+04)*S94+(-1.000000e+04)*S95+(-1.000000e+04)*S96+(-1.000000e+04)*S97+7.338726e-02*S98+(-8.926116e+03)*S99'
.param V88_part11='V88_part10+(-1.000000e+04)*S100+2.487467e+01*S101+3.674108e-01*S102+(-9.883491e+03)*S103+(-5.220821e+00)*S104+1.072717e+00*S105+4.014729e-01*S106+(-6.974312e+00)*S107+6.831672e-01*S108+9.085027e-01*S109'
.param V88_part12='V88_part11+1.252933e-01*S110+1.802990e+02*S111+4.359209e-02*S112+1.728158e+03*S113+1.928231e+00*S114+3.135571e+00*S115+(-1.000000e+04)*S116+2.766294e-01*S117+5.798571e-02*S118+2.399120e-02*S119'
.param V88_part13='V88_part12+0.000000e+00*S120+1.783516e-01*S121+9.222929e+02*S122+1.182470e+01*S123+1.651249e+02*S124+(-2.177305e+01)*S125+6.130942e+00*S126+1.166821e+02*S127+(-6.557985e+01)*S128+(-9.381659e+00)*S129'
.param V88_part14='V88_part13+(-8.768635e+01)*S130+(-1.896297e+01)*S131+5.479185e-01*S132+2.077581e+00*S133+(-1.065355e+01)*S134+4.603350e-01*S135+0.000000e+00*S136+(-8.416900e+00)*S137+0.000000e+00*S138+(-4.521349e+00)*S139'
.param V88_part15='V88_part14+7.848289e+01*S140+2.444484e-02*S141+(-2.029200e+00)*S142+(-8.225776e+00)*S143+(-1.565101e+00)*S144+(-2.612066e+00)*S145+(-4.557891e-01)*S146+(-5.953405e+00)*S147+(-1.622322e+00)*S148+(-1.255863e+00)*S149'
.param V88_part16='V88_part15+(-9.420415e-01)*S150+(-3.616679e+01)*S151+1.000000e+04*S152+1.143494e+01*S153+1.311708e+00*S154+1.000000e+04*S155+1.457527e-01*S156+9.411716e-02*S157+1.000000e+04*S158+4.995676e-02*S159'
.param V88_part17='V88_part16+(-1.173463e+03)*S160+2.177087e+01*S161+0.000000e+00*S162+1.135721e-02*S163+9.610421e-03*S164+(-5.603889e+02)*S165+1.046498e+01*S166+2.894979e-01*S167+(-1.000000e+04)*S168+2.091264e-01*S169'
.param V88_part18='V88_part17+2.042737e-01*S170+(-2.322826e-01)*S171+1.517783e-01*S172+1.162446e-01*S173+3.185329e-02*S174+(-7.229061e-03)*S175+1.376559e-02*S176+0.000000e+00*S177+5.236226e-02*S178+1.126140e-02*S179'
.param V88_part19='V88_part18+4.608509e+03*S180+7.084229e-01*S181+5.548473e+01*S182+(-8.376052e-01)*S183+(-1.506005e+02)*S184+1.385828e+01*S185+3.354063e-02*S186+(-1.658517e+00)*S187+1.216768e-01*S188+6.258204e-02*S189'
.param V88_part20='V88_part19+(-3.004395e+00)*S190+(-5.093532e+00)*S191+(-2.197800e-02)*S192+6.929049e-02*S193+4.020654e-02*S194+2.237935e+01*S195+2.154619e+00*S196+3.576444e+00*S197+(-7.132380e-01)*S198+3.565530e+00*S199'
.param V88_part21='V88_part20+6.878788e-01*S200+(-1.669270e-01)*S201+(-6.909147e-02)*S202+(-6.304035e+01)*S203+(-1.528545e-01)*S204+(-1.000000e+04)*S205+(-1.878290e+01)*S206+5.169312e+01*S207+1.000000e+04*S208+(-9.496944e+00)*S209'
.param V88_part22='V88_part21+1.028507e-01*S210+(-1.380231e-01)*S211+(-1.586446e+01)*S212+0.000000e+00*S213+5.622893e-01*S214+(-6.007415e+00)*S215+1.931716e-01*S216+1.588072e-01*S217+(-1.171804e+00)*S218+0.000000e+00*S219'
.param V88_part23='V88_part22+(-2.643909e+00)*S220+4.441778e-01*S221+0.000000e+00*S222+2.516762e-01*S223+(-4.654297e+02)*S224+(-1.564319e-02)*S225+2.244255e-01*S226+6.678241e+02*S227+(-2.518215e-01)*S228+1.097105e+00*S229'
.param V88_part24='V88_part23+3.062095e+00*S230+(-2.611164e+00)*S231+(-3.877242e-01)*S232+7.661756e-02*S233+(-2.843434e-01)*S234+3.746906e-01*S235+7.022532e-02*S236+(-2.528215e-01)*S237+(-1.260737e-01)*S238+2.896529e-02*S239'
.param V88_part25='V88_part24+8.971939e-01*S240+(-3.525948e+00)*S241+(-1.289186e+02)*S242+5.769393e-01*S243+(-9.841692e-01)*S244+3.186294e-02*S245+3.538023e-01*S246+1.124225e-02*S247+8.465046e-02*S248+(-1.024332e+00)*S249'
.param V88_part26='V88_part25+4.379839e+00*S250+5.764996e-02*S251+0.000000e+00*S252+9.472104e+00*S253+5.792538e-04*S254+(-3.509082e-01)*S255+(-2.777884e+03)*S256+(-4.592956e+00)*S257+3.158368e+01*S258+9.795625e-01*S259'
.param V88_part27='V88_part26+(-2.289926e+00)*S260+0.000000e+00*S261+0.000000e+00*S262+1.917044e-01*S263+(-9.335706e-01)*S264+(-1.074334e-01)*S265+2.433769e-02*S266+0.000000e+00*S267+9.246480e+00*S268+(-6.866182e-03)*S269'
.param V88_part28='V88_part27+7.630289e-01*S270+(-1.073925e+00)*S271+1.000000e+04*S272+1.948924e-02*S273+3.129853e-01*S274+4.000700e+02*S275+(-2.456477e-01)*S276+9.829096e-02*S277+4.943984e-02*S278+0.000000e+00*S279'
.param V88_part29='V88_part28+6.172579e-01*S280+4.631062e-02*S281+(-4.023584e-02)*S282+(-2.573866e-03)*S283+1.126943e+01*S284+(-3.613080e-02)*S285+(-3.095814e-01)*S286+3.093498e-01*S287+(-3.114313e-02)*S288+1.591075e-01*S289'
.param V88_part30='V88_part29+1.030144e-01*S290+(-1.903139e-01)*S291+2.230915e-02*S292+(-6.669783e-01)*S293+3.447765e-02*S294+(-2.204558e-02)*S295+(-1.318434e+01)*S296+0.000000e+00*S297+(-6.574133e-01)*S298+(-1.185359e+01)*S299'
.param V88_part31='V88_part30+0.000000e+00*S300+7.849504e+02*S301+(-2.686918e+01)*S302+(-1.266732e+00)*S303+(-1.429567e-01)*S304+(-9.840563e+00)*S305+1.488150e-01*S306+(-5.628511e-02)*S307+(-1.007337e-02)*S308+0.000000e+00*S309'
.param V88='V88_part31+(-5.612582e-02)*S310+(-2.593755e-02)*S311+0.000000e+00*S312+(-3.929908e-02)*S313+(-4.815927e-02)*S314'
.param V89_part1='0.000000e+00*S0+0.000000e+00*S1+1.759976e-01*S2+5.443712e-03*S3+1.002092e-01*S4+(-4.452474e-01)*S5+(-3.497664e+00)*S6+6.010913e-02*S7+1.908947e-01*S8+8.074565e-02*S9'
.param V89_part2='V89_part1+9.856288e-02*S10+5.137048e-01*S11+3.091897e-02*S12+4.229178e-02*S13+(-2.112993e-01)*S14+(-1.839433e-02)*S15+(-2.665569e-02)*S16+9.631712e-03*S17+1.182544e-01*S18+9.466779e-02*S19'
.param V89_part3='V89_part2+2.563746e-02*S20+(-3.304443e-02)*S21+2.771050e-02*S22+1.900003e-01*S23+2.280644e-01*S24+6.425952e-02*S25+(-1.032891e-02)*S26+1.305220e-01*S27+3.719037e-02*S28+5.733539e-03*S29'
.param V89_part4='V89_part3+(-1.581216e-02)*S30+(-5.526238e-02)*S31+(-4.134524e-02)*S32+1.803262e-02*S33+(-6.400438e-01)*S34+3.795553e-01*S35+4.681526e-02*S36+(-1.629072e-01)*S37+3.226701e-03*S38+4.687508e-02*S39'
.param V89_part5='V89_part4+(-1.074361e-01)*S40+(-1.204592e-02)*S41+6.189437e-02*S42+(-1.610949e-01)*S43+7.946089e-02*S44+1.000000e+04*S45+5.010152e-01*S46+4.483486e+00*S47+1.307511e-02*S48+3.951536e+01*S49'
.param V89_part6='V89_part5+2.365804e+00*S50+4.270370e-01*S51+(-6.871403e-01)*S52+(-5.171851e+00)*S53+5.980891e-02*S54+2.170430e-02*S55+(-2.588605e+00)*S56+(-2.257903e-03)*S57+1.000000e+04*S58+(-1.951333e+00)*S59'
.param V89_part7='V89_part6+5.335875e+01*S60+5.864109e+03*S61+1.436624e+00*S62+3.562952e-02*S63+(-4.341901e-01)*S64+6.928348e+03*S65+2.587538e+00*S66+1.439207e-02*S67+1.951775e-02*S68+2.001287e-01*S69'
.param V89_part8='V89_part7+(-1.689446e-01)*S70+(-2.719983e-02)*S71+1.974752e-01*S72+(-5.497146e-02)*S73+4.224507e-01*S74+7.660830e+01*S75+(-5.193097e+00)*S76+6.776125e-01*S77+(-2.623430e-01)*S78+4.996891e-02*S79'
.param V89_part9='V89_part8+4.423831e-01*S80+2.413209e+00*S81+6.100244e-01*S82+5.030708e-01*S83+4.337970e-01*S84+6.000040e+03*S85+1.125665e+00*S86+1.191363e+02*S87+5.513884e-01*S88+4.450970e+01*S89'
.param V89_part10='V89_part9+(-3.948499e-01)*S90+(-5.270602e+00)*S91+7.696005e+01*S92+(-7.895770e-02)*S93+2.120326e+01*S94+(-2.392767e+00)*S95+4.530949e+01*S96+1.000000e+04*S97+4.199643e-02*S98+4.060936e+02*S99'
.param V89_part11='V89_part10+1.660003e+00*S100+4.795561e-02*S101+1.307919e-01*S102+(-1.054101e-01)*S103+2.833675e+00*S104+7.467746e+00*S105+4.745309e+00*S106+3.157667e+01*S107+4.424521e+00*S108+5.610424e+00*S109'
.param V89_part12='V89_part11+3.733925e-02*S110+(-6.452328e+00)*S111+7.931669e+02*S112+1.386242e+00*S113+(-5.394623e+00)*S114+(-2.276385e+00)*S115+9.999760e+03*S116+1.084745e+01*S117+3.836538e-02*S118+1.469756e-01*S119'
.param V89_part13='V89_part12+0.000000e+00*S120+(-1.836869e-01)*S121+(-3.053370e+01)*S122+2.513904e+00*S123+4.387007e+00*S124+2.157325e+02*S125+2.811534e+01*S126+3.528560e+02*S127+4.621303e+01*S128+1.767984e+00*S129'
.param V89_part14='V89_part13+(-2.062833e+01)*S130+9.974445e+00*S131+(-3.938383e+00)*S132+(-3.746730e-01)*S133+2.997503e+00*S134+1.784879e+00*S135+0.000000e+00*S136+2.037923e+00*S137+0.000000e+00*S138+9.308881e-01*S139'
.param V89_part15='V89_part14+1.316083e+00*S140+(-8.563357e-02)*S141+(-3.219150e-01)*S142+2.465014e-01*S143+1.829523e-01*S144+(-9.954773e-03)*S145+5.560504e+00*S146+2.189835e+00*S147+3.522564e-01*S148+1.272734e+00*S149'
.param V89_part16='V89_part15+(-1.154547e+01)*S150+1.052107e+00*S151+(-1.457196e+01)*S152+9.463717e+00*S153+1.153929e-02*S154+(-1.106773e+00)*S155+1.911267e-01*S156+5.083501e-02*S157+(-5.027780e+00)*S158+4.728039e-01*S159'
.param V89_part17='V89_part16+8.127207e+00*S160+(-7.413333e-02)*S161+0.000000e+00*S162+(-1.301697e-02)*S163+3.870129e-02*S164+3.729093e+00*S165+9.992905e+03*S166+5.521668e-02*S167+1.110376e+02*S168+5.821019e-02*S169'
.param V89_part18='V89_part17+(-2.374969e-04)*S170+1.039023e+00*S171+1.293099e-01*S172+1.365636e-01*S173+1.485844e-01*S174+(-6.321669e-03)*S175+2.036573e-01*S176+0.000000e+00*S177+3.741278e-02*S178+1.969805e-01*S179'
.param V89_part19='V89_part18+1.000000e+04*S180+1.636382e-01*S181+(-1.626203e+03)*S182+2.018756e+00*S183+(-2.259231e+01)*S184+2.171375e-01*S185+1.805878e-02*S186+(-3.071950e+00)*S187+(-1.006211e-02)*S188+2.049959e-01*S189'
.param V89_part20='V89_part19+8.826510e+02*S190+1.000000e+04*S191+7.448613e-01*S192+1.245697e-01*S193+9.191741e-02*S194+(-3.919460e+02)*S195+(-3.837400e+01)*S196+3.456625e-01*S197+5.149509e-01*S198+2.399513e+00*S199'
.param V89_part21='V89_part20+2.169386e+00*S200+6.015279e-01*S201+1.962120e+01*S202+8.511153e+00*S203+1.354344e-01*S204+1.000000e+04*S205+(-7.304333e-01)*S206+(-1.810199e+02)*S207+1.058755e+03*S208+(-2.662038e+00)*S209'
.param V89_part22='V89_part21+1.330350e+00*S210+4.360384e-02*S211+1.980510e+01*S212+0.000000e+00*S213+(-2.602791e+00)*S214+7.248690e+00*S215+(-7.771237e-03)*S216+2.768870e+00*S217+2.137196e+00*S218+0.000000e+00*S219'
.param V89_part23='V89_part22+(-2.101516e+00)*S220+2.564079e+01*S221+0.000000e+00*S222+4.154546e-01*S223+9.378711e+03*S224+1.676990e+01*S225+1.386757e-01*S226+1.217563e-01*S227+1.023709e+00*S228+(-3.624396e-02)*S229'
.param V89_part24='V89_part23+3.020451e+00*S230+(-3.380335e+00)*S231+1.412416e+01*S232+1.206070e-01*S233+3.475182e-02*S234+2.780549e+00*S235+1.282780e-01*S236+1.114023e-01*S237+2.516723e-02*S238+8.292031e-02*S239'
.param V89_part25='V89_part24+1.063449e+01*S240+2.205070e+00*S241+(-3.641209e-01)*S242+(-8.152790e-02)*S243+8.619651e-01*S244+1.672497e+01*S245+(-1.770973e+00)*S246+2.403062e-01*S247+1.827152e-01*S248+2.228117e+00*S249'
.param V89_part26='V89_part25+(-8.790885e+00)*S250+1.837689e-01*S251+0.000000e+00*S252+(-9.718386e+01)*S253+2.216926e-01*S254+1.000000e+04*S255+6.668931e+03*S256+1.140405e+01*S257+4.849895e+00*S258+1.317664e+00*S259'
.param V89_part27='V89_part26+2.579450e+00*S260+0.000000e+00*S261+0.000000e+00*S262+1.088568e-01*S263+5.200786e-01*S264+1.027505e+00*S265+2.370327e-01*S266+0.000000e+00*S267+(-3.223403e+01)*S268+3.921634e-01*S269'
.param V89_part28='V89_part27+3.277284e-01*S270+1.000000e+04*S271+(-1.464811e+00)*S272+(-2.492321e-02)*S273+2.636704e+00*S274+3.575390e+00*S275+(-5.692198e-03)*S276+1.075066e+00*S277+1.466391e-01*S278+0.000000e+00*S279'
.param V89_part29='V89_part28+4.977935e-01*S280+1.670313e-01*S281+9.161287e-01*S282+3.731411e-02*S283+(-2.841108e+02)*S284+1.618825e-01*S285+3.312835e-01*S286+2.239858e-02*S287+(-7.305284e-02)*S288+3.755965e-01*S289'
.param V89_part30='V89_part29+1.597454e-01*S290+1.335151e+00*S291+2.434931e-01*S292+(-5.691559e-02)*S293+1.926295e-01*S294+3.680040e-01*S295+2.417425e+00*S296+0.000000e+00*S297+1.426712e+00*S298+3.806444e+00*S299'
.param V89_part31='V89_part30+0.000000e+00*S300+4.413426e+03*S301+6.187981e+01*S302+1.139793e+00*S303+2.708068e+00*S304+1.622713e+01*S305+(-3.425741e-02)*S306+2.024532e-01*S307+6.577971e-02*S308+0.000000e+00*S309'
.param V89='V89_part31+2.513792e-01*S310+6.859940e-02*S311+0.000000e+00*S312+2.049409e-01*S313+1.999664e-02*S314'
.param V90_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V90_part2='V90_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+1.632033e-01*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V90_part3='V90_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-8.729012e-02)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V90_part4='V90_part3+0.000000e+00*S30+1.935392e-01*S31+0.000000e+00*S32+0.000000e+00*S33+2.771033e-01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V90_part5='V90_part4+0.000000e+00*S40+3.710484e-01*S41+0.000000e+00*S42+6.573959e-01*S43+4.675319e-01*S44+1.682814e-01*S45+2.280679e-01*S46+0.000000e+00*S47+(-1.667650e-01)*S48+0.000000e+00*S49'
.param V90_part6='V90_part5+0.000000e+00*S50+2.939929e-01*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V90_part7='V90_part6+6.718049e-02*S60+0.000000e+00*S61+1.239456e+00*S62+0.000000e+00*S63+(-5.579006e-02)*S64+0.000000e+00*S65+7.756975e-01*S66+2.850164e-01*S67+(-9.643357e-02)*S68+0.000000e+00*S69'
.param V90_part8='V90_part7+(-2.594929e-02)*S70+(-2.881178e-01)*S71+0.000000e+00*S72+1.012569e-02*S73+1.361641e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V90_part9='V90_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V90_part10='V90_part9+1.921503e-01*S90+0.000000e+00*S91+0.000000e+00*S92+(-1.251005e-01)*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V90_part11='V90_part10+0.000000e+00*S100+(-6.885566e-01)*S101+0.000000e+00*S102+(-4.598022e-01)*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V90_part12='V90_part11+0.000000e+00*S110+(-1.561402e-01)*S111+(-2.444458e-01)*S112+(-3.871287e-01)*S113+9.940724e-02*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V90_part13='V90_part12+0.000000e+00*S120+7.447488e-02*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V90_part14='V90_part13+0.000000e+00*S130+(-1.584813e+00)*S131+0.000000e+00*S132+(-1.152569e+00)*S133+(-2.361859e+00)*S134+0.000000e+00*S135+2.454451e+02*S136+6.059656e-01*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V90_part15='V90_part14+6.675125e-02*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+7.007052e-02*S148+0.000000e+00*S149'
.param V90_part16='V90_part15+2.229974e-01*S150+2.377555e-01*S151+0.000000e+00*S152+(-2.198656e-01)*S153+7.615346e-02*S154+(-3.720209e-01)*S155+0.000000e+00*S156+0.000000e+00*S157+(-1.794439e+00)*S158+0.000000e+00*S159'
.param V90_part17='V90_part16+(-7.949364e-01)*S160+(-2.862702e+00)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+2.669857e-01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V90_part18='V90_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+(-3.294655e-01)*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V90_part19='V90_part18+0.000000e+00*S180+(-4.670187e-01)*S181+(-4.518303e-01)*S182+0.000000e+00*S183+0.000000e+00*S184+(-1.216864e+00)*S185+9.420457e+00*S186+0.000000e+00*S187+0.000000e+00*S188+6.993079e+00*S189'
.param V90_part20='V90_part19+(-1.105208e+00)*S190+(-2.859600e+00)*S191+1.040005e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+1.424532e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V90_part21='V90_part20+(-3.022197e-01)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+(-5.209354e-01)*S206+2.195147e+00*S207+7.184383e-02*S208+(-1.303827e+00)*S209'
.param V90_part22='V90_part21+0.000000e+00*S210+(-1.317442e+00)*S211+(-1.161358e+00)*S212+3.776032e+00*S213+3.264062e-01*S214+(-1.513980e+00)*S215+0.000000e+00*S216+(-1.705635e+00)*S217+(-1.754480e+00)*S218+0.000000e+00*S219'
.param V90_part23='V90_part22+(-1.040700e+00)*S220+(-5.747579e+00)*S221+0.000000e+00*S222+(-2.925140e+00)*S223+(-5.331171e+00)*S224+(-2.764536e-01)*S225+0.000000e+00*S226+(-1.171368e+00)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V90_part24='V90_part23+(-2.075744e+00)*S230+0.000000e+00*S231+(-2.895323e-01)*S232+0.000000e+00*S233+0.000000e+00*S234+(-8.312989e-01)*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V90_part25='V90_part24+0.000000e+00*S240+(-9.889572e-01)*S241+(-1.077028e+00)*S242+3.377057e-01*S243+(-1.191808e+00)*S244+(-2.060847e+00)*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+(-9.449585e-01)*S249'
.param V90_part26='V90_part25+1.200084e-01*S250+0.000000e+00*S251+0.000000e+00*S252+2.250210e+00*S253+0.000000e+00*S254+3.324699e-01*S255+0.000000e+00*S256+(-1.031092e+00)*S257+(-1.667427e-02)*S258+(-6.896026e-01)*S259'
.param V90_part27='V90_part26+(-1.340587e+00)*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+(-1.883291e+00)*S265+0.000000e+00*S266+1.694569e+01*S267+3.372969e+00*S268+0.000000e+00*S269'
.param V90_part28='V90_part27+0.000000e+00*S270+0.000000e+00*S271+(-2.027266e+00)*S272+2.216444e+00*S273+(-1.051486e+00)*S274+(-1.436395e+00)*S275+0.000000e+00*S276+(-3.133957e+00)*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V90_part29='V90_part28+1.537511e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+(-8.401298e+00)*S284+1.500363e-01*S285+(-2.004925e+00)*S286+0.000000e+00*S287+2.583367e+00*S288+1.257411e+00*S289'
.param V90_part30='V90_part29+0.000000e+00*S290+9.835101e-01*S291+0.000000e+00*S292+(-8.541569e+00)*S293+(-1.740076e+01)*S294+0.000000e+00*S295+(-8.903992e+00)*S296+1.000000e+04*S297+(-1.828479e+00)*S298+(-1.047990e+01)*S299'
.param V90_part31='V90_part30+0.000000e+00*S300+4.540042e-01*S301+(-4.746350e-02)*S302+8.937215e-01*S303+0.000000e+00*S304+(-1.133012e-01)*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V90='V90_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V91_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V91_part2='V91_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.345310e-01*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V91_part3='V91_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-6.941299e-03)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V91_part4='V91_part3+0.000000e+00*S30+6.307429e-01*S31+0.000000e+00*S32+0.000000e+00*S33+5.093759e-01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V91_part5='V91_part4+0.000000e+00*S40+2.984394e-01*S41+0.000000e+00*S42+1.940392e-01*S43+1.173378e-01*S44+(-8.987646e-03)*S45+2.840955e-01*S46+0.000000e+00*S47+7.643984e-01*S48+0.000000e+00*S49'
.param V91_part6='V91_part5+0.000000e+00*S50+4.074054e-01*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V91_part7='V91_part6+9.455063e-01*S60+0.000000e+00*S61+1.010883e-01*S62+0.000000e+00*S63+(-1.951785e-02)*S64+0.000000e+00*S65+(-3.922904e-01)*S66+3.121357e-01*S67+2.967517e-01*S68+0.000000e+00*S69'
.param V91_part8='V91_part7+7.579441e-02*S70+3.069292e-01*S71+0.000000e+00*S72+3.127273e-02*S73+5.163679e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V91_part9='V91_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V91_part10='V91_part9+4.368009e-01*S90+0.000000e+00*S91+0.000000e+00*S92+3.654394e-01*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V91_part11='V91_part10+0.000000e+00*S100+1.340686e+00*S101+0.000000e+00*S102+5.367643e-01*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V91_part12='V91_part11+0.000000e+00*S110+5.532552e-01*S111+5.508697e-01*S112+1.206606e+00*S113+7.129891e-01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V91_part13='V91_part12+0.000000e+00*S120+6.742286e-01*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V91_part14='V91_part13+0.000000e+00*S130+1.791532e+00*S131+0.000000e+00*S132+8.976378e-01*S133+2.087404e+00*S134+0.000000e+00*S135+1.117101e+01*S136+(-7.341430e-01)*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V91_part15='V91_part14+(-2.969239e-01)*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+1.862181e-01*S148+0.000000e+00*S149'
.param V91_part16='V91_part15+4.959948e-01*S150+5.124688e-01*S151+0.000000e+00*S152+9.343819e-01*S153+3.872472e-01*S154+1.263296e+00*S155+0.000000e+00*S156+0.000000e+00*S157+2.665378e+00*S158+0.000000e+00*S159'
.param V91_part17='V91_part16+1.518751e+00*S160+3.369119e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+(-3.413524e-01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V91_part18='V91_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+1.927603e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V91_part19='V91_part18+0.000000e+00*S180+5.086367e-01*S181+1.142162e+00*S182+0.000000e+00*S183+0.000000e+00*S184+2.112876e+00*S185+(-2.754285e+01)*S186+0.000000e+00*S187+0.000000e+00*S188+(-1.925235e+00)*S189'
.param V91_part20='V91_part19+2.317691e+00*S190+3.914493e+00*S191+1.229336e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+6.111630e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V91_part21='V91_part20+9.103566e-01*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+7.512830e-01*S206+(-1.290612e-02)*S207+3.773121e-01*S208+1.382529e+00*S209'
.param V91_part22='V91_part21+0.000000e+00*S210+2.922545e+00*S211+2.930029e+00*S212+1.109838e+01*S213+(-7.945015e-03)*S214+2.235162e+00*S215+0.000000e+00*S216+2.221431e+00*S217+2.592075e+00*S218+0.000000e+00*S219'
.param V91_part23='V91_part22+2.258065e+00*S220+5.986401e+00*S221+0.000000e+00*S222+2.591427e+00*S223+3.866292e+00*S224+(-6.637197e-01)*S225+0.000000e+00*S226+2.644450e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V91_part24='V91_part23+2.905245e+00*S230+0.000000e+00*S231+1.877862e+00*S232+0.000000e+00*S233+0.000000e+00*S234+2.429387e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V91_part25='V91_part24+0.000000e+00*S240+2.509939e+00*S241+2.031770e+00*S242+2.219239e+00*S243+2.810082e+00*S244+3.475380e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+2.531661e+00*S249'
.param V91_part26='V91_part25+2.463403e+00*S250+0.000000e+00*S251+0.000000e+00*S252+1.839248e+00*S253+0.000000e+00*S254+4.108288e-01*S255+0.000000e+00*S256+1.928513e+00*S257+3.940749e-01*S258+1.218735e+00*S259'
.param V91_part27='V91_part26+1.965606e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+3.252693e+00*S265+0.000000e+00*S266+3.162388e+01*S267+7.991509e-01*S268+0.000000e+00*S269'
.param V91_part28='V91_part27+0.000000e+00*S270+0.000000e+00*S271+3.537315e+00*S272+1.180246e+01*S273+1.029928e+00*S274+2.136189e+00*S275+0.000000e+00*S276+3.947798e+00*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V91_part29='V91_part28+5.621360e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+6.432664e+00*S284+(-2.885676e+00)*S285+3.710150e+00*S286+0.000000e+00*S287+(-2.054907e+00)*S288+1.247901e+00*S289'
.param V91_part30='V91_part29+0.000000e+00*S290+(-4.228120e-01)*S291+0.000000e+00*S292+7.425701e+00*S293+1.272524e+01*S294+0.000000e+00*S295+8.167449e+00*S296+1.000000e+04*S297+7.911325e-01*S298+8.326405e+00*S299'
.param V91_part31='V91_part30+0.000000e+00*S300+(-3.060268e-01)*S301+1.261807e+00*S302+7.355641e-01*S303+0.000000e+00*S304+1.605631e+00*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V91='V91_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V92_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V92_part2='V92_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-3.038811e-01)*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V92_part3='V92_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+4.664833e-01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V92_part4='V92_part3+0.000000e+00*S30+2.694513e-01*S31+0.000000e+00*S32+0.000000e+00*S33+3.260654e-01*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V92_part5='V92_part4+0.000000e+00*S40+1.711274e-01*S41+0.000000e+00*S42+9.857696e-01*S43+2.952894e-01*S44+(-1.727833e-01)*S45+(-7.044521e-02)*S46+0.000000e+00*S47+4.370950e+00*S48+0.000000e+00*S49'
.param V92_part6='V92_part5+0.000000e+00*S50+2.627517e-01*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V92_part7='V92_part6+(-5.273115e-02)*S60+0.000000e+00*S61+8.066304e-03*S62+0.000000e+00*S63+1.418488e+00*S64+0.000000e+00*S65+(-2.891419e-01)*S66+2.255296e-01*S67+3.074085e-01*S68+0.000000e+00*S69'
.param V92_part8='V92_part7+1.968572e-01*S70+5.723970e-01*S71+0.000000e+00*S72+5.442126e-01*S73+6.830953e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V92_part9='V92_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V92_part10='V92_part9+6.467771e-01*S90+0.000000e+00*S91+0.000000e+00*S92+3.560648e-02*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V92_part11='V92_part10+0.000000e+00*S100+8.469121e-01*S101+0.000000e+00*S102+8.272358e-01*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V92_part12='V92_part11+0.000000e+00*S110+4.924457e-01*S111+2.438815e-01*S112+7.704230e-01*S113+6.584918e-01*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V92_part13='V92_part12+0.000000e+00*S120+7.128954e-01*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V92_part14='V92_part13+0.000000e+00*S130+1.020623e+00*S131+0.000000e+00*S132+1.149761e+00*S133+1.680404e+00*S134+0.000000e+00*S135+(-1.789300e+02)*S136+(-2.080156e-01)*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V92_part15='V92_part14+1.680336e-01*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+(-2.096837e-01)*S148+0.000000e+00*S149'
.param V92_part16='V92_part15+4.816010e-01*S150+4.566047e-01*S151+0.000000e+00*S152+8.546696e-01*S153+9.094523e-01*S154+(-2.956625e-02)*S155+0.000000e+00*S156+0.000000e+00*S157+1.440203e+00*S158+0.000000e+00*S159'
.param V92_part17='V92_part16+3.852364e-01*S160+2.706471e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+5.847089e-01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V92_part18='V92_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+1.405615e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V92_part19='V92_part18+0.000000e+00*S180+1.273540e+00*S181+1.700427e-01*S182+0.000000e+00*S183+0.000000e+00*S184+1.623978e+00*S185+4.961215e+01*S186+0.000000e+00*S187+0.000000e+00*S188+(-1.157499e+01)*S189'
.param V92_part20='V92_part19+1.485723e+00*S190+3.187667e+00*S191+(-1.841230e+00)*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+5.422905e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V92_part21='V92_part20+1.190634e-01*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+6.081239e-01*S206+1.964518e+00*S207+(-1.395093e-02)*S208+1.049849e+00*S209'
.param V92_part22='V92_part21+0.000000e+00*S210+2.498326e+00*S211+5.966515e-01*S212+2.861546e+01*S213+(-2.835057e-01)*S214+1.166395e+00*S215+0.000000e+00*S216+3.825311e+00*S217+1.461450e+00*S218+0.000000e+00*S219'
.param V92_part23='V92_part22+3.708827e+00*S220+6.978901e+00*S221+0.000000e+00*S222+8.117498e+00*S223+7.720585e+00*S224+2.162191e+00*S225+0.000000e+00*S226+2.091360e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V92_part24='V92_part23+3.595222e+00*S230+0.000000e+00*S231+1.550070e+00*S232+0.000000e+00*S233+0.000000e+00*S234+3.163097e+00*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V92_part25='V92_part24+0.000000e+00*S240+2.124715e+00*S241+2.532134e+00*S242+(-1.836861e+00)*S243+2.166604e+00*S244+3.268785e+00*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+7.458171e+00*S249'
.param V92_part26='V92_part25+6.485518e-01*S250+0.000000e+00*S251+0.000000e+00*S252+(-3.115837e-01)*S253+0.000000e+00*S254+1.085774e+00*S255+0.000000e+00*S256+9.626638e-01*S257+6.171727e-01*S258+1.059874e+00*S259'
.param V92_part27='V92_part26+1.589402e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+4.721711e+00*S265+0.000000e+00*S266+(-5.834469e+01)*S267+(-1.866979e-02)*S268+0.000000e+00*S269'
.param V92_part28='V92_part27+0.000000e+00*S270+0.000000e+00*S271+3.216717e+00*S272+2.597058e+00*S273+4.346424e+00*S274+4.726363e+00*S275+0.000000e+00*S276+1.074492e+01*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V92_part29='V92_part28+(-2.384989e-01)*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+1.064857e+01*S284+2.092689e+01*S285+4.300129e+00*S286+0.000000e+00*S287+(-1.863819e+00)*S288+(-1.278471e+00)*S289'
.param V92_part30='V92_part29+0.000000e+00*S290+(-8.046811e-01)*S291+0.000000e+00*S292+1.013077e+01*S293+5.642891e+01*S294+0.000000e+00*S295+9.836626e+00*S296+1.000000e+04*S297+8.640459e+00*S298+1.194917e+01*S299'
.param V92_part31='V92_part30+0.000000e+00*S300+1.530378e-01*S301+1.457707e-03*S302+(-1.323861e-01)*S303+0.000000e+00*S304+5.677899e-03*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V92='V92_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V93_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V93_part2='V93_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.366736e-02*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V93_part3='V93_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-8.575686e-03)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V93_part4='V93_part3+0.000000e+00*S30+(-1.461716e-01)*S31+0.000000e+00*S32+0.000000e+00*S33+(-3.160269e-01)*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V93_part5='V93_part4+0.000000e+00*S40+(-2.382871e-01)*S41+0.000000e+00*S42+(-6.524550e-01)*S43+(-2.692618e-01)*S44+(-7.564263e-02)*S45+(-1.251351e-01)*S46+0.000000e+00*S47+6.377455e-01*S48+0.000000e+00*S49'
.param V93_part6='V93_part5+0.000000e+00*S50+(-2.455311e-01)*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V93_part7='V93_part6+(-3.887924e-02)*S60+0.000000e+00*S61+(-5.461176e-01)*S62+0.000000e+00*S63+6.701032e-01*S64+0.000000e+00*S65+(-2.980297e-01)*S66+(-1.590451e-01)*S67+(-8.471046e-02)*S68+0.000000e+00*S69'
.param V93_part8='V93_part7+(-4.769079e-02)*S70+8.937211e-03*S71+0.000000e+00*S72+4.534345e-02*S73+(-2.326150e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V93_part9='V93_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V93_part10='V93_part9+(-1.433158e-01)*S90+0.000000e+00*S91+0.000000e+00*S92+9.404895e-02*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V93_part11='V93_part10+0.000000e+00*S100+(-3.010022e-01)*S101+0.000000e+00*S102+(-6.298474e-02)*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V93_part12='V93_part11+0.000000e+00*S110+(-2.798218e-01)*S111+6.987852e-02*S112+(-3.156630e-01)*S113+(-3.033921e-01)*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V93_part13='V93_part12+0.000000e+00*S120+(-1.415350e-01)*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V93_part14='V93_part13+0.000000e+00*S130+(-3.136473e-01)*S131+0.000000e+00*S132+(-3.021181e-02)*S133+(-3.724167e-01)*S134+0.000000e+00*S135+(-1.548113e+01)*S136+(-1.846649e-02)*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V93_part15='V93_part14+1.455523e-02*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+(-1.382691e-02)*S148+0.000000e+00*S149'
.param V93_part16='V93_part15+(-2.021616e-01)*S150+(-2.015304e-01)*S151+0.000000e+00*S152+(-8.382660e-02)*S153+(-2.259577e-01)*S154+3.942070e-02*S155+0.000000e+00*S156+0.000000e+00*S157+(-2.539252e-01)*S158+0.000000e+00*S159'
.param V93_part17='V93_part16+(-5.151914e-02)*S160+(-1.458198e-01)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+(-1.154990e-01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V93_part18='V93_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+1.334420e-01*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V93_part19='V93_part18+0.000000e+00*S180+(-1.512342e-01)*S181+6.940202e-02*S182+0.000000e+00*S183+0.000000e+00*S184+(-3.979611e-01)*S185+3.866130e+00*S186+0.000000e+00*S187+0.000000e+00*S188+(-5.221759e-03)*S189'
.param V93_part20='V93_part19+(-3.681591e-01)*S190+(-4.265749e-02)*S191+(-1.123472e-01)*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-2.856288e-01)*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V93_part21='V93_part20+(-9.535526e-02)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+(-1.898371e-01)*S206+(-6.473279e-01)*S207+(-2.204695e-01)*S208+(-1.912304e-01)*S209'
.param V93_part22='V93_part21+0.000000e+00*S210+(-3.004208e-01)*S211+1.555796e-01*S212+5.094012e+01*S213+(-1.774676e-01)*S214+1.456181e-01*S215+0.000000e+00*S216+1.505965e-01*S217+1.490381e-01*S218+0.000000e+00*S219'
.param V93_part23='V93_part22+2.372818e-01*S220+4.506120e-02*S221+0.000000e+00*S222+3.784954e-01*S223+2.103701e-01*S224+(-1.957877e-02)*S225+0.000000e+00*S226+(-3.631592e-01)*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V93_part24='V93_part23+(-5.844229e-01)*S230+0.000000e+00*S231+(-4.051616e-01)*S232+0.000000e+00*S233+0.000000e+00*S234+(-6.350802e-01)*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V93_part25='V93_part24+0.000000e+00*S240+(-2.595713e-01)*S241+(-3.336904e-01)*S242+(-1.926264e-01)*S243+(-7.656788e-03)*S244+(-5.144399e-01)*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+2.063167e-01*S249'
.param V93_part26='V93_part25+1.631780e-01*S250+0.000000e+00*S251+0.000000e+00*S252+(-9.798685e-01)*S253+0.000000e+00*S254+(-8.262282e-02)*S255+0.000000e+00*S256+(-1.565668e-01)*S257+(-8.873423e-02)*S258+(-1.372659e-01)*S259'
.param V93_part27='V93_part26+(-2.795243e-01)*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+1.708380e-02*S265+0.000000e+00*S266+2.853226e+00*S267+(-5.731275e-01)*S268+0.000000e+00*S269'
.param V93_part28='V93_part27+0.000000e+00*S270+0.000000e+00*S271+(-3.806236e-01)*S272+(-2.937985e+00)*S273+(-8.162427e-02)*S274+(-7.153834e-01)*S275+0.000000e+00*S276+1.407060e-01*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V93_part29='V93_part28+(-3.173839e+00)*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+4.260878e-01*S284+(-6.391806e-01)*S285+1.806996e-01*S286+0.000000e+00*S287+(-2.256225e-01)*S288+(-4.086661e-01)*S289'
.param V93_part30='V93_part29+0.000000e+00*S290+8.182149e-02*S291+0.000000e+00*S292+1.889384e-01*S293+(-7.529758e-02)*S294+0.000000e+00*S295+8.992112e-02*S296+(-6.250000e+02)*S297+9.767518e-02*S298+2.310659e-01*S299'
.param V93_part31='V93_part30+0.000000e+00*S300+(-3.061784e-02)*S301+1.761720e-01*S302+2.660982e-01*S303+0.000000e+00*S304+1.517832e-01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V93='V93_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V94_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V94_part2='V94_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.329816e-03*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V94_part3='V94_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-4.184763e-03)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V94_part4='V94_part3+0.000000e+00*S30+7.625374e-03*S31+0.000000e+00*S32+0.000000e+00*S33+(-1.194790e-02)*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V94_part5='V94_part4+0.000000e+00*S40+2.882926e-03*S41+0.000000e+00*S42+(-1.352871e-01)*S43+(-2.756482e-02)*S44+(-1.781446e-02)*S45+(-1.741576e-02)*S46+0.000000e+00*S47+2.311968e-01*S48+0.000000e+00*S49'
.param V94_part6='V94_part5+0.000000e+00*S50+(-1.013224e-01)*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V94_part7='V94_part6+(-3.314494e-02)*S60+0.000000e+00*S61+(-3.712356e-02)*S62+0.000000e+00*S63+7.384638e-02*S64+0.000000e+00*S65+(-1.222608e-01)*S66+(-1.170051e-01)*S67+(-5.256365e-03)*S68+0.000000e+00*S69'
.param V94_part8='V94_part7+2.850350e-03*S70+8.520869e-03*S71+0.000000e+00*S72+1.913632e-03*S73+(-3.022548e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V94_part9='V94_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V94_part10='V94_part9+(-7.405576e-04)*S90+0.000000e+00*S91+0.000000e+00*S92+1.010835e-02*S93+0.000000e+00*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V94_part11='V94_part10+0.000000e+00*S100+4.968575e-02*S101+0.000000e+00*S102+3.718610e-02*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V94_part12='V94_part11+0.000000e+00*S110+1.208903e-01*S111+2.354861e-02*S112+4.491904e-02*S113+(-2.216686e-03)*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V94_part13='V94_part12+0.000000e+00*S120+(-5.986332e-02)*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V94_part14='V94_part13+0.000000e+00*S130+1.022958e-01*S131+0.000000e+00*S132+7.786680e-02*S133+1.086728e-01*S134+0.000000e+00*S135+(-2.057089e+01)*S136+(-3.788447e-02)*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V94_part15='V94_part14+(-4.588156e-03)*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+(-1.298164e-02)*S148+0.000000e+00*S149'
.param V94_part16='V94_part15+6.637989e-02*S150+2.596967e-02*S151+0.000000e+00*S152+5.379555e-02*S153+5.947073e-02*S154+9.364611e-02*S155+0.000000e+00*S156+0.000000e+00*S157+1.844185e-01*S158+0.000000e+00*S159'
.param V94_part17='V94_part16+7.019698e-02*S160+(-1.591156e-02)*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+2.349258e-03*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V94_part18='V94_part17+0.000000e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+(-3.969829e-01)*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V94_part19='V94_part18+0.000000e+00*S180+4.641005e-02*S181+1.117617e-01*S182+0.000000e+00*S183+0.000000e+00*S184+7.151100e-02*S185+1.326230e+01*S186+0.000000e+00*S187+0.000000e+00*S188+(-9.933095e-04)*S189'
.param V94_part20='V94_part19+(-1.445094e-01)*S190+(-4.261717e-01)*S191+(-1.173364e-01)*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+3.178499e-02*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V94_part21='V94_part20+4.007460e-02*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+7.278274e-02*S206+(-2.792284e-01)*S207+5.598271e-02*S208+9.435387e-02*S209'
.param V94_part22='V94_part21+0.000000e+00*S210+2.555622e-01*S211+3.724449e-01*S212+4.987883e-01*S213+7.542062e-02*S214+3.229873e-01*S215+0.000000e+00*S216+(-9.734785e-02)*S217+3.396968e-01*S218+0.000000e+00*S219'
.param V94_part23='V94_part22+(-4.442188e-01)*S220+(-3.391397e-01)*S221+0.000000e+00*S222+(-4.386811e-01)*S223+(-4.454857e-01)*S224+8.316355e-02*S225+0.000000e+00*S226+1.961047e-01*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V94_part24='V94_part23+1.097370e-02*S230+0.000000e+00*S231+(-2.466107e-01)*S232+0.000000e+00*S233+0.000000e+00*S234+(-1.370650e-01)*S235+0.000000e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V94_part25='V94_part24+0.000000e+00*S240+1.885600e-01*S241+4.976740e-02*S242+4.669998e-01*S243+(-9.575341e-02)*S244+(-1.371784e-01)*S245+0.000000e+00*S246+0.000000e+00*S247+0.000000e+00*S248+(-5.186434e-01)*S249'
.param V94_part26='V94_part25+(-6.904692e-02)*S250+0.000000e+00*S251+0.000000e+00*S252+(-2.526582e-01)*S253+0.000000e+00*S254+(-4.008523e-02)*S255+0.000000e+00*S256+1.194897e-01*S257+(-1.310260e-01)*S258+9.242966e-02*S259'
.param V94_part27='V94_part26+2.227813e-01*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+(-2.628527e-01)*S265+0.000000e+00*S266+5.283072e+01*S267+(-7.513079e-01)*S268+0.000000e+00*S269'
.param V94_part28='V94_part27+0.000000e+00*S270+0.000000e+00*S271+3.600734e-01*S272+9.696219e-01*S273+(-1.026550e-01)*S274+(-2.153123e-01)*S275+0.000000e+00*S276+(-6.284874e-01)*S277+0.000000e+00*S278+0.000000e+00*S279'
.param V94_part29='V94_part28+4.316055e-01*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+(-2.225995e-01)*S284+4.289449e-01*S285+3.059725e-02*S286+0.000000e+00*S287+3.191138e-01*S288+(-3.709410e-01)*S289'
.param V94_part30='V94_part29+0.000000e+00*S290+(-7.073294e-02)*S291+0.000000e+00*S292+1.534633e-01*S293+3.145788e-01*S294+0.000000e+00*S295+(-9.117591e-02)*S296+1.000000e+04*S297+(-7.451342e-01)*S298+(-8.122811e-02)*S299'
.param V94_part31='V94_part30+0.000000e+00*S300+(-9.058580e-02)*S301+2.799820e-01*S302+(-4.060449e-01)*S303+0.000000e+00*S304+4.258004e-01*S305+0.000000e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V94='V94_part31+0.000000e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V95_part1='8.330194e+00*S0+5.683779e+00*S1+(-8.744891e-01)*S2+5.241503e+03*S3+6.154652e+00*S4+2.898353e+01*S5+(-4.640330e+01)*S6+1.900219e+00*S7+6.342381e+00*S8+3.994434e+01*S9'
.param V95_part2='V95_part1+1.743414e+02*S10+5.609854e+00*S11+1.071121e+01*S12+1.173322e+01*S13+5.880665e+00*S14+3.374309e+01*S15+2.404441e+00*S16+2.903658e+00*S17+7.535845e+03*S18+9.459793e+00*S19'
.param V95_part3='V95_part2+3.393775e+00*S20+1.000520e+00*S21+(-3.233008e+01)*S22+6.182742e+00*S23+8.735146e-01*S24+9.323303e+00*S25+6.922772e+00*S26+1.968511e+01*S27+1.091101e+01*S28+2.848197e+00*S29'
.param V95_part4='V95_part3+8.879211e+00*S30+(-3.532150e+03)*S31+3.852879e+01*S32+2.462951e+01*S33+1.134112e+01*S34+1.648244e+00*S35+1.165448e+03*S36+0.000000e+00*S37+2.623058e+03*S38+2.002040e+03*S39'
.param V95_part5='V95_part4+3.097977e+03*S40+1.963408e+02*S41+1.000000e+04*S42+4.319678e+00*S43+1.233141e+01*S44+2.409730e+02*S45+2.029907e+01*S46+1.521486e+01*S47+(-9.996855e+02)*S48+1.249982e+03*S49'
.param V95_part6='V95_part5+4.869497e+00*S50+2.655915e+01*S51+0.000000e+00*S52+1.010254e+01*S53+(-3.868515e+02)*S54+(-5.479728e-01)*S55+6.131333e+00*S56+1.140960e+03*S57+3.742064e-02*S58+4.186778e+00*S59'
.param V95_part7='V95_part6+1.076233e+02*S60+1.670682e+02*S61+3.462676e+00*S62+9.848727e+00*S63+1.268840e+01*S64+4.936688e+00*S65+1.448489e+00*S66+8.395542e+00*S67+5.564634e-01*S68+(-9.919629e+00)*S69'
.param V95_part8='V95_part7+2.573064e+03*S70+2.605852e+03*S71+1.487258e+00*S72+2.665038e+03*S73+4.191023e+00*S74+0.000000e+00*S75+1.151932e+01*S76+(-5.606023e+01)*S77+1.473217e+00*S78+(-9.528377e+01)*S79'
.param V95_part9='V95_part8+4.343056e+00*S80+1.435605e+00*S81+8.929463e+00*S82+6.387875e+00*S83+(-1.140793e-01)*S84+1.629158e+01*S85+5.543077e+00*S86+5.219849e+00*S87+1.519657e+01*S88+3.300728e+00*S89'
.param V95_part10='V95_part9+1.156467e+02*S90+2.936598e+00*S91+2.485221e+00*S92+0.000000e+00*S93+5.168823e-01*S94+4.143749e+00*S95+3.744811e+00*S96+4.386042e+00*S97+(-5.211631e+02)*S98+7.864153e+00*S99'
.param V95_part11='V95_part10+3.798415e+00*S100+5.892005e+00*S101+4.600448e+00*S102+4.917175e+00*S103+(-2.091891e-01)*S104+0.000000e+00*S105+0.000000e+00*S106+5.562431e+00*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V95_part12='V95_part11+2.364504e+03*S110+9.223838e+00*S111+1.179598e+03*S112+5.559585e+00*S113+8.021223e+00*S114+8.409671e+00*S115+(-3.255952e-01)*S116+0.000000e+00*S117+2.696550e+01*S118+(-9.972291e+00)*S119'
.param V95_part13='V95_part12+8.286669e+00*S120+4.540564e+02*S121+8.139427e+00*S122+1.395780e+01*S123+7.144186e+00*S124+5.180876e+00*S125+1.309450e+01*S126+1.116350e+01*S127+3.190943e+00*S128+8.153947e+00*S129'
.param V95_part14='V95_part13+9.216775e+00*S130+4.385233e+00*S131+2.745274e-01*S132+3.948463e+00*S133+3.880918e+00*S134+9.212071e+00*S135+1.514658e+01*S136+3.743479e+01*S137+5.778250e+01*S138+3.310081e+01*S139'
.param V95_part15='V95_part14+4.104913e+01*S140+(-9.998066e+02)*S141+5.523550e+01*S142+1.251851e+02*S143+6.192116e+00*S144+4.973484e+01*S145+2.854778e+01*S146+0.000000e+00*S147+2.069228e+01*S148+9.441623e+00*S149'
.param V95_part16='V95_part15+3.328262e+02*S150+1.491435e+01*S151+6.320979e+00*S152+3.913242e+00*S153+1.503134e+03*S154+5.893971e+00*S155+4.892558e+00*S156+(-1.418862e+02)*S157+4.729811e+00*S158+(-4.111824e+00)*S159'
.param V95_part17='V95_part16+1.100633e-02*S160+1.804832e+00*S161+3.072737e+00*S162+(-2.483090e+02)*S163+3.255780e+00*S164+(-4.972131e+01)*S165+1.744418e+03*S166+(-4.682120e+03)*S167+0.000000e+00*S168+1.043029e+01*S169'
.param V95_part18='V95_part17+(-4.640321e+03)*S170+(-9.756458e-02)*S171+(-4.697440e+03)*S172+(-3.825287e+03)*S173+(-2.262706e-01)*S174+6.041968e+02*S175+(-2.025038e+01)*S176+2.237474e+00*S177+(-1.625510e+01)*S178+1.612440e+01*S179'
.param V95_part19='V95_part18+(-2.832083e-01)*S180+2.857167e+02*S181+(-9.524184e-02)*S182+0.000000e+00*S183+7.105573e+00*S184+6.332428e+00*S185+8.161388e+00*S186+6.416898e+00*S187+(-2.125655e+01)*S188+4.255491e+00*S189'
.param V95_part20='V95_part19+4.364509e+00*S190+8.715763e-01*S191+(-4.073058e+00)*S192+(-1.465848e+01)*S193+4.695015e+01*S194+0.000000e+00*S195+2.850544e+01*S196+5.706707e+01*S197+5.236335e+00*S198+1.111307e+01*S199'
.param V95_part21='V95_part20+7.017238e+00*S200+1.303206e+01*S201+1.085895e+01*S202+6.650140e+00*S203+(-2.021552e+03)*S204+1.192257e+01*S205+4.561312e+00*S206+(-4.209688e+01)*S207+4.256953e+00*S208+3.761199e+00*S209'
.param V95_part22='V95_part21+0.000000e+00*S210+2.494321e+02*S211+2.962562e+00*S212+2.838462e+01*S213+0.000000e+00*S214+4.155261e+00*S215+3.210113e+00*S216+3.133830e+00*S217+3.000440e+00*S218+(-3.173220e+01)*S219'
.param V95_part23='V95_part22+1.632232e-01*S220+8.026577e-01*S221+1.854262e+00*S222+8.839822e-01*S223+9.006548e-02*S224+0.000000e+00*S225+1.428298e+01*S226+5.931915e+00*S227+(-2.943698e+00)*S228+(-6.417045e+00)*S229'
.param V95_part24='V95_part23+5.621770e+00*S230+5.172096e+02*S231+4.294009e+00*S232+(-7.579571e+01)*S233+0.000000e+00*S234+2.944737e+00*S235+1.000000e+04*S236+0.000000e+00*S237+(-1.415336e+03)*S238+3.463632e+03*S239'
.param V95_part25='V95_part24+2.885524e+00*S240+6.492302e+00*S241+7.568349e+00*S242+9.425119e-01*S243+3.317769e+00*S244+4.116083e+00*S245+3.106625e+01*S246+9.481159e+00*S247+(-4.258808e+03)*S248+(-8.001399e+01)*S249'
.param V95_part26='V95_part25+1.598291e+00*S250+(-1.636599e+02)*S251+(-3.511582e+01)*S252+2.097189e+00*S253+(-3.387412e+03)*S254+(-4.978076e+03)*S255+5.494042e+00*S256+1.336041e+01*S257+7.840108e+01*S258+1.107504e+01*S259'
.param V95_part27='V95_part26+7.565759e+00*S260+2.905090e+00*S261+(-7.266919e+00)*S262+(-1.610119e+01)*S263+0.000000e+00*S264+2.799443e+00*S265+3.803464e+01*S266+1.494416e+00*S267+1.611589e+00*S268+(-8.140692e+02)*S269'
.param V95_part28='V95_part27+4.521870e+00*S270+6.141223e+00*S271+5.868683e+00*S272+3.061970e+00*S273+7.757596e+00*S274+4.310963e+00*S275+0.000000e+00*S276+1.106603e+00*S277+6.029999e+03*S278+(-4.252130e+02)*S279'
.param V95_part29='V95_part28+2.353928e+00*S280+7.521696e+02*S281+(-1.134340e+00)*S282+9.836054e+03*S283+6.165316e-01*S284+8.356435e+00*S285+2.960593e+00*S286+(-4.916821e+03)*S287+5.027902e+00*S288+6.988861e+00*S289'
.param V95_part30='V95_part29+(-2.883573e+02)*S290+(-1.529903e+02)*S291+(-1.180640e+03)*S292+1.599716e+00*S293+3.176840e+00*S294+(-4.966282e+03)*S295+6.813958e-01*S296+(-9.975254e+02)*S297+1.985675e-01*S298+7.127687e-01*S299'
.param V95_part31='V95_part30+5.900966e+00*S300+6.851557e+00*S301+3.651439e+00*S302+0.000000e+00*S303+3.056688e+00*S304+2.992497e+00*S305+1.780504e+00*S306+7.752789e+00*S307+8.198619e+01*S308+2.249635e+00*S309'
.param V95='V95_part31+5.596868e+00*S310+4.327083e+01*S311+(-9.993899e+02)*S312+8.283216e+00*S313+2.794586e+01*S314'
.param V96_part1='9.185959e+03*S0+8.497322e+00*S1+5.990878e+00*S2+(-3.016554e+03)*S3+4.708094e+00*S4+8.191196e+00*S5+1.486845e+02*S6+3.975090e+00*S7+(-3.187659e+00)*S8+(-1.822482e+01)*S9'
.param V96_part2='V96_part1+(-1.051700e+02)*S10+(-6.588660e+00)*S11+(-3.376402e+00)*S12+(-5.833014e-01)*S13+5.332346e+00*S14+(-1.152968e+01)*S15+1.018925e+01*S16+1.309789e+01*S17+4.420877e+01*S18+6.558822e+00*S19'
.param V96_part3='V96_part2+2.527478e+00*S20+7.395294e+01*S21+5.570480e+01*S22+1.886076e+00*S23+5.580584e+01*S24+(-4.739355e+00)*S25+5.033143e+00*S26+(-2.503290e+00)*S27+(-2.336572e+00)*S28+5.274151e+00*S29'
.param V96_part4='V96_part3+3.929688e+01*S30+(-6.576074e+01)*S31+(-1.475714e+01)*S32+2.533142e+01*S33+(-7.045878e+00)*S34+(-1.939728e-01)*S35+9.438505e+02*S36+0.000000e+00*S37+(-2.973749e+02)*S38+2.596440e+02*S39'
.param V96_part5='V96_part4+3.097977e+03*S40+(-1.063938e+01)*S41+1.281099e+02*S42+(-4.929647e-01)*S43+(-6.231883e-01)*S44+(-3.480322e+02)*S45+(-1.735430e+01)*S46+(-4.766179e-01)*S47+(-6.178209e-01)*S48+3.921216e+00*S49'
.param V96_part6='V96_part5+9.210348e+00*S50+(-1.434465e+01)*S51+0.000000e+00*S52+2.578268e-01*S53+(-4.904903e-01)*S54+1.103397e+00*S55+3.650306e-01*S56+2.701641e+01*S57+2.527058e-01*S58+6.406952e-01*S59'
.param V96_part7='V96_part6+(-2.005173e+01)*S60+3.236366e+01*S61+2.176208e+00*S62+(-4.197778e+00)*S63+(-7.620648e+00)*S64+1.787486e+00*S65+5.490536e-01*S66+(-2.781628e+00)*S67+(-9.001989e-01)*S68+8.896528e-02*S69'
.param V96_part8='V96_part7+(-5.543283e+01)*S70+(-2.472857e+02)*S71+(-5.573853e-01)*S72+(-4.647100e+01)*S73+(-1.214616e+00)*S74+0.000000e+00*S75+(-1.295990e+01)*S76+1.703259e+02*S77+9.567042e-01*S78+9.154380e+01*S79'
.param V96_part9='V96_part8+(-2.133571e+00)*S80+(-1.690270e-01)*S81+(-1.054067e+00)*S82+(-1.678835e+00)*S83+1.176929e+00*S84+(-8.367589e-01)*S85+(-1.115207e+00)*S86+(-5.388481e-01)*S87+(-6.542072e-01)*S88+(-6.996048e-02)*S89'
.param V96_part10='V96_part9+2.107252e+02*S90+4.848486e+00*S91+1.565269e+00*S92+0.000000e+00*S93+4.384822e+00*S94+1.493909e+00*S95+6.297967e+00*S96+2.033968e+00*S97+(-3.705668e+01)*S98+5.160445e+00*S99'
.param V96_part11='V96_part10+(-6.149785e-01)*S100+(-2.771707e+00)*S101+(-9.669730e-01)*S102+(-1.688531e+00)*S103+5.599928e-01*S104+0.000000e+00*S105+0.000000e+00*S106+4.303398e-01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V96_part12='V96_part11+1.429399e+02*S110+(-1.076618e+00)*S111+3.883967e+02*S112+(-2.909783e+00)*S113+(-2.281359e+00)*S114+1.162217e+00*S115+5.876414e-01*S116+0.000000e+00*S117+1.546813e+02*S118+1.071677e+01*S119'
.param V96_part13='V96_part12+1.520083e+00*S120+(-2.943623e+01)*S121+(-1.722472e+00)*S122+1.976683e+00*S123+(-1.208626e+00)*S124+(-1.701170e+00)*S125+(-1.291545e+00)*S126+(-3.653073e+00)*S127+2.518706e-01*S128+3.867235e+00*S129'
.param V96_part14='V96_part13+(-3.523217e+00)*S130+(-6.944927e-01)*S131+(-2.186531e-01)*S132+(-7.166734e-01)*S133+(-5.948802e-01)*S134+(-2.414474e+00)*S135+1.585543e+02*S136+(-2.560527e+00)*S137+1.381990e+01*S138+2.338893e+01*S139'
.param V96_part15='V96_part14+(-1.248496e+01)*S140+(-8.492718e-01)*S141+2.653756e-01*S142+6.381610e-01*S143+1.140966e+01*S144+1.305687e+01*S145+(-7.472813e-01)*S146+0.000000e+00*S147+7.726038e+00*S148+(-2.238233e+00)*S149'
.param V96_part16='V96_part15+6.036528e+01*S150+(-2.976774e+00)*S151+1.784096e+00*S152+2.923420e+00*S153+3.254910e+01*S154+1.475267e+00*S155+(-9.387743e-01)*S156+(-5.456135e+01)*S157+(-1.503705e+00)*S158+(-1.526179e+00)*S159'
.param V96_part17='V96_part16+4.920109e-01*S160+6.103951e-02*S161+1.092628e+00*S162+(-7.137651e+00)*S163+9.310584e-01*S164+6.706544e+01*S165+1.605504e+01*S166+(-7.108666e+01)*S167+0.000000e+00*S168+(-3.212746e+01)*S169'
.param V96_part18='V96_part17+(-2.787952e+02)*S170+(-2.466067e-01)*S171+(-1.200995e+02)*S172+6.888378e+01*S173+5.734882e-01*S174+4.864917e+02*S175+3.203992e+01*S176+(-3.152039e-01)*S177+3.364358e+00*S178+2.674621e+01*S179'
.param V96_part19='V96_part18+1.117867e+01*S180+(-9.207360e+00)*S181+6.674120e-01*S182+0.000000e+00*S183+(-1.426311e+00)*S184+(-1.816317e+00)*S185+(-7.904009e-01)*S186+(-2.125550e+00)*S187+2.959387e+01*S188+(-1.683159e+00)*S189'
.param V96_part20='V96_part19+(-2.063420e+00)*S190+6.969250e-02*S191+(-1.869332e-01)*S192+(-4.562424e+00)*S193+6.423134e-01*S194+0.000000e+00*S195+(-1.153719e+01)*S196+(-1.801426e+00)*S197+2.407087e+00*S198+2.228879e+00*S199'
.param V96_part21='V96_part20+(-2.355844e+00)*S200+4.950592e+00*S201+(-3.023996e+00)*S202+(-1.794703e+00)*S203+7.627755e+01*S204+(-5.591775e+00)*S205+(-8.998160e-01)*S206+1.858539e+02*S207+(-4.268219e-01)*S208+(-1.982401e-01)*S209'
.param V96_part22='V96_part21+0.000000e+00*S210+2.008330e+03*S211+1.346390e-01*S212+9.444903e+00*S213+0.000000e+00*S214+2.126239e-01*S215+(-9.683772e-04)*S216+(-9.836856e-01)*S217+1.057006e+00*S218+(-1.210387e+00)*S219'
.param V96_part23='V96_part22+9.710817e-02*S220+(-1.743282e-02)*S221+4.424965e-01*S222+(-1.147091e-01)*S223+4.523258e-02*S224+0.000000e+00*S225+1.399432e+01*S226+(-2.515055e+00)*S227+(-2.586472e-01)*S228+2.083795e+00*S229'
.param V96_part24='V96_part23+(-6.946322e-01)*S230+3.651399e+01*S231+(-2.314613e+00)*S232+(-1.126837e+02)*S233+0.000000e+00*S234+(-7.565248e-01)*S235+(-2.276321e+02)*S236+0.000000e+00*S237+(-2.283067e+01)*S238+(-3.739972e+01)*S239'
.param V96_part25='V96_part24+6.527202e+00*S240+(-3.415454e+00)*S241+(-3.598465e-01)*S242+(-7.360408e+00)*S243+(-1.303133e+00)*S244+(-7.774812e-01)*S245+4.478541e+00*S246+4.364884e+00*S247+(-2.452315e+00)*S248+(-1.588693e+00)*S249'
.param V96_part26='V96_part25+(-5.543609e-01)*S250+(-2.555946e-01)*S251+(-2.484621e+00)*S252+(-6.828522e-01)*S253+(-1.861587e+01)*S254+2.574489e+02*S255+2.069977e-01*S256+(-5.006602e-01)*S257+2.102136e+01*S258+(-5.101162e+00)*S259'
.param V96_part27='V96_part26+(-1.533326e+00)*S260+1.300284e+00*S261+(-1.370103e+01)*S262+3.181992e+01*S263+0.000000e+00*S264+(-1.212191e+00)*S265+1.988266e+00*S266+1.198450e-01*S267+(-6.353830e-01)*S268+(-2.493987e+00)*S269'
.param V96_part28='V96_part27+(-5.764160e+00)*S270+(-2.646596e+00)*S271+(-1.736329e+00)*S272+(-1.695578e-01)*S273+(-3.985798e+00)*S274+(-1.356888e+00)*S275+0.000000e+00*S276+(-2.552019e-01)*S277+3.679519e+03*S278+(-2.786498e+00)*S279'
.param V96_part29='V96_part28+9.637935e-02*S280+9.588342e+00*S281+(-8.273851e+00)*S282+4.973616e+03*S283+(-3.552059e-02)*S284+7.968535e+00*S285+(-1.429986e+00)*S286+5.138889e+01*S287+7.552222e+00*S288+5.487373e+00*S289'
.param V96_part30='V96_part29+8.382276e+00*S290+(-5.508805e+00)*S291+1.902085e+01*S292+2.242106e-01*S293+2.489093e-01*S294+5.855075e+00*S295+3.832477e-02*S296+(-2.591590e+00)*S297+(-6.304561e-01)*S298+4.265389e-02*S299'
.param V96_part31='V96_part30+(-3.060273e+00)*S300+(-1.097646e+00)*S301+7.839428e-01*S302+0.000000e+00*S303+(-3.790189e+00)*S304+5.803169e-01*S305+6.210872e-01*S306+7.791912e+00*S307+(-7.902613e-01)*S308+6.352638e-01*S309'
.param V96='V96_part31+8.265717e+00*S310+8.940727e-01*S311+(-5.594379e-01)*S312+3.906257e+00*S313+(-2.155165e-01)*S314'
.param V97_part1='(-4.584158e+02)*S0+3.223849e+00*S1+4.533975e+00*S2+(-2.822668e+03)*S3+(-1.526282e+00)*S4+(-2.407616e+00)*S5+4.627687e+01*S6+3.402105e+00*S7+3.187402e+00*S8+(-8.085921e+00)*S9'
.param V97_part2='V97_part1+(-5.098247e+01)*S10+7.550074e+00*S11+2.897573e-02*S12+(-6.864856e-01)*S13+9.454728e-01*S14+(-2.609986e+01)*S15+(-1.636426e+00)*S16+4.766351e+00*S17+(-4.143292e+01)*S18+(-5.048881e+00)*S19'
.param V97_part3='V97_part2+1.017267e+01*S20+(-1.331862e+01)*S21+9.622194e+01*S22+2.152344e+00*S23+(-6.825240e+01)*S24+(-3.097277e+00)*S25+8.001017e+00*S26+(-1.843704e+01)*S27+5.111456e+00*S28+9.737762e+00*S29'
.param V97_part4='V97_part3+9.865765e+00*S30+9.868769e+03*S31+(-2.092971e+01)*S32+2.038118e+01*S33+(-6.728225e+00)*S34+(-8.401128e-01)*S35+2.188443e+03*S36+0.000000e+00*S37+1.581193e+02*S38+4.852134e+01*S39'
.param V97_part5='V97_part4+3.097977e+03*S40+(-1.688423e+02)*S41+2.677538e+02*S42+(-3.603343e+00)*S43+(-7.558284e+00)*S44+(-1.713012e+02)*S45+(-1.035441e+01)*S46+(-6.589139e+00)*S47+1.000000e+04*S48+4.517529e+00*S49'
.param V97_part6='V97_part5+2.430446e-02*S50+(-7.149339e+00)*S51+0.000000e+00*S52+2.712031e-02*S53+3.872161e+03*S54+(-2.066217e-01)*S55+2.610480e-02*S56+(-3.790258e-01)*S57+(-1.831498e-02)*S58+7.972617e-03*S59'
.param V97_part7='V97_part6+(-7.003003e+01)*S60+(-7.335255e+01)*S61+3.403601e+00*S62+(-9.199125e+00)*S63+(-7.020872e+00)*S64+(-3.353993e+00)*S65+(-2.598252e+00)*S66+(-4.116842e+00)*S67+1.006591e+02*S68+9.983852e+01*S69'
.param V97_part8='V97_part7+5.213630e+01*S70+2.122795e+02*S71+(-1.149477e+00)*S72+(-1.159985e+02)*S73+(-1.576563e+00)*S74+0.000000e+00*S75+(-5.297217e-01)*S76+9.771254e+00*S77+(-4.279112e-01)*S78+(-1.460922e+01)*S79'
.param V97_part9='V97_part8+(-1.818463e-01)*S80+(-1.229289e+00)*S81+(-2.801124e+00)*S82+(-1.486699e+00)*S83+1.658509e-01*S84+(-3.560626e+00)*S85+(-1.422474e+00)*S86+(-5.786585e+00)*S87+1.667065e+01*S88+(-1.169364e+00)*S89'
.param V97_part10='V97_part9+(-2.963690e+02)*S90+(-5.043747e+00)*S91+(-2.645111e+00)*S92+0.000000e+00*S93+(-2.335615e+00)*S94+(-4.687752e+00)*S95+(-1.360763e+01)*S96+(-7.064883e+00)*S97+(-4.111005e+02)*S98+(-2.106161e+01)*S99'
.param V97_part11='V97_part10+(-4.053576e+00)*S100+(-1.667516e+00)*S101+(-5.636609e+00)*S102+(-3.099372e+00)*S103+3.288160e-02*S104+0.000000e+00*S105+0.000000e+00*S106+(-6.181583e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V97_part12='V97_part11+(-2.366612e+03)*S110+(-1.041648e+01)*S111+(-1.157256e+03)*S112+(-1.375352e+00)*S113+(-7.046597e+00)*S114+1.647709e-01*S115+8.806078e-02*S116+0.000000e+00*S117+(-4.034359e+01)*S118+(-4.174651e+00)*S119'
.param V97_part13='V97_part12+(-1.429761e+01)*S120+1.329271e+01*S121+(-3.054867e+00)*S122+(-1.974065e+01)*S123+(-5.491603e+00)*S124+(-2.652381e+00)*S125+(-2.037837e+01)*S126+(-7.994205e+00)*S127+(-2.063948e+00)*S128+(-2.344937e+01)*S129'
.param V97_part14='V97_part13+(-7.155980e+00)*S130+(-2.358944e+00)*S131+1.227726e+00*S132+(-1.675370e+00)*S133+(-2.070027e+00)*S134+(-1.206076e+01)*S135+(-3.891074e+01)*S136+(-2.448741e+01)*S137+(-9.122437e+01)*S138+(-2.234748e+01)*S139'
.param V97_part15='V97_part14+3.179111e-01*S140+1.000000e+04*S141+(-2.416341e+01)*S142+(-8.216918e+01)*S143+(-1.111464e+01)*S144+(-1.558529e+01)*S145+(-1.509387e+01)*S146+0.000000e+00*S147+(-1.685967e+01)*S148+(-5.010895e+00)*S149'
.param V97_part16='V97_part15+(-1.372738e+02)*S150+(-1.166810e+01)*S151+(-6.431047e+00)*S152+(-7.385761e+00)*S153+4.716673e+01*S154+(-6.153012e+00)*S155+(-6.472584e+00)*S156+4.526982e+02*S157+(-2.390283e+00)*S158+2.626269e+01*S159'
.param V97_part17='V97_part16+1.899932e-01*S160+(-1.165259e+00)*S161+(-1.846121e+00)*S162+5.772620e+02*S163+(-3.046811e+00)*S164+(-1.754419e+02)*S165+(-4.134361e+01)*S166+(-2.388060e+02)*S167+0.000000e+00*S168+(-4.775695e-01)*S169'
.param V97_part18='V97_part17+(-1.602440e+02)*S170+4.881153e+00*S171+(-2.634925e+02)*S172+(-1.148042e+03)*S173+9.419445e-02*S174+6.199955e+02*S175+(-4.428052e+01)*S176+(-2.065068e+00)*S177+4.449067e+01*S178+(-3.473722e+01)*S179'
.param V97_part19='V97_part18+(-4.781901e+00)*S180+2.064872e+03*S181+(-2.717785e-02)*S182+0.000000e+00*S183+(-5.575380e+00)*S184+(-2.610901e+00)*S185+(-1.305951e+01)*S186+(-4.813244e+00)*S187+9.458073e+00*S188+(-6.425392e+00)*S189'
.param V97_part20='V97_part19+(-1.631627e+00)*S190+(-4.330094e-01)*S191+3.698618e-01*S192+6.319023e+01*S193+(-4.385674e+01)*S194+0.000000e+00*S195+(-1.717706e+01)*S196+(-4.202678e+01)*S197+(-8.334342e+00)*S198+(-7.590964e+00)*S199'
.param V97_part21='V97_part20+(-3.223541e+00)*S200+(-3.091981e+01)*S201+(-8.901127e+00)*S202+(-3.630158e+00)*S203+1.000000e+04*S204+(-6.877679e+00)*S205+(-2.327821e+00)*S206+(-9.950862e+01)*S207+(-1.961137e+00)*S208+(-2.342459e+00)*S209'
.param V97_part22='V97_part21+0.000000e+00*S210+(-1.000042e+03)*S211+(-2.660573e+00)*S212+(-5.977378e+01)*S213+0.000000e+00*S214+(-3.724956e+00)*S215+(-5.241733e+00)*S216+(-2.803490e+00)*S217+(-3.137565e+00)*S218+3.300675e+02*S219'
.param V97_part23='V97_part22+3.010958e-01*S220+(-3.999744e-01)*S221+(-2.533636e+00)*S222+(-2.086278e-01)*S223+2.792023e-01*S224+0.000000e+00*S225+(-2.036287e+01)*S226+(-3.005025e+00)*S227+3.150990e+01*S228+1.933138e+01*S229'
.param V97_part24='V97_part23+(-3.468296e+00)*S230+(-1.232228e+03)*S231+(-1.416088e+00)*S232+4.422301e+02*S233+0.000000e+00*S234+(-1.718087e+00)*S235+(-1.319065e+02)*S236+0.000000e+00*S237+1.000000e+04*S238+(-8.864181e+02)*S239'
.param V97_part25='V97_part24+(-8.816797e+00)*S240+(-4.685157e+00)*S241+(-4.977658e+00)*S242+3.144414e+01*S243+(-2.395227e+00)*S244+(-2.188892e+00)*S245+(-5.353662e+01)*S246+(-1.358941e+01)*S247+(-5.279395e+01)*S248+8.196259e+02*S249'
.param V97_part26='V97_part25+(-1.153458e+00)*S250+(-7.149538e+01)*S251+3.757015e+02*S252+(-1.235745e+00)*S253+(-5.226954e+01)*S254+(-1.867746e+01)*S255+(-1.348348e+00)*S256+(-9.730526e+00)*S257+(-1.879358e+02)*S258+(-8.199291e+00)*S259'
.param V97_part27='V97_part26+(-4.527331e+00)*S260+(-4.958520e+00)*S261+4.536074e+01*S262+(-4.306041e+02)*S263+0.000000e+00*S264+(-1.286556e+00)*S265+(-3.631649e+01)*S266+(-1.022331e+00)*S267+(-5.808289e-01)*S268+(-2.801524e+01)*S269'
.param V97_part28='V97_part27+(-4.622840e+00)*S270+(-6.712027e+00)*S271+(-3.454726e+00)*S272+(-4.315813e+00)*S273+(-6.702179e+00)*S274+(-2.125283e+00)*S275+0.000000e+00*S276+(-3.860022e-01)*S277+5.579672e+03*S278+4.275577e+03*S279'
.param V97_part29='V97_part28+(-2.272529e+00)*S280+(-3.375052e+01)*S281+5.435623e+01*S282+(-1.000000e+04)*S283+(-8.630007e-02)*S284+(-1.990132e+01)*S285+(-2.046895e+00)*S286+(-5.380678e+01)*S287+(-1.676827e+01)*S288+(-1.284718e+01)*S289'
.param V97_part30='V97_part29+(-1.855432e+01)*S290+1.559316e+03*S291+5.400937e+01*S292+(-1.051087e+00)*S293+(-4.739350e+00)*S294+(-3.735210e+01)*S295+(-1.796357e-01)*S296+1.000000e+04*S297+1.467708e+00*S298+(-1.848075e-01)*S299'
.param V97_part31='V97_part30+(-1.004681e+01)*S300+(-5.239071e+00)*S301+(-2.706882e+00)*S302+0.000000e+00*S303+(-9.099921e-01)*S304+(-2.411851e+00)*S305+(-2.318174e+00)*S306+(-1.558206e+01)*S307+(-7.587560e+01)*S308+(-3.527212e+00)*S309'
.param V97='V97_part31+(-1.533460e+01)*S310+(-4.038929e+01)*S311+1.000000e+04*S312+(-1.530865e+01)*S313+(-2.561613e+01)*S314'
.param V98_part1='1.556686e+01*S0+2.612142e+01*S1+8.501742e+00*S2+1.000000e+04*S3+1.650153e+01*S4+(-1.078893e+00)*S5+(-3.543695e+01)*S6+9.015619e+00*S7+6.240187e+00*S8+3.319781e+01*S9'
.param V98_part2='V98_part1+(-6.523254e+00)*S10+6.289371e+00*S11+5.871145e+00*S12+3.080397e+00*S13+2.059703e+01*S14+5.711231e+01*S15+7.172600e+00*S16+2.720220e+01*S17+(-1.000000e+04)*S18+1.162024e+01*S19'
.param V98_part3='V98_part2+3.150122e+01*S20+(-4.240978e+00)*S21+(-9.523829e+00)*S22+1.560404e+01*S23+3.839115e+01*S24+7.064326e+00*S25+3.737162e+01*S26+4.136827e+00*S27+2.193580e+01*S28+3.089123e+01*S29'
.param V98_part4='V98_part3+5.258300e+01*S30+1.701858e+03*S31+3.762823e+01*S32+1.064520e+02*S33+(-5.210679e-02)*S34+(-3.979548e-01)*S35+6.533571e+03*S36+0.000000e+00*S37+1.000000e+04*S38+1.084327e+03*S39'
.param V98_part5='V98_part4+1.350899e+02*S40+(-1.653995e+00)*S41+1.423680e+03*S42+1.083199e-01*S43+(-1.736669e-01)*S44+1.796292e+01*S45+7.092489e-01*S46+1.425468e+00*S47+9.293465e-04*S48+5.009349e+03*S49'
.param V98_part6='V98_part5+5.413092e-01*S50+(-6.448729e+00)*S51+0.000000e+00*S52+(-1.354767e+01)*S53+(-1.115495e-01)*S54+3.037418e-01*S55+(-8.344335e+00)*S56+(-1.528669e+03)*S57+(-7.210151e-02)*S58+(-6.033432e+00)*S59'
.param V98_part7='V98_part6+1.534178e+02*S60+(-1.131021e+02)*S61+1.124677e+00*S62+(-1.167528e+00)*S63+(-2.421695e+00)*S64+3.751915e-01*S65+(-5.186775e-01)*S66+(-2.374569e-01)*S67+1.650342e+02*S68+(-2.171189e-02)*S69'
.param V98_part8='V98_part7+1.000000e+04*S70+1.000000e+04*S71+(-4.650601e-01)*S72+1.000000e+04*S73+5.137838e-02*S74+0.000000e+00*S75+1.261679e+01*S76+(-2.989255e+00)*S77+6.420062e+00*S78+(-1.374759e+01)*S79'
.param V98_part9='V98_part8+2.608512e+00*S80+1.704625e-01*S81+(-1.922670e+00)*S82+(-5.869275e-01)*S83+4.011255e-02*S84+(-9.334999e+00)*S85+(-3.430280e-01)*S86+1.807141e+00*S87+5.905942e+01*S88+(-1.233677e-01)*S89'
.param V98_part10='V98_part9+(-6.891896e+00)*S90+2.317104e+00*S91+(-3.033154e-01)*S92+0.000000e+00*S93+(-3.367929e-01)*S94+2.361770e-02*S95+3.084191e-01*S96+5.765386e-02*S97+(-1.875694e+01)*S98+2.087695e-01*S99'
.param V98_part11='V98_part10+1.158950e-01*S100+(-2.485560e-01)*S101+(-2.416456e-01)*S102+(-5.161689e-03)*S103+9.360331e-03*S104+0.000000e+00*S105+0.000000e+00*S106+1.039128e-01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V98_part12='V98_part11+(-2.278798e+01)*S110+(-8.081971e-01)*S111+1.307047e+01*S112+(-5.245782e-02)*S113+8.710963e-02*S114+(-1.120858e+01)*S115+8.246734e-02*S116+0.000000e+00*S117+(-1.105165e+02)*S118+2.520802e+00*S119'
.param V98_part13='V98_part12+(-7.892479e-02)*S120+(-5.210225e+02)*S121+(-1.050727e+00)*S122+(-4.876510e+00)*S123+(-1.782020e+00)*S124+(-5.676313e-01)*S125+(-1.336817e+00)*S126+(-1.255922e+00)*S127+(-4.454833e-01)*S128+(-9.624882e-01)*S129'
.param V98_part14='V98_part13+(-9.979494e-01)*S130+(-3.998156e-01)*S131+(-2.634800e-02)*S132+(-4.128787e-02)*S133+(-2.429869e-01)*S134+3.198811e+00*S135+5.175669e-01*S136+(-7.013109e+00)*S137+(-9.174235e+00)*S138+(-2.038509e+01)*S139'
.param V98_part15='V98_part14+5.166339e+01*S140+(-6.406539e-02)*S141+(-3.434617e+01)*S142+(-3.751770e+01)*S143+(-3.779806e+00)*S144+(-4.243346e+01)*S145+(-8.043651e+00)*S146+0.000000e+00*S147+(-1.067916e+01)*S148+(-3.920838e-02)*S149'
.param V98_part16='V98_part15+2.324701e+00*S150+8.077363e-01*S151+5.408215e-03*S152+(-1.112624e+00)*S153+(-5.782149e+00)*S154+2.051273e-02*S155+3.596904e-02*S156+6.751807e-01*S157+(-2.139661e-01)*S158+(-3.486251e-01)*S159'
.param V98_part17='V98_part16+7.036143e-02*S160+(-9.842404e-02)*S161+(-2.289354e-01)*S162+4.704753e+00*S163+6.192739e-01*S164+(-2.216172e+00)*S165+8.644032e-01*S166+(-1.637453e+00)*S167+0.000000e+00*S168+2.746462e-01*S169'
.param V98_part18='V98_part17+(-1.562646e+00)*S170+(-3.855339e-02)*S171+1.203381e+01*S172+(-1.500803e+01)*S173+4.563557e-02*S174+(-8.091108e+03)*S175+2.482405e-02*S176+(-2.075899e-02)*S177+(-6.665350e-01)*S178+(-7.429858e-01)*S179'
.param V98_part19='V98_part18+(-2.961778e-01)*S180+(-1.227685e+03)*S181+1.387015e-01*S182+0.000000e+00*S183+(-1.089670e+00)*S184+(-1.715836e-02)*S185+(-4.335979e-01)*S186+(-8.095508e-02)*S187+(-5.972126e-01)*S188+(-2.460737e-01)*S189'
.param V98_part20='V98_part19+(-2.238234e-01)*S190+1.589868e-02*S191+(-7.065607e-02)*S192+1.500823e+00*S193+(-6.426045e-02)*S194+0.000000e+00*S195+7.574885e+00*S196+(-4.538424e+00)*S197+(-3.628313e-01)*S198+(-3.115022e+00)*S199'
.param V98_part21='V98_part20+(-2.539741e-01)*S200+(-3.053911e+00)*S201+(-1.161213e+00)*S202+(-3.666838e-01)*S203+(-9.531631e+00)*S204+(-1.641493e-01)*S205+(-2.943171e-01)*S206+(-3.925428e-02)*S207+(-2.806531e-01)*S208+(-1.784362e-01)*S209'
.param V98_part22='V98_part21+0.000000e+00*S210+6.799162e-02*S211+2.196851e-02*S212+1.297173e+00*S213+0.000000e+00*S214+6.984726e-02*S215+(-3.458977e-01)*S216+6.705666e-02*S217+7.625305e-02*S218+(-9.435018e-02)*S219'
.param V98_part23='V98_part22+8.244406e-02*S220+(-3.127406e-03)*S221+(-6.680217e-02)*S222+1.663306e-02*S223+3.086130e-02*S224+0.000000e+00*S225+(-4.319680e-01)*S226+(-7.409566e-03)*S227+(-1.038129e-02)*S228+(-2.155316e+00)*S229'
.param V98_part24='V98_part23+2.258914e-03*S230+1.167073e+02*S231+(-5.875405e-01)*S232+(-1.564298e+01)*S233+0.000000e+00*S234+(-2.885294e-01)*S235+1.000000e+04*S236+0.000000e+00*S237+1.000000e+04*S238+1.000000e+04*S239'
.param V98_part25='V98_part24+(-9.331085e-01)*S240+(-2.867282e-01)*S241+(-4.863100e-02)*S242+(-8.849936e-01)*S243+(-1.854323e-01)*S244+(-1.514567e-01)*S245+(-1.421925e+00)*S246+(-6.286497e-01)*S247+(-3.947299e+00)*S248+3.034119e-01*S249'
.param V98_part26='V98_part25+1.622751e-01*S250+(-4.593592e+00)*S251+(-4.020945e-02)*S252+(-1.408114e-01)*S253+(-5.732188e+00)*S254+(-3.869322e+01)*S255+(-2.937686e+01)*S256+(-4.749499e-01)*S257+(-5.835224e+00)*S258+(-1.952777e-01)*S259'
.param V98_part27='V98_part26+(-2.537552e-01)*S260+(-8.933532e-01)*S261+(-1.667223e+00)*S262+(-1.007845e+01)*S263+0.000000e+00*S264+(-3.387531e-01)*S265+(-5.261648e-01)*S266+(-4.304118e-01)*S267+(-3.017050e-01)*S268+(-6.664944e+00)*S269'
.param V98_part28='V98_part27+(-5.643208e-01)*S270+5.070564e-01*S271+(-6.163024e-02)*S272+(-2.302219e-01)*S273+4.820745e-01*S274+(-8.713716e-02)*S275+0.000000e+00*S276+9.237835e-05*S277+(-3.007446e+03)*S278+(-8.978808e-02)*S279'
.param V98_part29='V98_part28+(-4.137871e-01)*S280+2.506442e+00*S281+(-3.592802e-02)*S282+(-1.000000e+04)*S283+2.845669e-02*S284+(-9.374865e-02)*S285+5.514529e-02*S286+(-8.796754e+00)*S287+1.425057e-01*S288+3.015638e-01*S289'
.param V98_part30='V98_part29+(-4.449538e+00)*S290+(-4.068920e-02)*S291+(-5.635429e+00)*S292+(-1.500760e-02)*S293+(-1.479879e-02)*S294+(-3.787874e+00)*S295+8.867099e-03*S296+9.541427e-02*S297+3.557139e-02*S298+9.651104e-03*S299'
.param V98_part31='V98_part30+(-7.154054e-01)*S300+(-3.943423e-01)*S301+(-2.426293e-03)*S302+0.000000e+00*S303+(-8.521712e-01)*S304+(-9.450629e-03)*S305+(-6.512285e-01)*S306+(-1.124794e+00)*S307+(-4.378028e-01)*S308+(-3.565745e-01)*S309'
.param V98='V98_part31+(-8.954136e-01)*S310+(-2.366936e-01)*S311+(-2.028407e-01)*S312+(-8.039624e-01)*S313+(-2.616537e-02)*S314'
.param V99_part1='(-8.699606e+02)*S0+2.568424e-01*S1+6.988808e-02*S2+(-2.564888e-01)*S3+6.525380e-02*S4+(-2.228829e-01)*S5+1.587878e-01*S6+2.502690e-02*S7+(-1.356611e-02)*S8+1.350528e-01*S9'
.param V99_part2='V99_part1+(-8.418141e-02)*S10+1.158636e-01*S11+6.586319e-02*S12+1.024166e-02*S13+2.310270e-01*S14+(-7.140303e-02)*S15+(-5.598678e-02)*S16+3.873154e-01*S17+7.908718e-01*S18+(-1.872084e-01)*S19'
.param V99_part3='V99_part2+8.061487e-02*S20+(-1.425654e+00)*S21+(-1.874718e+00)*S22+3.709986e-02*S23+2.289697e+00*S24+(-3.707676e-02)*S25+(-5.776121e-02)*S26+(-1.439701e-01)*S27+(-1.294177e-01)*S28+(-8.119661e-02)*S29'
.param V99_part4='V99_part3+1.459775e+00*S30+1.661718e+02*S31+8.263821e-02*S32+2.029109e+00*S33+5.002404e-02*S34+(-8.785925e-03)*S35+(-1.262255e+02)*S36+0.000000e+00*S37+9.746258e+00*S38+(-1.214698e+03)*S39'
.param V99_part5='V99_part4+3.097977e+03*S40+2.002151e+00*S41+(-6.492435e+03)*S42+2.771412e-01*S43+9.826889e-02*S44+(-8.024304e+00)*S45+2.324679e-01*S46+2.412871e+00*S47+5.611260e-02*S48+1.602157e+00*S49'
.param V99_part6='V99_part5+6.465587e-01*S50+1.040517e+01*S51+0.000000e+00*S52+(-1.333294e-03)*S53+1.021771e-01*S54+1.406427e-01*S55+4.113678e-03*S56+3.330373e+00*S57+(-1.726984e-02)*S58+8.131358e-04*S59'
.param V99_part7='V99_part6+(-7.581806e+00)*S60+(-4.754508e+00)*S61+2.093805e+00*S62+6.003429e-01*S63+1.763802e+00*S64+4.873971e-01*S65+(-1.915947e-01)*S66+9.284306e-02*S67+2.331352e+00*S68+1.013738e-03*S69'
.param V99_part8='V99_part7+6.919650e+00*S70+2.536763e+01*S71+6.839016e-01*S72+5.610728e+00*S73+3.984353e-01*S74+0.000000e+00*S75+1.802566e-01*S76+3.500088e+01*S77+2.394333e-01*S78+2.077327e+02*S79'
.param V99_part9='V99_part8+(-1.701849e-01)*S80+3.432714e-01*S81+3.230761e-01*S82+1.673550e-01*S83+2.741593e-01*S84+4.733004e-01*S85+2.785511e-01*S86+2.523083e-01*S87+(-3.515957e-01)*S88+5.284361e-02*S89'
.param V99_part10='V99_part9+(-1.957722e+00)*S90+7.880050e-02*S91+2.260315e-01*S92+0.000000e+00*S93+3.038685e-01*S94+1.481272e-01*S95+(-8.645305e-01)*S96+(-1.359186e-01)*S97+2.151708e+03*S98+(-1.707087e+00)*S99'
.param V99_part11='V99_part10+(-8.832313e-02)*S100+(-1.257596e-01)*S101+1.196409e+00*S102+(-2.024748e-02)*S103+1.077417e-02*S104+0.000000e+00*S105+0.000000e+00*S106+5.168330e-01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V99_part12='V99_part11+1.304929e+01*S110+(-1.071679e+00)*S111+5.060108e+00*S112+(-1.263310e-01)*S113+(-7.119610e-01)*S114+(-1.630994e-01)*S115+1.521668e-02*S116+0.000000e+00*S117+(-6.819201e+00)*S118+2.702423e+01*S119'
.param V99_part13='V99_part12+2.576202e+00*S120+(-5.717111e+00)*S121+(-1.980814e-01)*S122+(-2.645781e-01)*S123+(-2.614562e-01)*S124+(-3.681247e-02)*S125+(-4.674259e-01)*S126+(-3.706618e-01)*S127+1.365214e-01*S128+(-1.225322e-01)*S129'
.param V99_part14='V99_part13+(-2.367235e-01)*S130+2.228785e-02*S131+2.534582e-01*S132+7.438172e-02*S133+(-1.604282e-02)*S134+6.646497e-01*S135+(-5.644088e+00)*S136+7.390901e-01*S137+(-4.052744e+00)*S138+8.969989e-01*S139'
.param V99_part15='V99_part14+(-1.370089e+00)*S140+3.122442e-01*S141+9.714564e-01*S142+3.162280e+00*S143+(-1.882503e-01)*S144+9.631170e-01*S145+3.772101e-01*S146+0.000000e+00*S147+6.925515e-01*S148+(-3.959758e-02)*S149'
.param V99_part16='V99_part15+(-1.743610e+02)*S150+(-1.598136e-01)*S151+2.015018e-01*S152+(-3.882561e-01)*S153+(-9.690309e+02)*S154+2.946018e-01*S155+1.155630e-01*S156+6.396122e+01*S157+(-1.252174e-02)*S158+6.863266e+00*S159'
.param V99_part17='V99_part16+3.151202e-02*S160+1.773802e-01*S161+(-7.500851e-01)*S162+9.117707e+01*S163+6.153851e+00*S164+2.692261e+02*S165+(-1.088967e+03)*S166+1.000000e+04*S167+0.000000e+00*S168+5.691291e+01*S169'
.param V99_part18='V99_part17+1.000000e+04*S170+3.642320e-01*S171+1.000000e+04*S172+1.000000e+04*S173+1.824237e-02*S174+1.000000e+04*S175+1.088681e+02*S176+4.495447e-01*S177+3.083332e+00*S178+3.719046e+00*S179'
.param V99_part19='V99_part18+2.299289e-01*S180+7.672570e+01*S181+3.915173e-02*S182+0.000000e+00*S183+(-3.768483e-01)*S184+(-2.822435e-02)*S185+4.352180e-01*S186+(-3.653648e-01)*S187+1.314949e+01*S188+2.615701e-01*S189'
.param V99_part20='V99_part19+2.409733e-01*S190+1.702260e-02*S191+9.036459e+00*S192+2.069007e-01*S193+1.635478e+00*S194+0.000000e+00*S195+(-2.678676e+00)*S196+(-8.441560e-01)*S197+2.890124e-02*S198+3.857439e-01*S199'
.param V99_part21='V99_part20+(-1.809640e-01)*S200+2.268105e+00*S201+(-4.816035e-01)*S202+(-3.775090e-02)*S203+6.281648e+01*S204+(-7.077520e-01)*S205+(-9.772621e-04)*S206+(-4.460478e+01)*S207+(-3.145122e-01)*S208+(-2.717065e-02)*S209'
.param V99_part22='V99_part21+0.000000e+00*S210+(-6.272569e-01)*S211+1.236762e-01*S212+2.856097e-01*S213+0.000000e+00*S214+1.842006e-01*S215+3.353722e-01*S216+7.075297e-01*S217+1.218014e-01*S218+1.058672e+00*S219'
.param V99_part23='V99_part22+(-7.049934e-03)*S220+5.587428e-02*S221+2.418851e-01*S222+5.371922e-03*S223+2.369104e-02*S224+0.000000e+00*S225+2.476354e+00*S226+(-1.973936e-01)*S227+1.060558e+00*S228+6.724613e+00*S229'
.param V99_part24='V99_part23+1.395587e-01*S230+6.974442e-01*S231+2.540191e-01*S232+1.416673e+01*S233+0.000000e+00*S234+2.397512e-01*S235+(-4.746315e+03)*S236+0.000000e+00*S237+(-2.844111e+01)*S238+5.569079e+01*S239'
.param V99_part25='V99_part24+(-2.058590e-02)*S240+(-3.965759e-01)*S241+(-2.602423e-01)*S242+1.917965e+00*S243+(-1.058062e-01)*S244+1.327048e-01*S245+(-3.087479e+00)*S246+1.584217e+00*S247+8.687888e+03*S248+1.400597e-01*S249'
.param V99_part26='V99_part25+2.310093e-01*S250+5.151698e+02*S251+1.990615e+00*S252+2.102729e-01*S253+6.957664e+03*S254+1.000000e+04*S255+5.906035e+01*S256+(-1.388405e-03)*S257+(-2.583832e+00)*S258+(-3.857139e-01)*S259'
.param V99_part27='V99_part26+(-1.510289e-01)*S260+5.843340e-01*S261+7.940199e+00*S262+9.243463e+02*S263+0.000000e+00*S264+3.422774e-01*S265+2.318096e+00*S266+3.255691e-01*S267+1.329985e-01*S268+1.723119e+03*S269'
.param V99_part28='V99_part27+2.010607e-01*S270+1.677850e-01*S271+(-1.346168e-01)*S272+1.822923e-01*S273+6.455028e-01*S274+(-2.834766e-02)*S275+0.000000e+00*S276+8.063840e-02*S277+1.000000e+04*S278+2.488580e+00*S279'
.param V99_part29='V99_part28+1.599114e-01*S280+1.506775e+00*S281+3.059321e+00*S282+7.784682e+03*S283+6.157788e-03*S284+7.334295e-01*S285+(-1.099833e-02)*S286+1.000000e+04*S287+2.520448e-01*S288+2.141475e+00*S289'
.param V99_part30='V99_part29+6.551653e+02*S290+9.576325e-01*S291+2.350059e+03*S292+(-2.186410e-02)*S293+1.636855e-01*S294+1.000000e+04*S295+1.836198e-02*S296+3.085180e+00*S297+1.309939e-02*S298+2.172533e-02*S299'
.param V99_part31='V99_part30+3.758471e+00*S300+(-3.388481e-01)*S301+1.989935e-01*S302+0.000000e+00*S303+6.827064e-01*S304+1.483885e-01*S305+4.625534e-01*S306+4.513411e+00*S307+2.623862e-02*S308+2.694006e-01*S309'
.param V99='V99_part31+4.891766e+00*S310+9.008684e-02*S311+1.568820e+00*S312+4.141741e+00*S313+(-3.833323e-02)*S314'
.param V100_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+1.537355e-03*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V100_part2='V100_part1+0.000000e+00*S10+2.163875e-01*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+2.585043e-01*S15+0.000000e+00*S16+0.000000e+00*S17+1.773074e-01*S18+0.000000e+00*S19'
.param V100_part3='V100_part2+0.000000e+00*S20+1.064080e-01*S21+5.746935e-02*S22+1.110715e-01*S23+0.000000e+00*S24+1.048094e-01*S25+7.233420e-02*S26+2.031105e-03*S27+1.462150e-01*S28+2.148226e-01*S29'
.param V100_part4='V100_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V100_part5='V100_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+1.187964e-01*S49'
.param V100_part6='V100_part5+2.612850e-02*S50+0.000000e+00*S51+0.000000e+00*S52+(-2.002878e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+6.317374e-02*S56+3.697167e-01*S57+0.000000e+00*S58+4.500731e-01*S59'
.param V100_part7='V100_part6+9.309948e-02*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-5.661125e-01)*S65+7.025334e-01*S66+1.845958e-01*S67+6.462926e-04*S68+0.000000e+00*S69'
.param V100_part8='V100_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+9.730600e-01*S78+0.000000e+00*S79'
.param V100_part9='V100_part8+4.280405e-01*S80+0.000000e+00*S81+3.066207e-01*S82+5.455196e-01*S83+0.000000e+00*S84+4.115231e-01*S85+6.054296e-01*S86+3.971705e-01*S87+4.934000e-01*S88+(-4.003236e-01)*S89'
.param V100_part10='V100_part9+0.000000e+00*S90+(-6.413619e-01)*S91+(-5.721882e-01)*S92+(-4.277989e-01)*S93+(-2.403791e-02)*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V100_part11='V100_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+2.707198e-01*S106+6.975126e+00*S107+0.000000e+00*S108+1.215059e+03*S109'
.param V100_part12='V100_part11+0.000000e+00*S110+(-5.337009e-02)*S111+1.810110e+03*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+(-6.893103e-01)*S119'
.param V100_part13='V100_part12+0.000000e+00*S120+2.913556e-02*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V100_part14='V100_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V100_part15='V100_part14+1.974143e-01*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+6.115314e-02*S148+0.000000e+00*S149'
.param V100_part16='V100_part15+0.000000e+00*S150+5.428761e-02*S151+0.000000e+00*S152+(-1.087391e-01)*S153+0.000000e+00*S154+(-3.954335e-01)*S155+0.000000e+00*S156+(-6.745920e-01)*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V100_part17='V100_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+(-9.399136e-01)*S163+(-3.011492e+00)*S164+0.000000e+00*S165+1.535453e-01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V100_part18='V100_part17+(-1.914477e+00)*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+(-6.368333e-01)*S176+5.983366e-01*S177+(-1.667393e+00)*S178+(-1.985757e+00)*S179'
.param V100_part19='V100_part18+1.680130e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+(-1.426465e+00)*S188+2.826959e-01*S189'
.param V100_part20='V100_part19+0.000000e+00*S190+2.042127e+00*S191+4.712080e+00*S192+(-8.486090e-01)*S193+(-4.875548e+00)*S194+0.000000e+00*S195+0.000000e+00*S196+1.051829e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V100_part21='V100_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+9.623379e-01*S208+0.000000e+00*S209'
.param V100_part22='V100_part21+0.000000e+00*S210+0.000000e+00*S211+(-7.016623e-01)*S212+0.000000e+00*S213+1.000000e+04*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+2.111711e-01*S219'
.param V100_part23='V100_part22+0.000000e+00*S220+(-3.401750e+00)*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V100_part24='V100_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+(-2.469804e+00)*S233+0.000000e+00*S234+0.000000e+00*S235+(-2.891655e+00)*S236+0.000000e+00*S237+(-5.085336e-01)*S238+(-5.186827e+00)*S239'
.param V100_part25='V100_part24+0.000000e+00*S240+(-4.637159e-02)*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+(-1.835285e+00)*S247+(-2.543381e+00)*S248+(-4.484466e-01)*S249'
.param V100_part26='V100_part25+1.549116e+00*S250+(-3.124572e+00)*S251+0.000000e+00*S252+2.164978e-01*S253+(-4.808085e+00)*S254+3.119778e-01*S255+2.112971e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V100_part27='V100_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+(-2.859997e+00)*S266+1.088989e+00*S267+2.007654e-01*S268+(-1.765822e+00)*S269'
.param V100_part28='V100_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+4.586272e-01*S273+0.000000e+00*S274+0.000000e+00*S275+8.235198e+03*S276+1.017545e+00*S277+(-2.278059e+00)*S278+0.000000e+00*S279'
.param V100_part29='V100_part28+0.000000e+00*S280+(-2.014706e+00)*S281+(-9.818815e+00)*S282+(-1.227271e+00)*S283+0.000000e+00*S284+1.418339e-01*S285+0.000000e+00*S286+0.000000e+00*S287+4.427672e-01*S288+(-5.445092e-01)*S289'
.param V100_part30='V100_part29+(-2.196625e+00)*S290+0.000000e+00*S291+(-4.621358e-01)*S292+0.000000e+00*S293+4.540381e-01*S294+(-9.941903e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+2.465387e+00*S299'
.param V100_part31='V100_part30+0.000000e+00*S300+7.670248e-01*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+7.624918e-01*S305+0.000000e+00*S306+(-1.615143e+00)*S307+(-4.165969e+00)*S308+0.000000e+00*S309'
.param V100='V100_part31+(-1.373155e+00)*S310+(-6.292289e+00)*S311+6.179103e-01*S312+(-9.389563e-01)*S313+(-9.584809e+00)*S314'
.param V101_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+9.602225e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V101_part2='V101_part1+0.000000e+00*S10+5.627462e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+2.033131e-01*S15+0.000000e+00*S16+0.000000e+00*S17+1.330833e-02*S18+0.000000e+00*S19'
.param V101_part3='V101_part2+0.000000e+00*S20+3.612863e-03*S21+1.299754e-01*S22+4.528886e-02*S23+0.000000e+00*S24+3.953445e-02*S25+8.554031e-02*S26+1.677989e-01*S27+2.436686e-02*S28+(-4.315247e-02)*S29'
.param V101_part4='V101_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V101_part5='V101_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+7.649587e-02*S49'
.param V101_part6='V101_part5+9.195507e-02*S50+0.000000e+00*S51+0.000000e+00*S52+5.019539e-01*S53+0.000000e+00*S54+0.000000e+00*S55+4.007133e-01*S56+3.449689e-01*S57+0.000000e+00*S58+1.719985e-03*S59'
.param V101_part7='V101_part6+8.299392e-01*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+7.018653e-01*S65+(-9.914537e-02)*S66+1.854194e-01*S67+7.897288e-02*S68+0.000000e+00*S69'
.param V101_part8='V101_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+(-3.019935e-03)*S78+0.000000e+00*S79'
.param V101_part9='V101_part8+3.636613e-02*S80+0.000000e+00*S81+2.317646e-01*S82+(-2.955707e-02)*S83+0.000000e+00*S84+9.551694e-02*S85+(-3.609099e-02)*S86+3.128034e-01*S87+3.794709e-02*S88+1.002197e+00*S89'
.param V101_part10='V101_part9+0.000000e+00*S90+1.366612e+00*S91+5.329559e-02*S92+4.812526e+00*S93+3.092144e-01*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V101_part11='V101_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+4.566505e-01*S106+(-8.588793e+00)*S107+0.000000e+00*S108+1.658783e+02*S109'
.param V101_part12='V101_part11+0.000000e+00*S110+2.463462e-01*S111+2.936822e+02*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+8.944780e-01*S119'
.param V101_part13='V101_part12+0.000000e+00*S120+2.464903e-01*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V101_part14='V101_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V101_part15='V101_part14+(-2.286933e-01)*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+2.658646e-01*S148+0.000000e+00*S149'
.param V101_part16='V101_part15+0.000000e+00*S150+2.646147e-01*S151+0.000000e+00*S152+7.669632e-01*S153+0.000000e+00*S154+1.984429e-01*S155+0.000000e+00*S156+9.742468e-01*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V101_part17='V101_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+1.673216e+00*S163+2.977264e+00*S164+0.000000e+00*S165+(-4.296630e-01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V101_part18='V101_part17+2.763129e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+7.537295e-01*S176+1.222540e+00*S177+2.524104e+00*S178+2.020169e+00*S179'
.param V101_part19='V101_part18+(-3.305605e+00)*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+1.830035e+00*S188+3.805712e-01*S189'
.param V101_part20='V101_part19+0.000000e+00*S190+(-4.244570e-01)*S191+5.831372e+00*S192+1.973842e+00*S193+3.297992e+00*S194+0.000000e+00*S195+0.000000e+00*S196+1.462298e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V101_part21='V101_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+(-8.065315e-01)*S208+0.000000e+00*S209'
.param V101_part22='V101_part21+0.000000e+00*S210+0.000000e+00*S211+2.488797e+00*S212+0.000000e+00*S213+8.923398e+03*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+1.211158e+00*S219'
.param V101_part23='V101_part22+0.000000e+00*S220+5.206745e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V101_part24='V101_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+2.780279e+00*S233+0.000000e+00*S234+0.000000e+00*S235+2.853767e+00*S236+0.000000e+00*S237+1.876484e+00*S238+4.081813e+00*S239'
.param V101_part25='V101_part24+0.000000e+00*S240+4.251501e-01*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+2.925759e+00*S247+3.131661e+00*S248+2.440310e-01*S249'
.param V101_part26='V101_part25+5.959240e-02*S250+3.088112e+00*S251+0.000000e+00*S252+1.050128e+00*S253+4.371087e+00*S254+1.103249e-01*S255+(-1.461207e-01)*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V101_part27='V101_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+2.799988e+00*S266+1.490838e+00*S267+1.773802e+00*S268+2.700320e+00*S269'
.param V101_part28='V101_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+8.025389e-01*S273+0.000000e+00*S274+0.000000e+00*S275+8.357415e+03*S276+(-1.174939e+00)*S277+2.717526e+00*S278+0.000000e+00*S279'
.param V101_part29='V101_part28+0.000000e+00*S280+2.325761e+00*S281+1.434065e+00*S282+3.204142e+00*S283+0.000000e+00*S284+1.130867e+00*S285+0.000000e+00*S286+0.000000e+00*S287+2.062745e+00*S288+2.669346e+00*S289'
.param V101_part30='V101_part29+3.025407e+00*S290+0.000000e+00*S291+2.579804e+00*S292+0.000000e+00*S293+1.321361e+00*S294+3.204298e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+(-8.520572e-02)*S299'
.param V101_part31='V101_part30+0.000000e+00*S300+(-1.484660e+00)*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-3.940983e-01)*S305+0.000000e+00*S306+2.980638e+00*S307+3.986757e+00*S308+0.000000e+00*S309'
.param V101='V101_part31+2.488488e+00*S310+4.916908e+00*S311+1.724336e+00*S312+1.968819e+00*S313+6.580580e+00*S314'
.param V102_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+5.000428e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V102_part2='V102_part1+0.000000e+00*S10+(-2.069651e-01)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+1.852284e-01*S15+0.000000e+00*S16+0.000000e+00*S17+(-3.536612e-01)*S18+0.000000e+00*S19'
.param V102_part3='V102_part2+0.000000e+00*S20+(-1.284607e-01)*S21+(-8.811474e-02)*S22+6.075567e-02*S23+0.000000e+00*S24+5.739173e-03*S25+9.085937e-02*S26+6.531823e-02*S27+4.211202e-02*S28+6.088477e-02*S29'
.param V102_part4='V102_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V102_part5='V102_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+4.166201e-01*S49'
.param V102_part6='V102_part5+1.978224e-02*S50+0.000000e+00*S51+0.000000e+00*S52+2.500284e-01*S53+0.000000e+00*S54+0.000000e+00*S55+2.227390e-01*S56+(-5.870727e-02)*S57+0.000000e+00*S58+1.553769e-01*S59'
.param V102_part7='V102_part6+(-1.747443e-01)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+1.264618e+00*S65+7.568840e-01*S66+1.087042e-01*S67+4.171743e-02*S68+0.000000e+00*S69'
.param V102_part8='V102_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+(-7.933653e-01)*S78+0.000000e+00*S79'
.param V102_part9='V102_part8+5.413461e-02*S80+0.000000e+00*S81+3.690145e-02*S82+2.718896e-02*S83+0.000000e+00*S84+5.025740e-02*S85+1.890131e-02*S86+(-1.010959e-01)*S87+(-6.937822e-02)*S88+3.763763e-01*S89'
.param V102_part10='V102_part9+0.000000e+00*S90+1.424333e+00*S91+1.231156e+00*S92+(-2.105396e+00)*S93+4.343568e-01*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V102_part11='V102_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+3.141267e-01*S106+4.358377e+00*S107+0.000000e+00*S108+6.319951e+02*S109'
.param V102_part12='V102_part11+0.000000e+00*S110+(-1.770166e-01)*S111+1.529019e+03*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+2.111957e+00*S119'
.param V102_part13='V102_part12+0.000000e+00*S120+3.024485e-01*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V102_part14='V102_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V102_part15='V102_part14+5.904262e-03*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+(-3.041163e-01)*S148+0.000000e+00*S149'
.param V102_part16='V102_part15+0.000000e+00*S150+2.298229e-01*S151+0.000000e+00*S152+8.060073e-01*S153+0.000000e+00*S154+7.784493e-01*S155+0.000000e+00*S156+7.992671e-01*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V102_part17='V102_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+2.538456e+00*S163+4.225163e+00*S164+0.000000e+00*S165+2.193857e-01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V102_part18='V102_part17+1.108787e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+2.510910e+00*S176+1.328408e-01*S177+2.028321e+00*S178+3.448309e+00*S179'
.param V102_part19='V102_part18+1.299377e-01*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+1.336857e+00*S188+(-4.929476e-02)*S189'
.param V102_part20='V102_part19+0.000000e+00*S190+6.068165e-01*S191+(-2.773539e-01)*S192+1.085568e+00*S193+4.473746e+00*S194+0.000000e+00*S195+0.000000e+00*S196+2.958569e-01*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V102_part21='V102_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+(-3.076244e-01)*S208+0.000000e+00*S209'
.param V102_part22='V102_part21+0.000000e+00*S210+0.000000e+00*S211+8.142122e-01*S212+0.000000e+00*S213+1.000000e+04*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+1.054394e+00*S219'
.param V102_part23='V102_part22+0.000000e+00*S220+1.494371e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V102_part24='V102_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+2.906830e+00*S233+0.000000e+00*S234+0.000000e+00*S235+3.382472e+00*S236+0.000000e+00*S237+9.562575e-01*S238+4.697254e+00*S239'
.param V102_part25='V102_part24+0.000000e+00*S240+4.446794e-02*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+2.230837e+00*S247+2.342513e+00*S248+1.022412e-01*S249'
.param V102_part26='V102_part25+5.707729e-01*S250+2.964914e+00*S251+0.000000e+00*S252+1.482387e+00*S253+4.163314e+00*S254+1.088668e-01*S255+7.692287e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V102_part27='V102_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+2.653688e+00*S266+(-8.795770e-01)*S267+2.474667e+00*S268+1.741920e+00*S269'
.param V102_part28='V102_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+1.066100e+00*S273+0.000000e+00*S274+0.000000e+00*S275+9.295702e+03*S276+3.580238e+00*S277+3.773669e+00*S278+0.000000e+00*S279'
.param V102_part29='V102_part28+0.000000e+00*S280+4.037724e+00*S281+4.354445e+01*S282+1.033941e+00*S283+0.000000e+00*S284+9.165846e-01*S285+0.000000e+00*S286+0.000000e+00*S287+1.763609e+00*S288+4.118107e+00*S289'
.param V102_part30='V102_part29+2.844596e+00*S290+0.000000e+00*S291+1.015505e+00*S292+0.000000e+00*S293+(-2.052668e-01)*S294+1.970694e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+(-1.290673e+00)*S299'
.param V102_part31='V102_part30+0.000000e+00*S300+6.798196e-03*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-5.115157e-01)*S305+0.000000e+00*S306+2.428461e+00*S307+3.914430e+00*S308+0.000000e+00*S309'
.param V102='V102_part31+3.272261e+00*S310+5.939610e+00*S311+(-4.865061e-01)*S312+4.141650e+00*S313+8.726893e+00*S314'
.param V103_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+1.977398e-01*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V103_part2='V103_part1+0.000000e+00*S10+(-8.223733e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-9.136220e-02)*S15+0.000000e+00*S16+0.000000e+00*S17+4.544746e-03*S18+0.000000e+00*S19'
.param V103_part3='V103_part2+0.000000e+00*S20+(-6.166860e-02)*S21+(-1.773463e-02)*S22+(-5.126387e-02)*S23+0.000000e+00*S24+(-7.498270e-02)*S25+(-9.921063e-02)*S26+(-6.988887e-02)*S27+(-1.035645e-01)*S28+(-9.434354e-02)*S29'
.param V103_part4='V103_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V103_part5='V103_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+(-1.247707e-01)*S49'
.param V103_part6='V103_part5+9.392742e-02*S50+0.000000e+00*S51+0.000000e+00*S52+1.342409e-01*S53+0.000000e+00*S54+0.000000e+00*S55+1.068156e-01*S56+8.256899e-02*S57+0.000000e+00*S58+1.120708e-01*S59'
.param V103_part7='V103_part6+(-3.196389e-02)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+4.043907e-01*S65+3.408154e-01*S66+(-5.501151e-02)*S67+(-1.210071e-01)*S68+0.000000e+00*S69'
.param V103_part8='V103_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+(-6.366200e-01)*S78+0.000000e+00*S79'
.param V103_part9='V103_part8+(-1.898458e-01)*S80+0.000000e+00*S81+(-1.341464e-01)*S82+(-1.883780e-01)*S83+0.000000e+00*S84+(-1.915976e-01)*S85+(-2.143352e-01)*S86+9.955677e-03*S87+(-2.049777e-01)*S88+2.313452e-01*S89'
.param V103_part10='V103_part9+0.000000e+00*S90+(-2.851488e-02)*S91+1.198889e+00*S92+1.161901e+00*S93+6.069230e-01*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V103_part11='V103_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+4.505799e-02*S106+(-3.602913e+00)*S107+0.000000e+00*S108+5.015849e+00*S109'
.param V103_part12='V103_part11+0.000000e+00*S110+(-1.902811e-02)*S111+1.964099e+02*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+4.420144e-02*S119'
.param V103_part13='V103_part12+0.000000e+00*S120+1.037153e-02*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V103_part14='V103_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V103_part15='V103_part14+9.406433e-04*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+5.557002e-02*S148+0.000000e+00*S149'
.param V103_part16='V103_part15+0.000000e+00*S150+9.610389e-03*S151+0.000000e+00*S152+2.757658e-01*S153+0.000000e+00*S154+1.186258e-01*S155+0.000000e+00*S156+4.387467e-02*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V103_part17='V103_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+4.766607e-02*S163+(-2.894236e-02)*S164+0.000000e+00*S165+6.085483e-02*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V103_part18='V103_part17+(-7.803520e-02)*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+2.570065e-01*S176+(-7.013945e-02)*S177+2.310342e-01*S178+2.795731e-01*S179'
.param V103_part19='V103_part18+1.986786e-01*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+2.823810e-01*S188+1.828002e-01*S189'
.param V103_part20='V103_part19+0.000000e+00*S190+(-4.385066e-01)*S191+5.785625e-01*S192+1.148346e-01*S193+2.009284e-01*S194+0.000000e+00*S195+0.000000e+00*S196+(-7.057904e-02)*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V103_part21='V103_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+(-1.703804e-02)*S208+0.000000e+00*S209'
.param V103_part22='V103_part21+0.000000e+00*S210+0.000000e+00*S211+1.067184e-01*S212+0.000000e+00*S213+3.731351e+03*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+(-1.619705e-02)*S219'
.param V103_part23='V103_part22+0.000000e+00*S220+(-3.418647e-02)*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V103_part24='V103_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+1.164459e-01*S233+0.000000e+00*S234+0.000000e+00*S235+7.124690e-02*S236+0.000000e+00*S237+1.085013e-01*S238+2.237298e-01*S239'
.param V103_part25='V103_part24+0.000000e+00*S240+(-1.809789e-01)*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+1.942306e-01*S247+1.483470e-01*S248+(-1.422586e-01)*S249'
.param V103_part26='V103_part25+(-1.604868e-01)*S250+1.256410e-01*S251+0.000000e+00*S252+(-1.565040e-01)*S253+2.499033e-01*S254+2.226125e-02*S255+1.945371e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V103_part27='V103_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+3.865785e-01*S266+2.419615e-01*S267+3.943674e-01*S268+4.112519e-01*S269'
.param V103_part28='V103_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+4.730572e-02*S273+0.000000e+00*S274+0.000000e+00*S275+7.310501e+02*S276+(-3.775848e-01)*S277+2.854638e-02*S278+0.000000e+00*S279'
.param V103_part29='V103_part28+0.000000e+00*S280+3.111224e-02*S281+(-1.914696e-02)*S282+4.473486e-01*S283+0.000000e+00*S284+1.984038e-03*S285+0.000000e+00*S286+0.000000e+00*S287+3.804622e-05*S288+8.701238e-02*S289'
.param V103_part30='V103_part29+7.047899e-02*S290+0.000000e+00*S291+2.408457e-02*S292+0.000000e+00*S293+(-5.583923e-02)*S294+5.778376e-02*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+(-4.124129e-03)*S299'
.param V103_part31='V103_part30+0.000000e+00*S300+8.379715e-02*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+1.000357e-01*S305+0.000000e+00*S306+4.226844e-01*S307+3.411713e-01*S308+0.000000e+00*S309'
.param V103='V103_part31+4.539718e-01*S310+4.177364e-01*S311+1.715418e-01*S312+5.758347e-01*S313+4.884394e-01*S314'
.param V104_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+(-1.941320e-04)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V104_part2='V104_part1+0.000000e+00*S10+(-3.056080e-03)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-2.382277e-03)*S15+0.000000e+00*S16+0.000000e+00*S17+4.597318e-03*S18+0.000000e+00*S19'
.param V104_part3='V104_part2+0.000000e+00*S20+1.423206e-03*S21+(-1.982349e-04)*S22+(-3.448933e-03)*S23+0.000000e+00*S24+3.889425e-03*S25+4.069605e-03*S26+9.084821e-04*S27+1.498687e-04*S28+1.457605e-03*S29'
.param V104_part4='V104_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V104_part5='V104_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+(-2.347021e-02)*S49'
.param V104_part6='V104_part5+(-4.211502e-02)*S50+0.000000e+00*S51+0.000000e+00*S52+(-4.569337e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+(-4.650544e-02)*S56+(-2.772037e-01)*S57+0.000000e+00*S58+(-4.958962e-02)*S59'
.param V104_part7='V104_part6+(-3.258914e-02)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-1.442568e-02)*S65+6.124572e-03*S66+(-9.128805e-02)*S67+5.326438e-04*S68+0.000000e+00*S69'
.param V104_part8='V104_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+2.704591e-02*S78+0.000000e+00*S79'
.param V104_part9='V104_part8+(-1.914658e-02)*S80+0.000000e+00*S81+(-3.743099e-02)*S82+(-4.917011e-02)*S83+0.000000e+00*S84+(-3.963104e-02)*S85+(-7.001889e-02)*S86+(-9.391982e-02)*S87+(-4.890041e-02)*S88+(-7.682604e-02)*S89'
.param V104_part10='V104_part9+0.000000e+00*S90+(-2.161812e-02)*S91+6.386396e-02*S92+2.407311e-02*S93+(-1.584515e-02)*S94+0.000000e+00*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V104_part11='V104_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+2.871249e-03*S106+(-1.434493e+00)*S107+0.000000e+00*S108+2.717053e+01*S109'
.param V104_part12='V104_part11+0.000000e+00*S110+1.254592e-01*S111+4.047675e+01*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+(-7.833940e-01)*S119'
.param V104_part13='V104_part12+0.000000e+00*S120+(-3.670876e-02)*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V104_part14='V104_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V104_part15='V104_part14+4.984192e-03*S140+0.000000e+00*S141+0.000000e+00*S142+0.000000e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+0.000000e+00*S147+2.377021e-02*S148+0.000000e+00*S149'
.param V104_part16='V104_part15+0.000000e+00*S150+1.525334e-02*S151+0.000000e+00*S152+4.360688e-02*S153+0.000000e+00*S154+(-8.385604e-02)*S155+0.000000e+00*S156+3.554658e-03*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V104_part17='V104_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+(-2.786074e-01)*S163+(-4.560620e-01)*S164+0.000000e+00*S165+(-8.430764e-03)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V104_part18='V104_part17+1.721508e-01*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+(-7.206702e-01)*S176+(-5.339476e-01)*S177+(-3.359392e-01)*S178+(-8.438904e-01)*S179'
.param V104_part19='V104_part18+(-1.671316e-01)*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+(-1.761254e-01)*S188+(-2.760383e-01)*S189'
.param V104_part20='V104_part19+0.000000e+00*S190+(-6.726812e-01)*S191+(-4.671323e+00)*S192+(-2.922540e-01)*S193+(-2.339710e-01)*S194+0.000000e+00*S195+0.000000e+00*S196+2.986330e-02*S197+0.000000e+00*S198+0.000000e+00*S199'
.param V104_part21='V104_part20+0.000000e+00*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+0.000000e+00*S206+0.000000e+00*S207+7.251920e-03*S208+0.000000e+00*S209'
.param V104_part22='V104_part21+0.000000e+00*S210+0.000000e+00*S211+1.576364e-01*S212+0.000000e+00*S213+1.225083e+02*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+(-3.255014e-01)*S219'
.param V104_part23='V104_part22+0.000000e+00*S220+3.834684e-01*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V104_part24='V104_part23+0.000000e+00*S230+0.000000e+00*S231+0.000000e+00*S232+(-2.009145e-01)*S233+0.000000e+00*S234+0.000000e+00*S235+(-1.862687e-01)*S236+0.000000e+00*S237+(-2.275084e-01)*S238+(-3.770485e-03)*S239'
.param V104_part25='V104_part24+0.000000e+00*S240+1.775645e-01*S241+0.000000e+00*S242+0.000000e+00*S243+0.000000e+00*S244+0.000000e+00*S245+0.000000e+00*S246+(-4.046097e-02)*S247+(-1.612482e-01)*S248+7.138403e-01*S249'
.param V104_part26='V104_part25+(-5.755920e-01)*S250+(-4.938906e-02)*S251+0.000000e+00*S252+(-5.685607e-01)*S253+(-3.652145e-01)*S254+(-3.251747e-02)*S255+1.430745e-01*S256+0.000000e+00*S257+0.000000e+00*S258+0.000000e+00*S259'
.param V104_part27='V104_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+(-2.824200e-01)*S266+(-7.044362e-01)*S267+(-8.537770e-01)*S268+(-6.839862e-01)*S269'
.param V104_part28='V104_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+(-1.970949e-01)*S273+0.000000e+00*S274+0.000000e+00*S275+1.000000e+04*S276+(-4.144839e-01)*S277+(-2.001722e-01)*S278+0.000000e+00*S279'
.param V104_part29='V104_part28+0.000000e+00*S280+(-3.128318e-01)*S281+2.948314e-01*S282+(-2.599540e-01)*S283+0.000000e+00*S284+(-1.574743e-01)*S285+0.000000e+00*S286+0.000000e+00*S287+(-5.041738e-01)*S288+(-6.102300e-01)*S289'
.param V104_part30='V104_part29+(-5.789159e-02)*S290+0.000000e+00*S291+(-3.215302e-01)*S292+0.000000e+00*S293+(-3.385661e-01)*S294+(-5.537809e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+(-2.028092e-01)*S299'
.param V104_part31='V104_part30+0.000000e+00*S300+(-1.749020e-01)*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-5.558708e-02)*S305+0.000000e+00*S306+(-2.655924e-01)*S307+(-5.377045e-02)*S308+0.000000e+00*S309'
.param V104='V104_part31+(-4.639672e-01)*S310+(-7.298112e-04)*S311+(-6.718630e-01)*S312+(-6.063858e-01)*S313+(-3.225018e-03)*S314'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='0.7064*_P21'
.param _P23='0.7064*_P21'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='V35+V36*rad_+V37*w_'
.param _P28='_P27+V38*gdis_+V39*spacing_'
.param _P29='0.5*(_P28+sqrt(_P28*_P28+0.001))'
.param _P30='V40+V41*rad_+V42*w_'
.param _P31='_P30+V43*gdis_+V44*spacing_'
.param _P32='0.5*(_P31+sqrt(_P31*_P31+0.001))'
.param _P33='V45+V46*rad_+V47*w_'
.param _P34='_P33+V48*gdis_+V49*spacing_'
.param _P35='0.5*(_P34+sqrt(_P34*_P34+0.001))'
.param _P36='V50+V51*rad_+V52*w_'
.param _P37='_P36+V53*gdis_+V54*spacing_'
.param _P38='0.5*(_P37+sqrt(_P37*_P37+0.001))'
.param _P39='V55+V56*rad_+V57*w_'
.param _P40='_P39+V58*gdis_+V59*spacing_'
.param _P41='0.5*(_P40+sqrt(_P40*_P40+0.001))'
.param _P42='V60+V61*rad_+V62*w_'
.param _P43='_P42+V63*gdis_+V64*spacing_'
.param _P44='0.5*(_P43+sqrt(_P43*_P43+0.001))'
.param _P45='V65+V66*rad_+V67*w_'
.param _P46='_P45+V68*gdis_+V69*spacing_'
.param _P47='0.5*(_P46+sqrt(_P46*_P46+0.001))'
.param _P48='V70+V71*rad_+V72*w_'
.param _P49='_P48+V73*gdis_+V74*spacing_'
.param _P50='0.5*(_P49+sqrt(_P49*_P49+0.001))'
.param _P51='1e-14*_P26'
.param _P52='100*_P29'
.param _P53='1e-15*_P32'
.param _P54='1e-14*_P35'
.param _P55='100*_P38'
.param _P56='1e-15*_P41'
.param _P57='1e-14*_P44'
.param _P58='100*_P47'
.param _P59='1e-15*_P50'
.param _P60='V75+V76*rad_+V77*w_'
.param _P61='_P60+V78*gdis_+V79*spacing_'
.param _P62='0.5*(_P61+sqrt(_P61*_P61+0.001))'
.param _P63='V80+V81*rad_+V82*w_'
.param _P64='_P63+V83*gdis_+V84*spacing_'
.param _P65='0.5*(_P64+sqrt(_P64*_P64+0.001))'
.param _P66='100*_P62'
.param _P67='1e-13*_P65'
.param _P68='V85+V86*rad_+V87*w_'
.param _P69='_P68+V88*gdis_+V89*spacing_'
.param _P70='0.5*(_P69+sqrt(_P69*_P69+0.001))'
.param _P71='V90+V91*rad_+V92*w_'
.param _P72='_P71+V93*gdis_+V94*spacing_'
.param _P73='0.5*(_P72+sqrt(_P72*_P72+0.001))'
.param _P74='100*_P70'
.param _P75='1e-13*_P73'
.param _P76='V95+V96*rad_+V97*w_'
.param _P77='_P76+V98*gdis_+V99*spacing_'
.param _P78='0.5*(_P77+sqrt(_P77*_P77+0.001))'
.param _P79='V100+V101*rad_+V102*w_'
.param _P80='_P79+V103*gdis_+V104*spacing_'
.param _P81='0.5*(_P80+sqrt(_P80*_P80+0.001))'
.param _P82='100*_P78'
.param _P83='1e-13*_P81'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P22
k2 ls2_1 ls1_2 K=_P23
c_1_sub top _n1_1_sub '_P51*((1/(12.503905+(1.7014125)*(lay-3+(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P52*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P53* csub_indfac'
c_2_sub bottom _n1_2_sub '_P54*((1/(12.503905+(1.7014125)*(lay-3+(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P55*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P56* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P57*((1/(12.503905+(1.7014125)*(lay-3+(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P58*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_3_sub _n1_3_sub gnode '_P59* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P66*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P67* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P74*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P75* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P82*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P83* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_std_mu_z

.subckt spiral_sym_mu_z top bottom gnode rad=6e-05 w=9e-06 nr=1 lay=9 gdis=5e-05 spacing=3e-06 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-8.619500e+00)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V0_part3='V0_part2+(-3.795500e-01)*S20+0.000000e+00*S21+0.000000e+00*S22+5.870941e+00*S23+0.000000e+00*S24+6.695880e+00*S25+(-5.514975e+00)*S26+5.691026e+00*S27+(-6.095081e+00)*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+0.000000e+00*S30+1.290755e-01*S31+2.292958e+00*S32+6.870209e+00*S33+8.033002e+00*S34+1.343237e+01*S35+1.390091e+01*S36+(-2.070417e+00)*S37+(-1.814526e+01)*S38+7.782202e-01*S39'
.param V0_part5='V0_part4+(-2.866072e+00)*S40+(-4.648330e+00)*S41+1.375563e+01*S42+(-3.057250e+01)*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.060426e+01)*S46+(-2.235518e+01)*S47+5.921854e+00*S48+(-3.681109e+00)*S49'
.param V0_part6='V0_part5+(-1.660273e+01)*S50+1.924456e+01*S51+0.000000e+00*S52+0.000000e+00*S53+2.200991e+01*S54+0.000000e+00*S55+0.000000e+00*S56+1.175913e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V0_part7='V0_part6+9.384241e+00*S60+2.584800e-01*S61+(-3.961658e+01)*S62+2.867643e+01*S63+(-1.386284e+01)*S64+(-3.234596e+01)*S65+1.885219e+01*S66+(-3.206149e+01)*S67+(-2.418752e+01)*S68+4.351786e+01*S69'
.param V0_part8='V0_part7+8.667120e+01*S70+0.000000e+00*S71+3.669476e+01*S72+5.975269e+01*S73+0.000000e+00*S74+1.325721e+01*S75+3.653943e+00*S76+4.214498e+01*S77+4.116458e+01*S78+6.284824e+01*S79'
.param V0='V0_part8+8.184190e+01*S80+4.203394e+01*S81+2.019028e+01*S82+9.635914e+01*S83+5.370260e+01*S84+9.188102e+01*S85+(-1.031295e+01)*S86+6.686562e+01*S87+5.515365e+01*S88+4.332218e-01*S89'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+3.331562e+01*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V1_part3='V1_part2+1.669266e+01*S20+0.000000e+00*S21+0.000000e+00*S22+8.571108e+00*S23+0.000000e+00*S24+1.238133e+01*S25+7.571372e+00*S26+1.622826e+01*S27+2.267098e+01*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+0.000000e+00*S30+2.784969e+01*S31+3.444366e+01*S32+2.492763e+01*S33+2.805606e+01*S34+1.504181e+01*S35+2.407678e+01*S36+3.991417e+01*S37+7.249440e+01*S38+2.552207e+01*S39'
.param V1_part5='V1_part4+4.220973e+01*S40+3.302361e+01*S41+1.584482e+01*S42+4.353797e+01*S43+0.000000e+00*S44+0.000000e+00*S45+8.882527e+01*S46+8.664310e+01*S47+6.559557e+01*S48+6.873946e+01*S49'
.param V1_part6='V1_part5+8.455238e+01*S50+2.576766e+01*S51+0.000000e+00*S52+0.000000e+00*S53+2.864062e+01*S54+0.000000e+00*S55+0.000000e+00*S56+4.838577e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V1_part7='V1_part6+7.811955e+01*S60+1.652795e+02*S61+1.100849e+02*S62+3.103565e+01*S63+7.575123e+01*S64+1.176380e+02*S65+5.156158e+01*S66+8.116927e+01*S67+1.641415e+02*S68+4.369516e+01*S69'
.param V1_part8='V1_part7+2.617593e+01*S70+0.000000e+00*S71+4.341112e+01*S72+5.834005e+01*S73+0.000000e+00*S74+5.657540e+01*S75+7.667775e+01*S76+1.128193e+02*S77+3.826402e+01*S78+5.931384e+01*S79'
.param V1='V1_part8+5.436010e+01*S80+5.772873e+01*S81+1.054641e+02*S82+4.802293e+01*S83+5.642536e+01*S84+5.559907e+01*S85+1.393678e+02*S86+7.105540e+01*S87+9.235532e+01*S88+1.314777e+02*S89'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+2.037617e+01*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V2_part3='V2_part2+1.220460e+01*S20+0.000000e+00*S21+0.000000e+00*S22+8.413394e+00*S23+0.000000e+00*S24+(-3.844791e-01)*S25+2.516411e+01*S26+(-1.505014e+01)*S27+2.449644e+01*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+0.000000e+00*S30+3.354435e+01*S31+4.202792e+01*S32+1.430692e+01*S33+4.026599e+01*S34+1.437923e+01*S35+2.169681e+01*S36+3.421260e+01*S37+1.820232e+01*S38+3.881932e+01*S39'
.param V2_part5='V2_part4+1.284161e+01*S40+1.814980e+01*S41+4.804595e+01*S42+7.040863e+01*S43+0.000000e+00*S44+0.000000e+00*S45+7.174777e+01*S46+8.850352e+01*S47+1.880755e+01*S48+5.286603e+01*S49'
.param V2_part6='V2_part5+1.090988e+02*S50+(-6.073243e+00)*S51+0.000000e+00*S52+0.000000e+00*S53+(-1.243756e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.600441e+01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V2_part7='V2_part6+3.405810e+01*S60+1.397546e+01*S61+1.114775e+02*S62+2.366355e+00*S63+1.121251e+02*S64+6.677406e+01*S65+1.195553e+02*S66+1.468116e+02*S67+8.621947e+01*S68+(-3.237438e+01)*S69'
.param V2_part8='V2_part7+(-2.223468e+01)*S70+0.000000e+00*S71+2.225241e+01*S72+(-6.258798e+01)*S73+0.000000e+00*S74+9.861108e+01*S75+1.050096e+02*S76+7.085709e+01*S77+7.607655e+01*S78+9.127096e+00*S79'
.param V2='V2_part8+3.377482e+01*S80+2.100274e+00*S81+8.988289e+01*S82+3.343255e+01*S83+(-7.743728e+00)*S84+4.794156e+00*S85+8.485919e+01*S86+(-1.607087e+00)*S87+3.535548e+01*S88+2.133465e+02*S89'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-1.683258e+00)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V3_part3='V3_part2+(-2.476612e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+(-2.818498e+00)*S23+0.000000e+00*S24+(-2.535031e+00)*S25+1.110894e+00*S26+1.413563e+00*S27+3.589148e+00*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+0.000000e+00*S30+1.026993e+00*S31+(-1.754536e+00)*S32+1.276133e+00*S33+(-1.790363e-01)*S34+(-1.398020e+00)*S35+1.438933e+00*S36+1.117673e+00*S37+(-4.088089e+00)*S38+1.406106e+00*S39'
.param V3_part5='V3_part4+(-8.381437e-02)*S40+(-1.517256e+00)*S41+(-2.630642e-01)*S42+3.877439e-01*S43+0.000000e+00*S44+0.000000e+00*S45+1.991424e+00*S46+(-1.342963e+00)*S47+(-1.605965e-01)*S48+2.135664e+00*S49'
.param V3_part6='V3_part5+2.827546e+00*S50+(-3.891346e-01)*S51+0.000000e+00*S52+0.000000e+00*S53+(-3.500508e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+2.771411e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V3_part7='V3_part6+4.182680e-01*S60+1.289707e-01*S61+1.675609e+00*S62+2.002861e+00*S63+(-9.297000e-01)*S64+1.773114e+00*S65+5.405548e-01*S66+(-2.380272e+00)*S67+(-4.220869e+00)*S68+(-6.684974e-01)*S69'
.param V3_part8='V3_part7+(-6.194561e+00)*S70+0.000000e+00*S71+1.036081e+00*S72+(-5.339344e-01)*S73+0.000000e+00*S74+2.338518e+00*S75+(-6.486713e-02)*S76+(-1.115091e+01)*S77+1.019882e+00*S78+(-5.246279e+00)*S79'
.param V3='V3_part8+(-7.955752e+00)*S80+9.332904e-01*S81+(-4.487333e+00)*S82+(-8.515181e+00)*S83+(-2.214784e-02)*S84+(-7.023524e+00)*S85+(-1.042143e+01)*S86+6.080048e-01*S87+(-5.112965e+00)*S88+6.709144e+00*S89'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-4.303185e+00)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V4_part3='V4_part2+(-5.796954e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+(-7.044727e+00)*S23+0.000000e+00*S24+(-7.711228e+00)*S25+(-8.923347e+00)*S26+(-7.208626e+00)*S27+(-6.901914e+00)*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+0.000000e+00*S30+(-8.321098e+00)*S31+(-1.293670e+01)*S32+(-9.941231e+00)*S33+(-1.056179e+01)*S34+(-1.705298e+01)*S35+(-1.089100e+01)*S36+(-1.036282e+01)*S37+(-1.706016e+01)*S38+(-1.008584e+01)*S39'
.param V4_part5='V4_part4+(-1.476190e+01)*S40+(-7.801454e+00)*S41+(-2.379644e+01)*S42+(-2.001218e+01)*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.522661e+01)*S46+(-2.411441e+01)*S47+(-2.200743e+01)*S48+(-1.494266e+01)*S49'
.param V4_part6='V4_part5+(-2.451299e+01)*S50+(-9.877988e+00)*S51+0.000000e+00*S52+0.000000e+00*S53+(-1.305741e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-2.449621e+01)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V4_part7='V4_part6+(-1.260259e+01)*S60+(-2.540217e+01)*S61+(-2.767240e+01)*S62+(-1.748025e+01)*S63+(-2.609888e+01)*S64+(-2.627349e+01)*S65+(-3.100746e+01)*S66+(-3.430009e+01)*S67+(-8.310524e+01)*S68+(-3.480202e+01)*S69'
.param V4_part8='V4_part7+(-4.817555e+01)*S70+0.000000e+00*S71+(-2.868947e+01)*S72+(-3.216201e+01)*S73+0.000000e+00*S74+(-9.840442e+00)*S75+(-2.902796e+01)*S76+(-6.464745e+01)*S77+(-2.110202e+01)*S78+(-4.570208e+01)*S79'
.param V4='V4_part8+(-6.967992e+01)*S80+(-3.201739e+01)*S81+(-5.328949e+01)*S82+(-8.033631e+01)*S83+(-4.150920e+01)*S84+(-6.645708e+01)*S85+(-9.379433e+01)*S86+(-6.172131e+01)*S87+(-7.250549e+01)*S88+(-7.936968e+01)*S89'
.param V5_part1='1.366800e+00*S0+1.880614e-01*S1+1.663576e+00*S2+(-9.767005e-03)*S3+6.073104e-01*S4+1.371876e+00*S5+(-4.743406e-01)*S6+2.023545e-01*S7+2.290302e-01*S8+(-1.360901e-01)*S9'
.param V5_part2='V5_part1+3.237005e+00*S10+3.211284e+00*S11+(-1.201417e-01)*S12+2.661943e+00*S13+5.052310e+00*S14+4.001071e-01*S15+9.464579e+00*S16+3.437321e+00*S17+(-2.376030e-02)*S18+1.555001e-01*S19'
.param V5_part3='V5_part2+4.746446e-02*S20+2.725200e-01*S21+1.882610e+00*S22+2.727137e-02*S23+6.340891e+00*S24+3.314429e-01*S25+1.034735e+00*S26+(-2.890186e-01)*S27+(-1.144391e-02)*S28+(-7.694207e-02)*S29'
.param V5_part4='V5_part3+3.733671e+01*S30+1.669869e+00*S31+1.744034e-01*S32+4.336233e+00*S33+2.403027e-01*S34+5.533897e+00*S35+(-5.504650e-01)*S36+1.139240e-02*S37+5.806268e-01*S38+(-1.511937e-01)*S39'
.param V5_part5='V5_part4+(-1.121494e-03)*S40+3.952431e-01*S41+(-3.781018e-01)*S42+(-6.688656e-02)*S43+(-6.124474e-02)*S44+2.848048e+01*S45+6.949940e-01*S46+1.161150e+00*S47+1.788882e-01*S48+3.590032e-01*S49'
.param V5_part6='V5_part5+2.308218e+00*S50+4.014088e-01*S51+1.599553e-01*S52+1.607086e-01*S53+3.712139e+00*S54+8.437701e-02*S55+9.166348e-02*S56+(-9.166722e-03)*S57+(-8.039017e-02)*S58+7.213221e-02*S59'
.param V5_part7='V5_part6+(-3.238099e-01)*S60+(-9.969650e-03)*S61+2.593711e-01*S62+(-1.804804e-01)*S63+2.176376e-01*S64+2.496893e-01*S65+(-5.144123e-01)*S66+7.749318e-02*S67+4.011693e+00*S68+(-5.491856e-01)*S69'
.param V5_part8='V5_part7+(-9.001217e-01)*S70+3.460816e+01*S71+(-6.685615e-01)*S72+8.871561e-03*S73+8.533568e-02*S74+1.652588e-02*S75+1.028209e+01*S76+4.256182e-01*S77+(-2.737984e-01)*S78+2.227644e-01*S79'
.param V5='V5_part8+3.602325e-01*S80+(-6.624398e-01)*S81+1.653919e-01*S82+3.265973e-01*S83+(-9.781147e-01)*S84+(-2.248416e-02)*S85+2.211788e-01*S86+1.233745e+02*S87+(-1.500259e-01)*S88+4.795898e+00*S89'
.param V6_part1='1.482477e+01*S0+1.022689e+00*S1+2.248348e+00*S2+3.400009e-02*S3+1.611893e+00*S4+1.598234e+00*S5+9.909826e-01*S6+2.403934e+00*S7+1.566546e+00*S8+2.126710e-01*S9'
.param V6_part2='V6_part1+(-1.902491e+00)*S10+(-1.977809e+00)*S11+(-1.111812e-03)*S12+(-1.530832e+00)*S13+(-4.978644e+00)*S14+(-5.800190e-01)*S15+(-1.841980e+01)*S16+(-3.675375e+00)*S17+4.076093e-02*S18+3.887913e-01*S19'
.param V6_part3='V6_part2+1.728261e-01*S20+(-1.328622e-01)*S21+(-1.544654e+00)*S22+1.770284e-01*S23+(-2.491941e-01)*S24+2.822507e-01*S25+7.172008e-01*S26+5.038334e-01*S27+(-1.417743e-01)*S28+5.024085e-01*S29'
.param V6_part4='V6_part3+(-6.198528e+01)*S30+(-1.533136e+01)*S31+7.569893e-02*S32+(-2.706921e+01)*S33+8.653784e-01*S34+(-8.966425e-01)*S35+1.893004e+00*S36+1.204342e+00*S37+8.501460e-01*S38+3.577107e-01*S39'
.param V6_part5='V6_part4+3.226072e-01*S40+(-1.866123e-01)*S41+5.746096e-01*S42+3.726519e-01*S43+3.097563e-01*S44+(-1.013041e+01)*S45+1.436823e+00*S46+6.018573e-01*S47+3.734348e-01*S48+1.557104e+00*S49'
.param V6_part6='V6_part5+8.567566e-02*S50+(-4.096445e+00)*S51+3.867879e-01*S52+1.033473e-01*S53+(-8.044041e+00)*S54+3.967999e-01*S55+2.062636e-01*S56+7.650585e-01*S57+4.096018e-01*S58+1.935494e-01*S59'
.param V6_part7='V6_part6+3.335085e+00*S60+(-1.707956e-01)*S61+2.036902e-01*S62+1.812286e+00*S63+5.763824e-01*S64+2.705377e-01*S65+1.523774e+00*S66+5.898418e-01*S67+(-3.748658e+00)*S68+1.201554e+00*S69'
.param V6_part8='V6_part7+(-1.871471e+00)*S70+(-2.714343e+01)*S71+1.073492e+00*S72+7.389230e-01*S73+3.561061e-01*S74+1.070996e+00*S75+(-1.686054e+00)*S76+2.551014e-01*S77+1.172916e+00*S78+6.723642e-01*S79'
.param V6='V6_part8+2.761118e-01*S80+1.852099e+00*S81+6.429601e-01*S82+2.254419e-01*S83+1.847795e+00*S84+7.324989e-01*S85+2.900757e-01*S86+(-9.102019e+01)*S87+6.875923e-01*S88+(-2.130622e+00)*S89'
.param V7_part1='1.629021e-01*S0+(-7.858205e-02)*S1+7.532289e-01*S2+2.583265e-01*S3+4.013615e-01*S4+1.152631e+00*S5+7.873370e-01*S6+(-7.217494e-02)*S7+(-3.461743e-02)*S8+4.749277e-02*S9'
.param V7_part2='V7_part1+5.961771e-01*S10+8.109360e-01*S11+1.848523e-01*S12+8.204377e-01*S13+3.464619e+00*S14+1.506081e-01*S15+2.657887e+00*S16+4.220816e+00*S17+2.523833e-01*S18+2.482465e-02*S19'
.param V7_part3='V7_part2+6.378749e-02*S20+2.653392e-01*S21+1.325799e+00*S22+9.085449e-02*S23+1.701688e+00*S24+1.259620e-02*S25+1.169313e-01*S26+1.326209e-01*S27+3.993495e-01*S28+1.071565e-01*S29'
.param V7_part4='V7_part3+2.331115e+01*S30+7.254102e+00*S31+7.587950e-02*S32+4.944885e+01*S33+2.662279e-03*S34+3.160306e+00*S35+1.325843e-01*S36+2.274539e-03*S37+1.401090e+00*S38+5.078958e-01*S39'
.param V7_part5='V7_part4+1.047009e-01*S40+1.942291e-01*S41+1.161682e+00*S42+1.276784e-01*S43+2.511947e-01*S44+1.208364e+00*S45+(-1.022347e-01)*S46+4.485859e-01*S47+4.447675e-01*S48+(-7.916808e-02)*S49'
.param V7_part6='V7_part5+1.884801e+00*S50+4.714677e+00*S51+9.911248e-02*S52+1.895764e-01*S53+5.975727e+00*S54+1.347042e-01*S55+2.034706e-01*S56+3.429740e-01*S57+2.114150e-01*S58+2.291582e-01*S59'
.param V7_part7='V7_part6+1.476939e-01*S60+5.173888e-01*S61+1.698097e-01*S62+1.533978e-01*S63+1.047155e-01*S64+1.333231e-01*S65+1.954044e-01*S66+1.661088e-01*S67+3.910262e+00*S68+2.364855e-01*S69'
.param V7_part8='V7_part7+4.768730e+00*S70+6.277087e+00*S71+2.803842e-01*S72+1.173460e-01*S73+3.093725e-01*S74+1.463138e-01*S75+(-4.754462e-01)*S76+1.175121e-01*S77+1.976965e-01*S78+1.443030e-01*S79'
.param V7='V7_part8+1.828186e-01*S80+2.313395e-01*S81+1.841349e-01*S82+2.391755e-01*S83+2.926689e-01*S84+2.370755e-01*S85+2.774178e-01*S86+7.026639e+01*S87+3.242871e-01*S88+5.927416e+00*S89'
.param V8_part1='1.222060e+00*S0+6.623423e-02*S1+4.264034e-01*S2+(-2.239696e-01)*S3+3.729649e-01*S4+5.465548e-01*S5+(-3.192233e-01)*S6+1.742381e-02*S7+2.022883e-02*S8+2.536701e-02*S9'
.param V8_part2='V8_part1+(-4.826566e-01)*S10+(-6.253621e-01)*S11+8.881242e-03*S12+(-3.355437e-01)*S13+5.203950e-01*S14+(-7.637393e-03)*S15+(-1.350713e+00)*S16+(-3.522160e-02)*S17+1.195182e-02*S18+1.834780e-02*S19'
.param V8_part3='V8_part2+2.597632e-03*S20+(-1.138284e-02)*S21+(-3.070921e-01)*S22+9.164830e-06*S23+(-1.701391e+00)*S24+(-1.289485e-02)*S25+7.720159e-02*S26+3.029718e-02*S27+(-1.962197e-02)*S28+1.346458e-02*S29'
.param V8_part4='V8_part3+(-3.785467e+00)*S30+(-2.157896e-01)*S31+3.498857e-03*S32+(-6.662149e+00)*S33+2.833014e-02*S34+(-2.071982e-01)*S35+8.975405e-02*S36+3.168795e-02*S37+(-9.553634e-02)*S38+(-5.281066e-02)*S39'
.param V8_part5='V8_part4+1.631011e-02*S40+2.313084e-02*S41+(-3.617530e-01)*S42+1.478132e-02*S43+1.067927e-02*S44+2.156777e+00*S45+(-2.412189e-02)*S46+(-6.066334e-02)*S47+(-2.996075e-02)*S48+1.966748e-02*S49'
.param V8_part6='V8_part5+(-1.936447e-02)*S50+(-1.630314e-02)*S51+1.685675e-02*S52+4.006049e-03*S53+2.056552e-01*S54+1.825083e-02*S55+(-1.813283e-05)*S56+3.788869e-01*S57+1.350992e-02*S58+1.505562e-03*S59'
.param V8_part7='V8_part6+9.881832e-02*S60+1.104090e-03*S61+2.118366e-04*S62+4.736114e-02*S63+1.427962e-02*S64+3.097499e-03*S65+5.390978e-02*S66+1.294794e-02*S67+1.008921e-01*S68+3.867635e-02*S69'
.param V8_part8='V8_part7+4.945074e-01*S70+(-1.156381e+00)*S71+3.497992e-02*S72+8.397444e-03*S73+(-3.163933e-03)*S74+2.645205e-02*S75+2.097932e-01*S76+(-2.991028e-04)*S77+2.903891e-02*S78+1.085151e-02*S79'
.param V8='V8_part8+3.344018e-03*S80+6.123843e-02*S81+1.700070e-02*S82+2.063015e-03*S83+7.357754e-02*S84+1.302928e-02*S85+4.490733e-03*S86+(-4.516341e-01)*S87+1.794316e-02*S88+(-5.340031e-01)*S89'
.param V9_part1='4.116195e-01*S0+2.809964e-02*S1+(-1.170632e-02)*S2+2.991753e-02*S3+(-2.770020e-02)*S4+(-2.150942e-02)*S5+2.428585e-02*S6+6.394716e-02*S7+3.503446e-02*S8+2.024514e-03*S9'
.param V9_part2='V9_part1+(-8.152491e-02)*S10+5.746473e-02*S11+(-3.644706e-03)*S12+(-3.705833e-03)*S13+(-4.503472e-02)*S14+(-4.288988e-02)*S15+1.654448e-01*S16+(-5.056767e-01)*S17+(-5.162316e-02)*S18+2.168829e-02*S19'
.param V9_part3='V9_part2+4.081650e-03*S20+(-1.149414e-01)*S21+1.028152e-01*S22+4.646538e-03*S23+1.784634e+00*S24+3.411305e-02*S25+2.068407e-02*S26+1.856185e-02*S27+(-4.942098e-03)*S28+4.896257e-02*S29'
.param V9_part4='V9_part3+6.165462e-01*S30+(-1.481921e+00)*S31+(-7.838958e-03)*S32+4.639774e+00*S33+5.186927e-02*S34+(-6.504158e-01)*S35+1.010053e-01*S36+7.839753e-02*S37+(-6.520435e-02)*S38+(-2.286815e-02)*S39'
.param V9_part5='V9_part4+1.359095e-02*S40+(-4.390832e-03)*S41+6.302427e-02*S42+1.534652e-02*S43+3.203075e-02*S44+(-1.757297e+00)*S45+9.999006e-02*S46+(-5.870657e-02)*S47+(-6.768864e-02)*S48+1.611244e-01*S49'
.param V9_part6='V9_part5+(-6.695903e-02)*S50+2.166313e+00*S51+2.237820e-02*S52+1.006321e-02*S53+3.723864e+00*S54+2.348050e-02*S55+9.843131e-03*S56+8.962142e-02*S57+1.233320e-02*S58+6.023048e-03*S59'
.param V9_part7='V9_part6+3.506171e-01*S60+4.217354e-02*S61+1.507919e-02*S62+1.814205e-01*S63+5.018772e-02*S64+2.744853e-02*S65+1.913324e-01*S66+5.421987e-02*S67+(-1.520405e-01)*S68+1.202391e-01*S69'
.param V9_part8='V9_part7+(-8.838490e-01)*S70+3.651339e+00*S71+1.297252e-01*S72+5.003157e-03*S73+7.961964e-03*S74+1.858004e-01*S75+(-9.489848e-01)*S76+2.851342e-02*S77+2.608567e-01*S78+6.033051e-02*S79'
.param V9='V9_part8+1.687276e-02*S80+4.143641e-01*S81+6.853183e-02*S82+2.025919e-02*S83+4.623979e-01*S84+6.546401e-02*S85+3.793662e-02*S86+4.676339e+00*S87+7.441354e-02*S88+(-3.265253e-01)*S89'
.param V10_part1='(-1.472063e-02)*S0+(-3.001430e-03)*S1+4.867341e-02*S2+6.426555e-02*S3+2.359562e-02*S4+6.127725e-02*S5+1.442031e-01*S6+(-1.061637e-02)*S7+2.695187e-03*S8+3.104090e-03*S9'
.param V10_part2='V10_part1+1.786717e-01*S10+6.256059e-02*S11+(-4.038457e-03)*S12+1.914005e-01*S13+1.634558e-01*S14+3.599179e-03*S15+6.190648e-01*S16+3.911212e-03*S17+(-3.023593e-03)*S18+(-2.147645e-02)*S19'
.param V10_part3='V10_part2+4.084408e-03*S20+(-3.574207e-03)*S21+(-4.352429e-02)*S22+(-1.482694e-02)*S23+(-6.060908e-02)*S24+(-8.347429e-02)*S25+3.285110e-02*S26+(-8.648074e-03)*S27+1.541211e-01*S28+(-5.016969e-02)*S29'
.param V10_part4='V10_part3+(-2.264427e-01)*S30+9.493659e-01*S31+(-2.752827e-02)*S32+(-2.514179e-01)*S33+(-5.666332e-03)*S34+(-9.995963e-02)*S35+(-3.302864e-02)*S36+(-2.323668e-02)*S37+1.487284e-01*S38+(-5.246827e-03)*S39'
.param V10_part5='V10_part4+(-2.252757e-02)*S40+(-7.778109e-02)*S41+(-4.224431e-02)*S42+(-9.564803e-03)*S43+(-1.133487e-01)*S44+(-3.273735e-01)*S45+2.606646e-02*S46+3.547384e-02*S47+(-2.191813e-02)*S48+1.680677e-02*S49'
.param V10_part6='V10_part5+7.287920e-02*S50+1.323165e-01*S51+(-7.348564e-03)*S52+(-4.527755e-02)*S53+3.815333e-01*S54+(-3.883292e-02)*S55+2.688592e-02*S56+7.621486e-02*S57+(-1.217803e-02)*S58+2.122143e-02*S59'
.param V10_part7='V10_part6+(-6.656398e-02)*S60+3.332344e-01*S61+(-1.876222e-02)*S62+3.040639e-04*S63+5.185814e-02*S64+3.538464e-02*S65+8.429280e-02*S66+8.276730e-03*S67+1.269234e+00*S68+(-3.770281e-02)*S69'
.param V10_part8='V10_part7+2.155946e+00*S70+1.278613e+00*S71+(-4.361255e-02)*S72+2.221216e-01*S73+(-1.090557e-02)*S74+1.796405e-02*S75+(-6.671700e-01)*S76+3.857268e-02*S77+6.619879e-04*S78+7.088569e-02*S79'
.param V10='V10_part8+3.263757e-03*S80+8.470491e-02*S81+4.238135e-02*S82+3.193250e-03*S83+8.742082e-02*S84+1.214550e-02*S85+1.223745e-02*S86+(-6.713012e+00)*S87+8.007874e-04*S88+1.913432e+00*S89'
.param V11_part1='6.471814e-01*S0+2.418012e-01*S1+2.314876e-01*S2+2.435255e-01*S3+2.243451e-01*S4+2.324361e-01*S5+2.965172e-01*S6+3.372604e-01*S7+2.822158e-01*S8+2.557039e-01*S9'
.param V11_part2='V11_part1+2.220075e-01*S10+1.763460e-01*S11+2.621846e-01*S12+2.383656e-01*S13+1.973438e-01*S14+6.771260e-01*S15+2.933743e-01*S16+1.151326e+00*S17+7.640681e-01*S18+7.768275e-01*S19'
.param V11_part3='V11_part2+6.800299e-01*S20+8.179476e-01*S21+1.011332e+00*S22+7.513403e-01*S23+1.567308e+00*S24+9.318539e-01*S25+9.536328e-01*S26+9.118874e-01*S27+8.601163e-01*S28+9.044243e-01*S29'
.param V11_part4='V11_part3+1.798554e+01*S30+3.961391e+00*S31+1.363739e+00*S32+2.884864e+01*S33+1.437873e+00*S34+2.651209e+00*S35+1.746422e+00*S36+1.542432e+00*S37+1.462768e+00*S38+1.807869e+00*S39'
.param V11_part5='V11_part4+1.671651e+00*S40+1.630357e+00*S41+2.048377e+00*S42+1.710339e+00*S43+1.782038e+00*S44+5.603353e+00*S45+2.195232e+00*S46+2.148366e+00*S47+2.665157e+00*S48+2.394354e+00*S49'
.param V11_part6='V11_part5+2.573174e+00*S50+3.263971e+00*S51+2.657581e+00*S52+2.454995e+00*S53+3.362819e+00*S54+2.797957e+00*S55+2.474194e+00*S56+3.299693e+00*S57+2.875464e+00*S58+2.611597e+00*S59'
.param V11_part7='V11_part6+4.075565e+00*S60+3.579532e+00*S61+3.255118e+00*S62+4.058622e+00*S63+3.660339e+00*S64+3.422452e+00*S65+4.213780e+00*S66+3.896661e+00*S67+2.984205e+00*S68+4.693196e+00*S69'
.param V11_part8='V11_part7+5.109298e+00*S70+2.378036e+00*S71+4.895088e+00*S72+4.314832e+00*S73+3.842450e+00*S74+5.206772e+00*S75+6.402447e+00*S76+4.545286e+00*S77+5.714892e+00*S78+5.129530e+00*S79'
.param V11='V11_part8+4.806864e+00*S80+5.913560e+00*S81+5.428379e+00*S82+5.030209e+00*S83+6.244501e+00*S84+5.711121e+00*S85+5.227793e+00*S86+3.532718e+01*S87+5.910577e+00*S88+4.970378e+00*S89'
.param V12_part1='2.873871e-01*S0+2.270394e-02*S1+3.703525e-03*S2+(-1.150865e-01)*S3+(-1.112569e-02)*S4+(-1.388504e-02)*S5+(-2.723649e-01)*S6+3.349409e-03*S7+3.667879e-03*S8+(-8.730679e-02)*S9'
.param V12_part2='V12_part1+(-1.094687e-01)*S10+5.005912e-04*S11+(-1.064867e-01)*S12+(-1.443836e-01)*S13+(-5.274723e-02)*S14+1.995653e-02*S15+(-7.145671e-02)*S16+1.470987e-01*S17+(-5.727425e-02)*S18+6.584648e-02*S19'
.param V12_part3='V12_part2+5.988795e-02*S20+(-1.456259e-01)*S21+2.103197e-02*S22+4.167034e-02*S23+1.229523e+00*S24+6.483693e-02*S25+9.144236e-02*S26+(-3.376989e-01)*S27+(-2.506736e-01)*S28+(-2.179514e-02)*S29'
.param V12_part4='V12_part3+4.173407e-01*S30+(-4.232849e-01)*S31+3.095172e-01*S32+(-7.004775e+00)*S33+1.338465e-01*S34+3.140602e-01*S35+(-1.881870e-01)*S36+5.970423e-02*S37+1.329346e-02*S38+(-4.255010e-01)*S39'
.param V12_part5='V12_part4+(-1.582744e-02)*S40+2.095571e-01*S41+(-6.667377e-01)*S42+(-1.328273e-01)*S43+1.476096e-01*S44+7.866950e+00*S45+5.023985e-01*S46+4.947313e-01*S47+2.127509e-01*S48+3.975702e-01*S49'
.param V12_part6='V12_part5+3.857399e-01*S50+(-4.722797e-01)*S51+3.359864e-01*S52+5.833284e-01*S53+(-9.159691e-01)*S54+2.061557e-01*S55+4.669478e-01*S56+(-4.246782e-01)*S57+2.322022e-02*S58+3.723281e-01*S59'
.param V12_part7='V12_part6+1.692680e+00*S60+1.238768e+00*S61+1.401226e+00*S62+6.533598e-01*S63+1.059964e+00*S64+1.333394e+00*S65+2.680672e-01*S66+9.014565e-01*S67+2.739825e-01*S68+9.036100e-02*S69'
.param V12_part8='V12_part7+(-9.351543e-01)*S70+1.195023e+00*S71+(-4.146256e-01)*S72+2.355007e-01*S73+9.277995e-01*S74+2.292303e+00*S75+7.506292e+00*S76+2.480403e+00*S77+1.837677e+00*S78+2.079521e+00*S79'
.param V12='V12_part8+2.375404e+00*S80+8.279339e-01*S81+1.774454e+00*S82+2.255314e+00*S83+1.455860e-01*S84+1.522716e+00*S85+2.168261e+00*S86+(-1.388034e+01)*S87+1.176555e+00*S88+4.444475e-01*S89'
.param V13_part1='7.914644e-02*S0+2.436251e-02*S1+3.906231e-02*S2+1.541109e-02*S3+3.288967e-02*S4+4.041171e-02*S5+1.765335e-02*S6+2.907562e-02*S7+2.517919e-02*S8+1.884140e-02*S9'
.param V13_part2='V13_part1+1.310547e-02*S10+8.090207e-03*S11+1.978133e-02*S12+1.657204e-02*S13+6.020917e-02*S14+1.896872e-02*S15+9.197759e-04*S16+6.452842e-02*S17+2.017585e-02*S18+2.415087e-02*S19'
.param V13_part3='V13_part2+2.412587e-02*S20+1.987212e-02*S21+3.614263e-02*S22+2.680281e-02*S23+3.349415e-02*S24+2.474128e-02*S25+3.426474e-02*S26+2.082980e-02*S27+2.261421e-02*S28+2.777147e-02*S29'
.param V13_part4='V13_part3+2.524344e-01*S30+9.643114e-02*S31+2.620900e-02*S32+5.819523e-01*S33+2.186913e-02*S34+4.008528e-02*S35+2.196511e-02*S36+2.452121e-02*S37+1.846084e-02*S38+2.199747e-02*S39'
.param V13_part5='V13_part4+2.314974e-02*S40+2.214973e-02*S41+8.163131e-03*S42+2.525468e-02*S43+2.449743e-02*S44+1.069218e-01*S45+2.406859e-02*S46+2.425062e-02*S47+2.191255e-02*S48+2.503560e-02*S49'
.param V13_part6='V13_part5+2.215320e-02*S50+2.071852e-02*S51+2.314070e-02*S52+2.548010e-02*S53+4.525107e-02*S54+2.313561e-02*S55+2.679765e-02*S56+3.299373e-02*S57+2.186668e-02*S58+2.433099e-02*S59'
.param V13_part7='V13_part6+2.543846e-02*S60+3.122110e-02*S61+2.959846e-02*S62+2.190312e-02*S63+2.469675e-02*S64+2.861483e-02*S65+1.902543e-02*S66+2.632448e-02*S67+6.196707e-02*S68+2.229620e-02*S69'
.param V13_part8='V13_part7+7.825899e-02*S70+(-9.634527e-02)*S71+2.479370e-02*S72+2.994631e-02*S73+3.243868e-02*S74+1.997705e-02*S75+3.279247e-02*S76+3.280629e-02*S77+2.130243e-02*S78+2.532988e-02*S79'
.param V13='V13_part8+2.974548e-02*S80+2.002165e-02*S81+2.433997e-02*S82+3.195395e-02*S83+2.216029e-02*S84+2.605128e-02*S85+2.688267e-02*S86+1.308937e+00*S87+2.126531e-02*S88+2.637073e-02*S89'
.param V14_part1='1.085816e-02*S0+4.785839e-03*S1+2.932311e-03*S2+4.373135e-03*S3+2.560218e-03*S4+2.393808e-03*S5+5.123926e-03*S6+5.837694e-03*S7+4.046374e-03*S8+4.028108e-03*S9'
.param V14_part2='V14_part1+1.316254e-03*S10+3.934741e-03*S11+4.017118e-03*S12+3.747282e-03*S13+1.387176e-03*S14+1.218470e-02*S15+3.088725e-02*S16+2.803228e-02*S17+1.107604e-02*S18+1.404944e-02*S19'
.param V14_part3='V14_part2+1.336504e-02*S20+7.434487e-03*S21+1.399175e-02*S22+1.413223e-02*S23+3.052898e-02*S24+1.143444e-02*S25+2.805164e-02*S26+3.411833e-03*S27+1.383721e-03*S28+1.145935e-02*S29'
.param V14_part4='V14_part3+6.095215e-01*S30+(-6.471708e-03)*S31+4.136186e-02*S32+1.611138e+00*S33+3.328941e-02*S34+1.848155e-01*S35+2.242069e-02*S36+3.100989e-02*S37+5.835552e-02*S38+1.689659e-02*S39'
.param V14_part5='V14_part4+2.291774e-02*S40+3.751481e-02*S41+(-9.237811e-03)*S42+1.987185e-02*S43+3.161495e-02*S44+1.974029e-01*S45+7.260441e-02*S46+1.023916e-01*S47+5.939362e-02*S48+6.641896e-02*S49'
.param V14_part6='V14_part5+1.778431e-01*S50+4.782235e-01*S51+5.505636e-02*S52+6.312698e-02*S53+6.766232e-01*S54+5.001222e-02*S55+5.843285e-02*S56+(-3.196800e-03)*S57+4.486777e-02*S58+5.318927e-02*S59'
.param V14_part7='V14_part6+1.430379e-01*S60+1.358264e-01*S61+1.206855e-01*S62+8.587740e-02*S63+1.088282e-01*S64+1.132486e-01*S65+5.035587e-02*S66+9.927286e-02*S67+2.211976e-01*S68+2.347846e-02*S69'
.param V14_part8='V14_part7+(-7.948588e-02)*S70+4.740166e+00*S71+(-1.897589e-02)*S72+8.837783e-02*S73+9.945294e-02*S74+1.715971e-01*S75+2.308912e-01*S76+1.982852e-01*S77+1.220588e-01*S78+1.814644e-01*S79'
.param V14='V14_part8+1.952923e-01*S80+1.169910e-01*S81+1.641014e-01*S82+1.807673e-01*S83+8.132905e-02*S84+1.454189e-01*S85+1.652209e-01*S86+7.099885e+00*S87+1.199267e-01*S88+3.254289e-01*S89'
.param V15_part1='(-7.982628e-02)*S0+(-3.757100e-02)*S1+1.414737e-02*S2+(-1.864797e-01)*S3+(-6.290908e-02)*S4+(-1.344473e-02)*S5+(-2.111487e-01)*S6+(-1.100214e-01)*S7+(-4.784651e-02)*S8+5.666132e-02*S9'
.param V15_part2='V15_part1+(-1.578053e-01)*S10+(-6.418635e-02)*S11+(-9.477707e-01)*S12+(-1.934892e-01)*S13+(-8.163739e-02)*S14+(-2.821591e-01)*S15+1.158295e-01*S16+1.773253e-01*S17+(-4.993732e-01)*S18+(-3.667673e-01)*S19'
.param V15_part3='V15_part2+1.357867e+00*S20+(-9.292215e-01)*S21+(-5.189617e-02)*S22+8.395763e-01*S23+(-4.317053e-01)*S24+(-9.260156e-01)*S25+5.680588e-03*S26+(-3.754435e+00)*S27+(-7.687462e-01)*S28+1.399199e-01*S29'
.param V15_part4='V15_part3+1.787003e-01*S30+3.131539e-01*S31+4.750795e+00*S32+(-9.898004e-04)*S33+(-3.525114e-02)*S34+3.452856e-01*S35+(-4.859275e-01)*S36+1.850054e-01*S37+3.245199e-01*S38+(-1.713145e+00)*S39'
.param V15_part5='V15_part4+1.565615e+01*S40+(-8.950917e-01)*S41+(-1.167458e+00)*S42+5.034888e+00*S43+1.091780e+00*S44+1.068409e-01*S45+5.360256e-02*S46+6.756165e-01*S47+(-9.948224e-01)*S48+4.530530e-01*S49'
.param V15_part6='V15_part5+6.965178e-01*S50+(-4.837722e-01)*S51+1.576230e+01*S52+3.349311e+01*S53+(-7.726253e-01)*S54+1.481585e+01*S55+1.923759e+01*S56+(-1.262384e+00)*S57+(-1.421890e+00)*S58+5.857253e+01*S59'
.param V15_part7='V15_part6+1.376778e+00*S60+2.272202e+00*S61+7.404090e-01*S62+(-6.899859e+00)*S63+(-1.995883e+00)*S64+(-8.856631e+03)*S65+(-5.341006e-01)*S66+(-5.036515e+00)*S67+3.548971e-01*S68+2.013524e+01*S69'
.param V15_part8='V15_part7+2.310790e-01*S70+7.374610e-01*S71+1.003433e+02*S72+2.885545e+01*S73+1.409093e+01*S74+1.000000e+04*S75+4.743223e-01*S76+(-1.072630e+03)*S77+1.000000e+04*S78+(-5.156044e+01)*S79'
.param V15='V15_part8+9.865824e+01*S80+(-5.385556e+00)*S81+(-3.284749e+00)*S82+9.487230e+01*S83+(-5.731934e+00)*S84+(-1.208262e+01)*S85+(-8.759456e+03)*S86+(-4.678875e-01)*S87+(-7.837446e+00)*S88+2.564880e-01*S89'
.param V16_part1='4.196814e-01*S0+2.367926e-01*S1+1.319725e-01*S2+5.563772e-01*S3+2.821691e-01*S4+1.422987e-01*S5+4.343768e-01*S6+2.772703e-01*S7+1.582643e-01*S8+(-2.868306e-01)*S9'
.param V16_part2='V16_part1+3.005353e-01*S10+1.529329e-01*S11+1.322540e+00*S12+2.865701e-01*S13+1.393380e-01*S14+2.278625e+00*S15+5.937102e-01*S16+1.063484e-01*S17+2.241225e+00*S18+1.103075e+00*S19'
.param V16_part3='V16_part2+(-8.309010e-01)*S20+2.304585e+00*S21+4.519661e-01*S22+(-1.872232e-01)*S23+8.041921e-01*S24+1.078475e+00*S25+3.106362e-01*S26+3.245307e+00*S27+1.782431e+00*S28+1.866284e-01*S29'
.param V16_part4='V16_part3+5.929510e-01*S30+3.237251e-01*S31+7.431217e-02*S32+7.468430e-01*S33+(-1.378860e-01)*S34+1.113999e-01*S35+7.107019e-03*S36+(-4.702992e-01)*S37+5.354273e-01*S38+3.257541e+00*S39'
.param V16_part5='V16_part4+(-2.557344e+01)*S40+2.413120e+00*S41+1.771554e+00*S42+(-5.458164e+00)*S43+(-1.673020e-01)*S44+1.444472e+00*S45+(-9.960961e-02)*S46+4.712211e-01*S47+4.877655e+00*S48+(-7.460629e-01)*S49'
.param V16_part6='V16_part5+(-1.042970e-01)*S50+1.828808e+00*S51+(-1.861180e+01)*S52+1.572555e+01*S53+1.801639e+00*S54+(-1.664528e+01)*S55+(-1.842716e+00)*S56+2.832191e+00*S57+(-1.155208e+01)*S58+4.481326e-01*S59'
.param V16_part7='V16_part6+1.036030e+00*S60+3.995744e+00*S61+8.551835e+00*S62+6.144414e+00*S63+(-8.376841e+00)*S64+6.171865e+03*S65+(-1.868738e+01)*S66+(-5.926522e+00)*S67+9.011664e-01*S68+(-2.361883e+01)*S69'
.param V16_part8='V16_part7+1.087411e+00*S70+1.728934e-01*S71+(-9.591303e+01)*S72+7.380925e+00*S73+(-1.763692e+00)*S74+(-7.048384e+03)*S75+1.096238e+00*S76+1.087705e+03*S77+(-5.671342e+03)*S78+4.699192e+00*S79'
.param V16='V16_part8+(-6.130678e+01)*S80+(-3.358058e+00)*S81+(-1.204092e+01)*S82+(-3.866048e+01)*S83+5.891157e-01*S84+(-9.163773e+00)*S85+2.806436e+03*S86+1.442991e+00*S87+(-1.789825e+01)*S88+1.057179e+00*S89'
.param V17_part1='4.042658e-02*S0+6.410847e-02*S1+3.816047e-02*S2+6.308611e-02*S3+5.414000e-02*S4+5.969050e-02*S5+7.815040e-02*S6+8.053500e-02*S7+8.915418e-02*S8+3.133120e+00*S9'
.param V17_part2='V17_part1+9.083409e-02*S10+1.024211e-01*S11+1.396096e-01*S12+1.123319e-01*S13+1.247570e-01*S14+9.746164e-02*S15+5.500208e-02*S16+1.019751e-01*S17+1.266456e-01*S18+4.933770e-01*S19'
.param V17_part3='V17_part2+9.353251e-01*S20+1.857650e-01*S21+1.530522e-01*S22+7.483327e-01*S23+1.927626e-01*S24+5.945307e-01*S25+2.034153e-01*S26+1.284330e+00*S27+1.383041e-01*S28+4.621273e-01*S29'
.param V17_part4='V17_part3+1.255746e-01*S30+1.163972e-01*S31+3.019445e+00*S32+1.741585e-01*S33+8.041372e-01*S34+1.997485e-01*S35+8.309193e-01*S36+8.453344e-01*S37+1.264545e-01*S38+3.511458e-01*S39'
.param V17_part5='V17_part4+3.889479e+01*S40+1.817252e+00*S41+3.727888e-01*S42+1.353494e+01*S43+1.246404e+00*S44+1.722289e-01*S45+7.810165e-01*S46+1.765504e-01*S47+2.756851e-01*S48+9.544031e-01*S49'
.param V17_part6='V17_part5+3.209785e-01*S50+3.056840e-01*S51+2.278398e+01*S52+6.878524e+01*S53+3.754716e-01*S54+2.706567e+01*S55+1.698333e+01*S56+1.062561e+00*S57+2.863758e+01*S58+7.014039e+01*S59'
.param V17_part7='V17_part6+6.233034e-01*S60+(-4.057757e-01)*S61+4.056004e+01*S62+2.840535e+00*S63+1.993159e+01*S64+1.000000e+04*S65+9.351787e+00*S66+1.619855e+01*S67+3.058691e-01*S68+1.487012e+01*S69'
.param V17_part8='V17_part7+3.871454e-01*S70+4.922263e-01*S71+2.300865e+01*S72+1.235737e+00*S73+3.227881e+00*S74+(-2.733612e+02)*S75+3.979008e-01*S76+2.131328e+03*S77+2.422841e+02*S78+1.041174e+02*S79'
.param V17='V17_part8+1.072687e+02*S80+1.007386e+01*S81+2.859626e+01*S82+1.134802e+02*S83+8.984913e+00*S84+5.940641e+01*S85+1.000000e+04*S86+6.618800e-01*S87+3.928507e+01*S88+5.855049e-01*S89'
.param V18_part1='5.124383e-02*S0+4.298819e-02*S1+2.197651e-02*S2+8.222012e-02*S3+3.319228e-02*S4+2.059309e-02*S5+5.734424e-02*S6+3.501523e-02*S7+2.150819e-02*S8+(-1.134232e+00)*S9'
.param V18_part2='V18_part1+3.361249e-02*S10+2.129978e-02*S11+1.525404e-01*S12+3.129933e-02*S13+1.849745e-02*S14+1.123089e-01*S15+3.156804e-02*S16+6.201862e-03*S17+1.135093e-01*S18+5.641920e-02*S19'
.param V18_part3='V18_part2+1.960043e-02*S20+1.133192e-01*S21+1.329486e-02*S22+3.151688e-02*S23+4.191529e-02*S24+7.897586e-02*S25+1.130691e-02*S26+2.127622e-03*S27+7.526536e-02*S28+7.429230e-03*S29'
.param V18_part4='V18_part3+4.053698e-02*S30+1.325650e-02*S31+(-2.565169e-01)*S32+3.965766e-02*S33+(-8.907486e-02)*S34+3.446399e-03*S35+(-9.429138e-02)*S36+(-3.608709e-02)*S37+2.594547e-02*S38+2.067967e-01*S39'
.param V18_part5='V18_part4+7.481956e+00*S40+(-4.567343e-02)*S41+1.424481e-01*S42+1.222206e+00*S43+(-9.930090e-03)*S44+4.898054e-02*S45+2.428133e-02*S46+1.361779e-02*S47+2.010608e-01*S48+1.704766e-02*S49'
.param V18_part6='V18_part5+1.454075e-02*S50+7.365433e-02*S51+3.761083e+00*S52+3.946346e+00*S53+7.303168e-02*S54+4.827365e+00*S55+3.124291e-01*S56+(-5.476796e-01)*S57+2.341820e+00*S58+8.279868e-01*S59'
.param V18_part7='V18_part6+4.138881e-02*S60+1.081856e-02*S61+7.155461e-01*S62+3.353333e-01*S63+9.145453e-01*S64+3.983311e+02*S65+2.164080e-01*S66+2.603887e-01*S67+9.689621e-03*S68+(-8.012963e-01)*S69'
.param V18_part8='V18_part7+1.680179e-02*S70+(-8.539267e-03)*S71+(-2.585753e+00)*S72+(-1.808678e+00)*S73+1.673571e-01*S74+8.768164e+01*S75+2.940081e-02*S76+9.758392e+01*S77+2.396429e+01*S78+6.781942e+00*S79'
.param V18='V18_part8+2.664759e+00*S80+(-2.525960e-01)*S81+8.985307e-01*S82+5.084292e+00*S83+(-8.086361e-01)*S84+1.764381e+00*S85+4.402191e+02*S86+2.738465e-03*S87+1.044591e+00*S88+(-4.353055e-03)*S89'
.param V19_part1='6.825779e-03*S0+5.566975e-04*S1+1.250849e-03*S2+8.900356e-03*S3+2.604162e-03*S4+1.414973e-03*S5+5.190911e-03*S6+1.941302e-03*S7+1.207154e-03*S8+1.355871e-01*S9'
.param V19_part2='V19_part1+2.675421e-03*S10+1.208163e-03*S11+1.616788e-02*S12+2.251343e-03*S13+1.321908e-03*S14+8.292845e-02*S15+9.991986e-03*S16+1.241849e-03*S17+1.126539e-01*S18+(-7.977050e-03)*S19'
.param V19_part3='V19_part2+(-9.393294e-02)*S20+1.530967e-01*S21+1.392273e-02*S22+(-6.040097e-02)*S23+3.278526e-02*S24+(-9.826871e-05)*S25+2.989083e-04*S26+(-1.600293e-03)*S27+6.796846e-02*S28+(-1.937881e-02)*S29'
.param V19_part4='V19_part3+2.365586e-02*S30+1.897111e-02*S31+(-6.922104e-01)*S32+3.595332e-02*S33+(-3.722170e-02)*S34+(-2.508511e-02)*S35+(-8.924664e-03)*S36+(-3.893308e-02)*S37+1.602821e-03*S38+1.820072e-01*S39'
.param V19_part5='V19_part4+(-4.465632e+00)*S40+(-4.390356e-02)*S41+1.157423e-01*S42+(-1.867669e-01)*S43+(-1.083514e-01)*S44+9.238661e-02*S45+(-1.348950e-02)*S46+(-1.813087e-02)*S47+4.512500e-01*S48+(-3.845836e-02)*S49'
.param V19_part6='V19_part5+(-3.510096e-02)*S50+1.175020e-01*S51+(-8.745808e+00)*S52+(-2.303473e+01)*S53+1.192002e-01*S54+(-7.532738e+00)*S55+(-6.849758e+00)*S56+1.938097e-02*S57+(-4.222375e+00)*S58+(-2.226043e+01)*S59'
.param V19_part7='V19_part6+(-1.289843e-01)*S60+2.116578e-01*S61+(-6.938933e+00)*S62+4.120077e-01*S63+(-4.934672e+00)*S64+(-1.515777e+02)*S65+(-3.060317e+00)*S66+(-2.938090e+00)*S67+7.179824e-02*S68+8.783282e+00*S69'
.param V19_part8='V19_part7+1.292371e-01*S70+(-1.618779e-01)*S71+2.542842e+01*S72+1.068464e+01*S73+(-1.947053e+00)*S74+(-1.533582e+03)*S75+1.077351e-01*S76+(-7.735792e+01)*S77+(-3.543415e+02)*S78+(-2.443977e+01)*S79'
.param V19='V19_part8+(-2.832454e+01)*S80+(-8.482127e+00)*S81+(-6.584674e+00)*S82+(-2.653936e+01)*S83+(-6.833856e+00)*S84+(-1.450397e+01)*S85+(-2.459530e+02)*S86+3.355021e-01*S87+(-7.115854e+00)*S88+8.215275e-02*S89'
.param V20_part1='1.609768e-02*S0+1.408562e-02*S1+2.287723e-02*S2+1.559420e-02*S3+1.582272e-02*S4+2.575668e-02*S5+1.353119e-02*S6+5.643912e-03*S7+2.465578e-02*S8+5.634653e-01*S9'
.param V20_part2='V20_part1+6.482436e-03*S10+2.617021e-02*S11+(-3.439042e-02)*S12+5.645392e-03*S13+1.390833e-02*S14+(-8.668394e-04)*S15+2.642401e-02*S16+1.470493e-02*S17+(-3.232829e-02)*S18+(-1.180163e-02)*S19'
.param V20_part3='V20_part2+2.619070e-02*S20+(-3.100785e-02)*S21+(-4.521407e-02)*S22+5.086160e-03*S23+(-1.195170e-03)*S24+(-4.991984e-02)*S25+2.830096e-02*S26+(-1.118104e-01)*S27+(-5.301433e-02)*S28+3.882783e-03*S29'
.param V20_part4='V20_part3+(-1.809477e-02)*S30+2.143513e-02*S31+(-1.574100e-01)*S32+(-5.077240e-02)*S33+1.788741e-01*S34+(-6.817880e-02)*S35+2.981892e-02*S36+3.810903e-01*S37+7.363581e-02*S38+(-1.507387e-01)*S39'
.param V20_part5='V20_part4+1.481332e+01*S40+(-4.953747e-02)*S41+(-1.774254e-01)*S42+6.767969e+00*S43+5.424915e-02*S44+(-1.842100e-03)*S45+3.757770e-01*S46+8.352998e-03*S47+(-1.496800e-01)*S48+7.213442e-01*S49'
.param V20_part6='V20_part5+(-1.761926e-01)*S50+(-7.657729e-02)*S51+9.830250e+00*S52+1.121782e+01*S53+(-8.212797e-02)*S54+1.218462e+01*S55+5.849694e+00*S56+2.350546e-01*S57+1.285244e+01*S58+1.857637e+01*S59'
.param V20_part7='V20_part6+(-4.097774e-02)*S60+1.215950e-01*S61+1.193325e+01*S62+2.904011e-01*S63+9.248918e+00*S64+2.350626e+03*S65+4.909038e+00*S66+8.010141e+00*S67+2.185278e-02*S68+1.957094e+00*S69'
.param V20_part8='V20_part7+(-8.893417e-02)*S70+(-4.941460e-01)*S71+5.939143e+00*S72+2.803015e+00*S73+7.674618e-01*S74+(-1.736512e+02)*S75+2.974263e-02*S76+6.014629e+02*S77+(-2.354408e+02)*S78+4.270472e+01*S79'
.param V20='V20_part8+4.755252e+01*S80+5.778806e+00*S81+1.711488e+01*S82+5.261536e+01*S83+5.953432e+00*S84+2.837028e+01*S85+3.872934e+03*S86+(-1.231144e-01)*S87+2.396461e+01*S88+(-4.161568e-01)*S89'
.param V21_part1='3.973081e-01*S0+3.569703e-01*S1+3.415526e-01*S2+4.419529e-01*S3+4.076146e-01*S4+3.553274e-01*S5+4.806345e-01*S6+4.317933e-01*S7+3.714932e-01*S8+5.897464e-01*S9'
.param V21_part2='V21_part1+4.544759e-01*S10+4.050699e-01*S11+6.089584e-01*S12+4.730161e-01*S13+4.372242e-01*S14+1.528320e+00*S15+1.250584e+00*S16+1.212324e+00*S17+1.705533e+00*S18+1.380845e+00*S19'
.param V21_part3='V21_part2+1.291959e+00*S20+1.822658e+00*S21+1.620546e+00*S22+1.367155e+00*S23+1.754012e+00*S24+1.580400e+00*S25+1.382219e+00*S26+2.363459e+00*S27+1.643346e+00*S28+1.460998e+00*S29'
.param V21_part4='V21_part3+3.050671e+00*S30+2.710748e+00*S31+3.760050e+00*S32+3.365574e+00*S33+3.427333e+00*S34+2.875777e+00*S35+3.905644e+00*S36+3.421423e+00*S37+2.884825e+00*S38+4.044306e+00*S39'
.param V21_part5='V21_part4+9.045177e+00*S40+3.119340e+00*S41+4.147934e+00*S42+4.388271e+00*S43+3.035941e+00*S44+4.945925e+00*S45+4.979085e+00*S46+4.578686e+00*S47+5.906450e+00*S48+5.243875e+00*S49'
.param V21_part6='V21_part5+4.953299e+00*S50+6.019197e+00*S51+1.065831e+01*S52+3.771106e+01*S53+6.331964e+00*S54+1.078742e+01*S55+1.163900e+01*S56+5.992477e+00*S57+8.425965e+00*S58+2.869384e+01*S59'
.param V21_part7='V21_part6+7.332156e+00*S60+6.538857e+00*S61+1.847177e+01*S62+9.943387e+00*S63+1.088906e+01*S64+2.365262e+03*S65+7.330896e+00*S66+9.996097e+00*S67+7.432529e+00*S68+1.010439e+01*S69'
.param V21_part8='V21_part7+8.240034e+00*S70+8.213428e+00*S71+8.107363e+00*S72+8.603568e+00*S73+1.068137e+01*S74+2.714891e+02*S75+9.339518e+00*S76+6.575472e+02*S77+5.047533e+02*S78+3.597049e+01*S79'
.param V21='V21_part8+4.197028e+01*S80+1.084566e+01*S81+1.495426e+01*S82+5.293496e+01*S83+1.179933e+01*S84+2.846409e+01*S85+1.682267e+03*S86+1.352650e+01*S87+1.428880e+01*S88+1.133368e+01*S89'
.param V22_part1='(-1.066054e-02)*S0+1.534138e-02*S1+1.597664e-02*S2+(-6.905766e-02)*S3+(-1.176390e-02)*S4+5.811530e-03*S5+(-1.274749e-01)*S6+(-3.133625e-02)*S7+(-7.404939e-03)*S8+(-8.559578e-01)*S9'
.param V22_part2='V22_part1+(-6.396444e-02)*S10+(-2.917795e-02)*S11+(-2.053515e-01)*S12+(-9.518307e-02)*S13+(-4.820621e-02)*S14+1.015658e-01*S15+1.055536e-01*S16+1.502095e-01*S17+(-2.273949e-02)*S18+4.729120e-02*S19'
.param V22_part3='V22_part2+8.875266e-02*S20+(-2.705703e-01)*S21+(-2.000694e-02)*S22+4.783223e-02*S23+(-4.617443e-01)*S24+(-1.137105e-01)*S25+2.802720e-03*S26+(-6.646390e-01)*S27+(-2.190135e-01)*S28+(-6.455124e-02)*S29'
.param V22_part4='V22_part3+3.971320e-01*S30+4.427291e-01*S31+5.950722e-01*S32+1.271917e-01*S33+2.203848e-01*S34+5.189317e-01*S35+(-2.263299e-01)*S36+(-1.384926e-01)*S37+3.812874e-01*S38+(-4.328937e-01)*S39'
.param V22_part5='V22_part4+(-1.436000e+01)*S40+1.013535e-01*S41+(-9.190985e-01)*S42+(-5.866398e+00)*S43+3.033809e-02*S44+1.131766e+00*S45+1.191798e+00*S46+1.555479e+00*S47+1.280464e+00*S48+6.057722e-01*S49'
.param V22_part6='V22_part5+1.431597e+00*S50+2.135349e-01*S51+(-7.502822e+00)*S52+(-5.632986e-01)*S53+(-4.492451e-01)*S54+(-1.033517e+01)*S55+1.238499e+00*S56+(-1.453428e+00)*S57+(-1.094564e+01)*S58+(-2.083444e+00)*S59'
.param V22_part7='V22_part6+1.995812e+00*S60+2.085425e+00*S61+1.692890e+00*S62+2.107639e+00*S63+(-4.257604e+00)*S64+(-2.411590e+03)*S65+(-2.198697e+00)*S66+(-4.065567e+00)*S67+2.712148e+00*S68+(-3.235084e+00)*S69'
.param V22_part8='V22_part7+1.333750e+00*S70+2.310941e+00*S71+(-3.226779e+00)*S72+(-3.991591e-03)*S73+5.404806e+00*S74+2.331502e+03*S75+4.710065e+00*S76+(-4.093163e+02)*S77+3.229903e+03*S78+(-3.438180e+01)*S79'
.param V22='V22_part8+6.444048e+00*S80+(-3.092394e-02)*S81+(-8.310712e+00)*S82+(-4.891047e-01)*S83+(-8.914540e-01)*S84+(-2.379949e+01)*S85+(-3.867722e+03)*S86+(-1.585744e-01)*S87+(-1.452955e+01)*S88+4.535854e+00*S89'
.param V23_part1='3.853802e-02*S0+3.614679e-02*S1+3.530777e-02*S2+3.751936e-02*S3+3.980513e-02*S4+3.635288e-02*S5+3.895758e-02*S6+3.822967e-02*S7+3.662668e-02*S8+2.631933e-02*S9'
.param V23_part2='V23_part1+3.787180e-02*S10+3.806232e-02*S11+4.775130e-02*S12+3.813020e-02*S13+4.003832e-02*S14+4.753969e-02*S15+3.869352e-02*S16+4.186393e-02*S17+4.969787e-02*S18+4.036261e-02*S19'
.param V23_part3='V23_part2+5.067064e-02*S20+4.914784e-02*S21+4.900885e-02*S22+5.305009e-02*S23+4.036977e-02*S24+4.524133e-02*S25+4.505470e-02*S26+6.873105e-02*S27+4.665852e-02*S28+4.820534e-02*S29'
.param V23_part4='V23_part3+4.042908e-02*S30+4.188081e-02*S31+6.045043e-02*S32+4.332266e-02*S33+6.127913e-02*S34+5.382837e-02*S35+4.969477e-02*S36+5.506544e-02*S37+5.064034e-02*S38+5.048609e-02*S39'
.param V23_part5='V23_part4+6.658680e-01*S40+4.697638e-02*S41+4.975929e-02*S42+9.406624e-02*S43+5.991048e-02*S44+3.688937e-02*S45+8.884286e-02*S46+6.441789e-02*S47+5.529541e-02*S48+5.160010e-02*S49'
.param V23_part6='V23_part5+5.118137e-02*S50+4.179272e-02*S51+2.122195e-01*S52+4.181895e-01*S53+4.259121e-02*S54+2.642781e-01*S55+(-3.251471e-03)*S56+4.534999e-02*S57+1.406767e-01*S58+(-9.242585e-03)*S59'
.param V23_part7='V23_part6+4.358497e-02*S60+5.185948e-02*S61+1.889446e-01*S62+7.761740e-02*S63+1.198915e-01*S64+8.623327e+01*S65+(-1.157911e-01)*S66+5.606430e-02*S67+4.745010e-02*S68+1.022233e-01*S69'
.param V23_part8='V23_part7+5.847978e-02*S70+7.430733e-02*S71+2.910322e-01*S72+4.774271e-02*S73+(-1.615338e-02)*S74+7.059675e+00*S75+4.824744e-02*S76+3.513055e+01*S77+1.246591e+01*S78+1.081155e+00*S79'
.param V23='V23_part8+7.746419e-01*S80+(-2.055168e-01)*S81+1.630828e-01*S82+2.029223e+00*S83+(-3.488850e-01)*S84+6.765944e-01*S85+1.546209e+02*S86+5.674436e-02*S87+1.256066e-01*S88+6.849927e-02*S89'
.param V24_part1='8.088735e-03*S0+6.737848e-03*S1+5.843602e-03*S2+8.158986e-03*S3+6.799110e-03*S4+5.907845e-03*S5+8.130480e-03*S6+6.854814e-03*S7+5.835587e-03*S8+8.481500e-03*S9'
.param V24_part2='V24_part1+6.806691e-03*S10+5.876877e-03*S11+9.149624e-03*S12+6.807843e-03*S13+6.179441e-03*S14+2.829100e-02*S15+2.304386e-02*S16+2.616412e-02*S17+2.684776e-02*S18+2.605204e-02*S19'
.param V24_part3='V24_part2+2.846094e-02*S20+1.799576e-02*S21+2.277407e-02*S22+2.740135e-02*S23+1.149051e-02*S24+2.188174e-02*S25+2.227781e-02*S26+(-4.543316e-04)*S27+2.117870e-02*S28+2.128982e-02*S29'
.param V24_part4='V24_part3+6.764427e-02*S30+6.675200e-02*S31+1.738508e-01*S32+5.159947e-02*S33+5.754076e-02*S34+8.309161e-02*S35+2.551019e-02*S36+2.413297e-02*S37+6.821408e-02*S38+2.557664e-02*S39'
.param V24_part5='V24_part4+(-4.659678e-01)*S40+9.006561e-02*S41+(-1.782351e-02)*S42+(-1.292691e-01)*S43+6.391368e-02*S44+1.244800e-01*S45+1.332607e-01*S46+1.755392e-01*S47+1.072572e-01*S48+4.880572e-02*S49'
.param V24_part6='V24_part5+1.669111e-01*S50+5.892182e-02*S51+(-7.427374e-01)*S52+(-2.752043e+00)*S53+1.718538e-02*S54+(-6.883679e-01)*S55+(-7.047614e-01)*S56+1.057619e-02*S57+(-1.770227e-01)*S58+(-1.577464e+00)*S59'
.param V24_part7='V24_part6+2.588872e-01*S60+2.678769e-01*S61+(-4.296177e-01)*S62+1.370353e-01*S63+(-4.105067e-01)*S64+4.962129e+01*S65+(-4.413542e-01)*S66+(-3.239067e-01)*S67+2.362194e-01*S68+2.628991e+00*S69'
.param V24_part8='V24_part7+1.731189e-01*S70+4.106736e-01*S71+7.127207e+00*S72+3.255454e+00*S73+3.956930e-01*S74+3.821067e+00*S75+3.895108e-01*S76+3.277534e+01*S77+(-1.227242e+01)*S78+(-2.050194e+00)*S79'
.param V24='V24_part8+(-7.651200e-01)*S80+(-8.906640e-01)*S81+(-8.494834e-01)*S82+(-1.580384e+00)*S83+(-8.735642e-01)*S84+(-1.834366e+00)*S85+(-1.933455e+01)*S86+(-8.047190e-03)*S87+(-1.263657e+00)*S88+3.318452e-01*S89'
.param V25_part1='4.339206e-01*S0+3.496669e+00*S1+(-1.631721e-01)*S2+(-4.540689e-02)*S3+3.001928e-03*S4+(-1.417279e-01)*S5+(-3.795572e-02)*S6+1.673650e+00*S7+2.056308e+00*S8+(-6.046436e-02)*S9'
.param V25_part2='V25_part1+(-5.270650e-03)*S10+(-4.873344e-02)*S11+1.063648e+00*S12+(-1.469675e-02)*S13+(-2.073599e-01)*S14+3.618038e-01*S15+6.261463e-02*S16+5.709455e-02*S17+9.736328e-01*S18+3.401647e+00*S19'
.param V25_part3='V25_part2+8.877438e-01*S20+7.536014e-01*S21+4.878892e-01*S22+1.577795e+00*S23+6.263529e-01*S24+3.009786e+00*S25+1.205209e+00*S26+3.012268e+00*S27+2.587827e+00*S28+2.611851e+00*S29'
.param V25_part4='V25_part3+1.216443e+00*S30+1.570139e-01*S31+3.327641e-01*S32+2.199337e+01*S33+2.668431e+00*S34+8.253329e-02*S35+4.351860e+00*S36+2.227732e+00*S37+5.085386e-02*S38+1.262448e+00*S39'
.param V25_part5='V25_part4+(-1.346898e-01)*S40+2.189747e+00*S41+1.367993e+00*S42+(-9.347984e-02)*S43+7.858246e-01*S44+4.479151e-01*S45+2.376831e+00*S46+7.300565e-01*S47+1.940108e+00*S48+1.924392e+00*S49'
.param V25_part6='V25_part5+5.173667e-01*S50+2.064192e-01*S51+(-2.338296e-02)*S52+(-2.734334e-02)*S53+1.253530e-01*S54+(-5.626452e-02)*S55+1.870494e-01*S56+3.988483e+00*S57+(-1.140276e-01)*S58+(-3.351237e-02)*S59'
.param V25_part7='V25_part6+1.989931e+00*S60+2.396332e+00*S61+4.754035e-02*S62+2.626999e+00*S63+(-1.048359e-02)*S64+(-3.048215e-01)*S65+(-1.056261e-01)*S66+(-1.008262e-01)*S67+(-4.445706e-01)*S68+1.441914e-02*S69'
.param V25_part8='V25_part7+7.598501e-02*S70+(-5.777684e-02)*S71+(-2.045616e-01)*S72+(-2.574464e-01)*S73+9.352665e-01*S74+(-1.110797e-01)*S75+1.328442e+00*S76+(-2.130326e-01)*S77+(-1.815698e-01)*S78+(-8.453671e-02)*S79'
.param V25='V25_part8+(-1.429034e-02)*S80+6.006653e-02*S81+(-9.022216e-02)*S82+(-3.174091e-02)*S83+1.732209e-01*S84+9.178484e-03*S85+(-4.060968e-01)*S86+(-2.243020e-01)*S87+(-1.445694e-01)*S88+(-2.413900e-01)*S89'
.param V26_part1='5.814054e-02*S0+(-1.241503e+00)*S1+5.463809e-01*S2+2.185733e+00*S3+5.817139e-01*S4+3.886600e-01*S5+1.038125e+00*S6+(-1.385699e-01)*S7+(-4.310831e-01)*S8+6.850288e-01*S9'
.param V26_part2='V26_part1+1.035251e+00*S10+7.592172e-01*S11+1.613136e+00*S12+9.353522e-01*S13+3.884984e-01*S14+5.314149e+00*S15+9.782526e-01*S16+1.369036e-01*S17+2.891064e+00*S18+(-1.824242e+00)*S19'
.param V26_part3='V26_part2+5.475860e-01*S20+2.814320e+00*S21+(-9.615720e-02)*S22+(-1.295931e-01)*S23+1.526878e-01*S24+(-1.303193e+00)*S25+1.796189e-01*S26+(-6.626071e-01)*S27+(-7.941156e-01)*S28+(-8.373423e-01)*S29'
.param V26_part4='V26_part3+2.782348e+00*S30+(-1.001601e-02)*S31+(-5.114964e-03)*S32+1.923435e+00*S33+(-1.300341e+00)*S34+3.712218e-02*S35+(-2.266028e+00)*S36+(-7.951014e-01)*S37+6.062277e-01*S38+1.345908e+00*S39'
.param V26_part5='V26_part4+1.515654e-01*S40+(-1.265318e+00)*S41+(-1.493512e-01)*S42+3.408588e-01*S43+4.582552e-01*S44+1.095066e-01*S45+(-8.509286e-01)*S46+4.317706e-01*S47+2.279591e+00*S48+(-4.594632e-01)*S49'
.param V26_part6='V26_part5+8.323840e-02*S50+5.631228e-01*S51+1.979628e-01*S52+(-8.137293e-02)*S53+4.855380e-01*S54+2.015949e-01*S55+3.302532e-02*S56+(-9.482845e-02)*S57+2.666222e-01*S58+(-1.000483e-04)*S59'
.param V26_part7='V26_part6+2.345859e+00*S60+(-3.162887e-01)*S61+(-4.770362e-02)*S62+(-1.206704e+00)*S63+3.066405e-01*S64+(-2.836081e-01)*S65+1.441312e+00*S66+4.527738e-01*S67+1.015261e+00*S68+5.091215e-01*S69'
.param V26_part8='V26_part7+5.836091e-01*S70+5.178058e-01*S71+5.089344e-01*S72+4.735906e-01*S73+1.348924e-01*S74+(-3.918422e-01)*S75+3.982954e-01*S76+(-2.450959e-01)*S77+(-3.273701e-01)*S78+(-1.699073e-02)*S79'
.param V26='V26_part8+(-3.823527e-02)*S80+1.584907e+00*S81+3.087649e-01*S82+(-4.088395e-02)*S83+1.298062e+00*S84+5.397997e-03*S85+(-1.658387e-01)*S86+(-6.546386e-02)*S87+2.769462e-01*S88+6.340250e-01*S89'
.param V27_part1='(-5.055039e-01)*S0+(-1.332680e+00)*S1+1.384441e-01*S2+2.241879e+00*S3+3.363884e-01*S4+2.008777e-01*S5+1.186863e+00*S6+(-6.325250e-01)*S7+(-3.947184e-01)*S8+6.345456e-01*S9'
.param V27_part2='V27_part1+1.712515e-01*S10+(-2.538864e-02)*S11+1.475478e+00*S12+2.475498e-01*S13+1.022382e-01*S14+4.901971e-01*S15+1.504117e-01*S16+(-1.578410e-01)*S17+5.257087e-01*S18+(-4.732601e-01)*S19'
.param V27_part3='V27_part2+(-1.486007e-01)*S20+1.306117e+00*S21+(-1.743712e-01)*S22+(-2.427714e-01)*S23+(-8.786597e-01)*S24+(-4.734191e-01)*S25+(-2.159148e-01)*S26+(-1.652164e+00)*S27+(-3.843817e-01)*S28+3.542523e-01*S29'
.param V27_part4='V27_part3+(-3.358513e+01)*S30+4.944349e-01*S31+(-1.434830e-01)*S32+(-2.564680e+02)*S33+(-7.588411e-01)*S34+(-1.272419e-01)*S35+(-2.982367e+00)*S36+(-2.284138e-01)*S37+4.265919e-01*S38+(-7.210696e-01)*S39'
.param V27_part5='V27_part4+3.427416e-01*S40+1.772733e-01*S41+(-7.039154e-01)*S42+5.274645e-01*S43+3.546642e-01*S44+(-4.974725e-01)*S45+(-8.453113e-01)*S46+2.533422e-01*S47+(-2.226143e+00)*S48+1.221800e-01*S49'
.param V27_part6='V27_part5+2.393013e-02*S50+(-1.959753e-01)*S51+5.639456e-01*S52+2.359048e-01*S53+(-2.576252e-01)*S54+5.428214e-01*S55+2.396489e-01*S56+(-2.323980e+00)*S57+6.637033e-01*S58+1.688833e-01*S59'
.param V27_part7='V27_part6+(-1.292906e+00)*S60+(-8.196446e-01)*S61+4.543498e-01*S62+(-7.060455e-01)*S63+9.801385e-01*S64+3.031422e-01*S65+1.744458e+00*S66+1.277295e+00*S67+3.967522e-01*S68+(-2.271769e-01)*S69'
.param V27_part8='V27_part7+1.535782e+00*S70+(-1.395282e-01)*S71+(-4.149426e-01)*S72+1.258736e-01*S73+6.100329e-02*S74+2.410874e-01*S75+(-5.877276e-01)*S76+2.761504e-01*S77+4.036498e-01*S78+6.591810e-01*S79'
.param V27='V27_part8+2.494210e-01*S80+1.594313e+00*S81+1.027059e+00*S82+2.516940e-01*S83+1.419467e+00*S84+6.884425e-01*S85+3.816165e-01*S86+(-3.517628e-01)*S87+9.465991e-01*S88+2.974932e-01*S89'
.param V28_part1='(-1.384688e-02)*S0+(-2.392787e-01)*S1+(-3.038161e-02)*S2+2.922477e-01*S3+(-8.687061e-02)*S4+(-4.221407e-02)*S5+1.217149e-01*S6+(-4.592440e-02)*S7+(-3.364049e-02)*S8+6.820520e-02*S9'
.param V28_part2='V28_part1+9.751886e-02*S10+1.716818e-01*S11+(-1.416442e-01)*S12+6.077315e-02*S13+(-6.308480e-02)*S14+(-7.830241e-03)*S15+3.791003e-02*S16+(-3.700345e-02)*S17+(-1.950975e-01)*S18+(-2.957978e-01)*S19'
.param V28_part3='V28_part2+(-1.132984e-01)*S20+(-2.214353e-01)*S21+(-3.384425e-02)*S22+(-1.698315e-01)*S23+(-1.203431e-02)*S24+(-2.434431e-01)*S25+(-8.303476e-03)*S26+(-1.750622e-01)*S27+(-8.055249e-02)*S28+(-4.393714e-02)*S29'
.param V28_part4='V28_part3+(-1.029998e-02)*S30+(-1.116702e-02)*S31+4.189755e-04*S32+1.661291e-01*S33+(-1.550582e-01)*S34+3.360303e-03*S35+(-2.017466e-01)*S36+(-8.580387e-02)*S37+5.987432e-02*S38+9.796548e-02*S39'
.param V28_part5='V28_part4+(-2.160171e-02)*S40+1.313751e-01*S41+1.441035e-01*S42+(-1.567292e-02)*S43+7.146417e-02*S44+(-1.260493e-02)*S45+(-6.989860e-02)*S46+3.470607e-02*S47+6.116301e-02*S48+(-1.019964e-02)*S49'
.param V28_part6='V28_part5+2.677825e-02*S50+1.922386e-02*S51+(-1.443123e-02)*S52+(-6.668942e-03)*S53+1.077288e-02*S54+(-1.756152e-02)*S55+(-6.439785e-05)*S56+4.634612e-01*S57+(-1.640016e-02)*S58+(-6.294940e-03)*S59'
.param V28_part7='V28_part6+1.710508e-04*S60+(-2.685169e-02)*S61+(-3.362378e-03)*S62+(-8.411012e-02)*S63+(-1.371806e-02)*S64+(-1.174852e-02)*S65+4.032511e-02*S66+(-1.441004e-02)*S67+2.255540e-03*S68+8.040695e-03*S69'
.param V28_part8='V28_part7+(-4.770452e-02)*S70+2.423251e-02*S71+3.272299e-03*S72+1.522057e-02*S73+(-1.056997e-03)*S74+(-7.330768e-03)*S75+(-1.651766e-02)*S76+(-1.280889e-02)*S77+(-1.069639e-02)*S78+(-1.536183e-02)*S79'
.param V28='V28_part8+(-8.898741e-03)*S80+5.693495e-02*S81+(-2.028238e-02)*S82+(-1.278587e-02)*S83+8.311661e-02*S84+(-2.111731e-02)*S85+(-2.040732e-02)*S86+(-2.284175e-02)*S87+(-2.406333e-02)*S88+2.429538e-02*S89'
.param V29_part1='(-7.071086e-04)*S0+(-4.956619e-02)*S1+1.625351e-02*S2+3.409069e-02*S3+2.959325e-02*S4+1.542799e-02*S5+1.173427e-02*S6+(-1.113296e-02)*S7+4.522633e-03*S8+1.043533e-02*S9'
.param V29_part2='V29_part1+2.697976e-02*S10+9.868735e-04*S11+4.970276e-02*S12+1.099076e-02*S13+1.105428e-02*S14+1.116341e-01*S15+(-7.970716e-03)*S16+9.621933e-03*S17+1.814479e-01*S18+7.040901e-02*S19'
.param V29_part3='V29_part2+(-3.759135e-03)*S20+5.500144e-01*S21+1.433706e-02*S22+(-3.557798e-02)*S23+(-1.775548e-02)*S24+2.815884e-02*S25+(-5.730694e-02)*S26+(-4.410854e-02)*S27+(-5.282388e-04)*S28+9.612312e-02*S29'
.param V29_part4='V29_part3+(-4.718354e-01)*S30+(-1.331956e-03)*S31+(-3.346686e-02)*S32+(-6.939331e-02)*S33+(-1.584429e-01)*S34+(-4.786135e-02)*S35+(-2.288444e-01)*S36+(-8.396037e-02)*S37+(-4.461724e-02)*S38+(-7.725305e-02)*S39'
.param V29_part5='V29_part4+(-2.977923e-03)*S40+(-1.046800e-01)*S41+1.747668e-01*S42+4.003477e-04*S43+2.933044e-02*S44+(-4.362752e-02)*S45+(-2.509362e-01)*S46+(-1.249727e-01)*S47+1.368934e-01*S48+(-1.121522e-01)*S49'
.param V29_part6='V29_part5+(-9.335773e-02)*S50+(-1.633224e-01)*S51+1.374024e-02*S52+2.968837e-03*S53+(-1.527033e-01)*S54+5.803757e-03*S55+1.114763e-02*S56+(-2.294127e-01)*S57+(-9.570684e-03)*S58+(-1.300581e-03)*S59'
.param V29_part7='V29_part6+(-2.233683e-01)*S60+(-2.851773e-01)*S61+(-1.666156e-02)*S62+(-2.750479e-01)*S63+5.061739e-03*S64+(-4.962722e-02)*S65+6.684631e-03*S66+1.334858e-02*S67+(-5.410234e-03)*S68+(-1.414704e-01)*S69'
.param V29_part8='V29_part7+2.812404e-03*S70+(-4.355916e-01)*S71+(-1.648330e-01)*S72+(-1.514073e-01)*S73+(-7.341895e-02)*S74+(-1.470928e-01)*S75+(-9.624708e-02)*S76+(-4.801586e-02)*S77+(-1.781820e-01)*S78+(-9.475810e-03)*S79'
.param V29='V29_part8+(-1.876997e-02)*S80+(-1.432980e-01)*S81+1.682505e-02*S82+(-1.408691e-02)*S83+(-2.427754e-01)*S84+2.972858e-03*S85+(-3.459789e-02)*S86+(-6.573547e-02)*S87+1.452180e-02*S88+(-7.179585e-03)*S89'
.param V30_part1='3.706038e-01*S0+(-6.093446e-01)*S1+(-1.318573e+00)*S2+(-2.548585e-01)*S3+(-6.355774e-01)*S4+(-1.651080e+00)*S5+3.069788e-01*S6+(-1.133720e+00)*S7+(-2.627591e+00)*S8+(-7.838179e-01)*S9'
.param V30_part2='V30_part1+(-7.103328e-01)*S10+(-2.834686e+00)*S11+(-4.839958e-01)*S12+(-1.152592e+00)*S13+(-2.738161e+00)*S14+(-4.406159e-01)*S15+(-1.548134e+00)*S16+(-5.125573e+00)*S17+(-5.509951e-01)*S18+(-2.305981e+00)*S19'
.param V30_part3='V30_part2+(-7.202019e+00)*S20+(-2.538546e-01)*S21+(-3.445002e+00)*S22+(-8.678548e+00)*S23+(-4.873091e-01)*S24+(-4.118890e+00)*S25+(-6.366622e-01)*S26+(-1.570600e+00)*S27+(-1.203042e+00)*S28+(-4.053271e+00)*S29'
.param V30_part4='V30_part3+(-2.125028e+00)*S30+(-3.525974e+00)*S31+(-1.103372e+01)*S32+(-2.072039e+00)*S33+(-6.276408e+00)*S34+(-9.304996e+00)*S35+(-3.590382e+00)*S36+(-4.067699e-01)*S37+2.616224e-01*S38+7.309001e-01*S39'
.param V30_part5='V30_part4+5.921385e-01*S40+(-5.531528e+00)*S41+(-2.268504e+00)*S42+6.243197e+00*S43+(-4.074020e+00)*S44+(-5.676831e+00)*S45+1.742656e+00*S46+3.619036e+00*S47+(-1.000805e-02)*S48+1.568561e+00*S49'
.param V30_part6='V30_part5+(-3.846305e+00)*S50+(-2.758182e+00)*S51+(-2.790906e-01)*S52+(-7.697910e+00)*S53+(-2.933488e+00)*S54+7.613367e-02*S55+(-9.562904e+00)*S56+(-1.076976e+00)*S57+(-1.761981e+00)*S58+(-1.073617e+01)*S59'
.param V30_part7='V30_part6+(-2.145160e-01)*S60+(-5.550150e-01)*S61+4.398268e+00*S62+(-6.494964e+00)*S63+2.508282e+00*S64+5.490904e-01*S65+(-2.456305e+00)*S66+6.324644e+00*S67+(-1.389064e+00)*S68+(-6.287049e+00)*S69'
.param V30_part8='V30_part7+(-1.648515e+01)*S70+(-2.097550e+01)*S71+(-4.773166e+00)*S72+(-1.136024e+01)*S73+(-9.616290e+00)*S74+(-2.896075e+00)*S75+(-3.323088e+00)*S76+(-1.585688e+01)*S77+(-7.164534e+00)*S78+(-1.308393e+01)*S79'
.param V30='V30_part8+(-2.605768e+01)*S80+(-7.717059e+00)*S81+(-2.668616e+00)*S82+(-3.033734e+01)*S83+(-8.682801e+00)*S84+(-1.805374e+01)*S85+(-5.760017e+00)*S86+(-7.165100e+00)*S87+(-9.751446e+00)*S88+(-5.115680e+00)*S89'
.param V31_part1='2.643411e+00*S0+2.277738e+00*S1+2.304676e+00*S2+1.684148e+00*S3+2.422033e+00*S4+3.148749e+00*S5+4.290320e-01*S6+2.395133e+00*S7+3.867651e+00*S8+1.884715e+00*S9'
.param V31_part2='V31_part1+1.974241e+00*S10+3.459293e+00*S11+1.351046e+00*S12+2.281019e+00*S13+3.419103e+00*S14+7.660175e+00*S15+9.554459e+00*S16+1.069887e+01*S17+6.111213e+00*S18+1.030201e+01*S19'
.param V31_part3='V31_part2+9.633970e+00*S20+5.520757e+00*S21+1.099415e+01*S22+9.860049e+00*S23+7.403827e+00*S24+5.199170e+00*S25+4.344048e+00*S26+2.396479e+00*S27+3.032260e+00*S28+8.395147e+00*S29'
.param V31_part4='V31_part3+1.967428e+01*S30+1.190545e+01*S31+1.460688e+01*S32+8.195540e+00*S33+9.631747e+00*S34+1.362149e+01*S35+7.328967e+00*S36+3.102326e+00*S37+(-2.434643e+00)*S38+3.922336e+00*S39'
.param V31_part5='V31_part4+1.111042e+00*S40+7.803375e+00*S41+6.796311e+00*S42+5.924366e-01*S43+1.240556e+01*S44+4.853126e+01*S45+(-3.569807e+00)*S46+(-5.867537e-01)*S47+1.852246e+00*S48+1.503345e+00*S49'
.param V31_part6='V31_part5+4.243567e+00*S50+8.842069e+00*S51+1.445364e+01*S52+2.136352e+01*S53+8.252913e+00*S54+1.420058e+01*S55+2.021360e+01*S56+5.290054e+00*S57+1.471012e+01*S58+2.003033e+01*S59'
.param V31_part7='V31_part6+3.192999e+00*S60+(-1.250277e+01)*S61+1.366139e+00*S62+1.610730e+01*S63+4.773851e+00*S64+3.446677e+00*S65+1.020075e+01*S66+3.219583e+00*S67+(-8.048555e+00)*S68+1.005359e+01*S69'
.param V31_part8='V31_part7+1.354035e+01*S70+2.791697e+01*S71+1.020777e+01*S72+7.821801e+00*S73+2.487227e+01*S74+1.709723e+01*S75+1.222490e+01*S76+1.472669e+01*S77+1.766459e+01*S78+1.418467e+01*S79'
.param V31='V31_part8+2.531064e+01*S80+1.409634e+01*S81+3.278291e+00*S82+2.660094e+01*S83+1.322019e+01*S84+1.461379e+01*S85+3.785811e+00*S86+8.132474e+00*S87+6.065823e+00*S88+2.076264e+00*S89'
.param V32_part1='1.204278e+00*S0+2.651551e+00*S1+3.158544e+00*S2+2.514141e+00*S3+2.538305e+00*S4+4.027601e+00*S5+2.632338e+00*S6+3.812942e+00*S7+4.656508e+00*S8+4.256995e+00*S9'
.param V32_part2='V32_part1+4.181261e+00*S10+5.242529e+00*S11+5.987210e+00*S12+4.833585e+00*S13+5.797089e+00*S14+8.198648e+00*S15+7.636354e+00*S16+8.062415e+00*S17+9.550572e+00*S18+1.034160e+01*S19'
.param V32_part3='V32_part2+1.352899e+01*S20+6.522989e+00*S21+1.417352e+01*S22+1.524511e+01*S23+8.606045e+00*S24+1.381870e+01*S25+8.270194e+00*S26+1.376254e+01*S27+8.498755e+00*S28+1.324185e+01*S29'
.param V32_part4='V32_part3+1.832386e+01*S30+1.316607e+01*S31+2.209241e+01*S32+1.348678e+01*S33+1.611136e+01*S34+2.216219e+01*S35+1.124805e+01*S36+1.324371e+01*S37+1.912506e+01*S38+8.873309e+00*S39'
.param V32_part5='V32_part4+1.678103e+01*S40+2.145744e+01*S41+9.155766e+00*S42+6.320346e+00*S43+2.502286e+01*S44+4.826920e+01*S45+1.745178e+01*S46+1.402581e+01*S47+1.592757e+01*S48+1.694993e+01*S49'
.param V32_part6='V32_part5+1.440288e+01*S50+2.299628e+01*S51+2.885888e+01*S52+3.802821e+01*S53+2.566950e+01*S54+3.058727e+01*S55+4.113847e+01*S56+2.516338e+01*S57+3.508693e+01*S58+4.286530e+01*S59'
.param V32_part7='V32_part6+2.104110e+01*S60+3.783691e+01*S61+2.571726e+01*S62+3.672363e+01*S63+1.748298e+01*S64+3.726158e+01*S65+7.550879e+00*S66+1.368241e+01*S67+3.570129e+01*S68+4.025771e+01*S69'
.param V32_part8='V32_part7+4.744639e+01*S70+6.164032e+01*S71+3.122048e+01*S72+5.828345e+01*S73+5.706678e+01*S74+2.038710e+01*S75+3.322539e+01*S76+5.101019e+01*S77+2.786765e+01*S78+5.332234e+01*S79'
.param V32='V32_part8+6.225301e+01*S80+4.650257e+01*S81+3.915351e+01*S82+6.518820e+01*S83+4.969884e+01*S84+5.921022e+01*S85+5.666010e+01*S86+4.308797e+01*S87+5.629213e+01*S88+2.781033e+01*S89'
.param V33_part1='5.491032e-01*S0+4.873267e-01*S1+9.220853e-01*S2+5.909232e-01*S3+6.372410e-01*S4+9.442799e-01*S5+(-9.322576e-02)*S6+6.691331e-01*S7+9.576459e-01*S8+4.900659e-01*S9'
.param V33_part2='V33_part1+5.583766e-01*S10+9.947225e-01*S11+2.645953e-01*S12+6.022569e-01*S13+7.236555e-01*S14+2.413342e-01*S15+3.428750e-01*S16+1.213719e+00*S17+3.705750e-01*S18+3.944623e-01*S19'
.param V33_part3='V33_part2+1.726971e+00*S20+3.277769e-01*S21+6.160014e-01*S22+1.794515e+00*S23+5.104787e-01*S24+1.445199e+00*S25+(-3.204200e-01)*S26+5.370226e-02*S27+(-8.388612e-01)*S28+3.463032e-01*S29'
.param V33_part4='V33_part3+6.143309e-01*S30+2.873804e-01*S31+1.808186e+00*S32+2.267536e-01*S33+8.386938e-01*S34+8.660773e-01*S35+6.834944e-02*S36+5.068032e-02*S37+1.369126e+00*S38+1.105597e-02*S39'
.param V33_part5='V33_part4+2.720998e-01*S40+5.643072e-01*S41+4.159472e-01*S42+3.441146e-01*S43+4.614855e-01*S44+1.048150e+00*S45+6.931833e-03*S46+8.938942e-01*S47+2.840877e-01*S48+(-3.188502e-01)*S49'
.param V33_part6='V33_part5+(-8.398663e-02)*S50+4.308665e-01*S51+3.668763e-01*S52+6.400880e-01*S53+4.314111e-01*S54+4.543244e-01*S55+9.209046e-01*S56+(-2.399685e-01)*S57+6.933703e-01*S58+1.108653e+00*S59'
.param V33_part7='V33_part6+2.433686e-01*S60+4.153826e-01*S61+1.772063e-01*S62+1.066632e-02*S63+6.334019e-01*S64+2.072985e-01*S65+2.991895e-01*S66+9.924907e-01*S67+1.769084e+00*S68+5.423574e-01*S69'
.param V33_part8='V33_part7+1.737103e+00*S70+1.029860e+00*S71+1.998573e-01*S72+8.199028e-01*S73+1.014814e+00*S74+(-1.410136e-01)*S75+4.763334e-01*S76+3.434855e+00*S77+2.412472e-01*S78+1.630578e+00*S79'
.param V33='V33_part8+2.554370e+00*S80+2.895617e-01*S81+1.567364e+00*S82+2.700579e+00*S83+4.513904e-01*S84+2.117986e+00*S85+3.073379e+00*S86+3.031012e-01*S87+1.760022e+00*S88+1.189654e-01*S89'
.param V34_part1='8.020655e-02*S0+3.020145e-02*S1+3.014554e-02*S2+3.208967e-02*S3+3.615534e-02*S4+2.508364e-02*S5+3.535695e-02*S6+2.455514e-02*S7+3.212512e-02*S8+4.898693e-02*S9'
.param V34_part2='V34_part1+2.694942e-02*S10+2.266800e-02*S11+2.942151e-04*S12+2.225305e-02*S13+2.304550e-02*S14+(-5.282521e-01)*S15+(-3.717428e-01)*S16+3.806000e-01*S17+(-7.662747e-01)*S18+(-1.059673e+00)*S19'
.param V34_part3='V34_part2+4.597770e-01*S20+(-8.545251e-01)*S21+(-1.370608e+00)*S22+5.353590e-01*S23+(-1.302463e+00)*S24+4.291349e-01*S25+4.662271e-01*S26+2.424297e-01*S27+1.856350e-01*S28+(-1.910032e+00)*S29'
.param V34_part4='V34_part3+(-7.207113e-01)*S30+4.647534e-01*S31+1.080584e+00*S32+9.538386e-01*S33+6.902525e-01*S34+1.309251e+00*S35+5.464975e-01*S36+(-2.529183e-01)*S37+2.285783e-01*S38+(-5.271836e-01)*S39'
.param V34_part5='V34_part4+1.700000e-01*S40+(-2.126797e+00)*S41+1.119054e+00*S42+5.190101e-01*S43+(-4.455589e+00)*S44+(-6.938180e-01)*S45+1.028521e+00*S46+1.048107e+00*S47+1.658729e+00*S48+(-8.108417e-01)*S49'
.param V34_part6='V34_part5+3.742301e-01*S50+(-6.538130e-01)*S51+(-3.926505e+00)*S52+(-5.765832e+00)*S53+(-9.624281e-01)*S54+(-4.954184e+00)*S55+(-6.303769e+00)*S56+(-6.503029e-02)*S57+(-5.663521e+00)*S58+(-6.850718e+00)*S59'
.param V34_part7='V34_part6+3.755009e-01*S60+1.109740e+00*S61+(-1.170664e+00)*S62+1.320886e+00*S63+1.822970e-01*S64+(-3.019494e+00)*S65+1.953748e+00*S66+5.321596e-01*S67+7.327190e+00*S68+1.836693e+00*S69'
.param V34_part8='V34_part7+2.384989e+00*S70+(-3.167494e+00)*S71+(-3.509178e-01)*S72+(-1.821647e+00)*S73+(-1.038643e+01)*S74+1.001135e+00*S75+9.384861e-01*S76+3.473020e+00*S77+1.196045e+00*S78+2.138370e+00*S79'
.param V34='V34_part8+3.612114e+00*S80+2.419844e+00*S81+1.802126e+00*S82+4.040272e+00*S83+2.429904e+00*S84+3.274611e+00*S85+4.492143e+00*S86+3.250950e+00*S87+2.983081e+00*S88+1.378039e+00*S89'
.param V35_part1='2.091115e+01*S0+2.025296e+02*S1+2.626753e+01*S2+3.416833e+01*S3+2.976011e+01*S4+1.468534e+02*S5+5.085415e+00*S6+7.599027e+03*S7+7.607742e+03*S8+2.200446e+01*S9'
.param V35_part2='V35_part1+8.577525e+01*S10+1.151267e+03*S11+5.458616e+02*S12+4.659038e+01*S13+1.842788e+01*S14+1.059868e+02*S15+2.670502e+02*S16+1.004169e+01*S17+1.828203e+01*S18+1.916585e+02*S19'
.param V35_part3='V35_part2+2.852393e+01*S20+9.448896e+00*S21+4.675172e+02*S22+2.361919e+01*S23+1.652417e+01*S24+2.334106e+01*S25+1.533159e+01*S26+8.324549e+02*S27+7.822248e+00*S28+1.913135e+01*S29'
.param V35_part4='V35_part3+2.549430e+02*S30+7.908736e+00*S31+8.651028e+00*S32+9.717920e+00*S33+1.213095e+01*S34+1.337267e+01*S35+1.767317e+01*S36+1.796485e+01*S37+1.334676e+02*S38+1.224184e+01*S39'
.param V35_part5='V35_part4+1.250635e+01*S40+8.028213e+00*S41+5.655939e+00*S42+3.819018e+00*S43+9.776044e+01*S44+5.469450e+01*S45+7.086267e+00*S46+9.053360e+00*S47+9.822796e+00*S48+1.545597e+01*S49'
.param V35_part6='V35_part5+4.695438e+00*S50+7.759996e+00*S51+3.725614e+01*S52+3.779197e+01*S53+7.622918e+00*S54+1.266687e+02*S55+7.438761e+01*S56+1.193552e+01*S57+4.283160e+02*S58+2.303121e+01*S59'
.param V35_part7='V35_part6+1.116598e+01*S60+2.716946e+02*S61+7.122833e+00*S62+3.048187e+01*S63+6.861321e+00*S64+5.549009e+00*S65+1.494739e+01*S66+1.474676e+01*S67+3.388596e+00*S68+7.633480e+00*S69'
.param V35_part8='V35_part7+1.891163e+03*S70+3.254580e+00*S71+5.289575e+00*S72+5.955379e+00*S73+2.382396e+01*S74+2.319754e+01*S75+5.938951e+00*S76+7.448950e+00*S77+8.564432e+00*S78+3.360200e+02*S79'
.param V35='V35_part8+4.926083e+03*S80+1.379917e+01*S81+7.173542e+00*S82+2.485594e+03*S83+1.025042e+01*S84+8.032193e+01*S85+4.594926e+00*S86+7.963642e+00*S87+8.360903e+00*S88+1.200497e+00*S89'
.param V36_part1='2.972901e+00*S0+(-2.437468e+00)*S1+8.482387e+00*S2+(-6.186880e+00)*S3+(-2.285399e+01)*S4+2.596948e+00*S5+(-6.606349e+00)*S6+(-2.037907e+01)*S7+3.231900e+00*S8+(-6.566718e+00)*S9'
.param V36_part2='V36_part1+(-3.731022e+00)*S10+(-4.267588e+01)*S11+(-4.045761e+01)*S12+(-1.128190e+01)*S13+(-4.610221e+00)*S14+(-7.377608e+01)*S15+1.158347e+02*S16+(-2.888480e+00)*S17+(-9.592243e+00)*S18+(-1.891796e+00)*S19'
.param V36_part3='V36_part2+(-3.164506e+00)*S20+(-3.317754e+00)*S21+(-1.470080e+02)*S22+(-4.120630e+00)*S23+(-1.934662e+00)*S24+(-3.657387e+00)*S25+(-4.881388e+00)*S26+8.266386e+02*S27+9.905146e-01*S28+(-5.651148e+00)*S29'
.param V36_part4='V36_part3+(-2.929603e+01)*S30+(-1.809593e+00)*S31+(-3.001126e+00)*S32+8.930447e-01*S33+(-2.350497e+00)*S34+7.448983e+00*S35+9.238489e-01*S36+(-5.106964e+00)*S37+(-3.377641e+01)*S38+(-2.521271e+00)*S39'
.param V36_part5='V36_part4+(-4.440763e+00)*S40+(-1.906760e+00)*S41+(-1.895442e+00)*S42+(-7.753949e-01)*S43+(-1.533540e+01)*S44+2.352513e+01*S45+4.184638e+00*S46+(-1.041950e+00)*S47+(-2.018334e+00)*S48+(-5.469955e+00)*S49'
.param V36_part6='V36_part5+(-1.132066e+00)*S50+(-3.129847e+00)*S51+1.103090e+00*S52+(-5.398463e+00)*S53+(-2.670192e+00)*S54+(-4.977410e+00)*S55+(-6.350936e+00)*S56+(-3.946847e+00)*S57+(-2.960100e+01)*S58+(-3.047726e+00)*S59'
.param V36_part7='V36_part6+(-1.897351e+00)*S60+5.598153e+01*S61+(-1.618719e+00)*S62+(-6.136637e+00)*S63+(-2.563018e+00)*S64+(-1.080620e+00)*S65+(-5.438248e+00)*S66+(-4.946954e+00)*S67+(-7.264947e-01)*S68+(-2.346796e+00)*S69'
.param V36_part8='V36_part7+(-8.414101e+01)*S70+(-5.827759e-01)*S71+(-1.711571e+00)*S72+(-1.573324e+00)*S73+(-3.940957e+00)*S74+4.958963e+00*S75+(-2.098671e+00)*S76+(-1.246906e+00)*S77+9.321600e-01*S78+(-1.998986e+01)*S79'
.param V36='V36_part8+(-4.288562e+01)*S80+(-1.582974e+00)*S81+(-2.088173e+00)*S82+(-2.589363e+01)*S83+(-1.686317e+00)*S84+(-1.701060e+01)*S85+(-7.768208e-01)*S86+(-2.264753e+00)*S87+(-1.868629e+00)*S88+(-1.596522e-01)*S89'
.param V37_part1='(-8.382471e+00)*S0+(-4.547608e+01)*S1+(-1.084755e+01)*S2+(-3.864558e+01)*S3+(-3.752764e+00)*S4+(-1.531029e+01)*S5+9.902524e+00*S6+(-3.739182e+01)*S7+(-4.461296e+01)*S8+(-1.565166e+01)*S9'
.param V37_part2='V37_part1+5.360033e+00*S10+(-1.598210e+01)*S11+(-1.158723e+02)*S12+(-1.496915e+01)*S13+(-5.033087e+00)*S14+(-7.969663e+01)*S15+6.081612e+01*S16+(-4.822929e+00)*S17+(-1.734089e+01)*S18+(-8.496335e+01)*S19'
.param V37_part3='V37_part2+(-8.714993e+00)*S20+(-9.804030e+00)*S21+(-2.236422e+02)*S22+(-8.364964e+00)*S23+(-1.976912e+01)*S24+(-8.937598e+00)*S25+(-7.072951e+00)*S26+1.000000e+04*S27+(-5.982152e+00)*S28+(-7.218825e+00)*S29'
.param V37_part4='V37_part3+(-4.630355e+02)*S30+(-5.188764e+00)*S31+(-3.194678e+00)*S32+(-1.492763e+01)*S33+(-7.207291e+00)*S34+3.854368e+00*S35+(-2.407936e+01)*S36+(-1.115927e+01)*S37+(-6.381879e+01)*S38+(-1.384780e+01)*S39'
.param V37_part5='V37_part4+(-6.296776e+00)*S40+(-3.159753e+00)*S41+1.538676e+01*S42+2.881414e-01*S43+(-5.015939e+01)*S44+(-8.584372e+01)*S45+(-5.277548e+00)*S46+(-4.707581e+00)*S47+(-9.372654e+00)*S48+(-9.441359e+00)*S49'
.param V37_part6='V37_part5+(-3.812766e-01)*S50+(-6.261905e+00)*S51+1.065992e+02*S52+(-1.862438e+01)*S53+(-5.950929e+00)*S54+1.100321e+02*S55+(-3.789212e+01)*S56+2.231111e+00*S57+(-4.677863e+00)*S58+(-1.390450e+01)*S59'
.param V37_part7='V37_part6+(-1.379505e+01)*S60+3.242219e+02*S61+(-3.463433e+00)*S62+(-5.162731e+01)*S63+(-3.756073e+00)*S64+(-2.565183e+00)*S65+(-1.075522e+01)*S66+(-7.736215e+00)*S67+(-1.158036e+00)*S68+(-6.150809e+00)*S69'
.param V37_part8='V37_part7+(-1.029331e+02)*S70+(-1.292174e+00)*S71+(-3.205037e+00)*S72+(-2.997532e+00)*S73+(-1.493441e+01)*S74+(-4.018850e+01)*S75+(-4.314105e+00)*S76+(-3.594844e+00)*S77+(-1.154410e+01)*S78+(-8.403627e+01)*S79'
.param V37='V37_part8+(-2.321199e+02)*S80+(-1.930844e+01)*S81+(-4.191241e+00)*S82+(-2.142402e+02)*S83+(-1.038147e+01)*S84+(-3.838875e+01)*S85+(-1.981428e+00)*S86+(-5.418251e+00)*S87+(-4.391091e+00)*S88+(-2.762014e-01)*S89'
.param V38_part1='(-5.920400e+00)*S0+(-1.806443e+02)*S1+(-3.524891e+00)*S2+(-1.513682e+00)*S3+2.047089e+00*S4+(-1.317754e+02)*S5+(-8.284728e-01)*S6+(-1.000000e+04)*S7+(-1.000000e+04)*S8+(-1.890992e-01)*S9'
.param V38_part2='V38_part1+2.056905e+02*S10+(-1.383804e+03)*S11+1.636579e+03*S12+(-1.681324e+01)*S13+(-1.946324e+00)*S14+(-1.453515e+00)*S15+1.145196e+03*S16+(-3.263642e-01)*S17+(-1.975868e-01)*S18+(-1.005024e+02)*S19'
.param V38_part3='V38_part2+(-7.131865e+00)*S20+1.219204e-01*S21+(-1.447892e+02)*S22+(-4.510575e+00)*S23+(-1.811836e-01)*S24+(-5.639066e+00)*S25+(-5.661711e-01)*S26+1.000000e+04*S27+(-1.773009e-01)*S28+(-1.322073e+00)*S29'
.param V38_part4='V38_part3+1.849959e+01*S30+(-2.878645e-02)*S31+(-1.998075e-01)*S32+(-1.595481e-01)*S33+(-5.827707e-01)*S34+1.523919e+01*S35+(-1.202245e+00)*S36+(-1.509701e+00)*S37+(-3.686971e+01)*S38+(-1.478571e-01)*S39'
.param V38_part5='V38_part4+(-1.334173e+00)*S40+(-4.816727e-01)*S41+8.309002e+00*S42+1.774306e+00*S43+(-2.318277e+01)*S44+(-4.627242e+00)*S45+(-2.963089e-01)*S46+(-2.155935e-01)*S47+(-1.008195e-01)*S48+(-1.961522e+00)*S49'
.param V38_part6='V38_part5+2.376503e-01*S50+(-4.099714e-02)*S51+1.149170e+01*S52+(-7.626164e+00)*S53+2.537618e-03*S54+1.952071e+01*S55+(-1.854223e+01)*S56+6.439881e+00*S57+(-7.170540e+00)*S58+(-9.452940e-01)*S59'
.param V38_part7='V38_part6+(-4.122788e-01)*S60+1.113818e+03*S61+(-3.771055e-01)*S62+9.444106e-01*S63+(-2.403810e-01)*S64+(-2.228118e-01)*S65+(-1.561251e+00)*S66+(-1.890427e+00)*S67+5.577916e-01*S68+(-2.485295e-01)*S69'
.param V38_part8='V38_part7+6.915921e+03*S70+7.485673e-02*S71+6.112570e-02*S72+(-2.000014e-01)*S73+1.058373e-01*S74+(-6.662257e-01)*S75+(-6.609296e-02)*S76+(-4.784160e-01)*S77+(-5.768135e-01)*S78+(-3.294043e+02)*S79'
.param V38='V38_part8+(-6.176096e+03)*S80+(-2.921201e-01)*S81+(-3.906177e-01)*S82+(-2.952100e+03)*S83+(-1.010006e+00)*S84+(-3.754618e+01)*S85+(-1.473082e-01)*S86+2.608907e-01*S87+(-6.357924e-01)*S88+1.660400e-01*S89'
.param V39_part1='(-4.580825e-01)*S0+7.826921e-01*S1+(-4.815348e-02)*S2+2.723792e-01*S3+(-1.236398e+00)*S4+(-2.953726e-01)*S5+1.039173e-01*S6+1.926171e-01*S7+(-1.040839e+00)*S8+(-5.896119e-02)*S9'
.param V39_part2='V39_part1+(-1.571184e+00)*S10+(-1.958888e+00)*S11+(-1.551937e+00)*S12+4.238526e-02*S13+(-2.925629e-02)*S14+(-1.768619e+01)*S15+3.620628e+00*S16+4.408646e-02*S17+1.892482e-01*S18+(-7.388537e+00)*S19'
.param V39_part3='V39_part2+(-2.606168e-01)*S20+(-9.567036e-02)*S21+(-4.488037e+01)*S22+(-3.067155e-01)*S23+(-9.085727e-01)*S24+(-5.879632e-01)*S25+(-1.548298e-01)*S26+2.529160e+01*S27+2.656441e-01*S28+(-5.684622e-01)*S29'
.param V39_part4='V39_part3+1.496588e+00*S30+(-3.503731e-01)*S31+(-2.267109e-01)*S32+1.846660e-01*S33+(-6.113676e-01)*S34+4.204112e-01*S35+(-1.054761e+00)*S36+(-5.707060e-01)*S37+(-2.508346e+00)*S38+(-8.342240e-01)*S39'
.param V39_part5='V39_part4+(-3.866604e-01)*S40+(-5.757259e-02)*S41+1.952436e+00*S42+(-7.086532e-02)*S43+(-1.221624e+00)*S44+(-6.041309e+00)*S45+(-3.440476e-01)*S46+(-2.748171e-01)*S47+(-7.129448e-01)*S48+(-5.335986e-01)*S49'
.param V39_part6='V39_part5+(-6.379815e-01)*S50+(-2.887954e-01)*S51+(-4.438008e+01)*S52+(-1.448022e+00)*S53+(-3.037132e-01)*S54+(-9.988758e+01)*S55+(-3.207591e+00)*S56+(-3.106653e-01)*S57+(-2.458572e+02)*S58+(-2.385027e-01)*S59'
.param V39_part7='V39_part6+(-1.049222e+00)*S60+7.530267e+00*S61+(-1.798972e-01)*S62+6.415325e-01*S63+(-2.462411e-01)*S64+(-1.528071e-01)*S65+(-1.112529e+00)*S66+(-6.921723e-01)*S67+(-5.688935e-02)*S68+(-3.558657e-01)*S69'
.param V39_part8='V39_part7+(-6.766862e-01)*S70+(-1.364245e-01)*S71+(-2.326796e-01)*S72+(-1.761136e-01)*S73+(-7.413880e-01)*S74+(-7.007161e-01)*S75+(-2.886096e-01)*S76+(-3.603811e-01)*S77+(-5.023171e-01)*S78+4.144469e+00*S79'
.param V39='V39_part8+(-5.004615e+00)*S80+(-7.868777e-01)*S81+(-3.816668e-01)*S82+(-5.080878e+00)*S83+(-5.109643e-01)*S84+7.036280e-01*S85+(-1.526611e-01)*S86+(-1.094811e+00)*S87+(-4.823225e-01)*S88+(-9.127462e-02)*S89'
.param V40_part1='1.101615e+01*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+1.574165e+00*S4+6.452159e+00*S5+1.494098e+01*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V40_part2='V40_part1+5.429417e+00*S10+0.000000e+00*S11+6.267580e+00*S12+6.306353e+00*S13+7.793643e+00*S14+0.000000e+00*S15+0.000000e+00*S16+7.555344e+00*S17+9.393341e+00*S18+0.000000e+00*S19'
.param V40_part3='V40_part2+8.442494e+00*S20+0.000000e+00*S21+0.000000e+00*S22+4.986916e+00*S23+0.000000e+00*S24+7.770991e+00*S25+(-3.434786e+00)*S26+2.449902e+01*S27+2.236207e+01*S28+2.654243e+01*S29'
.param V40_part4='V40_part3+0.000000e+00*S30+1.723017e+01*S31+7.775829e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+1.305298e+01*S39'
.param V40_part5='V40_part4+3.408523e+00*S40+0.000000e+00*S41+2.427657e+01*S42+(-4.920561e+01)*S43+(-6.532593e+00)*S44+(-2.507261e+00)*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V40_part6='V40_part5+3.232796e+00*S50+1.128685e+01*S51+6.502896e+01*S52+0.000000e+00*S53+1.070642e+01*S54+6.920200e+01*S55+0.000000e+00*S56+9.775862e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V40_part7='V40_part6+7.246903e+00*S60+(-1.034864e+00)*S61+0.000000e+00*S62+9.742813e+00*S63+0.000000e+00*S64+(-2.860277e+01)*S65+0.000000e+00*S66+0.000000e+00*S67+(-4.081657e+01)*S68+2.748509e+01*S69'
.param V40_part8='V40_part7+0.000000e+00*S70+1.976413e+02*S71+(-7.546278e+00)*S72+8.886607e+00*S73+(-8.109073e+00)*S74+1.034233e+01*S75+(-1.254940e+01)*S76+0.000000e+00*S77+2.936866e+01*S78+2.332235e+01*S79'
.param V40='V40_part8+2.277194e+01*S80+0.000000e+00*S81+(-1.149620e+01)*S82+1.420792e+01*S83+2.238802e+01*S84+1.595977e+01*S85+0.000000e+00*S86+(-1.934869e+01)*S87+(-1.718463e+00)*S88+3.272538e+02*S89'
.param V41_part1='(-2.016047e+01)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+3.367536e+00*S4+(-8.286037e+00)*S5+1.394808e+01*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V41_part2='V41_part1+4.021701e-01*S10+0.000000e+00*S11+1.202843e+00*S12+3.040243e+00*S13+6.564854e-01*S14+0.000000e+00*S15+0.000000e+00*S16+9.535766e+00*S17+9.586849e+00*S18+0.000000e+00*S19'
.param V41_part3='V41_part2+(-6.177951e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+1.388988e+00*S23+0.000000e+00*S24+(-3.820578e+00)*S25+2.937399e+01*S26+(-9.909295e+00)*S27+3.480532e+00*S28+(-6.788507e-02)*S29'
.param V41_part4='V41_part3+0.000000e+00*S30+5.915116e+00*S31+(-1.364399e+01)*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+2.864213e+01*S39'
.param V41_part5='V41_part4+3.535058e+01*S40+0.000000e+00*S41+1.851845e+01*S42+6.466557e+01*S43+3.845506e+01*S44+2.908045e+01*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V41_part6='V41_part5+1.092929e+02*S50+3.473528e+01*S51+6.370402e+00*S52+0.000000e+00*S53+3.331566e+01*S54+9.042973e+00*S55+0.000000e+00*S56+2.870720e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V41_part7='V41_part6+3.391170e+01*S60+5.640170e+01*S61+0.000000e+00*S62+4.367168e+01*S63+0.000000e+00*S64+6.951723e+01*S65+0.000000e+00*S66+0.000000e+00*S67+9.983817e+01*S68+2.293014e+01*S69'
.param V41_part8='V41_part7+0.000000e+00*S70+2.270274e+01*S71+4.635812e+01*S72+3.657442e+01*S73+2.353114e+01*S74+1.688588e+01*S75+4.405705e+01*S76+0.000000e+00*S77+(-9.559299e+00)*S78+5.848404e+00*S79'
.param V41='V41_part8+(-2.091286e+00)*S80+0.000000e+00*S81+4.797687e+01*S82+(-2.941369e+00)*S83+5.155931e+01*S84+(-1.860840e+00)*S85+0.000000e+00*S86+1.899755e+02*S87+2.680473e+01*S88+2.142506e+00*S89'
.param V42_part1='1.008547e+01*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-2.201981e+00)*S4+(-2.057142e+00)*S5+(-2.148360e+01)*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V42_part2='V42_part1+(-2.281756e+00)*S10+0.000000e+00*S11+1.647745e-01*S12+(-4.536634e+00)*S13+(-1.661963e+00)*S14+0.000000e+00*S15+0.000000e+00*S16+8.100047e+00*S17+6.464383e+00*S18+0.000000e+00*S19'
.param V42_part3='V42_part2+1.026939e+01*S20+0.000000e+00*S21+0.000000e+00*S22+1.597006e+01*S23+0.000000e+00*S24+2.416058e+01*S25+1.327636e+01*S26+1.931204e+01*S27+1.899205e+01*S28+1.332850e+00*S29'
.param V42_part4='V42_part3+0.000000e+00*S30+1.847427e-01*S31+7.680466e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+4.946216e+01*S39'
.param V42_part5='V42_part4+4.242222e+01*S40+0.000000e+00*S41+2.894505e+01*S42+1.067037e+01*S43+4.842894e+01*S44+6.779455e+01*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V42_part6='V42_part5+4.615285e+01*S50+4.325678e+01*S51+(-7.724666e+01)*S52+0.000000e+00*S53+4.397244e+01*S54+(-8.609974e+01)*S55+0.000000e+00*S56+4.467097e+01*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V42_part7='V42_part6+6.258525e+01*S60+6.938727e+01*S61+0.000000e+00*S62+7.066691e+01*S63+0.000000e+00*S64+8.405563e+01*S65+0.000000e+00*S66+0.000000e+00*S67+9.653997e+01*S68+4.780479e+01*S69'
.param V42_part8='V42_part7+0.000000e+00*S70+(-5.685957e+01)*S71+7.440622e+01*S72+4.847506e+01*S73+(-2.135714e+00)*S74+9.666578e+01*S75+1.181193e+02*S76+0.000000e+00*S77+9.306964e+01*S78+3.487177e+01*S79'
.param V42='V42_part8+3.396531e+01*S80+0.000000e+00*S81+9.735805e+01*S82+2.510039e+01*S83+8.099694e+00*S84+3.766468e+01*S85+0.000000e+00*S86+1.068462e+02*S87+5.509543e+01*S88+(-2.832992e+01)*S89'
.param V43_part1='(-5.167749e-01)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-5.074403e-01)*S4+1.181166e+00*S5+6.278907e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V43_part2='V43_part1+(-1.059563e-01)*S10+0.000000e+00*S11+(-4.372562e+00)*S12+2.381890e+00*S13+1.580192e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-1.699579e+00)*S17+(-9.525050e-01)*S18+0.000000e+00*S19'
.param V43_part3='V43_part2+6.258777e+00*S20+0.000000e+00*S21+0.000000e+00*S22+6.752901e+00*S23+0.000000e+00*S24+7.509442e+00*S25+(-1.134134e+01)*S26+(-1.918961e+01)*S27+(-9.470542e+00)*S28+8.439994e+00*S29'
.param V43_part4='V43_part3+0.000000e+00*S30+(-4.422848e+00)*S31+1.029578e+01*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+(-1.426692e+01)*S39'
.param V43_part5='V43_part4+(-8.680537e+00)*S40+0.000000e+00*S41+(-1.634653e+01)*S42+(-1.029513e+01)*S43+(-1.778760e+01)*S44+(-2.786339e+00)*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V43_part6='V43_part5+(-2.239517e+01)*S50+(-1.110944e+01)*S51+(-1.331612e+01)*S52+0.000000e+00*S53+(-1.238599e+01)*S54+(-1.060947e+01)*S55+0.000000e+00*S56+(-7.687156e+00)*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V43_part7='V43_part6+(-6.214329e+00)*S60+(-1.101265e+01)*S61+0.000000e+00*S62+(-1.306642e+01)*S63+0.000000e+00*S64+(-1.704242e+01)*S65+0.000000e+00*S66+0.000000e+00*S67+(-2.246311e+01)*S68+(-1.526569e+01)*S69'
.param V43_part8='V43_part7+0.000000e+00*S70+(-2.491922e+01)*S71+(-1.535556e+01)*S72+(-1.850410e+01)*S73+(-1.327871e+01)*S74+(-8.402915e+00)*S75+(-1.257982e+01)*S76+0.000000e+00*S77+(-1.035901e+01)*S78+(-1.037356e+01)*S79'
.param V43='V43_part8+(-1.346025e+01)*S80+0.000000e+00*S81+(-1.456287e+01)*S82+(-8.407454e+00)*S83+(-1.818526e+01)*S84+5.876060e-01*S85+0.000000e+00*S86+(-7.097112e+01)*S87+(-1.943590e+00)*S88+(-3.090599e+00)*S89'
.param V44_part1='(-8.247837e-01)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+4.877262e-01*S4+(-1.030607e-02)*S5+(-4.279436e-01)*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V44_part2='V44_part1+1.238917e-01*S10+0.000000e+00*S11+(-3.226232e-01)*S12+1.162114e-01*S13+1.483512e-02*S14+0.000000e+00*S15+0.000000e+00*S16+(-4.438322e-01)*S17+(-6.529977e+00)*S18+0.000000e+00*S19'
.param V44_part3='V44_part2+(-3.476927e-01)*S20+0.000000e+00*S21+0.000000e+00*S22+3.761059e-01*S23+0.000000e+00*S24+2.381647e+00*S25+1.443568e+00*S26+(-2.536424e+00)*S27+(-3.990843e+00)*S28+(-7.190913e+00)*S29'
.param V44_part4='V44_part3+0.000000e+00*S30+9.943555e-01*S31+5.565199e-01*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+4.546446e+00*S39'
.param V44_part5='V44_part4+2.669209e+00*S40+0.000000e+00*S41+3.822009e+00*S42+2.712781e+00*S43+8.361022e+00*S44+4.490505e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V44_part6='V44_part5+(-1.839578e+00)*S50+4.342161e+00*S51+1.724386e-01*S52+0.000000e+00*S53+6.132909e+00*S54+(-4.415877e-01)*S55+0.000000e+00*S56+5.244266e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V44_part7='V44_part6+5.354181e+00*S60+4.658487e+00*S61+0.000000e+00*S62+(-6.413945e+00)*S63+0.000000e+00*S64+1.178382e+01*S65+0.000000e+00*S66+0.000000e+00*S67+(-3.427294e+00)*S68+(-6.462828e-01)*S69'
.param V44_part8='V44_part7+0.000000e+00*S70+(-6.531343e+01)*S71+1.156775e+01*S72+9.802898e+00*S73+2.319533e+01*S74+3.628569e+00*S75+6.840220e+00*S76+0.000000e+00*S77+5.902049e+00*S78+1.189931e+01*S79'
.param V44='V44_part8+2.197934e+01*S80+0.000000e+00*S81+8.476932e+00*S82+8.165759e+00*S83+(-2.978227e+00)*S84+1.286528e+01*S85+0.000000e+00*S86+(-1.922842e+00)*S87+1.903963e+01*S88+8.557090e+01*S89'
.param V45_part1='(-1.689949e+00)*S0+(-4.466202e-01)*S1+(-2.168636e+00)*S2+(-6.277051e-01)*S3+(-1.287547e+00)*S4+(-2.792060e+00)*S5+(-2.897511e+00)*S6+(-1.135728e+00)*S7+(-2.467919e+00)*S8+(-7.477108e-01)*S9'
.param V45_part2='V45_part1+(-2.595957e+00)*S10+(-3.640424e+00)*S11+(-1.168146e+00)*S12+(-3.061335e+00)*S13+(-5.386379e+00)*S14+2.336230e+00*S15+(-1.391564e+00)*S16+(-3.380708e+00)*S17+(-5.487517e-01)*S18+(-1.511931e+00)*S19'
.param V45_part3='V45_part2+(-2.438462e+00)*S20+(-4.299247e+00)*S21+(-6.619144e+00)*S22+(-3.010481e+00)*S23+(-2.671354e+00)*S24+(-2.131040e+00)*S25+(-2.219145e+01)*S26+(-2.205966e+00)*S27+(-8.226592e+00)*S28+(-1.649533e+01)*S29'
.param V45_part4='V45_part3+(-2.494293e-01)*S30+(-1.251746e+00)*S31+(-4.534940e+00)*S32+(-1.348672e+00)*S33+(-1.981464e+00)*S34+(-8.875854e+00)*S35+1.893480e-01*S36+(-1.102215e+01)*S37+(-3.291620e+01)*S38+(-7.581526e+00)*S39'
.param V45_part5='V45_part4+(-1.738897e+01)*S40+(-2.414470e+01)*S41+(-6.478086e+00)*S42+(-3.078469e+01)*S43+(-3.566743e+01)*S44+(-2.773801e+00)*S45+(-1.324596e+01)*S46+(-3.659571e+01)*S47+(-4.823336e+00)*S48+(-1.613152e+01)*S49'
.param V45_part6='V45_part5+(-3.673276e+01)*S50+(-3.799346e+00)*S51+(-8.033176e+00)*S52+9.726913e-01*S53+(-5.721155e+00)*S54+(-8.799481e+00)*S55+6.148575e-01*S56+(-1.234674e+01)*S57+2.825198e+00*S58+(-5.812011e-01)*S59'
.param V45_part7='V45_part6+(-4.199521e+00)*S60+(-2.224790e+01)*S61+(-5.803347e+01)*S62+0.000000e+00*S63+(-3.020590e+01)*S64+(-6.285670e+01)*S65+(-8.842753e+00)*S66+(-3.940231e+01)*S67+(-6.859324e+01)*S68+0.000000e+00*S69'
.param V45_part8='V45_part7+(-2.462196e+00)*S70+0.000000e+00*S71+(-8.681752e+00)*S72+(-1.635079e+01)*S73+(-1.828853e+01)*S74+(-3.677250e+00)*S75+(-2.348620e+01)*S76+(-4.169267e+01)*S77+1.657146e+00*S78+(-8.575562e+00)*S79'
.param V45='V45_part8+(-3.071701e+01)*S80+0.000000e+00*S81+(-3.257013e+01)*S82+(-3.377537e+01)*S83+0.000000e+00*S84+(-9.226349e+00)*S85+(-9.088425e+01)*S86+(-2.501773e+00)*S87+(-2.946871e+01)*S88+(-5.799403e+01)*S89'
.param V46_part1='4.426608e+00*S0+5.038622e+00*S1+8.690026e+00*S2+5.335323e+00*S3+5.392383e+00*S4+7.803179e+00*S5+8.774363e+00*S6+5.235802e+00*S7+7.032809e+00*S8+4.354402e+00*S9'
.param V46_part2='V46_part1+5.820085e+00*S10+8.016156e+00*S11+4.076873e+00*S12+5.717000e+00*S13+7.810741e+00*S14+2.156725e+00*S15+2.104362e+00*S16+3.656490e+00*S17+1.701084e+00*S18+3.959264e+00*S19'
.param V46_part3='V46_part2+6.466217e+00*S20+4.171385e+00*S21+5.368344e+00*S22+6.396901e+00*S23+3.048572e+00*S24+5.474814e+00*S25+1.738307e+01*S26+5.430499e+00*S27+1.021803e+01*S28+9.106325e+00*S29'
.param V46_part4='V46_part3+(-1.012555e+00)*S30+3.183922e+00*S31+1.015300e+01*S32+2.245276e+00*S33+7.282335e+00*S34+1.149126e+01*S35+2.042373e+00*S36+1.400035e+01*S37+3.919086e+01*S38+5.096344e+00*S39'
.param V46_part5='V46_part4+1.882705e+01*S40+1.933933e+01*S41+2.805024e+00*S42+1.939663e+01*S43+1.224062e+01*S44+6.951191e+00*S45+2.919117e+01*S46+4.302043e+01*S47+9.787593e+00*S48+2.070111e+01*S49'
.param V46_part6='V46_part5+3.949867e+01*S50+9.153053e-01*S51+2.727511e+00*S52+5.295261e+00*S53+2.129783e+00*S54+2.335075e+00*S55+5.317344e+00*S56+8.885028e+00*S57+3.585270e+00*S58+4.608570e+00*S59'
.param V46_part7='V46_part6+1.067007e+01*S60+5.119651e+01*S61+5.156459e+01*S62+0.000000e+00*S63+2.285576e+01*S64+5.152381e+01*S65+2.616628e+00*S66+2.274200e+01*S67+7.488160e+01*S68+0.000000e+00*S69'
.param V46_part8='V46_part7+5.573300e+00*S70+0.000000e+00*S71+1.847791e+00*S72+1.641278e+01*S73+2.053126e+00*S74+(-2.267163e+00)*S75+1.685812e+01*S76+3.946163e+01*S77+(-5.304451e+00)*S78+1.068566e+01*S79'
.param V46='V46_part8+2.060888e+01*S80+0.000000e+00*S81+3.004644e+01*S82+2.069480e+01*S83+0.000000e+00*S84+9.304253e+00*S85+6.223624e+01*S86+5.532100e+00*S87+2.471828e+01*S88+3.328509e+01*S89'
.param V47_part1='4.357835e+00*S0+3.513240e+00*S1+5.363132e+00*S2+2.696150e+00*S3+5.199210e+00*S4+4.653712e+00*S5+4.734104e+00*S6+4.393395e+00*S7+4.802262e+00*S8+4.813873e+00*S9'
.param V47_part2='V47_part1+5.307347e+00*S10+5.232102e+00*S11+4.988783e+00*S12+6.014155e+00*S13+6.089106e+00*S14+4.001806e+00*S15+4.213805e+00*S16+1.271145e+01*S17+5.803225e+00*S18+1.225518e+01*S19'
.param V47_part3='V47_part2+4.968793e+00*S20+9.925327e+00*S21+1.531546e+01*S22+5.116011e+00*S23+5.306961e+00*S24+3.953383e+00*S25+2.244020e+01*S26+4.938225e+00*S27+1.659829e+01*S28+1.423669e+01*S29'
.param V47_part4='V47_part3+1.065707e+00*S30+4.617936e+00*S31+8.990386e+00*S32+2.296983e+00*S33+9.157738e+00*S34+1.011523e+01*S35+1.347692e+01*S36+1.835897e+01*S37+2.370273e+01*S38+2.447130e+01*S39'
.param V47_part5='V47_part4+1.846614e+01*S40+2.373648e+01*S41+3.203386e+01*S42+4.419199e+01*S43+3.364862e+01*S44+1.544056e+01*S45+1.862348e+01*S46+4.770850e+01*S47+1.140964e+01*S48+2.852546e+01*S49'
.param V47_part6='V47_part5+5.966832e+01*S50+8.093808e+00*S51+1.834433e+01*S52+7.756283e+00*S53+1.021982e+01*S54+1.924359e+01*S55+8.234319e+00*S56+1.654038e+01*S57+8.012560e+00*S58+1.001017e+01*S59'
.param V47_part7='V47_part6+1.217513e+01*S60+3.065022e+01*S61+6.301687e+01*S62+0.000000e+00*S63+5.507729e+01*S64+5.222162e+01*S65+5.668588e+01*S66+6.992667e+01*S67+6.468470e+01*S68+0.000000e+00*S69'
.param V47_part8='V47_part7+1.351751e+01*S70+0.000000e+00*S71+2.842840e+01*S72+3.673424e+00*S73+2.165497e+01*S74+3.409345e+01*S75+4.504694e+01*S76+5.827881e+01*S77+2.636574e+01*S78+1.639177e+01*S79'
.param V47='V47_part8+4.546997e+01*S80+0.000000e+00*S81+5.362570e+01*S82+4.947028e+01*S83+0.000000e+00*S84+2.546025e+01*S85+7.807163e+01*S86+2.816207e+01*S87+4.205665e+01*S88+1.283448e+02*S89'
.param V48_part1='(-8.983485e-02)*S0+3.305582e-01*S1+1.134139e-01*S2+(-3.600277e-02)*S3+1.488017e-01*S4+9.710162e-02*S5+1.179853e+00*S6+1.200805e-01*S7+7.118344e-02*S8+(-5.930764e-01)*S9'
.param V48_part2='V48_part1+3.797908e-01*S10+(-2.111758e-04)*S11+(-4.229672e-01)*S12+3.815599e-01*S13+5.528753e-01*S14+(-6.283361e-01)*S15+6.051591e-01*S16+(-3.521019e-01)*S17+(-8.926726e-01)*S18+(-1.299726e-01)*S19'
.param V48_part3='V48_part2+(-1.231010e+00)*S20+(-3.733559e-01)*S21+3.729801e-02*S22+(-1.329379e+00)*S23+(-1.156521e-01)*S24+(-1.192397e+00)*S25+2.650963e+00*S26+3.999347e-01*S27+1.640959e+00*S28+1.379766e+00*S29'
.param V48_part4='V48_part3+(-4.939604e-03)*S30+8.905210e-02*S31+(-1.229660e+00)*S32+5.778449e-04*S33+(-5.734699e-01)*S34+2.671672e-01*S35+4.163582e-01*S36+9.192281e-01*S37+(-6.070947e-01)*S38+9.485549e-01*S39'
.param V48_part5='V48_part4+1.041996e+00*S40+2.495126e-02*S41+5.205313e-01*S42+8.918289e-01*S43+6.533504e-01*S44+3.138419e-01*S45+(-1.444122e-02)*S46+(-4.895447e-01)*S47+(-1.009854e-01)*S48+8.015766e-01*S49'
.param V48_part6='V48_part5+2.086452e+00*S50+4.134231e-01*S51+3.317748e-01*S52+(-1.954139e+00)*S53+4.849058e-01*S54+(-1.245325e-01)*S55+(-2.341349e+00)*S56+1.521899e+00*S57+(-1.981744e+00)*S58+(-2.005511e+00)*S59'
.param V48_part7='V48_part6+1.479394e-02*S60+1.346169e+00*S61+1.688847e+00*S62+0.000000e+00*S63+3.160005e-01*S64+1.688314e+00*S65+6.747466e-01*S66+(-7.971654e-01)*S67+(-1.186188e+00)*S68+0.000000e+00*S69'
.param V48_part8='V48_part7+(-1.409988e+00)*S70+0.000000e+00*S71+7.455842e-01*S72+(-7.731140e-02)*S73+2.318404e+00*S74+6.144334e-01*S75+7.843006e-01*S76+(-3.845661e+00)*S77+(-2.961830e-02)*S78+(-1.749295e+00)*S79'
.param V48='V48_part8+(-2.381925e+00)*S80+0.000000e+00*S81+(-1.316150e+00)*S82+(-2.537377e+00)*S83+0.000000e+00*S84+(-2.354665e+00)*S85+(-3.303986e+00)*S86+(-9.200466e-03)*S87+(-9.976074e-01)*S88+3.731280e+00*S89'
.param V49_part1='1.161325e-01*S0+8.961338e-02*S1+1.119557e-01*S2+1.048495e-01*S3+4.949906e-02*S4+1.061214e-01*S5+(-3.769212e-03)*S6+7.206424e-02*S7+8.948025e-02*S8+6.503861e-02*S9'
.param V49_part2='V49_part1+6.376740e-02*S10+1.011955e-01*S11+8.200345e-02*S12+7.050609e-02*S13+1.099510e-01*S14+8.131333e-02*S15+4.438538e-01*S16+3.808809e-01*S17+1.797318e+00*S18+7.148151e-01*S19'
.param V49_part3='V49_part2+3.009654e-01*S20+2.815195e+00*S21+2.132752e+00*S22+2.861123e-01*S23+1.058211e+00*S24+1.116239e-01*S25+5.088770e-01*S26+3.719687e-01*S27+7.476819e-01*S28+5.002478e+00*S29'
.param V49_part4='V49_part3+7.015498e-01*S30+8.446698e-02*S31+5.059415e-01*S32+1.954405e-01*S33+4.340140e-01*S34+9.536792e-02*S35+4.973062e-01*S36+1.871618e+00*S37+2.333251e+00*S38+2.752424e+00*S39'
.param V49_part5='V49_part4+1.816637e+00*S40+6.293526e+00*S41+(-1.169171e-01)*S42+1.481740e+00*S43+1.169122e+01*S44+6.464945e-01*S45+4.996762e-01*S46+1.225945e+00*S47+8.387293e-02*S48+3.270796e+00*S49'
.param V49_part6='V49_part5+4.083496e+00*S50+3.782569e+00*S51+2.426703e-01*S52+(-5.703342e-02)*S53+4.820845e+00*S54+8.080571e-01*S55+(-1.868225e-01)*S56+3.574834e+00*S57+(-1.109465e+00)*S58+(-1.350991e-01)*S59'
.param V49_part7='V49_part6+1.440654e+00*S60+2.518192e+00*S61+8.563046e+00*S62+0.000000e+00*S63+4.156559e+00*S64+1.268502e+01*S65+7.782676e-01*S66+5.029349e+00*S67+(-7.170888e+00)*S68+0.000000e+00*S69'
.param V49_part8='V49_part7+5.690760e-01*S70+0.000000e+00*S71+5.739930e+00*S72+9.462475e+00*S73+1.925957e+01*S74+2.175468e+00*S75+3.964214e+00*S76+2.319946e+00*S77+1.449746e+00*S78+1.867106e+00*S79'
.param V49='V49_part8+2.356737e+00*S80+0.000000e+00*S81+3.042592e+00*S82+2.346841e+00*S83+0.000000e+00*S84+1.052833e+00*S85+1.619704e+00*S86+(-2.419534e-01)*S87+1.874376e+00*S88+8.173741e+00*S89'
.param V50_part1='1.023555e+00*S0+3.207417e-02*S1+1.001424e+00*S2+0.000000e+00*S3+8.642460e-01*S4+(-5.826895e-02)*S5+1.150221e+01*S6+(-6.862843e-02)*S7+(-8.384605e-02)*S8+(-7.136819e-02)*S9'
.param V50_part2='V50_part1+(-4.628115e-02)*S10+(-1.338786e-01)*S11+3.777203e-02*S12+8.137579e-02*S13+(-2.270893e-02)*S14+1.977691e+02*S15+(-2.415422e-02)*S16+4.554673e+00*S17+2.976171e+03*S18+2.638052e+00*S19'
.param V50_part3='V50_part2+8.344594e-02*S20+3.505260e+02*S21+1.917227e+00*S22+1.325530e-01*S23+3.183248e-01*S24+(-1.139368e-02)*S25+(-7.484640e-01)*S26+1.068454e+00*S27+4.095227e+00*S28+1.265059e-01*S29'
.param V50_part4='V50_part3+5.434899e+00*S30+1.451839e+00*S31+(-4.186779e-02)*S32+2.074055e+00*S33+7.783979e-01*S34+8.942674e-02*S35+4.101034e+00*S36+1.287891e+00*S37+1.314304e+00*S38+3.618046e+00*S39'
.param V50_part5='V50_part4+1.364588e+00*S40+2.221203e+00*S41+3.272434e+00*S42+5.685071e+00*S43+1.712233e+00*S44+1.416080e+01*S45+1.555859e+00*S46+1.892294e+00*S47+9.453420e-02*S48+2.613990e+00*S49'
.param V50_part6='V50_part5+4.320192e+00*S50+3.855928e+00*S51+9.999796e+03*S52+9.999148e+03*S53+3.222735e+00*S54+9.999578e+03*S55+9.998671e+03*S56+2.570649e+00*S57+1.000000e+04*S58+9.998663e+03*S59'
.param V50_part7='V50_part6+9.894050e+00*S60+2.903339e+00*S61+1.939040e+00*S62+3.225602e+00*S63+3.830159e+00*S64+2.831172e+00*S65+3.408087e+00*S66+2.217569e+00*S67+8.637645e+00*S68+4.271239e+00*S69'
.param V50_part8='V50_part7+0.000000e+00*S70+1.201024e+01*S71+4.144407e+00*S72+2.927130e+00*S73+1.209480e+00*S74+5.550452e+00*S75+4.046171e+00*S76+1.697945e+00*S77+9.238977e+00*S78+1.278405e+00*S79'
.param V50='V50_part8+8.870980e-01*S80+2.726047e+00*S81+2.671414e+00*S82+8.240914e-01*S83+3.439803e+00*S84+1.302752e+00*S85+1.855915e+00*S86+3.424809e+00*S87+1.428853e+00*S88+2.935877e+00*S89'
.param V51_part1='8.428508e-01*S0+2.790107e-01*S1+(-9.041444e-02)*S2+0.000000e+00*S3+(-2.738457e-01)*S4+1.948928e-01*S5+(-5.085952e+00)*S6+2.090519e-01*S7+2.220925e-01*S8+1.429477e-01*S9'
.param V51_part2='V51_part1+2.578192e-01*S10+2.774646e-01*S11+1.272463e-01*S12+2.229439e-01*S13+2.852096e-01*S14+3.198013e+01*S15+4.331801e-01*S16+(-3.167786e+00)*S17+(-1.421123e+01)*S18+(-1.627504e+00)*S19'
.param V51_part3='V51_part2+2.926698e-02*S20+7.178231e+01*S21+(-7.868360e-01)*S22+2.672831e-02*S23+(-1.887058e-01)*S24+1.486676e-01*S25+7.696116e-01*S26+(-4.497571e-01)*S27+(-1.879655e+00)*S28+7.018326e-02*S29'
.param V51_part4='V51_part3+(-1.330040e+00)*S30+8.756606e-01*S31+3.077338e-01*S32+(-1.053955e+00)*S33+(-4.142433e-01)*S34+1.798181e-01*S35+(-4.008360e+00)*S36+(-2.499144e-01)*S37+(-1.922340e-01)*S38+(-2.932880e+00)*S39'
.param V51_part5='V51_part4+3.421226e-01*S40+(-4.445935e-01)*S41+(-1.225614e+00)*S42+(-1.780749e+00)*S43+(-4.511873e-01)*S44+(-1.123547e+01)*S45+1.393002e+00*S46+(-3.049441e-01)*S47+1.960297e+00*S48+(-6.628234e-01)*S49'
.param V51_part6='V51_part5+(-1.421385e+00)*S50+(-2.784215e+00)*S51+(-1.611744e-02)*S52+(-2.458999e-01)*S53+(-2.461138e+00)*S54+5.179592e-02*S55+(-1.945494e-01)*S56+(-8.211042e-01)*S57+5.526940e-01*S58+(-2.972679e-02)*S59'
.param V51_part7='V51_part6+(-1.329980e+01)*S60+(-7.827273e-01)*S61+2.020488e-01*S62+(-4.587561e-01)*S63+(-4.136438e-01)*S64+(-4.056326e-01)*S65+(-1.931273e+00)*S66+(-6.905370e-01)*S67+(-1.317538e+00)*S68+(-2.862061e+00)*S69'
.param V51_part8='V51_part7+0.000000e+00*S70+(-1.380029e+00)*S71+(-1.649306e+00)*S72+(-7.021517e-01)*S73+(-2.183562e-01)*S74+(-4.728968e+00)*S75+(-3.805820e-01)*S76+(-3.805649e-01)*S77+(-8.934675e+00)*S78+(-9.286434e-01)*S79'
.param V51='V51_part8+(-3.654423e-01)*S80+(-1.664622e+00)*S81+(-5.300335e-01)*S82+(-3.503617e-01)*S83+(-4.195331e+00)*S84+(-8.660174e-01)*S85+(-1.130150e-01)*S86+(-1.642635e+00)*S87+(-3.847029e-01)*S88+(-6.855817e-01)*S89'
.param V52_part1='(-1.349655e+00)*S0+3.952311e-04*S1+(-2.674859e-01)*S2+0.000000e+00*S3+(-2.959058e-01)*S4+9.314855e-02*S5+(-1.197983e+01)*S6+8.558689e-02*S7+9.961314e-02*S8+1.121925e-01*S9'
.param V52_part2='V52_part1+8.347456e-02*S10+8.432214e-02*S11+(-2.586466e-02)*S12+(-5.138954e-03)*S13+9.729788e-02*S14+(-4.169706e+01)*S15+1.685802e-01*S16+2.803097e-01*S17+(-1.037280e+02)*S18+(-7.842475e-01)*S19'
.param V52_part3='V52_part2+1.064055e-01*S20+(-1.631090e+01)*S21+(-2.995360e-01)*S22+1.296904e-01*S23+1.523306e+00*S24+2.623072e-01*S25+1.888124e+00*S26+(-4.741714e-01)*S27+(-6.702947e-01)*S28+9.522071e-02*S29'
.param V52_part4='V52_part3+(-6.485519e+00)*S30+2.144435e-01*S31+3.197495e-01*S32+8.114406e-01*S33+(-2.669590e-01)*S34+(-1.308395e-03)*S35+4.791652e-01*S36+2.085594e-01*S37+(-3.765872e-01)*S38+3.513960e+00*S39'
.param V52_part5='V52_part4+1.524242e-01*S40+(-3.127860e-01)*S41+(-1.491688e+00)*S42+(-2.298729e+00)*S43+(-4.196586e-01)*S44+(-1.358480e+01)*S45+1.120829e-01*S46+2.340985e-02*S47+1.536997e+00*S48+(-1.068900e+00)*S49'
.param V52_part6='V52_part5+(-2.010988e+00)*S50+5.549925e+00*S51+(-2.612722e-01)*S52+(-8.826302e-01)*S53+4.929863e+00*S54+5.922433e-02*S55+(-3.628065e-01)*S56+(-1.394862e+00)*S57+(-7.285092e-01)*S58+(-3.296396e-01)*S59'
.param V52_part7='V52_part6+(-2.104914e+00)*S60+(-2.020115e+00)*S61+(-3.607596e-01)*S62+(-9.392466e-01)*S63+(-7.262890e-01)*S64+(-6.719191e-01)*S65+(-6.623434e-01)*S66+(-8.336585e-01)*S67+(-4.066424e+00)*S68+1.493601e+00*S69'
.param V52_part8='V52_part7+0.000000e+00*S70+2.145678e+00*S71+7.649390e+00*S72+(-5.636676e-01)*S73+(-2.193610e-01)*S74+(-4.124432e+00)*S75+2.740913e+00*S76+(-6.781919e-01)*S77+(-4.053110e+00)*S78+(-1.236593e+00)*S79'
.param V52='V52_part8+(-4.125905e-01)*S80+1.540285e-01*S81+(-7.986490e-01)*S82+(-3.789474e-01)*S83+9.384310e-01*S84+(-7.944745e-01)*S85+(-2.286651e-01)*S86+(-1.878512e-01)*S87+(-5.462710e-01)*S88+(-1.153850e+00)*S89'
.param V53_part1='1.100361e+00*S0+4.242789e-01*S1+1.972492e-01*S2+0.000000e+00*S3+2.480685e-01*S4+2.735602e-01*S5+1.197954e+00*S6+2.374068e-01*S7+1.925888e-01*S8+4.649042e-02*S9'
.param V53_part2='V53_part1+3.802677e-01*S10+1.912091e-01*S11+2.255815e-02*S12+5.926673e-01*S13+6.141882e-01*S14+(-2.237840e+02)*S15+4.384108e-01*S16+1.871497e+00*S17+(-3.872625e+03)*S18+2.816432e-01*S19'
.param V53_part3='V53_part2+2.242222e-01*S20+(-6.019915e+01)*S21+3.007389e-01*S22+3.113263e-01*S23+7.406674e-01*S24+4.232139e-01*S25+1.152685e+00*S26+4.530988e-01*S27+8.419625e-01*S28+7.139325e-01*S29'
.param V53_part4='V53_part3+1.800224e-01*S30+6.060657e+00*S31+7.368302e-01*S32+1.561633e+00*S33+7.722279e-01*S34+1.904564e-01*S35+1.143068e+00*S36+9.834646e-01*S37+2.384942e-01*S38+1.671294e+00*S39'
.param V53_part5='V53_part4+1.537508e+00*S40+1.012329e+00*S41+2.495025e-01*S42+(-5.086383e-01)*S43+2.060380e-01*S44+1.815804e-01*S45+1.375546e+00*S46+6.760792e-01*S47+1.853670e+00*S48+1.021119e+00*S49'
.param V53_part6='V53_part5+2.716590e-01*S50+6.685591e+00*S51+(-2.732345e-02)*S52+(-9.894658e-03)*S53+4.785085e+00*S54+(-1.060991e-01)*S55+(-2.970457e-04)*S56+2.755670e-01*S57+(-3.428469e-01)*S58+(-1.338311e-02)*S59'
.param V53_part7='V53_part6+4.552459e+00*S60+1.878363e-01*S61+9.470230e-01*S62+2.907909e-01*S63+2.645255e+00*S64+1.238325e+00*S65+1.319660e+00*S66+6.313826e-01*S67+(-1.288312e+00)*S68+3.111270e+00*S69'
.param V53_part8='V53_part7+0.000000e+00*S70+1.837193e+01*S71+1.053887e+01*S72+1.602314e+00*S73+1.328347e-01*S74+6.356625e-01*S75+6.582167e+00*S76+5.314365e-01*S77+2.437814e+00*S78+2.171234e-01*S79'
.param V53='V53_part8+1.010883e-01*S80+8.151610e-01*S81+1.412598e+00*S82+9.054785e-02*S83+1.199442e+00*S84+2.037083e-01*S85+8.456642e-01*S86+5.753044e-01*S87+6.939573e-01*S88+9.079644e-02*S89'
.param V54_part1='(-6.956230e-02)*S0+9.202822e-03*S1+(-1.003844e-02)*S2+0.000000e+00*S3+4.138080e-02*S4+4.744203e-03*S5+(-2.246154e-01)*S6+(-2.223470e-03)*S7+9.746793e-04*S8+9.747324e-04*S9'
.param V54_part2='V54_part1+(-1.492026e-03)*S10+3.294423e-03*S11+(-2.113561e-03)*S12+3.192088e-03*S13+3.398513e-03*S14+(-7.259600e+00)*S15+(-8.175148e-03)*S16+(-2.457713e-01)*S17+9.435930e+00*S18+(-5.061895e-02)*S19'
.param V54_part3='V54_part2+2.844228e-03*S20+(-7.236665e+00)*S21+(-9.239660e-03)*S22+9.901829e-03*S23+2.190166e-01*S24+3.987821e-02*S25+(-1.948406e-03)*S26+(-4.044286e-02)*S27+(-1.692866e-01)*S28+3.797128e-01*S29'
.param V54_part4='V54_part3+(-9.366672e-01)*S30+(-1.283447e-01)*S31+5.275463e-02*S32+8.790579e-04*S33+2.613850e-02*S34+7.151540e-02*S35+(-1.086490e-01)*S36+5.945704e-02*S37+(-1.510731e-03)*S38+2.342045e-01*S39'
.param V54_part5='V54_part4+7.403827e-02*S40+9.488259e-02*S41+(-2.186395e-01)*S42+(-1.398653e-01)*S43+2.992703e-02*S44+(-8.265439e-01)*S45+(-1.510177e-01)*S46+(-6.104126e-02)*S47+(-3.779617e-02)*S48+(-1.093532e-02)*S49'
.param V54_part6='V54_part5+6.473913e-03*S50+1.201239e+00*S51+(-6.666279e+03)*S52+(-6.665358e+03)*S53+1.194689e+00*S54+(-6.666351e+03)*S55+(-6.665427e+03)*S56+(-6.256307e-02)*S57+(-6.666126e+03)*S58+(-6.665523e+03)*S59'
.param V54_part7='V54_part6+(-4.029141e-02)*S60+(-1.512960e-01)*S61+3.198038e-02*S62+(-6.949350e-01)*S63+(-1.571530e-01)*S64+4.153269e-02*S65+(-4.552352e-02)*S66+2.441819e-02*S67+(-3.241015e-01)*S68+1.758017e-01*S69'
.param V54_part8='V54_part7+0.000000e+00*S70+(-1.617298e+00)*S71+1.620735e+00*S72+1.576197e-01*S73+3.261742e-02*S74+(-2.528509e-01)*S75+2.846708e-01*S76+2.035914e-01*S77+(-3.077341e-01)*S78+3.836329e-01*S79'
.param V54='V54_part8+1.409679e-01*S80+(-1.059788e-01)*S81+1.197351e-01*S82+1.817144e-01*S83+1.581385e-01*S84+3.234836e-01*S85+5.285000e-02*S86+8.008514e-01*S87+3.246926e-01*S88+(-7.742724e-02)*S89'
.param V55_part1='2.084683e+01*S0+3.185046e+02*S1+1.946995e+02*S2+0.000000e+00*S3+1.808048e+02*S4+3.029193e+02*S5+1.118270e+01*S6+4.041187e+02*S7+2.917295e+02*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+1.932722e+02*S10+3.185988e+02*S11+0.000000e+00*S12+1.215717e+02*S13+1.546042e+02*S14+(-5.127140e+01)*S15+2.959872e+02*S16+2.848850e+01*S17+(-3.380961e+01)*S18+3.891899e+01*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+3.261107e+01*S21+4.579682e+01*S22+0.000000e+00*S23+1.264888e+02*S24+0.000000e+00*S25+3.735902e+01*S26+(-5.346736e+01)*S27+(-1.110105e+01)*S28+(-4.639366e+01)*S29'
.param V55_part4='V55_part3+2.513294e+01*S30+(-3.177199e+01)*S31+8.847348e+01*S32+8.446091e+01*S33+5.687997e+02*S34+7.492011e+01*S35+3.361122e+01*S36+8.946103e+01*S37+1.756148e+02*S38+0.000000e+00*S39'
.param V55_part5='V55_part4+0.000000e+00*S40+2.769091e+01*S41+0.000000e+00*S42+1.425160e+02*S43+0.000000e+00*S44+0.000000e+00*S45+1.374139e+02*S46+4.767232e+01*S47+2.417092e+02*S48+3.419867e+01*S49'
.param V55_part6='V55_part5+(-4.826215e+01)*S50+0.000000e+00*S51+(-1.995759e+03)*S52+(-6.103319e+03)*S53+0.000000e+00*S54+(-2.682901e+03)*S55+(-1.000000e+04)*S56+0.000000e+00*S57+(-2.549215e+03)*S58+(-6.693536e+03)*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+0.000000e+00*S61+1.253248e+00*S62+0.000000e+00*S63+2.478303e+01*S64+0.000000e+00*S65+1.555437e+01*S66+(-1.246192e+01)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+1.303045e+02*S74+0.000000e+00*S75+0.000000e+00*S76+2.001403e+02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V55='V55_part8+0.000000e+00*S80+7.037535e+01*S81+0.000000e+00*S82+4.422797e+01*S83+0.000000e+00*S84+(-1.981014e+00)*S85+7.056036e+01*S86+0.000000e+00*S87+0.000000e+00*S88+(-2.536429e+00)*S89'
.param V56_part1='1.576983e+02*S0+(-3.147285e+02)*S1+(-6.469625e+01)*S2+0.000000e+00*S3+(-3.574297e+01)*S4+7.105681e+00*S5+4.671491e+01*S6+(-1.231701e+02)*S7+(-2.268549e+01)*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+(-7.116856e+00)*S10+(-5.845342e+01)*S11+0.000000e+00*S12+3.959798e+00*S13+(-4.150937e+00)*S14+1.732047e+02*S15+(-1.247219e+02)*S16+2.555706e+01*S17+9.586810e+01*S18+5.038697e+01*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+6.030754e+01*S21+5.822580e+01*S22+0.000000e+00*S23+4.692830e+01*S24+0.000000e+00*S25+6.790104e+00*S26+9.463574e+01*S27+5.080468e+01*S28+6.823581e+01*S29'
.param V56_part4='V56_part3+4.514897e+01*S30+3.720361e+01*S31+1.836180e+02*S32+2.930611e+01*S33+(-3.423227e+02)*S34+7.388527e+01*S35+8.381570e+01*S36+3.782534e+01*S37+(-2.526044e+01)*S38+0.000000e+00*S39'
.param V56_part5='V56_part4+0.000000e+00*S40+7.388193e+01*S41+0.000000e+00*S42+(-7.915297e+01)*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.095391e+02)*S46+6.426284e+01*S47+(-2.268978e+02)*S48+7.126721e+01*S49'
.param V56_part6='V56_part5+5.183674e+01*S50+0.000000e+00*S51+1.081537e+03*S52+3.657789e+03*S53+0.000000e+00*S54+1.187683e+03*S55+5.069771e+03*S56+0.000000e+00*S57+9.054423e+02*S58+2.465171e+03*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+0.000000e+00*S61+9.969672e+01*S62+0.000000e+00*S63+6.736051e+01*S64+0.000000e+00*S65+8.142492e+01*S66+7.834449e+01*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-7.684916e+01)*S74+0.000000e+00*S75+0.000000e+00*S76+1.064956e+02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V56='V56_part8+0.000000e+00*S80+7.699835e+00*S81+0.000000e+00*S82+1.165407e+02*S83+0.000000e+00*S84+6.155411e+01*S85+1.286175e+02*S86+0.000000e+00*S87+0.000000e+00*S88+9.908057e+01*S89'
.param V57_part1='5.025792e+00*S0+(-9.137506e+00)*S1+(-5.122944e+00)*S2+0.000000e+00*S3+2.924477e-01*S4+(-5.756995e+01)*S5+1.756145e+01*S6+(-1.179142e+02)*S7+(-6.188893e+01)*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+(-1.243762e+01)*S10+(-6.011647e+01)*S11+0.000000e+00*S12+3.205084e+01*S13+1.021584e+01*S14+2.730732e+02*S15+(-6.458799e+01)*S16+1.975856e+01*S17+1.121342e+02*S18+4.268534e+01*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+5.027211e+01*S21+3.722981e+01*S22+0.000000e+00*S23+6.326773e+00*S24+0.000000e+00*S25+2.369506e+01*S26+4.940250e+01*S27+2.327349e+01*S28+5.896607e+01*S29'
.param V57_part4='V57_part3+8.292138e+01*S30+2.121602e+02*S31+4.473263e+01*S32+9.215268e+01*S33+(-1.023383e+02)*S34+1.117602e+02*S35+6.312999e+01*S36+4.589571e+01*S37+3.944675e+01*S38+0.000000e+00*S39'
.param V57_part5='V57_part4+0.000000e+00*S40+8.056773e+01*S41+0.000000e+00*S42+5.804670e+01*S43+0.000000e+00*S44+0.000000e+00*S45+6.344305e+01*S46+9.747549e+01*S47+2.283824e+01*S48+9.835850e+01*S49'
.param V57_part6='V57_part5+7.410039e+01*S50+0.000000e+00*S51+3.788355e+03*S52+5.923763e+03*S53+0.000000e+00*S54+4.440472e+03*S55+8.538716e+03*S56+0.000000e+00*S57+5.096068e+03*S58+6.017855e+03*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+0.000000e+00*S61+1.551091e+02*S62+0.000000e+00*S63+1.353775e+02*S64+0.000000e+00*S65+1.589569e+02*S66+1.924211e+02*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+6.353490e+01*S74+0.000000e+00*S75+0.000000e+00*S76+1.373041e+02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V57='V57_part8+0.000000e+00*S80+9.103540e+01*S81+0.000000e+00*S82+2.195210e+01*S83+0.000000e+00*S84+1.898228e+00*S85+1.442255e+02*S86+0.000000e+00*S87+0.000000e+00*S88+5.901403e+00*S89'
.param V58_part1='(-3.777572e+01)*S0+(-4.978005e+01)*S1+(-5.393352e+01)*S2+0.000000e+00*S3+(-6.859455e+01)*S4+(-1.097656e+02)*S5+(-2.733524e+01)*S6+(-1.045070e+02)*S7+(-7.222811e+01)*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+(-9.436183e+01)*S10+(-7.563017e+01)*S11+0.000000e+00*S12+(-7.045259e+01)*S13+(-6.799823e+01)*S14+7.436794e+00*S15+(-1.269594e+02)*S16+(-1.650329e+01)*S17+(-4.874439e+00)*S18+(-1.877974e+01)*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+(-2.081882e+01)*S21+(-2.545132e+01)*S22+0.000000e+00*S23+(-4.979147e+01)*S24+0.000000e+00*S25+(-6.788333e+00)*S26+1.208700e+02*S27+(-1.154669e+01)*S28+(-5.678123e+01)*S29'
.param V58_part4='V58_part3+(-1.402164e+01)*S30+7.694073e-01*S31+(-1.218463e+02)*S32+(-3.733211e+01)*S33+(-6.432458e+01)*S34+(-1.742979e+00)*S35+(-3.408078e+01)*S36+(-3.946473e+01)*S37+(-5.412796e+01)*S38+0.000000e+00*S39'
.param V58_part5='V58_part4+0.000000e+00*S40+(-3.887161e+01)*S41+0.000000e+00*S42+(-1.242138e+01)*S43+0.000000e+00*S44+0.000000e+00*S45+(-3.506250e+01)*S46+(-3.794904e+01)*S47+(-4.694351e+01)*S48+(-2.812100e+01)*S49'
.param V58_part6='V58_part5+(-1.296168e+01)*S50+0.000000e+00*S51+1.188737e+02*S52+2.473279e+01*S53+0.000000e+00*S54+1.468407e+02*S55+1.403325e+02*S56+0.000000e+00*S57+1.348012e+02*S58+6.811182e+01*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+0.000000e+00*S61+(-3.912592e+01)*S62+0.000000e+00*S63+(-3.242877e+01)*S64+0.000000e+00*S65+(-2.866778e+01)*S66+(-3.306878e+01)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.206954e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+(-7.623264e+01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V58='V58_part8+0.000000e+00*S80+(-2.570670e+01)*S81+0.000000e+00*S82+(-4.369431e+01)*S83+0.000000e+00*S84+(-5.452997e+01)*S85+(-7.702258e+01)*S86+0.000000e+00*S87+0.000000e+00*S88+(-4.981280e+01)*S89'
.param V59_part1='1.658678e+01*S0+6.282844e+00*S1+7.815697e-01*S2+0.000000e+00*S3+(-6.520406e+00)*S4+(-1.953426e+00)*S5+1.871177e+00*S6+1.027709e+00*S7+1.570285e-02*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+(-1.407650e+00)*S10+5.197911e-01*S11+0.000000e+00*S12+(-1.139309e+00)*S13+(-2.604506e-01)*S14+1.352853e+01*S15+1.558940e+01*S16+2.971900e+00*S17+1.894867e+01*S18+2.565990e+00*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+(-3.489356e+00)*S21+(-1.536252e+00)*S22+0.000000e+00*S23+(-1.378513e+01)*S24+0.000000e+00*S25+(-6.764965e-01)*S26+2.364652e+01*S27+8.093389e+00*S28+2.932330e+01*S29'
.param V59_part4='V59_part3+5.368760e+00*S30+1.428335e+01*S31+(-3.351282e+00)*S32+4.323707e-01*S33+(-4.992918e+01)*S34+(-5.951117e+00)*S35+6.373777e+00*S36+(-2.855949e-01)*S37+(-7.048354e+00)*S38+0.000000e+00*S39'
.param V59_part5='V59_part4+0.000000e+00*S40+5.144675e+00*S41+0.000000e+00*S42+(-2.539553e+00)*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.403760e+00)*S46+4.988270e+00*S47+9.673780e+00*S48+3.984697e+00*S49'
.param V59_part6='V59_part5+1.035723e+01*S50+0.000000e+00*S51+9.082548e+02*S52+1.830221e+03*S53+0.000000e+00*S54+1.560799e+03*S55+3.646588e+03*S56+0.000000e+00*S57+8.449403e+02*S58+3.194413e+03*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+0.000000e+00*S61+1.249096e+01*S62+0.000000e+00*S63+8.451178e+00*S64+0.000000e+00*S65+8.150292e+00*S66+1.312804e+01*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+4.152438e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-7.766264e+01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V59='V59_part8+0.000000e+00*S80+4.960868e+00*S81+0.000000e+00*S82+1.261686e+01*S83+0.000000e+00*S84+1.206290e+01*S85+(-3.155393e+01)*S86+0.000000e+00*S87+0.000000e+00*S88+1.392770e+01*S89'
.param V60_part1='5.140668e+00*S0+(-6.315404e+00)*S1+2.146212e+01*S2+1.836003e+03*S3+5.838165e+00*S4+(-3.536120e+02)*S5+8.505347e+01*S6+3.059949e+01*S7+2.491229e+01*S8+(-6.453238e+01)*S9'
.param V60_part2='V60_part1+1.218668e+02*S10+1.817370e+01*S11+(-9.993283e+02)*S12+1.000000e+04*S13+1.000000e+04*S14+(-9.998232e+02)*S15+2.974033e+01*S16+1.000000e+04*S17+(-9.999311e+02)*S18+1.050750e+01*S19'
.param V60_part3='V60_part2+(-3.446373e+03)*S20+(-1.934424e+02)*S21+1.211238e+01*S22+(-1.288804e+00)*S23+1.048321e+01*S24+(-1.206059e+03)*S25+(-4.489629e+03)*S26+(-4.888422e+03)*S27+1.000000e+04*S28+5.965115e+00*S29'
.param V60_part4='V60_part3+1.508738e+01*S30+(-2.336168e+02)*S31+(-4.513456e+03)*S32+8.451073e+01*S33+(-5.218130e+03)*S34+9.151835e+00*S35+(-4.908212e+03)*S36+(-4.958070e+03)*S37+(-4.942984e+03)*S38+4.684893e+00*S39'
.param V60_part5='V60_part4+(-4.962492e+03)*S40+2.177105e+00*S41+(-5.453006e+00)*S42+1.230625e+00*S43+1.251309e+00*S44+4.458802e+01*S45+4.842029e+00*S46+1.786375e+01*S47+1.375133e-02*S48+8.131977e+00*S49'
.param V60_part6='V60_part5+(-1.401592e+02)*S50+(-5.000089e+03)*S51+6.458982e-01*S52+9.677105e-01*S53+(-1.237007e+03)*S54+4.868460e-01*S55+6.468584e-01*S56+2.750280e+01*S57+2.356230e-01*S58+4.593070e-01*S59'
.param V60_part7='V60_part6+1.801753e+00*S60+3.134508e+00*S61+8.706366e+00*S62+(-5.009120e+03)*S63+2.469515e+00*S64+7.475134e+00*S65+1.084812e+00*S66+5.336510e-01*S67+1.058653e+01*S68+(-4.578334e+03)*S69'
.param V60_part8='V60_part7+1.086167e+00*S70+1.215940e+01*S71+(-4.999739e+03)*S72+(-4.998304e+03)*S73+1.264413e-01*S74+(-3.193049e+01)*S75+(-2.366145e+00)*S76+6.266811e+00*S77+(-4.998380e+03)*S78+3.071763e+00*S79'
.param V60='V60_part8+4.466429e+00*S80+(-4.999465e+03)*S81+6.128035e+00*S82+4.900030e+00*S83+(-4.999323e+03)*S84+2.914365e+00*S85+4.107572e+00*S86+6.600881e-03*S87+3.487779e+00*S88+1.827492e+02*S89'
.param V61_part1='6.018413e+01*S0+1.098712e+02*S1+5.259599e+01*S2+1.193812e+02*S3+6.620311e+01*S4+1.180473e+03*S5+(-3.047243e+01)*S6+8.957329e+00*S7+1.080086e+02*S8+(-9.073213e-01)*S9'
.param V61_part2='V61_part1+(-1.861204e+02)*S10+5.992244e+00*S11+(-1.082454e-01)*S12+1.000000e+04*S13+1.000000e+04*S14+(-8.522723e-01)*S15+(-1.132137e+01)*S16+2.717928e+01*S17+(-1.116616e-01)*S18+(-3.514720e+00)*S19'
.param V61_part3='V61_part2+(-1.514532e+01)*S20+(-4.164549e-02)*S21+(-1.793797e+00)*S22+(-3.853252e+01)*S23+(-9.584693e-01)*S24+(-6.551285e+02)*S25+(-4.857140e+02)*S26+(-1.030074e+02)*S27+1.000000e+04*S28+(-6.462601e-01)*S29'
.param V61_part4='V61_part3+4.302522e+00*S30+8.679733e+00*S31+(-1.513904e+02)*S32+3.283212e+02*S33+(-5.717126e+02)*S34+(-1.787242e+00)*S35+(-9.149581e+01)*S36+(-2.213821e+02)*S37+(-2.242537e+01)*S38+(-5.461104e-01)*S39'
.param V61_part5='V61_part4+(-5.146580e+01)*S40+4.151344e-02*S41+(-4.004106e-03)*S42+4.521903e-01*S43+(-3.982967e-01)*S44+4.439282e+01*S45+7.475062e+01*S46+(-1.067032e+01)*S47+1.723744e+00*S48+2.869981e+00*S49'
.param V61_part6='V61_part5+(-3.355497e+01)*S50+4.230454e-01*S51+(-5.810750e-01)*S52+(-2.876525e-01)*S53+3.834467e-01*S54+(-3.856449e-01)*S55+(-2.957520e-01)*S56+2.085713e+00*S57+(-2.447138e-01)*S58+(-2.099181e-01)*S59'
.param V61_part7='V61_part6+9.516922e-01*S60+3.223488e+00*S61+(-1.418313e+00)*S62+4.903046e-01*S63+2.743879e+00*S64+3.442222e+00*S65+1.171198e+01*S66+7.520954e-01*S67+(-1.784459e+00)*S68+2.804929e-01*S69'
.param V61_part8='V61_part7+(-4.236662e-01)*S70+4.442320e-01*S71+3.559214e-01*S72+(-3.262580e-01)*S73+(-1.664983e-02)*S74+(-1.437066e+00)*S75+(-6.545449e+00)*S76+(-1.525115e+00)*S77+(-1.676848e+00)*S78+(-3.373224e+00)*S79'
.param V61='V61_part8+(-1.465356e+00)*S80+(-3.477759e-01)*S81+(-5.593130e+00)*S82+(-1.446097e+00)*S83+(-2.444854e-01)*S84+(-4.517930e-01)*S85+(-8.408202e-01)*S86+1.392517e-01*S87+(-2.020062e-01)*S88+5.932917e+00*S89'
.param V62_part1='7.998934e+00*S0+5.930217e+01*S1+1.789626e+01*S2+9.823148e+01*S3+3.871747e+01*S4+(-1.040309e+01)*S5+(-6.546089e+01)*S6+5.851244e+01*S7+7.762174e+00*S8+6.626462e+02*S9'
.param V62_part2='V62_part1+4.708092e+03*S10+6.272768e+01*S11+1.000000e+04*S12+1.000000e+04*S13+1.000000e+04*S14+1.000000e+04*S15+(-2.831733e+01)*S16+1.000000e+04*S17+1.000000e+04*S18+(-6.612623e+00)*S19'
.param V62_part3='V62_part2+(-4.040958e+02)*S20+1.935219e+03*S21+(-8.136060e+00)*S22+(-6.163672e+01)*S23+(-1.420057e+01)*S24+(-1.198766e+03)*S25+(-2.541933e+01)*S26+1.676216e+02*S27+1.000000e+04*S28+(-3.423237e+00)*S29'
.param V62_part4='V62_part3+(-2.726510e+01)*S30+(-1.097108e+02)*S31+(-2.645271e+02)*S32+(-7.452420e+00)*S33+1.534540e+03*S34+(-5.590997e+00)*S35+6.244191e+01*S36+3.969166e+02*S37+(-3.673251e+01)*S38+(-8.473914e+00)*S39'
.param V62_part5='V62_part4+3.495201e+01*S40+(-1.356404e+00)*S41+5.755435e+01*S42+1.739002e+00*S43+(-4.587526e-01)*S44+(-1.204150e+02)*S45+(-1.454376e+02)*S46+(-1.221936e+01)*S47+1.452221e+00*S48+(-9.880084e+00)*S49'
.param V62_part6='V62_part5+(-3.068032e+01)*S50+7.163341e-01*S51+(-3.658298e-01)*S52+(-4.933319e-01)*S53+5.272329e-01*S54+(-1.506471e-01)*S55+(-1.951972e-01)*S56+(-2.007409e+00)*S57+1.530282e-01*S58+(-6.674566e-02)*S59'
.param V62_part7='V62_part6+(-8.245404e+00)*S60+(-4.111272e+00)*S61+4.171740e-01*S62+9.258476e+01*S63+5.025223e+00*S64+1.068542e+00*S65+6.261479e+00*S66+3.066356e+00*S67+(-8.180558e+00)*S68+(-8.371529e-01)*S69'
.param V62_part8='V62_part7+(-3.590462e-01)*S70+(-1.047276e+01)*S71+(-4.273800e-01)*S72+(-1.540783e+00)*S73+1.576387e-02*S74+1.222894e+00*S75+5.094699e-01*S76+(-5.596630e+00)*S77+(-2.496345e-01)*S78+(-3.588487e+00)*S79'
.param V62='V62_part8+(-4.146748e+00)*S80+(-1.663631e-01)*S81+(-6.990480e+00)*S82+(-4.090490e+00)*S83+(-4.885966e-01)*S84+(-4.932278e+00)*S85+(-3.579033e+00)*S86+(-4.632517e-03)*S87+(-5.904975e+00)*S88+5.516846e+01*S89'
.param V63_part1='6.033930e+01*S0+9.922231e+01*S1+8.644327e+01*S2+7.444572e+03*S3+7.891489e+01*S4+6.246846e+01*S5+1.245055e+01*S6+5.860029e+01*S7+9.483917e+01*S8+(-8.142176e-01)*S9'
.param V63_part2='V63_part1+(-7.392850e+03)*S10+5.291512e+01*S11+(-3.008019e-01)*S12+(-1.249913e+03)*S13+7.421872e+03*S14+1.758222e-02*S15+(-1.068270e+00)*S16+1.186387e+00*S17+(-2.639661e-03)*S18+(-3.963469e-01)*S19'
.param V63_part3='V63_part2+(-3.724107e+00)*S20+7.036749e-03*S21+(-5.002284e-01)*S22+2.559394e+00*S23+(-5.137298e-01)*S24+(-5.956458e+00)*S25+(-2.252107e+01)*S26+1.961939e-01*S27+(-6.856655e+03)*S28+(-2.323042e-01)*S29'
.param V63_part4='V63_part3+(-1.033320e+00)*S30+5.729864e+00*S31+(-4.794697e+00)*S32+(-3.452301e+00)*S33+2.323142e+01*S34+(-2.253522e-01)*S35+(-4.971241e+00)*S36+(-6.296678e+00)*S37+(-1.118706e+00)*S38+(-5.147178e-01)*S39'
.param V63_part5='V63_part4+(-2.365304e+00)*S40+(-1.720751e-01)*S41+1.184023e-02*S42+(-2.073662e-01)*S43+(-2.200094e-02)*S44+(-4.155881e-01)*S45+1.536326e+00*S46+(-5.211865e-01)*S47+(-4.682627e-02)*S48+(-3.552959e-01)*S49'
.param V63_part6='V63_part5+(-8.025644e-02)*S50+9.650391e-02*S51+(-5.277764e-02)*S52+(-3.210641e-02)*S53+1.329842e-01*S54+(-2.501651e-02)*S55+(-2.171171e-03)*S56+9.608498e+01*S57+4.266426e-03*S58+1.878429e-02*S59'
.param V63_part7='V63_part6+(-5.613567e-02)*S60+(-1.602012e-01)*S61+(-1.815444e-01)*S62+1.169169e-01*S63+(-1.503940e-01)*S64+(-1.089749e-01)*S65+(-4.629272e-02)*S66+(-2.049774e-02)*S67+(-1.122173e-01)*S68+9.631031e-02*S69'
.param V63_part8='V63_part7+(-5.838943e-02)*S70+(-5.112660e-01)*S71+1.611463e-01*S72+1.095716e-01*S73+1.035089e-02*S74+1.671228e-01*S75+7.215942e-02*S76+(-2.927468e-02)*S77+1.368383e-01*S78+(-1.027269e-01)*S79'
.param V63='V63_part8+(-3.763230e-02)*S80+3.246256e-02*S81+(-7.209630e-02)*S82+(-2.107925e-02)*S83+4.691923e-02*S84+1.314259e-04*S85+3.105219e-03*S86+4.716667e-02*S87+2.999485e-03*S88+2.190998e-01*S89'
.param V64_part1='1.714527e+00*S0+(-3.914508e-01)*S1+1.206940e+00*S2+(-1.187461e-01)*S3+(-1.884613e+00)*S4+1.865392e+01*S5+2.004571e+01*S6+(-4.564852e+00)*S7+(-6.189278e+00)*S8+(-5.737376e-02)*S9'
.param V64_part2='V64_part1+9.999997e+03*S10+(-3.402159e+00)*S11+(-7.171866e-03)*S12+1.000000e+04*S13+1.000000e+04*S14+9.339818e-02*S15+7.207181e+00*S16+2.432212e+02*S17+4.386021e-02*S18+9.097253e-01*S19'
.param V64_part3='V64_part2+8.033879e+03*S20+2.080885e-02*S21+9.154898e-01*S22+3.610398e+02*S23+4.475954e+00*S24+5.083896e+03*S25+9.999908e+03*S26+1.000000e+04*S27+(-3.083909e+02)*S28+6.549363e-01*S29'
.param V64_part4='V64_part3+3.265033e+00*S30+6.921278e+02*S31+9.808096e+03*S32+(-9.445361e+01)*S33+1.000000e+04*S34+1.493053e+00*S35+1.000000e+04*S36+1.000000e+04*S37+1.000000e+04*S38+3.374351e+00*S39'
.param V64_part5='V64_part4+1.000000e+04*S40+6.262635e-01*S41+(-7.472264e-02)*S42+(-6.227452e-01)*S43+2.067460e-01*S44+1.763184e+01*S45+2.115061e+02*S46+3.618496e+00*S47+(-3.736060e-01)*S48+8.759607e-01*S49'
.param V64_part6='V64_part5+3.965066e+02*S50+1.000000e+04*S51+4.555898e-01*S52+3.102366e-01*S53+2.473945e+03*S54+3.143423e-01*S55+2.897731e-01*S56+2.060811e+00*S57+2.928531e-01*S58+2.420280e-01*S59'
.param V64_part7='V64_part6+4.403903e+00*S60+5.028660e-01*S61+(-3.922018e+00)*S62+1.000000e+04*S63+(-2.859456e+00)*S64+(-5.473270e+00)*S65+(-4.752165e+00)*S66+(-1.008303e+00)*S67+3.058076e-01*S68+9.157558e+03*S69'
.param V64_part8='V64_part7+(-7.535044e-02)*S70+5.166689e-01*S71+1.000000e+04*S72+1.000000e+04*S73+1.329582e-01*S74+6.526652e+01*S75+1.020715e+01*S76+1.653918e+00*S77+1.000000e+04*S78+2.319736e+00*S79'
.param V64='V64_part8+2.549383e+00*S80+1.000000e+04*S81+4.766545e+00*S82+1.674726e+00*S83+9.999999e+03*S84+2.364293e+00*S85+1.751732e+00*S86+8.315440e-02*S87+2.505036e+00*S88+(-8.937102e-03)*S89'
.param V65_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.142077e-03)*S5+0.000000e+00*S6+(-2.475330e-02)*S7+(-3.393779e-02)*S8+7.558174e-03*S9'
.param V65_part2='V65_part1+(-3.225336e-02)*S10+(-6.973919e-03)*S11+(-3.213511e-03)*S12+(-2.196499e-02)*S13+5.162166e-03*S14+(-1.581182e-02)*S15+(-1.131306e-01)*S16+(-9.952158e-02)*S17+2.235477e-01*S18+3.617127e-01*S19'
.param V65_part3='V65_part2+(-1.134362e-01)*S20+1.400169e+00*S21+0.000000e+00*S22+(-2.295940e-01)*S23+3.380822e-01*S24+(-1.156690e-01)*S25+(-1.378262e-02)*S26+4.797914e-02*S27+0.000000e+00*S28+(-2.431954e-01)*S29'
.param V65_part4='V65_part3+0.000000e+00*S30+(-1.153901e-02)*S31+(-2.566389e-01)*S32+0.000000e+00*S33+(-1.163965e-01)*S34+(-9.933597e-01)*S35+0.000000e+00*S36+(-2.080696e-03)*S37+7.527922e-01*S38+0.000000e+00*S39'
.param V65_part5='V65_part4+5.392417e-01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+3.655482e-01*S45+0.000000e+00*S46+0.000000e+00*S47+2.919930e+00*S48+0.000000e+00*S49'
.param V65_part6='V65_part5+0.000000e+00*S50+(-2.168204e-01)*S51+2.968503e+00*S52+6.218169e-01*S53+(-5.024020e-01)*S54+4.265449e+00*S55+7.080343e-01*S56+0.000000e+00*S57+3.944064e+00*S58+6.498762e-01*S59'
.param V65_part7='V65_part6+7.419324e-01*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+(-1.408518e+00)*S69'
.param V65_part8='V65_part7+(-7.177019e+00)*S70+(-3.354792e+00)*S71+(-3.778024e-01)*S72+(-6.395540e+00)*S73+1.094813e+01*S74+0.000000e+00*S75+1.464456e+00*S76+(-4.693809e+00)*S77+(-7.188478e-01)*S78+(-4.676907e+00)*S79'
.param V65='V65_part8+(-8.294553e+00)*S80+0.000000e+00*S81+(-8.101107e-01)*S82+(-1.184540e+01)*S83+(-6.291693e-01)*S84+(-5.748574e+00)*S85+(-3.446311e+00)*S86+0.000000e+00*S87+(-2.958299e+00)*S88+0.000000e+00*S89'
.param V66_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-3.829904e-02)*S5+0.000000e+00*S6+7.223360e-02*S7+5.354531e-02*S8+5.702063e-02*S9'
.param V66_part2='V66_part1+4.454259e-02*S10+3.756781e-02*S11+2.811255e-02*S12+3.321773e-02*S13+1.274810e-02*S14+6.989188e-01*S15+6.776590e-01*S16+2.585528e-01*S17+5.075837e-01*S18+2.958570e-01*S19'
.param V66_part3='V66_part2+3.562698e-01*S20+9.899388e-01*S21+0.000000e+00*S22+4.913653e-01*S23+4.614561e-01*S24+2.535485e-01*S25+5.999931e-01*S26+1.520749e-01*S27+0.000000e+00*S28+9.404972e-01*S29'
.param V66_part4='V66_part3+0.000000e+00*S30+5.098047e-01*S31+8.678446e-01*S32+0.000000e+00*S33+3.941807e-01*S34+2.172790e+00*S35+0.000000e+00*S36+2.069540e-01*S37+(-5.310865e-01)*S38+0.000000e+00*S39'
.param V66_part5='V66_part4+3.777908e-02*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+5.984659e-01*S45+0.000000e+00*S46+0.000000e+00*S47+(-4.666242e-01)*S48+0.000000e+00*S49'
.param V66_part6='V66_part5+0.000000e+00*S50+2.450554e+00*S51+8.229220e+00*S52+9.021617e+00*S53+2.861644e+00*S54+9.462451e+00*S55+9.969186e+00*S56+0.000000e+00*S57+1.074105e+01*S58+1.102811e+01*S59'
.param V66_part7='V66_part6+8.882333e-01*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+2.555709e+00*S69'
.param V66_part8='V66_part7+9.300435e+00*S70+1.356824e+01*S71+1.947338e+00*S72+6.120684e+00*S73+1.625093e+01*S74+0.000000e+00*S75+5.651394e+00*S76+7.987946e+00*S77+2.242280e+00*S78+9.203399e+00*S79'
.param V66='V66_part8+1.147628e+01*S80+0.000000e+00*S81+3.963590e+00*S82+1.285671e+01*S83+2.268401e+00*S84+5.368523e+00*S85+7.112136e+00*S86+0.000000e+00*S87+2.864605e+00*S88+0.000000e+00*S89'
.param V67_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+5.421409e-02*S5+0.000000e+00*S6+2.775139e-02*S7+5.718956e-02*S8+(-8.703720e-02)*S9'
.param V67_part2='V67_part1+5.035054e-02*S10+4.977707e-02*S11+1.509133e-02*S12+5.068292e-02*S13+3.684219e-02*S14+2.203374e-01*S15+3.715971e-01*S16+8.842433e-02*S17+1.136697e-01*S18+(-1.572491e-01)*S19'
.param V67_part3='V67_part2+2.094521e-01*S20+(-4.087064e-01)*S21+0.000000e+00*S22+3.030553e-01*S23+(-1.730827e-01)*S24+4.029057e-01*S25+(-5.770666e-02)*S26+5.597458e-01*S27+0.000000e+00*S28+1.098451e+00*S29'
.param V67_part4='V67_part3+0.000000e+00*S30+2.258573e-01*S31+3.130475e-01*S32+0.000000e+00*S33+2.645704e-01*S34+1.487401e+00*S35+0.000000e+00*S36+2.550370e-01*S37+1.647162e+00*S38+0.000000e+00*S39'
.param V67_part5='V67_part4+1.551486e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+5.575215e-01*S45+0.000000e+00*S46+0.000000e+00*S47+(-4.505032e+00)*S48+0.000000e+00*S49'
.param V67_part6='V67_part5+0.000000e+00*S50+3.393475e+00*S51+3.833526e+00*S52+5.085146e+00*S53+4.866322e+00*S54+3.534635e+00*S55+5.783863e+00*S56+0.000000e+00*S57+4.567934e+00*S58+6.182787e+00*S59'
.param V67_part7='V67_part6+1.160451e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+1.111976e+01*S69'
.param V67_part8='V67_part7+1.139958e+01*S70+1.249026e+01*S71+6.103513e+00*S72+2.098219e+01*S73+(-1.092913e+00)*S74+0.000000e+00*S75+(-5.567312e-01)*S76+6.924180e+00*S77+2.156935e+00*S78+1.031931e+01*S79'
.param V67='V67_part8+1.112424e+01*S80+0.000000e+00*S81+4.546515e+00*S82+1.403515e+01*S83+1.100142e+01*S84+1.530640e+01*S85+9.287381e+00*S86+0.000000e+00*S87+1.265133e+01*S88+0.000000e+00*S89'
.param V68_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+4.597773e-02*S5+0.000000e+00*S6+1.878041e-02*S7+3.105191e-02*S8+4.757635e-02*S9'
.param V68_part2='V68_part1+3.775532e-02*S10+3.409670e-02*S11+5.182777e-02*S12+1.859496e-02*S13+2.203242e-03*S14+2.022550e-02*S15+1.476543e-02*S16+3.478701e-02*S17+(-1.757184e-04)*S18+(-1.718896e-02)*S19'
.param V68_part3='V68_part2+1.082356e-02*S20+(-4.807209e-02)*S21+0.000000e+00*S22+1.599700e-02*S23+(-7.062278e-03)*S24+4.292500e-02*S25+3.613212e-02*S26+7.249671e-02*S27+0.000000e+00*S28+(-9.024596e-03)*S29'
.param V68_part4='V68_part3+0.000000e+00*S30+(-1.728169e-02)*S31+(-4.159596e-02)*S32+0.000000e+00*S33+5.644265e-03*S34+(-1.037781e-02)*S35+0.000000e+00*S36+2.104816e-02*S37+5.076284e-02*S38+0.000000e+00*S39'
.param V68_part5='V68_part4+1.554720e-03*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+2.763947e-02*S45+0.000000e+00*S46+0.000000e+00*S47+(-3.108373e-01)*S48+0.000000e+00*S49'
.param V68_part6='V68_part5+0.000000e+00*S50+(-5.930430e-03)*S51+(-3.830566e-01)*S52+(-5.378933e-01)*S53+(-3.918221e-02)*S54+(-6.572712e-01)*S55+(-6.639356e-01)*S56+0.000000e+00*S57+(-8.064256e-01)*S58+(-8.793881e-01)*S59'
.param V68_part7='V68_part6+(-5.463069e-02)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+(-3.437494e-02)*S69'
.param V68_part8='V68_part7+(-2.240442e-01)*S70+(-5.260016e-01)*S71+(-1.054945e-01)*S72+(-4.670989e-01)*S73+(-1.428814e+00)*S74+0.000000e+00*S75+(-1.501236e-01)*S76+3.594455e-01*S77+3.175498e-02*S78+1.832931e-01*S79'
.param V68='V68_part8+2.274622e-01*S80+0.000000e+00*S81+9.739279e-02*S82+1.545592e-01*S83+1.544541e-01*S84+1.735807e-01*S85+2.564034e-01*S86+0.000000e+00*S87+4.743717e-04*S88+0.000000e+00*S89'
.param V69_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.716314e-03)*S5+0.000000e+00*S6+2.463964e-03*S7+2.010483e-03*S8+1.189115e-03*S9'
.param V69_part2='V69_part1+(-4.840017e-04)*S10+8.598927e-04*S11+(-8.770182e-04)*S12+(-1.140696e-03)*S13+(-9.970288e-04)*S14+(-4.874238e-02)*S15+(-3.498591e-02)*S16+(-8.923299e-03)*S17+(-1.214834e-01)*S18+(-1.755514e-01)*S19'
.param V69_part3='V69_part2+(-3.811017e-05)*S20+(-6.147906e-01)*S21+0.000000e+00*S22+(-5.076464e-03)*S23+(-2.630540e-01)*S24+1.979381e-02*S25+1.472702e-02*S26+(-2.192280e-02)*S27+0.000000e+00*S28+(-4.003356e-01)*S29'
.param V69_part4='V69_part3+0.000000e+00*S30+7.119446e-03*S31+1.289701e-02*S32+0.000000e+00*S33+3.274573e-03*S34+(-4.414729e-02)*S35+0.000000e+00*S36+(-2.782530e-02)*S37+(-7.599656e-02)*S38+0.000000e+00*S39'
.param V69_part5='V69_part4+(-1.468853e-01)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-2.496762e-01)*S45+0.000000e+00*S46+0.000000e+00*S47+9.824487e-01*S48+0.000000e+00*S49'
.param V69_part6='V69_part5+0.000000e+00*S50+(-4.938255e-01)*S51+(-3.530602e+00)*S52+(-3.100134e+00)*S53+(-6.740144e-01)*S54+(-5.005962e+00)*S55+(-4.126598e+00)*S56+0.000000e+00*S57+(-6.005928e+00)*S58+(-5.038008e+00)*S59'
.param V69_part7='V69_part6+(-2.497132e-01)*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+1.134415e+00*S69'
.param V69_part8='V69_part7+9.683853e-01*S70+(-4.313112e+00)*S71+1.868170e-02*S72+(-1.822002e+00)*S73+(-9.758689e+00)*S74+0.000000e+00*S75+3.026222e-01*S76+2.337400e+00*S77+(-5.323097e-02)*S78+1.419767e+00*S79'
.param V69='V69_part8+2.338174e+00*S80+0.000000e+00*S81+1.520827e+00*S82+3.180059e+00*S83+(-6.095776e-02)*S84+2.649256e+00*S85+4.862304e+00*S86+0.000000e+00*S87+3.107160e+00*S88+0.000000e+00*S89'
.param V70_part1='(-3.977771e-01)*S0+4.018930e+01*S1+2.002517e+02*S2+7.930295e+01*S3+1.712401e+01*S4+1.599155e+01*S5+4.202409e+01*S6+2.224823e+01*S7+1.680229e+01*S8+1.678736e+03*S9'
.param V70_part2='V70_part1+1.472462e+01*S10+1.502169e+01*S11+1.235646e+01*S12+1.330042e+01*S13+1.741110e+01*S14+1.228032e+01*S15+1.171121e+01*S16+6.002424e+00*S17+4.385399e+00*S18+(-5.647299e+02)*S19'
.param V70_part3='V70_part2+9.176168e+00*S20+2.067087e-01*S21+1.000000e+04*S22+8.147378e+00*S23+6.739395e+01*S24+8.048703e+00*S25+6.186602e+00*S26+4.445707e+00*S27+(-7.639428e+03)*S28+7.803873e-01*S29'
.param V70_part4='V70_part3+(-9.403660e+02)*S30+(-3.681422e+00)*S31+3.751510e+01*S32+(-4.911587e+03)*S33+1.404422e+02*S34+6.029632e+00*S35+9.620964e+00*S36+6.238176e+00*S37+1.515221e+00*S38+(-4.266251e+00)*S39'
.param V70_part5='V70_part4+1.996728e+00*S40+1.000000e+04*S41+1.008785e+00*S42+(-1.566871e+02)*S43+1.000000e+04*S44+(-8.079212e+01)*S45+5.443421e+02*S46+3.317096e+01*S47+(-2.900269e+01)*S48+9.739281e+03*S49'
.param V70_part6='V70_part5+3.041843e+01*S50+1.998873e+00*S51+5.799898e+00*S52+5.069346e+00*S53+1.573580e+00*S54+4.841419e+00*S55+4.441077e+00*S56+8.080323e-02*S57+5.565247e+00*S58+3.933716e+00*S59'
.param V70_part7='V70_part6+7.726265e+00*S60+6.819265e+03*S61+3.316525e+00*S62+2.717965e-01*S63+6.658847e-01*S64+1.438563e+00*S65+(-9.333388e+00)*S66+(-1.427597e+01)*S67+1.065156e+00*S68+4.980343e-01*S69'
.param V70_part8='V70_part7+6.569845e+00*S70+(-3.506408e-01)*S71+(-2.382064e-01)*S72+1.192608e+00*S73+8.462402e+03*S74+(-1.453078e+01)*S75+(-6.624675e-02)*S76+2.603746e+00*S77+2.851897e+00*S78+1.590126e+00*S79'
.param V70='V70_part8+1.291458e+00*S80+(-1.458146e+00)*S81+2.142364e+00*S82+1.328687e+00*S83+(-3.621343e-01)*S84+1.355106e+00*S85+1.286863e+00*S86+3.900256e+03*S87+2.133047e+00*S88+1.401505e+02*S89'
.param V71_part1='3.077496e+01*S0+(-2.872446e+01)*S1+(-3.203880e+02)*S2+(-1.847067e+01)*S3+2.115927e+02*S4+(-3.489512e+00)*S5+(-3.277354e-02)*S6+(-9.869492e+00)*S7+(-6.157414e+00)*S8+4.426630e+01*S9'
.param V71_part2='V71_part1+(-5.237313e+00)*S10+(-4.242913e+00)*S11+(-3.439787e+00)*S12+(-4.296589e+00)*S13+(-3.159570e+00)*S14+(-7.927165e+00)*S15+(-9.900048e+00)*S16+(-9.131986e+00)*S17+(-7.373358e-01)*S18+3.653192e+03*S19'
.param V71_part3='V71_part2+(-2.289259e+00)*S20+1.990857e-01*S21+1.000000e+04*S22+(-2.028901e+00)*S23+5.840235e+01*S24+(-5.659455e-01)*S25+(-4.418760e+00)*S26+2.527015e-01*S27+(-1.928105e+02)*S28+(-1.367976e-01)*S29'
.param V71_part4='V71_part3+(-1.891427e+02)*S30+8.342154e+01*S31+1.706147e+01*S32+(-1.110980e+02)*S33+3.307911e+01*S34+(-1.443957e+00)*S35+1.524429e+01*S36+3.262356e+00*S37+9.949895e-02*S38+(-4.861090e-02)*S39'
.param V71_part5='V71_part4+2.422747e-01*S40+1.000000e+04*S41+1.586067e+00*S42+(-1.103868e+01)*S43+1.000000e+04*S44+3.230651e+03*S45+1.255432e+02*S46+(-3.926234e+00)*S47+(-4.562331e+01)*S48+1.618919e+01*S49'
.param V71_part6='V71_part5+8.808194e+00*S50+1.425596e+00*S51+(-2.298315e+00)*S52+(-1.147614e+00)*S53+1.002211e+00*S54+(-1.758644e+00)*S55+(-9.345817e-01)*S56+(-8.674702e-03)*S57+(-1.759251e+00)*S58+(-1.052979e+00)*S59'
.param V71_part7='V71_part6+4.028756e+01*S60+(-1.462191e+00)*S61+(-2.787415e+00)*S62+7.670748e+00*S63+(-3.226904e+00)*S64+(-3.203557e-01)*S65+(-5.474304e-01)*S66+(-3.105583e+00)*S67+8.457575e-01*S68+1.756850e+00*S69'
.param V71_part8='V71_part7+(-2.013061e+00)*S70+(-2.083219e-02)*S71+5.396723e+00*S72+7.171623e-02*S73+5.976871e+03*S74+1.134272e+02*S75+1.619327e+00*S76+1.329032e+00*S77+4.716226e+01*S78+1.047157e+00*S79'
.param V71='V71_part8+4.673963e-01*S80+1.233088e+01*S81+1.091932e+00*S82+4.788377e-01*S83+5.572394e+00*S84+1.279618e+00*S85+3.315635e-01*S86+9.040642e+02*S87+1.199082e+00*S88+2.129996e+01*S89'
.param V72_part1='9.859502e+00*S0+(-2.473224e+01)*S1+(-3.590995e+01)*S2+(-4.815583e+01)*S3+(-4.833642e+01)*S4+(-5.801896e+00)*S5+(-5.084727e+01)*S6+(-1.058775e+01)*S7+(-5.793338e+00)*S8+(-4.920917e+01)*S9'
.param V72_part2='V72_part1+(-4.577326e+00)*S10+(-5.395986e+00)*S11+(-5.375548e+00)*S12+(-2.332644e+00)*S13+(-2.783372e+00)*S14+(-1.027438e+01)*S15+(-6.239931e+00)*S16+(-1.568887e+00)*S17+(-2.212864e-01)*S18+5.833823e+02*S19'
.param V72_part3='V72_part2+(-3.893920e+00)*S20+(-1.167834e-01)*S21+1.000000e+04*S22+(-3.152224e+00)*S23+(-1.886507e+02)*S24+(-5.050058e+00)*S25+9.902505e-01*S26+(-5.022466e+00)*S27+7.347144e+03*S28+2.435700e+00*S29'
.param V72_part4='V72_part3+1.254217e+02*S30+5.488150e+01*S31+(-2.881792e+01)*S32+2.139971e+01*S33+(-2.327867e+02)*S34+(-2.435930e+00)*S35+(-3.374153e+01)*S36+(-7.704711e+00)*S37+(-8.373711e-01)*S38+4.407609e+01*S39'
.param V72_part5='V72_part4+(-1.825646e+00)*S40+1.000000e+04*S41+(-3.923754e-01)*S42+6.644043e+00*S43+1.000000e+04*S44+(-9.282430e+02)*S45+2.240298e+02*S46+(-5.044507e+00)*S47+4.570462e+01*S48+(-6.706444e+00)*S49'
.param V72_part6='V72_part5+(-2.614843e+01)*S50+(-4.227853e+00)*S51+(-2.338991e+00)*S52+(-1.937930e+00)*S53+(-3.088605e+00)*S54+(-1.595414e+00)*S55+(-1.611504e+00)*S56+1.194137e-01*S57+(-2.442175e+00)*S58+(-4.655152e-01)*S59'
.param V72_part7='V72_part6+2.013027e+01*S60+(-6.024073e-01)*S61+(-2.578427e+00)*S62+(-5.898437e+00)*S63+(-2.389224e-01)*S64+(-1.182532e+00)*S65+3.479957e+00*S66+1.420044e+00*S67+7.243980e-01*S68+(-1.497900e+00)*S69'
.param V72_part8='V72_part7+(-3.572761e+00)*S70+3.890492e-02*S71+(-3.459226e+00)*S72+(-1.008693e+00)*S73+1.000000e+04*S74+(-7.493501e+00)*S75+4.637148e+00*S76+2.263312e-01*S77+(-3.421227e+01)*S78+3.278917e-01*S79'
.param V72='V72_part8+(-2.660979e-01)*S80+(-5.131041e+00)*S81+7.118009e-01*S82+(-2.143616e-01)*S83+(-3.835824e+00)*S84+(-1.334373e-01)*S85+1.289488e-01*S86+1.000000e+04*S87+1.841087e-01*S88+(-2.061794e+01)*S89'
.param V73_part1='(-4.876402e-02)*S0+4.245632e+00*S1+1.524151e+01*S2+(-1.422079e+00)*S3+(-3.281862e+01)*S4+1.279395e+00*S5+(-1.458126e+01)*S6+1.892823e+00*S7+7.939580e-01*S8+(-2.155914e+03)*S9'
.param V73_part2='V73_part1+(-1.436491e+00)*S10+7.300800e-01*S11+(-5.214210e-01)*S12+3.362188e+00*S13+9.271149e+00*S14+(-6.161419e-01)*S15+(-4.865219e-01)*S16+5.003179e-02*S17+(-8.921793e-02)*S18+3.274578e+03*S19'
.param V73_part3='V73_part2+1.477534e-01*S20+3.593815e-04*S21+(-1.000000e+04)*S22+1.731868e-01*S23+5.817761e+00*S24+(-8.359333e-02)*S25+(-4.603057e-01)*S26+(-2.186748e-01)*S27+(-1.826049e+01)*S28+1.897604e-01*S29'
.param V73_part4='V73_part3+1.231500e+00*S30+2.814849e+00*S31+(-5.901829e-01)*S32+1.599901e+00*S33+(-1.096236e+00)*S34+(-3.119290e-01)*S35+(-1.822596e-01)*S36+(-2.201002e-01)*S37+(-4.213398e-02)*S38+4.806738e-02*S39'
.param V73_part5='V73_part4+(-1.305772e-01)*S40+(-5.850377e+03)*S41+(-1.467094e-01)*S42+(-4.208677e-01)*S43+1.000000e+04*S44+2.676940e+01*S45+1.245169e+00*S46+(-7.860624e-01)*S47+(-1.735557e+00)*S48+(-2.784763e+00)*S49'
.param V73_part6='V73_part5+(-1.188612e+00)*S50+(-1.773085e-01)*S51+4.775384e-01*S52+5.758099e-01*S53+(-1.510790e-01)*S54+4.029170e-01*S55+3.238453e-01*S56+3.040050e-02*S57+3.032331e-01*S58+4.832479e-01*S59'
.param V73_part7='V73_part6+1.846837e-02*S60+(-1.322676e+00)*S61+(-1.419439e-02)*S62+(-2.186014e-01)*S63+3.774380e-02*S64+(-2.375083e-03)*S65+2.163807e-02*S66+(-2.221595e-02)*S67+(-3.882890e-02)*S68+(-1.122031e-01)*S69'
.param V73_part8='V73_part7+2.931710e-02*S70+1.505630e-02*S71+(-3.329835e-01)*S72+2.436169e-02*S73+(-2.152190e+01)*S74+(-6.938090e-01)*S75+(-6.190594e-02)*S76+(-3.889212e-02)*S77+1.613191e+00*S78+(-5.066352e-02)*S79'
.param V73='V73_part8+(-2.939183e-02)*S80+(-2.693072e-01)*S81+(-2.643304e-02)*S82+(-1.880492e-02)*S83+(-1.202552e-01)*S84+(-4.086671e-02)*S85+(-3.387161e-02)*S86+(-6.904238e+01)*S87+(-4.759227e-02)*S88+(-8.491512e-01)*S89'
.param V74_part1='6.029948e+00*S0+(-2.648927e-01)*S1+(-3.884211e+00)*S2+2.442240e-01*S3+7.563168e+00*S4+(-3.767749e-02)*S5+8.569774e-03*S6+(-1.627730e-01)*S7+(-4.800755e-02)*S8+7.974099e-01*S9'
.param V74_part2='V74_part1+(-1.012424e-01)*S10+(-2.370405e-02)*S11+5.126996e-02*S12+(-9.506568e-02)*S13+(-7.355038e-05)*S14+1.105834e+00*S15+(-2.576015e-01)*S16+1.129955e+02*S17+2.271312e+00*S18+9.553360e+00*S19'
.param V74_part3='V74_part2+(-7.242689e-02)*S20+4.137192e-01*S21+1.000000e+04*S22+(-8.793348e-02)*S23+(-1.566755e+00)*S24+(-5.388024e-01)*S25+(-2.429928e-01)*S26+2.332970e-02*S27+1.000000e+04*S28+7.662519e-01*S29'
.param V74_part4='V74_part3+2.014078e+03*S30+(-1.116973e+01)*S31+7.366612e-01*S32+1.000000e+04*S33+5.652139e+01*S34+(-4.257076e-01)*S35+2.353475e+00*S36+6.627414e-01*S37+(-6.647099e-02)*S38+5.240901e-02*S39'
.param V74_part5='V74_part4+(-1.386123e-02)*S40+1.000000e+04*S41+(-1.095976e+00)*S42+3.333810e+02*S43+1.000000e+04*S44+(-1.779848e+01)*S45+(-4.021102e+02)*S46+(-1.414856e+01)*S47+1.182544e+02*S48+(-6.488016e+03)*S49'
.param V74_part6='V74_part5+2.657240e-01*S50+(-1.387761e-01)*S51+(-3.794360e-01)*S52+(-4.644507e-02)*S53+(-3.142201e-01)*S54+(-1.713646e-01)*S55+(-3.142223e-02)*S56+1.869930e-02*S57+(-2.424659e-02)*S58+5.830830e-02*S59'
.param V74_part7='V74_part6+(-1.082924e+01)*S60+(-4.541140e+03)*S61+2.023289e+00*S62+1.257596e+00*S63+3.175014e+00*S64+6.403957e-01*S65+1.909748e+01*S66+3.263555e+01*S67+(-1.171423e+00)*S68+(-5.248040e-01)*S69'
.param V74_part8='V74_part7+(-2.188205e-01)*S70+8.590258e-01*S71+(-1.474681e+00)*S72+(-2.728802e-01)*S73+4.933205e+03*S74+4.525453e+00*S75+(-1.026002e+00)*S76+(-1.702801e+00)*S77+1.854222e+00*S78+(-1.169023e+00)*S79'
.param V74='V74_part8+(-5.635730e-01)*S80+(-5.823680e-01)*S81+(-1.757359e+00)*S82+(-7.060722e-01)*S83+(-4.731832e-01)*S84+(-1.222636e+00)*S85+(-8.984905e-01)*S86+(-3.725090e+03)*S87+(-1.907005e+00)*S88+3.071623e-01*S89'
.param V75_part1='2.418679e-01*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V75_part2='V75_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+9.919484e-02*S16+0.000000e+00*S17+0.000000e+00*S18+(-4.762348e-01)*S19'
.param V75_part3='V75_part2+0.000000e+00*S20+0.000000e+00*S21+2.087300e-01*S22+0.000000e+00*S23+1.116164e-01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+8.270445e-01*S29'
.param V75_part4='V75_part3+7.599279e-01*S30+0.000000e+00*S31+0.000000e+00*S32+2.440738e-01*S33+0.000000e+00*S34+5.086101e-01*S35+2.614622e-02*S36+2.819960e-01*S37+0.000000e+00*S38+1.356865e+00*S39'
.param V75_part5='V75_part4+0.000000e+00*S40+9.356378e-01*S41+1.697113e+00*S42+6.840590e+00*S43+2.729851e+00*S44+0.000000e+00*S45+4.342221e-01*S46+(-2.043991e-01)*S47+1.816904e-01*S48+2.472509e-01*S49'
.param V75_part6='V75_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V75_part7='V75_part6+0.000000e+00*S60+(-3.310927e-01)*S61+1.588397e+00*S62+1.328256e+00*S63+4.038012e+00*S64+2.502036e+00*S65+1.615447e+00*S66+9.630528e+00*S67+1.718666e+00*S68+0.000000e+00*S69'
.param V75_part8='V75_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.244520e+01)*S74+1.002289e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V75='V75_part8+0.000000e+00*S80+1.306518e-01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V76_part1='4.086379e-01*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V76_part2='V76_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+5.082123e-01*S16+0.000000e+00*S17+0.000000e+00*S18+7.734018e-01*S19'
.param V76_part3='V76_part2+0.000000e+00*S20+0.000000e+00*S21+9.687459e-01*S22+0.000000e+00*S23+2.534027e-01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-4.151284e-02)*S29'
.param V76_part4='V76_part3+1.599056e+00*S30+0.000000e+00*S31+0.000000e+00*S32+5.972584e-01*S33+0.000000e+00*S34+(-2.252559e-01)*S35+5.969208e-01*S36+3.592635e-02*S37+0.000000e+00*S38+1.452289e+00*S39'
.param V76_part5='V76_part4+0.000000e+00*S40+2.343852e+00*S41+1.234032e+00*S42+(-1.015077e+00)*S43+7.513247e+00*S44+0.000000e+00*S45+(-9.990597e-02)*S46+3.023280e+00*S47+4.121294e-01*S48+8.058600e-01*S49'
.param V76_part6='V76_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V76_part7='V76_part6+0.000000e+00*S60+(-3.192010e+00)*S61+7.373806e+00*S62+1.100810e+00*S63+5.373937e+00*S64+6.290656e+00*S65+4.331771e+00*S66+4.448009e+00*S67+(-1.900254e+00)*S68+0.000000e+00*S69'
.param V76_part8='V76_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+7.103103e+00*S74+9.136006e-01*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V76='V76_part8+0.000000e+00*S80+2.870443e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V77_part1='(-7.973319e-01)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V77_part2='V77_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+8.427173e-02*S16+0.000000e+00*S17+0.000000e+00*S18+1.025949e+00*S19'
.param V77_part3='V77_part2+0.000000e+00*S20+0.000000e+00*S21+8.501077e-01*S22+0.000000e+00*S23+8.212019e-01*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-7.394021e-01)*S29'
.param V77_part4='V77_part3+1.176686e+00*S30+0.000000e+00*S31+0.000000e+00*S32+9.483171e-01*S33+0.000000e+00*S34+(-9.657024e-02)*S35+9.999962e-01*S36+8.041473e-01*S37+0.000000e+00*S38+(-1.000680e+00)*S39'
.param V77_part5='V77_part4+0.000000e+00*S40+3.415373e+00*S41+(-4.526606e+00)*S42+(-4.886697e+00)*S43+3.656587e+00*S44+0.000000e+00*S45+5.277309e-01*S46+1.163631e+00*S47+9.803680e-02*S48+2.876920e+00*S49'
.param V77_part6='V77_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V77_part7='V77_part6+0.000000e+00*S60+9.007200e+00*S61+2.237014e+00*S62+5.939255e+00*S63+(-2.531810e+00)*S64+6.815819e+00*S65+(-7.996359e+00)*S66+(-1.015137e+01)*S67+4.636643e+00*S68+0.000000e+00*S69'
.param V77_part8='V77_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+2.052984e+01*S74+7.685440e-01*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V77='V77_part8+0.000000e+00*S80+1.522698e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V78_part1='3.387993e-02*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V78_part2='V78_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-2.469929e-02)*S16+0.000000e+00*S17+0.000000e+00*S18+4.860700e-02*S19'
.param V78_part3='V78_part2+0.000000e+00*S20+0.000000e+00*S21+2.955350e-02*S22+0.000000e+00*S23+(-3.249828e-03)*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-1.680694e-01)*S29'
.param V78_part4='V78_part3+(-8.704897e-03)*S30+0.000000e+00*S31+0.000000e+00*S32+(-8.334345e-02)*S33+0.000000e+00*S34+(-4.827970e-02)*S35+(-5.449711e-02)*S36+(-9.826367e-02)*S37+0.000000e+00*S38+(-7.134582e-02)*S39'
.param V78_part5='V78_part4+0.000000e+00*S40+(-1.838270e-01)*S41+(-3.568475e-02)*S42+(-3.084153e-01)*S43+(-6.631226e-01)*S44+0.000000e+00*S45+(-9.128705e-02)*S46+(-2.087693e-02)*S47+(-1.825369e-02)*S48+(-1.711482e-01)*S49'
.param V78_part6='V78_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V78_part7='V78_part6+0.000000e+00*S60+(-1.157807e-02)*S61+(-4.775696e-01)*S62+(-7.243711e-02)*S63+(-3.554658e-01)*S64+(-9.334874e-01)*S65+(-2.378443e-01)*S66+(-3.689185e-01)*S67+(-2.041984e-01)*S68+0.000000e+00*S69'
.param V78_part8='V78_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-8.789124e-01)*S74+(-1.321521e-02)*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V78='V78_part8+0.000000e+00*S80+(-2.629198e-02)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V79_part1='(-7.068866e-04)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V79_part2='V79_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-5.812113e-02)*S16+0.000000e+00*S17+0.000000e+00*S18+5.544089e-02*S19'
.param V79_part3='V79_part2+0.000000e+00*S20+0.000000e+00*S21+(-2.805620e-01)*S22+0.000000e+00*S23+3.940272e-04*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+2.602721e-02*S29'
.param V79_part4='V79_part3+(-4.642030e-01)*S30+0.000000e+00*S31+0.000000e+00*S32+4.475274e-02*S33+0.000000e+00*S34+1.092237e-01*S35+(-7.246156e-02)*S36+(-1.327604e-01)*S37+0.000000e+00*S38+(-7.559958e-01)*S39'
.param V79_part5='V79_part4+0.000000e+00*S40+(-1.540861e+00)*S41+1.443635e+00*S42+7.025177e-02*S43+(-4.105265e+00)*S44+0.000000e+00*S45+1.066981e-01*S46+2.489458e-01*S47+3.848411e-02*S48+(-1.194542e-01)*S49'
.param V79_part6='V79_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V79_part7='V79_part6+0.000000e+00*S60+4.353417e-01*S61+1.671385e-01*S62+(-6.591329e-01)*S63+1.187399e-01*S64+(-1.208417e+00)*S65+1.400132e+00*S66+3.249533e-01*S67+7.237532e+00*S68+0.000000e+00*S69'
.param V79_part8='V79_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.502941e+00)*S74+(-5.809771e-01)*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V79='V79_part8+0.000000e+00*S80+(-1.735225e-01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='0.7064*_P21'
.param _P23='0.7064*_P21'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='V35+V36*rad_+V37*w_'
.param _P28='_P27+V38*gdis_+V39*spacing_'
.param _P29='0.5*(_P28+sqrt(_P28*_P28+0.001))'
.param _P30='V40+V41*rad_+V42*w_'
.param _P31='_P30+V43*gdis_+V44*spacing_'
.param _P32='0.5*(_P31+sqrt(_P31*_P31+0.001))'
.param _P33='V45+V46*rad_+V47*w_'
.param _P34='_P33+V48*gdis_+V49*spacing_'
.param _P35='0.5*(_P34+sqrt(_P34*_P34+0.001))'
.param _P36='V50+V51*rad_+V52*w_'
.param _P37='_P36+V53*gdis_+V54*spacing_'
.param _P38='0.5*(_P37+sqrt(_P37*_P37+0.001))'
.param _P39='V55+V56*rad_+V57*w_'
.param _P40='_P39+V58*gdis_+V59*spacing_'
.param _P41='0.5*(_P40+sqrt(_P40*_P40+0.001))'
.param _P42='1e-14*_P26'
.param _P43='100*_P29'
.param _P44='1e-15*_P32'
.param _P45='1e-14*_P26'
.param _P46='100*_P29'
.param _P47='1e-15*_P32'
.param _P48='1e-14*_P35'
.param _P49='100*_P38'
.param _P50='1e-15*_P41'
.param _P51='V60+V61*rad_+V62*w_'
.param _P52='_P51+V63*gdis_+V64*spacing_'
.param _P53='0.5*(_P52+sqrt(_P52*_P52+0.001))'
.param _P54='V65+V66*rad_+V67*w_'
.param _P55='_P54+V68*gdis_+V69*spacing_'
.param _P56='0.5*(_P55+sqrt(_P55*_P55+0.001))'
.param _P57='100*_P53'
.param _P58='1e-13*_P56'
.param _P59='V70+V71*rad_+V72*w_'
.param _P60='_P59+V73*gdis_+V74*spacing_'
.param _P61='0.5*(_P60+sqrt(_P60*_P60+0.001))'
.param _P62='V75+V76*rad_+V77*w_'
.param _P63='_P62+V78*gdis_+V79*spacing_'
.param _P64='0.5*(_P63+sqrt(_P63*_P63+0.001))'
.param _P65='100*_P61'
.param _P66='1e-13*_P64'
.param _P67='100*_P61'
.param _P68='1e-13*_P64'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P22
k2 ls2_1 ls1_2 K=_P23
c_1_sub top _n1_1_sub '_P42*((1/(12.503905+(1.7014125)*(lay-3-(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P43*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P44* csub_indfac'
c_2_sub bottom _n1_2_sub '_P45*((1/(12.503905+(1.7014125)*(lay-3-(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P46*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P47* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P48*((1/(12.503905+(1.7014125)*(lay-3-(lay-9)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P49*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_3_sub _n1_3_sub gnode '_P50* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P57*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P58* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P65*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P66* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P67*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P68* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_sym_mu_z

.subckt spiral_sym_ct_mu_z top bottom gnode tap rad=6e-05 w=9e-06 nr=1 gdis=5e-05 spacing=3e-06 lay=9 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='4.033104e+00*S0+(-5.189601e-03)*S1+(-5.363835e-04)*S2+4.671074e+00*S3+1.453582e+00*S4+(-2.949642e-03)*S5+(-3.288494e+01)*S6+2.560034e-02*S7+3.174543e-02*S8+5.132071e-02*S9'
.param V0_part2='V0_part1+1.170629e+00*S10+4.079817e-03*S11+1.125927e-01*S12+(-2.806397e-02)*S13+(-1.780298e-01)*S14+5.500941e-01*S15+1.320305e-01*S16+1.252967e-01*S17+7.228608e-01*S18+1.512843e-02*S19'
.param V0_part3='V0_part2+1.377423e-01*S20+(-1.244868e+01)*S21+(-7.870439e-01)*S22+6.531402e-02*S23+(-2.116289e+00)*S24+(-1.764419e-03)*S25+1.266450e-01*S26+(-3.210350e+00)*S27+(-8.859814e-02)*S28+5.493851e-02*S29'
.param V0_part4='V0_part3+1.700995e-02*S30+8.048503e-01*S31+(-2.339723e+00)*S32+(-1.033810e+03)*S33+1.524747e+00*S34+1.725320e-02*S35+(-6.952210e+01)*S36+1.620890e-02*S37+2.688648e-01*S38+(-2.494978e-01)*S39'
.param V0_part5='V0_part4+6.832870e-01*S40+(-3.480577e-01)*S41+(-3.980303e-01)*S42+3.928579e-01*S43+4.485077e-02*S44+(-3.206887e-01)*S45+1.682069e-01*S46+(-1.504242e+01)*S47+(-1.733375e-01)*S48+7.041457e-01*S49'
.param V0_part6='V0_part5+(-8.645700e+00)*S50+(-1.687865e-01)*S51+4.774215e+01*S52+4.027632e-01*S53+(-1.139437e-02)*S54+1.433905e+00*S55+(-3.432032e+00)*S56+(-1.345115e-01)*S57+1.900882e+00*S58+(-3.363246e-01)*S59'
.param V0_part7='V0_part6+(-2.048085e-01)*S60+2.827565e-01*S61+9.775697e-01*S62+(-4.054931e-01)*S63+(-9.993260e-02)*S64+(-6.482521e-01)*S65+(-2.855749e-02)*S66+(-4.075397e-01)*S67+(-2.352591e-01)*S68+(-7.786999e-01)*S69'
.param V0_part8='V0_part7+(-5.610439e-01)*S70+1.574139e-02*S71+(-9.240090e-01)*S72+(-1.010477e+00)*S73+(-7.362537e-01)*S74+(-7.949181e-01)*S75+7.555220e+00*S76+2.119154e-01*S77+(-5.858911e-01)*S78+3.193508e-02*S79'
.param V0='V0_part8+2.835329e-01*S80+(-5.878513e-02)*S81+(-1.158264e-02)*S82+5.527146e-02*S83+(-2.424404e-01)*S84+(-3.222489e-01)*S85+1.467459e+00*S86+(-1.869270e-01)*S87+(-8.239695e-01)*S88+(-1.009956e+00)*S89'
.param V1_part1='5.803997e+01*S0+1.197022e-01*S1+1.042776e-01*S2+2.178852e+00*S3+5.022514e+01*S4+1.061394e-01*S5+1.297391e+02*S6+1.447888e-01*S7+1.117912e-01*S8+1.542440e-01*S9'
.param V1_part2='V1_part1+2.180111e+01*S10+1.159612e-01*S11+1.415928e+01*S12+7.498809e-01*S13+1.322472e+00*S14+2.178276e-01*S15+5.887093e-01*S16+5.769127e-01*S17+3.956276e-01*S18+7.018385e-01*S19'
.param V1_part3='V1_part2+5.991973e-01*S20+5.509167e+01*S21+3.066741e+00*S22+7.224209e-01*S23+8.348003e+00*S24+7.958384e-01*S25+5.104897e-01*S26+6.676921e+00*S27+9.032231e-01*S28+6.192464e-01*S29'
.param V1_part4='V1_part3+9.428450e-01*S30+5.084093e+00*S31+1.596482e+01*S32+6.617582e+01*S33+5.995094e-01*S34+1.710380e+00*S35+(-7.014210e+00)*S36+2.447011e+00*S37+1.123906e+00*S38+1.228014e+00*S39'
.param V1_part5='V1_part4+1.053485e+00*S40+2.184969e+00*S41+1.273464e+00*S42+1.219625e+00*S43+1.342874e+00*S44+5.386665e+00*S45+1.857123e+00*S46+2.757131e+02*S47+3.796478e+00*S48+1.464332e+00*S49'
.param V1_part6='V1_part5+1.251907e+02*S50+5.107632e+00*S51+1.443265e+01*S52+1.886127e+00*S53+1.881379e+00*S54+1.552596e+00*S55+1.194185e+01*S56+2.724681e+00*S57+2.704030e+00*S58+2.339400e+00*S59'
.param V1_part7='V1_part6+2.793312e+00*S60+2.138126e+00*S61+2.476909e+00*S62+2.932969e+00*S63+2.601277e+00*S64+3.623019e+00*S65+3.101608e+00*S66+2.864279e+00*S67+2.871617e+00*S68+3.795715e+00*S69'
.param V1_part8='V1_part7+3.026158e+00*S70+2.911292e+00*S71+4.329760e+00*S72+3.328159e+00*S73+3.533991e+00*S74+1.829146e+01*S75+1.343026e+00*S76+5.131098e+00*S77+1.161351e+01*S78+5.008425e+00*S79'
.param V1='V1_part8+4.957331e+00*S80+6.853712e+00*S81+5.392789e+00*S82+5.689380e+00*S83+6.745355e+00*S84+5.490865e+00*S85+6.336898e+00*S86+1.112298e+01*S87+6.266071e+00*S88+4.959369e+00*S89'
.param V2_part1='(-1.467069e+01)*S0+8.374256e-03*S1+7.526017e-03*S2+4.044437e+00*S3+(-1.634001e+00)*S4+6.887104e-03*S5+1.265303e+01*S6+(-3.302764e-02)*S7+(-1.629212e-02)*S8+(-1.146430e-01)*S9'
.param V2_part2='V2_part1+3.838122e-01*S10+(-5.228151e-03)*S11+8.233997e+00*S12+(-9.149129e-02)*S13+(-6.906923e-02)*S14+(-5.360972e-01)*S15+1.116001e-01*S16+1.756388e-01*S17+(-7.885832e-01)*S18+1.202475e-01*S19'
.param V2_part3='V2_part2+1.348258e-01*S20+6.141571e-01*S21+1.239805e+00*S22+1.324533e-01*S23+2.674536e+01*S24+(-1.082293e-01)*S25+(-4.061303e-02)*S26+9.559368e+01*S27+(-9.267045e-02)*S28+(-5.053944e-02)*S29'
.param V2_part4='V2_part3+6.479973e-02*S30+3.267764e-01*S31+2.623939e+00*S32+1.000000e+04*S33+6.181743e-02*S34+2.522558e-01*S35+6.860509e+02*S36+1.931094e-01*S37+1.944344e-01*S38+5.731284e-01*S39'
.param V2_part5='V2_part4+4.114158e-02*S40+1.349508e-01*S41+7.970367e-01*S42+4.336038e-03*S43+8.920307e-02*S44+7.608890e-01*S45+5.762140e-01*S46+3.790947e+01*S47+6.217036e-01*S48+5.099182e-01*S49'
.param V2_part6='V2_part5+3.072360e+00*S50+5.934605e-01*S51+(-9.897212e+00)*S52+5.362398e-01*S53+(-1.521681e-01)*S54+4.651833e-01*S55+8.817833e-01*S56+1.408835e-01*S57+(-1.114951e-01)*S58+5.097818e-01*S59'
.param V2_part7='V2_part6+8.758631e-01*S60+8.103468e-01*S61+8.700392e-01*S62+7.519582e-01*S63+7.188574e-01*S64+1.125427e+00*S65+4.180903e-01*S66+7.072091e-01*S67+9.863527e-01*S68+3.647178e-01*S69'
.param V2_part8='V2_part7+5.689895e-01*S70+8.528861e-01*S71+4.156497e-01*S72+7.100471e-01*S73+8.903187e-01*S74+5.263223e+00*S75+5.027361e-01*S76+1.836048e+00*S77+2.483096e+00*S78+1.681837e+00*S79'
.param V2='V2_part8+1.870091e+00*S80+8.570990e-01*S81+1.695670e+00*S82+2.066087e+00*S83+5.139672e-01*S84+1.489229e+00*S85+1.730059e+00*S86+(-7.869266e-01)*S87+1.136808e+00*S88+1.477001e+00*S89'
.param V3_part1='1.046172e+01*S0+1.347790e-02*S1+1.227110e-02*S2+(-2.632473e+00)*S3+(-1.684484e+00)*S4+1.145085e-02*S5+1.903137e+01*S6+7.265883e-03*S7+7.483769e-03*S8+7.229847e-03*S9'
.param V3_part2='V3_part1+(-4.361317e-01)*S10+1.198886e-02*S11+(-2.529740e+00)*S12+7.820925e-02*S13+1.591805e-01*S14+(-2.461007e-02)*S15+1.372336e-01*S16+1.346451e-01*S17+(-5.025827e-02)*S18+1.107379e-01*S19'
.param V3_part3='V3_part2+1.225486e-01*S20+(-4.793771e+00)*S21+2.510355e-01*S22+1.166348e-01*S23+4.336656e-01*S24+(-4.513200e-02)*S25+(-2.104730e-02)*S26+6.392142e-01*S27+(-4.333497e-02)*S28+(-3.461673e-02)*S29'
.param V3_part4='V3_part3+1.890997e-02*S30+(-2.983451e-01)*S31+2.971167e-01*S32+(-6.986568e+00)*S33+5.533062e-02*S34+1.067533e-01*S35+(-1.503529e+00)*S36+(-6.320843e-02)*S37+(-4.933223e-02)*S38+(-1.292383e-02)*S39'
.param V3_part5='V3_part4+1.653692e-01*S40+1.178746e-01*S41+(-5.092350e-03)*S42+1.613846e-01*S43+1.405172e-01*S44+(-6.561765e-03)*S45+8.731260e-02*S46+2.607866e+00*S47+2.012748e-03*S48+1.997396e-01*S49'
.param V3_part6='V3_part5+2.277687e-01*S50+(-2.310934e-03)*S51+(-1.153451e+01)*S52+2.366928e-01*S53+(-1.287881e-02)*S54+2.648078e-01*S55+1.211649e-01*S56+(-1.678934e-02)*S57+(-2.045974e-01)*S58+1.901025e-01*S59'
.param V3_part7='V3_part6+7.705297e-03*S60+1.044101e-01*S61+2.910112e-01*S62+9.267524e-03*S63+2.867557e-04*S64+8.007590e-02*S65+5.420181e-03*S66+(-1.856010e-03)*S67+1.390607e-01*S68+(-1.459071e-02)*S69'
.param V3_part8='V3_part7+2.312924e-03*S70+1.695268e-01*S71+(-2.113805e-02)*S72+(-2.217056e-02)*S73+2.156205e-01*S74+2.817201e-02*S75+(-3.209413e-01)*S76+2.418003e-01*S77+7.878137e-04*S78+1.112108e-01*S79'
.param V3='V3_part8+3.095986e-01*S80+(-4.803846e-02)*S81+2.467582e-01*S82+1.881325e-01*S83+1.742427e-01*S84+3.180789e-01*S85+5.683995e-01*S86+(-5.552012e-01)*S87+2.979477e-01*S88+1.719790e-01*S89'
.param V4_part1='4.684412e-03*S0+2.160263e-03*S1+1.616408e-03*S2+2.917502e-01*S3+2.557083e+00*S4+1.526228e-03*S5+1.000634e+00*S6+2.678304e-03*S7+2.019911e-03*S8+2.442859e-03*S9'
.param V4_part2='V4_part1+5.311563e-01*S10+1.916981e-03*S11+6.308239e-01*S12+7.299829e-03*S13+1.283371e-02*S14+(-1.059362e-04)*S15+5.281382e-03*S16+2.008499e-02*S17+4.181413e-04*S18+(-4.998723e-05)*S19'
.param V4_part3='V4_part2+1.548621e-02*S20+4.114807e+00*S21+1.885878e-01*S22+(-9.181391e-03)*S23+3.308626e+00*S24+3.468017e-03*S25+3.388942e-03*S26+1.871577e+01*S27+9.321011e-03*S28+1.067261e-02*S29'
.param V4_part4='V4_part3+1.656297e-02*S30+1.948852e-01*S31+7.126534e-01*S32+7.859168e+01*S33+(-2.423746e-01)*S34+3.283736e-02*S35+3.562248e+01*S36+(-2.448702e-03)*S37+(-6.585934e-03)*S38+5.284613e-01*S39'
.param V4_part5='V4_part4+1.510900e-02*S40+6.521621e-02*S41+8.047829e-01*S42+1.999268e-02*S43+3.564607e-02*S44+5.618826e-01*S45+1.039618e-01*S46+8.879256e+00*S47+4.801757e-01*S48+1.081897e-01*S49'
.param V4_part6='V4_part5+4.876400e+00*S50+8.662443e-01*S51+1.651209e+00*S52+1.131197e-01*S53+7.814308e-01*S54+5.904139e-03*S55+5.415262e-01*S56+3.248325e-01*S57+(-3.083465e-01)*S58+2.600810e-02*S59'
.param V4_part7='V4_part6+3.108323e-01*S60+2.657637e-02*S61+1.647382e-01*S62+3.837262e-01*S63+3.829443e-01*S64+1.212493e-01*S65+3.289328e-01*S66+2.483886e-01*S67+1.038310e-01*S68+4.771095e-01*S69'
.param V4_part8='V4_part7+2.776954e-01*S70+2.170777e-02*S71+5.766960e-01*S72+5.678109e-01*S73+1.286234e-02*S74+1.502067e+00*S75+(-9.387787e-01)*S76+4.778392e-01*S77+7.423278e-01*S78+4.859490e-01*S79'
.param V4='V4_part8+4.996177e-01*S80+1.678430e+00*S81+6.787285e-01*S82+7.635401e-01*S83+6.849430e-01*S84+6.501749e-01*S85+9.485378e-01*S86+3.371573e+00*S87+7.468441e-01*S88+(-1.476608e-02)*S89'
.param V5_part1='(-2.688306e+02)*S0+(-1.747167e-02)*S1+(-4.018050e-03)*S2+3.229275e+02*S3+(-2.765869e+01)*S4+(-1.576131e-02)*S5+(-6.492829e+02)*S6+(-5.462618e-02)*S7+(-2.825284e-02)*S8+(-1.300660e-01)*S9'
.param V5_part2='V5_part1+(-2.218025e+01)*S10+(-3.489633e-02)*S11+(-3.220775e+01)*S12+(-4.731799e-01)*S13+(-1.292171e+00)*S14+(-4.971984e-02)*S15+1.257603e+00*S16+2.206148e+00*S17+(-1.338139e-01)*S18+1.127753e+00*S19'
.param V5_part3='V5_part2+2.244813e+00*S20+(-2.241479e-01)*S21+9.290062e-01*S22+2.012436e+00*S23+9.652090e-01*S24+(-1.238224e-01)*S25+(-1.265816e-02)*S26+9.347509e-01*S27+(-1.747982e-01)*S28+(-4.643658e-02)*S29'
.param V5_part4='V5_part3+1.491727e+00*S30+7.875745e-02*S31+3.086785e+00*S32+(-3.067762e-01)*S33+3.340987e-02*S34+2.666843e+00*S35+(-4.237444e-01)*S36+(-7.537565e-02)*S37+8.383011e-02*S38+(-3.399230e-01)*S39'
.param V5_part5='V5_part4+1.908150e+00*S40+2.901592e+00*S41+(-4.693609e-01)*S42+1.339947e+00*S43+2.605937e+00*S44+3.859827e+00*S45+3.777300e+00*S46+5.426026e+00*S47+1.703759e+00*S48+3.451927e+00*S49'
.param V5_part6='V5_part5+4.833181e+00*S50+1.199319e+00*S51+(-4.445043e-02)*S52+4.649347e+00*S53+4.336273e-01*S54+2.862106e+00*S55+3.746223e+00*S56+(-4.310896e-01)*S57+(-3.304519e-01)*S58+3.705868e+00*S59'
.param V5_part7='V5_part6+2.161353e+00*S60+3.775122e+00*S61+6.415552e+00*S62+1.374814e+00*S63+2.026651e+00*S64+5.229977e+00*S65+5.025658e-01*S66+2.100035e+00*S67+5.539250e+00*S68+6.068325e-01*S69'
.param V5_part8='V5_part7+1.642075e+00*S70+4.837535e+00*S71+1.538515e-01*S72+9.205344e-01*S73+4.115518e+00*S74+3.713154e+00*S75+2.661032e-01*S76+7.428973e+00*S77+3.365222e+00*S78+5.039016e+00*S79'
.param V5='V5_part8+7.126622e+00*S80+2.666872e+00*S81+4.802944e+00*S82+6.544309e+00*S83+1.426386e+00*S84+4.091291e+00*S85+6.395091e+00*S86+2.747603e+00*S87+3.507275e+00*S88+4.625291e+00*S89'
.param V6_part1='1.512477e+03*S0+1.305920e-01*S1+6.737093e-02*S2+9.409099e+00*S3+2.083193e+03*S4+6.801374e-02*S5+1.597574e+03*S6+1.339777e-01*S7+7.575302e-02*S8+1.939266e-01*S9'
.param V6_part2='V6_part1+1.008815e+03*S10+7.110202e-02*S11+6.618224e+02*S12+2.417579e+01*S13+1.997312e+01*S14+4.217605e-01*S15+1.099810e+00*S16+2.718154e-01*S17+4.384363e-01*S18+9.520335e-01*S19'
.param V6_part3='V6_part2+(-2.941385e-01)*S20+4.722007e-01*S21+2.793725e-01*S22+(-8.095010e-02)*S23+1.855882e+00*S24+2.790153e-01*S25+1.284696e-01*S26+2.559004e+00*S27+2.903954e-01*S28+1.456097e-01*S29'
.param V6_part4='V6_part3+1.312235e+00*S30+3.924859e-01*S31+5.689276e-01*S32+9.547631e-01*S33+4.206358e-01*S34+1.296394e+00*S35+8.510380e-01*S36+5.007696e-01*S37+2.101283e-01*S38+1.605660e+00*S39'
.param V6_part5='V6_part4+6.530120e-01*S40+5.100819e-01*S41+1.128690e+00*S42+1.242691e+00*S43+5.486627e-01*S44+(-2.446656e-01)*S45+3.146301e-01*S46+6.008379e-01*S47+3.583727e+00*S48+2.983223e-01*S49'
.param V6_part6='V6_part5+1.349621e+00*S50+5.204368e+00*S51+5.439735e-01*S52+4.511641e-01*S53+6.131930e-01*S54+1.341726e+00*S55+1.706029e+00*S56+1.017869e+00*S57+6.497239e-01*S58+4.978729e-01*S59'
.param V6_part7='V6_part6+4.392363e-01*S60+(-2.950953e-01)*S61+8.732107e-01*S62+2.340671e-01*S63+3.633610e-01*S64+2.925357e+00*S65+2.010706e+00*S66+7.085440e-01*S67+7.016929e-01*S68+1.446434e+00*S69'
.param V6_part8='V6_part7+1.186567e+00*S70+4.271853e-01*S71+9.138587e-01*S72+1.764830e+00*S73+5.858698e-01*S74+3.809941e-01*S75+8.266420e-01*S76+1.363769e+00*S77+9.667743e-01*S78+1.689110e+00*S79'
.param V6='V6_part8+1.186080e+00*S80+2.286463e+00*S81+1.888820e+00*S82+1.827310e+00*S83+3.197266e+00*S84+2.182214e+00*S85+2.301136e+00*S86+6.183036e+00*S87+2.786612e+00*S88+1.602791e+00*S89'
.param V7_part1='9.817998e+01*S0+1.881388e-02*S1+2.168762e-02*S2+2.070412e+01*S3+4.426246e+00*S4+3.270782e-02*S5+2.761787e+02*S6+3.536433e-02*S7+4.030585e-02*S8+4.719565e-02*S9'
.param V7_part2='V7_part1+1.788547e+01*S10+4.894645e-02*S11+7.452204e+01*S12+4.515455e+00*S13+2.645209e+01*S14+5.439020e-02*S15+1.239518e-01*S16+(-1.201879e-01)*S17+8.154540e-02*S18+1.926516e-01*S19'
.param V7_part3='V7_part2+2.044566e-02*S20+1.098820e-01*S21+4.680164e-01*S22+1.917224e-01*S23+2.502119e-01*S24+1.032895e-01*S25+9.683773e-02*S26+2.718896e-01*S27+1.205204e-01*S28+1.185247e-01*S29'
.param V7_part4='V7_part3+1.825496e-01*S30+5.859911e-02*S31+(-2.239065e-01)*S32+1.605808e-01*S33+9.262954e-02*S34+(-1.717242e-02)*S35+2.113136e-01*S36+1.146674e-01*S37+1.101652e-01*S38+2.928190e-01*S39'
.param V7_part5='V7_part4+4.245092e-01*S40+1.086880e-01*S41+4.362799e-01*S42+5.338389e-01*S43+1.444185e-01*S44+2.970788e-01*S45+4.602062e-03*S46+(-8.316179e-01)*S47+3.351033e-01*S48+6.554048e-02*S49'
.param V7_part6='V7_part5+(-5.322689e-01)*S50+5.316063e-01*S51+1.690904e-01*S52+(-7.286366e-01)*S53+5.361725e-01*S54+2.556048e-01*S55+(-4.884779e-01)*S56+4.093138e-01*S57+2.600391e-01*S58+(-3.007943e-02)*S59'
.param V7_part7='V7_part6+1.838583e-01*S60+(-7.677577e-02)*S61+(-8.842998e-01)*S62+4.963492e-01*S63+9.874681e-02*S64+(-1.232298e+00)*S65+3.886660e-01*S66+7.002358e-02*S67+(-8.861062e-01)*S68+3.464286e-01*S69'
.param V7_part8='V7_part7+1.225185e-01*S70+(-1.647692e-01)*S71+4.621925e-01*S72+1.394643e-01*S73+(-4.100243e-02)*S74+2.173687e-01*S75+1.605477e-01*S76+(-6.998687e-01)*S77+2.276598e-01*S78+(-1.608871e-01)*S79'
.param V7='V7_part8+(-5.671795e-01)*S80+4.824207e-01*S81+(-1.859029e-01)*S82+(-4.694197e-01)*S83+2.944608e-01*S84+(-2.474502e-02)*S85+(-6.458293e-01)*S86+7.292344e-01*S87+(-1.009439e-02)*S88+(-5.549538e-02)*S89'
.param V8_part1='2.550971e+02*S0+1.738916e-02*S1+1.033092e-02*S2+(-1.256495e+02)*S3+(-1.095414e+01)*S4+9.178323e-03*S5+2.763328e+02*S6+1.511135e-02*S7+9.590919e-03*S8+2.325086e-02*S9'
.param V8_part2='V8_part1+3.963041e+01*S10+8.855532e-03*S11+(-1.331585e+02)*S12+5.064447e+00*S13+7.480777e+00*S14+1.770938e-02*S15+7.860198e-01*S16+6.588611e-01*S17+1.533508e-02*S18+6.897243e-01*S19'
.param V8_part3='V8_part2+6.268067e-01*S20+2.330316e-02*S21+2.979840e-01*S22+5.805839e-01*S23+1.632332e-01*S24+7.254438e-03*S25+3.107349e-03*S26+2.611906e-01*S27+8.020984e-03*S28+2.293644e-03*S29'
.param V8_part4='V8_part3+1.789963e-01*S30+1.452280e-02*S31+3.190254e-01*S32+1.872499e-02*S33+1.724731e-02*S34+3.265142e-01*S35+(-2.424301e-02)*S36+1.408993e-02*S37+2.185670e-03*S38+3.757094e-01*S39'
.param V8_part5='V8_part4+1.505407e-01*S40+3.798666e-01*S41+4.379816e-01*S42+1.877985e-01*S43+4.050809e-01*S44+6.499539e-02*S45+2.982494e-01*S46+4.740521e-01*S47+1.513633e-01*S48+3.866310e-01*S49'
.param V8_part6='V8_part5+4.391885e-01*S50+1.211709e-01*S51+1.030194e-02*S52+6.496444e-01*S53+7.709718e-02*S54+2.095456e-01*S55+5.266813e-01*S56+6.696812e-03*S57+9.731104e-03*S58+6.579236e-01*S59'
.param V8_part7='V8_part6+1.841853e-01*S60+3.400867e-01*S61+4.535160e-01*S62+8.041737e-02*S63+1.694897e-01*S64+3.894749e-01*S65+1.432250e-01*S66+2.058405e-01*S67+6.215588e-01*S68+2.894713e-01*S69'
.param V8_part8='V8_part7+2.899469e-01*S70+4.835581e-01*S71+1.735211e-02*S72+4.390040e-01*S73+6.138883e-01*S74+1.145579e-01*S75+1.827450e-02*S76+2.599209e-01*S77+1.523330e-01*S78+1.269386e-01*S79'
.param V8='V8_part8+3.097821e-01*S80+9.060872e-02*S81+1.426813e-01*S82+1.327494e-01*S83+2.236656e-01*S84+1.830097e-01*S85+1.350146e-01*S86+(-2.396854e-01)*S87+9.081168e-02*S88+3.805078e-01*S89'
.param V9_part1='(-4.196735e+00)*S0+1.280939e-03*S1+8.378202e-04*S2+1.493740e+01*S3+9.421720e+01*S4+7.066363e-04*S5+1.431184e+01*S6+1.206121e-03*S7+7.765108e-04*S8+1.960882e-03*S9'
.param V9_part2='V9_part1+2.310680e+01*S10+7.347395e-04*S11+2.969467e+01*S12+3.918573e-01*S13+(-3.612637e-01)*S14+1.996395e-02*S15+(-5.505755e-03)*S16+(-4.514461e-02)*S17+1.699820e-02*S18+(-3.906048e-02)*S19'
.param V9_part3='V9_part2+(-1.340629e-03)*S20+1.719654e-02*S21+4.641819e-02*S22+(-7.318121e-03)*S23+(-4.926431e-01)*S24+6.366503e-03*S25+5.139750e-03*S26+(-9.031089e-01)*S27+1.103348e-02*S28+5.562507e-03*S29'
.param V9_part4='V9_part3+(-2.964828e-01)*S30+2.015430e-02*S31+(-1.771179e-01)*S32+9.183199e-02*S33+3.396583e-03*S34+(-3.553494e-01)*S35+1.174916e-01*S36+1.921115e-02*S37+3.997313e-03*S38+4.559787e-01*S39'
.param V9_part5='V9_part4+(-5.092517e-01)*S40+(-3.967542e-01)*S41+4.510881e-01*S42+(-6.617800e-01)*S43+(-2.709160e-01)*S44+(-9.263693e-01)*S45+(-6.746599e-01)*S46+(-6.759590e-01)*S47+(-5.114194e-01)*S48+(-4.473103e-01)*S49'
.param V9_part6='V9_part5+(-8.087667e-01)*S50+(-8.429034e-01)*S51+5.147609e-02*S52+(-1.801132e-02)*S53+(-1.728128e-01)*S54+(-8.694396e-01)*S55+(-3.547091e-01)*S56+(-2.386454e-01)*S57+5.196655e-02*S58+(-7.822652e-02)*S59'
.param V9_part7='V9_part6+(-2.096896e-01)*S60+4.332811e-02*S61+(-9.891773e-01)*S62+(-4.008330e-01)*S63+1.966049e-01*S64+(-4.998887e-01)*S65+(-1.561604e-01)*S66+1.136555e-02*S67+(-2.756571e-01)*S68+1.534934e-01*S69'
.param V9_part8='V9_part7+3.703070e-02*S70+(-9.286834e-02)*S71+(-3.657700e-01)*S72+2.614897e-01*S73+9.575574e-02*S74+(-5.989103e-01)*S75+1.150272e-01*S76+(-1.262295e+00)*S77+(-5.117293e-01)*S78+(-7.356214e-01)*S79'
.param V9='V9_part8+(-1.103236e+00)*S80+(-6.019742e-01)*S81+(-7.119578e-01)*S82+(-1.058853e+00)*S83+(-3.543598e-01)*S84+(-7.565736e-01)*S85+(-1.293383e+00)*S86+(-1.771531e+00)*S87+(-8.537762e-01)*S88+(-5.269605e-02)*S89'
.param V10_part1='0.000000e+00*S0+5.594843e-03*S1+0.000000e+00*S2+3.127402e+00*S3+0.000000e+00*S4+5.388350e-02*S5+0.000000e+00*S6+0.000000e+00*S7+1.962529e-02*S8+0.000000e+00*S9'
.param V10_part2='V10_part1+0.000000e+00*S10+(-5.974835e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-2.732107e-01)*S18+0.000000e+00*S19'
.param V10_part3='V10_part2+(-1.750769e-02)*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-3.213820e-02)*S24+8.575199e+00*S25+2.605443e+00*S26+(-4.450134e-02)*S27+9.559899e-01*S28+1.439419e-01*S29'
.param V10_part4='V10_part3+6.121749e-02*S30+3.562532e+00*S31+0.000000e+00*S32+3.272482e+02*S33+0.000000e+00*S34+5.258247e-03*S35+(-2.480576e+01)*S36+(-4.425096e-01)*S37+(-5.881328e+00)*S38+1.691680e-02*S39'
.param V10_part5='V10_part4+1.751309e-02*S40+5.448070e-02*S41+3.665026e-02*S42+0.000000e+00*S43+2.350335e-02*S44+3.359091e-02*S45+0.000000e+00*S46+0.000000e+00*S47+3.097614e-02*S48+8.058908e-03*S49'
.param V10_part6='V10_part5+5.447695e-03*S50+7.434242e-02*S51+1.056446e+01*S52+(-6.972012e-03)*S53+0.000000e+00*S54+1.328701e-02*S55+0.000000e+00*S56+0.000000e+00*S57+(-1.295433e+01)*S58+0.000000e+00*S59'
.param V10_part7='V10_part6+0.000000e+00*S60+(-9.556007e-02)*S61+(-2.669717e-02)*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+7.296302e-02*S66+0.000000e+00*S67+0.000000e+00*S68+6.168799e-02*S69'
.param V10_part8='V10_part7+(-7.398490e-04)*S70+0.000000e+00*S71+3.514305e-02*S72+(-2.898736e-02)*S73+0.000000e+00*S74+3.447019e-02*S75+0.000000e+00*S76+0.000000e+00*S77+3.274788e-02*S78+2.295932e-02*S79'
.param V10='V10_part8+1.906368e-02*S80+9.598962e-02*S81+8.358973e-02*S82+2.123860e-01*S83+9.815986e-02*S84+1.167507e-01*S85+1.712977e-01*S86+1.622201e-01*S87+1.170658e-01*S88+0.000000e+00*S89'
.param V11_part1='0.000000e+00*S0+1.097651e-01*S1+0.000000e+00*S2+(-1.222124e+00)*S3+0.000000e+00*S4+2.040932e-02*S5+0.000000e+00*S6+0.000000e+00*S7+3.279024e-02*S8+0.000000e+00*S9'
.param V11_part2='V11_part1+0.000000e+00*S10+9.159422e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.407112e-01*S18+0.000000e+00*S19'
.param V11_part3='V11_part2+2.466984e-02*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+8.684592e-02*S24+(-3.830044e+00)*S25+1.903628e+00*S26+1.120570e-01*S27+7.217992e-01*S28+2.234862e+00*S29'
.param V11_part4='V11_part3+8.871137e-02*S30+(-1.188528e+01)*S31+0.000000e+00*S32+8.102693e+00*S33+0.000000e+00*S34+1.092812e-01*S35+7.164589e-01*S36+1.181788e+00*S37+(-3.561374e+00)*S38+2.059980e-01*S39'
.param V11_part5='V11_part4+3.837588e-03*S40+9.796985e-02*S41+1.957481e-01*S42+0.000000e+00*S43+1.741632e-01*S44+8.338933e-02*S45+0.000000e+00*S46+0.000000e+00*S47+1.104737e-01*S48+(-3.924931e-02)*S49'
.param V11_part6='V11_part5+2.216656e-02*S50+8.801309e-02*S51+(-4.073306e+01)*S52+8.366830e-02*S53+0.000000e+00*S54+8.110730e-02*S55+0.000000e+00*S56+0.000000e+00*S57+1.971712e+00*S58+0.000000e+00*S59'
.param V11_part7='V11_part6+0.000000e+00*S60+2.472169e-01*S61+1.236075e-01*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+2.106688e-01*S66+0.000000e+00*S67+0.000000e+00*S68+2.424115e-01*S69'
.param V11_part8='V11_part7+1.249283e-02*S70+0.000000e+00*S71+9.260383e-02*S72+2.534404e-01*S73+0.000000e+00*S74+1.475997e-01*S75+0.000000e+00*S76+0.000000e+00*S77+1.289964e-01*S78+1.323429e-01*S79'
.param V11='V11_part8+1.082734e-01*S80+9.114871e-02*S81+1.865610e-02*S82+(-1.464045e-01)*S83+3.415573e-02*S84+2.512909e-02*S85+1.534721e-02*S86+3.542945e-03*S87+1.442199e-02*S88+0.000000e+00*S89'
.param V12_part1='0.000000e+00*S0+(-1.611842e-02)*S1+0.000000e+00*S2+(-2.851205e+00)*S3+0.000000e+00*S4+(-3.385519e-02)*S5+0.000000e+00*S6+0.000000e+00*S7+(-1.913289e-02)*S8+0.000000e+00*S9'
.param V12_part2='V12_part1+0.000000e+00*S10+1.575735e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+5.518478e+00*S18+0.000000e+00*S19'
.param V12_part3='V12_part2+6.607621e-03*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.472141e-02*S24+1.009085e+01*S25+8.589418e+00*S26+(-2.006633e-03)*S27+1.013727e+01*S28+9.266316e+00*S29'
.param V12_part4='V12_part3+(-2.600060e-02)*S30+1.843145e+01*S31+0.000000e+00*S32+1.000000e+04*S33+0.000000e+00*S34+5.100436e-04*S35+9.448197e+01*S36+7.137108e+00*S37+1.870966e+01*S38+(-1.300399e-01)*S39'
.param V12_part5='V12_part4+1.940453e-02*S40+2.660767e-02*S41+(-2.234061e-01)*S42+0.000000e+00*S43+2.950360e-02*S44+(-3.505391e-02)*S45+0.000000e+00*S46+0.000000e+00*S47+(-7.836300e-02)*S48+(-3.113960e-03)*S49'
.param V12_part6='V12_part5+(-2.054193e-02)*S50+(-1.365978e-01)*S51+5.171870e+01*S52+2.037566e-02*S53+0.000000e+00*S54+1.757273e-02*S55+0.000000e+00*S56+0.000000e+00*S57+3.007642e+01*S58+0.000000e+00*S59'
.param V12_part7='V12_part6+0.000000e+00*S60+9.631200e-02*S61+7.572427e-02*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-1.740114e-01)*S66+0.000000e+00*S67+0.000000e+00*S68+(-1.040756e-01)*S69'
.param V12_part8='V12_part7+5.540231e-02*S70+0.000000e+00*S71+(-1.140247e-01)*S72+2.134886e-02*S73+0.000000e+00*S74+6.676853e-02*S75+0.000000e+00*S76+0.000000e+00*S77+2.902641e-02*S78+4.926172e-02*S79'
.param V12='V12_part8+1.928520e-02*S80+(-7.990647e-02)*S81+5.063465e-02*S82+(-1.608730e-02)*S83+(-8.917168e-02)*S84+3.445683e-02*S85+(-1.622752e-01)*S86+(-2.001674e-01)*S87+6.275556e-02*S88+0.000000e+00*S89'
.param V13_part1='0.000000e+00*S0+4.645933e-02*S1+0.000000e+00*S2+5.877522e-02*S3+0.000000e+00*S4+1.601755e-02*S5+0.000000e+00*S6+0.000000e+00*S7+3.175879e-02*S8+0.000000e+00*S9'
.param V13_part2='V13_part1+0.000000e+00*S10+8.664462e-05*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+7.027010e-01*S18+0.000000e+00*S19'
.param V13_part3='V13_part2+7.292569e-03*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.223579e-02*S24+2.241358e+01*S25+1.833849e+01*S26+4.029598e-04*S27+2.076684e+01*S28+1.820975e+01*S29'
.param V13_part4='V13_part3+3.521233e-02*S30+2.065483e+01*S31+0.000000e+00*S32+2.876040e+01*S33+0.000000e+00*S34+5.766747e-02*S35+1.279899e+00*S36+8.020489e+00*S37+2.047350e+01*S38+4.335179e-02*S39'
.param V13_part5='V13_part4+(-3.591131e-02)*S40+4.059527e-02*S41+3.799438e-02*S42+0.000000e+00*S43+4.539544e-02*S44+(-4.511371e-03)*S45+0.000000e+00*S46+0.000000e+00*S47+4.575569e-05*S48+2.224573e-03*S49'
.param V13_part6='V13_part5+(-2.289009e-03)*S50+2.658097e-05*S51+4.526280e+01*S52+1.896498e-03*S53+0.000000e+00*S54+(-1.943027e-03)*S55+0.000000e+00*S56+0.000000e+00*S57+8.746593e+00*S58+0.000000e+00*S59'
.param V13_part7='V13_part6+0.000000e+00*S60+(-3.543764e-03)*S61+(-5.322341e-02)*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+4.803338e-02*S66+0.000000e+00*S67+0.000000e+00*S68+4.749627e-02*S69'
.param V13_part8='V13_part7+(-2.632485e-02)*S70+0.000000e+00*S71+(-5.272851e-03)*S72+4.720834e-02*S73+0.000000e+00*S74+1.470585e-03*S75+0.000000e+00*S76+0.000000e+00*S77+2.858400e-03*S78+6.306261e-03*S79'
.param V13='V13_part8+2.619358e-03*S80+3.024261e-03*S81+6.190791e-03*S82+3.493628e-03*S83+8.406901e-03*S84+3.859204e-03*S85+3.863807e-03*S86+(-5.617598e-02)*S87+4.879665e-03*S88+0.000000e+00*S89'
.param V14_part1='0.000000e+00*S0+(-5.766352e-04)*S1+0.000000e+00*S2+3.586210e-01*S3+0.000000e+00*S4+(-3.277954e-04)*S5+0.000000e+00*S6+0.000000e+00*S7+(-5.819686e-04)*S8+0.000000e+00*S9'
.param V14_part2='V14_part1+0.000000e+00*S10+1.363777e-03*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+6.243594e-02*S18+0.000000e+00*S19'
.param V14_part3='V14_part2+1.552631e-02*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.156339e-02*S24+(-4.526805e-01)*S25+(-1.349428e+00)*S26+1.088225e-02*S27+2.479493e-02*S28+(-6.305632e-01)*S29'
.param V14_part4='V14_part3+(-1.845660e-03)*S30+8.638055e-01*S31+0.000000e+00*S32+3.164609e+01*S33+0.000000e+00*S34+(-5.123420e-03)*S35+3.178077e+01*S36+(-1.297991e-02)*S37+3.905825e+00*S38+2.473493e-02*S39'
.param V14_part5='V14_part4+5.818110e-03*S40+(-4.018973e-03)*S41+2.383248e-02*S42+0.000000e+00*S43+2.309473e-03*S44+1.084309e-02*S45+0.000000e+00*S46+0.000000e+00*S47+1.659552e-02*S48+1.302165e-03*S49'
.param V14_part6='V14_part5+3.690251e-03*S50+5.851213e-03*S51+1.626625e+01*S52+3.354231e-02*S53+0.000000e+00*S54+4.614481e-03*S55+0.000000e+00*S56+0.000000e+00*S57+5.008796e+00*S58+0.000000e+00*S59'
.param V14_part7='V14_part6+0.000000e+00*S60+5.117344e-02*S61+2.097884e-02*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-8.841729e-03)*S66+0.000000e+00*S67+0.000000e+00*S68+3.113777e-02*S69'
.param V14_part8='V14_part7+6.185218e-03*S70+0.000000e+00*S71+(-9.874542e-03)*S72+7.170880e-02*S73+0.000000e+00*S74+2.764831e-02*S75+0.000000e+00*S76+0.000000e+00*S77+3.759243e-02*S78+1.186285e-02*S79'
.param V14='V14_part8+2.143692e-03*S80+3.195980e-02*S81+5.440744e-03*S82+(-1.720331e-02)*S83+3.356378e-02*S84+7.745280e-03*S85+(-4.840983e-03)*S86+1.005585e-02*S87+4.281762e-03*S88+0.000000e+00*S89'
.param V15_part1='(-1.698585e-01)*S0+0.000000e+00*S1+(-5.537435e-03)*S2+1.792073e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+(-1.983154e-02)*S7+0.000000e+00*S8+(-1.299689e-02)*S9'
.param V15_part2='V15_part1+0.000000e+00*S10+(-7.004287e-03)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+3.438835e+01*S15+(-2.914307e-02)*S16+0.000000e+00*S17+3.896678e+01*S18+0.000000e+00*S19'
.param V15_part3='V15_part2+0.000000e+00*S20+2.664823e+01*S21+(-2.081745e-02)*S22+(-1.276946e-02)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V15_part4='V15_part3+0.000000e+00*S30+0.000000e+00*S31+4.890372e-02*S32+2.666794e+01*S33+5.726362e+00*S34+9.205872e-02*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V15_part5='V15_part4+7.537122e-03*S40+0.000000e+00*S41+0.000000e+00*S42+1.061093e-03*S43+0.000000e+00*S44+0.000000e+00*S45+5.785601e-02*S46+7.985013e-02*S47+0.000000e+00*S48+4.553285e-02*S49'
.param V15_part6='V15_part5+1.081930e-01*S50+0.000000e+00*S51+0.000000e+00*S52+5.785416e-02*S53+0.000000e+00*S54+0.000000e+00*S55+1.103952e-01*S56+0.000000e+00*S57+0.000000e+00*S58+(-6.316505e-03)*S59'
.param V15_part7='V15_part6+7.225069e-02*S60+1.605305e-01*S61+1.511352e-01*S62+9.499313e-02*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.114419e-01*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V15_part8='V15_part7+3.081299e-02*S70+1.859430e-01*S71+0.000000e+00*S72+0.000000e+00*S73+(-2.078540e-01)*S74+0.000000e+00*S75+8.590752e+01*S76+1.871786e-02*S77+0.000000e+00*S78+5.451596e-02*S79'
.param V15='V15_part8+1.395256e-01*S80+0.000000e+00*S81+1.200164e-02*S82+0.000000e+00*S83+2.737796e-02*S84+(-2.740962e-03)*S85+(-9.048129e-05)*S86+3.528892e-02*S87+(-4.808250e-04)*S88+8.592511e-02*S89'
.param V16_part1='9.954004e+00*S0+0.000000e+00*S1+7.112226e-02*S2+(-9.895774e-01)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+5.292411e-02*S7+0.000000e+00*S8+5.980531e-02*S9'
.param V16_part2='V16_part1+0.000000e+00*S10+4.532906e-03*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-7.110944e+01)*S15+6.349353e-02*S16+0.000000e+00*S17+(-3.691375e+01)*S18+0.000000e+00*S19'
.param V16_part3='V16_part2+0.000000e+00*S20+(-1.794395e+01)*S21+1.506716e-02*S22+(-1.492686e-02)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V16_part4='V16_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.096337e-01)*S32+6.539780e+01*S33+6.853248e-01*S34+9.872077e-03*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V16_part5='V16_part4+1.395054e-01*S40+0.000000e+00*S41+0.000000e+00*S42+1.774434e-01*S43+0.000000e+00*S44+0.000000e+00*S45+6.722265e-02*S46+(-4.717283e-02)*S47+0.000000e+00*S48+8.361529e-02*S49'
.param V16_part6='V16_part5+(-7.895779e-02)*S50+0.000000e+00*S51+0.000000e+00*S52+9.606513e-03*S53+0.000000e+00*S54+0.000000e+00*S55+(-2.238094e-02)*S56+0.000000e+00*S57+0.000000e+00*S58+1.046629e-01*S59'
.param V16_part7='V16_part6+2.147408e-01*S60+(-4.947249e-02)*S61+(-4.949886e-02)*S62+1.617315e-01*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.989070e-01*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V16_part8='V16_part7+2.279687e-01*S70+2.079759e-01*S71+0.000000e+00*S72+0.000000e+00*S73+1.785130e-01*S74+0.000000e+00*S75+(-2.011944e+01)*S76+4.730034e-03*S77+0.000000e+00*S78+(-6.237673e-02)*S79'
.param V16='V16_part8+(-2.155305e-01)*S80+0.000000e+00*S81+2.274437e-02*S82+0.000000e+00*S83+1.974531e-02*S84+(-5.965059e-03)*S85+(-1.097847e-02)*S86+9.392474e-03*S87+(-7.930486e-03)*S88+1.797038e-01*S89'
.param V17_part1='(-1.124598e-01)*S0+0.000000e+00*S1+6.759229e-03*S2+1.265342e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+7.128812e-03*S7+0.000000e+00*S8+1.499881e-03*S9'
.param V17_part2='V17_part1+0.000000e+00*S10+(-9.734483e-04)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+1.782515e+00*S15+(-9.042914e-04)*S16+0.000000e+00*S17+(-1.248412e+00)*S18+0.000000e+00*S19'
.param V17_part3='V17_part2+0.000000e+00*S20+1.330034e+00*S21+3.829636e-03*S22+1.521280e-03*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V17_part4='V17_part3+0.000000e+00*S30+0.000000e+00*S31+2.514171e-02*S32+(-6.924469e+02)*S33+(-7.258241e-01)*S34+(-2.799819e-02)*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V17_part5='V17_part4+1.280620e-02*S40+0.000000e+00*S41+0.000000e+00*S42+1.377696e-02*S43+0.000000e+00*S44+0.000000e+00*S45+(-1.091739e-02)*S46+(-1.539249e-02)*S47+0.000000e+00*S48+(-8.334393e-03)*S49'
.param V17_part6='V17_part5+(-8.212194e-03)*S50+0.000000e+00*S51+0.000000e+00*S52+(-4.595774e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+(-1.928606e-02)*S56+0.000000e+00*S57+0.000000e+00*S58+(-6.310754e-03)*S59'
.param V17_part7='V17_part6+8.906065e-05*S60+(-6.901199e-03)*S61+(-1.428564e-02)*S62+5.488047e-03*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+(-1.499366e-02)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V17_part8='V17_part7+1.352558e-03*S70+(-6.328515e-02)*S71+0.000000e+00*S72+0.000000e+00*S73+3.294608e-02*S74+0.000000e+00*S75+(-1.784526e+01)*S76+1.977475e-03*S77+0.000000e+00*S78+(-2.774139e-03)*S79'
.param V17='V17_part8+(-6.774922e-05)*S80+0.000000e+00*S81+(-3.189370e-04)*S82+0.000000e+00*S83+(-5.922467e-04)*S84+9.404427e-04*S85+4.236442e-03*S86+1.174431e-02*S87+1.207033e-03*S88+(-1.080004e-02)*S89'
.param V18_part1='4.138039e-01*S0+0.000000e+00*S1+3.382898e-02*S2+(-1.103292e+00)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+4.558756e-02*S7+0.000000e+00*S8+4.261020e-02*S9'
.param V18_part2='V18_part1+0.000000e+00*S10+2.150487e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.031226e+01*S15+1.244757e-02*S16+0.000000e+00*S17+4.435422e+01*S18+0.000000e+00*S19'
.param V18_part3='V18_part2+0.000000e+00*S20+4.945799e+01*S21+3.059876e-03*S22+3.583885e-03*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V18_part4='V18_part3+0.000000e+00*S30+0.000000e+00*S31+2.745118e-02*S32+(-5.917218e+02)*S33+1.910614e+01*S34+(-1.644520e-02)*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V18_part5='V18_part4+6.139572e-02*S40+0.000000e+00*S41+0.000000e+00*S42+2.809048e-02*S43+0.000000e+00*S44+0.000000e+00*S45+5.963432e-03*S46+3.031009e-03*S47+0.000000e+00*S48+5.326620e-03*S49'
.param V18_part6='V18_part5+6.149204e-04*S50+0.000000e+00*S51+0.000000e+00*S52+8.840431e-03*S53+0.000000e+00*S54+0.000000e+00*S55+3.500473e-03*S56+0.000000e+00*S57+0.000000e+00*S58+1.261740e-02*S59'
.param V18_part7='V18_part6+4.341404e-02*S60+4.928758e-02*S61+9.388318e-02*S62+3.697304e-02*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+3.482584e-02*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V18_part8='V18_part7+6.344571e-02*S70+4.998617e-02*S71+0.000000e+00*S72+0.000000e+00*S73+9.713444e-03*S74+0.000000e+00*S75+6.262253e+01*S76+(-1.832912e-04)*S77+0.000000e+00*S78+(-1.711666e-03)*S79'
.param V18='V18_part8+1.839910e-03*S80+0.000000e+00*S81+(-2.216932e-03)*S82+0.000000e+00*S83+(-2.914139e-03)*S84+(-4.709853e-03)*S85+5.547316e-03*S86+2.296775e-03*S87+(-9.012522e-03)*S88+1.231264e-02*S89'
.param V19_part1='2.870028e-02*S0+0.000000e+00*S1+7.087616e-06*S2+(-3.313686e-01)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+(-1.729342e-03)*S7+0.000000e+00*S8+(-4.069335e-04)*S9'
.param V19_part2='V19_part1+0.000000e+00*S10+2.956269e-05*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-8.330844e-03)*S15+1.916879e-02*S16+0.000000e+00*S17+8.155472e-03*S18+0.000000e+00*S19'
.param V19_part3='V19_part2+0.000000e+00*S20+(-1.314792e+00)*S21+2.272180e-02*S22+1.990406e-02*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V19_part4='V19_part3+0.000000e+00*S30+0.000000e+00*S31+6.155206e-03*S32+1.000000e+04*S33+2.255980e+00*S34+4.079398e-03*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V19_part5='V19_part4+(-1.855604e-02)*S40+0.000000e+00*S41+0.000000e+00*S42+(-2.289006e-02)*S43+0.000000e+00*S44+0.000000e+00*S45+6.177656e-03*S46+1.308958e-02*S47+0.000000e+00*S48+1.305224e-02*S49'
.param V19_part6='V19_part5+4.739290e-03*S50+0.000000e+00*S51+0.000000e+00*S52+(-6.090420e-05)*S53+0.000000e+00*S54+0.000000e+00*S55+2.779007e-02*S56+0.000000e+00*S57+0.000000e+00*S58+4.944651e-02*S59'
.param V19_part7='V19_part6+1.251352e-02*S60+(-2.509973e-02)*S61+(-1.908629e-02)*S62+(-2.074832e-02)*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.723154e-02*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V19_part8='V19_part7+9.150661e-03*S70+3.695552e-02*S71+0.000000e+00*S72+0.000000e+00*S73+3.969272e-02*S74+0.000000e+00*S75+4.262044e+00*S76+3.109664e-02*S77+0.000000e+00*S78+2.961392e-03*S79'
.param V19='V19_part8+1.910110e-03*S80+0.000000e+00*S81+7.336727e-04*S82+0.000000e+00*S83+4.138386e-03*S84+(-2.948733e-04)*S85+(-1.144296e-03)*S86+8.182346e-03*S87+(-5.944436e-04)*S88+6.845700e-02*S89'
.param V20_part1='1.645462e-02*S0+8.158776e-01*S1+3.922911e+00*S2+(-3.709360e-03)*S3+1.869097e-02*S4+4.849296e-01*S5+2.481079e-02*S6+2.052511e+02*S7+1.824565e+02*S8+1.175930e+02*S9'
.param V20_part2='V20_part1+5.772223e-02*S10+(-1.462019e-01)*S11+9.100110e-02*S12+(-4.950646e-03)*S13+1.066704e-02*S14+2.485534e-02*S15+2.950256e-01*S16+2.486694e-01*S17+1.566505e-02*S18+1.917486e-01*S19'
.param V20_part3='V20_part2+2.200916e-01*S20+(-3.221978e-01)*S21+(-8.685073e-01)*S22+1.149243e-01*S23+(-1.756417e+02)*S24+(-1.268549e-01)*S25+1.164830e-01*S26+(-3.914041e+02)*S27+8.683197e-02*S28+1.228946e-01*S29'
.param V20_part4='V20_part3+(-3.908805e-02)*S30+(-4.772009e-01)*S31+3.266897e+00*S32+(-8.122781e-02)*S33+1.329605e-01*S34+5.962172e-01*S35+6.074204e-02*S36+2.010090e-01*S37+5.103691e-02*S38+(-4.998673e+03)*S39'
.param V20_part5='V20_part4+2.677861e+00*S40+(-9.109793e-02)*S41+(-5.013178e+03)*S42+1.477781e+00*S43+(-1.810088e-01)*S44+1.529569e-01*S45+2.611169e+00*S46+1.236572e+02*S47+7.587229e+00*S48+5.010539e+00*S49'
.param V20_part6='V20_part5+7.870526e+01*S50+8.142675e+00*S51+(-6.228193e+00)*S52+1.449467e+00*S53+1.121464e+03*S54+5.281414e+00*S55+4.074382e+00*S56+1.526239e+01*S57+5.589789e-01*S58+(-3.218479e-01)*S59'
.param V20_part7='V20_part6+1.000000e+04*S60+3.283183e+00*S61+3.795481e+00*S62+3.179119e+02*S63+(-4.887935e+03)*S64+1.169825e+00*S65+2.303220e+02*S66+1.000000e+04*S67+(-1.859968e-01)*S68+1.000000e+04*S69'
.param V20_part8='V20_part7+1.000000e+04*S70+2.529173e+00*S71+9.513020e+00*S72+(-5.080741e+03)*S73+1.530201e-01*S74+1.194572e+02*S75+2.678361e-01*S76+3.723009e+00*S77+6.000402e+01*S78+1.001468e+01*S79'
.param V20='V20_part8+5.029714e+00*S80+2.692715e+01*S81+1.364068e+01*S82+6.925054e+00*S83+2.692347e+01*S84+1.436133e+01*S85+1.461823e+01*S86+1.297647e+01*S87+1.488963e+01*S88+1.800680e+00*S89'
.param V21_part1='1.494008e-01*S0+(-1.188029e+00)*S1+(-9.017778e-02)*S2+1.513292e-01*S3+1.496639e-01*S4+2.415737e+00*S5+1.920268e-01*S6+9.599395e+00*S7+(-4.614449e+01)*S8+9.825521e+01*S9'
.param V21_part2='V21_part1+1.233727e-01*S10+1.012122e+00*S11+1.265425e-01*S12+1.522443e-01*S13+1.120252e-01*S14+7.282559e-01*S15+3.731587e-01*S16+2.571167e-01*S17+7.108918e-01*S18+5.442181e-01*S19'
.param V21_part3='V21_part2+3.623069e-01*S20+3.655000e+00*S21+3.238976e+00*S22+4.820954e-01*S23+3.128743e+02*S24+8.749660e-01*S25+7.574762e-01*S26+5.429296e+02*S27+7.211255e-01*S28+7.232454e-01*S29'
.param V21_part4='V21_part3+2.643837e+00*S30+5.110462e+00*S31+2.692414e+00*S32+1.244642e+00*S33+1.242923e+00*S34+5.878617e-01*S35+1.115020e+00*S36+1.084134e+00*S37+1.265107e+00*S38+(-4.349816e+00)*S39'
.param V21_part5='V21_part4+6.776381e-01*S40+1.888106e+00*S41+8.776809e+00*S42+1.209058e+00*S43+1.671970e+00*S44+1.135561e+01*S45+2.568944e-01*S46+1.336047e+02*S47+(-4.492591e+00)*S48+(-8.689929e-01)*S49'
.param V21_part6='V21_part5+4.767329e+01*S50+(-4.524384e+00)*S51+3.825676e+01*S52+1.267296e+00*S53+5.110567e+01*S54+(-9.859524e-03)*S55+6.920047e+00*S56+1.239258e+01*S57+2.049916e+00*S58+3.149931e+00*S59'
.param V21_part7='V21_part6+1.979284e+02*S60+3.791947e+00*S61+(-9.871254e-01)*S62+2.556848e+01*S63+(-7.624793e+01)*S64+2.346284e+00*S65+8.984149e+01*S66+1.452365e+02*S67+4.908774e+00*S68+2.496785e+02*S69'
.param V21_part8='V21_part7+1.374113e+02*S70+2.835300e+00*S71+2.223467e+01*S72+1.190702e+02*S73+5.105202e+00*S74+(-6.178174e-02)*S75+3.386124e+00*S76+8.689411e-01*S77+(-4.173444e+00)*S78+4.396390e-01*S79'
.param V21='V21_part8+9.822965e-02*S80+(-1.402320e+01)*S81+(-3.581624e-01)*S82+(-5.677518e-01)*S83+(-4.991458e+00)*S84+(-7.207071e-01)*S85+(-3.136711e+00)*S86+(-1.099676e+00)*S87+(-3.755165e-01)*S88+5.789377e+00*S89'
.param V22_part1='(-3.594915e-02)*S0+3.626637e+00*S1+1.075145e+00*S2+(-1.705023e-02)*S3+(-1.964935e-02)*S4+2.052524e-01*S5+(-7.433748e-02)*S6+(-3.633974e+01)*S7+(-5.987626e-01)*S8+1.974500e+02*S9'
.param V22_part2='V22_part1+(-5.866978e-02)*S10+1.080097e-02*S11+(-1.381042e-01)*S12+(-2.790703e-02)*S13+(-1.373595e-02)*S14+4.330238e-02*S15+(-1.107424e-01)*S16+(-2.731460e-02)*S17+2.385716e-02*S18+(-1.070480e-01)*S19'
.param V22_part3='V22_part2+(-4.566934e-02)*S20+7.364072e-01*S21+9.809010e-01*S22+(-1.042475e-02)*S23+5.672463e+01*S24+7.920596e-02*S25+9.160914e-02*S26+1.286590e+02*S27+(-4.867671e-02)*S28+7.340142e-02*S29'
.param V22_part4='V22_part3+4.393417e-01*S30+8.982521e-01*S31+(-5.230993e-01)*S32+1.097370e-01*S33+2.532286e-01*S34+2.485787e-01*S35+(-2.789159e-01)*S36+1.482426e-01*S37+2.096086e-01*S38+1.998289e+02*S39'
.param V22_part5='V22_part4+(-1.108128e-01)*S40+1.978920e-01*S41+2.274314e+02*S42+(-2.473620e-01)*S43+1.624033e-01*S44+3.275745e+00*S45+2.714729e-01*S46+5.455769e+00*S47+(-3.483749e-01)*S48+(-3.990412e-01)*S49'
.param V22_part6='V22_part5+(-2.307986e+01)*S50+(-4.575389e-01)*S51+4.035677e+00*S52+6.028109e-01*S53+3.141370e+01*S54+(-5.582488e-02)*S55+1.305898e-01*S56+1.816579e-01*S57+2.188224e-01*S58+5.898705e-01*S59'
.param V22_part7='V22_part6+1.283442e+02*S60+1.244778e+00*S61+1.417043e+00*S62+1.681612e+01*S63+(-4.947597e+01)*S64+1.151945e+00*S65+3.486446e+01*S66+1.490807e+02*S67+1.476796e+00*S68+1.592421e+02*S69'
.param V22_part8='V22_part7+1.229673e+02*S70+1.495900e+00*S71+1.720673e+00*S72+3.275871e+01*S73+1.492866e+00*S74+(-7.152677e+00)*S75+1.680372e+00*S76+3.215853e+00*S77+2.771957e-01*S78+8.338978e-01*S79'
.param V22='V22_part8+2.914372e+00*S80+(-5.631845e-01)*S81+(-8.916355e-02)*S82+2.912525e+00*S83+8.709649e-01*S84+(-2.500379e-01)*S85+(-5.403492e-04)*S86+1.627222e+00*S87+(-3.374654e-01)*S88+2.952978e+00*S89'
.param V23_part1='1.659941e-02*S0+(-7.132895e-02)*S1+1.683404e+00*S2+1.085089e-02*S3+1.255428e-02*S4+5.294478e-01*S5+1.521759e-02*S6+(-1.453084e+02)*S7+(-3.108850e+01)*S8+1.309644e+01*S9'
.param V23_part2='V23_part1+8.730479e-03*S10+1.005991e-01*S11+8.968533e-03*S12+1.306787e-02*S13+1.190826e-02*S14+7.459581e-02*S15+(-2.613581e-02)*S16+(-7.649550e-03)*S17+8.833338e-02*S18+(-2.809807e-02)*S19'
.param V23_part3='V23_part2+(-1.003338e-02)*S20+2.877709e-01*S21+(-1.265679e-01)*S22+(-1.228683e-02)*S23+3.229695e+00*S24+9.885973e-02*S25+1.484407e-01*S26+3.996967e+00*S27+1.068801e-01*S28+1.614848e-01*S29'
.param V23_part4='V23_part3+(-2.989207e-02)*S30+1.027022e-01*S31+(-4.157417e-01)*S32+(-7.098817e-04)*S33+4.936095e-02*S34+1.808404e-02*S35+(-1.970577e-02)*S36+6.401421e-02*S37+1.225951e-01*S38+(-4.138932e+00)*S39'
.param V23_part5='V23_part4+(-7.000890e-02)*S40+(-1.052443e-01)*S41+(-2.172383e+00)*S42+(-1.418705e-01)*S43+(-9.757780e-02)*S44+6.503199e-02*S45+8.274837e-04*S46+(-2.965867e+01)*S47+(-6.918791e-03)*S48+(-4.618349e-02)*S49'
.param V23_part6='V23_part5+(-1.662962e+01)*S50+7.943801e-03*S51+(-1.429260e-04)*S52+(-1.387254e-01)*S53+1.962633e+00*S54+(-1.484511e-01)*S55+(-1.672317e+00)*S56+(-4.207156e-01)*S57+2.144935e-01*S58+(-2.457082e-01)*S59'
.param V23_part7='V23_part6+3.330279e+00*S60+(-4.366349e-01)*S61+(-1.720968e-01)*S62+(-4.864302e-01)*S63+(-7.767034e-02)*S64+(-8.308811e-02)*S65+8.850311e-01*S66+8.047650e-02*S67+(-2.594202e-01)*S68+3.950543e-01*S69'
.param V23_part8='V23_part7+3.680478e-01*S70+(-3.826575e-01)*S71+(-7.270582e-01)*S72+(-6.882929e+00)*S73+(-5.214321e-01)*S74+8.888709e-01*S75+1.708493e-01*S76+(-7.604483e-02)*S77+1.455362e+00*S78+1.850057e-01*S79'
.param V23='V23_part8+(-4.764139e-02)*S80+2.003785e-01*S81+3.690288e-01*S82+(-1.882788e-01)*S83+2.024583e-01*S84+7.809228e-02*S85+1.643498e-01*S86+(-2.122656e-01)*S87+2.299327e-01*S88+(-4.922917e-01)*S89'
.param V24_part1='2.823782e-03*S0+4.836530e-02*S1+(-2.706017e-02)*S2+2.889128e-03*S3+2.253606e-03*S4+4.882032e-02*S5+2.965002e-03*S6+6.337735e+00*S7+3.560529e-01*S8+4.250425e+00*S9'
.param V24_part2='V24_part1+1.743410e-03*S10+1.100287e-02*S11+1.812759e-03*S12+2.349795e-03*S13+1.686166e-03*S14+8.052190e-03*S15+(-4.693621e-03)*S16+(-2.034096e-03)*S17+7.680887e-04*S18+1.112528e-02*S19'
.param V24_part3='V24_part2+(-5.564101e-03)*S20+2.332729e-01*S21+2.416579e-01*S22+2.037898e-03*S23+1.758488e+01*S24+(-1.033397e-02)*S25+(-1.228485e-02)*S26+4.346131e+01*S27+(-2.703629e-02)*S28+(-3.045772e-02)*S29'
.param V24_part4='V24_part3+6.158294e-02*S30+1.793553e-01*S31+2.707487e-01*S32+9.987259e-02*S33+7.580164e-02*S34+(-1.747308e-02)*S35+1.946591e-01*S36+2.657990e-03*S37+6.071171e-02*S38+1.000000e+04*S39'
.param V24_part5='V24_part4+(-3.350288e-01)*S40+2.383308e-02*S41+1.000000e+04*S42+(-9.766170e-02)*S43+6.164592e-03*S44+4.946261e-01*S45+(-4.972865e-01)*S46+(-6.974510e+00)*S47+(-8.931530e-01)*S48+(-7.345275e-01)*S49'
.param V24_part6='V24_part5+(-2.623740e+00)*S50+(-6.237534e-01)*S51+3.187998e+00*S52+(-9.888800e-02)*S53+(-7.261326e+02)*S54+(-4.516331e-01)*S55+2.563882e-01*S56+(-1.012394e+01)*S57+4.837111e-02*S58+(-4.084623e-02)*S59'
.param V24_part7='V24_part6+(-6.686012e+03)*S60+(-3.000907e-01)*S61+(-9.165513e-02)*S62+(-2.129036e+02)*S63+1.000000e+04*S64+1.168063e-02*S65+(-1.719671e+02)*S66+(-6.737354e+03)*S67+(-9.686513e-03)*S68+(-6.758768e+03)*S69'
.param V24_part8='V24_part7+(-6.744453e+03)*S70+(-1.496889e-01)*S71+(-1.112571e+01)*S72+1.000000e+04*S73+(-1.094956e-01)*S74+(-3.972893e+01)*S75+1.342748e-01*S76+(-3.497470e-01)*S77+(-2.010662e+01)*S78+(-1.588503e+00)*S79'
.param V24='V24_part8+(-4.123613e-01)*S80+(-2.729806e+00)*S81+(-2.389391e+00)*S82+(-6.639697e-01)*S83+(-5.359409e+00)*S84+(-2.350971e+00)*S85+(-1.070900e+00)*S86+(-2.117102e+00)*S87+(-2.403794e+00)*S88+(-3.416580e-01)*S89'
.param V25_part1='(-4.192701e-02)*S0+1.930604e+02*S1+1.757977e+02*S2+(-7.418386e-02)*S3+(-3.509998e-02)*S4+2.817095e+01*S5+(-1.037919e-01)*S6+6.035347e+03*S7+5.587433e+03*S8+7.564131e+03*S9'
.param V25_part2='V25_part1+(-7.299484e-02)*S10+(-1.108526e+01)*S11+(-1.579602e-01)*S12+(-8.600003e-02)*S13+(-4.261214e-02)*S14+5.120563e-01*S15+1.253849e-02*S16+4.559037e-02*S17+3.011969e-01*S18+(-2.607620e-02)*S19'
.param V25_part3='V25_part2+2.573299e-02*S20+8.292609e-02*S21+(-7.608060e-02)*S22+9.473476e-03*S23+(-3.137058e-01)*S24+1.238919e+00*S25+2.011035e+00*S26+(-4.035798e-01)*S27+1.293533e+00*S28+1.967887e+00*S29'
.param V25_part4='V25_part3+(-7.256366e-02)*S30+2.077831e+00*S31+1.455665e-01*S32+5.559978e-01*S33+2.466371e+00*S34+1.311033e-01*S35+1.046758e-01*S36+2.888123e+00*S37+2.832721e+00*S38+(-3.678645e-01)*S39'
.param V25_part5='V25_part4+(-1.308208e-01)*S40+5.157448e-02*S41+(-5.285798e-01)*S42+(-2.041791e-01)*S43+(-2.198143e-02)*S44+(-5.159724e-02)*S45+1.538385e-01*S46+2.507140e-01*S47+(-2.974776e-01)*S48+5.069531e-02*S49'
.param V25_part6='V25_part5+2.385907e-01*S50+(-4.278145e-01)*S51+2.829294e+00*S52+1.817614e-01*S53+(-1.070356e+00)*S54+(-2.504420e-01)*S55+1.876220e-01*S56+(-3.251713e+00)*S57+3.632976e+00*S58+3.282658e-02*S59'
.param V25_part7='V25_part6+(-2.237020e-01)*S60+2.043794e-01*S61+4.028317e-01*S62+(-6.503451e-01)*S63+3.832450e-02*S64+3.756900e-01*S65+(-4.311742e-01)*S66+(-2.367783e-01)*S67+2.935498e-01*S68+(-1.659179e+00)*S69'
.param V25_part8='V25_part7+(-3.579253e-01)*S70+2.450510e-01*S71+(-4.765685e+00)*S72+(-2.772165e-01)*S73+1.637920e-01*S74+(-4.293107e-01)*S75+4.745526e+00*S76+4.509468e-01*S77+(-1.023490e+00)*S78+3.844541e-02*S79'
.param V25='V25_part8+3.852051e-01*S80+(-1.144877e+00)*S81+(-2.229694e-02)*S82+2.780776e-01*S83+(-6.212469e-01)*S84+(-3.264942e-01)*S85+(-3.787395e-01)*S86+(-1.062768e+00)*S87+(-4.461901e-01)*S88+2.223277e-01*S89'
.param V26_part1='2.109895e-01*S0+(-8.089082e+01)*S1+2.266423e+01*S2+2.042433e-01*S3+1.321906e-01*S4+6.573987e+01*S5+2.003355e-01*S6+7.759967e+02*S7+(-1.230911e+02)*S8+5.964163e+02*S9'
.param V26_part2='V26_part1+1.328405e-01*S10+4.435600e+01*S11+1.920269e-01*S12+1.232626e-01*S13+6.140723e-02*S14+2.900244e+00*S15+2.374285e-01*S16+1.063330e-01*S17+2.219734e+00*S18+2.199435e-01*S19'
.param V26_part3='V26_part2+1.254072e-01*S20+1.975886e+00*S21+2.573538e-01*S22+1.295967e-01*S23+4.680655e-01*S24+3.145879e-01*S25+(-1.187516e-01)*S26+4.632587e-01*S27+(-1.277921e-01)*S28+(-2.612240e-02)*S29'
.param V26_part4='V26_part3+7.902005e-01*S30+4.469878e-01*S31+1.471814e-01*S32+1.982582e+00*S33+8.071484e-01*S34+1.929453e-01*S35+2.384357e+00*S36+(-3.548209e-01)*S37+4.872111e-01*S38+9.152740e-01*S39'
.param V26_part5='V26_part4+4.702715e-01*S40+1.960933e-01*S41+1.011526e+00*S42+4.475532e-01*S43+2.381021e-01*S44+1.016161e+00*S45+5.465610e-01*S46+2.213086e-01*S47+1.057069e+00*S48+6.002644e-01*S49'
.param V26_part6='V26_part5+1.997645e-01*S50+9.463243e-01*S51+1.604568e+00*S52+2.428853e-01*S53+2.009820e+00*S54+6.928850e-01*S55+2.014297e-01*S56+3.904938e+00*S57+1.839427e-01*S58+2.998005e-01*S59'
.param V26_part7='V26_part6+2.044140e+00*S60+7.373717e-01*S61+2.807524e-01*S62+2.602100e+00*S63+1.095197e+00*S64+2.312311e-01*S65+1.483216e+00*S66+1.153439e+00*S67+3.957393e-01*S68+2.322662e+00*S69'
.param V26_part8='V26_part7+1.064625e+00*S70+3.862974e-01*S71+5.648519e+00*S72+9.609237e-01*S73+3.823298e-01*S74+2.211014e+00*S75+6.585417e-01*S76+2.473229e-01*S77+2.218306e+00*S78+9.156747e-01*S79'
.param V26='V26_part8+7.555262e-02*S80+1.962660e+00*S81+7.291770e-01*S82+6.287084e-02*S83+(-1.579139e-01)*S84+8.492251e-01*S85+6.887184e-01*S86+1.135483e+00*S87+7.432181e-01*S88+4.384612e-01*S89'
.param V27_part1='1.954235e-02*S0+(-2.228595e+01)*S1+3.769327e+01*S2+2.922569e-02*S3+2.676632e-02*S4+2.960249e+01*S5+3.823999e-02*S6+6.300246e+02*S7+4.349855e+02*S8+1.142965e+03*S9'
.param V27_part2='V27_part1+4.423076e-02*S10+5.128514e+00*S11+5.608732e-02*S12+5.429552e-02*S13+6.374269e-02*S14+8.173931e-02*S15+4.846569e-02*S16+5.075202e-02*S17+1.282568e-01*S18+7.100535e-02*S19'
.param V27_part3='V27_part2+6.293444e-02*S20+1.574894e-01*S21+8.561807e-02*S22+7.616875e-02*S23+1.279995e-01*S24+2.883213e-01*S25+2.523745e-01*S26+1.519160e-01*S27+5.244464e-01*S28+2.690719e-01*S29'
.param V27_part4='V27_part3+8.480104e-02*S30+1.132700e-01*S31+5.336743e-02*S32+1.238843e-01*S33+2.044056e-01*S34+6.593057e-02*S35+1.530949e-01*S36+3.236184e-01*S37+2.037519e-01*S38+2.144722e-01*S39'
.param V27_part5='V27_part4+1.473561e-01*S40+1.432051e-01*S41+2.400844e-01*S42+1.797591e-01*S43+1.823789e-01*S44+1.072807e-01*S45+8.488366e-02*S46+7.521114e-02*S47+1.643834e-01*S48+1.208277e-01*S49'
.param V27_part6='V27_part5+1.046893e-01*S50+1.999643e-01*S51+2.067738e-01*S52+1.374281e-01*S53+2.638806e-01*S54+2.107377e-01*S55+1.823399e-01*S56+4.209188e-01*S57+3.357231e-01*S58+2.378578e-01*S59'
.param V27_part7='V27_part6+1.807416e-01*S60+1.126313e-01*S61+7.290229e-02*S62+2.036536e-01*S63+2.037543e-01*S64+1.332945e-01*S65+3.352219e-01*S66+2.830485e-01*S67+1.432345e-01*S68+5.109389e-01*S69'
.param V27_part8='V27_part7+3.683159e-01*S70+2.071247e-01*S71+6.479371e-01*S72+4.166466e-01*S73+2.829595e-01*S74+2.384017e-01*S75+(-3.005943e-01)*S76+1.630422e-01*S77+3.770009e-01*S78+2.357372e-01*S79'
.param V27='V27_part8+2.880643e-01*S80+4.036492e-01*S81+3.018010e-01*S82+4.000787e-01*S83+7.477156e-01*S84+4.019925e-01*S85+4.887807e-01*S86+4.930872e-01*S87+5.016677e-01*S88+3.877619e-01*S89'
.param V28_part1='2.847234e-02*S0+(-4.498959e+00)*S1+6.693599e+01*S2+2.690475e-02*S3+1.615009e-02*S4+2.311454e+01*S5+2.508993e-02*S6+(-5.328103e+03)*S7+(-1.886223e+02)*S8+1.325857e+03*S9'
.param V28_part2='V28_part1+1.414715e-02*S10+6.880036e+00*S11+2.288023e-02*S12+1.316948e-02*S13+8.267290e-03*S14+6.621425e-01*S15+1.333732e-02*S16+5.622362e-03*S17+6.122121e-01*S18+9.407570e-03*S19'
.param V28_part3='V28_part2+5.275154e-03*S20+3.971284e-01*S21+1.394077e-02*S22+4.314929e-03*S23+2.735785e-02*S24+5.262900e-01*S25+5.796530e-01*S26+2.556269e-02*S27+3.333540e-01*S28+5.716788e-01*S29'
.param V28_part4='V28_part3+2.783625e-02*S30+2.282161e-01*S31+3.953568e-03*S32+3.073715e-01*S33+7.690056e-02*S34+1.050599e-02*S35+5.635808e-01*S36+1.392711e-01*S37+4.136381e-01*S38+2.645664e-03*S39'
.param V28_part5='V28_part4+1.161884e-02*S40+3.617740e-03*S41+(-1.003279e-02)*S42+9.784548e-03*S43+(-1.235666e-03)*S44+3.306999e-02*S45+1.663619e-02*S46+3.790216e-03*S47+4.146270e-02*S48+1.568104e-02*S49'
.param V28_part6='V28_part5+3.119290e-03*S50+4.808408e-02*S51+2.958187e-01*S52+4.892373e-03*S53+4.845947e-02*S54+1.011826e-02*S55+2.907263e-03*S56+2.294939e-01*S57+2.888852e-01*S58+1.370474e-03*S59'
.param V28_part7='V28_part6+3.372411e-02*S60+1.574544e-02*S61+8.650001e-04*S62+4.803211e-02*S63+3.546083e-02*S64+8.992165e-03*S65+8.623822e-03*S66+3.211781e-02*S67+4.626618e-03*S68+4.225328e-03*S69'
.param V28_part8='V28_part7+3.128420e-02*S70+(-2.188643e-03)*S71+9.102442e-02*S72+1.419469e-02*S73+2.371311e-03*S74+5.086329e-02*S75+3.672147e-01*S76+4.447216e-03*S77+2.909977e-02*S78+1.586430e-02*S79'
.param V28='V28_part8+7.825581e-04*S80+4.512930e-02*S81+1.564096e-02*S82+2.026242e-03*S83+(-7.659336e-03)*S84+1.449463e-02*S85+3.020207e-02*S86+3.344945e-02*S87+1.754127e-02*S88+2.946847e-03*S89'
.param V29_part1='2.225260e-03*S0+1.514531e+00*S1+1.113642e+00*S2+2.076498e-03*S3+1.198945e-03*S4+1.800304e+00*S5+2.079721e-03*S6+2.545929e+02*S7+3.402124e+01*S8+2.240599e+02*S9'
.param V29_part2='V29_part1+1.120670e-03*S10+4.956298e-01*S11+1.875221e-03*S12+1.102815e-03*S13+3.715072e-04*S14+6.867624e-02*S15+9.831137e-03*S16+3.646265e-03*S17+8.410634e-02*S18+1.143765e-02*S19'
.param V29_part3='V29_part2+3.241367e-03*S20+5.751502e-02*S21+1.145305e-02*S22+4.000377e-03*S23+3.060442e-02*S24+9.818108e-03*S25+2.278863e-02*S26+3.523124e-02*S27+5.900439e-02*S28+1.349329e-02*S29'
.param V29_part4='V29_part3+5.855500e-02*S30+(-1.052003e-01)*S31+5.768806e-03*S32+(-1.710752e-01)*S33+(-6.415109e-01)*S34+8.859327e-03*S35+(-8.797779e-02)*S36+(-6.655640e-01)*S37+(-4.342248e-01)*S38+(-4.135142e-02)*S39'
.param V29_part5='V29_part4+2.102765e-02*S40+1.037928e-02*S41+(-5.368133e-02)*S42+2.936176e-02*S43+1.011175e-02*S44+9.835522e-02*S45+3.299128e-02*S46+1.588519e-02*S47+1.269323e-01*S48+3.843779e-02*S49'
.param V29_part6='V29_part5+1.259856e-02*S50+1.406303e-01*S51+(-8.308757e-01)*S52+2.410921e-02*S53+2.403876e-01*S54+6.108851e-02*S55+8.371813e-03*S56+1.264009e+00*S57+(-7.405928e-01)*S58+3.460593e-02*S59'
.param V29_part7='V29_part6+2.316828e-01*S60+9.253374e-02*S61+2.327977e-02*S62+3.285786e-01*S63+1.073426e-01*S64+2.983990e-02*S65+2.384963e-01*S66+1.820285e-01*S67+3.536302e-02*S68+2.956030e-01*S69'
.param V29_part8='V29_part7+1.733161e-01*S70+3.465516e-02*S71+1.053721e+00*S72+7.331370e-02*S73+3.814760e-02*S74+3.586743e-01*S75+1.696408e-01*S76+3.014849e-02*S77+4.407259e-01*S78+1.288070e-01*S79'
.param V29='V29_part8+3.070798e-02*S80+4.517497e-01*S81+1.549977e-01*S82+2.167183e-02*S83+4.748508e-01*S84+2.000775e-01*S85+1.005206e-01*S86+4.542215e-01*S87+2.160885e-01*S88+3.271931e-02*S89'
.param V30_part1='(-2.241627e-02)*S0+1.533893e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-3.569300e-03)*S4+1.716809e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V30_part2='V30_part1+(-3.244877e-02)*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-4.744767e-02)*S14+(-1.932264e-02)*S15+1.562504e+01*S16+2.342048e+01*S17+(-9.903142e-03)*S18+1.622604e+01*S19'
.param V30_part3='V30_part2+0.000000e+00*S20+(-3.943614e-02)*S21+(-7.007939e+00)*S22+7.524173e+00*S23+(-5.335139e-02)*S24+0.000000e+00*S25+(-4.789902e-02)*S26+(-2.299786e-02)*S27+(-2.101974e-02)*S28+(-2.851549e-02)*S29'
.param V30_part4='V30_part3+(-3.604056e+00)*S30+7.357764e-02*S31+(-2.631364e+00)*S32+2.263313e-02*S33+0.000000e+00*S34+1.210204e+00*S35+1.591000e-02*S36+0.000000e+00*S37+(-1.427152e-02)*S38+1.715451e-01*S39'
.param V30_part5='V30_part4+1.503500e-01*S40+0.000000e+00*S41+0.000000e+00*S42+(-2.094606e+00)*S43+(-7.783978e+00)*S44+0.000000e+00*S45+2.578960e+00*S46+4.930261e-01*S47+0.000000e+00*S48+6.111622e+00*S49'
.param V30_part6='V30_part5+(-1.419217e+00)*S50+0.000000e+00*S51+5.057757e-02*S52+(-1.055798e+01)*S53+0.000000e+00*S54+(-8.812243e+00)*S55+(-3.603835e-01)*S56+0.000000e+00*S57+9.746243e-03*S58+2.256344e-01*S59'
.param V30_part7='V30_part6+(-2.143687e+02)*S60+(-4.295702e+01)*S61+(-1.149032e+02)*S62+(-1.099324e+00)*S63+0.000000e+00*S64+2.713113e+01*S65+(-8.731527e-02)*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V30_part8='V30_part7+1.000000e+04*S70+(-3.224004e+01)*S71+0.000000e+00*S72+1.000000e+04*S73+0.000000e+00*S74+(-3.429204e+01)*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+6.314612e+00*S79'
.param V30='V30_part8+(-2.785308e+01)*S80+(-1.514615e+00)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+(-6.405153e-01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V31_part1='1.385830e-01*S0+(-9.488391e-01)*S1+0.000000e+00*S2+0.000000e+00*S3+4.830827e-02*S4+(-8.227583e-01)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V31_part2='V31_part1+6.514089e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+7.974998e-02*S14+4.922417e-02*S15+(-2.034125e+01)*S16+(-2.999232e+01)*S17+4.404046e-02*S18+(-1.705090e+01)*S19'
.param V31_part3='V31_part2+0.000000e+00*S20+9.545753e-02*S21+6.024653e-01*S22+(-1.607498e+00)*S23+1.640636e-01*S24+0.000000e+00*S25+7.205426e-02*S26+3.833191e-02*S27+6.239416e-02*S28+6.614017e-02*S29'
.param V31_part4='V31_part3+(-2.571269e-02)*S30+(-2.003920e-02)*S31+(-4.691719e+00)*S32+1.878345e-01*S33+0.000000e+00*S34+(-1.290902e+00)*S35+8.646933e-02*S36+0.000000e+00*S37+3.432060e-02*S38+9.076545e-01*S39'
.param V31_part5='V31_part4+2.270436e-01*S40+0.000000e+00*S41+0.000000e+00*S42+2.901902e-01*S43+1.961481e+00*S44+0.000000e+00*S45+(-4.058610e+01)*S46+(-2.405410e+01)*S47+0.000000e+00*S48+(-1.404322e+01)*S49'
.param V31_part6='V31_part5+(-3.579401e+01)*S50+0.000000e+00*S51+3.392353e-02*S52+1.168571e+00*S53+0.000000e+00*S54+(-1.795077e+00)*S55+(-1.886511e+00)*S56+0.000000e+00*S57+8.119067e-02*S58+(-1.204144e+01)*S59'
.param V31_part7='V31_part6+3.682123e+00*S60+2.582765e+01*S61+(-2.012863e+01)*S62+1.052673e+00*S63+0.000000e+00*S64+1.106252e+02*S65+4.638630e-01*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V31_part8='V31_part7+1.000000e+04*S70+(-1.732599e+00)*S71+0.000000e+00*S72+1.000000e+04*S73+0.000000e+00*S74+1.188857e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+(-7.478307e+01)*S79'
.param V31='V31_part8+(-6.517359e+01)*S80+1.189275e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+5.674017e-01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V32_part1='2.527510e-03*S0+7.682881e-02*S1+0.000000e+00*S2+0.000000e+00*S3+(-5.797249e-03)*S4+(-8.226990e-01)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V32_part2='V32_part1+1.072854e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+7.241824e-03*S14+(-1.494582e-02)*S15+1.143902e+01*S16+2.002823e+00*S17+(-3.558769e-02)*S18+9.375308e+00*S19'
.param V32_part3='V32_part2+0.000000e+00*S20+(-1.149500e-02)*S21+3.377787e+01*S22+6.604588e+00*S23+8.040117e-01*S24+0.000000e+00*S25+2.142230e-02*S26+6.857601e-01*S27+(-6.592697e-04)*S28+8.626125e-03*S29'
.param V32_part4='V32_part3+2.606645e+01*S30+(-1.005732e-02)*S31+1.436353e+01*S32+(-5.642977e-02)*S33+0.000000e+00*S34+1.670115e+01*S35+(-1.125203e-01)*S36+0.000000e+00*S37+4.160896e-02*S38+3.872264e+01*S39'
.param V32_part5='V32_part4+8.401383e+00*S40+0.000000e+00*S41+0.000000e+00*S42+1.151149e+01*S43+1.737215e+01*S44+0.000000e+00*S45+5.844766e+01*S46+2.413157e+01*S47+0.000000e+00*S48+3.149459e+01*S49'
.param V32_part6='V32_part5+2.574811e+01*S50+0.000000e+00*S51+1.307473e-02*S52+4.175565e+01*S53+0.000000e+00*S54+4.040318e+01*S55+3.491692e+01*S56+0.000000e+00*S57+2.673201e-02*S58+4.461944e+01*S59'
.param V32_part7='V32_part6+2.130478e+03*S60+1.379163e+02*S61+3.124644e+01*S62+1.070766e+01*S63+0.000000e+00*S64+(-2.753493e-01)*S65+1.604372e+01*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V32_part8='V32_part7+1.000000e+04*S70+6.070118e+01*S71+0.000000e+00*S72+1.000000e+04*S73+0.000000e+00*S74+2.207773e+02*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+7.929138e+01*S79'
.param V32='V32_part8+4.618531e+01*S80+8.164255e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+2.312680e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V33_part1='6.133464e-02*S0+(-4.625368e-02)*S1+0.000000e+00*S2+0.000000e+00*S3+4.648172e-02*S4+4.152560e-02*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V33_part2='V33_part1+4.271803e-02*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+(-2.752580e-03)*S14+4.111414e-03*S15+2.737624e+01*S16+2.134011e+01*S17+6.890872e-03*S18+2.153161e+01*S19'
.param V33_part3='V33_part2+0.000000e+00*S20+4.661968e-03*S21+2.588047e+01*S22+1.752707e+01*S23+2.593975e-01*S24+0.000000e+00*S25+1.148775e-02*S26+2.584993e-01*S27+8.776610e-03*S28+1.239958e-02*S29'
.param V33_part4='V33_part3+5.355766e+00*S30+2.876108e-02*S31+2.395991e+01*S32+3.201116e-02*S33+0.000000e+00*S34+4.123630e+01*S35+4.492832e-02*S36+0.000000e+00*S37+4.514995e-02*S38+1.692450e+01*S39'
.param V33_part5='V33_part4+1.475897e+01*S40+0.000000e+00*S41+0.000000e+00*S42+1.058528e+01*S43+1.966966e+01*S44+0.000000e+00*S45+3.221039e+00*S46+3.818992e+01*S47+0.000000e+00*S48+2.469331e+01*S49'
.param V33_part6='V33_part5+3.281808e+01*S50+0.000000e+00*S51+(-5.652300e-04)*S52+3.574169e+01*S53+0.000000e+00*S54+4.559127e+01*S55+4.753604e+01*S56+0.000000e+00*S57+4.276331e-03*S58+2.537469e+01*S59'
.param V33_part7='V33_part6+8.976656e+01*S60+3.429888e+01*S61+1.597511e+01*S62+5.065343e-01*S63+0.000000e+00*S64+(-7.963023e-01)*S65+3.657204e+00*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V33_part8='V33_part7+1.000000e+04*S70+1.220360e+01*S71+0.000000e+00*S72+1.000000e+04*S73+0.000000e+00*S74+4.386681e+01*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+5.316726e+01*S79'
.param V33='V33_part8+3.005819e+01*S80+4.355662e-01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+3.222415e-01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V34_part1='(-1.453962e-03)*S0+(-1.118593e-02)*S1+0.000000e+00*S2+0.000000e+00*S3+(-1.127812e-03)*S4+(-2.133329e-02)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V34_part2='V34_part1+(-2.000366e-04)*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+1.008850e-03*S14+1.591029e-02*S15+4.138929e-01*S16+2.158256e-01*S17+1.983820e-02*S18+(-4.313585e-01)*S19'
.param V34_part3='V34_part2+0.000000e+00*S20+2.043748e-02*S21+4.390916e-02*S22+(-1.233396e+00)*S23+9.715154e-02*S24+0.000000e+00*S25+1.619815e-02*S26+1.878377e-01*S27+1.842534e-02*S28+1.748195e-02*S29'
.param V34_part4='V34_part3+2.161284e-01*S30+4.100989e-03*S31+5.423687e+00*S32+8.183582e-04*S33+0.000000e+00*S34+1.169835e+00*S35+3.323110e-02*S36+0.000000e+00*S37+(-5.720839e-03)*S38+1.490101e-01*S39'
.param V34_part5='V34_part4+1.661894e+00*S40+0.000000e+00*S41+0.000000e+00*S42+1.535527e+00*S43+2.233224e+00*S44+0.000000e+00*S45+9.434305e+00*S46+2.451548e+01*S47+0.000000e+00*S48+5.013849e+00*S49'
.param V34_part6='V34_part5+3.528414e+01*S50+0.000000e+00*S51+7.209633e-03*S52+2.857510e+00*S53+0.000000e+00*S54+1.307385e+01*S55+1.216342e-01*S56+0.000000e+00*S57+1.130227e-02*S58+2.306374e+00*S59'
.param V34_part7='V34_part6+8.827471e-01*S60+(-6.300921e-01)*S61+2.214711e+02*S62+1.518995e-01*S63+0.000000e+00*S64+(-2.926970e+01)*S65+3.238135e-02*S66+1.000000e+04*S67+0.000000e+00*S68+1.000000e+04*S69'
.param V34_part8='V34_part7+1.000000e+04*S70+3.058982e+00*S71+0.000000e+00*S72+1.000000e+04*S73+0.000000e+00*S74+2.576397e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+2.837001e+01*S79'
.param V34='V34_part8+8.699874e+01*S80+7.389992e-01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+5.228330e-01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V35_part1='0.000000e+00*S0+0.000000e+00*S1+9.557817e-01*S2+(-2.855066e-03)*S3+0.000000e+00*S4+7.772844e-03*S5+(-2.951580e-03)*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V35_part2='V35_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.580202e-02)*S12+(-5.060433e-02)*S13+(-3.628984e-03)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V35_part3='V35_part2+1.765508e+01*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+1.145781e-02*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V35_part4='V35_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+6.569050e-02*S34+0.000000e+00*S35+0.000000e+00*S36+6.257773e-02*S37+3.471431e-02*S38+0.000000e+00*S39'
.param V35_part5='V35_part4+0.000000e+00*S40+1.897337e+01*S41+1.878279e+01*S42+0.000000e+00*S43+0.000000e+00*S44+2.331810e-01*S45+0.000000e+00*S46+0.000000e+00*S47+3.536363e-01*S48+0.000000e+00*S49'
.param V35_part6='V35_part5+0.000000e+00*S50+2.409915e-01*S51+0.000000e+00*S52+0.000000e+00*S53+2.341299e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V35_part7='V35_part6+1.000000e+04*S60+0.000000e+00*S61+0.000000e+00*S62+3.054475e+02*S63+(-3.680418e+00)*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+2.854835e+01*S68+1.000000e+04*S69'
.param V35_part8='V35_part7+1.000000e+04*S70+0.000000e+00*S71+0.000000e+00*S72+1.000000e+04*S73+(-1.903097e+01)*S74+0.000000e+00*S75+7.667657e-02*S76+1.367490e+01*S77+1.502769e+01*S78+0.000000e+00*S79'
.param V35='V35_part8+0.000000e+00*S80+0.000000e+00*S81+(-1.607503e+00)*S82+8.242350e+00*S83+(-2.825925e+00)*S84+5.237624e+00*S85+3.610292e+00*S86+0.000000e+00*S87+5.851180e+00*S88+3.129018e-01*S89'
.param V36_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.409928e+00)*S2+8.762542e-02*S3+0.000000e+00*S4+(-8.533480e-02)*S5+3.652269e-02*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V36_part2='V36_part1+0.000000e+00*S10+0.000000e+00*S11+3.153847e-02*S12+9.947360e-02*S13+(-1.901354e-03)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V36_part3='V36_part2+1.791683e-03*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+3.330705e-02*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V36_part4='V36_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+1.412514e-01*S34+0.000000e+00*S35+0.000000e+00*S36+1.400696e-01*S37+1.304338e-01*S38+0.000000e+00*S39'
.param V36_part5='V36_part4+0.000000e+00*S40+(-8.651250e-01)*S41+8.401861e-01*S42+0.000000e+00*S43+0.000000e+00*S44+6.996194e-01*S45+0.000000e+00*S46+0.000000e+00*S47+7.032493e-01*S48+0.000000e+00*S49'
.param V36_part6='V36_part5+0.000000e+00*S50+3.653151e-01*S51+0.000000e+00*S52+0.000000e+00*S53+3.867673e-01*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V36_part7='V36_part6+2.737967e+00*S60+0.000000e+00*S61+0.000000e+00*S62+1.223133e+00*S63+2.890396e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+(-2.593744e+01)*S68+1.000000e+04*S69'
.param V36_part8='V36_part7+1.000000e+04*S70+0.000000e+00*S71+0.000000e+00*S72+2.476348e+03*S73+4.811176e+01*S74+0.000000e+00*S75+(-1.647992e-02)*S76+(-8.010321e+01)*S77+1.818625e+00*S78+0.000000e+00*S79'
.param V36='V36_part8+0.000000e+00*S80+0.000000e+00*S81+1.080654e-01*S82+(-1.114592e-01)*S83+(-2.887882e-01)*S84+(-7.515879e-01)*S85+6.085223e-03*S86+0.000000e+00*S87+(-1.758865e+00)*S88+(-1.307945e-02)*S89'
.param V37_part1='0.000000e+00*S0+0.000000e+00*S1+1.022381e+00*S2+2.543869e-03*S3+0.000000e+00*S4+1.199155e-01*S5+1.370621e-03*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V37_part2='V37_part1+0.000000e+00*S10+0.000000e+00*S11+3.326167e-03*S12+(-2.830146e-03)*S13+3.255162e-03*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V37_part3='V37_part2+(-4.130556e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+(-1.949100e-03)*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V37_part4='V37_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+(-3.166877e-03)*S34+0.000000e+00*S35+0.000000e+00*S36+(-5.697334e-04)*S37+4.146398e-03*S38+0.000000e+00*S39'
.param V37_part5='V37_part4+0.000000e+00*S40+(-8.212350e+00)*S41+(-1.907601e+00)*S42+0.000000e+00*S43+0.000000e+00*S44+(-4.101885e-02)*S45+0.000000e+00*S46+0.000000e+00*S47+(-6.337359e-02)*S48+0.000000e+00*S49'
.param V37_part6='V37_part5+0.000000e+00*S50+(-3.929485e-02)*S51+0.000000e+00*S52+0.000000e+00*S53+(-2.648531e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V37_part7='V37_part6+(-9.982549e+02)*S60+0.000000e+00*S61+0.000000e+00*S62+(-5.046826e+01)*S63+4.614066e+00*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+4.285011e+01*S68+1.000000e+04*S69'
.param V37_part8='V37_part7+1.000000e+04*S70+0.000000e+00*S71+0.000000e+00*S72+5.726911e+03*S73+9.661044e+00*S74+0.000000e+00*S75+(-1.808071e-02)*S76+(-3.288526e+01)*S77+(-1.247779e-01)*S78+0.000000e+00*S79'
.param V37='V37_part8+0.000000e+00*S80+0.000000e+00*S81+(-1.127001e+00)*S82+(-1.187301e+01)*S83+(-1.471027e+00)*S84+(-7.162433e+00)*S85+(-2.803142e+01)*S86+0.000000e+00*S87+(-9.863678e+00)*S88+2.199451e+00*S89'
.param V38_part1='0.000000e+00*S0+0.000000e+00*S1+1.196612e-02*S2+5.394467e-02*S3+0.000000e+00*S4+2.118349e-02*S5+4.910075e-02*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V38_part2='V38_part1+0.000000e+00*S10+0.000000e+00*S11+4.432341e-02*S12+1.190704e-02*S13+2.741788e-02*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V38_part3='V38_part2+2.194148e+01*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+1.404802e-02*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V38_part4='V38_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+3.227418e-02*S34+0.000000e+00*S35+0.000000e+00*S36+3.128341e-02*S37+(-1.371050e-03)*S38+0.000000e+00*S39'
.param V38_part5='V38_part4+0.000000e+00*S40+2.439774e+01*S41+5.177747e-01*S42+0.000000e+00*S43+0.000000e+00*S44+1.907059e-01*S45+0.000000e+00*S46+0.000000e+00*S47+2.805156e-01*S48+0.000000e+00*S49'
.param V38_part6='V38_part5+0.000000e+00*S50+1.864405e-01*S51+0.000000e+00*S52+0.000000e+00*S53+2.704662e-01*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V38_part7='V38_part6+(-2.354714e+01)*S60+0.000000e+00*S61+0.000000e+00*S62+2.340836e+02*S63+(-1.968535e+00)*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+1.711114e+00*S68+1.000000e+04*S69'
.param V38_part8='V38_part7+1.000000e+04*S70+0.000000e+00*S71+0.000000e+00*S72+2.896056e+03*S73+1.605149e-01*S74+0.000000e+00*S75+6.530931e-03*S76+2.794644e+01*S77+2.046689e+02*S78+0.000000e+00*S79'
.param V38='V38_part8+0.000000e+00*S80+0.000000e+00*S81+2.548539e-01*S82+1.525036e+01*S83+2.169707e+00*S84+1.169359e+01*S85+2.218958e+01*S86+0.000000e+00*S87+2.114930e+01*S88+4.014734e+00*S89'
.param V39_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.226322e-02)*S2+(-1.117205e-03)*S3+0.000000e+00*S4+1.496592e-02*S5+(-1.748892e-03)*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V39_part2='V39_part1+0.000000e+00*S10+0.000000e+00*S11+(-5.760611e-04)*S12+1.341993e-03*S13+(-2.375711e-04)*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V39_part3='V39_part2+1.367738e-01*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+1.550342e-02*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V39_part4='V39_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+(-1.856652e-02)*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.743417e-02)*S37+(-1.370518e-03)*S38+0.000000e+00*S39'
.param V39_part5='V39_part4+0.000000e+00*S40+3.038732e+00*S41+1.522081e-01*S42+0.000000e+00*S43+0.000000e+00*S44+2.178770e-01*S45+0.000000e+00*S46+0.000000e+00*S47+3.180334e-01*S48+0.000000e+00*S49'
.param V39_part6='V39_part5+0.000000e+00*S50+2.295072e-01*S51+0.000000e+00*S52+0.000000e+00*S53+7.817628e-02*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V39_part7='V39_part6+1.052917e+00*S60+0.000000e+00*S61+0.000000e+00*S62+1.550357e+01*S63+1.597954e+01*S64+0.000000e+00*S65+0.000000e+00*S66+5.394215e+03*S67+(-1.526546e+01)*S68+1.000000e+04*S69'
.param V39_part8='V39_part7+1.000000e+04*S70+0.000000e+00*S71+0.000000e+00*S72+8.609793e+03*S73+2.055755e+00*S74+0.000000e+00*S75+2.896641e-02*S76+1.636361e+02*S77+7.418499e+01*S78+0.000000e+00*S79'
.param V39='V39_part8+0.000000e+00*S80+0.000000e+00*S81+4.428286e+01*S82+4.864991e+01*S83+3.847065e+01*S84+4.963735e+01*S85+9.668928e+01*S86+0.000000e+00*S87+5.764019e+01*S88+5.085714e+00*S89'
.param V40_part1='4.559725e-03*S0+9.609153e-01*S1+7.284754e-01*S2+1.000362e+00*S3+4.219876e-02*S4+1.822594e+00*S5+2.517068e-01*S6+(-1.182557e-02)*S7+1.488122e-02*S8+(-4.521417e-03)*S9'
.param V40_part2='V40_part1+(-1.952447e-01)*S10+3.184506e-02*S11+(-1.627883e-01)*S12+2.002967e+03*S13+2.948677e+02*S14+(-1.847076e-01)*S15+(-5.388492e-01)*S16+(-3.470924e-01)*S17+(-6.263796e-02)*S18+(-5.833656e-02)*S19'
.param V40_part3='V40_part2+(-1.106455e+00)*S20+(-1.982882e+00)*S21+2.694346e-01*S22+(-2.087982e+00)*S23+(-1.963279e+00)*S24+5.954785e+01*S25+(-3.491573e+00)*S26+(-1.277851e+00)*S27+(-1.580725e+00)*S28+(-5.740106e+00)*S29'
.param V40_part4='V40_part3+2.310924e+00*S30+(-5.010970e-01)*S31+(-2.659749e+00)*S32+8.504683e+01*S33+(-3.699667e-01)*S34+8.151995e-02*S35+2.010308e+01*S36+1.630351e-01*S37+(-2.436867e+00)*S38+1.000000e+04*S39'
.param V40_part5='V40_part4+(-7.178183e-01)*S40+2.559236e+00*S41+4.714656e+01*S42+(-9.446828e-01)*S43+(-1.981761e+02)*S44+(-1.229535e-01)*S45+(-3.664250e-01)*S46+(-4.577712e+01)*S47+(-6.123959e-01)*S48+(-8.616732e-01)*S49'
.param V40_part6='V40_part5+(-1.893011e+01)*S50+(-1.014808e+00)*S51+(-7.023985e+00)*S52+(-6.601241e-01)*S53+1.433309e+01*S54+(-8.794150e-01)*S55+(-2.867800e-01)*S56+5.378124e+01*S57+(-1.105287e+00)*S58+(-1.247017e+02)*S59'
.param V40_part7='V40_part6+3.619966e+03*S60+(-3.301675e-01)*S61+(-3.825057e-01)*S62+1.000000e+04*S63+6.287125e+00*S64+1.000000e+04*S65+2.571677e+01*S66+1.000000e+04*S67+1.000000e+04*S68+1.000000e+04*S69'
.param V40_part8='V40_part7+1.000000e+04*S70+(-6.913431e+00)*S71+(-7.911081e+02)*S72+8.151929e+03*S73+(-7.655033e+02)*S74+(-2.498304e+00)*S75+(-2.184400e-01)*S76+2.029560e-01*S77+(-9.854198e-01)*S78+(-3.113111e-02)*S79'
.param V40='V40_part8+5.911783e-03*S80+(-5.205231e-01)*S81+(-1.591553e-01)*S82+(-5.754734e-02)*S83+(-2.060497e-01)*S84+(-2.278939e-01)*S85+(-6.739935e-01)*S86+(-6.142629e-01)*S87+(-1.490235e-01)*S88+(-1.568715e+02)*S89'
.param V41_part1='7.037958e-01*S0+2.198331e+00*S1+1.660348e+00*S2+5.481994e-01*S3+5.198881e-01*S4+1.383611e+00*S5+1.418299e-01*S6+5.620654e-01*S7+6.384268e-01*S8+5.832581e-01*S9'
.param V41_part2='V41_part1+8.068998e-01*S10+3.755775e+00*S11+8.766909e-01*S12+2.245615e+02*S13+6.918452e+02*S14+3.123082e+00*S15+3.550811e+00*S16+3.441018e+00*S17+2.807075e+00*S18+4.099455e+00*S19'
.param V41_part3='V41_part2+4.877033e+00*S20+(-2.088940e-01)*S21+(-2.126128e-01)*S22+7.153585e+00*S23+(-2.045197e+00)*S24+(-5.207464e+01)*S25+7.511375e+00*S26+(-1.132545e+00)*S27+9.428346e+00*S28+1.096083e+01*S29'
.param V41_part4='V41_part3+1.166303e+02*S30+(-8.963174e-03)*S31+1.019758e+00*S32+(-1.761145e+02)*S33+2.421250e+00*S34+2.424360e+00*S35+(-1.331972e+01)*S36+2.537275e+00*S37+9.179598e+00*S38+1.000000e+04*S39'
.param V41_part5='V41_part4+1.785641e+00*S40+(-1.044292e+00)*S41+7.600702e+01*S42+2.606324e+00*S43+2.668624e+02*S44+1.695136e-01*S45+3.010742e+00*S46+(-1.475393e-01)*S47+1.921950e+00*S48+2.599830e+00*S49'
.param V41_part6='V41_part5+(-1.491981e+00)*S50+2.014354e+00*S51+1.999802e+00*S52+3.393207e+00*S53+(-3.731741e+00)*S54+1.925673e+00*S55+(-2.896231e-01)*S56+(-2.470568e+01)*S57+2.875931e+00*S58+4.285955e+02*S59'
.param V41_part7='V41_part6+6.915371e+03*S60+3.592022e+00*S61+2.208931e+00*S62+1.000000e+04*S63+4.877665e+00*S64+1.000000e+04*S65+7.268709e+00*S66+1.000000e+04*S67+1.000000e+04*S68+1.000000e+04*S69'
.param V41_part8='V41_part7+1.000000e+04*S70+1.222680e+01*S71+4.324536e+02*S72+1.000000e+04*S73+1.007862e+03*S74+9.966969e-01*S75+2.817549e+00*S76+1.407144e+00*S77+5.518112e-01*S78+1.393044e+00*S79'
.param V41='V41_part8+1.752222e+00*S80+1.440960e+00*S81+1.249404e+00*S82+1.407280e+00*S83+9.889434e-01*S84+1.442518e+00*S85+1.211717e+00*S86+1.190193e+00*S87+1.240981e+00*S88+2.431089e+02*S89'
.param V42_part1='6.711020e-01*S0+(-4.684761e-01)*S1+1.990817e-02*S2+(-4.475462e-01)*S3+4.483262e-01*S4+(-3.066521e-01)*S5+(-1.131231e-01)*S6+4.544831e-01*S7+3.909484e-01*S8+3.399993e-01*S9'
.param V42_part2='V42_part1+5.783376e-01*S10+1.031330e+02*S11+2.146145e-01*S12+3.541218e+02*S13+9.628266e+02*S14+8.298959e-01*S15+6.627167e-01*S16+3.340859e-01*S17+4.539028e-01*S18+5.076164e-01*S19'
.param V42_part3='V42_part2+6.793713e-01*S20+(-2.450393e+00)*S21+(-1.179469e+00)*S22+6.880672e-01*S23+(-3.304834e+01)*S24+(-3.875926e+00)*S25+1.138983e+00*S26+(-7.825135e+01)*S27+5.199911e-01*S28+5.476654e-01*S29'
.param V42_part4='V42_part3+1.956512e+01*S30+2.150876e-01*S31+8.211280e-01*S32+(-1.387916e+02)*S33+2.079972e-01*S34+1.631642e-01*S35+(-2.902611e+01)*S36+1.718803e-01*S37+5.255796e-01*S38+1.000000e+04*S39'
.param V42_part5='V42_part4+1.527709e-01*S40+7.154618e-02*S41+(-7.410343e+01)*S42+1.729598e-01*S43+1.941669e+01*S44+3.379325e-01*S45+5.398179e-01*S46+9.993241e+00*S47+3.547284e-01*S48+5.097130e-01*S49'
.param V42_part6='V42_part5+6.817610e+00*S50+2.030259e-01*S51+1.516379e+00*S52+2.714873e-01*S53+1.491320e+00*S54+1.647009e-01*S55+2.300343e-01*S56+4.706699e+01*S57+3.521679e-01*S58+8.142318e+00*S59'
.param V42_part7='V42_part6+1.641276e+03*S60+1.025301e+00*S61+5.456514e-01*S62+1.000000e+04*S63+9.280406e-01*S64+1.000000e+04*S65+(-1.510017e+01)*S66+1.000000e+04*S67+1.000000e+04*S68+(-9.071429e+02)*S69'
.param V42_part8='V42_part7+1.000000e+04*S70+1.965936e+00*S71+(-2.778480e+01)*S72+2.420574e+03*S73+8.647449e+01*S74+1.396443e+00*S75+1.103857e+00*S76+5.076520e-01*S77+6.263139e-01*S78+6.075648e-01*S79'
.param V42='V42_part8+4.220472e-01*S80+5.030705e-01*S81+4.460871e-01*S82+2.882160e-01*S83+2.997049e-01*S84+4.258938e-01*S85+4.476081e-01*S86+1.584043e-01*S87+3.971458e-01*S88+9.584339e+00*S89'
.param V43_part1='(-1.847066e-02)*S0+1.466154e-01*S1+9.605441e-03*S2+2.336841e-01*S3+1.139832e-01*S4+1.087289e-02*S5+(-6.928292e-03)*S6+1.820158e-01*S7+1.667510e-01*S8+9.536229e-02*S9'
.param V43_part2='V43_part1+1.222128e-01*S10+(-3.960888e+00)*S11+1.112855e-01*S12+(-8.796761e+01)*S13+(-2.463914e+00)*S14+(-1.959983e-01)*S15+(-6.316015e-02)*S16+(-2.809380e-02)*S17+(-2.705239e-01)*S18+(-2.316278e-01)*S19'
.param V43_part3='V43_part2+(-9.467384e-03)*S20+2.785013e-02*S21+4.798792e-02*S22+(-4.271543e-02)*S23+(-1.238176e-01)*S24+1.695723e+00*S25+3.269225e-03*S26+(-4.550564e-02)*S27+1.832794e-01*S28+(-6.774683e-02)*S29'
.param V43_part4='V43_part3+(-1.307182e+00)*S30+8.431410e-02*S31+1.790337e-01*S32+(-4.946804e+01)*S33+(-4.236609e-02)*S34+(-1.355851e-01)*S35+(-8.471255e-01)*S36+2.087884e-03*S37+(-2.513588e-01)*S38+(-5.553618e+03)*S39'
.param V43_part5='V43_part4+(-6.356187e-02)*S40+1.221408e-01*S41+(-3.576556e+01)*S42+(-6.536464e-02)*S43+(-5.862318e+00)*S44+1.341888e-02*S45+(-6.562253e-02)*S46+3.371459e+00*S47+1.828122e-02*S48+(-8.398783e-02)*S49'
.param V43_part6='V43_part5+1.660914e+00*S50+1.888485e-02*S51+6.416951e-01*S52+(-8.968714e-02)*S53+1.207328e-01*S54+(-4.997529e-02)*S55+1.328272e-01*S56+1.725226e+01*S57+(-7.139073e-02)*S58+(-7.829811e+00)*S59'
.param V43_part7='V43_part6+(-7.787582e+03)*S60+(-7.027293e-02)*S61+(-7.000639e-02)*S62+5.126868e+03*S63+(-1.247329e+00)*S64+(-1.000000e+04)*S65+3.171851e+00*S66+1.000000e+04*S67+1.000000e+04*S68+3.688048e+01*S69'
.param V43_part8='V43_part7+4.655673e+03*S70+(-1.568950e-01)*S71+(-3.762503e+02)*S72+2.039993e+01*S73+(-1.039053e+01)*S74+1.398298e-02*S75+(-1.209964e-01)*S76+(-6.104227e-02)*S77+(-4.977568e-03)*S78+(-4.624563e-02)*S79'
.param V43='V43_part8+(-8.823446e-02)*S80+1.147651e-02*S81+(-7.331940e-02)*S82+(-2.667737e-03)*S83+(-3.274514e-02)*S84+(-9.443749e-02)*S85+(-5.830522e-02)*S86+5.383242e-02*S87+(-8.931535e-02)*S88+(-5.620604e+00)*S89'
.param V44_part1='3.563405e-02*S0+4.515527e-02*S1+4.806714e-02*S2+4.537030e-03*S3+1.242914e-02*S4+6.823169e-02*S5+1.155215e-02*S6+3.168934e-03*S7+5.625216e-03*S8+1.168975e-02*S9'
.param V44_part2='V44_part1+1.230731e-02*S10+6.658027e-01*S11+1.407074e-02*S12+9.484149e+01*S13+9.803601e+02*S14+9.410008e-02*S15+1.215065e-01*S16+9.081048e-02*S17+7.757746e-02*S18+1.593149e-01*S19'
.param V44_part3='V44_part2+1.226708e-01*S20+(-4.184685e-01)*S21+(-1.736128e-01)*S22+2.174764e-01*S23+(-3.639970e+00)*S24+(-2.726627e+00)*S25+2.322066e-01*S26+(-1.305674e+01)*S27+(-1.793655e-01)*S28+3.402966e-01*S29'
.param V44_part4='V44_part3+7.053435e+00*S30+(-1.075884e-01)*S31+(-2.041645e-01)*S32+2.154946e+02*S33+1.031850e-01*S34+1.095861e-01*S35+9.616673e+00*S36+1.449030e-01*S37+1.770896e-01*S38+1.000000e+04*S39'
.param V44_part5='V44_part4+1.092349e-01*S40+(-3.182404e-02)*S41+(-4.730935e+00)*S42+1.434031e-01*S43+(-8.720027e+00)*S44+(-2.563354e-01)*S45+1.913083e-01*S46+1.599616e+00*S47+(-7.446698e-02)*S48+1.278639e-01*S49'
.param V44_part6='V44_part5+2.535643e-01*S50+(-6.973258e-02)*S51+(-4.402599e-01)*S52+8.253299e-02*S53+6.359758e+00*S54+1.183699e-01*S55+(-7.093167e-02)*S56+7.017445e+01*S57+1.785909e-01*S58+1.043624e+00*S59'
.param V44_part7='V44_part6+4.749684e+03*S60+4.029762e-01*S61+7.431815e-02*S62+1.000000e+04*S63+(-1.545682e+00)*S64+(-4.014125e+03)*S65+1.157737e+01*S66+1.000000e+04*S67+(-1.000000e+04)*S68+2.742545e+03*S69'
.param V44_part8='V44_part7+1.000000e+04*S70+1.714616e-01*S71+1.580915e+03*S72+2.559451e+03*S73+1.017129e+01*S74+3.541452e-03*S75+2.613455e-01*S76+5.757689e-02*S77+1.092124e-01*S78+3.590774e-02*S79'
.param V44='V44_part8+4.130273e-02*S80+(-1.712085e-01)*S81+3.208115e-02*S82+1.666272e-03*S83+1.639717e-02*S84+6.083416e-02*S85+2.479803e-02*S86+1.431807e-02*S87+5.756695e-02*S88+(-9.195216e+00)*S89'
.param V45_part1='(-1.644878e-01)*S0+5.636743e+00*S1+5.511920e+00*S2+8.010365e+00*S3+6.496445e-01*S4+5.734433e+00*S5+(-1.045215e-01)*S6+5.559025e-01*S7+(-1.784233e-01)*S8+(-1.539109e-01)*S9'
.param V45_part2='V45_part1+(-2.753432e-01)*S10+1.088557e+00*S11+(-6.486699e-01)*S12+1.067737e+00*S13+8.817934e-01*S14+3.305155e+03*S15+4.441214e+01*S16+5.217934e+00*S17+2.450589e+03*S18+9.562404e+00*S19'
.param V45_part3='V45_part2+4.562728e+01*S20+(-7.204420e+02)*S21+1.000000e+04*S22+8.975505e+00*S23+8.473528e+03*S24+8.657587e+03*S25+1.000000e+04*S26+1.000000e+04*S27+1.000000e+04*S28+7.669610e+03*S29'
.param V45_part4='V45_part3+5.074382e+00*S30+4.515476e+03*S31+1.000000e+04*S32+4.106019e-01*S33+1.000000e+04*S34+1.504509e+02*S35+(-2.896948e-01)*S36+1.519702e+03*S37+1.000000e+04*S38+(-3.987885e-01)*S39'
.param V45_part5='V45_part4+1.000000e+04*S40+1.000000e+04*S41+(-4.422152e-01)*S42+1.000000e+04*S43+2.896068e+00*S44+1.000000e+04*S45+7.804700e+03*S46+1.000000e+04*S47+2.562087e+02*S48+(-1.018798e+03)*S49'
.param V45_part6='V45_part5+1.000000e+04*S50+5.917477e+02*S51+1.000000e+04*S52+3.283409e+03*S53+(-8.052417e-02)*S54+1.000000e+04*S55+1.000000e+04*S56+(-6.104637e-01)*S57+1.000000e+04*S58+3.516802e+00*S59'
.param V45_part7='V45_part6+8.014650e-01*S60+1.000000e+04*S61+1.000000e+04*S62+1.344184e+00*S63+8.424623e-02*S64+6.953697e-01*S65+1.119309e-01*S66+1.248138e+00*S67+1.033231e+00*S68+9.996712e-01*S69'
.param V45_part8='V45_part7+1.412182e+00*S70+1.000000e+04*S71+5.276385e-01*S72+9.103253e-01*S73+2.474927e-01*S74+1.762374e+01*S75+1.200593e+01*S76+6.958911e+00*S77+(-9.506474e-01)*S78+(-3.948032e+02)*S79'
.param V45='V45_part8+9.260258e+03*S80+3.352365e+03*S81+(-7.169507e+02)*S82+6.761424e+00*S83+4.710527e+03*S84+9.036330e+01*S85+2.359413e+02*S86+6.147010e+01*S87+8.161363e+01*S88+1.183091e+01*S89'
.param V46_part1='3.267450e+00*S0+(-3.128857e+00)*S1+6.891531e-01*S2+(-5.803874e+00)*S3+7.810696e-01*S4+(-1.169812e+00)*S5+1.622933e+00*S6+1.137509e+00*S7+1.991320e+00*S8+1.626097e+00*S9'
.param V46_part2='V46_part1+1.623941e+00*S10+3.279628e-01*S11+1.714692e+00*S12+(-2.889726e-02)*S13+8.824374e-01*S14+2.599673e+00*S15+(-3.256429e+01)*S16+2.811717e+00*S17+3.025253e+00*S18+(-2.360438e+00)*S19'
.param V46_part3='V46_part2+(-3.739782e+01)*S20+3.635183e+02*S21+1.000000e+04*S22+(-4.548017e+00)*S23+8.473528e+03*S24+1.764921e+03*S25+7.631951e+03*S26+1.000000e+04*S27+1.000000e+04*S28+7.669610e+03*S29'
.param V46_part4='V46_part3+(-2.504465e+00)*S30+4.515476e+03*S31+9.928070e+03*S32+2.373645e-01*S33+1.000000e+04*S34+6.288988e+02*S35+8.149808e-01*S36+5.191546e+03*S37+1.000000e+04*S38+1.087031e+00*S39'
.param V46_part5='V46_part4+1.000000e+04*S40+1.000000e+04*S41+1.012412e+00*S42+1.000000e+04*S43+4.519635e+02*S44+1.000000e+04*S45+1.000000e+04*S46+1.000000e+04*S47+8.066194e+03*S48+3.612986e+03*S49'
.param V46_part6='V46_part5+1.000000e+04*S50+5.489634e+03*S51+1.000000e+04*S52+3.283409e+03*S53+1.041790e+00*S54+1.000000e+04*S55+1.000000e+04*S56+6.633427e-01*S57+1.000000e+04*S58+3.019447e+00*S59'
.param V46_part7='V46_part6+3.476651e-01*S60+1.000000e+04*S61+1.000000e+04*S62+(-1.815822e-02)*S63+4.420433e-01*S64+1.432731e+00*S65+5.184575e-01*S66+(-2.234462e-01)*S67+7.788760e-01*S68+(-1.912471e-01)*S69'
.param V46_part8='V46_part7+(-3.168314e-01)*S70+1.000000e+04*S71+(-8.837534e-02)*S72+(-2.575599e-01)*S73+1.817664e+00*S74+7.305549e+02*S75+(-6.453774e+00)*S76+1.597320e+01*S77+3.567919e+02*S78+1.641650e+03*S79'
.param V46='V46_part8+8.373684e+03*S80+3.352365e+03*S81+4.321139e+03*S82+(-4.499690e+02)*S83+1.000000e+04*S84+1.000000e+04*S85+4.490702e+03*S86+7.551170e+03*S87+7.474447e+03*S88+4.279920e+01*S89'
.param V47_part1='3.356184e+00*S0+(-2.085527e+00)*S1+(-1.984481e+00)*S2+(-5.372640e+00)*S3+4.611069e-01*S4+(-2.261102e+00)*S5+1.597256e+00*S6+7.299604e-01*S7+1.181854e+00*S8+1.746288e+00*S9'
.param V47_part2='V47_part1+9.210174e-01*S10+(-1.380103e-01)*S11+1.272577e+00*S12+(-2.681090e-01)*S13+7.924761e-03*S14+(-5.386881e+03)*S15+6.814185e+01*S16+3.013928e+00*S17+(-3.447882e+03)*S18+5.607186e-01*S19'
.param V47_part3='V47_part2+(-1.457569e+01)*S20+6.328837e+03*S21+1.000000e+04*S22+(-2.111837e+00)*S23+2.447855e+03*S24+(-3.521214e+03)*S25+9.366799e+03*S26+1.000000e+04*S27+7.167440e+03*S28+(-6.262961e+03)*S29'
.param V47_part4='V47_part3+1.948263e+00*S30+4.515476e+03*S31+1.000000e+04*S32+(-4.182556e-02)*S33+1.000000e+04*S34+3.808925e+01*S35+1.067724e+00*S36+1.739705e+03*S37+1.000000e+04*S38+(-7.561859e-01)*S39'
.param V47_part5='V47_part4+1.000000e+04*S40+1.000000e+04*S41+(-1.039025e+00)*S42+1.000000e+04*S43+8.634572e+00*S44+1.000000e+04*S45+(-2.750569e+03)*S46+1.000000e+04*S47+2.562087e+02*S48+(-7.004338e+02)*S49'
.param V47_part6='V47_part5+1.000000e+04*S50+5.917477e+02*S51+1.000000e+04*S52+(-1.897476e+03)*S53+5.127254e-01*S54+1.000000e+04*S55+1.000000e+04*S56+(-9.710489e-02)*S57+1.000000e+04*S58+(-2.562772e+00)*S59'
.param V47_part7='V47_part6+5.729515e-01*S60+1.000000e+04*S61+1.000000e+04*S62+4.310075e-01*S63+2.862199e-01*S64+(-5.236194e-02)*S65+5.478141e-01*S66+6.734105e-02*S67+(-5.591309e-02)*S68+2.644993e-01*S69'
.param V47_part8='V47_part7+1.357181e-01*S70+2.568152e+03*S71+8.955559e-03*S72+(-1.430579e-01)*S73+(-1.967978e-01)*S74+(-1.125641e+03)*S75+2.396835e-01*S76+(-4.928291e+00)*S77+(-2.048467e+02)*S78+(-3.328972e+02)*S79'
.param V47='V47_part8+5.322712e+03*S80+(-8.321853e+03)*S81+(-5.057739e+02)*S82+(-9.571284e+02)*S83+6.688222e+01*S84+(-1.244775e+03)*S85+(-1.005200e+03)*S86+1.911024e+03*S87+(-9.641869e+02)*S88+(-3.470342e+01)*S89'
.param V48_part1='3.412291e-01*S0+(-7.289933e-01)*S1+(-2.632346e-01)*S2+2.180282e-02*S3+1.472009e-01*S4+(-8.325516e-02)*S5+2.297295e-01*S6+3.445719e-01*S7+4.632936e-01*S8+3.020334e-01*S9'
.param V48_part2='V48_part1+1.662413e-01*S10+(-7.229377e-02)*S11+1.015339e-01*S12+(-3.781404e-02)*S13+(-1.018771e-01)*S14+6.270435e+02*S15+8.205636e+01*S16+4.416920e-01*S17+4.153161e+03*S18+(-5.155609e-01)*S19'
.param V48_part3='V48_part2+(-4.104234e+00)*S20+5.981974e+01*S21+(-1.000000e+04)*S22+(-6.979816e-01)*S23+7.657967e+03*S24+(-8.326124e+03)*S25+(-3.640698e+03)*S26+1.000000e+04*S27+(-5.742422e+03)*S28+(-7.503673e+03)*S29'
.param V48_part4='V48_part3+3.817692e-03*S30+(-1.000000e+04)*S31+(-1.000000e+04)*S32+3.768241e-02*S33+(-1.000000e+04)*S34+(-1.647714e+01)*S35+8.585861e-02*S36+(-9.348396e+01)*S37+(-1.000000e+04)*S38+4.212520e-02*S39'
.param V48_part5='V48_part4+(-1.000000e+04)*S40+(-1.000000e+04)*S41+2.943866e-02*S42+(-1.000000e+04)*S43+(-3.416683e+00)*S44+1.256798e+03*S45+(-1.296528e+03)*S46+(-9.345147e+03)*S47+1.000000e+04*S48+(-1.792884e+02)*S49'
.param V48_part6='V48_part5+(-1.000000e+04)*S50+1.000000e+04*S51+(-1.000000e+04)*S52+(-6.723392e+03)*S53+3.694546e-02*S54+(-7.530274e+03)*S55+(-3.120171e+03)*S56+5.597594e-02*S57+(-8.214532e+03)*S58+(-1.958615e-02)*S59'
.param V48_part7='V48_part6+4.214840e-03*S60+3.817378e+02*S61+(-1.000000e+04)*S62+1.372415e-02*S63+4.046758e-02*S64+(-1.888233e-01)*S65+1.076402e-02*S66+2.704478e-02*S67+(-1.496620e-01)*S68+2.513698e-02*S69'
.param V48_part8='V48_part7+1.473861e-02*S70+1.864195e+02*S71+7.089392e-02*S72+2.998310e-02*S73+(-7.619771e-02)*S74+(-2.239957e+02)*S75+3.045767e-01*S76+(-4.703753e-01)*S77+(-8.550739e+01)*S78+(-1.417114e+02)*S79'
.param V48='V48_part8+(-1.258172e+03)*S80+1.000000e+04*S81+(-1.825750e+03)*S82+(-1.816935e+02)*S83+(-8.905826e+02)*S84+(-1.000000e+04)*S85+(-3.347110e+03)*S86+1.000000e+04*S87+(-8.544661e+03)*S88+(-1.524865e+00)*S89'
.param V49_part1='3.806295e-02*S0+(-1.102877e-03)*S1+7.144482e-02*S2+(-1.206118e-01)*S3+3.100589e-02*S4+4.554904e-02*S5+2.186238e-02*S6+(-2.894345e-03)*S7+4.965449e-03*S8+2.124588e-02*S9'
.param V49_part2='V49_part1+2.577811e-02*S10+(-7.902015e-03)*S11+3.334091e-02*S12+(-8.683816e-03)*S13+7.153511e-03*S14+8.774500e-01*S15+(-1.616958e+01)*S16+(-1.675526e+00)*S17+3.558986e-01*S18+(-3.675658e+00)*S19'
.param V49_part3='V49_part2+(-1.148407e-01)*S20+(-2.034573e+01)*S21+1.000000e+04*S22+(-2.271924e-01)*S23+8.473528e+03*S24+2.853003e+03*S25+2.927909e+03*S26+1.000000e+04*S27+1.215269e+02*S28+5.016970e+02*S29'
.param V49_part4='V49_part3+1.211687e+00*S30+4.515476e+03*S31+(-1.390819e+03)*S32+(-3.289676e-01)*S33+1.000000e+04*S34+1.231658e+00*S35+(-4.775278e-01)*S36+1.216160e+00*S37+1.000000e+04*S38+(-5.586760e-01)*S39'
.param V49_part5='V49_part4+1.000000e+04*S40+1.000000e+04*S41+(-6.702965e-01)*S42+1.000000e+04*S43+1.870404e+02*S44+1.000000e+04*S45+4.415051e+03*S46+1.000000e+04*S47+2.562087e+02*S48+6.582822e+02*S49'
.param V49_part6='V49_part5+9.137855e+03*S50+5.917477e+02*S51+1.000000e+04*S52+9.731216e+03*S53+(-1.097354e+00)*S54+1.000000e+04*S55+1.000000e+04*S56+(-1.314090e+00)*S57+1.000000e+04*S58+1.144421e+00*S59'
.param V49_part7='V49_part6+(-8.042678e-01)*S60+7.982022e+01*S61+1.000000e+04*S62+(-1.136731e+00)*S63+(-1.947999e-01)*S64+3.141912e-02*S65+(-6.421968e-01)*S66+(-5.650894e-01)*S67+(-4.024647e-02)*S68+(-6.689365e-01)*S69'
.param V49_part8='V49_part7+(-6.148139e-01)*S70+5.538273e+03*S71+(-1.476874e+00)*S72+(-1.993607e-01)*S73+(-3.148360e-02)*S74+2.663954e+03*S75+(-2.283326e+00)*S76+4.140905e+00*S77+2.109122e+02*S78+3.592763e+02*S79'
.param V49='V49_part8+6.017379e+03*S80+3.352365e+03*S81+6.491558e+02*S82+3.013343e+03*S83+7.357412e+02*S84+3.016090e+03*S85+5.101660e+02*S86+8.198794e+03*S87+1.524122e+03*S88+5.664914e-01*S89'
.param V50_part1='8.300569e+01*S0+1.000000e+04*S1+2.087435e+01*S2+(-1.049688e+03)*S3+1.081441e+01*S4+7.435120e+01*S5+1.933080e+02*S6+9.275230e+03*S7+1.000000e+04*S8+1.000000e+04*S9'
.param V50_part2='V50_part1+1.092458e+03*S10+6.540801e+02*S11+1.524128e+03*S12+3.095267e+01*S13+6.340243e+00*S14+(-1.359868e-02)*S15+(-5.993919e-02)*S16+(-8.249034e-02)*S17+(-2.562371e-02)*S18+(-9.577495e-02)*S19'
.param V50_part3='V50_part2+(-2.630446e-02)*S20+4.148548e-02*S21+2.906796e-02*S22+5.839336e-03*S23+8.817381e-02*S24+(-4.059350e-03)*S25+1.516479e-02*S26+1.568739e-01*S27+1.646678e-01*S28+1.407808e-01*S29'
.param V50_part4='V50_part3+1.070818e-02*S30+1.281639e-02*S31+(-3.601688e-01)*S32+4.497226e-02*S33+(-6.402635e-02)*S34+(-4.026386e-02)*S35+7.463000e-02*S36+1.271309e-01*S37+2.374094e-02*S38+1.620084e-02*S39'
.param V50_part5='V50_part4+(-1.301847e-02)*S40+6.531885e-02*S41+(-6.182961e-03)*S42+4.124983e-02*S43+3.145775e-01*S44+(-4.113960e-02)*S45+(-3.901717e-02)*S46+(-1.527030e-01)*S47+(-2.051865e-01)*S48+(-5.652533e-02)*S49'
.param V50_part6='V50_part5+(-3.748945e-01)*S50+(-5.412526e-01)*S51+(-2.420663e-01)*S52+(-2.381120e-03)*S53+(-2.133847e-02)*S54+(-2.786803e-02)*S55+(-3.715910e-01)*S56+(-1.031972e-01)*S57+(-1.731248e-01)*S58+1.232278e-01*S59'
.param V50_part7='V50_part6+3.445831e-02*S60+1.227211e-01*S61+(-1.783149e-01)*S62+(-3.648930e-02)*S63+1.070614e-01*S64+(-6.843684e-01)*S65+2.333556e-02*S66+1.965312e-01*S67+3.374113e-01*S68+1.490586e-01*S69'
.param V50_part8='V50_part7+2.445567e-01*S70+(-1.393595e-01)*S71+(-8.738117e-02)*S72+3.335429e-01*S73+(-1.943317e-01)*S74+(-1.155914e-01)*S75+(-2.800476e-02)*S76+(-9.027102e-01)*S77+(-3.011957e-01)*S78+(-3.388891e-01)*S79'
.param V50='V50_part8+(-1.836733e+00)*S80+(-7.630174e-01)*S81+(-5.617933e-01)*S82+(-2.811262e+00)*S83+(-1.459539e+00)*S84+(-9.941605e-01)*S85+(-1.724704e+00)*S86+(-2.912528e+00)*S87+(-9.692522e-01)*S88+(-6.019727e-01)*S89'
.param V51_part1='1.243408e+01*S0+2.474499e+02*S1+8.002627e+02*S2+1.934290e+02*S3+2.473751e+03*S4+2.992176e+01*S5+(-2.904162e+01)*S6+1.044344e+02*S7+1.000000e+04*S8+1.000000e+04*S9'
.param V51_part2='V51_part1+3.832407e+02*S10+5.268959e+00*S11+1.691074e+01*S12+2.741176e+02*S13+1.388536e+02*S14+2.370701e-01*S15+3.283189e-01*S16+3.457377e-01*S17+2.354474e-01*S18+3.933277e-01*S19'
.param V51_part3='V51_part2+2.892657e-01*S20+7.154728e-02*S21+2.718685e-01*S22+3.441254e-01*S23+1.260748e-02*S24+3.561055e-01*S25+3.739091e-01*S26+(-2.782671e-02)*S27+2.418883e-01*S28+2.498594e-01*S29'
.param V51_part4='V51_part3+2.313802e-01*S30+5.232734e-01*S31+1.310978e+00*S32+8.573866e-02*S33+4.341070e-01*S34+7.365545e-01*S35+6.878711e-02*S36+2.417764e-01*S37+3.780927e-01*S38+1.402755e-01*S39'
.param V51_part5='V51_part4+4.291819e-01*S40+4.813001e-01*S41+1.584390e-01*S42+4.413905e-01*S43+2.473073e-01*S44+5.343631e-01*S45+6.558687e-01*S46+9.888122e-01*S47+8.172345e-01*S48+6.969510e-01*S49'
.param V51_part6='V51_part5+1.159000e+00*S50+1.366721e+00*S51+1.024624e+00*S52+9.054148e-01*S53+2.789820e-01*S54+7.825414e-01*S55+1.164453e+00*S56+3.456372e-01*S57+1.086095e+00*S58+5.825494e-01*S59'
.param V51_part7='V51_part6+3.351087e-01*S60+6.018213e-01*S61+1.438902e+00*S62+3.699078e-01*S63+2.903413e-01*S64+1.995351e+00*S65+3.690198e-01*S66+2.889738e-01*S67+3.920140e-01*S68+3.578352e-01*S69'
.param V51_part8='V51_part7+2.658177e-01*S70+1.012148e+00*S71+5.498284e-01*S72+1.944587e-01*S73+1.083971e+00*S74+9.065430e-01*S75+1.147920e+00*S76+2.948338e+00*S77+1.274448e+00*S78+1.636301e+00*S79'
.param V51='V51_part8+3.776484e+00*S80+1.760152e+00*S81+2.091150e+00*S82+4.477222e+00*S83+2.572837e+00*S84+2.521339e+00*S85+2.381011e+00*S86+4.073758e+00*S87+2.826128e+00*S88+1.601189e+00*S89'
.param V52_part1='(-1.435132e+02)*S0+(-1.214107e+03)*S1+1.557094e+00*S2+1.000000e+04*S3+3.457436e+00*S4+5.296853e+00*S5+(-2.868810e+02)*S6+5.724847e+02*S7+1.986040e+03*S8+1.000000e+04*S9'
.param V52_part2='V52_part1+7.667606e+01*S10+8.179844e-01*S11+2.318001e+02*S12+1.373432e+01*S13+2.856721e+02*S14+4.073321e-02*S15+1.968131e-01*S16+2.301372e-01*S17+2.129112e-02*S18+1.888114e-01*S19'
.param V52_part3='V52_part2+1.918283e-01*S20+(-6.930024e-02)*S21+2.122109e-02*S22+1.403773e-01*S23+(-3.871606e-02)*S24+2.533764e-02*S25+1.096782e-01*S26+(-4.277415e-02)*S27+(-1.277732e-01)*S28+2.723414e-02*S29'
.param V52_part4='V52_part3+1.606015e-01*S30+2.381164e-01*S31+5.775709e-01*S32+6.719895e-03*S33+1.547122e-01*S34+2.143753e-01*S35+(-3.461390e-02)*S36+5.066058e-02*S37+2.474300e-01*S38+(-3.120530e-02)*S39'
.param V52_part5='V52_part4+3.437582e-03*S40+1.412197e-01*S41+(-2.442468e-02)*S42+(-8.564417e-02)*S43+7.660383e-02*S44+5.535175e-01*S45+4.330354e-01*S46+6.325355e-01*S47+6.682698e-01*S48+3.801599e-01*S49'
.param V52_part6='V52_part5+6.845929e-01*S50+1.003185e+00*S51+3.680801e-01*S52+4.797113e-01*S53+2.364123e-01*S54+2.191128e-01*S55+4.776339e-01*S56+6.762971e-01*S57+(-7.643025e-03)*S58+5.237894e-01*S59'
.param V52_part7='V52_part6+4.024693e-01*S60+5.897707e-01*S61+9.934526e-01*S62+5.262312e-01*S63+2.579506e-01*S64+1.194335e+00*S65+3.436497e-01*S66+1.583064e-01*S67+8.117638e-01*S68+2.312968e-01*S69'
.param V52_part8='V52_part7+1.012171e-01*S70+7.702287e-01*S71+9.488411e-01*S72+(-2.521962e-02)*S73+7.403227e-01*S74+1.281375e+00*S75+1.222655e+00*S76+2.030925e+00*S77+1.525481e+00*S78+1.329925e+00*S79'
.param V52='V52_part8+2.514843e+00*S80+2.529762e+00*S81+1.133277e+00*S82+2.856411e+00*S83+2.776816e+00*S84+1.180722e+00*S85+3.574681e+00*S86+5.439020e+00*S87+5.033270e-01*S88+1.530270e+00*S89'
.param V53_part1='(-2.807293e+00)*S0+(-8.344288e+01)*S1+1.469760e-01*S2+1.649199e+01*S3+(-8.864969e+00)*S4+5.272207e+00*S5+(-1.051080e+01)*S6+6.169046e+01*S7+1.242946e+02*S8+2.832608e+03*S9'
.param V53_part2='V53_part1+4.065998e+00*S10+1.150750e+00*S11+4.167093e-01*S12+1.300421e+01*S13+4.227429e+02*S14+1.906923e-02*S15+4.747818e-02*S16+8.494114e-02*S17+1.777917e-02*S18+5.638879e-02*S19'
.param V53_part3='V53_part2+8.587158e-02*S20+1.413412e-03*S21+2.095314e-02*S22+8.669038e-02*S23+(-1.983799e-03)*S24+5.377365e-02*S25+9.130968e-02*S26+(-7.469272e-03)*S27+4.996727e-02*S28+8.411584e-02*S29'
.param V53_part4='V53_part3+8.949022e-03*S30+2.137114e-02*S31+4.877830e-02*S32+(-1.408667e-02)*S33+(-4.501463e-03)*S34+(-2.318221e-03)*S35+(-1.770298e-02)*S36+1.033996e-02*S37+5.295058e-02*S38+(-1.243501e-02)*S39'
.param V53_part5='V53_part4+7.724265e-03*S40+3.756902e-02*S41+(-1.564120e-02)*S42+2.458621e-02*S43+5.014898e-02*S44+(-1.633887e-03)*S45+4.513342e-03*S46+4.266539e-02*S47+(-1.526528e-02)*S48+1.736234e-03*S49'
.param V53_part6='V53_part5+4.685369e-02*S50+(-3.576519e-02)*S51+1.161252e-02*S52+4.771598e-02*S53+(-5.281275e-03)*S54+3.964861e-03*S55+2.226019e-02*S56+1.107260e-02*S57+7.373957e-04*S58+1.923052e-02*S59'
.param V53_part7='V53_part6+(-6.467709e-03)*S60+1.849614e-02*S61+6.017741e-02*S62+7.758385e-05*S63+(-2.279508e-02)*S64+(-2.319453e-02)*S65+(-1.303897e-02)*S66+(-3.638754e-02)*S67+1.690803e-02*S68+(-4.430819e-02)*S69'
.param V53_part8='V53_part7+(-5.659187e-02)*S70+6.779752e-03*S71+1.813199e-02*S72+(-7.052359e-02)*S73+1.206656e-02*S74+(-1.784012e-02)*S75+4.456014e-03*S76+1.445802e-02*S77+(-4.771515e-02)*S78+(-5.989060e-02)*S79'
.param V53='V53_part8+(-1.607659e-02)*S80+(-7.150581e-02)*S81+(-8.573672e-02)*S82+(-3.310356e-02)*S83+(-1.433014e-01)*S84+(-1.013340e-01)*S85+(-1.700926e-01)*S86+(-1.113111e-01)*S87+(-1.730482e-01)*S88+(-4.087600e-02)*S89'
.param V54_part1='1.834598e-01*S0+2.510402e+03*S1+3.461679e+01*S2+1.511500e+00*S3+2.938409e-01*S4+3.940327e+01*S5+8.473850e-02*S6+8.371598e+01*S7+7.758764e+01*S8+1.000000e+04*S9'
.param V54_part2='V54_part1+1.402786e+01*S10+2.857270e+01*S11+1.156881e+01*S12+6.400911e+01*S13+3.164777e+02*S14+(-1.649349e-03)*S15+4.136762e-04*S16+8.285824e-03*S17+(-4.011089e-03)*S18+(-9.051726e-03)*S19'
.param V54_part3='V54_part2+4.011396e-03*S20+(-3.580408e-03)*S21+(-1.427592e-02)*S22+(-2.226219e-02)*S23+(-4.686093e-03)*S24+(-1.738580e-02)*S25+(-3.202695e-02)*S26+(-3.438840e-03)*S27+(-4.291259e-02)*S28+(-4.580157e-02)*S29'
.param V54_part4='V54_part3+(-3.714461e-04)*S30+(-8.936853e-03)*S31+(-1.724886e-02)*S32+(-1.050280e-02)*S33+5.999420e-02*S34+(-6.449188e-03)*S35+(-2.962830e-02)*S36+1.569771e-02*S37+3.221017e-02*S38+(-9.536781e-04)*S39'
.param V54_part5='V54_part4+4.195019e-02*S40+1.591388e-04*S41+1.287765e-03*S42+6.764745e-02*S43+(-1.000038e-02)*S44+2.094795e-02*S45+5.629108e-02*S46+2.234791e-03*S47+2.618781e-02*S48+4.995499e-02*S49'
.param V54_part6='V54_part5+4.160084e-02*S50+2.237750e-02*S51+7.112416e-02*S52+(-6.093788e-02)*S53+(-4.194820e-02)*S54+1.334806e-01*S55+(-1.733321e-02)*S56+(-6.496108e-02)*S57+1.429422e-01*S58+(-1.201292e-01)*S59'
.param V54_part7='V54_part6+(-2.836075e-02)*S60+(-5.201245e-02)*S61+1.301437e-02*S62+(-2.406436e-02)*S63+(-3.395994e-02)*S64+(-4.349471e-02)*S65+(-4.959207e-02)*S66+(-7.627448e-02)*S67+(-8.647059e-02)*S68+(-9.976039e-02)*S69'
.param V54_part8='V54_part7+(-7.992481e-02)*S70+(-1.553360e-01)*S71+(-1.299216e-01)*S72+(-5.318330e-02)*S73+(-1.885578e-01)*S74+2.764423e-02*S75+(-3.976472e-02)*S76+1.968327e-01*S77+3.670643e-03*S78+1.608109e-01*S79'
.param V54='V54_part8+2.283081e-01*S80+(-5.895106e-02)*S81+2.156197e-01*S82+4.276541e-01*S83+(-2.466597e-02)*S84+2.156514e-01*S85+2.002379e-01*S86+(-4.370369e-01)*S87+2.081093e-01*S88+(-2.150406e-01)*S89'
.param V55_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-3.863007e+00)*S24+0.000000e+00*S25+0.000000e+00*S26+(-4.558005e+00)*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V55_part4='V55_part3+1.649198e+00*S30+0.000000e+00*S31+0.000000e+00*S32+2.311511e+00*S33+1.484221e-02*S34+(-1.178026e+01)*S35+0.000000e+00*S36+4.965227e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V55_part5='V55_part4+(-1.431976e-02)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+1.117416e+00*S45+1.345321e+00*S46+0.000000e+00*S47+4.052228e+00*S48+(-4.236535e+00)*S49'
.param V55_part6='V55_part5+0.000000e+00*S50+6.601156e+00*S51+0.000000e+00*S52+0.000000e+00*S53+3.044717e+01*S54+0.000000e+00*S55+0.000000e+00*S56+3.180066e+01*S57+5.169204e+00*S58+0.000000e+00*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+4.126671e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+1.343464e+01*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+0.000000e+00*S71+2.691003e+01*S72+0.000000e+00*S73+0.000000e+00*S74+6.567144e+00*S75+1.678826e+01*S76+0.000000e+00*S77+(-7.533254e-01)*S78+9.427773e+00*S79'
.param V55='V55_part8+(-1.306627e+01)*S80+2.507686e+01*S81+1.710391e+01*S82+(-1.501998e+01)*S83+4.434935e+01*S84+1.488195e+01*S85+(-9.242261e+00)*S86+6.426032e+01*S87+1.431688e+01*S88+0.000000e+00*S89'
.param V56_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.413383e+01*S24+0.000000e+00*S25+0.000000e+00*S26+1.008280e+01*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V56_part4='V56_part3+2.551787e+01*S30+0.000000e+00*S31+0.000000e+00*S32+2.049336e+01*S33+1.193274e+01*S34+1.537755e+01*S35+0.000000e+00*S36+1.066386e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V56_part5='V56_part4+(-5.515157e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+4.776406e+01*S45+3.715548e+01*S46+0.000000e+00*S47+3.565333e+01*S48+7.179687e+00*S49'
.param V56_part6='V56_part5+0.000000e+00*S50+3.054868e+01*S51+0.000000e+00*S52+0.000000e+00*S53+3.280224e+01*S54+0.000000e+00*S55+0.000000e+00*S56+3.051645e+01*S57+(-6.534510e+00)*S58+0.000000e+00*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+1.119762e+02*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+7.001150e+01*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+0.000000e+00*S71+6.170616e+01*S72+0.000000e+00*S73+0.000000e+00*S74+5.773284e+01*S75+1.345727e+02*S76+0.000000e+00*S77+(-3.071425e+01)*S78+1.147596e+01*S79'
.param V56='V56_part8+2.862232e+01*S80+3.495298e+01*S81+2.955342e+00*S82+(-4.732196e-01)*S83+4.531089e+00*S84+4.981610e+00*S85+2.587246e+00*S86+7.924518e+00*S87+7.640967e+00*S88+0.000000e+00*S89'
.param V57_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+1.430174e+01*S24+0.000000e+00*S25+0.000000e+00*S26+9.213692e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V57_part4='V57_part3+3.236663e+01*S30+0.000000e+00*S31+0.000000e+00*S32+3.303552e+01*S33+4.263131e+01*S34+3.854345e+01*S35+0.000000e+00*S36+3.679723e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V57_part5='V57_part4+1.850898e+01*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+4.709895e+01*S45+6.244599e+01*S46+0.000000e+00*S47+5.257844e+01*S48+5.232791e+01*S49'
.param V57_part6='V57_part5+0.000000e+00*S50+5.828257e+01*S51+0.000000e+00*S52+0.000000e+00*S53+(-1.428276e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-2.583945e+01)*S57+9.479553e+01*S58+0.000000e+00*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+1.196642e+02*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+1.658132e+01*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+0.000000e+00*S71+(-1.849688e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+9.739381e+01*S75+1.496731e+02*S76+0.000000e+00*S77+8.128416e+01*S78+1.188801e+02*S79'
.param V57='V57_part8+5.907701e+01*S80+9.993205e+01*S81+1.505573e+02*S82+6.696671e+01*S83+1.014842e+02*S84+1.595622e+02*S85+1.224364e+02*S86+1.062677e+02*S87+1.621448e+02*S88+0.000000e+00*S89'
.param V58_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+3.828091e+00*S24+0.000000e+00*S25+0.000000e+00*S26+3.414667e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V58_part4='V58_part3+1.335134e+00*S30+0.000000e+00*S31+0.000000e+00*S32+1.839520e+00*S33+2.111499e+00*S34+2.295513e+00*S35+0.000000e+00*S36+1.893851e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V58_part5='V58_part4+1.739431e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+2.529644e+00*S45+3.827870e+00*S46+0.000000e+00*S47+3.327529e+00*S48+3.822734e+00*S49'
.param V58_part6='V58_part5+0.000000e+00*S50+5.133404e+00*S51+0.000000e+00*S52+0.000000e+00*S53+1.115056e+00*S54+0.000000e+00*S55+0.000000e+00*S56+(-6.845698e-01)*S57+5.028327e+00*S58+0.000000e+00*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+6.001245e-01*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-2.389978e-02)*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+0.000000e+00*S71+(-1.629394e-01)*S72+0.000000e+00*S73+0.000000e+00*S74+4.218118e+00*S75+4.931783e-01*S76+0.000000e+00*S77+7.391508e-01*S78+7.695131e+00*S79'
.param V58='V58_part8+6.147393e+00*S80+6.149538e+00*S81+8.734204e+00*S82+9.799576e+00*S83+8.024648e+00*S84+1.502731e+01*S85+1.079909e+01*S86+9.199465e+00*S87+1.375675e+01*S88+0.000000e+00*S89'
.param V59_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+(-5.097799e+00)*S24+0.000000e+00*S25+0.000000e+00*S26+(-3.300739e+00)*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V59_part4='V59_part3+(-8.012632e+00)*S30+0.000000e+00*S31+0.000000e+00*S32+(-6.186774e+00)*S33+(-9.582567e+00)*S34+(-4.857724e+00)*S35+0.000000e+00*S36+(-6.256673e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V59_part5='V59_part4+4.591190e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+(-5.930687e+00)*S45+(-1.237648e+01)*S46+0.000000e+00*S47+(-7.472321e+00)*S48+1.630633e+00*S49'
.param V59_part6='V59_part5+0.000000e+00*S50+(-1.054156e+01)*S51+0.000000e+00*S52+0.000000e+00*S53+(-2.430325e+01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-2.324635e+01)*S57+(-3.006376e+00)*S58+0.000000e+00*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+(-4.791992e+01)*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-2.137281e+01)*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+0.000000e+00*S71+(-3.224486e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-7.213820e+00)*S75+(-6.756404e+01)*S76+0.000000e+00*S77+9.713457e+00*S78+(-5.228273e+00)*S79'
.param V59='V59_part8+1.546698e+01*S80+(-2.223918e+01)*S81+(-1.798390e+01)*S82+2.003604e+01*S83+(-1.319320e+01)*S84+(-2.200973e+01)*S85+(-2.531474e+01)*S86+(-5.428991e+01)*S87+(-2.712633e+01)*S88+0.000000e+00*S89'
.param V60_part1='(-1.084684e+02)*S0+2.417219e+00*S1+1.483787e+00*S2+5.903688e-02*S3+2.256652e+00*S4+(-1.504100e+00)*S5+(-1.049395e+00)*S6+1.454680e-01*S7+1.383578e+00*S8+(-1.046551e+00)*S9'
.param V60_part2='V60_part1+(-9.682165e-02)*S10+9.975569e-01*S11+(-1.040319e+00)*S12+(-4.898216e-01)*S13+(-2.424128e+00)*S14+(-1.971509e-01)*S15+(-1.769664e-01)*S16+(-6.664553e+00)*S17+(-3.351303e-01)*S18+(-1.923343e+00)*S19'
.param V60_part3='V60_part2+(-4.948671e+00)*S20+3.671454e-01*S21+(-3.638525e-01)*S22+(-2.519978e+00)*S23+(-1.570704e-02)*S24+(-2.401987e-01)*S25+(-2.400892e+00)*S26+7.168654e-01*S27+(-4.690232e-01)*S28+(-2.235820e+00)*S29'
.param V60_part4='V60_part3+(-3.453382e-01)*S30+(-1.003357e+00)*S31+(-4.203781e+00)*S32+(-1.568005e-01)*S33+(-1.723635e+00)*S34+(-3.185269e+00)*S35+(-4.074165e-01)*S36+(-2.477729e+00)*S37+(-5.411397e+00)*S38+2.622944e+00*S39'
.param V60_part5='V60_part4+(-1.577579e+00)*S40+(-5.585123e+00)*S41+2.871406e+00*S42+(-2.341897e+00)*S43+(-2.489951e+00)*S44+5.238384e-01*S45+(-2.599919e+00)*S46+(-5.994408e+00)*S47+4.422208e-01*S48+(-6.697950e-01)*S49'
.param V60_part6='V60_part5+(-9.376427e+00)*S50+3.237722e-01*S51+(-2.252615e+00)*S52+(-4.679270e+00)*S53+(-2.309844e+00)*S54+(-2.023874e+00)*S55+(-6.684327e+00)*S56+(-1.667423e+00)*S57+(-2.183387e+00)*S58+1.945941e-01*S59'
.param V60_part7='V60_part6+2.907924e+00*S60+3.451449e-01*S61+(-7.639934e+00)*S62+4.242363e+00*S63+1.105836e+00*S64+(-4.468504e+00)*S65+1.426728e+00*S66+1.818249e+00*S67+(-1.580989e+00)*S68+5.733861e+00*S69'
.param V60_part8='V60_part7+2.406613e+00*S70+(-3.800030e+00)*S71+(-5.467457e-02)*S72+2.011161e+00*S73+3.022533e-01*S74+2.132741e-01*S75+(-8.690155e-01)*S76+(-1.327215e+01)*S77+1.335923e+00*S78+(-4.420726e+00)*S79'
.param V60='V60_part8+(-1.149404e+01)*S80+(-3.035142e+00)*S81+(-5.805978e+00)*S82+(-1.354036e+01)*S83+(-4.291127e+00)*S84+(-4.018510e+00)*S85+(-1.487334e+01)*S86+(-9.778307e+00)*S87+(-5.429135e+00)*S88+(-1.856000e+00)*S89'
.param V61_part1='6.773552e+00*S0+(-7.292869e-01)*S1+1.207897e+00*S2+2.167587e+00*S3+2.962648e-01*S4+5.111971e+00*S5+2.515962e+00*S6+2.091228e+00*S7+9.540353e-01*S8+2.569260e+00*S9'
.param V61_part2='V61_part1+2.080214e+00*S10+1.382192e+00*S11+2.397680e+00*S12+1.960094e+00*S13+3.552859e+00*S14+9.082876e+00*S15+8.200575e+00*S16+1.830010e+01*S17+7.708034e+00*S18+9.699213e+00*S19'
.param V61_part3='V61_part2+1.298327e+01*S20+5.561608e+00*S21+6.901406e+00*S22+9.349366e+00*S23+3.105601e+00*S24+7.446500e+00*S25+8.843183e+00*S26+3.034255e+00*S27+6.355653e+00*S28+8.032945e+00*S29'
.param V61_part4='V61_part3+5.303997e+00*S30+1.407503e+01*S31+2.073459e+01*S32+5.610780e+00*S33+9.151577e+00*S34+1.366616e+01*S35+1.005563e+01*S36+1.097494e+01*S37+1.425115e+01*S38+7.937540e+00*S39'
.param V61_part5='V61_part4+1.198461e+01*S40+1.444187e+01*S41+8.049311e+00*S42+1.107179e+01*S43+1.160920e+01*S44+6.441682e+00*S45+1.092669e+01*S46+2.461684e+01*S47+7.939839e+00*S48+1.562699e+01*S49'
.param V61_part6='V61_part5+2.547868e+01*S50+8.448578e+00*S51+1.664420e+01*S52+2.097823e+01*S53+6.664729e+00*S54+1.584838e+01*S55+2.172661e+01*S56+6.355537e+00*S57+1.680515e+01*S58+1.579529e+01*S59'
.param V61_part7='V61_part6+1.831096e+01*S60+(-9.859673e-02)*S61+3.095983e+01*S62+1.695791e+01*S63+2.084710e+01*S64+2.674193e+01*S65+4.473089e+00*S66+1.977451e+01*S67+2.351795e+01*S68+1.745958e+01*S69'
.param V61_part8='V61_part7+1.961911e+01*S70+2.212765e+01*S71+5.322745e+00*S72+2.037588e+01*S73+1.804305e+01*S74+1.535570e+01*S75+3.418799e-01*S76+3.860669e+01*S77+3.375054e+01*S78+2.635673e+01*S79'
.param V61='V61_part8+3.214615e+01*S80+1.940789e+01*S81+2.692009e+01*S82+3.844622e+01*S83+2.326031e+01*S84+2.514580e+01*S85+3.294303e+01*S86+2.351099e+01*S87+2.509010e+01*S88+2.329018e+01*S89'
.param V62_part1='1.093560e+03*S0+1.057824e+00*S1+1.055531e+00*S2+1.620897e+00*S3+(-5.988188e-01)*S4+1.930181e+00*S5+3.537526e+00*S6+1.450732e+00*S7+1.372444e+00*S8+3.125712e+00*S9'
.param V62_part2='V62_part1+1.428095e+00*S10+1.553957e+00*S11+2.507624e+00*S12+2.126357e+00*S13+3.150469e+00*S14+3.776174e+00*S15+6.164322e+00*S16+1.314246e+01*S17+5.303394e+00*S18+8.620934e+00*S19'
.param V62_part3='V62_part2+1.331772e+01*S20+5.220994e+00*S21+9.645437e+00*S22+1.198115e+01*S23+3.936173e+00*S24+9.093601e+00*S25+1.225889e+01*S26+5.455883e+00*S27+9.750976e+00*S28+1.185834e+01*S29'
.param V62_part4='V62_part3+5.163840e+00*S30+1.946307e+01*S31+2.931239e+01*S32+5.443693e+00*S33+7.125650e+00*S34+1.396936e+01*S35+1.472169e+01*S36+9.705841e+00*S37+2.284741e+01*S38+1.017504e+01*S39'
.param V62_part5='V62_part4+1.477484e+01*S40+2.373370e+01*S41+1.140884e+01*S42+2.098201e+01*S43+2.349918e+01*S44+6.346233e+00*S45+1.170683e+01*S46+3.261482e+01*S47+6.295701e+00*S48+1.536784e+01*S49'
.param V62_part6='V62_part5+3.547829e+01*S50+6.558781e+00*S51+2.911187e+01*S52+3.434139e+01*S53+1.972976e+01*S54+3.122211e+01*S55+3.581011e+01*S56+2.311587e+01*S57+1.303643e+01*S58+3.425220e+01*S59'
.param V62_part7='V62_part6+2.167581e+01*S60+1.172732e+01*S61+4.808970e+01*S62+2.365967e+01*S63+3.405638e+01*S64+4.745262e+01*S65+2.227376e+01*S66+3.749249e+01*S67+4.817646e+01*S68+2.700793e+01*S69'
.param V62_part8='V62_part7+3.947390e+01*S70+4.897521e+01*S71+3.232339e+01*S72+4.227342e+01*S73+4.970816e+01*S74+1.727274e+01*S75+1.869095e+01*S76+6.943362e+01*S77+2.261920e+01*S78+3.177286e+01*S79'
.param V62='V62_part8+6.073726e+01*S80+2.070137e+01*S81+2.833442e+01*S82+6.188963e+01*S83+2.161181e+01*S84+2.873852e+01*S85+5.559389e+01*S86+2.401892e+01*S87+3.261464e+01*S88+6.803984e+01*S89'
.param V63_part1='2.614389e-01*S0+(-3.589943e-01)*S1+(-2.556437e-01)*S2+(-3.924430e-01)*S3+(-6.527421e-01)*S4+7.754618e-01*S5+3.797977e-01*S6+(-2.922713e-02)*S7+1.396294e-01*S8+1.937404e-01*S9'
.param V63_part2='V63_part1+2.573909e-01*S10+4.806754e-01*S11+1.311305e-01*S12+3.092638e-01*S13+4.571155e-01*S14+4.371958e-01*S15+3.099895e-01*S16+(-6.256219e-02)*S17+1.535616e-01*S18+1.641802e-01*S19'
.param V63_part3='V63_part2+9.310092e-02*S20+1.573305e-01*S21+3.398118e-01*S22+4.505018e-01*S23+(-3.744650e-01)*S24+4.488800e-01*S25+4.151662e-01*S26+(-2.772119e-01)*S27+5.405149e-01*S28+5.001433e-01*S29'
.param V63_part4='V63_part3+2.611151e-02*S30+4.212279e-01*S31+8.066794e-01*S32+(-4.348787e-02)*S33+(-1.079003e-01)*S34+(-9.225649e-02)*S35+3.736365e-01*S36+1.705510e-02*S37+5.451525e-01*S38+3.033188e-01*S39'
.param V63_part5='V63_part4+5.486890e-02*S40+5.888473e-01*S41+3.034553e-01*S42+4.651002e-01*S43+7.485092e-01*S44+(-7.703171e-02)*S45+(-5.149167e-01)*S46+5.113196e-01*S47+(-2.683750e-01)*S48+(-5.037444e-01)*S49'
.param V63_part6='V63_part5+6.513450e-01*S50+(-6.573092e-01)*S51+4.749744e-01*S52+1.868575e-01*S53+1.383939e-01*S54+5.272966e-01*S55+3.520814e-01*S56+4.547717e-01*S57+(-5.927885e-01)*S58+5.905690e-01*S59'
.param V63_part7='V63_part6+3.195285e-01*S60+1.853038e-01*S61+6.495419e-01*S62+2.644191e-01*S63+2.034532e-01*S64+2.373918e-01*S65+3.514220e-01*S66+3.874859e-01*S67+1.733243e-01*S68+3.871454e-01*S69'
.param V63_part8='V63_part7+4.552121e-01*S70+5.597227e-01*S71+1.805268e-01*S72+4.558028e-01*S73+2.973979e-01*S74+(-4.675824e-01)*S75+3.076009e-01*S76+9.667015e-01*S77+4.265577e-01*S78+(-1.079361e+00)*S79'
.param V63='V63_part8+(-3.468249e-01)*S80+(-7.513386e-01)*S81+(-1.435811e+00)*S82+(-9.652120e-01)*S83+(-1.239168e+00)*S84+(-2.733863e+00)*S85+(-1.229632e+00)*S86+(-1.090629e+00)*S87+(-2.443026e+00)*S88+8.386018e-01*S89'
.param V64_part1='1.559267e-01*S0+(-1.242100e-01)*S1+1.220970e-01*S2+8.455202e-03*S3+8.003623e-03*S4+1.125370e-01*S5+2.889994e-02*S6+1.981433e-02*S7+(-2.451810e-03)*S8+3.523818e-02*S9'
.param V64_part2='V64_part1+4.365771e-02*S10+7.245582e-03*S11+1.611791e-02*S12+(-1.009087e-02)*S13+5.483958e-02*S14+(-5.805661e-01)*S15+(-6.355874e-01)*S16+(-1.088448e+00)*S17+(-7.671537e-01)*S18+(-9.555663e-01)*S19'
.param V64_part3='V64_part2+(-1.395707e+00)*S20+(-9.838050e-01)*S21+(-1.713992e+00)*S22+(-1.832282e+00)*S23+2.480601e-01*S24+(-1.666490e+00)*S25+(-2.053879e+00)*S26+(-1.181683e-01)*S27+(-1.594591e+00)*S28+(-2.116649e+00)*S29'
.param V64_part4='V64_part3+9.707418e-01*S30+(-1.829307e+00)*S31+(-4.432826e+00)*S32+3.121236e-01*S33+1.459137e+00*S34+(-7.912837e-01)*S35+(-8.026614e-01)*S36+(-3.500688e-03)*S37+(-2.166797e+00)*S38+(-2.431209e+00)*S39'
.param V64_part5='V64_part4+(-2.780850e+00)*S40+(-3.038862e+00)*S41+(-2.994436e+00)*S42+(-2.272703e+00)*S43+(-3.707866e+00)*S44+4.061484e-01*S45+1.897779e+00*S46+(-3.209229e+00)*S47+8.427342e-02*S48+(-2.429959e+00)*S49'
.param V64_part6='V64_part5+(-3.283983e+00)*S50+1.203415e-01*S51+(-2.406378e+00)*S52+(-5.502514e+00)*S53+6.280527e-01*S54+(-2.883259e+00)*S55+(-5.806426e+00)*S56+(-1.856761e-01)*S57+(-3.267496e+00)*S58+(-6.862799e+00)*S59'
.param V64_part7='V64_part6+(-2.357101e+00)*S60+4.673577e+00*S61+(-4.572048e+00)*S62+(-3.600759e+00)*S63+(-4.761589e+00)*S64+(-6.883687e+00)*S65+(-4.445056e-01)*S66+(-6.268690e+00)*S67+(-9.105794e+00)*S68+(-6.125644e+00)*S69'
.param V64_part8='V64_part7+(-7.404379e+00)*S70+(-8.086636e+00)*S71+8.454384e-02*S72+(-8.551101e+00)*S73+(-8.693145e+00)*S74+(-3.072462e-02)*S75+6.737951e+00*S76+(-4.864040e+00)*S77+(-4.104607e+00)*S78+(-3.216259e+00)*S79'
.param V64='V64_part8+(-9.900022e+00)*S80+1.194832e+00*S81+(-1.081031e+00)*S82+(-1.077471e+01)*S83+(-2.863712e+00)*S84+(-1.466043e+00)*S85+(-8.172762e-01)*S86+6.225049e+00*S87+(-8.893535e-01)*S88+(-1.047382e+01)*S89'
.param V65_part1='2.498054e+01*S0+2.689034e+01*S1+2.963719e+00*S2+3.306000e+01*S3+3.433569e+01*S4+6.864607e+00*S5+3.367436e+00*S6+7.264105e+00*S7+7.040511e+00*S8+4.833328e+00*S9'
.param V65_part2='V65_part1+5.234978e+00*S10+7.340984e+00*S11+6.592900e-01*S12+4.658221e+00*S13+4.537647e+00*S14+5.501159e+00*S15+7.386739e+00*S16+4.155540e+00*S17+4.419941e+00*S18+4.144131e+00*S19'
.param V65_part3='V65_part2+3.550066e+00*S20+3.313112e+00*S21+3.881211e+00*S22+2.797250e+00*S23+1.196694e+00*S24+3.045427e+00*S25+2.629194e+00*S26+2.003957e+00*S27+1.953386e+00*S28+1.800381e+00*S29'
.param V65_part4='V65_part3+2.143370e+00*S30+7.932007e+00*S31+4.803636e+00*S32+2.196255e+00*S33+2.347848e+00*S34+2.458885e+00*S35+6.167305e+00*S36+2.253538e+00*S37+3.754042e+00*S38+5.896794e+00*S39'
.param V65_part5='V65_part4+3.675351e+00*S40+2.597735e+00*S41+5.475350e+00*S42+3.851626e+00*S43+2.441826e+00*S44+3.705417e+00*S45+2.661573e+00*S46+4.122998e+00*S47+4.000088e+00*S48+2.640837e+00*S49'
.param V65_part6='V65_part5+3.226389e+00*S50+3.837716e+00*S51+4.947219e+00*S52+2.561621e+00*S53+2.746383e+00*S54+3.765540e+00*S55+2.683152e+00*S56+3.267569e+00*S57+3.044725e+00*S58+2.395686e+00*S59'
.param V65_part7='V65_part6+7.719058e+00*S60+2.499585e+00*S61+3.601186e+00*S62+6.741077e+00*S63+4.495250e+00*S64+2.526479e+00*S65+3.350987e+00*S66+4.818225e+00*S67+3.095093e+00*S68+4.811184e+00*S69'
.param V65_part8='V65_part7+4.569668e+00*S70+2.272020e+00*S71+4.232513e+00*S72+3.476457e+00*S73+2.546452e+00*S74+4.351700e+00*S75+3.039211e+00*S76+2.072697e+00*S77+7.473547e+00*S78+3.059781e+00*S79'
.param V65='V65_part8+2.281770e+00*S80+4.947215e+00*S81+3.279660e+00*S82+2.352933e+00*S83+4.214964e+00*S84+3.633642e+00*S85+2.287794e+00*S86+4.158087e+00*S87+2.961872e+00*S88+2.039595e+00*S89'
.param V66_part1='3.105760e+01*S0+(-1.818151e-01)*S1+3.238436e-01*S2+(-2.006778e+01)*S3+(-2.200901e+01)*S4+6.876903e-01*S5+1.983984e+00*S6+1.001227e+00*S7+(-1.818009e+00)*S8+3.441551e-01*S9'
.param V66_part2='V66_part1+4.833889e-01*S10+(-2.867180e+00)*S11+2.300229e+00*S12+(-1.532579e-01)*S13+(-1.015513e+00)*S14+6.460397e-01*S15+(-4.323740e+00)*S16+(-1.380148e+00)*S17+1.860516e-01*S18+(-2.412002e+00)*S19'
.param V66_part3='V66_part2+(-8.270509e-01)*S20+(-9.547817e-01)*S21+(-1.714350e+00)*S22+(-3.786631e-01)*S23+(-2.569394e-01)*S24+(-3.766567e-01)*S25+(-1.630569e-01)*S26+(-8.463279e-01)*S27+1.413738e-01*S28+(-1.005118e-01)*S29'
.param V66_part4='V66_part3+1.740388e+00*S30+(-4.184347e+00)*S31+(-9.660556e-01)*S32+1.124319e+00*S33+7.243393e-01*S34+(-4.063209e-02)*S35+1.061304e+00*S36+7.773279e-01*S37+(-6.904399e-01)*S38+(-5.297288e-01)*S39'
.param V66_part5='V66_part4+(-1.064837e-02)*S40+2.562012e-01*S41+(-1.010985e+00)*S42+8.818414e-02*S43+(-1.154328e-01)*S44+1.131768e+00*S45+1.460720e-01*S46+(-1.593243e-01)*S47+1.152427e-01*S48+1.070279e+00*S49'
.param V66_part6='V66_part5+(-3.705492e-02)*S50+1.406027e-01*S51+6.028591e-02*S52+(-3.217841e-01)*S53+1.767242e-01*S54+9.173846e-01*S55+(-3.667907e-01)*S56+(-3.125774e-01)*S57+(-7.918085e-01)*S58+2.694590e-02*S59'
.param V66_part7='V66_part6+(-2.249932e+00)*S60+2.463058e-01*S61+(-4.570957e-01)*S62+3.425852e-01*S63+5.767871e-02*S64+(-1.803670e-01)*S65+(-2.992566e-01)*S66+(-1.141604e+00)*S67+(-3.801389e-01)*S68+1.158472e+00*S69'
.param V66_part8='V66_part7+(-1.445433e+00)*S70+(-3.473260e-01)*S71+(-1.061351e+00)*S72+(-5.561248e-01)*S73+(-7.106388e-01)*S74+2.466376e+00*S75+(-2.771663e-01)*S76+(-1.094290e-01)*S77+(-2.423879e-01)*S78+(-2.927746e-01)*S79'
.param V66='V66_part8+(-1.463222e-01)*S80+(-3.285738e-01)*S81+(-6.277528e-01)*S82+(-3.241520e-01)*S83+(-3.687525e-01)*S84+(-9.617645e-01)*S85+(-2.778342e-01)*S86+(-2.022063e-01)*S87+(-6.164926e-01)*S88+(-1.424664e-03)*S89'
.param V67_part1='(-3.628049e+01)*S0+(-1.836517e+01)*S1+6.182970e+00*S2+(-2.033953e+01)*S3+(-1.886338e+01)*S4+(-1.248199e+00)*S5+5.199766e+00*S6+(-1.277729e+00)*S7+(-1.053871e+00)*S8+1.320328e+00*S9'
.param V67_part2='V67_part1+(-1.303441e+00)*S10+(-1.251847e+00)*S11+(-1.825163e-01)*S12+(-8.165694e-01)*S13+(-9.403918e-01)*S14+(-9.036166e+00)*S15+(-5.419553e+00)*S16+(-2.132687e+00)*S17+(-7.102936e+00)*S18+(-2.627122e+00)*S19'
.param V67_part3='V67_part2+(-1.810876e+00)*S20+(-1.545171e+00)*S21+(-1.790114e+00)*S22+(-1.007675e+00)*S23+(-9.489512e-01)*S24+(-2.217369e+00)*S25+(-1.105160e+00)*S26+(-1.249105e+00)*S27+(-1.027456e+00)*S28+(-5.454836e-01)*S29'
.param V67_part4='V67_part3+(-4.405974e+00)*S30+(-5.824840e+00)*S31+(-2.822942e+00)*S32+(-3.005994e+00)*S33+(-2.061829e+00)*S34+(-9.918664e-01)*S35+(-8.556654e+00)*S36+(-1.501111e+00)*S37+(-1.416990e+00)*S38+(-6.268233e+00)*S39'
.param V67_part5='V67_part4+(-2.727298e+00)*S40+(-1.242145e+00)*S41+(-3.608585e+00)*S42+(-2.343952e+00)*S43+(-9.461247e-01)*S44+(-6.919325e+00)*S45+(-2.157886e+00)*S46+(-1.818343e+00)*S47+(-5.890485e+00)*S48+(-1.409231e+00)*S49'
.param V67_part6='V67_part5+(-1.109865e+00)*S50+(-5.437286e+00)*S51+(-3.146963e+00)*S52+(-8.665733e-01)*S53+(-2.266783e+00)*S54+(-3.120642e+00)*S55+(-1.026406e+00)*S56+(-2.384112e+00)*S57+(-1.056910e+00)*S58+(-1.107575e+00)*S59'
.param V67_part7='V67_part6+(-8.061274e+00)*S60+(-1.220992e+00)*S61+(-1.594347e+00)*S62+(-9.408534e+00)*S63+(-3.133260e+00)*S64+(-1.024719e+00)*S65+(-2.704069e+00)*S66+(-3.062212e+00)*S67+(-1.189843e+00)*S68+(-6.782418e+00)*S69'
.param V67_part8='V67_part7+(-1.963117e+00)*S70+(-7.516656e-01)*S71+(-2.865640e+00)*S72+(-1.365984e+00)*S73+(-6.589145e-01)*S74+(-6.686975e+00)*S75+(-1.728314e+00)*S76+(-8.008080e-01)*S77+(-1.057725e+01)*S78+(-1.782020e+00)*S79'
.param V67='V67_part8+(-9.774018e-01)*S80+(-6.470177e+00)*S81+(-1.834154e+00)*S82+(-9.164754e-01)*S83+(-4.705919e+00)*S84+(-2.067511e+00)*S85+(-8.852395e-01)*S86+(-4.474661e+00)*S87+(-1.478556e+00)*S88+(-7.881688e-01)*S89'
.param V68_part1='1.249317e+01*S0+(-7.525773e-01)*S1+(-1.897022e+00)*S2+1.838317e+00*S3+(-5.421329e+00)*S4+(-1.681944e+00)*S5+(-2.960471e+00)*S6+(-3.154319e+00)*S7+(-2.025062e+00)*S8+(-2.919138e+00)*S9'
.param V68_part2='V68_part1+(-2.169745e+00)*S10+(-1.038071e+00)*S11+(-1.182757e-02)*S12+(-1.389611e+00)*S13+(-8.098960e-02)*S14+(-3.043981e-01)*S15+(-4.561410e-02)*S16+(-1.300764e-01)*S17+(-3.737158e-01)*S18+(-1.014158e-02)*S19'
.param V68_part3='V68_part2+(-3.554036e-02)*S20+4.226495e-01*S21+4.151821e-02*S22+5.278527e-02*S23+2.066307e-01*S24+2.839226e-02*S25+3.360926e-02*S26+1.448511e-01*S27+1.755943e-01*S28+1.956406e-01*S29'
.param V68_part4='V68_part3+4.566982e-03*S30+(-1.887700e-01)*S31+1.466837e-02*S32+3.248058e-02*S33+8.807130e-02*S34+2.908594e-01*S35+(-1.638809e-01)*S36+2.378736e-01*S37+2.787008e-01*S38+3.149849e-01*S39'
.param V68_part5='V68_part4+4.133217e-01*S40+3.842099e-01*S41+4.965296e-01*S42+2.664092e-01*S43+2.688810e-01*S44+1.460955e-01*S45+2.190310e-01*S46+2.314836e-01*S47+1.981047e-01*S48+2.512193e-01*S49'
.param V68_part6='V68_part5+2.454916e-01*S50+3.517245e-01*S51+(-5.058336e-02)*S52+3.156964e-01*S53+3.989439e-01*S54+1.536581e-01*S55+2.392721e-01*S56+3.667038e-01*S57+2.255261e-01*S58+1.731201e-01*S59'
.param V68_part7='V68_part6+9.649089e-01*S60+4.139430e-01*S61+2.641662e-01*S62+8.371341e-01*S63+3.805711e-01*S64+2.982007e-01*S65+3.228906e-01*S66+2.968847e-01*S67+1.118742e-01*S68+1.337201e-01*S69'
.param V68_part8='V68_part7+1.392230e-01*S70+1.722712e-01*S71+3.250121e-01*S72+2.044794e-01*S73+1.065226e-01*S74+2.740326e-01*S75+2.882557e-01*S76+1.400204e-01*S77+4.376648e-01*S78+2.236101e-01*S79'
.param V68='V68_part8+1.596159e-01*S80+2.243556e-01*S81+1.408999e-01*S82+1.103830e-01*S83+2.458251e-01*S84+2.073035e-01*S85+1.365746e-01*S86+2.119441e-01*S87+1.672885e-01*S88+1.295005e-01*S89'
.param V69_part1='(-6.055180e-01)*S0+9.893947e-02*S1+2.750138e-01*S2+(-3.471362e-01)*S3+(-2.180926e-01)*S4+8.828555e-02*S5+1.411818e-01*S6+(-4.945959e-02)*S7+(-2.589049e-03)*S8+9.249658e-02*S9'
.param V69_part2='V69_part1+5.320295e-02*S10+4.370796e-03*S11+2.688176e-01*S12+(-6.979934e-03)*S13+3.094260e-02*S14+(-6.925089e-02)*S15+8.734686e-02*S16+1.747981e-01*S17+(-6.595632e-02)*S18+1.016977e-01*S19'
.param V69_part3='V69_part2+6.489404e-02*S20+(-1.049332e+00)*S21+(-5.277935e-01)*S22+(-3.570650e-01)*S23+(-4.471226e-02)*S24+(-1.653531e-01)*S25+(-3.082854e-01)*S26+(-2.426970e-02)*S27+(-3.812404e-01)*S28+(-1.965773e-01)*S29'
.param V69_part4='V69_part3+2.892264e-01*S30+(-4.494030e-01)*S31+4.287394e-01*S32+(-4.335059e-01)*S33+2.638571e-05*S34+(-1.550885e-01)*S35+(-1.103922e+00)*S36+(-3.584218e-01)*S37+(-4.229129e-01)*S38+(-1.105773e+00)*S39'
.param V69_part5='V69_part4+(-5.443347e-01)*S40+(-2.246108e-01)*S41+(-1.202372e+00)*S42+(-8.343098e-01)*S43+(-1.318751e-01)*S44+2.011803e-01*S45+8.376640e-02*S46+(-5.943184e-01)*S47+(-1.721940e-01)*S48+(-5.156992e-01)*S49'
.param V69_part6='V69_part5+(-5.042725e-01)*S50+(-2.991386e-01)*S51+(-9.531559e-01)*S52+(-7.686395e-02)*S53+(-3.563084e-01)*S54+(-7.736956e-01)*S55+(-6.303315e-02)*S56+(-4.769724e-01)*S57+(-2.076140e-01)*S58+(-9.419251e-02)*S59'
.param V69_part7='V69_part6+(-1.174955e+00)*S60+(-2.008562e-01)*S61+(-3.709327e-01)*S62+(-8.042788e-01)*S63+(-6.256309e-01)*S64+(-9.234313e-02)*S65+(-2.906609e-01)*S66+(-4.321868e-01)*S67+(-3.092393e-01)*S68+(-6.335057e-01)*S69'
.param V69_part8='V69_part7+(-4.411212e-01)*S70+(-4.697903e-02)*S71+(-4.457107e-01)*S72+(-3.663851e-01)*S73+(-5.281123e-02)*S74+(-3.798627e-01)*S75+(-2.073648e-01)*S76+(-5.039474e-02)*S77+(-7.823677e-01)*S78+(-1.789178e-01)*S79'
.param V69='V69_part8+(-2.025704e-02)*S80+(-3.271184e-01)*S81+(-1.763651e-01)*S82+(-5.147483e-02)*S83+(-3.645008e-01)*S84+(-2.029216e-01)*S85+(-6.125804e-02)*S86+(-2.936521e-01)*S87+(-8.489011e-02)*S88+(-1.358547e-01)*S89'
.param V70_part1='0.000000e+00*S0+0.000000e+00*S1+2.663182e+01*S2+0.000000e+00*S3+0.000000e+00*S4+1.794301e+01*S5+1.359940e+01*S6+1.988367e+01*S7+3.214024e+01*S8+1.323780e+01*S9'
.param V70_part2='V70_part1+2.578101e+01*S10+0.000000e+00*S11+2.632842e+01*S12+0.000000e+00*S13+0.000000e+00*S14+3.066623e+01*S15+2.117804e+01*S16+(-7.672849e+00)*S17+3.394461e+01*S18+1.072360e+01*S19'
.param V70_part3='V70_part2+4.041849e+01*S20+5.341407e+01*S21+1.980440e+01*S22+4.301850e+01*S23+0.000000e+00*S24+4.368013e+01*S25+8.904681e+01*S26+1.135874e+02*S27+5.842431e+01*S28+1.057089e+02*S29'
.param V70_part4='V70_part3+6.594146e+01*S30+1.601828e+01*S31+7.905774e+00*S32+4.222005e+01*S33+6.764076e+01*S34+4.248177e+01*S35+8.035106e+00*S36+5.686751e+01*S37+5.249408e+01*S38+7.689896e-01*S39'
.param V70_part5='V70_part4+3.544713e+01*S40+1.005958e+01*S41+(-6.492866e+00)*S42+7.883685e+00*S43+1.387121e+01*S44+(-2.133057e+00)*S45+4.641330e+01*S46+3.536814e+01*S47+5.020015e+00*S48+(-3.211265e+00)*S49'
.param V70_part6='V70_part5+2.284042e+01*S50+(-5.526451e+00)*S51+5.038199e+01*S52+1.737527e+01*S53+0.000000e+00*S54+1.986425e+01*S55+5.620988e+01*S56+0.000000e+00*S57+0.000000e+00*S58+1.494220e+02*S59'
.param V70_part7='V70_part6+1.062588e+01*S60+0.000000e+00*S61+8.184401e+01*S62+(-5.702278e+00)*S63+9.014641e+00*S64+4.869653e+01*S65+0.000000e+00*S66+4.444458e+01*S67+1.499105e+02*S68+(-2.927739e+01)*S69'
.param V70_part8='V70_part7+(-9.749681e+00)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.264601e+01)*S73+1.381068e+02*S74+2.890325e+01*S75+0.000000e+00*S76+0.000000e+00*S77+(-7.104608e+00)*S78+0.000000e+00*S79'
.param V70='V70_part8+0.000000e+00*S80+1.162098e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+(-1.664426e+02)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V71_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.134370e+00)*S2+0.000000e+00*S3+0.000000e+00*S4+(-5.870939e+00)*S5+(-5.919392e+00)*S6+(-1.358925e+01)*S7+(-2.111887e+01)*S8+(-3.639900e+00)*S9'
.param V71_part2='V71_part1+(-1.859970e+01)*S10+0.000000e+00*S11+(-1.466106e+01)*S12+0.000000e+00*S13+0.000000e+00*S14+6.698014e+01*S15+1.725688e+01*S16+7.258680e+00*S17+3.056422e+01*S18+6.942802e+01*S19'
.param V71_part3='V71_part2+(-4.153012e+01)*S20+(-1.833214e+01)*S21+5.606612e+01*S22+2.928637e+01*S23+0.000000e+00*S24+3.167970e+00*S25+(-1.505416e+01)*S26+(-5.675713e+01)*S27+1.842317e+01*S28+(-1.264966e+01)*S29'
.param V71_part4='V71_part3+(-7.452924e+01)*S30+3.303527e+01*S31+2.647347e+01*S32+8.903061e+00*S33+1.932482e-01*S34+9.773507e-01*S35+2.863020e+01*S36+3.375354e+01*S37+1.853527e+01*S38+3.558802e+01*S39'
.param V71_part5='V71_part4+4.707553e+01*S40+7.722694e+01*S41+4.182248e+01*S42+7.963591e+01*S43+6.117494e+01*S44+6.547621e+01*S45+(-4.263103e+01)*S46+2.549084e+01*S47+3.571356e+01*S48+8.729408e+01*S49'
.param V71_part6='V71_part5+9.848588e+01*S50+6.288215e+01*S51+5.319298e+01*S52+2.593430e+01*S53+0.000000e+00*S54+1.077658e+02*S55+2.986019e+01*S56+0.000000e+00*S57+0.000000e+00*S58+(-5.256814e+00)*S59'
.param V71_part7='V71_part6+2.579749e+01*S60+0.000000e+00*S61+1.573249e+01*S62+7.071720e+01*S63+5.510922e+01*S64+4.110825e+01*S65+0.000000e+00*S66+2.973745e+01*S67+(-3.303555e+01)*S68+1.097840e+02*S69'
.param V71_part8='V71_part7+1.110167e+02*S70+0.000000e+00*S71+0.000000e+00*S72+8.705564e+01*S73+(-3.643298e+01)*S74+1.422470e+01*S75+0.000000e+00*S76+0.000000e+00*S77+9.083534e+01*S78+0.000000e+00*S79'
.param V71='V71_part8+0.000000e+00*S80+8.368018e+01*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+2.672490e+02*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V72_part1='0.000000e+00*S0+0.000000e+00*S1+(-2.523353e+01)*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.319753e+01)*S5+(-7.456265e+00)*S6+(-1.304507e+01)*S7+(-1.645734e+01)*S8+(-7.634095e+00)*S9'
.param V72_part2='V72_part1+(-1.340451e+01)*S10+0.000000e+00*S11+(-1.453494e+01)*S12+0.000000e+00*S13+0.000000e+00*S14+6.353274e-01*S15+3.592912e+00*S16+6.305639e+01*S17+3.992588e+01*S18+2.281454e+01*S19'
.param V72_part3='V72_part2+2.113318e+01*S20+2.042276e+01*S21+(-1.232199e+01)*S22+(-9.309702e-01)*S23+0.000000e+00*S24+2.836446e+00*S25+(-1.628948e+01)*S26+(-4.659190e+01)*S27+(-1.127590e+01)*S28+(-3.763714e+01)*S29'
.param V72_part4='V72_part3+(-1.348410e+00)*S30+2.635323e+01*S31+4.555956e+01*S32+(-3.399864e+01)*S33+(-4.330198e+01)*S34+1.929357e+01*S35+4.486060e+01*S36+(-5.971543e+01)*S37+1.320894e+01*S38+5.406421e+01*S39'
.param V72_part5='V72_part4+(-3.214995e+01)*S40+(-8.641657e+00)*S41+8.421931e+01*S42+(-1.009159e+01)*S43+(-1.294503e+01)*S44+3.261727e+01*S45+(-9.019168e+00)*S46+3.464956e+01*S47+(-4.448287e+00)*S48+3.357923e+01*S49'
.param V72_part6='V72_part5+1.346302e+01*S50+(-3.559749e+01)*S51+(-2.745303e+01)*S52+3.019464e+01*S53+0.000000e+00*S54+(-3.191319e+01)*S55+(-2.567130e+01)*S56+0.000000e+00*S57+0.000000e+00*S58+(-1.081526e+02)*S59'
.param V72_part7='V72_part6+6.761325e+01*S60+0.000000e+00*S61+2.141224e+01*S62+4.034446e+01*S63+7.471737e+01*S64+(-4.220194e+00)*S65+0.000000e+00*S66+3.759452e+01*S67+(-1.067724e+00)*S68+6.788363e+01*S69'
.param V72_part8='V72_part7+5.150092e+01*S70+0.000000e+00*S71+0.000000e+00*S72+1.081886e+02*S73+(-5.280798e+00)*S74+2.120539e+01*S75+0.000000e+00*S76+0.000000e+00*S77+6.826564e+01*S78+0.000000e+00*S79'
.param V72='V72_part8+0.000000e+00*S80+(-3.146056e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+(-1.465914e+01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V73_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.272053e+00)*S2+0.000000e+00*S3+0.000000e+00*S4+3.189000e+00*S5+5.162273e+00*S6+2.661679e+00*S7+4.681638e+00*S8+4.493098e+00*S9'
.param V73_part2='V73_part1+4.848024e+00*S10+0.000000e+00*S11+(-1.115928e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+(-2.439893e+00)*S15+(-2.289196e+00)*S16+(-2.053887e+01)*S17+(-1.608232e+00)*S18+(-5.758323e+00)*S19'
.param V73_part3='V73_part2+(-2.163390e+01)*S20+(-1.764287e+01)*S21+(-2.355869e+01)*S22+(-2.704340e+01)*S23+0.000000e+00*S24+(-2.518761e+01)*S25+(-3.349228e+01)*S26+(-2.786198e+01)*S27+(-2.598734e+01)*S28+(-3.226495e+01)*S29'
.param V73_part4='V73_part3+(-6.626076e+00)*S30+(-5.544579e+00)*S31+(-7.243235e+00)*S32+(-9.754886e+00)*S33+(-9.039620e+00)*S34+(-8.753945e+00)*S35+(-4.672564e+00)*S36+(-8.427807e+00)*S37+(-1.546624e+01)*S38+(-2.305331e+00)*S39'
.param V73_part5='V73_part4+(-5.452981e+00)*S40+2.629695e-01*S41+(-6.070253e+00)*S42+(-9.422138e+00)*S43+(-1.068454e+01)*S44+(-4.403651e+00)*S45+(-9.097142e+00)*S46+(-1.753499e+01)*S47+(-6.259712e+00)*S48+(-1.907556e+01)*S49'
.param V73_part6='V73_part5+(-1.865720e+01)*S50+(-3.523197e+00)*S51+(-1.754370e+01)*S52+(-6.738870e+00)*S53+0.000000e+00*S54+(-1.854354e+01)*S55+6.894234e-01*S56+0.000000e+00*S57+0.000000e+00*S58+(-6.839828e+00)*S59'
.param V73_part7='V73_part6+6.563413e-01*S60+0.000000e+00*S61+(-1.722674e+01)*S62+(-4.181355e+00)*S63+(-1.208956e+01)*S64+(-1.740740e+01)*S65+0.000000e+00*S66+(-8.676643e+00)*S67+(-3.060220e+01)*S68+(-1.556127e+01)*S69'
.param V73_part8='V73_part7+(-1.948887e+01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.819516e+01)*S73+(-5.169660e+01)*S74+(-1.050692e+01)*S75+0.000000e+00*S76+0.000000e+00*S77+(-4.794341e+00)*S78+0.000000e+00*S79'
.param V73='V73_part8+0.000000e+00*S80+(-1.740213e+01)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+(-2.401793e+01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V74_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.325451e-01)*S2+0.000000e+00*S3+0.000000e+00*S4+(-5.144273e-01)*S5+(-2.647011e-01)*S6+(-1.715390e-01)*S7+(-1.076342e-01)*S8+(-3.042311e-01)*S9'
.param V74_part2='V74_part1+(-3.615438e-01)*S10+0.000000e+00*S11+(-1.087639e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+(-1.685783e+01)*S15+(-8.973129e+00)*S16+1.678303e+01*S17+(-2.101333e+01)*S18+(-1.094032e+01)*S19'
.param V74_part3='V74_part2+2.536948e+01*S20+2.040067e+00*S21+1.193266e+01*S22+1.141659e+01*S23+0.000000e+00*S24+1.710369e+01*S25+1.290689e+01*S26+(-3.010244e-02)*S27+(-3.958942e+00)*S28+1.331535e+01*S29'
.param V74_part4='V74_part3+3.572975e-01*S30+4.226284e+00*S31+4.060835e+00*S32+3.096477e+00*S33+2.776897e+00*S34+(-1.213654e+00)*S35+7.465721e+00*S36+(-1.039401e+00)*S37+(-8.940738e+00)*S38+7.582086e+00*S39'
.param V74_part5='V74_part4+(-4.383426e+00)*S40+(-3.107706e+00)*S41+2.000247e+00*S42+(-1.540891e+01)*S43+1.890295e+00*S44+8.158813e+00*S45+3.273681e+00*S46+(-6.879068e+00)*S47+1.080033e+01*S48+(-1.221667e+01)*S49'
.param V74_part6='V74_part5+(-1.279276e+01)*S50+5.638172e+00*S51+(-1.491248e+01)*S52+1.125098e+00*S53+0.000000e+00*S54+(-2.600048e+01)*S55+(-6.648795e-01)*S56+0.000000e+00*S57+0.000000e+00*S58+(-1.352279e+01)*S59'
.param V74_part7='V74_part6+3.063248e+00*S60+0.000000e+00*S61+(-2.580917e+01)*S62+8.470867e+00*S63+(-8.610192e+00)*S64+(-7.777306e-01)*S65+0.000000e+00*S66+(-1.194391e+01)*S67+(-6.069155e+01)*S68+3.039239e+00*S69'
.param V74_part8='V74_part7+(-1.873361e+01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-3.036504e+01)*S73+(-3.696356e+01)*S74+(-3.018056e+00)*S75+0.000000e+00*S76+0.000000e+00*S77+1.897522e+00*S78+0.000000e+00*S79'
.param V74='V74_part8+0.000000e+00*S80+(-1.145667e-02)*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+1.242048e+01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V75_part1='(-2.585916e+02)*S0+1.549951e+02*S1+7.718259e+02*S2+(-2.767590e+02)*S3+2.116875e+02*S4+2.421297e+02*S5+5.457765e+03*S6+9.998748e+03*S7+1.000000e+04*S8+1.000000e+04*S9'
.param V75_part2='V75_part1+1.000000e+04*S10+7.463370e+02*S11+4.307403e+02*S12+9.656724e+02*S13+9.423174e+03*S14+3.883739e+01*S15+2.604139e+03*S16+3.133572e+03*S17+3.865784e+01*S18+2.242487e+03*S19'
.param V75_part3='V75_part2+1.291870e+03*S20+1.717787e+00*S21+(-5.715554e+01)*S22+2.207474e+01*S23+(-1.228559e+01)*S24+1.813823e+03*S25+1.516215e+01*S26+(-3.462894e+00)*S27+4.436538e+00*S28+8.981898e+00*S29'
.param V75_part4='V75_part3+(-8.651097e-01)*S30+5.954013e+00*S31+1.646401e+01*S32+(-6.706264e+01)*S33+(-3.893325e+00)*S34+7.180095e-01*S35+(-2.487697e+00)*S36+(-1.262173e+00)*S37+3.679484e-01*S38+(-1.090062e-01)*S39'
.param V75_part5='V75_part4+(-7.734247e-01)*S40+5.314708e-01*S41+(-1.224292e-01)*S42+(-3.399500e-01)*S43+8.284186e-01*S44+(-3.204146e+03)*S45+(-9.568319e+00)*S46+8.587918e-01*S47+(-5.000254e+03)*S48+(-1.452429e+00)*S49'
.param V75_part6='V75_part5+1.401715e-01*S50+(-1.018248e+02)*S51+(-5.263845e-01)*S52+5.512190e-01*S53+5.865591e-02*S54+(-5.487681e-01)*S55+3.145469e-01*S56+8.769517e-02*S57+(-1.949022e+00)*S58+2.751256e-01*S59'
.param V75_part7='V75_part6+(-5.450977e-02)*S60+4.418788e+00*S61+4.932805e-01*S62+(-8.880813e-02)*S63+4.816051e-03*S64+3.333514e-01*S65+5.842849e-02*S66+1.923826e-02*S67+2.768825e-01*S68+4.590789e-03*S69'
.param V75_part8='V75_part7+2.801845e-02*S70+2.397224e-02*S71+1.075767e-01*S72+3.447857e-02*S73+8.149183e-04*S74+(-7.169601e+01)*S75+4.297624e+00*S76+(-7.762110e-02)*S77+(-3.226439e+00)*S78+(-3.604515e+00)*S79'
.param V75='V75_part8+(-2.352848e-01)*S80+(-2.242435e+02)*S81+(-6.297751e+00)*S82+(-6.446639e-01)*S83+(-5.816934e+01)*S84+(-6.365640e+00)*S85+(-1.161085e+00)*S86+(-1.093000e+02)*S87+(-6.862954e+00)*S88+5.088689e-02*S89'
.param V76_part1='1.248039e+00*S0+1.040349e+02*S1+2.568392e+02*S2+1.509854e+03*S3+9.765125e+01*S4+2.619703e+02*S5+(-1.924688e+03)*S6+9.999797e+03*S7+1.000000e+04*S8+1.000000e+04*S9'
.param V76_part2='V76_part1+9.601888e+02*S10+6.871778e+02*S11+4.708438e+01*S12+1.084458e+02*S13+1.575926e+02*S14+3.820955e+01*S15+1.926373e+01*S16+1.718846e+03*S17+4.034434e+01*S18+6.285013e+01*S19'
.param V76_part3='V76_part2+(-1.281426e+02)*S20+(-1.268163e+00)*S21+(-7.045128e+01)*S22+(-9.669347e+00)*S23+(-3.375940e-01)*S24+(-4.302114e+00)*S25+(-6.433544e+00)*S26+2.481668e-02*S27+(-3.355673e+00)*S28+(-6.501865e-02)*S29'
.param V76_part4='V76_part3+(-2.702209e+01)*S30+(-2.434903e-01)*S31+(-3.491547e+00)*S32+3.944162e-01*S33+3.859313e-01*S34+(-1.057540e+00)*S35+8.363315e-02*S36+(-6.776332e-01)*S37+(-3.726736e-01)*S38+8.724126e-02*S39'
.param V76_part5='V76_part4+8.909917e-03*S40+(-2.266932e-01)*S41+7.402926e-02*S42+(-9.391914e-02)*S43+(-4.108244e-01)*S44+1.195730e+00*S45+(-4.486998e-01)*S46+(-6.867581e-01)*S47+5.905055e-01*S48+(-2.746202e-01)*S49'
.param V76_part6='V76_part5+(-2.589096e-01)*S50+4.397859e-01*S51+2.278870e-02*S52+(-1.879635e-01)*S53+9.120905e-02*S54+(-3.697445e-02)*S55+(-7.825390e-02)*S56+8.158432e-02*S57+(-2.216099e-01)*S58+(-1.065214e-01)*S59'
.param V76_part7='V76_part6+1.341258e-02*S60+9.632769e-01*S61+(-5.282532e-01)*S62+(-8.671733e-04)*S63+(-5.199463e-02)*S64+(-2.073585e-01)*S65+1.742705e-03*S66+(-4.210268e-02)*S67+(-2.072334e-01)*S68+(-2.915860e-02)*S69'
.param V76_part8='V76_part7+(-4.936836e-02)*S70+6.147653e-03*S71+8.300239e-02*S72+(-4.801546e-02)*S73+4.035918e-02*S74+(-6.633049e-02)*S75+5.241236e-01*S76+(-3.586732e-01)*S77+(-1.497200e-01)*S78+(-7.569535e-01)*S79'
.param V76='V76_part8+(-2.839013e-01)*S80+(-1.674776e-01)*S81+(-4.701173e-01)*S82+(-1.532417e-01)*S83+(-3.901440e-01)*S84+(-1.096994e-01)*S85+(-1.915142e-01)*S86+(-1.015949e-01)*S87+(-4.475037e-02)*S88+(-6.115814e-03)*S89'
.param V77_part1='2.515259e+03*S0+(-1.165618e+00)*S1+1.097217e+01*S2+(-4.370882e+02)*S3+(-1.313310e+02)*S4+2.460286e+02*S5+(-1.000000e+04)*S6+1.000000e+04*S7+1.000000e+04*S8+3.806233e+03*S9'
.param V77_part2='V77_part1+1.000000e+04*S10+7.913828e+02*S11+(-4.612566e+01)*S12+7.434259e+01*S13+7.352258e+03*S14+7.933498e+01*S15+(-3.361721e+01)*S16+4.517237e+02*S17+2.484728e+01*S18+(-5.658489e+01)*S19'
.param V77_part3='V77_part2+(-9.541506e+01)*S20+(-2.372961e+00)*S21+(-7.531433e+01)*S22+(-1.803635e+01)*S23+8.009382e-01*S24+(-1.162619e+02)*S25+(-1.068479e+01)*S26+5.188329e-01*S27+(-4.438652e+00)*S28+(-7.162943e+00)*S29'
.param V77_part4='V77_part3+5.225302e-01*S30+3.687208e-02*S31+6.553844e-02*S32+7.572380e-01*S33+1.461252e+00*S34+(-1.503843e-01)*S35+1.225262e-01*S36+8.574552e-01*S37+(-1.041912e-01)*S38+3.418527e-01*S39'
.param V77_part5='V77_part4+3.656444e-01*S40+(-2.733704e-01)*S41+3.758251e-01*S42+1.916703e-01*S43+(-3.249452e-01)*S44+1.641039e+00*S45+2.459502e+00*S46+(-5.535946e-01)*S47+1.595470e+00*S48+7.479377e-01*S49'
.param V77_part6='V77_part5+(-2.251612e-02)*S50+1.392343e+00*S51+2.058662e-01*S52+(-2.609557e-01)*S53+5.920204e-01*S54+1.165825e-01*S55+(-1.093598e-01)*S56+5.036821e-01*S57+7.839169e-01*S58+(-2.742939e-02)*S59'
.param V77_part7='V77_part6+3.932997e-01*S60+1.604521e+00*S61+(-2.766667e-01)*S62+4.557942e-01*S63+1.610105e-01*S64+(-8.731688e-02)*S65+6.624215e-01*S66+1.151965e-01*S67+(-2.388372e-02)*S68+2.288497e-01*S69'
.param V77_part8='V77_part7+1.032574e-01*S70+7.735998e-02*S71+4.284744e-01*S72+8.580613e-02*S73+8.006160e-02*S74+1.593301e+00*S75+1.272358e+00*S76+1.935944e-02*S77+3.917255e-01*S78+5.020878e-01*S79'
.param V77='V77_part8+(-4.278179e-02)*S80+7.096278e-01*S81+7.080160e-01*S82+1.807335e-01*S83+5.848153e-01*S84+5.325093e-01*S85+3.111682e-01*S86+3.375531e-01*S87+2.752307e-01*S88+6.543627e-02*S89'
.param V78_part1='(-4.448982e+01)*S0+3.950297e+02*S1+3.053971e+03*S2+9.563856e+00*S3+4.242053e+02*S4+(-1.848137e+02)*S5+7.740916e+03*S6+9.397430e+03*S7+1.000000e+04*S8+(-1.911118e+03)*S9'
.param V78_part2='V78_part1+4.036774e+02*S10+(-1.297123e+01)*S11+(-5.717707e+02)*S12+4.805584e+01*S13+4.431119e+03*S14+(-6.799581e+01)*S15+1.000000e+04*S16+1.555030e+01*S17+(-5.919801e+01)*S18+(-2.947993e+03)*S19'
.param V78_part3='V78_part2+(-1.435946e+03)*S20+(-9.521315e-02)*S21+(-1.170859e+00)*S22+(-7.526536e-01)*S23+1.089812e-01*S24+(-2.342110e+03)*S25+(-5.567596e-01)*S26+5.678311e-02*S27+1.483619e-01*S28+(-6.350986e-01)*S29'
.param V78_part4='V78_part3+1.381513e-01*S30+(-7.351170e-02)*S31+(-1.556547e-01)*S32+3.834870e-02*S33+1.656672e-01*S34+3.994716e-02*S35+(-1.595496e-03)*S36+1.619313e-01*S37+6.908053e-02*S38+1.526535e-02*S39'
.param V78_part5='V78_part4+7.832528e-02*S40+4.445161e-02*S41+1.694366e-02*S42+4.713377e-02*S43+5.092577e-02*S44+9.160569e-02*S45+3.889363e-01*S46+4.171305e-02*S47+1.063981e-01*S48+9.380887e-02*S49'
.param V78_part6='V78_part5+5.585209e-02*S50+1.600503e-01*S51+3.178721e-02*S52+4.360926e-03*S53+5.633692e-02*S54+3.247849e-02*S55+2.013225e-02*S56+3.769765e-02*S57+1.101474e-01*S58+1.841936e-02*S59'
.param V78_part7='V78_part6+1.425393e-02*S60+7.375729e-02*S61+3.912923e-02*S62+2.020897e-02*S63+1.813426e-02*S64+5.195691e-03*S65+4.364670e-02*S66+1.375674e-02*S67+5.362039e-03*S68+1.063278e-02*S69'
.param V78_part8='V78_part7+1.009139e-02*S70+1.668820e-02*S71+4.823472e-02*S72+7.155461e-03*S73+1.802854e-02*S74+1.063357e-01*S75+5.487212e-02*S76+4.139523e-02*S77+6.398017e-03*S78+1.294438e-01*S79'
.param V78='V78_part8+3.613200e-02*S80+7.541850e-02*S81+1.006300e-01*S82+4.693356e-02*S83+6.687095e-02*S84+9.960602e-02*S85+6.540326e-02*S86+3.165901e-02*S87+6.941262e-02*S88+1.048369e-02*S89'
.param V79_part1='(-1.013550e+01)*S0+(-9.983887e+00)*S1+(-4.314025e+00)*S2+2.841220e+01*S3+(-6.265277e-01)*S4+4.325272e+02*S5+4.765931e+03*S6+9.999998e+03*S7+1.000000e+04*S8+1.000000e+04*S9'
.param V79_part2='V79_part1+1.000000e+04*S10+4.652337e+03*S11+1.756944e+00*S12+1.061091e+02*S13+1.939079e+03*S14+1.855262e+00*S15+(-2.192947e+01)*S16+5.574473e+02*S17+(-2.774284e+00)*S18+1.804521e+01*S19'
.param V79_part3='V79_part2+3.752151e+00*S20+6.447525e-01*S21+3.100074e+02*S22+1.700811e+01*S23+2.527233e+01*S24+7.819576e+01*S25+1.131584e+01*S26+7.020051e+00*S27+9.159710e+00*S28+1.815639e+00*S29'
.param V79_part4='V79_part3+2.004153e+01*S30+8.562301e-02*S31+(-6.793556e+00)*S32+1.338169e+02*S33+6.834030e+00*S34+2.101297e+00*S35+4.929465e+00*S36+3.288240e+00*S37+5.899553e-01*S38+4.599383e-02*S39'
.param V79_part5='V79_part4+1.601555e+00*S40+4.517847e-01*S41+5.524477e-02*S42+1.056983e+00*S43+3.412021e-01*S44+6.407538e+03*S45+1.848441e+01*S46+4.768456e-01*S47+1.000000e+04*S48+3.028230e+00*S49'
.param V79_part6='V79_part5+4.879827e-01*S50+2.032416e+02*S51+1.123116e+00*S52+1.363209e-01*S53+(-6.036759e-02)*S54+1.318856e+00*S55+1.195325e-01*S56+(-5.377202e-02)*S57+4.184994e+00*S58+8.197277e-02*S59'
.param V79_part7='V79_part6+2.621187e-02*S60+(-3.356803e+00)*S61+3.611100e-01*S62+3.743079e-02*S63+4.411214e-02*S64+8.958593e-02*S65+(-7.617380e-03)*S66+4.330296e-02*S67+4.955694e-02*S68+3.122682e-02*S69'
.param V79_part8='V79_part7+4.350566e-02*S70+3.924105e-02*S71+(-7.774046e-02)*S72+4.160203e-02*S73+2.354722e-02*S74+1.434580e+02*S75+(-3.133900e+00)*S76+7.680566e-01*S77+6.611130e+00*S78+8.074187e+00*S79'
.param V79='V79_part8+1.378310e+00*S80+4.489190e+02*S81+1.312610e+01*S82+1.605587e+00*S83+1.172510e+02*S84+1.288626e+01*S85+2.589094e+00*S86+2.190703e+02*S87+1.399029e+01*S88+8.014669e-03*S89'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+3.354374e-02*S2+0.000000e+00*S3+(-5.433499e-02)*S4+(-4.070647e-02)*S5+(-3.321322e-02)*S6+(-4.114353e-02)*S7+(-3.717319e-02)*S8+1.560135e-02*S9'
.param V80_part2='V80_part1+(-2.290715e-02)*S10+7.817157e-02*S11+6.535691e-02*S12+8.423900e-02*S13+4.998797e-04*S14+(-2.422344e-01)*S15+(-1.957747e-01)*S16+(-3.828890e-01)*S17+(-1.320914e-01)*S18+(-2.569504e-01)*S19'
.param V80_part3='V80_part2+(-4.248565e-01)*S20+5.882422e-01*S21+(-2.347628e-01)*S22+(-1.553027e-01)*S23+8.762698e-01*S24+(-2.174943e-02)*S25+(-3.121669e-01)*S26+6.263487e-01*S27+4.557842e-01*S28+(-8.285643e-02)*S29'
.param V80_part4='V80_part3+3.019770e-01*S30+1.826898e-01*S31+(-9.486702e-02)*S32+3.418265e-01*S33+8.345765e-01*S34+1.274145e+00*S35+2.560149e+00*S36+1.173650e+00*S37+2.656086e+00*S38+0.000000e+00*S39'
.param V80_part5='V80_part4+2.617383e+00*S40+2.950408e+00*S41+0.000000e+00*S42+3.504711e+00*S43+3.683199e+00*S44+5.163164e-01*S45+3.202442e-01*S46+1.411650e+00*S47+4.456794e-01*S48+2.092224e+00*S49'
.param V80_part6='V80_part5+3.098683e+00*S50+5.689305e-01*S51+4.807993e+00*S52+4.855565e+00*S53+0.000000e+00*S54+5.102950e+00*S55+6.618473e+00*S56+0.000000e+00*S57+1.703151e+00*S58+1.684346e+01*S59'
.param V80_part7='V80_part6+0.000000e+00*S60+7.119098e-01*S61+1.455765e+00*S62+0.000000e+00*S63+0.000000e+00*S64+8.280635e+00*S65+0.000000e+00*S66+0.000000e+00*S67+2.531827e+01*S68+0.000000e+00*S69'
.param V80_part8='V80_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.452964e-01*S75+1.547436e-01*S76+4.199693e+00*S77+2.820952e+00*S78+8.664243e-01*S79'
.param V80='V80_part8+3.512187e+00*S80+(-8.029228e-01)*S81+3.591434e-01*S82+4.608514e+00*S83+(-1.435230e+00)*S84+8.363248e-01*S85+5.637888e+00*S86+(-1.711082e+00)*S87+7.572327e-01*S88+0.000000e+00*S89'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.093779e-03)*S2+0.000000e+00*S3+1.010273e-01*S4+8.361613e-02*S5+1.090703e-01*S6+7.832071e-02*S7+1.006262e-01*S8+7.359665e-02*S9'
.param V81_part2='V81_part1+9.143675e-02*S10+6.832422e-02*S11+6.506240e-02*S12+2.157748e-02*S13+1.198372e-01*S14+8.519063e-01*S15+7.557298e-01*S16+1.460934e+00*S17+7.086356e-01*S18+1.020186e+00*S19'
.param V81_part3='V81_part2+1.155688e+00*S20+3.074821e+00*S21+9.438272e-01*S22+6.440271e-01*S23+6.104134e-01*S24+6.484961e-01*S25+8.146364e-01*S26+1.115057e+00*S27+5.899426e-01*S28+7.662991e-01*S29'
.param V81_part4='V81_part3+1.041729e+00*S30+1.865833e+00*S31+2.058138e+00*S32+5.520444e-01*S33+9.242895e-01*S34+1.718441e+00*S35+1.794393e+00*S36+1.614322e+00*S37+3.052942e+00*S38+0.000000e+00*S39'
.param V81_part5='V81_part4+2.401180e+00*S40+2.781548e+00*S41+0.000000e+00*S42+2.790359e+00*S43+2.830220e+00*S44+2.249873e-01*S45+1.563530e+00*S46+8.045890e+00*S47+8.028879e-01*S48+2.708398e+00*S49'
.param V81_part6='V81_part5+7.782664e+00*S50+8.913138e-01*S51+5.134908e+00*S52+7.643159e+00*S53+0.000000e+00*S54+5.121516e+00*S55+8.474085e+00*S56+0.000000e+00*S57+4.586999e+00*S58+3.258273e+00*S59'
.param V81_part7='V81_part6+0.000000e+00*S60+6.289924e-02*S61+1.563129e+01*S62+0.000000e+00*S63+0.000000e+00*S64+1.318412e+01*S65+0.000000e+00*S66+0.000000e+00*S67+1.321792e+00*S68+0.000000e+00*S69'
.param V81_part8='V81_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.148249e+00*S75+1.230704e+00*S76+1.942813e+01*S77+8.323445e+00*S78+6.925597e+00*S79'
.param V81='V81_part8+1.285499e+01*S80+3.935725e+00*S81+7.377356e+00*S82+1.569054e+01*S83+5.851334e+00*S84+8.064258e+00*S85+1.292273e+01*S86+4.950626e+00*S87+8.632420e+00*S88+0.000000e+00*S89'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+(-1.780876e-02)*S2+0.000000e+00*S3+4.542268e-02*S4+5.021787e-02*S5+(-1.578545e-02)*S6+3.964432e-02*S7+4.601744e-02*S8+(-7.409828e-02)*S9'
.param V82_part2='V82_part1+3.051800e-02*S10+(-2.063795e-02)*S11+(-7.250556e-03)*S12+(-4.374965e-03)*S13+5.953299e-02*S14+5.463852e-01*S15+3.352525e-01*S16+5.048392e-01*S17+5.832195e-01*S18+5.830401e-01*S19'
.param V82_part3='V82_part2+8.237947e-01*S20+6.219635e-01*S21+1.004290e+00*S22+8.895597e-01*S23+(-3.855451e-01)*S24+8.757285e-01*S25+1.049445e+00*S26+(-1.242656e-01)*S27+7.085035e-01*S28+1.197605e+00*S29'
.param V82_part4='V82_part3+2.562432e-01*S30+1.064833e+00*S31+9.337903e-01*S32+3.669820e-01*S33+(-7.942210e-04)*S34+1.746215e-01*S35+9.013225e-01*S36+(-4.093882e-04)*S37+1.464839e+00*S38+0.000000e+00*S39'
.param V82_part5='V82_part4+5.139452e-01*S40+1.812239e+00*S41+0.000000e+00*S42+1.142941e+00*S43+1.314464e+00*S44+3.692332e-02*S45+3.005904e-01*S46+3.477433e+00*S47+1.251774e-02*S48+(-3.126543e-02)*S49'
.param V82_part6='V82_part5+2.937335e+00*S50+1.436873e-02*S51+2.184236e+00*S52+2.305027e+00*S53+0.000000e+00*S54+3.035855e+00*S55+4.986088e-01*S56+0.000000e+00*S57+(-1.115591e+00)*S58+(-5.261032e+00)*S59'
.param V82_part7='V82_part6+0.000000e+00*S60+(-1.360532e+00)*S61+6.510377e+00*S62+0.000000e+00*S63+0.000000e+00*S64+2.484034e+00*S65+0.000000e+00*S66+0.000000e+00*S67+(-4.449288e+00)*S68+0.000000e+00*S69'
.param V82_part8='V82_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.020264e+00*S75+(-1.067929e+00)*S76+1.048727e+01*S77+1.117300e+00*S78+2.476933e+00*S79'
.param V82='V82_part8+8.120869e+00*S80+2.318404e+00*S81+1.985817e+00*S82+8.136387e+00*S83+2.610746e+00*S84+2.127350e+00*S85+5.020183e+00*S86+2.387627e+00*S87+3.613177e+00*S88+0.000000e+00*S89'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+3.489270e-02*S2+0.000000e+00*S3+1.575972e-02*S4+6.892686e-02*S5+8.264906e-02*S6+5.780937e-02*S7+7.886618e-02*S8+8.287674e-02*S9'
.param V83_part2='V83_part1+6.861764e-02*S10+9.565329e-02*S11+5.897820e-02*S12+8.480736e-02*S13+5.571331e-02*S14+1.644461e-01*S15+(-9.140770e-05)*S16+9.186600e-02*S17+1.469164e-01*S18+3.709279e-02*S19'
.param V83_part3='V83_part2+8.880291e-02*S20+(-2.256344e-02)*S21+8.436045e-02*S22+7.111601e-02*S23+(-3.515033e-01)*S24+1.229636e-01*S25+9.588736e-02*S26+(-1.306906e-01)*S27+1.343278e-02*S28+2.934502e-02*S29'
.param V83_part4='V83_part3+(-6.052521e-02)*S30+(-2.597348e-02)*S31+(-4.822751e-02)*S32+(-6.392901e-02)*S33+(-1.434614e-01)*S34+(-2.492893e-01)*S35+(-2.648378e-02)*S36+(-2.472299e-01)*S37+(-4.108470e-01)*S38+0.000000e+00*S39'
.param V83_part5='V83_part4+(-3.889815e-01)*S40+(-5.417630e-01)*S41+0.000000e+00*S42+(-4.175000e-01)*S43+(-5.349356e-01)*S44+(-7.615770e-02)*S45+(-1.744280e-01)*S46+(-4.324520e-01)*S47+(-1.268734e-01)*S48+(-2.911428e-01)*S49'
.param V83_part6='V83_part5+(-6.340663e-01)*S50+(-2.915610e-01)*S51+(-3.115112e-01)*S52+(-1.214420e+00)*S53+0.000000e+00*S54+(-4.158551e-01)*S55+(-1.465545e+00)*S56+0.000000e+00*S57+(-5.731927e-01)*S58+(-1.598897e+00)*S59'
.param V83_part7='V83_part6+0.000000e+00*S60+(-1.950386e-01)*S61+(-7.952459e-01)*S62+0.000000e+00*S63+0.000000e+00*S64+(-1.671723e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-3.300918e+00)*S68+0.000000e+00*S69'
.param V83_part8='V83_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.632825e-01)*S75+(-1.700800e-01)*S76+(-9.831742e-01)*S77+(-1.478433e-01)*S78+(-5.474553e-01)*S79'
.param V83='V83_part8+(-1.009925e+00)*S80+(-3.283229e-01)*S81+(-6.280863e-01)*S82+(-1.426168e+00)*S83+(-5.285231e-01)*S84+(-1.176250e+00)*S85+(-1.214552e+00)*S86+(-6.203137e-01)*S87+(-1.190757e+00)*S88+0.000000e+00*S89'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+(-4.869281e-04)*S2+0.000000e+00*S3+2.414179e-04*S4+1.768567e-03*S5+(-4.631244e-04)*S6+1.558506e-03*S7+(-1.330799e-03)*S8+2.399593e-04*S9'
.param V84_part2='V84_part1+1.156456e-03*S10+(-1.327066e-03)*S11+(-7.018404e-03)*S12+(-1.703349e-03)*S13+(-8.407008e-04)*S14+2.576957e-02*S15+1.052326e-02*S16+(-2.229037e-01)*S17+1.225620e-02*S18+(-8.424873e-02)*S19'
.param V84_part3='V84_part2+(-3.058724e-01)*S20+(-8.970652e-01)*S21+(-2.375480e-01)*S22+(-2.469558e-01)*S23+(-1.172446e-01)*S24+(-2.992162e-01)*S25+(-3.235943e-01)*S26+(-4.453587e-01)*S27+(-3.653963e-01)*S28+(-4.408014e-01)*S29'
.param V84_part4='V84_part3+(-1.081290e-01)*S30+(-2.464255e-01)*S31+(-9.856183e-02)*S32+4.445404e-02*S33+(-2.765537e-01)*S34+(-6.649214e-01)*S35+(-1.510969e+00)*S36+(-6.270116e-01)*S37+(-1.801872e+00)*S38+0.000000e+00*S39'
.param V84_part5='V84_part4+(-1.925108e+00)*S40+(-2.042095e+00)*S41+0.000000e+00*S42+(-2.335901e+00)*S43+(-2.290935e+00)*S44+(-1.386582e-01)*S45+(-9.432873e-02)*S46+(-1.949835e+00)*S47+(-1.502413e-01)*S48+(-1.244828e+00)*S49'
.param V84_part6='V84_part5+(-2.689090e+00)*S50+(-1.324030e-01)*S51+(-3.217315e+00)*S52+(-3.448820e+00)*S53+0.000000e+00*S54+(-3.759568e+00)*S55+(-4.258488e+00)*S56+0.000000e+00*S57+(-1.879022e+00)*S58+(-5.456778e+00)*S59'
.param V84_part7='V84_part6+0.000000e+00*S60+1.818653e+00*S61+(-2.847814e+00)*S62+0.000000e+00*S63+0.000000e+00*S64+(-4.646885e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-1.004099e+01)*S68+0.000000e+00*S69'
.param V84_part8='V84_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.119977e-01)*S75+2.962480e+00*S76+(-5.224862e+00)*S77+(-2.690219e+00)*S78+(-1.577278e+00)*S79'
.param V84='V84_part8+(-5.859123e+00)*S80+6.781082e-02*S81+(-1.375234e+00)*S82+(-7.701570e+00)*S83+(-6.540831e-01)*S84+(-1.960648e+00)*S85+(-5.667323e+00)*S86+8.023934e-01*S87+(-2.666397e+00)*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-09*_P2'
.param _P4='1e-09*_P2'
.param _P5='V5+V6*rad_+V7/w_'
.param _P6='_P5+V8*gdis_+V9*spacing_'
.param _P7='0.5*(_P6+sqrt(_P6*_P6+0.001))'
.param _P8='V10+V11*rad_+V12*w_'
.param _P9='_P8+V13*gdis_+V14*spacing_'
.param _P10='0.5*(_P9+sqrt(_P9*_P9+0.001))'
.param _P11='1e-09*_P10'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='1e-09*_P14'
.param _P16='V20+V21*rad_+V22*w_'
.param _P17='_P16+V23*gdis_+V24*spacing_'
.param _P18='0.5*(_P17+sqrt(_P17*_P17+0.001))'
.param _P19='1e-09*_P18'
.param _P20='1e-09*_P18'
.param _P21='V25+V26*rad_+V27/w_'
.param _P22='_P21+V28*gdis_+V29*spacing_'
.param _P23='0.5*(_P22+sqrt(_P22*_P22+0.001))'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='1e-09*_P26'
.param _P28='V35+V36*rad_+V37/w_'
.param _P29='_P28+V38*gdis_+V39*spacing_'
.param _P30='0.5*(_P29+sqrt(_P29*_P29+0.001))'
.param _P31='1e-09*_P30'
.param _P32='V40+V41*rad_+V42*w_'
.param _P33='_P32+V43*gdis_+V44*spacing_'
.param _P34='atan(_P33-0.5)/1.5708'
.param _P35='V45+V46*rad_+V47*w_'
.param _P36='_P35+V48*gdis_+V49*spacing_'
.param _P37='atan(_P36-0.5)/1.5708'
.param _P38='0.5*_P34+0.5*_P37'
.param _P39='0.5*_P34-0.5*_P37'
.param _P40='V50+V51*rad_+V52*w_'
.param _P41='_P40+V53*gdis_+V54*spacing_'
.param _P42='0.5*(_P41+sqrt(_P41*_P41+0.001))'
.param _P43='1e-09*_P42'
.param _P44='1e-09*_P42'
.param _P45='1e-06'
.param _P46='V55+V56*rad_+V57*w_'
.param _P47='_P46+V58*gdis_+V59*spacing_'
.param _P48='0.5*(_P47+sqrt(_P47*_P47+0.001))'
.param _P49='1e-15*_P48'
.param _P50='V60+V61*rad_+V62*w_'
.param _P51='_P50+V63*gdis_+V64*spacing_'
.param _P52='0.5*(_P51+sqrt(_P51*_P51+0.001))'
.param _P53='V65+V66*rad_+V67*w_'
.param _P54='_P53+V68*gdis_+V69*spacing_'
.param _P55='0.5*(_P54+sqrt(_P54*_P54+0.001))'
.param _P56='V70+V71*rad_+V72*w_'
.param _P57='_P56+V73*gdis_+V74*spacing_'
.param _P58='0.5*(_P57+sqrt(_P57*_P57+0.001))'
.param _P59='1e-14*_P52'
.param _P60='100*_P55'
.param _P61='1e-15*_P58'
.param _P62='1e-14*_P52'
.param _P63='100*_P55'
.param _P64='1e-15*_P58'
.param _P65='V75+V76*rad_+V77*w_'
.param _P66='_P65+V78*gdis_+V79*spacing_'
.param _P67='0.5*(_P66+sqrt(_P66*_P66+0.001))'
.param _P68='V80+V81*rad_+V82*w_'
.param _P69='_P68+V83*gdis_+V84*spacing_'
.param _P70='0.5*(_P69+sqrt(_P69*_P69+0.001))'
.param _P71='100*_P67'
.param _P72='1e-13*_P70'
l1_sect1 top _n1i_sect1 '_P3* l_indfac'
l2_sect1 _n2i_sect1 bottom '_P4* l_indfac'
r1_sect1 _n1i_sect1 _n_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect1 _n_sect1 _n2i_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect1 _nc_sect1 tap '_P11* l_indfac'
rc_sect1 _n_sect1 _nc_sect1 '(_P15+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
l1_sect2 top _n1i_sect2 '_P19* l_indfac'
l2_sect2 _n2i_sect2 bottom '_P20* l_indfac'
r1_sect2 _n1i_sect2 _n_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect2 _n_sect2 _n2i_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect2 _nc_sect2 tap '_P27* l_indfac'
rc_sect2 _n_sect2 _nc_sect2 '(_P31+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
k12_sect1 l1_sect1 l2_sect1 K=_P38
k12_sect2 l1_sect2 l2_sect2 K=_P38
ks1s2_1 l1_sect1 l1_sect2 K=_P39
ks1s2_2 l2_sect1 l2_sect2 K=_P39
lx1 _n1i_sect1 _nx1 '_P43* l_indfac'
lx2 _n2i_sect1 _nx2 '_P44* l_indfac'
rx1 _nx1 _n1i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
rx2 _nx2 _n2i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
c12 top bottom '_P49*c12_indfac'
c_1_sub top _n1_1_sub '_P59*((1/(12.503905+(1.7014125)*(lay-3-(lay-9)/4*3)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P60*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P61* csub_indfac'
c_2_sub bottom _n1_2_sub '_P62*((1/(12.503905+(1.7014125)*(lay-3-(lay-9)/4*3)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P63*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P64* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P71*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P72* csub_indfac'
kzero1 l1_sect1 l2_sect2 K=1e-6
kzero2 l1_sect2 l2_sect1 K=1e-6
.ends spiral_sym_ct_mu_z
*
.subckt spiral_std_mza_a top bottom gnode rad=6e-05 w=9e-06 nr=0.5 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T177='(1-abs(sgn(nr-(0.5))))'
.param T178='(min(sgn(rad_-(0.3335))+1,1))'
.param T179='(min(sgn(w_-(0.4002))+1,1))'
.param T180='(min(sgn(w_-(0.3998))+1,1))'
.param T181='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T182='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T183='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T184='(min(sgn(rad_-(0.377933))+1,1))'
.param T185='(min(sgn(rad_-(0.333167))+1,1))'
.param T186='(min(sgn(rad_-(0.500167))+1,1))'
.param T187='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T188='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T189='(min(sgn(rad_-(0.377622))+1,1))'
.param T190='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T191='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T192='(min(sgn(rad_-(0.533489))+1,1))'
.param T193='(min(sgn(rad_-(0.499833))+1,1))'
.param T194='(min(sgn(rad_-(0.666833))+1,1))'
.param T195='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T196='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T197='(min(sgn(rad_-(0.533178))+1,1))'
.param T198='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T199='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T200='(min(sgn(rad_-(0.689044))+1,1))'
.param T201='(min(sgn(rad_-(0.6665))+1,1))'
.param T202='(min(sgn(rad_-(0.8335))+1,1))'
.param T203='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T204='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T205='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T206='(min(sgn(rad_-(0.8446))+1,1))'
.param T207='(min(sgn(rad_-(0.688733))+1,1))'
.param T208='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T209='(min(sgn(rad_-(0.833167))+1,1))'
.param T210='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T211='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T212='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T213='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T214='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T215='(min(sgn(rad_-(0.844289))+1,1))'
.param T216='(1-abs(sgn(nr-(0.75))))'
.param T217='(1-abs(sgn(nr-(1.25))))'
.param T218='(1-abs(sgn(nr-(1.5))))'
.param T219='(1-abs(sgn(nr-(1.75))))'
.param T220='(1-abs(sgn(nr-(1))))'
.param T221='(1-abs(sgn(nr-(2.25))))'
.param T222='(1-abs(sgn(nr-(2.5))))'
.param T223='(1-abs(sgn(nr-(2.75))))'
.param T224='(1-abs(sgn(nr-(2))))'
.param T225='(1-abs(sgn(nr-(3.25))))'
.param T226='(1-abs(sgn(nr-(3.5))))'
.param T227='(1-abs(sgn(nr-(3.75))))'
.param T228='(1-abs(sgn(nr-(3))))'
.param T229='(1-abs(sgn(nr-(4.25))))'
.param T230='(1-abs(sgn(nr-(4.5))))'
.param T231='(1-abs(sgn(nr-(4.75))))'
.param T232='(1-abs(sgn(nr-(4))))'
.param T233='(1-abs(sgn(nr-(5.25))))'
.param T234='(1-abs(sgn(nr-(5.5))))'
.param T235='(1-abs(sgn(nr-(5))))'
.param S0='T177*(1-T178)*(1-T179)'
.param noS0='(1-S0)'
.param S1='T177*T180*(1-T178)*(1-T181)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T177*T182*T183*(1-T184)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T177*(1-T179)*T185*(1-T186)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T177*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T177*T189*T190*T191*(1-T192)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T177*(1-T179)*T193*(1-T194)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T177*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T177*T197*T198*T199*(1-T200)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T177*(1-T179)*T201*(1-T202)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T177*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T177*T205*(1-T206)*T207*T208*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T177*(1-T179)*T209*(1-T210)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T177*T209*T180*(1-T211)*(1-T212)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T177*T213*T214*T215*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T216*(1-T178)*(1-T179)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T216*T180*(1-T178)*(1-T181)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T216*T182*T183*(1-T184)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T216*(1-T179)*T185*(1-T186)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T216*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T216*T189*T190*T191*(1-T192)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T216*(1-T179)*T193*(1-T194)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T216*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T216*T197*T198*T199*(1-T200)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T216*(1-T179)*T201*(1-T202)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T216*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T216*T205*(1-T206)*T207*T208*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T216*(1-T179)*T209*(1-T210)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T216*T209*T180*(1-T211)*(1-T212)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T216*T213*T214*T215*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T217*(1-T178)*(1-T179)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T217*T180*(1-T178)*(1-T181)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T217*T182*T183*(1-T184)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T217*(1-T179)*T185*(1-T186)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T217*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T217*T189*T190*T191*(1-T192)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T217*(1-T179)*T193*(1-T194)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T217*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T217*T197*T198*T199*(1-T200)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T217*(1-T179)*T201*(1-T202)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T217*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T217*T205*(1-T206)*T207*T208*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T217*(1-T179)*T209*(1-T210)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T217*T209*T180*(1-T211)*(1-T212)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T217*T213*T214*T215*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T218*(1-T178)*(1-T179)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T218*T180*(1-T178)*(1-T181)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T218*T182*T183*(1-T184)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T218*(1-T179)*T185*(1-T186)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T218*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T218*T189*T190*T191*(1-T192)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T218*(1-T179)*T193*(1-T194)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T218*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T218*T197*T198*T199*(1-T200)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T218*(1-T179)*T201*(1-T202)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T218*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T218*T205*(1-T206)*T207*T208*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T218*(1-T179)*T209*(1-T210)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T218*T209*T180*(1-T211)*(1-T212)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T218*T213*T214*T215*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T219*(1-T178)*(1-T179)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T219*T180*(1-T178)*(1-T181)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T219*T182*T183*(1-T184)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T219*(1-T179)*T185*(1-T186)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T219*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T219*T189*T190*T191*(1-T192)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T219*(1-T179)*T193*(1-T194)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T219*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T219*T197*T198*T199*(1-T200)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T219*(1-T179)*T201*(1-T202)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T219*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T219*T205*(1-T206)*T207*T208*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T219*(1-T179)*T209*(1-T210)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T219*T209*T180*(1-T211)*(1-T212)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T219*T213*T214*T215*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T220*(1-T178)*(1-T179)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T220*T180*(1-T178)*(1-T181)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T220*T182*T183*(1-T184)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T220*(1-T179)*T185*(1-T186)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T220*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T220*T189*T190*T191*(1-T192)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T220*(1-T179)*T193*(1-T194)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T220*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T220*T197*T198*T199*(1-T200)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T220*(1-T179)*T201*(1-T202)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T220*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T220*T205*(1-T206)*T207*T208*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T220*(1-T179)*T209*(1-T210)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T220*T209*T180*(1-T211)*(1-T212)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T220*T213*T214*T215*noS88'
.param noS89='(1-S89)*noS88'
.param S90='T221*(1-T178)*(1-T179)*noS89'
.param noS90='(1-S90)*noS89'
.param S91='T221*T180*(1-T178)*(1-T181)*noS90'
.param noS91='(1-S91)*noS90'
.param S92='T221*T182*T183*(1-T184)*noS91'
.param noS92='(1-S92)*noS91'
.param S93='T221*(1-T179)*T185*(1-T186)*noS92'
.param noS93='(1-S93)*noS92'
.param S94='T221*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS93'
.param noS94='(1-S94)*noS93'
.param S95='T221*T189*T190*T191*(1-T192)*noS94'
.param noS95='(1-S95)*noS94'
.param S96='T221*(1-T179)*T193*(1-T194)*noS95'
.param noS96='(1-S96)*noS95'
.param S97='T221*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS96'
.param noS97='(1-S97)*noS96'
.param S98='T221*T197*T198*T199*(1-T200)*noS97'
.param noS98='(1-S98)*noS97'
.param S99='T221*(1-T179)*T201*(1-T202)*noS98'
.param noS99='(1-S99)*noS98'
.param S100='T221*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS99'
.param noS100='(1-S100)*noS99'
.param S101='T221*T205*(1-T206)*T207*T208*noS100'
.param noS101='(1-S101)*noS100'
.param S102='T221*(1-T179)*T209*(1-T210)*noS101'
.param noS102='(1-S102)*noS101'
.param S103='T221*T209*T180*(1-T211)*(1-T212)*noS102'
.param noS103='(1-S103)*noS102'
.param S104='T221*T213*T214*T215*noS103'
.param noS104='(1-S104)*noS103'
.param S105='T222*(1-T178)*(1-T179)*noS104'
.param noS105='(1-S105)*noS104'
.param S106='T222*T180*(1-T178)*(1-T181)*noS105'
.param noS106='(1-S106)*noS105'
.param S107='T222*T182*T183*(1-T184)*noS106'
.param noS107='(1-S107)*noS106'
.param S108='T222*(1-T179)*T185*(1-T186)*noS107'
.param noS108='(1-S108)*noS107'
.param S109='T222*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS108'
.param noS109='(1-S109)*noS108'
.param S110='T222*T189*T190*T191*(1-T192)*noS109'
.param noS110='(1-S110)*noS109'
.param S111='T222*(1-T179)*T193*(1-T194)*noS110'
.param noS111='(1-S111)*noS110'
.param S112='T222*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS111'
.param noS112='(1-S112)*noS111'
.param S113='T222*T197*T198*T199*(1-T200)*noS112'
.param noS113='(1-S113)*noS112'
.param S114='T222*(1-T179)*T201*(1-T202)*noS113'
.param noS114='(1-S114)*noS113'
.param S115='T222*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS114'
.param noS115='(1-S115)*noS114'
.param S116='T222*T205*(1-T206)*T207*T208*noS115'
.param noS116='(1-S116)*noS115'
.param S117='T222*(1-T179)*T209*(1-T210)*noS116'
.param noS117='(1-S117)*noS116'
.param S118='T222*T209*T180*(1-T211)*(1-T212)*noS117'
.param noS118='(1-S118)*noS117'
.param S119='T222*T213*T214*T215*noS118'
.param noS119='(1-S119)*noS118'
.param S120='T223*(1-T178)*(1-T179)*noS119'
.param noS120='(1-S120)*noS119'
.param S121='T223*T180*(1-T178)*(1-T181)*noS120'
.param noS121='(1-S121)*noS120'
.param S122='T223*T182*T183*(1-T184)*noS121'
.param noS122='(1-S122)*noS121'
.param S123='T223*(1-T179)*T185*(1-T186)*noS122'
.param noS123='(1-S123)*noS122'
.param S124='T223*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS123'
.param noS124='(1-S124)*noS123'
.param S125='T223*T189*T190*T191*(1-T192)*noS124'
.param noS125='(1-S125)*noS124'
.param S126='T223*(1-T179)*T193*(1-T194)*noS125'
.param noS126='(1-S126)*noS125'
.param S127='T223*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS126'
.param noS127='(1-S127)*noS126'
.param S128='T223*T197*T198*T199*(1-T200)*noS127'
.param noS128='(1-S128)*noS127'
.param S129='T223*(1-T179)*T201*(1-T202)*noS128'
.param noS129='(1-S129)*noS128'
.param S130='T223*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS129'
.param noS130='(1-S130)*noS129'
.param S131='T223*T205*(1-T206)*T207*T208*noS130'
.param noS131='(1-S131)*noS130'
.param S132='T223*(1-T179)*T209*(1-T210)*noS131'
.param noS132='(1-S132)*noS131'
.param S133='T223*T209*T180*(1-T211)*(1-T212)*noS132'
.param noS133='(1-S133)*noS132'
.param S134='T223*T213*T214*T215*noS133'
.param noS134='(1-S134)*noS133'
.param S135='T224*(1-T178)*(1-T179)*noS134'
.param noS135='(1-S135)*noS134'
.param S136='T224*T180*(1-T178)*(1-T181)*noS135'
.param noS136='(1-S136)*noS135'
.param S137='T224*T182*T183*(1-T184)*noS136'
.param noS137='(1-S137)*noS136'
.param S138='T224*(1-T179)*T185*(1-T186)*noS137'
.param noS138='(1-S138)*noS137'
.param S139='T224*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS138'
.param noS139='(1-S139)*noS138'
.param S140='T224*T189*T190*T191*(1-T192)*noS139'
.param noS140='(1-S140)*noS139'
.param S141='T224*(1-T179)*T193*(1-T194)*noS140'
.param noS141='(1-S141)*noS140'
.param S142='T224*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS141'
.param noS142='(1-S142)*noS141'
.param S143='T224*T197*T198*T199*(1-T200)*noS142'
.param noS143='(1-S143)*noS142'
.param S144='T224*(1-T179)*T201*(1-T202)*noS143'
.param noS144='(1-S144)*noS143'
.param S145='T224*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS144'
.param noS145='(1-S145)*noS144'
.param S146='T224*T205*(1-T206)*T207*T208*noS145'
.param noS146='(1-S146)*noS145'
.param S147='T224*(1-T179)*T209*(1-T210)*noS146'
.param noS147='(1-S147)*noS146'
.param S148='T224*T209*T180*(1-T211)*(1-T212)*noS147'
.param noS148='(1-S148)*noS147'
.param S149='T224*T213*T214*T215*noS148'
.param noS149='(1-S149)*noS148'
.param S150='T225*(1-T178)*(1-T179)*noS149'
.param noS150='(1-S150)*noS149'
.param S151='T225*T180*(1-T178)*(1-T181)*noS150'
.param noS151='(1-S151)*noS150'
.param S152='T225*T182*T183*(1-T184)*noS151'
.param noS152='(1-S152)*noS151'
.param S153='T225*(1-T179)*T185*(1-T186)*noS152'
.param noS153='(1-S153)*noS152'
.param S154='T225*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS153'
.param noS154='(1-S154)*noS153'
.param S155='T225*T189*T190*T191*(1-T192)*noS154'
.param noS155='(1-S155)*noS154'
.param S156='T225*(1-T179)*T193*(1-T194)*noS155'
.param noS156='(1-S156)*noS155'
.param S157='T225*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS156'
.param noS157='(1-S157)*noS156'
.param S158='T225*T197*T198*T199*(1-T200)*noS157'
.param noS158='(1-S158)*noS157'
.param S159='T225*(1-T179)*T201*(1-T202)*noS158'
.param noS159='(1-S159)*noS158'
.param S160='T225*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS159'
.param noS160='(1-S160)*noS159'
.param S161='T225*T205*(1-T206)*T207*T208*noS160'
.param noS161='(1-S161)*noS160'
.param S162='T225*(1-T179)*T209*(1-T210)*noS161'
.param noS162='(1-S162)*noS161'
.param S163='T225*T209*T180*(1-T211)*(1-T212)*noS162'
.param noS163='(1-S163)*noS162'
.param S164='T225*T213*T214*T215*noS163'
.param noS164='(1-S164)*noS163'
.param S165='T226*(1-T178)*(1-T179)*noS164'
.param noS165='(1-S165)*noS164'
.param S166='T226*T180*(1-T178)*(1-T181)*noS165'
.param noS166='(1-S166)*noS165'
.param S167='T226*T182*T183*(1-T184)*noS166'
.param noS167='(1-S167)*noS166'
.param S168='T226*(1-T179)*T185*(1-T186)*noS167'
.param noS168='(1-S168)*noS167'
.param S169='T226*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS168'
.param noS169='(1-S169)*noS168'
.param S170='T226*T189*T190*T191*(1-T192)*noS169'
.param noS170='(1-S170)*noS169'
.param S171='T226*(1-T179)*T193*(1-T194)*noS170'
.param noS171='(1-S171)*noS170'
.param S172='T226*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS171'
.param noS172='(1-S172)*noS171'
.param S173='T226*T197*T198*T199*(1-T200)*noS172'
.param noS173='(1-S173)*noS172'
.param S174='T226*(1-T179)*T201*(1-T202)*noS173'
.param noS174='(1-S174)*noS173'
.param S175='T226*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS174'
.param noS175='(1-S175)*noS174'
.param S176='T226*T205*(1-T206)*T207*T208*noS175'
.param noS176='(1-S176)*noS175'
.param S177='T226*(1-T179)*T209*(1-T210)*noS176'
.param noS177='(1-S177)*noS176'
.param S178='T226*T209*T180*(1-T211)*(1-T212)*noS177'
.param noS178='(1-S178)*noS177'
.param S179='T226*T213*T214*T215*noS178'
.param noS179='(1-S179)*noS178'
.param S180='T227*(1-T178)*(1-T179)*noS179'
.param noS180='(1-S180)*noS179'
.param S181='T227*T180*(1-T178)*(1-T181)*noS180'
.param noS181='(1-S181)*noS180'
.param S182='T227*T182*T183*(1-T184)*noS181'
.param noS182='(1-S182)*noS181'
.param S183='T227*(1-T179)*T185*(1-T186)*noS182'
.param noS183='(1-S183)*noS182'
.param S184='T227*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS183'
.param noS184='(1-S184)*noS183'
.param S185='T227*T189*T190*T191*(1-T192)*noS184'
.param noS185='(1-S185)*noS184'
.param S186='T227*(1-T179)*T193*(1-T194)*noS185'
.param noS186='(1-S186)*noS185'
.param S187='T227*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS186'
.param noS187='(1-S187)*noS186'
.param S188='T227*T197*T198*T199*(1-T200)*noS187'
.param noS188='(1-S188)*noS187'
.param S189='T227*(1-T179)*T201*(1-T202)*noS188'
.param noS189='(1-S189)*noS188'
.param S190='T227*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS189'
.param noS190='(1-S190)*noS189'
.param S191='T227*T205*(1-T206)*T207*T208*noS190'
.param noS191='(1-S191)*noS190'
.param S192='T227*(1-T179)*T209*(1-T210)*noS191'
.param noS192='(1-S192)*noS191'
.param S193='T227*T209*T180*(1-T211)*(1-T212)*noS192'
.param noS193='(1-S193)*noS192'
.param S194='T227*T213*T214*T215*noS193'
.param noS194='(1-S194)*noS193'
.param S195='T228*(1-T178)*(1-T179)*noS194'
.param noS195='(1-S195)*noS194'
.param S196='T228*T180*(1-T178)*(1-T181)*noS195'
.param noS196='(1-S196)*noS195'
.param S197='T228*T182*T183*(1-T184)*noS196'
.param noS197='(1-S197)*noS196'
.param S198='T228*(1-T179)*T185*(1-T186)*noS197'
.param noS198='(1-S198)*noS197'
.param S199='T228*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS198'
.param noS199='(1-S199)*noS198'
.param S200='T228*T189*T190*T191*(1-T192)*noS199'
.param noS200='(1-S200)*noS199'
.param S201='T228*(1-T179)*T193*(1-T194)*noS200'
.param noS201='(1-S201)*noS200'
.param S202='T228*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS201'
.param noS202='(1-S202)*noS201'
.param S203='T228*T197*T198*T199*(1-T200)*noS202'
.param noS203='(1-S203)*noS202'
.param S204='T228*(1-T179)*T201*(1-T202)*noS203'
.param noS204='(1-S204)*noS203'
.param S205='T228*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS204'
.param noS205='(1-S205)*noS204'
.param S206='T228*T205*(1-T206)*T207*T208*noS205'
.param noS206='(1-S206)*noS205'
.param S207='T228*(1-T179)*T209*(1-T210)*noS206'
.param noS207='(1-S207)*noS206'
.param S208='T228*T209*T180*(1-T211)*(1-T212)*noS207'
.param noS208='(1-S208)*noS207'
.param S209='T228*T213*T214*T215*noS208'
.param noS209='(1-S209)*noS208'
.param S210='T229*(1-T178)*(1-T179)*noS209'
.param noS210='(1-S210)*noS209'
.param S211='T229*T180*(1-T178)*(1-T181)*noS210'
.param noS211='(1-S211)*noS210'
.param S212='T229*T182*T183*(1-T184)*noS211'
.param noS212='(1-S212)*noS211'
.param S213='T229*(1-T179)*T185*(1-T186)*noS212'
.param noS213='(1-S213)*noS212'
.param S214='T229*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS213'
.param noS214='(1-S214)*noS213'
.param S215='T229*T189*T190*T191*(1-T192)*noS214'
.param noS215='(1-S215)*noS214'
.param S216='T229*(1-T179)*T193*(1-T194)*noS215'
.param noS216='(1-S216)*noS215'
.param S217='T229*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS216'
.param noS217='(1-S217)*noS216'
.param S218='T229*T197*T198*T199*(1-T200)*noS217'
.param noS218='(1-S218)*noS217'
.param S219='T229*(1-T179)*T201*(1-T202)*noS218'
.param noS219='(1-S219)*noS218'
.param S220='T229*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS219'
.param noS220='(1-S220)*noS219'
.param S221='T229*T205*(1-T206)*T207*T208*noS220'
.param noS221='(1-S221)*noS220'
.param S222='T229*(1-T179)*T209*(1-T210)*noS221'
.param noS222='(1-S222)*noS221'
.param S223='T229*T209*T180*(1-T211)*(1-T212)*noS222'
.param noS223='(1-S223)*noS222'
.param S224='T229*T213*T214*T215*noS223'
.param noS224='(1-S224)*noS223'
.param S225='T230*(1-T178)*(1-T179)*noS224'
.param noS225='(1-S225)*noS224'
.param S226='T230*T180*(1-T178)*(1-T181)*noS225'
.param noS226='(1-S226)*noS225'
.param S227='T230*T182*T183*(1-T184)*noS226'
.param noS227='(1-S227)*noS226'
.param S228='T230*(1-T179)*T185*(1-T186)*noS227'
.param noS228='(1-S228)*noS227'
.param S229='T230*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS228'
.param noS229='(1-S229)*noS228'
.param S230='T230*T189*T190*T191*(1-T192)*noS229'
.param noS230='(1-S230)*noS229'
.param S231='T230*(1-T179)*T193*(1-T194)*noS230'
.param noS231='(1-S231)*noS230'
.param S232='T230*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS231'
.param noS232='(1-S232)*noS231'
.param S233='T230*T197*T198*T199*(1-T200)*noS232'
.param noS233='(1-S233)*noS232'
.param S234='T230*(1-T179)*T201*(1-T202)*noS233'
.param noS234='(1-S234)*noS233'
.param S235='T230*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS234'
.param noS235='(1-S235)*noS234'
.param S236='T230*T205*(1-T206)*T207*T208*noS235'
.param noS236='(1-S236)*noS235'
.param S237='T230*(1-T179)*T209*(1-T210)*noS236'
.param noS237='(1-S237)*noS236'
.param S238='T230*T209*T180*(1-T211)*(1-T212)*noS237'
.param noS238='(1-S238)*noS237'
.param S239='T230*T213*T214*T215*noS238'
.param noS239='(1-S239)*noS238'
.param S240='T231*(1-T178)*(1-T179)*noS239'
.param noS240='(1-S240)*noS239'
.param S241='T231*T180*(1-T178)*(1-T181)*noS240'
.param noS241='(1-S241)*noS240'
.param S242='T231*T182*T183*(1-T184)*noS241'
.param noS242='(1-S242)*noS241'
.param S243='T231*(1-T179)*T185*(1-T186)*noS242'
.param noS243='(1-S243)*noS242'
.param S244='T231*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS243'
.param noS244='(1-S244)*noS243'
.param S245='T231*T189*T190*T191*(1-T192)*noS244'
.param noS245='(1-S245)*noS244'
.param S246='T231*(1-T179)*T193*(1-T194)*noS245'
.param noS246='(1-S246)*noS245'
.param S247='T231*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS246'
.param noS247='(1-S247)*noS246'
.param S248='T231*T197*T198*T199*(1-T200)*noS247'
.param noS248='(1-S248)*noS247'
.param S249='T231*(1-T179)*T201*(1-T202)*noS248'
.param noS249='(1-S249)*noS248'
.param S250='T231*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS249'
.param noS250='(1-S250)*noS249'
.param S251='T231*T205*(1-T206)*T207*T208*noS250'
.param noS251='(1-S251)*noS250'
.param S252='T231*(1-T179)*T209*(1-T210)*noS251'
.param noS252='(1-S252)*noS251'
.param S253='T231*T209*T180*(1-T211)*(1-T212)*noS252'
.param noS253='(1-S253)*noS252'
.param S254='T231*T213*T214*T215*noS253'
.param noS254='(1-S254)*noS253'
.param S255='T232*(1-T178)*(1-T179)*noS254'
.param noS255='(1-S255)*noS254'
.param S256='T232*T180*(1-T178)*(1-T181)*noS255'
.param noS256='(1-S256)*noS255'
.param S257='T232*T182*T183*(1-T184)*noS256'
.param noS257='(1-S257)*noS256'
.param S258='T232*(1-T179)*T185*(1-T186)*noS257'
.param noS258='(1-S258)*noS257'
.param S259='T232*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS258'
.param noS259='(1-S259)*noS258'
.param S260='T232*T189*T190*T191*(1-T192)*noS259'
.param noS260='(1-S260)*noS259'
.param S261='T232*(1-T179)*T193*(1-T194)*noS260'
.param noS261='(1-S261)*noS260'
.param S262='T232*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS261'
.param noS262='(1-S262)*noS261'
.param S263='T232*T197*T198*T199*(1-T200)*noS262'
.param noS263='(1-S263)*noS262'
.param S264='T232*(1-T179)*T201*(1-T202)*noS263'
.param noS264='(1-S264)*noS263'
.param S265='T232*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS264'
.param noS265='(1-S265)*noS264'
.param S266='T232*T205*(1-T206)*T207*T208*noS265'
.param noS266='(1-S266)*noS265'
.param S267='T232*(1-T179)*T209*(1-T210)*noS266'
.param noS267='(1-S267)*noS266'
.param S268='T232*T209*T180*(1-T211)*(1-T212)*noS267'
.param noS268='(1-S268)*noS267'
.param S269='T232*T213*T214*T215*noS268'
.param noS269='(1-S269)*noS268'
.param S270='T233*(1-T178)*(1-T179)*noS269'
.param noS270='(1-S270)*noS269'
.param S271='T233*T180*(1-T178)*(1-T181)*noS270'
.param noS271='(1-S271)*noS270'
.param S272='T233*T182*T183*(1-T184)*noS271'
.param noS272='(1-S272)*noS271'
.param S273='T233*(1-T179)*T185*(1-T186)*noS272'
.param noS273='(1-S273)*noS272'
.param S274='T233*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS273'
.param noS274='(1-S274)*noS273'
.param S275='T233*T189*T190*T191*(1-T192)*noS274'
.param noS275='(1-S275)*noS274'
.param S276='T233*(1-T179)*T193*(1-T194)*noS275'
.param noS276='(1-S276)*noS275'
.param S277='T233*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS276'
.param noS277='(1-S277)*noS276'
.param S278='T233*T197*T198*T199*(1-T200)*noS277'
.param noS278='(1-S278)*noS277'
.param S279='T233*(1-T179)*T201*(1-T202)*noS278'
.param noS279='(1-S279)*noS278'
.param S280='T233*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS279'
.param noS280='(1-S280)*noS279'
.param S281='T233*T205*(1-T206)*T207*T208*noS280'
.param noS281='(1-S281)*noS280'
.param S282='T233*(1-T179)*T209*(1-T210)*noS281'
.param noS282='(1-S282)*noS281'
.param S283='T233*T209*T180*(1-T211)*(1-T212)*noS282'
.param noS283='(1-S283)*noS282'
.param S284='T233*T213*T214*T215*noS283'
.param noS284='(1-S284)*noS283'
.param S285='T234*(1-T178)*(1-T179)*noS284'
.param noS285='(1-S285)*noS284'
.param S286='T234*T180*(1-T178)*(1-T181)*noS285'
.param noS286='(1-S286)*noS285'
.param S287='T234*T182*T183*(1-T184)*noS286'
.param noS287='(1-S287)*noS286'
.param S288='T234*(1-T179)*T185*(1-T186)*noS287'
.param noS288='(1-S288)*noS287'
.param S289='T234*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS288'
.param noS289='(1-S289)*noS288'
.param S290='T234*T189*T190*T191*(1-T192)*noS289'
.param noS290='(1-S290)*noS289'
.param S291='T234*(1-T179)*T193*(1-T194)*noS290'
.param noS291='(1-S291)*noS290'
.param S292='T234*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS291'
.param noS292='(1-S292)*noS291'
.param S293='T234*T197*T198*T199*(1-T200)*noS292'
.param noS293='(1-S293)*noS292'
.param S294='T234*(1-T179)*T201*(1-T202)*noS293'
.param noS294='(1-S294)*noS293'
.param S295='T234*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS294'
.param noS295='(1-S295)*noS294'
.param S296='T234*T205*(1-T206)*T207*T208*noS295'
.param noS296='(1-S296)*noS295'
.param S297='T234*(1-T179)*T209*(1-T210)*noS296'
.param noS297='(1-S297)*noS296'
.param S298='T234*T209*T180*(1-T211)*(1-T212)*noS297'
.param noS298='(1-S298)*noS297'
.param S299='T234*T213*T214*T215*noS298'
.param noS299='(1-S299)*noS298'
.param S300='T235*(1-T178)*(1-T179)*noS299'
.param noS300='(1-S300)*noS299'
.param S301='T235*T180*(1-T178)*(1-T181)*noS300'
.param noS301='(1-S301)*noS300'
.param S302='T235*T182*T183*(1-T184)*noS301'
.param noS302='(1-S302)*noS301'
.param S303='T235*(1-T179)*T185*(1-T186)*noS302'
.param noS303='(1-S303)*noS302'
.param S304='T235*T185*T180*(1-T186)*(1-T187)*(1-T188)*noS303'
.param noS304='(1-S304)*noS303'
.param S305='T235*T189*T190*T191*(1-T192)*noS304'
.param noS305='(1-S305)*noS304'
.param S306='T235*(1-T179)*T193*(1-T194)*noS305'
.param noS306='(1-S306)*noS305'
.param S307='T235*T193*T180*(1-T194)*(1-T195)*(1-T196)*noS306'
.param noS307='(1-S307)*noS306'
.param S308='T235*T197*T198*T199*(1-T200)*noS307'
.param noS308='(1-S308)*noS307'
.param S309='T235*(1-T179)*T201*(1-T202)*noS308'
.param noS309='(1-S309)*noS308'
.param S310='T235*T201*T180*(1-T202)*(1-T203)*(1-T204)*noS309'
.param noS310='(1-S310)*noS309'
.param S311='T235*T205*(1-T206)*T207*T208*noS310'
.param noS311='(1-S311)*noS310'
.param S312='T235*(1-T179)*T209*(1-T210)*noS311'
.param noS312='(1-S312)*noS311'
.param S313='T235*T209*T180*(1-T211)*(1-T212)*noS312'
.param noS313='(1-S313)*noS312'
.param S314='T235*T213*T214*T215*noS313'
.param noS314='(1-S314)*noS313'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V0_part3='V0_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+(-2.304775e+01)*S35+0.000000e+00*S36+0.000000e+00*S37+(-2.710104e+01)*S38+2.159916e+00*S39'
.param V0_part5='V0_part4+(-5.148825e+00)*S40+(-2.231227e+01)*S41+3.464739e+00*S42+(-1.142561e+01)*S43+(-1.377253e+01)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V0_part6='V0_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+(-6.369574e+00)*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V0_part7='V0_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V0_part8='V0_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+1.049053e+01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V0_part9='V0_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V0_part10='V0_part9+0.000000e+00*S90+0.000000e+00*S91+(-1.638022e+01)*S92+0.000000e+00*S93+0.000000e+00*S94+(-6.828663e+00)*S95+0.000000e+00*S96+(-1.581318e+00)*S97+2.152915e+00*S98+0.000000e+00*S99'
.param V0_part11='V0_part10+0.000000e+00*S100+1.095450e+01*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-9.234928e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V0_part12='V0_part11+(-4.380306e+00)*S110+0.000000e+00*S111+0.000000e+00*S112+1.945809e+00*S113+0.000000e+00*S114+0.000000e+00*S115+7.988930e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V0_part13='V0_part12+0.000000e+00*S120+(-9.343742e-01)*S121+2.851979e+00*S122+0.000000e+00*S123+(-5.395322e-01)*S124+6.060682e+00*S125+0.000000e+00*S126+0.000000e+00*S127+7.598561e+00*S128+0.000000e+00*S129'
.param V0_part14='V0_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+(-1.082628e+00)*S136+(-7.735224e+00)*S137+1.866464e+00*S138+1.100100e+00*S139'
.param V0_part15='V0_part14+3.525281e+00*S140+6.059036e+00*S141+2.728195e-01*S142+1.094635e+01*S143+9.578135e+00*S144+9.159892e+00*S145+1.767548e+01*S146+1.385902e+01*S147+1.382703e+01*S148+2.840187e+01*S149'
.param V0_part16='V0_part15+3.679569e-01*S150+0.000000e+00*S151+1.262015e+00*S152+0.000000e+00*S153+0.000000e+00*S154+1.046807e+01*S155+0.000000e+00*S156+0.000000e+00*S157+(-1.414457e+01)*S158+0.000000e+00*S159'
.param V0_part17='V0_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+(-6.511802e-01)*S165+1.582446e-01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V0_part18='V0_part17+(-9.018007e+00)*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V0_part19='V0_part18+0.000000e+00*S180+0.000000e+00*S181+(-2.408877e+01)*S182+0.000000e+00*S183+0.000000e+00*S184+(-2.903742e+00)*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V0_part20='V0_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+1.042007e-02*S196+6.209267e+00*S197+4.138764e+00*S198+8.134962e+00*S199'
.param V0_part21='V0_part20+1.719314e+01*S200+9.817209e+00*S201+1.528467e+01*S202+2.925327e+01*S203+1.096996e+01*S204+4.886904e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V0_part22='V0_part21+0.000000e+00*S210+0.000000e+00*S211+2.441368e+01*S212+0.000000e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+(-1.134247e+01)*S219'
.param V0_part23='V0_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V0_part24='V0_part23+(-8.077793e+00)*S230+0.000000e+00*S231+0.000000e+00*S232+(-1.224643e+01)*S233+0.000000e+00*S234+9.998578e+00*S235+2.984359e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V0_part25='V0_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+(-4.623723e+00)*S244+(-2.052069e+00)*S245+0.000000e+00*S246+0.000000e+00*S247+(-4.128800e+00)*S248+0.000000e+00*S249'
.param V0_part26='V0_part25+0.000000e+00*S250+(-5.233996e-03)*S251+0.000000e+00*S252+0.000000e+00*S253+(-8.479014e-01)*S254+5.853078e+00*S255+7.186288e+00*S256+3.196249e+00*S257+8.011364e+00*S258+(-6.692490e+00)*S259'
.param V0_part27='V0_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+5.412511e-02*S263+0.000000e+00*S264+5.990574e+00*S265+1.554164e+00*S266+0.000000e+00*S267+8.489475e+00*S268+(-1.981424e+01)*S269'
.param V0_part28='V0_part27+(-2.353665e+00)*S270+(-9.439001e+00)*S271+(-4.091940e+01)*S272+(-3.017622e+00)*S273+0.000000e+00*S274+(-1.684824e+01)*S275+(-1.257537e+00)*S276+(-4.214134e-01)*S277+8.290404e+00*S278+0.000000e+00*S279'
.param V0_part29='V0_part28+0.000000e+00*S280+6.076779e+00*S281+(-7.243952e+00)*S282+0.000000e+00*S283+1.899052e+01*S284+(-8.316294e+00)*S285+(-2.676799e+00)*S286+0.000000e+00*S287+0.000000e+00*S288+(-5.831603e+00)*S289'
.param V0_part30='V0_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V0_part31='V0_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-7.041407e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+(-4.628830e+00)*S308+0.000000e+00*S309'
.param V0='V0_part31+0.000000e+00*S310+2.821046e+01*S311+0.000000e+00*S312+0.000000e+00*S313+4.160114e+01*S314'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V1_part3='V1_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+2.596777e+01*S35+0.000000e+00*S36+0.000000e+00*S37+2.334141e+01*S38+1.477339e+00*S39'
.param V1_part5='V1_part4+1.014806e+01*S40+1.498894e+01*S41+8.097051e-01*S42+1.487464e+01*S43+1.044404e+01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V1_part6='V1_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+1.190681e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V1_part7='V1_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V1_part8='V1_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+2.595352e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V1_part9='V1_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V1_part10='V1_part9+0.000000e+00*S90+0.000000e+00*S91+1.738090e+01*S92+0.000000e+00*S93+0.000000e+00*S94+(-1.659143e+00)*S95+0.000000e+00*S96+9.681692e+00*S97+(-9.394418e+00)*S98+0.000000e+00*S99'
.param V1_part11='V1_part10+0.000000e+00*S100+(-1.733102e+01)*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+1.885471e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V1_part12='V1_part11+9.979671e+00*S110+0.000000e+00*S111+0.000000e+00*S112+1.148079e+01*S113+0.000000e+00*S114+0.000000e+00*S115+8.903254e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V1_part13='V1_part12+0.000000e+00*S120+1.881367e+01*S121+5.094237e+00*S122+0.000000e+00*S123+1.548877e+01*S124+1.619875e+00*S125+0.000000e+00*S126+0.000000e+00*S127+1.824461e+00*S128+0.000000e+00*S129'
.param V1_part14='V1_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+1.729278e+01*S136+3.504095e+01*S137+2.361306e+01*S138+2.028704e+01*S139'
.param V1_part15='V1_part14+1.572785e+01*S140+8.610399e+00*S141+2.278673e+01*S142+6.201172e+00*S143+6.539395e+00*S144+9.485780e+00*S145+7.427286e-01*S146+3.978766e+00*S147+6.508899e+00*S148+(-5.980342e+00)*S149'
.param V1_part16='V1_part15+2.241794e+00*S150+0.000000e+00*S151+(-1.091117e+01)*S152+0.000000e+00*S153+0.000000e+00*S154+(-2.469833e+01)*S155+0.000000e+00*S156+0.000000e+00*S157+1.359182e+01*S158+0.000000e+00*S159'
.param V1_part17='V1_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+7.523611e+00*S165+1.427004e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V1_part18='V1_part17+1.915667e+01*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V1_part19='V1_part18+0.000000e+00*S180+0.000000e+00*S181+3.589381e+01*S182+0.000000e+00*S183+0.000000e+00*S184+3.255337e+00*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V1_part20='V1_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+6.166779e+00*S196+(-6.103051e+00)*S197+1.652501e+01*S198+(-3.488410e+00)*S199'
.param V1_part21='V1_part20+(-1.470676e+01)*S200+6.400670e+00*S201+9.874051e-01*S202+(-2.514291e+01)*S203+1.873221e+00*S204+9.677594e+00*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V1_part22='V1_part21+0.000000e+00*S210+0.000000e+00*S211+(-4.992285e+01)*S212+0.000000e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+3.391164e+00*S219'
.param V1_part23='V1_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V1_part24='V1_part23+1.157039e+01*S230+0.000000e+00*S231+0.000000e+00*S232+1.515145e+01*S233+0.000000e+00*S234+6.599184e+00*S235+5.455732e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V1_part25='V1_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+2.077938e+01*S244+5.909244e+00*S245+0.000000e+00*S246+0.000000e+00*S247+6.523584e+00*S248+0.000000e+00*S249'
.param V1_part26='V1_part25+0.000000e+00*S250+1.451610e+01*S251+0.000000e+00*S252+0.000000e+00*S253+1.531329e+01*S254+2.062894e-01*S255+(-4.988864e+00)*S256+1.710854e+01*S257+1.531458e+00*S258+3.117563e+01*S259'
.param V1_part27='V1_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+1.689315e+01*S263+0.000000e+00*S264+9.698290e+00*S265+9.462653e+00*S266+0.000000e+00*S267+7.069139e+00*S268+2.559650e+01*S269'
.param V1_part28='V1_part27+1.653747e+01*S270+2.026468e+01*S271+(-2.076270e+00)*S272+7.231621e+00*S273+0.000000e+00*S274+2.038728e+01*S275+1.439441e+00*S276+1.828490e+01*S277+(-1.750953e+01)*S278+0.000000e+00*S279'
.param V1_part29='V1_part28+0.000000e+00*S280+(-6.380447e+00)*S281+(-9.090347e-01)*S282+0.000000e+00*S283+(-1.166415e+01)*S284+1.985408e+01*S285+1.843360e+01*S286+0.000000e+00*S287+0.000000e+00*S288+1.457370e+01*S289'
.param V1_part30='V1_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V1_part31='V1_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+2.028561e+01*S305+0.000000e+00*S306+0.000000e+00*S307+1.959016e+01*S308+0.000000e+00*S309'
.param V1='V1_part31+0.000000e+00*S310+(-1.168903e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+(-2.194831e+01)*S314'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V2_part3='V2_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+2.697817e+01*S35+0.000000e+00*S36+0.000000e+00*S37+4.661569e+01*S38+1.012500e+01*S39'
.param V2_part5='V2_part4+2.046890e+01*S40+4.688595e+01*S41+6.705356e+00*S42+2.707653e+01*S43+4.178986e+01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V2_part6='V2_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+1.914631e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V2_part7='V2_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V2_part8='V2_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+1.375169e+01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V2_part9='V2_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V2_part10='V2_part9+0.000000e+00*S90+0.000000e+00*S91+6.492203e+01*S92+0.000000e+00*S93+0.000000e+00*S94+5.014842e+01*S95+0.000000e+00*S96+4.072757e+01*S97+4.058520e+01*S98+0.000000e+00*S99'
.param V2_part11='V2_part10+0.000000e+00*S100+3.911318e+01*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+3.992823e+01*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V2_part12='V2_part11+2.746908e+01*S110+0.000000e+00*S111+0.000000e+00*S112+2.453318e+01*S113+0.000000e+00*S114+0.000000e+00*S115+2.351898e+01*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V2_part13='V2_part12+0.000000e+00*S120+1.758048e+01*S121+2.722294e+01*S122+0.000000e+00*S123+2.145839e+01*S124+2.810567e+01*S125+0.000000e+00*S126+0.000000e+00*S127+2.511910e+01*S128+0.000000e+00*S129'
.param V2_part14='V2_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+2.302509e+01*S136+3.212384e+01*S137+1.590250e+01*S138+1.468369e+01*S139'
.param V2_part15='V2_part14+2.534328e+01*S140+1.479134e+01*S141+1.811797e+01*S142+2.160762e+01*S143+9.760923e+00*S144+7.255309e+00*S145+1.827901e+01*S146+3.752756e+00*S147+1.720969e+00*S148+6.164951e+00*S149'
.param V2_part16='V2_part15+1.741800e+01*S150+0.000000e+00*S151+4.713311e+01*S152+0.000000e+00*S153+0.000000e+00*S154+4.457016e+01*S155+0.000000e+00*S156+0.000000e+00*S157+5.657218e+01*S158+0.000000e+00*S159'
.param V2_part17='V2_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+2.967542e+01*S165+1.282616e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V2_part18='V2_part17+3.707656e+01*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V2_part19='V2_part18+0.000000e+00*S180+0.000000e+00*S181+5.711148e+01*S182+0.000000e+00*S183+0.000000e+00*S184+3.158930e+01*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V2_part20='V2_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+3.158109e+01*S196+3.132385e+01*S197+1.675464e+01*S198+1.839824e+01*S199'
.param V2_part21='V2_part20+2.139185e+01*S200+1.426869e+01*S201+1.312647e+01*S202+1.390464e+01*S203+1.314015e+01*S204+1.691908e+01*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V2_part22='V2_part21+0.000000e+00*S210+0.000000e+00*S211+2.963631e+01*S212+0.000000e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+6.775467e+01*S219'
.param V2_part23='V2_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V2_part24='V2_part23+3.606415e+01*S230+0.000000e+00*S231+0.000000e+00*S232+5.143151e+01*S233+0.000000e+00*S234+4.358509e+00*S235+3.889617e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V2_part25='V2_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+4.369419e+01*S244+2.863244e+01*S245+0.000000e+00*S246+0.000000e+00*S247+3.923499e+01*S248+0.000000e+00*S249'
.param V2_part26='V2_part25+0.000000e+00*S250+2.030923e+01*S251+0.000000e+00*S252+0.000000e+00*S253+2.369851e+01*S254+1.921913e+01*S255+2.074074e+01*S256+2.608569e+01*S257+1.363541e+01*S258+4.600354e+01*S259'
.param V2_part27='V2_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+1.707566e+01*S263+0.000000e+00*S264+2.729667e+01*S265+3.042968e+01*S266+0.000000e+00*S267+2.864997e+01*S268+6.390719e+01*S269'
.param V2_part28='V2_part27+3.514501e+01*S270+6.739703e+01*S271+1.071448e+02*S272+4.285340e+01*S273+0.000000e+00*S274+5.321730e+01*S275+4.234097e+01*S276+2.981244e+01*S277+7.004581e+01*S278+0.000000e+00*S279'
.param V2_part29='V2_part28+0.000000e+00*S280+7.544068e+01*S281+9.185039e+01*S282+0.000000e+00*S283+5.226345e+01*S284+4.301817e+01*S285+3.775838e+01*S286+0.000000e+00*S287+0.000000e+00*S288+5.735746e+01*S289'
.param V2_part30='V2_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V2_part31='V2_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+4.985197e+01*S305+0.000000e+00*S306+0.000000e+00*S307+4.414745e+01*S308+0.000000e+00*S309'
.param V2='V2_part31+0.000000e+00*S310+2.845222e+01*S311+0.000000e+00*S312+0.000000e+00*S313+2.064089e+01*S314'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V3_part3='V3_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+(-3.014366e+00)*S35+0.000000e+00*S36+0.000000e+00*S37+(-3.481480e+00)*S38+1.238352e+00*S39'
.param V3_part5='V3_part4+(-3.723975e-01)*S40+(-2.407257e+00)*S41+2.571075e+00*S42+(-8.142328e-02)*S43+(-2.894043e+00)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V3_part6='V3_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+3.197646e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V3_part7='V3_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V3_part8='V3_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-2.323897e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V3_part9='V3_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V3_part10='V3_part9+0.000000e+00*S90+0.000000e+00*S91+(-4.730449e+00)*S92+0.000000e+00*S93+0.000000e+00*S94+(-4.970604e+00)*S95+0.000000e+00*S96+(-3.384900e-01)*S97+(-1.035959e+01)*S98+0.000000e+00*S99'
.param V3_part11='V3_part10+0.000000e+00*S100+(-9.056655e+00)*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-5.776846e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V3_part12='V3_part11+(-1.616841e-01)*S110+0.000000e+00*S111+0.000000e+00*S112+(-1.009833e+01)*S113+0.000000e+00*S114+0.000000e+00*S115+(-1.220577e+01)*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V3_part13='V3_part12+0.000000e+00*S120+(-7.030859e+00)*S121+(-9.275872e+00)*S122+0.000000e+00*S123+(-5.509736e+00)*S124+(-9.506876e+00)*S125+0.000000e+00*S126+0.000000e+00*S127+(-7.587705e+00)*S128+0.000000e+00*S129'
.param V3_part14='V3_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+5.021570e+00*S136+7.037921e+00*S137+2.758970e+00*S138+5.925994e+00*S139'
.param V3_part15='V3_part14+(-4.421014e+00)*S140+3.468584e+00*S141+2.218803e+00*S142+(-3.809619e+00)*S143+2.460377e+00*S144+2.167077e+00*S145+(-2.610001e+00)*S146+2.602730e+00*S147+1.336824e+00*S148+(-1.438218e+00)*S149'
.param V3_part16='V3_part15+(-1.909299e+00)*S150+0.000000e+00*S151+(-6.222973e+00)*S152+0.000000e+00*S153+0.000000e+00*S154+(-4.450070e+00)*S155+0.000000e+00*S156+0.000000e+00*S157+(-2.837422e+00)*S158+0.000000e+00*S159'
.param V3_part17='V3_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+(-4.824569e+00)*S165+1.764323e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V3_part18='V3_part17+4.060098e+00*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V3_part19='V3_part18+0.000000e+00*S180+0.000000e+00*S181+1.777186e+00*S182+0.000000e+00*S183+0.000000e+00*S184+(-1.833775e+00)*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V3_part20='V3_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+5.033167e+00*S196+4.838676e+00*S197+3.985360e-01*S198+2.811875e+00*S199'
.param V3_part21='V3_part20+2.305822e+00*S200+3.643155e+00*S201+(-3.249478e+00)*S202+7.449444e-02*S203+(-3.176063e+00)*S204+(-4.569879e+00)*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V3_part22='V3_part21+0.000000e+00*S210+0.000000e+00*S211+(-4.367047e+00)*S212+0.000000e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+(-3.430037e-01)*S219'
.param V3_part23='V3_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V3_part24='V3_part23+7.411703e-01*S230+0.000000e+00*S231+0.000000e+00*S232+5.289825e+00*S233+0.000000e+00*S234+2.762674e+00*S235+5.709625e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V3_part25='V3_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+7.973523e-01*S244+(-6.211954e-01)*S245+0.000000e+00*S246+0.000000e+00*S247+2.133636e+00*S248+0.000000e+00*S249'
.param V3_part26='V3_part25+0.000000e+00*S250+4.463429e-01*S251+0.000000e+00*S252+0.000000e+00*S253+7.054916e-01*S254+2.393215e+00*S255+2.236005e+00*S256+8.912617e+00*S257+3.213831e+00*S258+4.877048e+00*S259'
.param V3_part27='V3_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+2.802507e+00*S263+0.000000e+00*S264+8.183196e+00*S265+7.329039e+00*S266+0.000000e+00*S267+6.996261e+00*S268+1.169834e+01*S269'
.param V3_part28='V3_part27+(-2.648923e+00)*S270+3.477457e-01*S271+8.305832e+00*S272+(-6.358913e-01)*S273+0.000000e+00*S274+9.947776e+00*S275+(-3.563491e-01)*S276+3.208531e+00*S277+8.001729e+00*S278+0.000000e+00*S279'
.param V3_part29='V3_part28+0.000000e+00*S280+9.691975e+00*S281+8.188691e-01*S282+0.000000e+00*S283+8.919187e+00*S284+(-3.593574e+00)*S285+3.278864e+00*S286+0.000000e+00*S287+0.000000e+00*S288+2.693625e+00*S289'
.param V3_part30='V3_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V3_part31='V3_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+9.194939e+00*S305+0.000000e+00*S306+0.000000e+00*S307+1.157364e+01*S308+0.000000e+00*S309'
.param V3='V3_part31+0.000000e+00*S310+1.357158e+01*S311+0.000000e+00*S312+0.000000e+00*S313+1.397958e+01*S314'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V4_part3='V4_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+(-2.398406e+00)*S35+0.000000e+00*S36+0.000000e+00*S37+(-3.085106e+00)*S38+(-2.431947e+00)*S39'
.param V4_part5='V4_part4+(-2.985505e+00)*S40+(-3.762812e+00)*S41+(-3.319908e+00)*S42+(-3.793335e+00)*S43+(-4.389978e+00)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V4_part6='V4_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+(-4.642222e+00)*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V4_part7='V4_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V4_part8='V4_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-7.482939e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V4_part9='V4_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V4_part10='V4_part9+0.000000e+00*S90+0.000000e+00*S91+(-5.654913e+00)*S92+0.000000e+00*S93+0.000000e+00*S94+(-7.138272e+00)*S95+0.000000e+00*S96+(-5.531612e+00)*S97+(-8.061429e+00)*S98+0.000000e+00*S99'
.param V4_part11='V4_part10+0.000000e+00*S100+(-9.364422e+00)*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+(-5.142460e+00)*S107+0.000000e+00*S108+0.000000e+00*S109'
.param V4_part12='V4_part11+(-6.905310e+00)*S110+0.000000e+00*S111+0.000000e+00*S112+(-7.446668e+00)*S113+0.000000e+00*S114+0.000000e+00*S115+(-8.652805e+00)*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V4_part13='V4_part12+0.000000e+00*S120+(-3.033746e+00)*S121+(-5.190729e+00)*S122+0.000000e+00*S123+(-4.015443e+00)*S124+(-7.283761e+00)*S125+0.000000e+00*S126+0.000000e+00*S127+(-7.654373e+00)*S128+0.000000e+00*S129'
.param V4_part14='V4_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+(-4.867527e+00)*S136+(-7.515058e+00)*S137+(-6.428074e+00)*S138+(-7.050382e+00)*S139'
.param V4_part15='V4_part14+(-8.578629e+00)*S140+(-7.385360e+00)*S141+(-8.024151e+00)*S142+(-9.747769e+00)*S143+(-8.505290e+00)*S144+(-9.103138e+00)*S145+(-1.053415e+01)*S146+(-9.882898e+00)*S147+(-1.056718e+01)*S148+(-1.188458e+01)*S149'
.param V4_part16='V4_part15+(-2.804507e+00)*S150+0.000000e+00*S151+(-9.245967e+00)*S152+0.000000e+00*S153+0.000000e+00*S154+(-1.054909e+01)*S155+0.000000e+00*S156+0.000000e+00*S157+(-9.492846e+00)*S158+0.000000e+00*S159'
.param V4_part17='V4_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+0.000000e+00*S163+0.000000e+00*S164+(-3.428658e+00)*S165+(-3.761388e+00)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V4_part18='V4_part17+(-7.676630e+00)*S170+0.000000e+00*S171+0.000000e+00*S172+0.000000e+00*S173+0.000000e+00*S174+0.000000e+00*S175+0.000000e+00*S176+0.000000e+00*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V4_part19='V4_part18+0.000000e+00*S180+0.000000e+00*S181+(-5.620492e+00)*S182+0.000000e+00*S183+0.000000e+00*S184+(-9.050476e+00)*S185+0.000000e+00*S186+0.000000e+00*S187+0.000000e+00*S188+0.000000e+00*S189'
.param V4_part20='V4_part19+0.000000e+00*S190+0.000000e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+(-5.307417e+00)*S196+(-8.796104e+00)*S197+(-5.372721e+00)*S198+(-7.485539e+00)*S199'
.param V4_part21='V4_part20+(-1.059761e+01)*S200+(-6.979354e+00)*S201+(-8.349791e+00)*S202+(-1.189366e+01)*S203+(-7.411865e+00)*S204+(-7.529999e+00)*S205+0.000000e+00*S206+0.000000e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V4_part22='V4_part21+0.000000e+00*S210+0.000000e+00*S211+(-1.297018e+01)*S212+0.000000e+00*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+(-6.060105e+00)*S219'
.param V4_part23='V4_part22+0.000000e+00*S220+0.000000e+00*S221+0.000000e+00*S222+0.000000e+00*S223+0.000000e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+0.000000e+00*S228+0.000000e+00*S229'
.param V4_part24='V4_part23+(-8.921765e+00)*S230+0.000000e+00*S231+0.000000e+00*S232+(-1.032829e+01)*S233+0.000000e+00*S234+(-7.509747e+00)*S235+(-1.064556e+01)*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V4_part25='V4_part24+0.000000e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+(-4.304416e+00)*S244+(-1.045792e+01)*S245+0.000000e+00*S246+0.000000e+00*S247+(-1.060129e+01)*S248+0.000000e+00*S249'
.param V4_part26='V4_part25+0.000000e+00*S250+(-9.763110e+00)*S251+0.000000e+00*S252+0.000000e+00*S253+(-1.037610e+01)*S254+(-6.035922e+00)*S255+(-7.189612e+00)*S256+(-9.846325e+00)*S257+(-5.859129e+00)*S258+(-6.075128e+00)*S259'
.param V4_part27='V4_part26+0.000000e+00*S260+0.000000e+00*S261+0.000000e+00*S262+(-1.116520e+01)*S263+0.000000e+00*S264+(-8.748879e+00)*S265+(-1.176447e+01)*S266+0.000000e+00*S267+(-9.641511e+00)*S268+(-1.111315e+01)*S269'
.param V4_part28='V4_part27+(-4.139549e+00)*S270+(-3.729489e+00)*S271+(-5.390912e+00)*S272+(-3.470830e+00)*S273+0.000000e+00*S274+(-6.133473e+00)*S275+(-2.672166e+00)*S276+(-4.634233e+00)*S277+(-8.447707e+00)*S278+0.000000e+00*S279'
.param V4_part29='V4_part28+0.000000e+00*S280+(-1.433529e+01)*S281+(-1.060022e+01)*S282+0.000000e+00*S283+(-1.273555e+01)*S284+(-2.831218e+00)*S285+(-3.714657e+00)*S286+0.000000e+00*S287+0.000000e+00*S288+(-3.966861e+00)*S289'
.param V4_part30='V4_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+0.000000e+00*S295+0.000000e+00*S296+0.000000e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V4_part31='V4_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+0.000000e+00*S303+0.000000e+00*S304+(-1.011103e+01)*S305+0.000000e+00*S306+0.000000e+00*S307+(-1.135602e+01)*S308+0.000000e+00*S309'
.param V4='V4_part31+0.000000e+00*S310+(-1.579047e+01)*S311+0.000000e+00*S312+0.000000e+00*S313+(-1.656684e+01)*S314'
.param V5_part1='(-3.180652e-02)*S0+(-2.456434e-02)*S1+(-1.465403e-02)*S2+(-5.711941e-02)*S3+(-4.241597e-02)*S4+(-2.441865e-02)*S5+(-8.913456e-02)*S6+(-6.747159e-02)*S7+(-3.457208e-02)*S8+(-1.169923e-01)*S9'
.param V5_part2='V5_part1+(-8.476501e-02)*S10+(-4.615548e-02)*S11+(-1.301339e-01)*S12+(-1.025568e-01)*S13+(-5.891106e-02)*S14+4.317688e+00*S15+3.785998e+01*S16+(-8.852069e-03)*S17+5.094627e+00*S18+4.049798e+00*S19'
.param V5_part3='V5_part2+(-2.472414e-02)*S20+4.899574e+00*S21+3.603112e+00*S22+(-4.092394e-02)*S23+4.433121e+00*S24+(-1.173327e-01)*S25+2.507793e+00*S26+5.201960e+00*S27+5.044259e+00*S28+3.367958e+00*S29'
.param V5_part4='V5_part3+(-3.850248e-02)*S30+4.370493e+00*S31+2.152065e-01*S32+4.881793e+00*S33+(-3.599471e-02)*S34+8.270248e+00*S35+5.924437e+00*S36+(-8.642475e-02)*S37+(-9.648244e-03)*S38+(-2.608617e-01)*S39'
.param V5_part5='V5_part4+(-1.259805e-01)*S40+(-3.590188e-02)*S41+(-3.198631e-01)*S42+(-1.630289e-01)*S43+(-6.560961e-02)*S44+1.271927e+00*S45+3.054967e+00*S46+1.653017e+00*S47+1.611458e+00*S48+4.818023e+00*S49'
.param V5_part6='V5_part5+2.945106e-02*S50+(-2.351962e-01)*S51+(-9.608763e-02)*S52+(-6.734860e-03)*S53+(-2.555142e-01)*S54+(-1.612177e-01)*S55+(-3.574904e-02)*S56+(-3.644901e-01)*S57+(-1.945347e-01)*S58+(-5.940285e-02)*S59'
.param V5_part7='V5_part6+2.135399e+00*S60+4.341683e+00*S61+2.780671e+00*S62+3.573409e+00*S63+5.732600e+00*S64+5.310650e+00*S65+1.005359e+01*S66+5.527332e+00*S67+3.448630e+00*S68+1.128409e+01*S69'
.param V5_part8='V5_part7+6.242171e+00*S70+8.378027e+00*S71+1.679204e+01*S72+1.954680e+01*S73+(-6.959506e-01)*S74+1.193054e+00*S75+1.886623e+00*S76+1.439825e+00*S77+2.108119e+00*S78+3.364588e+00*S79'
.param V5_part9='V5_part8+(-8.075340e-03)*S80+3.243339e+00*S81+6.355220e+00*S82+2.881683e+00*S83+4.029744e+00*S84+8.879949e+00*S85+4.280720e+00*S86+5.277892e+00*S87+8.789646e+00*S88+3.756781e+00*S89'
.param V5_part10='V5_part9+(-6.485927e-02)*S90+3.539979e+00*S91+2.117059e+00*S92+(-1.757704e-01)*S93+3.078144e+00*S94+6.510237e-02*S95+(-2.859403e-01)*S96+(-1.378311e-01)*S97+3.900009e+00*S98+1.459105e+01*S99'
.param V5_part11='V5_part10+(-2.130137e-01)*S100+6.260350e+00*S101+(-5.115998e-01)*S102+(-2.514711e-01)*S103+1.463206e+01*S104+3.151589e+00*S105+3.555528e+00*S106+2.380480e+00*S107+6.043542e+00*S108+3.931740e+00*S109'
.param V5_part12='V5_part11+4.799810e+00*S110+7.945027e+00*S111+1.374552e+01*S112+7.474144e+00*S113+8.998542e+00*S114+2.429007e+01*S115+4.275883e+00*S116+4.809212e+00*S117+2.912912e+01*S118+2.666973e+00*S119'
.param V5_part13='V5_part12+4.508011e+00*S120+3.234990e+00*S121+2.988671e+00*S122+8.007028e+00*S123+4.754152e+00*S124+3.225033e+00*S125+(-3.762644e-01)*S126+1.564493e+01*S127+4.877398e+00*S128+5.176102e+00*S129'
.param V5_part14='V5_part13+2.333147e+01*S130+3.322136e+00*S131+(-6.625316e-01)*S132+5.065474e+00*S133+2.194491e+00*S134+2.115969e+00*S135+4.739518e+00*S136+7.628548e-01*S137+4.072557e+00*S138+6.024758e+00*S139'
.param V5_part15='V5_part14+1.091446e+00*S140+8.564953e+00*S141+7.925594e+00*S142+1.354654e+00*S143+1.353856e+01*S144+1.399219e+01*S145+3.375541e+00*S146+2.745405e+01*S147+1.594664e+01*S148+8.784520e+00*S149'
.param V5_part16='V5_part15+1.061438e+02*S150+1.401736e+00*S151+8.290112e-01*S152+7.719603e+00*S153+(-8.818765e+01)*S154+3.261453e+00*S155+9.639379e+00*S156+4.052441e+00*S157+3.114222e+00*S158+(-6.349914e-01)*S159'
.param V5_part17='V5_part16+4.008886e+00*S160+9.812523e-03*S161+3.284046e+00*S162+(-4.190068e-01)*S163+(-8.553345e-02)*S164+(-1.949236e-02)*S165+8.881775e-02*S166+1.406248e+01*S167+3.570846e+00*S168+1.238335e+01*S169'
.param V5_part18='V5_part17+4.341290e+00*S170+5.853948e+00*S171+(-2.002309e-01)*S172+1.321595e+01*S173+(-7.777892e-01)*S174+3.929387e+00*S175+8.758489e+00*S176+(-9.444808e-01)*S177+3.369949e+00*S178+8.673581e+00*S179'
.param V5_part19='V5_part18+(-2.068871e+00)*S180+3.400492e+00*S181+1.391128e+00*S182+3.363580e+00*S183+(-4.735887e-01)*S184+2.099676e-01*S185+5.472239e+00*S186+6.117885e+00*S187+4.387455e+00*S188+(-7.283601e-01)*S189'
.param V5_part20='V5_part19+2.328799e+00*S190+7.126853e+00*S191+(-8.821857e-01)*S192+2.533392e+00*S193+7.299564e+00*S194+3.572677e+00*S195+5.426565e+00*S196+9.172813e+00*S197+6.025387e+00*S198+1.330476e+01*S199'
.param V5_part21='V5_part20+1.217088e+01*S200+1.018581e+01*S201+1.237273e+01*S202+1.205977e+01*S203+1.173257e+01*S204+8.584083e+00*S205+8.476385e+00*S206+1.358607e+00*S207+1.909220e+01*S208+6.997152e+00*S209'
.param V5_part22='V5_part21+(-3.379877e+00)*S210+4.765415e+02*S211+2.991988e-01*S212+6.059593e+00*S213+3.251220e-01*S214+3.010209e-01*S215+(-5.544107e-01)*S216+(-1.767176e-01)*S217+1.345393e-01*S218+(-8.294277e-01)*S219'
.param V5_part23='V5_part22+6.480006e+00*S220+1.968512e-02*S221+(-1.074888e+00)*S222+7.426246e+00*S223+1.590869e+01*S224+4.668391e-02*S225+2.190346e-01*S226+3.919180e-01*S227+(-2.943698e-01)*S228+5.136838e-02*S229'
.param V5_part24='V5_part23+3.512930e-01*S230+(-6.329926e-01)*S231+(-1.101209e-01)*S232+2.782715e-01*S233+(-9.479564e-01)*S234+(-2.351062e-01)*S235+1.678121e-01*S236+(-1.101144e+00)*S237+4.974792e+00*S238+5.465308e+00*S239'
.param V5_part25='V5_part24+4.133820e-01*S240+1.798638e+00*S241+1.813815e+00*S242+(-4.656878e-01)*S243+4.807232e-02*S244+1.839904e+00*S245+(-5.536002e-01)*S246+6.777704e-01*S247+2.148920e+00*S248+(-9.110595e-01)*S249'
.param V5_part26='V5_part25+(-3.717638e-01)*S250+3.964137e+00*S251+(-1.156229e+00)*S252+5.618644e+00*S253+1.168041e+01*S254+9.564540e+00*S255+9.702699e+00*S256+8.677532e+00*S257+3.415816e+01*S258+1.254466e+00*S259'
.param V5_part27='V5_part26+1.743648e+00*S260+2.496521e+00*S261+3.900764e+00*S262+3.895070e+00*S263+4.619469e+00*S264+5.823279e+00*S265+6.485846e+00*S266+(-9.499412e-01)*S267+8.149784e+00*S268+1.029042e+01*S269'
.param V5_part28='V5_part27+(-2.087747e-01)*S270+4.795020e+00*S271+1.643566e+00*S272+7.753745e-01*S273+1.295128e+00*S274+1.864062e+00*S275+(-1.290836e-01)*S276+1.555418e+00*S277+3.853418e+00*S278+7.998862e-01*S279'
.param V5_part29='V5_part28+4.543501e+00*S280+1.024524e+01*S281+(-4.559741e+01)*S282+6.441115e+00*S283+8.698667e+00*S284+2.482102e-01*S285+5.107120e+00*S286+1.686429e+00*S287+(-1.185348e+00)*S288+5.488378e+00*S289'
.param V5_part30='V5_part29+1.266537e+00*S290+(-8.861599e-01)*S291+(-1.820805e-01)*S292+3.102400e+00*S293+(-1.722646e+00)*S294+(-3.790713e-01)*S295+4.214757e+00*S296+3.647889e+00*S297+(-6.247603e-01)*S298+3.223085e+00*S299'
.param V5_part31='V5_part30+(-3.236986e+00)*S300+1.104733e-01*S301+1.804724e+00*S302+(-2.023353e+00)*S303+7.058293e-01*S304+1.267387e+00*S305+(-8.234170e-01)*S306+6.140575e+00*S307+2.433842e+00*S308+(-9.589038e-01)*S309'
.param V5='V5_part31+3.670341e+00*S310+7.587366e+00*S311+4.122171e+00*S312+(-5.495994e-01)*S313+6.871562e+00*S314'
.param V6_part1='1.636346e-01*S0+1.231951e-01*S1+6.380695e-02*S2+1.605387e-01*S3+1.279890e-01*S4+6.376759e-02*S5+1.669818e-01*S6+1.366466e-01*S7+6.891186e-02*S8+1.656119e-01*S9'
.param V6_part2='V6_part1+1.291196e-01*S10+7.028535e-02*S11+1.524225e-01*S12+1.232957e-01*S13+7.363328e-02*S14+7.447650e+00*S15+9.539692e+00*S16+9.216391e-02*S17+4.102800e+00*S18+1.823438e+00*S19'
.param V6_part3='V6_part2+9.818957e-02*S20+2.473812e+00*S21+1.760084e+00*S22+1.015674e-01*S23+1.688845e+00*S24+1.866619e-01*S25+1.073660e+00*S26+2.519300e+00*S27+1.228269e+00*S28+8.438791e-01*S29'
.param V6_part4='V6_part3+3.871759e-01*S30+1.923585e+00*S31+3.554962e-01*S32+(-2.864585e+00)*S33+3.384546e-01*S34+(-6.180086e+00)*S35+(-3.051333e+00)*S36+3.135506e-01*S37+1.880586e-01*S38+4.250733e-01*S39'
.param V6_part5='V6_part4+3.079494e-01*S40+1.684951e-01*S41+4.126161e-01*S42+2.954772e-01*S43+1.437571e-01*S44+1.291464e+00*S45+2.908646e+00*S46+1.667090e-01*S47+(-4.567103e-01)*S48+(-8.383856e-01)*S49'
.param V6_part6='V6_part5+1.920431e-01*S50+5.296408e-01*S51+3.774065e-01*S52+1.533271e-01*S53+4.733172e-01*S54+3.893383e-01*S55+1.309188e-01*S56+4.781850e-01*S57+3.241671e-01*S58+2.157887e-01*S59'
.param V6_part7='V6_part6+1.150343e+00*S60+2.830572e+00*S61+(-4.177017e-01)*S62+(-5.880174e-01)*S63+4.884821e-02*S64+(-6.003303e+00)*S65+(-7.163404e+00)*S66+(-3.363238e+00)*S67+(-3.530330e+00)*S68+(-8.171126e+00)*S69'
.param V6_part8='V6_part7+(-4.967107e+00)*S70+(-9.062595e+00)*S71+(-1.264684e+01)*S72+(-1.968721e+01)*S73+7.816170e-01*S74+3.631154e-01*S75+1.139067e+00*S76+2.688785e-01*S77+(-8.636037e-01)*S78+2.801989e-02*S79'
.param V6_part9='V6_part8+1.403658e-01*S80+(-5.545338e-01)*S81+1.018091e+00*S82+6.504972e-01*S83+(-1.487105e-02)*S84+(-1.528574e-01)*S85+3.678844e-01*S86+(-6.387955e-01)*S87+(-1.581419e-01)*S88+1.371941e-01*S89'
.param V6_part10='V6_part9+7.931652e-01*S90+(-2.413895e+00)*S91+(-2.603924e+00)*S92+8.189927e-01*S93+(-7.826798e+00)*S94+1.634809e-01*S95+7.948365e-01*S96+4.874377e-01*S97+(-3.657566e+00)*S98+(-1.469442e+01)*S99'
.param V6_part11='V6_part10+5.133339e-01*S100+(-5.281460e+00)*S101+7.408889e-01*S102+4.599796e-01*S103+(-1.066708e+01)*S104+(-4.171787e+00)*S105+(-5.386443e+00)*S106+(-1.991741e+00)*S107+(-9.413116e+00)*S108+(-7.634798e+00)*S109'
.param V6_part12='V6_part11+(-4.315366e+00)*S110+(-9.503866e+00)*S111+(-1.978382e+01)*S112+(-5.579939e+00)*S113+(-1.049890e+01)*S114+(-2.379577e+01)*S115+(-2.013618e+00)*S116+(-3.492491e+00)*S117+(-2.408646e+01)*S118+(-1.336357e+00)*S119'
.param V6_part13='V6_part12+(-4.362161e+00)*S120+(-6.317905e+00)*S121+(-2.567543e+00)*S122+(-1.475657e+01)*S123+(-8.049038e+00)*S124+(-2.533234e+00)*S125+9.951084e-01*S126+(-2.004024e+01)*S127+(-3.008989e+00)*S128+(-6.215937e+00)*S129'
.param V6_part14='V6_part13+(-2.397773e+01)*S130+(-2.260441e+00)*S131+9.420019e-01*S132+(-4.204899e+00)*S133+(-9.562275e-01)*S134+(-1.172156e+00)*S135+(-6.155821e-01)*S136+(-1.832712e+00)*S137+(-4.933052e+00)*S138+(-3.319349e+00)*S139'
.param V6_part15='V6_part14+(-1.594447e+00)*S140+(-1.075071e+01)*S141+(-1.156076e+01)*S142+(-1.457949e+00)*S143+(-1.558117e+01)*S144+(-1.786104e+01)*S145+(-2.724792e+00)*S146+(-2.715813e+01)*S147+(-1.624786e+01)*S148+(-7.048947e+00)*S149'
.param V6_part16='V6_part15+(-6.591141e+02)*S150+(-2.524042e+01)*S151+3.642630e-01*S152+(-1.362729e+01)*S153+(-4.679551e+01)*S154+(-2.521729e+00)*S155+(-1.169272e+01)*S156+(-4.742230e+00)*S157+(-2.003368e+00)*S158+1.206671e+00*S159'
.param V6_part17='V6_part16+(-2.728913e+00)*S160+3.960079e-01*S161+(-1.166885e+00)*S162+8.144521e-01*S163+4.139392e-01*S164+1.138092e+00*S165+1.068823e+00*S166+7.542891e+00*S167+(-4.045547e+00)*S168+(-1.209684e+01)*S169'
.param V6_part18='V6_part17+(-2.705777e+00)*S170+(-4.031490e+00)*S171+9.621370e-01*S172+(-9.024903e+00)*S173+1.359669e+00*S174+(-6.312853e-01)*S175+(-5.108267e+00)*S176+1.284611e+00*S177+(-2.399808e+00)*S178+(-4.330414e+00)*S179'
.param V6_part19='V6_part18+1.154521e+01*S180+(-5.053508e+00)*S181+9.964968e-02*S182+(-7.126176e+00)*S183+2.543834e+00*S184+3.256013e-01*S185+(-2.077693e+00)*S186+(-4.319616e+00)*S187+(-1.278284e+00)*S188+1.419060e+00*S189'
.param V6_part20='V6_part19+(-1.128412e+00)*S190+(-3.497136e+00)*S191+1.335760e+00*S192+(-2.262688e+00)*S193+(-3.781627e+00)*S194+(-5.760412e+00)*S195+(-8.491793e+00)*S196+6.658682e+00*S197+(-9.865404e+00)*S198+(-1.444857e+01)*S199'
.param V6_part21='V6_part20+(-1.587058e+00)*S200+(-1.393464e+01)*S201+(-1.287255e+01)*S202+(-3.972685e+00)*S203+(-1.317090e+01)*S204+(-4.637667e+00)*S205+(-5.373040e+00)*S206+(-7.602824e-01)*S207+(-1.782940e+01)*S208+(-3.115702e+00)*S209'
.param V6_part22='V6_part21+9.847358e+00*S210+(-5.284982e+02)*S211+4.567215e-01*S212+(-4.547345e+00)*S213+1.114347e+00*S214+3.319560e-01*S215+1.619176e+00*S216+1.109824e+00*S217+5.053181e-01*S218+1.674030e+00*S219'
.param V6_part23='V6_part22+(-2.378215e+00)*S220+5.292655e-01*S221+1.594250e+00*S222+(-3.519012e+00)*S223+(-1.343507e+01)*S224+1.378563e+00*S225+9.109731e-01*S226+3.639245e-01*S227+1.760240e+00*S228+9.868471e-01*S229'
.param V6_part24='V6_part23+3.368213e-01*S230+1.773575e+00*S231+1.040717e+00*S232+4.897973e-01*S233+1.829643e+00*S234+9.672575e-01*S235+3.693117e-01*S236+1.692670e+00*S237+(-2.359292e+00)*S238+(-3.734918e+00)*S239'
.param V6_part25='V6_part24+1.589649e+00*S240+(-2.268859e-01)*S241+3.973415e-01*S242+2.754442e+00*S243+1.324942e+00*S244+3.580187e-01*S245+2.259517e+00*S246+1.342325e+00*S247+(-5.169975e-01)*S248+2.095556e+00*S249'
.param V6_part26='V6_part25+1.158912e+00*S250+(-2.486986e+00)*S251+1.897235e+00*S252+(-5.014433e+00)*S253+(-8.281844e+00)*S254+(-1.440712e+01)*S255+(-7.956881e-01)*S256+3.692981e+00*S257+(-4.642064e+01)*S258+1.440818e+00*S259'
.param V6_part27='V6_part26+(-5.934446e-01)*S260+(-1.961633e+00)*S261+(-2.174814e+00)*S262+(-1.685471e+00)*S263+(-3.086022e+00)*S264+(-2.415692e+00)*S265+(-3.142483e+00)*S266+1.442947e+00*S267+(-5.084963e+00)*S268+(-3.945887e+00)*S269'
.param V6_part28='V6_part27+(-3.201306e+00)*S270+(-2.872307e+00)*S271+(-1.514503e-01)*S272+(-1.640194e+00)*S273+(-5.855952e-03)*S274+(-5.663355e-01)*S275+(-2.188939e+00)*S276+(-6.263819e-01)*S277+(-2.641345e+00)*S278+(-2.837812e+00)*S279'
.param V6_part29='V6_part28+(-3.634766e+00)*S280+(-9.074930e+00)*S281+1.607515e+01*S282+(-6.042858e+00)*S283+(-4.880486e+00)*S284+(-1.842077e-02)*S285+(-2.043081e+00)*S286+4.422058e-02*S287+(-5.430545e-02)*S288+(-1.898164e+00)*S289'
.param V6_part30='V6_part29+(-1.257415e-01)*S290+3.583088e+00*S291+1.636679e+00*S292+(-2.108264e+00)*S293+3.934640e+00*S294+1.414659e+00*S295+(-2.824171e+00)*S296+(-2.925950e+00)*S297+1.366694e+00*S298+(-1.645397e+00)*S299'
.param V6_part31='V6_part30+(-1.885330e+00)*S300+3.216063e+00*S301+1.648624e-01*S302+(-2.962423e+00)*S303+1.037054e+00*S304+(-2.001588e-02)*S305+(-2.332505e+00)*S306+(-2.780164e+00)*S307+(-1.224818e+00)*S308+1.904277e+00*S309'
.param V6='V6_part31+(-2.506541e+00)*S310+(-6.408591e+00)*S311+3.672912e-01*S312+1.207853e+00*S313+(-4.710877e+00)*S314'
.param V7_part1='2.675669e-02*S0+2.853873e-02*S1+3.158583e-02*S2+3.508479e-02*S3+3.531895e-02*S4+4.031734e-02*S5+4.577130e-02*S6+4.519212e-02*S7+4.785058e-02*S8+5.549941e-02*S9'
.param V7_part2='V7_part1+5.575695e-02*S10+5.824341e-02*S11+6.363774e-02*S12+6.620737e-02*S13+6.742413e-02*S14+(-2.476004e-02)*S15+3.467122e-02*S16+3.897649e-02*S17+6.363447e-01*S18+7.967041e-02*S19'
.param V7_part3='V7_part2+5.085526e-02*S20+7.886207e-01*S21+3.648164e-01*S22+6.498558e-02*S23+7.642315e-01*S24+7.480589e-02*S25+5.416865e-01*S26+6.706174e-01*S27+1.123929e-01*S28+6.707751e-01*S29'
.param V7_part4='V7_part3+5.682809e-02*S30+1.028021e-01*S31+3.377901e-01*S32+1.937570e+00*S33+6.532804e-02*S34+4.397971e+00*S35+3.007349e+00*S36+8.752433e-02*S37+9.404004e-02*S38+1.247288e-01*S39'
.param V7_part5='V7_part4+1.072734e-01*S40+1.225977e-01*S41+1.467758e-01*S42+1.305634e-01*S43+1.610274e-01*S44+1.512470e+00*S45+3.928235e-01*S46+1.013583e+00*S47+1.555608e+00*S48+1.376719e+00*S49'
.param V7_part6='V7_part5+8.686527e-02*S50+1.208209e-01*S51+1.012240e-01*S52+1.292413e-01*S53+1.334264e-01*S54+1.277987e-01*S55+1.680278e-01*S56+1.717382e-01*S57+1.632735e-01*S58+1.187204e-01*S59'
.param V7_part7='V7_part6+1.076253e+00*S60+4.081037e-01*S61+1.970139e+00*S62+1.484824e+00*S63+1.236413e+00*S64+3.958927e+00*S65+2.672542e+00*S66+1.171438e+00*S67+4.828723e+00*S68+2.847676e+00*S69'
.param V7_part8='V7_part7+2.176979e+00*S70+6.108904e+00*S71+4.279835e+00*S72+8.147169e+00*S73+1.399359e+00*S74+4.333502e-01*S75+(-6.541537e-02)*S76+7.344794e-01*S77+6.703645e-01*S78+2.279297e-02*S79'
.param V7_part9='V7_part8+5.508994e-02*S80+1.211267e+00*S81+2.781329e-01*S82+1.137345e+00*S83+1.604337e+00*S84+9.689672e-01*S85+1.584774e+00*S86+2.280553e+00*S87+1.242764e+00*S88+1.635406e+00*S89'
.param V7_part10='V7_part9+9.832301e-02*S90+1.647534e+00*S91+1.169632e+00*S92+1.309501e-01*S93+4.132385e+00*S94+1.501867e-01*S95+1.687056e-01*S96+1.792184e-01*S97+2.123283e+00*S98+5.263878e+00*S99'
.param V7_part11='V7_part10+2.118956e-01*S100+3.363765e+00*S101+2.512514e-01*S102+2.536903e-01*S103+4.864836e+00*S104+1.946756e+00*S105+2.369224e+00*S106+7.067091e-01*S107+2.967259e+00*S108+3.313982e+00*S109'
.param V7_part12='V7_part11+2.006162e+00*S110+3.690207e+00*S111+6.174200e+00*S112+2.441702e+00*S113+4.946698e+00*S114+6.473677e+00*S115+1.967725e+00*S116+2.289173e+00*S117+7.693643e+00*S118+2.390344e+00*S119'
.param V7_part13='V7_part12+2.051465e+00*S120+2.392091e+00*S121+1.021473e+00*S122+3.969083e+00*S123+3.343116e+00*S124+1.194057e+00*S125+2.093607e-01*S126+5.369315e+00*S127+2.094718e+00*S128+3.941331e+00*S129'
.param V7_part14='V7_part13+6.995343e+00*S130+2.344687e+00*S131+3.055207e-01*S132+4.004283e+00*S133+1.591754e+00*S134+1.114521e+00*S135+1.667180e-01*S136+1.784187e+00*S137+2.170845e+00*S138+1.192765e+00*S139'
.param V7_part15='V7_part14+1.292456e+00*S140+3.451418e+00*S141+4.231742e+00*S142+1.703883e+00*S143+4.799426e+00*S144+6.583281e+00*S145+2.167471e+00*S146+7.163770e+00*S147+6.509017e+00*S148+3.734767e+00*S149'
.param V7_part16='V7_part15+1.119498e+02*S150+7.067710e+00*S151+1.572794e-01*S152+4.187446e+00*S153+1.222154e+02*S154+1.578383e+00*S155+5.011999e+00*S156+4.646435e+00*S157+2.149914e+00*S158+3.091774e-01*S159'
.param V7_part17='V7_part16+4.669600e+00*S160+2.968414e-01*S161+3.097606e+00*S162+3.468789e-01*S163+3.604316e-01*S164+1.492768e-01*S165+1.260352e-01*S166+8.838500e+00*S167+2.643210e+00*S168+1.223814e+01*S169'
.param V7_part18='V7_part17+1.801306e+00*S170+3.712142e+00*S171+2.395373e-01*S172+4.891455e+00*S173+3.524885e-01*S174+2.855449e+00*S175+4.435557e+00*S176+4.051459e-01*S177+4.121584e+00*S178+3.738240e+00*S179'
.param V7_part19='V7_part18+5.487215e+00*S180+2.539964e+00*S181+3.877521e-01*S182+4.323921e+00*S183+5.344203e-01*S184+2.162505e-01*S185+4.285548e+00*S186+3.507303e+00*S187+3.683118e+00*S188+3.610432e-01*S189'
.param V7_part20='V7_part19+2.040711e+00*S190+4.819954e+00*S191+4.123870e-01*S192+2.209207e+00*S193+2.723899e+00*S194+1.962125e+00*S195+9.082642e+00*S196+5.817002e+00*S197+3.280509e+00*S198+9.601436e+00*S199'
.param V7_part21='V7_part20+9.550001e+00*S200+4.194058e+00*S201+3.651826e+00*S202+5.694858e+00*S203+5.108836e+00*S204+3.851583e+00*S205+3.729115e+00*S206+2.853373e+00*S207+8.930781e+00*S208+2.966941e+00*S209'
.param V7_part22='V7_part21+2.066822e+00*S210+3.264334e+00*S211+1.884212e-01*S212+3.768753e+00*S213+2.361064e-01*S214+2.460711e-01*S215+3.329832e-01*S216+3.050183e-01*S217+3.368970e-01*S218+4.147244e-01*S219'
.param V7_part23='V7_part22+4.682194e+00*S220+4.179882e-01*S221+4.807699e-01*S222+4.411865e+00*S223+9.810205e+00*S224+1.895836e-01*S225+1.644462e-01*S226+1.783008e-01*S227+2.691617e-01*S228+2.258799e-01*S229'
.param V7_part24='V7_part23+2.503145e-01*S230+3.608300e-01*S231+2.948807e-01*S232+3.835168e-01*S233+4.403548e-01*S234+3.726952e-01*S235+4.073532e-01*S236+5.046544e-01*S237+4.006157e+00*S238+3.024674e+00*S239'
.param V7_part25='V7_part24+1.600266e-01*S240+1.792233e+00*S241+1.062587e+00*S242+3.082257e-01*S243+2.405222e-01*S244+9.975070e-01*S245+3.531618e-01*S246+9.006398e-01*S247+1.274442e+00*S248+4.174659e-01*S249'
.param V7_part26='V7_part25+4.425580e-01*S250+2.920952e+00*S251+5.171792e-01*S252+2.636949e+00*S253+7.474393e+00*S254+5.763005e+00*S255+9.120374e+00*S256+3.015039e+00*S257+1.238090e+01*S258+1.160447e+00*S259'
.param V7_part27='V7_part26+1.046426e+00*S260+4.517690e+00*S261+3.426750e+00*S262+1.980833e+00*S263+4.401750e+00*S264+4.515501e+00*S265+3.507105e+00*S266+4.406067e-01*S267+6.283936e+00*S268+4.972015e+00*S269'
.param V7_part28='V7_part27+3.873954e+00*S270+3.551255e+00*S271+1.019209e+00*S272+3.185831e+00*S273+1.695794e+00*S274+1.267427e+00*S275+2.960153e+00*S276+1.419704e+00*S277+2.596779e+00*S278+2.940640e+00*S279'
.param V7_part29='V7_part28+1.809593e+00*S280+5.355004e+00*S281+5.023803e+01*S282+3.081963e+00*S283+4.061532e+00*S284+2.102661e+00*S285+3.336324e+00*S286+1.624767e+00*S287+2.486709e+00*S288+3.756689e+00*S289'
.param V7_part30='V7_part29+1.461966e+00*S290+3.760266e-01*S291+3.810423e-01*S292+1.869398e+00*S293+5.172759e-01*S294+5.048567e-01*S295+2.126912e+00*S296+2.524306e+00*S297+6.269610e-01*S298+1.522299e+00*S299'
.param V7_part31='V7_part30+4.695896e+00*S300+4.909088e-01*S301+1.086550e+00*S302+4.221288e+00*S303+1.180469e+00*S304+1.013848e+00*S305+3.169345e+00*S306+3.404026e+00*S307+2.026417e+00*S308+4.921293e-01*S309'
.param V7='V7_part31+2.368744e+00*S310+4.893649e+00*S311+4.175954e+00*S312+5.522935e-01*S313+3.270868e+00*S314'
.param V8_part1='4.462829e-02*S0+2.733026e-02*S1+1.823364e-02*S2+4.249351e-02*S3+2.682490e-02*S4+1.680784e-02*S5+4.023003e-02*S6+2.539216e-02*S7+1.612839e-02*S8+3.998982e-02*S9'
.param V8_part2='V8_part1+2.541808e-02*S10+1.577311e-02*S11+3.884237e-02*S12+2.478410e-02*S13+1.567749e-02*S14+5.100747e+00*S15+1.403228e+02*S16+1.807305e-02*S17+4.629168e+00*S18+1.324446e+00*S19'
.param V8_part3='V8_part2+1.872773e-02*S20+3.255666e+00*S21+1.546169e+00*S22+1.848534e-02*S23+2.605887e+00*S24+2.888900e-02*S25+7.821711e-01*S26+2.912534e+00*S27+1.362306e+00*S28+1.158361e+00*S29'
.param V8_part4='V8_part3+3.945870e-02*S30+8.519397e-01*S31+(-4.188618e-01)*S32+2.598458e+00*S33+2.402377e-02*S34+1.071998e+00*S35+3.644498e+00*S36+2.319200e-02*S37+5.342189e-03*S38+3.932413e-02*S39'
.param V8_part5='V8_part4+2.252036e-02*S40+(-4.163111e-03)*S41+3.702592e-02*S42+1.737025e-02*S43+(-1.302393e-02)*S44+1.277786e+00*S45+9.347196e-01*S46+(-1.803627e-03)*S47+1.095426e+00*S48+5.323272e-01*S49'
.param V8_part6='V8_part5+1.085253e-03*S50+3.426333e-02*S51+1.882322e-02*S52+(-1.086376e-02)*S53+4.460122e-02*S54+1.837151e-02*S55+(-1.014237e-02)*S56+2.658254e-02*S57+6.233809e-03*S58+2.875196e-02*S59'
.param V8_part7='V8_part6+1.381352e+00*S60+1.189797e+00*S61+2.604897e-02*S62+1.683873e+00*S63+1.378903e+00*S64+(-5.665022e-01)*S65+1.782669e+00*S66+6.171245e-01*S67+(-8.295124e-01)*S68+8.411941e-01*S69'
.param V8_part8='V8_part7+1.514403e-01*S70+(-7.669853e-02)*S71+3.997170e-02*S72+(-1.544011e-01)*S73+(-7.683275e-01)*S74+8.229640e-01*S75+4.745511e-01*S76+3.415122e-01*S77+7.538106e-01*S78+7.851415e-01*S79'
.param V8_part9='V8_part8+1.632445e-02*S80+1.697081e+00*S81+1.032526e+00*S82+5.501463e-01*S83+2.250711e+00*S84+2.576406e+00*S85+7.786905e-01*S86+3.136917e+00*S87+2.833394e+00*S88+7.392098e-01*S89'
.param V8_part10='V8_part9+3.905150e-02*S90+1.256055e+00*S91+3.130390e-01*S92+3.086350e-02*S93+1.401815e+00*S94+1.047658e-02*S95+2.489585e-02*S96+1.235390e-02*S97+5.040556e-01*S98+(-2.848734e-01)*S99'
.param V8_part11='V8_part10+4.061286e-03*S100+7.238324e-01*S101+1.920491e-02*S102+(-4.198265e-03)*S103+1.334414e+00*S104+1.051298e+00*S105+7.934515e-01*S106+2.771737e-01*S107+4.148296e-01*S108+7.123940e-01*S109'
.param V8_part12='V8_part11+5.541864e-01*S110+4.442680e-01*S111+3.092285e+00*S112+7.704521e-01*S113+2.480405e+00*S114+4.650475e+00*S115+6.422029e-01*S116+1.176734e+00*S117+4.544587e+00*S118+6.936771e-01*S119'
.param V8_part13='V8_part12+1.467501e+00*S120+4.378608e-01*S121+3.335447e-01*S122+1.305876e-01*S123+6.094835e-01*S124+2.912290e-01*S125+2.291493e-02*S126+1.678915e+00*S127+4.343017e-01*S128+2.829536e+00*S129'
.param V8_part14='V8_part13+2.741885e+00*S130+4.428699e-01*S131+1.796466e-02*S132+8.213599e-01*S133+4.951965e-01*S134+1.437432e+00*S135+9.486940e-01*S136+3.717564e-01*S137+1.336397e+00*S138+6.629926e-01*S139'
.param V8_part15='V8_part14+3.107427e-01*S140+1.397663e+00*S141+5.333238e-01*S142+3.399391e-01*S143+1.626114e+00*S144+2.046552e+00*S145+3.763294e-01*S146+2.939093e+00*S147+2.328356e+00*S148+1.188660e+00*S149'
.param V8_part16='V8_part15+(-5.625890e+00)*S150+(-7.310680e-01)*S151+(-1.680917e-02)*S152+1.664317e+00*S153+1.904184e+00*S154+3.413970e-01*S155+2.184026e+00*S156+1.989011e+00*S157+4.584327e-01*S158+1.344157e-02*S159'
.param V8_part17='V8_part16+1.472702e+00*S160+(-1.224634e-02)*S161+1.977084e+00*S162+9.197978e-03*S163+(-3.767873e-03)*S164+4.338779e-02*S165+6.428434e-03*S166+(-7.622725e-01)*S167+1.681003e+00*S168+(-4.222240e-01)*S169'
.param V8_part18='V8_part17+5.879494e-01*S170+3.262512e+00*S171+7.216410e-03*S172+1.895321e+00*S173+2.033357e-02*S174+2.278914e+00*S175+1.319204e+00*S176+3.390094e-02*S177+1.436880e+00*S178+1.089312e+00*S179'
.param V8_part19='V8_part18+(-2.868179e+00)*S180+9.298233e-01*S181+(-3.258215e-02)*S182+3.879180e+00*S183+(-1.447852e-01)*S184+1.812713e-02*S185+2.259907e+00*S186+1.529264e+00*S187+7.153656e-01*S188+1.764701e-02*S189'
.param V8_part20='V8_part19+4.521341e-01*S190+8.578877e-01*S191+2.111046e-02*S192+2.711834e-01*S193+6.076468e-01*S194+1.288357e+00*S195+(-1.221578e+00)*S196+(-9.199510e-01)*S197+1.052324e+00*S198+(-1.566425e+00)*S199'
.param V8_part21='V8_part20+(-8.197532e-01)*S200+1.597198e+00*S201+1.602800e+00*S202+(-1.536957e-01)*S203+2.971600e+00*S204+2.932203e+00*S205+1.099076e+00*S206+2.138156e+00*S207+3.479211e+00*S208+8.623630e-01*S209'
.param V8_part22='V8_part21+(-8.411291e-01)*S210+(-1.723901e+01)*S211+1.398618e-02*S212+3.217880e+00*S213+8.997423e-02*S214+8.327083e-03*S215+(-1.191762e-03)*S216+6.002443e-03*S217+(-1.689549e-02)*S218+6.931032e-03*S219'
.param V8_part23='V8_part22+2.198877e+00*S220+(-1.646066e-02)*S221+1.904502e-02*S222+2.099408e+00*S223+(-1.444742e+00)*S224+4.012910e-02*S225+3.663876e-02*S226+2.335014e-02*S227+1.611738e-02*S228+3.603041e-02*S229'
.param V8_part24='V8_part23+1.602153e-02*S230+4.627098e-02*S231+3.383788e-02*S232+1.956973e-02*S233+4.789006e-02*S234+4.461815e-02*S235+1.969689e-02*S236+3.327695e-02*S237+1.467438e+00*S238+(-1.792279e-01)*S239'
.param V8_part25='V8_part24+7.052366e-02*S240+(-6.668696e-02)*S241+(-1.748431e-01)*S242+4.589738e-02*S243+(-4.698621e-03)*S244+(-8.996043e-02)*S245+8.439672e-02*S246+(-2.399661e-02)*S247+(-9.388234e-03)*S248+1.158873e-01*S249'
.param V8_part26='V8_part25+1.534983e-02*S250+3.434124e-03*S251+9.549338e-02*S252+1.567369e-01*S253+(-5.253927e-01)*S254+(-1.443181e+00)*S255+(-1.303052e+00)*S256+(-3.407375e-01)*S257+(-2.880925e+00)*S258+9.913759e-02*S259'
.param V8_part27='V8_part26+6.265224e-02*S260+3.374019e+00*S261+1.329509e+00*S262+4.567425e-01*S263+3.453789e+00*S264+2.451977e+00*S265+1.072553e+00*S266+2.467291e-02*S267+3.195229e+00*S268+1.942004e+00*S269'
.param V8_part28='V8_part27+1.845329e-01*S270+1.583864e+00*S271+5.677082e-02*S272+1.003991e+00*S273+1.173808e-01*S274+1.762796e-02*S275+7.279939e-02*S276+1.110857e-01*S277+(-5.365844e-02)*S278+1.029840e-01*S279'
.param V8_part29='V8_part28+3.222004e-01*S280+8.406489e-02*S281+4.889078e+00*S282+3.769261e-02*S283+(-2.245063e-01)*S284+1.276617e-02*S285+1.512684e+00*S286+(-9.287980e-02)*S287+2.670638e-02*S288+1.956024e+00*S289'
.param V8_part30='V8_part29+2.943646e-02*S290+6.437029e-02*S291+4.124005e-02*S292+1.231749e-02*S293+6.637641e-02*S294+1.000850e-02*S295+9.813721e-03*S296+8.548438e-01*S297+4.222192e-03*S298+(-4.486740e-02)*S299'
.param V8_part31='V8_part30+6.410932e-01*S300+(-4.624908e-03)*S301+(-1.042239e-01)*S302+2.253201e-01*S303+1.114070e-01*S304+3.209797e-02*S305+1.493048e-01*S306+1.871371e+00*S307+(-2.284899e-03)*S308+1.451456e-02*S309'
.param V8='V8_part31+7.009438e-01*S310+1.183692e-01*S311+5.522210e+00*S312+6.240003e-03*S313+(-1.082613e-01)*S314'
.param V9_part1='(-1.095396e-04)*S0+(-4.815360e-05)*S1+3.503961e-05*S2+1.236026e-04*S3+1.030022e-04*S4+3.217572e-05*S5+7.795766e-05*S6+3.362555e-06*S7+(-2.440733e-05)*S8+2.031084e-05*S9'
.param V9_part2='V9_part1+(-1.321249e-04)*S10+(-2.944383e-08)*S11+3.324904e-04*S12+3.002290e-08*S13+2.390174e-08*S14+2.207043e-02*S15+3.770972e-02*S16+2.672772e-04*S17+1.926039e-02*S18+1.516604e-02*S19'
.param V9_part3='V9_part2+1.985872e-04*S20+(-2.287797e-03)*S21+7.245853e-03*S22+2.025602e-04*S23+1.824307e-02*S24+5.228138e-04*S25+9.171737e-03*S26+1.249076e-02*S27+1.185561e-02*S28+4.567422e-03*S29'
.param V9_part4='V9_part3+9.410952e-03*S30+6.268659e-02*S31+1.929144e-02*S32+2.751843e-01*S33+4.275007e-03*S34+5.903111e-02*S35+6.557913e-01*S36+5.511387e-03*S37+3.579879e-03*S38+8.148724e-03*S39'
.param V9_part5='V9_part4+5.188384e-03*S40+3.223593e-03*S41+8.132157e-03*S42+4.894570e-03*S43+3.115646e-03*S44+(-8.974344e-02)*S45+(-1.433299e-02)*S46+7.261660e-05*S47+6.860429e-02*S48+2.491185e-01*S49'
.param V9_part6='V9_part5+5.869672e-03*S50+9.207495e-03*S51+5.095464e-03*S52+3.402074e-03*S53+7.591340e-03*S54+5.772190e-03*S55+2.436649e-03*S56+7.714235e-03*S57+2.806640e-03*S58+(-3.124578e-03)*S59'
.param V9_part7='V9_part6+(-2.880978e-02)*S60+3.362666e-02*S61+1.397331e-02*S62+(-4.034128e-02)*S63+1.668705e-01*S64+(-6.382248e-02)*S65+5.440100e-01*S66+3.074232e-01*S67+(-7.403196e-03)*S68+7.017168e-01*S69'
.param V9_part8='V9_part7+4.131691e-01*S70+(-2.118336e-02)*S71+1.023624e+00*S72+1.024642e-01*S73+4.874581e-02*S74+(-3.472106e-01)*S75+(-2.210608e-01)*S76+(-1.841008e-01)*S77+(-2.736302e-01)*S78+(-2.244975e-01)*S79'
.param V9_part9='V9_part8+5.984322e-04*S80+(-2.372992e-01)*S81+(-1.960961e-01)*S82+(-2.558117e-01)*S83+(-4.284856e-01)*S84+(-4.640318e-01)*S85+(-3.104677e-01)*S86+(-3.329180e-01)*S87+(-2.030477e-01)*S88+(-2.208870e-01)*S89'
.param V9_part10='V9_part9+3.075804e-02*S90+(-1.589414e-01)*S91+(-2.139445e-01)*S92+2.155249e-02*S93+(-2.813065e-02)*S94+2.753922e-03*S95+1.647947e-02*S96+6.178049e-03*S97+(-1.974760e-01)*S98+7.481235e-01*S99'
.param V9_part11='V9_part10+3.360258e-03*S100+(-2.615710e-01)*S101+1.511153e-02*S102+1.979924e-03*S103+(-2.532975e-01)*S104+(-2.852341e-01)*S105+(-3.487657e-01)*S106+(-2.232591e-01)*S107+(-2.519457e-02)*S108+(-2.432640e-01)*S109'
.param V9_part12='V9_part11+(-3.678154e-01)*S110+2.598867e-01*S111+(-6.393961e-01)*S112+(-4.456813e-01)*S113+4.100067e-01*S114+(-3.852711e-01)*S115+(-3.052298e-01)*S116+4.595345e-01*S117+(-2.923587e-01)*S118+5.595127e-02*S119'
.param V9_part13='V9_part12+(-4.590405e-01)*S120+(-2.530852e-01)*S121+(-3.033197e-01)*S122+(-6.855524e-01)*S123+(-4.204149e-01)*S124+(-2.689333e-01)*S125+2.736187e-02*S126+(-7.234551e-01)*S127+(-3.390080e-01)*S128+4.214934e-01*S129'
.param V9_part14='V9_part13+(-5.176513e-01)*S130+(-1.100561e-01)*S131+2.539535e-02*S132+(-7.306314e-02)*S133+(-5.522339e-02)*S134+(-5.108498e-01)*S135+(-3.863113e-01)*S136+(-1.549032e-01)*S137+(-1.171085e-01)*S138+(-2.586003e-01)*S139'
.param V9_part15='V9_part14+(-1.014588e-01)*S140+(-2.206582e-02)*S141+(-4.044079e-01)*S142+(-1.139454e-01)*S143+(-8.950494e-02)*S144+(-6.189126e-01)*S145+(-1.987586e-01)*S146+(-3.778208e-01)*S147+(-5.698703e-01)*S148+(-2.598240e-01)*S149'
.param V9_part16='V9_part15+4.801774e+01*S150+2.620666e-01*S151+1.465522e-02*S152+(-3.961456e-01)*S153+(-1.094374e+01)*S154+(-2.759221e-01)*S155+(-3.164736e-02)*S156+(-3.941611e-01)*S157+(-2.622739e-01)*S158+4.811655e-02*S159'
.param V9_part17='V9_part16+(-5.340813e-01)*S160+1.686599e-02*S161+(-3.400528e-01)*S162+3.501765e-02*S163+1.284814e-02*S164+4.498877e-02*S165+5.885265e-02*S166+(-8.217059e-01)*S167+(-6.185151e-02)*S168+1.336616e-01*S169'
.param V9_part18='V9_part17+(-4.732492e-01)*S170+1.114044e-01*S171+4.243574e-02*S172+(-1.300554e+00)*S173+6.952996e-02*S174+1.852125e-01*S175+(-5.449208e-01)*S176+5.512295e-02*S177+(-2.498869e-01)*S178+(-2.883059e-01)*S179'
.param V9_part19='V9_part18+(-1.476094e+00)*S180+(-6.546951e-01)*S181+4.140173e-02*S182+(-1.513924e-01)*S183+5.026630e-02*S184+1.672098e-02*S185+(-5.709429e-01)*S186+(-4.049064e-01)*S187+(-4.833739e-01)*S188+6.890264e-02*S189'
.param V9_part20='V9_part19+(-9.123238e-02)*S190+(-4.663912e-01)*S191+6.097690e-02*S192+9.757568e-02*S193+(-1.601501e-01)*S194+(-2.605214e-01)*S195+(-7.859711e-01)*S196+(-7.216105e-01)*S197+(-6.269192e-01)*S198+(-1.067059e+00)*S199'
.param V9_part21='V9_part20+(-9.553266e-01)*S200+(-8.957516e-01)*S201+(-1.071310e+00)*S202+(-3.726232e-01)*S203+(-1.047447e+00)*S204+(-7.257897e-01)*S205+(-5.645395e-01)*S206+(-2.790142e-01)*S207+(-1.430823e+00)*S208+(-4.012102e-01)*S209'
.param V9_part22='V9_part21+(-5.711474e-02)*S210+3.155863e+01*S211+1.993803e-02*S212+(-3.726186e-01)*S213+9.790003e-02*S214+2.104450e-02*S215+9.302212e-02*S216+7.026421e-02*S217+3.959586e-02*S218+1.083683e-01*S219'
.param V9_part23='V9_part22+(-3.026856e-01)*S220+3.839214e-02*S221+1.044703e-01*S222+(-1.953805e-02)*S223+6.324969e-01*S224+7.262440e-02*S225+7.357136e-02*S226+3.547787e-02*S227+1.109345e-01*S228+7.069648e-02*S229'
.param V9_part24='V9_part23+3.998983e-02*S230+1.272918e-01*S231+6.424959e-02*S232+4.400482e-02*S233+1.339856e-01*S234+7.430070e-02*S235+3.638310e-02*S236+1.009107e-01*S237+(-7.922401e-02)*S238+1.184562e-02*S239'
.param V9_part25='V9_part24+1.976389e-01*S240+6.687196e-02*S241+4.827758e-02*S242+1.612678e-01*S243+9.093540e-02*S244+5.121156e-02*S245+1.403787e-01*S246+1.726338e-01*S247+4.597355e-02*S248+1.106150e-01*S249'
.param V9_part26='V9_part25+6.328053e-02*S250+(-1.755723e-01)*S251+9.160545e-02*S252+3.000137e-01*S253+(-4.122456e-01)*S254+(-1.469291e+00)*S255+(-9.878908e-01)*S256+(-5.611855e-01)*S257+(-2.764960e+00)*S258+(-1.333666e-02)*S259'
.param V9_part27='V9_part26+(-9.056110e-03)*S260+(-8.225087e-01)*S261+(-5.998972e-01)*S262+(-3.073616e-01)*S263+(-7.457295e-01)*S264+(-7.792638e-01)*S265+(-5.212463e-01)*S266+7.221848e-02*S267+(-6.207299e-01)*S268+(-7.516431e-01)*S269'
.param V9_part28='V9_part27+(-9.571759e-01)*S270+(-1.096393e+00)*S271+3.355881e-03*S272+(-5.903610e-01)*S273+1.419936e-01*S274+5.543762e-02*S275+(-3.010575e-02)*S276+1.363892e-01*S277+(-7.561281e-02)*S278+1.577479e-01*S279'
.param V9_part29='V9_part28+3.864695e-01*S280+(-2.830610e-01)*S281+3.551542e+00*S282+3.101133e-01*S283+(-2.486941e-02)*S284+(-2.978157e-01)*S285+(-1.048691e+00)*S286+7.679252e-02*S287+8.698697e-02*S288+(-7.849663e-01)*S289'
.param V9_part30='V9_part29+3.769368e-02*S290+2.355094e-01*S291+1.241760e-01*S292+7.447013e-02*S293+2.408359e-01*S294+1.213873e-01*S295+6.402114e-02*S296+8.914129e-01*S297+1.205248e-01*S298+1.772997e-01*S299'
.param V9_part31='V9_part30+9.354270e-02*S300+1.703064e-02*S301+3.747921e-02*S302+(-6.300800e-02)*S303+2.145590e-02*S304+1.122034e-02*S305+2.332896e-01*S306+(-3.313941e-01)*S307+(-7.841434e-03)*S308+1.399627e-01*S309'
.param V9='V9_part31+1.497067e-01*S310+(-2.084894e-01)*S311+1.077075e+00*S312+9.916529e-02*S313+(-7.109580e-03)*S314'
.param V10_part1='1.808345e-02*S0+1.636549e-02*S1+1.793741e-02*S2+1.974392e-02*S3+1.872850e-02*S4+1.994020e-02*S5+2.119289e-02*S6+2.005648e-02*S7+2.215366e-02*S8+2.104899e-02*S9'
.param V10_part2='V10_part1+2.072066e-02*S10+2.348222e-02*S11+2.038547e-02*S12+2.166229e-02*S13+2.400245e-02*S14+3.847886e-02*S15+5.870479e-01*S16+1.484009e-02*S17+7.132599e-02*S18+3.991461e-02*S19'
.param V10_part3='V10_part2+1.704657e-02*S20+6.116777e-02*S21+3.906855e-02*S22+1.770400e-02*S23+5.299316e-02*S24+1.293700e-02*S25+3.018707e-02*S26+5.997058e-02*S27+4.256033e-02*S28+3.448627e-02*S29'
.param V10_part4='V10_part3+1.793168e-02*S30+5.184353e-02*S31+6.410954e-02*S32+8.673976e-02*S33+1.333597e-02*S34+1.431830e-01*S35+1.180641e-01*S36+1.007371e-02*S37+2.315526e-02*S38+1.155992e-02*S39'
.param V10_part5='V10_part4+1.036801e-02*S40+1.286519e-02*S41+8.714440e-03*S42+9.814044e-03*S43+(-1.580516e-03)*S44+8.944210e-02*S45+6.803115e-02*S46+3.004087e-02*S47+7.661720e-02*S48+9.964072e-02*S49'
.param V10_part6='V10_part5+3.018847e-02*S50+1.246675e-02*S51+1.113975e-02*S52+3.946262e-03*S53+2.088564e-02*S54+1.176625e-02*S55+(-1.073723e-02)*S56+(-4.637807e-03)*S57+(-9.653926e-03)*S58+6.327535e-02*S59'
.param V10_part7='V10_part6+5.211924e-02*S60+6.349286e-02*S61+3.679927e-02*S62+5.667781e-02*S63+7.359752e-02*S64+3.223858e-02*S65+9.668944e-02*S66+3.077226e-02*S67+3.347096e-02*S68+8.454941e-02*S69'
.param V10_part8='V10_part7+3.079440e-02*S70+1.725773e-01*S71+1.318702e-01*S72+1.682243e-01*S73+(-9.541116e-02)*S74+1.796466e-02*S75+1.203102e-02*S76+2.349529e-02*S77+3.094553e-02*S78+2.743210e-02*S79'
.param V10_part9='V10_part8+1.471800e-03*S80+5.935490e-02*S81+7.244893e-02*S82+4.161355e-02*S83+6.946255e-02*S84+1.136171e-01*S85+5.350657e-02*S86+8.389255e-02*S87+1.108100e-01*S88+4.100865e-02*S89'
.param V10_part10='V10_part9+1.707595e-02*S90+7.949527e-02*S91+5.185655e-02*S92+2.457282e-03*S93+1.232046e-01*S94+1.012144e-02*S95+(-9.418317e-03)*S96+(-4.710082e-02)*S97+2.404471e-01*S98+2.722614e-01*S99'
.param V10_part11='V10_part10+(-5.271312e-02)*S100+5.152533e-01*S101+(-3.761711e-02)*S102+(-6.235139e-02)*S103+7.510063e-01*S104+1.214285e-01*S105+1.134793e-01*S106+5.352317e-02*S107+1.678872e-01*S108+1.940273e-01*S109'
.param V10_part12='V10_part11+2.044062e-01*S110+2.603448e-01*S111+5.460518e-01*S112+3.643282e-01*S113+4.922154e-01*S114+6.877826e-01*S115+2.809367e-01*S116+2.658048e-01*S117+8.348661e-01*S118+3.401881e-01*S119'
.param V10_part13='V10_part12+9.404386e-02*S120+3.633594e-02*S121+4.405226e-02*S122+9.378718e-02*S123+1.146885e-01*S124+8.267472e-02*S125+(-2.724826e-02)*S126+5.402892e-01*S127+1.712852e-01*S128+2.726502e-01*S129'
.param V10_part14='V10_part13+8.608301e-01*S130+2.681575e-01*S131+(-5.472494e-02)*S132+3.346393e-01*S133+1.856563e-01*S134+6.200597e-02*S135+5.695864e-02*S136+1.975035e-02*S137+8.315081e-02*S138+6.870976e-02*S139'
.param V10_part15='V10_part14+3.239959e-02*S140+1.140568e-01*S141+7.453047e-02*S142+5.960672e-02*S143+2.043363e-01*S144+3.001666e-01*S145+1.808827e-01*S146+5.286663e-01*S147+5.000856e-01*S148+6.121079e-01*S149'
.param V10_part16='V10_part15+9.909758e+00*S150+1.242917e+00*S151+7.587339e-04*S152+3.063824e-01*S153+1.908686e+01*S154+1.470873e-01*S155+5.662974e-01*S156+2.944235e-01*S157+2.619886e-01*S158+(-4.326702e-02)*S159'
.param V10_part17='V10_part16+3.184864e-01*S160+(-2.585770e-02)*S161+1.657266e-01*S162+(-7.539046e-02)*S163+(-3.629175e-02)*S164+(-7.646541e-04)*S165+(-7.134328e-03)*S166+(-8.078780e-01)*S167+2.307002e-01*S168+(-1.443104e-01)*S169'
.param V10_part18='V10_part17+3.245344e-01*S170+5.155115e-01*S171+(-4.963655e-02)*S172+1.368546e+00*S173+(-8.316510e-02)*S174+2.991440e-01*S175+1.272072e+00*S176+(-1.189149e-01)*S177+4.008016e-01*S178+1.275785e+00*S179'
.param V10_part19='V10_part18+2.623563e-01*S180+1.327182e-01*S181+(-8.472276e-03)*S182+3.433781e-01*S183+(-1.135844e-01)*S184+1.444070e-02*S185+2.623476e-01*S186+4.114368e-01*S187+2.842603e-01*S188+(-7.760843e-02)*S189'
.param V10_part20='V10_part19+1.645110e-01*S190+5.175055e-01*S191+(-6.400271e-02)*S192+2.471898e-01*S193+7.801523e-01*S194+7.193948e-02*S195+(-8.348616e-02)*S196+(-4.675117e-01)*S197+1.596035e-01*S198+(-5.416905e-01)*S199'
.param V10_part21='V10_part20+(-6.362827e-01)*S200+4.534350e-01*S201+4.662001e-01*S202+(-7.215750e-01)*S203+7.673823e-01*S204+5.186304e-01*S205+5.667097e-01*S206+1.486547e-01*S207+9.727834e-01*S208+6.875544e-01*S209'
.param V10_part22='V10_part21+1.286299e-01*S210+(-8.903637e+00)*S211+2.352504e-02*S212+4.310810e-01*S213+(-2.765246e-03)*S214+1.842056e-02*S215+(-4.820849e-02)*S216+(-8.643315e-02)*S217+(-4.187527e-02)*S218+(-7.474703e-02)*S219'
.param V10_part23='V10_part22+5.413668e-01*S220+(-6.422787e-02)*S221+(-1.213821e-01)*S222+4.917323e-01*S223+3.622967e+00*S224+6.958407e-03*S225+4.493335e-02*S226+6.841052e-02*S227+(-5.467610e-02)*S228+7.052661e-03*S229'
.param V10_part24='V10_part23+4.222845e-02*S230+(-9.114593e-02)*S231+(-1.574608e-02)*S232+5.098515e-02*S233+(-1.357049e-01)*S234+(-6.254390e-02)*S235+9.826910e-03*S236+(-1.861827e-01)*S237+3.280197e-01*S238+8.971580e-01*S239'
.param V10_part25='V10_part24+3.931618e-02*S240+7.841365e-03*S241+(-2.981466e-02)*S242+(-9.922832e-02)*S243+(-2.437627e-02)*S244+3.211288e-02*S245+(-1.606485e-01)*S246+(-7.411341e-02)*S247+8.533274e-02*S248+(-1.286170e-01)*S249'
.param V10_part26='V10_part25+(-1.933864e-01)*S250+5.147157e-01*S251+(-1.279480e-01)*S252+4.234087e-01*S253+2.993779e+00*S254+(-1.763724e-01)*S255+(-3.431252e-01)*S256+(-1.652822e-01)*S257+(-1.090965e-01)*S258+(-3.257996e-02)*S259'
.param V10_part27='V10_part26+2.321728e-02*S260+2.327326e-01*S261+2.330768e-01*S262+2.873445e-01*S263+2.859129e-01*S264+4.819104e-01*S265+7.209752e-01*S266+(-1.023871e-01)*S267+8.237915e-01*S268+1.498565e+00*S269'
.param V10_part28='V10_part27+3.674271e-01*S270+2.707992e-01*S271+6.516956e-02*S272+2.749768e-01*S273+4.437016e-02*S274+9.342904e-02*S275+3.056253e-01*S276+(-2.597379e-03)*S277+4.574296e-01*S278+3.649744e-01*S279'
.param V10_part29='V10_part28+1.064363e-01*S280+1.682729e+00*S281+(-8.846315e-01)*S282+5.504586e-01*S283+1.608962e+00*S284+1.706176e-01*S285+2.433842e-01*S286+7.503782e-02*S287+2.198506e-01*S288+3.244485e-01*S289'
.param V10_part30='V10_part29+7.136132e-02*S290+(-1.784245e-01)*S291+(-1.038232e-01)*S292+2.255880e-01*S293+(-2.422447e-01)*S294+(-1.358771e-01)*S295+3.630428e-01*S296+1.217657e-01*S297+(-1.684931e-01)*S298+2.555122e-01*S299'
.param V10_part31='V10_part30+3.559312e-01*S300+(-1.919115e-02)*S301+(-3.080107e-02)*S302+2.800384e-01*S303+(-5.386635e-02)*S304+8.793290e-03*S305+2.679681e-01*S306+3.496490e-01*S307+1.938493e-01*S308+(-9.212728e-02)*S309'
.param V10='V10_part31+1.593835e-01*S310+1.311782e+00*S311+4.459593e-01*S312+(-1.511415e-01)*S313+1.120916e+00*S314'
.param V11_part1='1.099561e-01*S0+1.012996e-01*S1+8.466127e-02*S2+1.172865e-01*S3+1.076692e-01*S4+9.015000e-02*S5+1.224134e-01*S6+1.134315e-01*S7+9.586908e-02*S8+1.292165e-01*S9'
.param V11_part2='V11_part1+1.194936e-01*S10+1.012726e-01*S11+1.335949e-01*S12+1.241906e-01*S13+1.082224e-01*S14+1.389187e-01*S15+1.633060e-01*S16+1.253200e-01*S17+1.377540e-01*S18+1.308850e-01*S19'
.param V11_part3='V11_part2+1.357470e-01*S20+1.410446e-01*S21+1.379624e-01*S22+1.462254e-01*S23+1.452686e-01*S24+1.776483e-01*S25+1.266867e-01*S26+1.482752e-01*S27+1.446598e-01*S28+1.329584e-01*S29'
.param V11_part4='V11_part3+3.195112e-01*S30+2.465779e-01*S31+2.576586e-01*S32+2.959148e-01*S33+3.405653e-01*S34+2.118871e-01*S35+3.157431e-01*S36+3.594357e-01*S37+3.138303e-01*S38+4.059942e-01*S39'
.param V11_part5='V11_part4+3.773518e-01*S40+3.373813e-01*S41+4.224522e-01*S42+3.948626e-01*S43+3.649306e-01*S44+4.015561e-01*S45+3.774223e-01*S46+3.654471e-01*S47+4.466445e-01*S48+4.028150e-01*S49'
.param V11_part6='V11_part5+3.904936e-01*S50+5.347533e-01*S51+4.999074e-01*S52+4.524996e-01*S53+5.454565e-01*S54+5.253574e-01*S55+4.909925e-01*S56+5.956955e-01*S57+5.606585e-01*S58+4.615306e-01*S59'
.param V11_part7='V11_part6+5.098927e-01*S60+4.627074e-01*S61+4.464017e-01*S62+5.668727e-01*S63+5.321907e-01*S64+5.337101e-01*S65+6.151319e-01*S66+5.779487e-01*S67+5.629462e-01*S68+6.592694e-01*S69'
.param V11_part8='V11_part7+6.400877e-01*S70+5.573612e-01*S71+7.551063e-01*S72+7.466446e-01*S73+1.035867e+00*S74+1.693012e-01*S75+1.642086e-01*S76+1.417421e-01*S77+1.801542e-01*S78+1.680901e-01*S79'
.param V11_part9='V11_part8+1.903801e-01*S80+1.897198e-01*S81+1.613542e-01*S82+1.658886e-01*S83+2.024526e-01*S84+1.687033e-01*S85+1.775041e-01*S86+2.187360e-01*S87+1.950547e-01*S88+1.952414e-01*S89'
.param V11_part10='V11_part9+8.512316e-01*S90+7.094421e-01*S91+6.804905e-01*S92+9.704612e-01*S93+8.219036e-01*S94+7.981653e-01*S95+1.051345e+00*S96+1.021360e+00*S97+6.969125e-01*S98+1.070635e+00*S99'
.param V11_part11='V11_part10+1.066144e+00*S100+6.044124e-01*S101+1.175562e+00*S102+1.113578e+00*S103+5.275301e-01*S104+9.317902e-01*S105+8.950257e-01*S106+8.563686e-01*S107+1.102286e+00*S108+9.877551e-01*S109'
.param V11_part12='V11_part11+8.609485e-01*S110+1.235402e+00*S111+8.283344e-01*S112+8.948674e-01*S113+1.299132e+00*S114+8.228354e-01*S115+1.016739e+00*S116+1.332870e+00*S117+1.030434e+00*S118+1.027937e+00*S119'
.param V11_part13='V11_part12+1.119653e+00*S120+1.112968e+00*S121+1.057686e+00*S122+1.454827e+00*S123+1.255598e+00*S124+1.120327e+00*S125+1.510082e+00*S126+1.050731e+00*S127+1.237674e+00*S128+1.541796e+00*S129'
.param V11_part14='V11_part13+9.175826e-01*S130+1.192964e+00*S131+1.671579e+00*S132+1.506500e+00*S133+1.250783e+00*S134+5.731587e-01*S135+5.499048e-01*S136+5.586733e-01*S137+6.676960e-01*S138+6.343668e-01*S139'
.param V11_part15='V11_part14+6.079091e-01*S140+7.845102e-01*S141+7.515916e-01*S142+6.631905e-01*S143+8.584258e-01*S144+6.464861e-01*S145+6.446036e-01*S146+7.844474e-01*S147+6.281936e-01*S148+4.462626e-01*S149'
.param V11_part16='V11_part15+4.662677e-01*S150+8.794954e-01*S151+1.403662e+00*S152+1.731276e+00*S153+1.688463e+01*S154+1.487617e+00*S155+1.844318e+00*S156+1.775324e+00*S157+1.526768e+00*S158+2.120380e+00*S159'
.param V11_part17='V11_part16+1.865352e+00*S160+1.831923e+00*S161+2.075783e+00*S162+2.091011e+00*S163+1.931569e+00*S164+1.915352e+00*S165+1.870159e+00*S166+7.274428e+00*S167+2.066320e+00*S168+5.843017e+00*S169'
.param V11_part18='V11_part17+1.587553e+00*S170+2.173371e+00*S171+2.195400e+00*S172+1.134004e+00*S173+2.470546e+00*S174+2.141358e+00*S175+1.476390e+00*S176+2.560779e+00*S177+2.144212e+00*S178+1.646329e+00*S179'
.param V11_part19='V11_part18+5.300097e+00*S180+1.966043e+00*S181+1.860244e+00*S182+2.346288e+00*S183+2.874597e+00*S184+1.982433e+00*S185+2.510568e+00*S186+2.318454e+00*S187+2.391449e+00*S188+2.751350e+00*S189'
.param V11_part20='V11_part19+2.318341e+00*S190+2.359583e+00*S191+2.834596e+00*S192+2.325508e+00*S193+2.019706e+00*S194+1.326086e+00*S195+3.553989e+00*S196+4.692034e+00*S197+1.514352e+00*S198+4.984015e+00*S199'
.param V11_part21='V11_part20+5.666947e+00*S200+1.575776e+00*S201+1.274126e+00*S202+3.896538e+00*S203+1.625132e+00*S204+1.542211e+00*S205+1.321512e+00*S206+1.775232e+00*S207+1.525568e+00*S208+1.361660e+00*S209'
.param V11_part22='V11_part21+4.044154e+00*S210+1.561330e-01*S211+2.292364e+00*S212+2.866711e+00*S213+2.665646e+00*S214+2.470030e+00*S215+3.200356e+00*S216+3.054844e+00*S217+2.833720e+00*S218+3.408490e+00*S219'
.param V11_part23='V11_part22+2.983710e+00*S220+2.944806e+00*S221+3.565706e+00*S222+3.084423e+00*S223+1.355597e+00*S224+2.933020e+00*S225+2.720687e+00*S226+2.576215e+00*S227+3.336620e+00*S228+3.029283e+00*S229'
.param V11_part24='V11_part23+2.777952e+00*S230+3.593657e+00*S231+3.247121e+00*S232+2.857773e+00*S233+3.810727e+00*S234+3.441468e+00*S235+3.111212e+00*S236+3.998849e+00*S237+3.442869e+00*S238+2.685598e+00*S239'
.param V11_part25='V11_part24+3.099386e+00*S240+3.155616e+00*S241+2.941766e+00*S242+3.828198e+00*S243+3.444539e+00*S244+3.039715e+00*S245+4.043670e+00*S246+3.571070e+00*S247+3.153893e+00*S248+4.159749e+00*S249'
.param V11_part26='V11_part25+3.923953e+00*S250+3.081295e+00*S251+4.338635e+00*S252+3.456041e+00*S253+2.351018e+00*S254+4.009561e+00*S255+6.450789e+00*S256+3.771321e+00*S257+8.054523e+00*S258+2.489570e+00*S259'
.param V11_part27='V11_part26+2.227418e+00*S260+2.729436e+00*S261+2.538340e+00*S262+2.236215e+00*S263+2.926494e+00*S264+2.642419e+00*S265+2.241375e+00*S266+3.160116e+00*S267+2.706850e+00*S268+2.171942e+00*S269'
.param V11_part28='V11_part27+3.470077e+00*S270+3.456696e+00*S271+3.318893e+00*S272+3.919879e+00*S273+3.850008e+00*S274+3.546402e+00*S275+4.145959e+00*S276+4.090704e+00*S277+3.564322e+00*S278+4.380284e+00*S279'
.param V11_part29='V11_part28+4.252390e+00*S280+3.162380e+00*S281+3.612749e+00*S282+4.168966e+00*S283+3.540893e+00*S284+3.900085e+00*S285+3.850378e+00*S286+3.702093e+00*S287+4.333847e+00*S288+4.131603e+00*S289'
.param V11_part30='V11_part29+3.864570e+00*S290+5.225924e+00*S291+4.828168e+00*S292+4.070656e+00*S293+5.553662e+00*S294+5.071537e+00*S295+4.213620e+00*S296+5.254426e+00*S297+5.252767e+00*S298+4.480193e+00*S299'
.param V11_part31='V11_part30+3.318990e+00*S300+4.081857e+00*S301+3.172904e+00*S302+3.576325e+00*S303+3.579949e+00*S304+3.250199e+00*S305+3.805059e+00*S306+3.802376e+00*S307+3.387498e+00*S308+4.473446e+00*S309'
.param V11='V11_part31+3.896816e+00*S310+3.003831e+00*S311+4.541498e+00*S312+4.410740e+00*S313+3.240390e+00*S314'
.param V12_part1='(-1.366276e-02)*S0+(-2.657424e-03)*S1+2.320943e-03*S2+(-2.608636e-02)*S3+(-1.185374e-02)*S4+(-2.173224e-03)*S5+(-3.810978e-02)*S6+(-2.040945e-02)*S7+(-7.734948e-03)*S8+(-5.104159e-02)*S9'
.param V12_part2='V12_part1+(-2.976632e-02)*S10+(-1.311972e-02)*S11+(-6.123385e-02)*S12+(-3.917110e-02)*S13+(-2.008172e-02)*S14+(-1.281257e-02)*S15+5.432701e-03*S16+5.863479e-03*S17+(-3.394399e-02)*S18+(-1.182814e-02)*S19'
.param V12_part3='V12_part2+(-9.536813e-04)*S20+(-3.376144e-02)*S21+(-1.587934e-02)*S22+(-7.701917e-03)*S23+(-4.402736e-02)*S24+(-3.366942e-02)*S25+(-6.118551e-03)*S26+(-5.556660e-02)*S27+(-3.536716e-02)*S28+(-1.217422e-02)*S29'
.param V12_part4='V12_part3+(-8.540934e-03)*S30+1.666987e-02*S31+5.189279e-03*S32+(-1.750639e-02)*S33+(-1.148192e-02)*S34+5.860390e-02*S35+(-1.026767e-02)*S36+(-3.209179e-02)*S37+(-1.312961e-02)*S38+(-1.114813e-01)*S39'
.param V12_part5='V12_part4+(-5.836985e-02)*S40+(-2.169974e-02)*S41+(-1.461117e-01)*S42+(-8.702509e-02)*S43+(-3.140432e-02)*S44+(-1.195407e-03)*S45+4.383486e-02*S46+6.736840e-02*S47+(-2.498172e-02)*S48+4.243608e-02*S49'
.param V12_part6='V12_part5+2.407451e-02*S50+(-7.457918e-02)*S51+(-2.748279e-02)*S52+1.729426e-02*S53+(-1.424037e-01)*S54+(-6.499708e-02)*S55+4.365056e-03*S56+(-1.678259e-01)*S57+(-8.348387e-02)*S58+(-5.281379e-02)*S59'
.param V12_part7='V12_part6+2.836963e-02*S60+5.429634e-02*S61+7.735706e-02*S62+5.151674e-03*S63+4.781969e-02*S64+1.008316e-01*S65+(-6.789329e-04)*S66+9.406955e-03*S67+1.140960e-01*S68+(-2.627450e-02)*S69'
.param V12_part8='V12_part7+1.354155e-02*S70+2.575107e-01*S71+1.460054e-02*S72+3.734385e-01*S73+(-2.748623e-02)*S74+(-7.577792e-03)*S75+6.623374e-03*S76+1.453027e-02*S77+(-2.072172e-02)*S78+(-1.755853e-03)*S79'
.param V12_part9='V12_part8+3.293010e-03*S80+(-3.113881e-02)*S81+(-7.136551e-03)*S82+1.564524e-02*S83+(-2.944501e-02)*S84+1.138928e-02*S85+2.031028e-02*S86+(-2.552565e-02)*S87+(-2.027948e-03)*S88+8.265189e-03*S89'
.param V12_part10='V12_part9+9.034442e-02*S90+1.198534e-01*S91+1.199325e-01*S92+1.301965e-02*S93+1.215956e-01*S94+9.838328e-02*S95+(-7.068628e-02)*S96+5.705332e-02*S97+9.327261e-02*S98+2.017951e-01*S99'
.param V12_part11='V12_part10+(-8.619310e-03)*S100+1.598660e-01*S101+(-2.582588e-01)*S102+(-7.589053e-02)*S103+4.989919e-01*S104+1.048668e-01*S105+1.898701e-01*S106+1.645648e-01*S107+8.521241e-02*S108+1.494715e-01*S109'
.param V12_part12='V12_part11+2.125585e-01*S110+2.963651e-02*S111+6.415735e-01*S112+3.026963e-01*S113+(-2.503885e-01)*S114+1.312000e+00*S115+1.392558e-01*S116+(-4.934562e-01)*S117+1.402003e+00*S118+(-3.620571e-02)*S119'
.param V12_part13='V12_part12+1.809823e-01*S120+2.753812e-01*S121+2.169530e-01*S122+3.329232e-01*S123+2.626411e-01*S124+1.914518e-01*S125+(-1.448147e-02)*S126+7.234542e-01*S127+2.496310e-01*S128+(-2.700403e-01)*S129'
.param V12_part14='V12_part13+1.294659e+00*S130+8.028014e-02*S131+(-2.954789e-01)*S132+(-3.745545e-02)*S133+(-2.907374e-02)*S134+1.840189e-02*S135+6.412147e-02*S136+6.866360e-02*S137+1.883285e-02*S138+6.520187e-02*S139'
.param V12_part15='V12_part14+4.254139e-02*S140+3.317997e-02*S141+1.927479e-01*S142+3.126187e-02*S143+8.273977e-02*S144+4.832171e-01*S145+5.657654e-02*S146+5.179532e-01*S147+4.577884e-01*S148+1.479752e-01*S149'
.param V12_part16='V12_part15+6.872518e+00*S150+2.531248e-01*S151+2.880156e-01*S152+2.342734e-01*S153+(-2.050968e+01)*S154+2.477793e-01*S155+(-1.709150e-02)*S156+7.317955e-02*S157+1.688255e-01*S158+(-9.254068e-02)*S159'
.param V12_part17='V12_part16+1.543464e-02*S160+2.606482e-01*S161+(-4.942442e-01)*S162+3.417091e-02*S163+1.717585e-01*S164+4.768334e-01*S165+5.652756e-01*S166+1.706450e+00*S167+(-1.246061e-02)*S168+1.306429e+00*S169'
.param V12_part18='V12_part17+2.725607e-01*S170+(-2.540228e-01)*S171+3.448217e-01*S172+3.272259e-01*S173+2.077286e-02*S174+(-5.540654e-02)*S175+(-5.900513e-03)*S176+(-1.693135e-01)*S177+(-2.482177e-01)*S178+(-1.791180e-01)*S179'
.param V12_part19='V12_part18+1.073070e+00*S180+4.487435e-01*S181+4.535369e-01*S182+(-2.141134e-02)*S183+7.379139e-01*S184+5.218443e-01*S185+7.946168e-02*S186+6.855773e-02*S187+3.975222e-01*S188+3.054530e-02*S189'
.param V12_part20='V12_part19+(-3.426726e-02)*S190+4.888945e-01*S191+(-2.529489e-01)*S192+(-2.362229e-01)*S193+(-5.603165e-02)*S194+1.837362e-01*S195+6.606247e-01*S196+9.057183e-01*S197+1.789079e-01*S198+1.167713e+00*S199'
.param V12_part21='V12_part20+9.755236e-01*S200+(-1.577400e-02)*S201+5.582339e-01*S202+1.042480e+00*S203+(-3.386951e-01)*S204+1.903426e-01*S205+3.074216e-01*S206+(-5.087270e-01)*S207+7.796334e-01*S208+1.472073e-01*S209'
.param V12_part22='V12_part21+9.778012e-01*S210+8.611168e+01*S211+8.539202e-01*S212+9.396743e-02*S213+5.651385e-01*S214+7.853153e-01*S215+4.501211e-01*S216+7.320200e-01*S217+8.418180e-01*S218+1.857816e-01*S219'
.param V12_part23='V12_part22+(-3.746162e-02)*S220+7.507861e-01*S221+(-9.569723e-02)*S222+(-1.907116e-01)*S223+(-9.292072e-01)*S224+1.046682e+00*S225+9.633313e-01*S226+9.692263e-01*S227+9.119674e-01*S228+8.848083e-01*S229'
.param V12_part24='V12_part23+9.058223e-01*S230+6.531830e-01*S231+7.254061e-01*S232+7.650710e-01*S233+3.842770e-01*S234+5.504876e-01*S235+7.636506e-01*S236+5.637805e-03*S237+(-1.261753e-01)*S238+1.528704e-02*S239'
.param V12_part25='V12_part24+8.975619e-01*S240+9.098167e-01*S241+9.570484e-01*S242+1.205050e+00*S243+1.175499e+00*S244+8.371372e-01*S245+9.852206e-01*S246+5.894631e-01*S247+7.063175e-01*S248+5.063996e-01*S249'
.param V12_part26='V12_part25+8.917663e-01*S250+3.950446e-01*S251+(-1.800838e-04)*S252+(-6.924093e-02)*S253+(-7.800600e-01)*S254+1.297285e+00*S255+1.727784e+00*S256+9.671828e-01*S257+7.870048e-01*S258+3.752676e-01*S259'
.param V12_part27='V12_part26+4.599724e-01*S260+9.417799e-03*S261+2.269131e-01*S262+3.444084e-01*S263+(-2.593902e-01)*S264+5.264306e-02*S265+2.119027e-01*S266+(-1.991673e-01)*S267+(-1.872890e-01)*S268+(-6.295986e-02)*S269'
.param V12_part28='V12_part27+5.946929e-01*S270+1.157439e+00*S271+1.251196e+00*S272+4.828037e-01*S273+9.728615e-01*S274+1.124070e+00*S275+5.522205e-02*S276+8.415540e-01*S277+7.781417e-01*S278+(-4.059180e-01)*S279'
.param V12_part29='V12_part28+4.944440e-01*S280+1.678146e-01*S281+1.258255e-01*S282+(-4.090375e-02)*S283+(-5.493440e-02)*S284+1.071544e+00*S285+1.361899e+00*S286+1.454865e+00*S287+6.183906e-01*S288+1.098739e+00*S289'
.param V12_part30='V12_part29+1.391216e+00*S290+1.696015e+00*S291+1.694213e+00*S292+1.106978e+00*S293+1.309838e+00*S294+1.385275e+00*S295+8.791996e-01*S296+(-6.093404e-01)*S297+1.119003e+00*S298+7.693725e-01*S299'
.param V12_part31='V12_part30+2.434269e-01*S300+1.785003e+00*S301+1.107364e+00*S302+2.144030e-01*S303+9.170393e-01*S304+1.022410e+00*S305+(-6.953425e-02)*S306+5.236694e-01*S307+7.522058e-01*S308+5.034725e-01*S309'
.param V12='V12_part31+3.348591e-01*S310+2.180302e-01*S311+(-9.221398e-01)*S312+7.066302e-01*S313+1.179402e-01*S314'
.param V13_part1='3.904061e-02*S0+3.712651e-02*S1+3.351710e-02*S2+3.870456e-02*S3+3.694184e-02*S4+3.338268e-02*S5+3.845717e-02*S6+3.700248e-02*S7+3.383048e-02*S8+3.920492e-02*S9'
.param V13_part2='V13_part1+3.732802e-02*S10+3.417875e-02*S11+3.891727e-02*S12+3.737191e-02*S13+3.461986e-02*S14+8.426526e-02*S15+2.305651e+00*S16+2.869226e-02*S17+1.310680e-01*S18+8.735838e-02*S19'
.param V13_part3='V13_part2+2.888223e-02*S20+1.275966e-01*S21+9.348528e-02*S22+2.940122e-02*S23+1.195293e-01*S24+3.258821e-02*S25+7.631366e-02*S26+1.358273e-01*S27+1.050440e-01*S28+8.639109e-02*S29'
.param V13_part4='V13_part3+3.298518e-02*S30+9.268228e-02*S31+1.259680e-02*S32+1.544283e-01*S33+3.195649e-02*S34+2.102321e-01*S35+2.179609e-01*S36+3.268492e-02*S37+3.162831e-02*S38+3.396683e-02*S39'
.param V13_part5='V13_part4+3.232183e-02*S40+3.438375e-02*S41+3.407076e-02*S42+3.232060e-02*S43+3.706627e-02*S44+1.124433e-01*S45+9.776292e-02*S46+7.393381e-02*S47+1.183965e-01*S48+1.547631e-01*S49'
.param V13_part6='V13_part5+3.811802e-02*S50+3.961258e-02*S51+3.807065e-02*S52+4.017950e-02*S53+4.097406e-02*S54+3.967885e-02*S55+4.030968e-02*S56+4.043628e-02*S57+4.075944e-02*S58+3.530159e-02*S59'
.param V13_part7='V13_part6+9.874183e-02*S60+1.078094e-01*S61+9.602338e-02*S62+1.320152e-01*S63+1.517511e-01*S64+1.498935e-01*S65+2.429526e-01*S66+1.283713e-01*S67+1.863986e-01*S68+2.672723e-01*S69'
.param V13_part8='V13_part7+1.789384e-01*S70+3.941074e-01*S71+4.405859e-01*S72+6.253779e-01*S73+(-2.958473e-03)*S74+3.665042e-02*S75+3.318919e-02*S76+4.319139e-02*S77+5.435980e-02*S78+5.193394e-02*S79'
.param V13_part9='V13_part8+1.219692e-02*S80+9.917558e-02*S81+1.129626e-01*S82+7.386360e-02*S83+1.246515e-01*S84+1.752888e-01*S85+1.056914e-01*S86+1.606619e-01*S87+1.800437e-01*S88+9.581065e-02*S89'
.param V13_part10='V13_part9+3.572384e-02*S90+1.222608e-01*S91+8.587784e-02*S92+3.648223e-02*S93+2.019883e-01*S94+3.056068e-02*S95+3.804181e-02*S96+3.703574e-02*S97+1.759257e-01*S98+5.693877e-01*S99'
.param V13_part11='V13_part10+3.939664e-02*S100+3.259888e-01*S101+3.951591e-02*S102+4.147054e-02*S103+7.044942e-01*S104+1.460794e-01*S105+1.527158e-01*S106+8.208020e-02*S107+2.549004e-01*S108+2.381848e-01*S109'
.param V13_part12='V13_part11+1.971140e-01*S110+3.711524e-01*S111+6.079775e-01*S112+3.057253e-01*S113+5.151898e-01*S114+8.575591e-01*S115+2.267384e-01*S116+3.017826e-01*S117+1.065284e+00*S118+2.052402e-01*S119'
.param V13_part13='V13_part12+1.524822e-01*S120+1.356694e-01*S121+9.387547e-02*S122+2.839837e-01*S123+2.291976e-01*S124+1.205356e-01*S125+4.088139e-02*S126+6.014760e-01*S127+2.293627e-01*S128+3.730837e-01*S129'
.param V13_part14='V13_part13+9.006126e-01*S130+2.054179e-01*S131+3.962218e-02*S132+4.050265e-01*S133+1.484814e-01*S134+7.393774e-02*S135+7.028072e-02*S136+4.536998e-02*S137+1.378450e-01*S138+1.241120e-01*S139'
.param V13_part15='V13_part14+4.856217e-02*S140+2.467790e-01*S141+2.348554e-01*S142+8.180867e-02*S143+3.989273e-01*S144+5.228705e-01*S145+1.575323e-01*S146+8.170008e-01*S147+6.428645e-01*S148+3.767930e-01*S149'
.param V13_part16='V13_part15+1.813946e+00*S150+2.561652e-02*S151+4.054780e-02*S152+3.739280e-01*S153+1.203479e+00*S154+1.328166e-01*S155+5.692692e-01*S156+3.145759e-01*S157+1.698895e-01*S158+3.560270e-02*S159'
.param V13_part17='V13_part16+3.638601e-01*S160+3.914561e-02*S161+3.023465e-01*S162+3.184455e-02*S163+3.455361e-02*S164+4.152852e-02*S165+4.309337e-02*S166+2.768143e-01*S167+2.266497e-01*S168+3.748777e-01*S169'
.param V13_part18='V13_part17+1.630851e-01*S170+4.010063e-01*S171+4.308401e-02*S172+5.048144e-01*S173+4.247051e-02*S174+3.183296e-01*S175+3.992460e-01*S176+4.040069e-02*S177+2.925031e-01*S178+3.899914e-01*S179'
.param V13_part19='V13_part18+1.324449e-02*S180+1.270903e-01*S181+4.010110e-02*S182+3.340843e-01*S183+2.502407e-02*S184+3.296560e-02*S185+3.793421e-01*S186+2.489642e-01*S187+2.432059e-01*S188+3.766929e-02*S189'
.param V13_part20='V13_part19+1.145540e-01*S190+3.843931e-01*S191+3.372500e-02*S192+9.472855e-02*S193+2.522528e-01*S194+1.031033e-01*S195+6.531552e-02*S196+6.661338e-02*S197+2.434516e-01*S198+1.298449e-01*S199'
.param V13_part21='V13_part20+1.027000e-01*S200+4.299029e-01*S201+4.494141e-01*S202+8.564733e-02*S203+5.057100e-01*S204+4.516140e-01*S205+3.386552e-01*S206+1.790401e-01*S207+8.538528e-01*S208+2.767894e-01*S209'
.param V13_part22='V13_part21+1.873477e-02*S210+8.570042e-01*S211+3.291001e-02*S212+3.269030e-01*S213+3.699748e-02*S214+3.408555e-02*S215+3.561947e-02*S216+3.810635e-02*S217+4.278884e-02*S218+2.659767e-02*S219'
.param V13_part23='V13_part22+3.684850e-01*S220+4.761158e-02*S221+3.291703e-02*S222+3.606202e-01*S223+(-5.449341e-02)*S224+4.008357e-02*S225+3.729706e-02*S226+3.590314e-02*S227+5.179193e-02*S228+3.700439e-02*S229'
.param V13_part24='V13_part23+3.892972e-02*S230+4.146167e-02*S231+3.908518e-02*S232+4.327587e-02*S233+4.289182e-02*S234+3.718656e-02*S235+3.762255e-02*S236+4.870783e-02*S237+2.852578e-01*S238+8.416685e-02*S239'
.param V13_part25='V13_part24+3.657255e-02*S240+5.533154e-02*S241+4.889508e-02*S242+4.500738e-02*S243+3.389645e-02*S244+5.352102e-02*S245+3.339251e-02*S246+5.266390e-02*S247+6.590449e-02*S248+2.662515e-02*S249'
.param V13_part26='V13_part25+4.117130e-02*S250+9.508343e-02*S251+2.515222e-02*S252+9.694386e-02*S253+6.823740e-02*S254+9.540626e-02*S255+8.863032e-02*S256+1.045470e-02*S257+3.180492e-01*S258+3.360067e-02*S259'
.param V13_part27='V13_part26+4.266369e-02*S260+3.138990e-01*S261+1.874374e-01*S262+1.210827e-01*S263+3.652805e-01*S264+3.794830e-01*S265+2.587907e-01*S266+6.499829e-03*S267+5.214538e-01*S268+4.554357e-01*S269'
.param V13_part28='V13_part27+7.186838e-02*S270+1.959929e-01*S271+5.709902e-02*S272+1.311293e-01*S273+6.984746e-02*S274+6.067061e-02*S275+8.195928e-02*S276+6.834470e-02*S277+7.651121e-02*S278+8.526269e-02*S279'
.param V13_part29='V13_part28+1.115678e-01*S280+1.284257e-01*S281+8.275432e-02*S282+9.587860e-02*S283+1.135827e-01*S284+6.082944e-02*S285+2.139263e-01*S286+5.490095e-02*S287+7.497176e-02*S288+2.623585e-01*S289'
.param V13_part30='V13_part29+7.035997e-02*S290+3.618408e-02*S291+3.521140e-02*S292+1.054829e-01*S293+3.306080e-02*S294+2.983488e-02*S295+1.265719e-01*S296+1.461508e-01*S297+3.700877e-02*S298+1.042381e-01*S299'
.param V13_part31='V13_part30+5.208448e-02*S300+7.753781e-03*S301+2.754201e-02*S302+5.394673e-02*S303+3.296943e-02*S304+2.922084e-02*S305+5.255575e-02*S306+2.492486e-01*S307+3.877762e-02*S308+5.661288e-03*S309'
.param V13='V13_part31+1.148516e-01*S310+8.348590e-02*S311+4.271852e-01*S312+5.028886e-03*S313+5.236269e-02*S314'
.param V14_part1='9.073246e-06*S0+1.253061e-05*S1+2.346187e-06*S2+1.546980e-06*S3+(-2.553214e-06)*S4+(-9.497496e-06)*S5+(-8.273061e-06)*S6+7.363658e-06*S7+(-2.207026e-06)*S8+(-5.252813e-06)*S9'
.param V14_part2='V14_part1+1.352855e-05*S10+(-3.279647e-05)*S11+(-2.361243e-05)*S12+(-2.059549e-05)*S13+(-1.853246e-05)*S14+2.388822e-04*S15+2.330133e-04*S16+3.578265e-04*S17+1.567858e-04*S18+2.731646e-04*S19'
.param V14_part3='V14_part2+3.941220e-04*S20+2.735519e-04*S21+2.432230e-04*S22+4.051020e-04*S23+2.504483e-04*S24+4.897345e-04*S25+2.501488e-04*S26+1.239204e-04*S27+2.255375e-04*S28+3.035938e-04*S29'
.param V14_part4='V14_part3+2.383939e-03*S30+1.966227e-03*S31+2.573779e-03*S32+7.871142e-04*S33+1.583405e-03*S34+2.953582e-03*S35+(-1.434809e-03)*S36+1.422940e-03*S37+2.486155e-03*S38+1.004592e-03*S39'
.param V14_part5='V14_part4+1.704125e-03*S40+2.206524e-03*S41+7.278519e-04*S42+1.417937e-03*S43+1.882367e-03*S44+2.106556e-03*S45+1.606503e-03*S46+2.624008e-03*S47+3.632982e-04*S48+(-1.258588e-03)*S49'
.param V14_part6='V14_part5+2.683725e-03*S50+1.077670e-03*S51+1.502521e-03*S52+2.075169e-03*S53+9.177169e-04*S54+1.618196e-03*S55+1.252781e-03*S56+(-1.246998e-03)*S57+4.449584e-04*S58+(-2.949272e-03)*S59'
.param V14_part7='V14_part6+1.653606e-03*S60+5.541338e-04*S61+1.673253e-03*S62+(-1.016855e-03)*S63+(-2.006150e-03)*S64+1.569623e-04*S65+(-6.315130e-03)*S66+3.762847e-05*S67+(-3.158693e-03)*S68+(-1.214929e-02)*S69'
.param V14_part8='V14_part7+(-2.915512e-03)*S70+(-1.360038e-02)*S71+(-2.316394e-02)*S72+(-1.827105e-02)*S73+8.207321e-03*S74+2.120893e-05*S75+1.995853e-04*S76+(-1.731016e-04)*S77+(-2.355535e-05)*S78+1.455148e-06*S79'
.param V14_part9='V14_part8+1.678345e-03*S80+(-1.140495e-03)*S81+(-1.911374e-03)*S82+(-8.744178e-04)*S83+(-7.556861e-04)*S84+(-3.423247e-03)*S85+(-1.805525e-03)*S86+(-1.308526e-03)*S87+(-2.123231e-03)*S88+(-4.210014e-04)*S89'
.param V14_part10='V14_part9+9.387147e-03*S90+4.778787e-03*S91+1.051817e-02*S92+6.122561e-03*S93+2.662592e-03*S94+1.014695e-02*S95+2.249665e-03*S96+6.793265e-03*S97+6.541343e-03*S98+(-2.743804e-02)*S99'
.param V14_part11='V14_part10+4.033617e-03*S100+4.031875e-03*S101+(-6.539011e-03)*S102+1.306641e-03*S103+2.837665e-02*S104+5.048971e-03*S105+5.791431e-03*S106+1.621210e-02*S107+3.866541e-05*S108+(-5.737879e-04)*S109'
.param V14_part12='V14_part11+1.350547e-02*S110+(-4.696369e-03)*S111+(-1.592101e-02)*S112+1.661854e-02*S113+(-4.634854e-04)*S114+2.228778e-02*S115+1.218505e-02*S116+(-5.254232e-03)*S117+2.139611e-02*S118+4.110805e-03*S119'
.param V14_part13='V14_part12+9.836463e-03*S120+1.728309e-02*S121+2.387720e-02*S122+4.296254e-03*S123+1.366946e-02*S124+2.158419e-02*S125+1.914624e-03*S126+(-1.735133e-02)*S127+2.670272e-02*S128+5.522526e-03*S129'
.param V14_part14='V14_part13+(-2.398123e-02)*S130+1.741515e-02*S131+(-1.184530e-02)*S132+(-1.064592e-02)*S133+1.062135e-02*S134+1.230101e-04*S135+3.948055e-04*S136+8.944358e-03*S137+4.562597e-03*S138+6.317504e-03*S139'
.param V14_part15='V14_part14+9.249458e-03*S140+2.934586e-03*S141+5.143435e-03*S142+9.061123e-03*S143+1.389280e-04*S144+1.991858e-04*S145+8.092627e-03*S146+(-5.449695e-04)*S147+(-1.700098e-03)*S148+7.727786e-03*S149'
.param V14_part16='V14_part15+2.949334e+00*S150+6.549877e-02*S151+3.635262e-02*S152+8.527130e-03*S153+(-1.378561e+00)*S154+4.053792e-02*S155+1.036561e-02*S156+2.015688e-02*S157+3.433980e-02*S158+(-6.015611e-03)*S159'
.param V14_part17='V14_part16+1.765189e-02*S160+2.058131e-02*S161+5.448182e-03*S162+(-1.449083e-03)*S163+1.535022e-02*S164+3.370570e-02*S165+3.247148e-02*S166+4.643902e-01*S167+3.150765e-02*S168+3.372969e-01*S169'
.param V14_part18='V14_part17+3.897623e-02*S170+5.137017e-04*S171+1.619554e-02*S172+(-1.710840e-02)*S173+(-6.572545e-03)*S174+2.279464e-02*S175+3.054157e-02*S176+(-1.260142e-02)*S177+3.185673e-02*S178+3.529979e-02*S179'
.param V14_part19='V14_part18+(-3.894465e-02)*S180+4.079543e-02*S181+6.445890e-02*S182+3.939498e-02*S183+3.731946e-02*S184+3.561572e-02*S185+4.609569e-03*S186+2.590571e-02*S187+4.721987e-02*S188+(-5.843680e-03)*S189'
.param V14_part20='V14_part19+2.708887e-02*S190+4.211385e-02*S191+(-2.064651e-02)*S192+3.046503e-02*S193+4.321304e-02*S194+2.844932e-02*S195+1.507546e-01*S196+2.361253e-01*S197+3.156110e-02*S198+2.394021e-01*S199'
.param V14_part21='V14_part20+2.929985e-01*S200+3.279355e-02*S201+3.139088e-02*S202+2.584296e-01*S203+7.128529e-03*S204+1.290104e-02*S205+2.151689e-02*S206+2.093874e-03*S207+(-3.197754e-02)*S208+4.289450e-03*S209'
.param V14_part22='V14_part21+3.424093e-02*S210+6.528798e+00*S211+5.724710e-02*S212+3.975542e-02*S213+4.685286e-02*S214+5.015662e-02*S215+1.788272e-02*S216+3.266079e-02*S217+4.769841e-02*S218+(-2.612726e-03)*S219'
.param V14_part23='V14_part22+5.261215e-02*S220+4.224068e-02*S221+(-1.878131e-02)*S222+3.992882e-02*S223+1.689307e-01*S224+6.043004e-02*S225+5.520985e-02*S226+5.585467e-02*S227+4.716203e-02*S228+4.617272e-02*S229'
.param V14_part24='V14_part23+5.332719e-02*S230+2.826551e-02*S231+3.552028e-02*S232+5.470910e-02*S233+4.360157e-04*S234+2.242113e-02*S235+4.189032e-02*S236+(-1.632424e-02)*S237+4.692240e-02*S238+8.641874e-02*S239'
.param V14_part25='V14_part24+6.696905e-02*S240+1.254164e-01*S241+1.335559e-01*S242+6.159156e-02*S243+6.114888e-02*S244+1.241604e-01*S245+3.178540e-02*S246+8.137616e-02*S247+1.169618e-01*S248+3.083069e-03*S249'
.param V14_part26='V14_part25+3.777296e-02*S250+1.099921e-01*S251+(-1.538819e-02)*S252+6.864918e-02*S253+1.194359e-01*S254+2.267277e-01*S255+3.921651e-01*S256+2.260563e-01*S257+6.881975e-01*S258+7.233422e-02*S259'
.param V14_part27='V14_part26+7.616721e-02*S260+4.815616e-02*S261+3.124762e-02*S262+6.797071e-02*S263+6.251647e-03*S264+3.077427e-02*S265+5.242836e-02*S266+(-2.126099e-02)*S267+2.198573e-02*S268+2.535728e-02*S269'
.param V14_part28='V14_part27+1.191126e-01*S270+1.280028e-01*S271+1.402892e-01*S272+1.013094e-01*S273+1.241180e-01*S274+1.371379e-01*S275+8.726398e-02*S276+1.050276e-01*S277+1.522137e-01*S278+6.681024e-02*S279'
.param V14_part29='V14_part28+8.861220e-02*S280+1.489093e-01*S281+5.605459e-02*S282+8.577362e-02*S283+1.670380e-01*S284+1.453583e-01*S285+1.584483e-01*S286+1.772248e-01*S287+1.222737e-01*S288+1.431224e-01*S289'
.param V14_part30='V14_part29+1.462130e-01*S290+5.419351e-02*S291+7.596058e-02*S292+1.646816e-01*S293+1.590009e-02*S294+4.922137e-02*S295+1.577016e-01*S296+5.187142e-02*S297+2.358854e-02*S298+1.348517e-01*S299'
.param V14_part31='V14_part30+1.249023e-01*S300+8.265885e-02*S301+1.405640e-01*S302+1.150529e-01*S303+1.014130e-01*S304+1.136340e-01*S305+9.725447e-02*S306+8.173414e-02*S307+1.253330e-01*S308+4.418748e-03*S309'
.param V14='V14_part31+8.867549e-02*S310+1.453505e-01*S311+(-1.200090e-02)*S312+1.447442e-02*S313+1.310277e-01*S314'
.param V15_part1='3.563142e+00*S0+2.977310e+00*S1+5.550907e+00*S2+1.223861e+01*S3+5.546069e+00*S4+1.454504e+01*S5+3.595378e+00*S6+3.660758e+00*S7+7.154932e+00*S8+5.405901e+00*S9'
.param V15_part2='V15_part1+4.007922e+00*S10+4.434825e+00*S11+2.355001e+01*S12+3.524709e+00*S13+4.432419e+00*S14+(-6.242317e-02)*S15+(-4.296188e-02)*S16+6.949825e+00*S17+(-1.619604e-01)*S18+(-1.134991e-01)*S19'
.param V15_part3='V15_part2+9.575265e+00*S20+(-2.516727e-01)*S21+(-1.851193e-01)*S22+7.473795e+00*S23+(-3.543133e-01)*S24+2.234122e+01*S25+(-1.073819e-01)*S26+(-4.432780e-01)*S27+(-2.783603e-01)*S28+(-1.471682e-01)*S29'
.param V15_part4='V15_part3+6.187983e+00*S30+2.697679e-02*S31+1.258652e-01*S32+(-2.213656e-01)*S33+6.966454e+00*S34+7.299082e-02*S35+(-3.717104e-01)*S36+1.549251e+01*S37+4.652973e+00*S38+1.645174e+01*S39'
.param V15_part5='V15_part4+1.745501e+01*S40+8.094553e+00*S41+2.711923e+01*S42+1.845069e+01*S43+1.342783e+01*S44+(-1.089030e-01)*S45+2.741611e-02*S46+1.101694e-01*S47+(-2.986625e-01)*S48+(-8.220355e-02)*S49'
.param V15_part6='V15_part5+1.146785e+00*S50+6.073753e+00*S51+1.722793e+01*S52+1.672581e+01*S53+7.471619e+03*S54+1.215598e+01*S55+2.081013e+01*S56+5.808579e+01*S57+4.577279e+01*S58+7.494550e+03*S59'
.param V15_part7='V15_part6+(-1.343794e-01)*S60+5.127047e-02*S61+1.619272e-01*S62+(-3.205631e-01)*S63+(-6.250149e-02)*S64+1.357338e-01*S65+(-4.848870e-01)*S66+(-2.244573e-01)*S67+1.757101e-02*S68+(-7.266653e-01)*S69'
.param V15_part8='V15_part7+(-3.686593e-01)*S70+(-9.015104e-02)*S71+(-8.910005e-01)*S72+(-4.592998e-01)*S73+(-1.098551e-01)*S74+(-1.034827e-01)*S75+(-2.739935e-02)*S76+1.425727e-02*S77+(-2.377970e-01)*S78+(-1.074481e-01)*S79'
.param V15_part9='V15_part8+4.295784e+00*S80+(-3.400109e-01)*S81+(-1.709051e-01)*S82+(-4.842616e-02)*S83+(-4.441669e-01)*S84+(-2.529411e-01)*S85+(-8.655399e-02)*S86+(-5.547909e-01)*S87+(-3.135287e-01)*S88+(-1.417844e-01)*S89'
.param V15_part10='V15_part9+5.288474e+00*S90+1.095320e-01*S91+8.916110e-02*S92+1.183255e+01*S93+(-4.217509e-02)*S94+5.789825e+01*S95+2.240318e+01*S96+3.901955e+01*S97+(-7.069151e-02)*S98+(-8.667869e-01)*S99'
.param V15_part11='V15_part10+4.524900e+01*S100+(-1.442832e-01)*S101+6.216889e+01*S102+4.452463e+01*S103+(-4.948877e-02)*S104+(-1.464314e-01)*S105+1.007929e-01*S106+1.332644e-01*S107+(-4.228673e-01)*S108+(-1.129630e-01)*S109'
.param V15_part12='V15_part11+7.401648e-02*S110+(-7.141280e-01)*S111+(-3.312966e-01)*S112+3.131454e-02*S113+(-1.053634e+00)*S114+(-4.720602e-01)*S115+(-1.307903e-01)*S116+(-1.616306e+00)*S117+(-5.272673e-01)*S118+(-3.115912e-01)*S119'
.param V15_part13='V15_part12+(-9.735379e-02)*S120+1.271868e-01*S121+2.029358e-01*S122+(-4.343473e-01)*S123+(-1.107311e-01)*S124+1.076506e-01*S125+2.474665e+01*S126+(-2.848941e-01)*S127+2.628905e-02*S128+(-1.193922e+00)*S129'
.param V15_part14='V15_part13+(-5.679094e-01)*S130+(-1.513744e-01)*S131+6.179487e+01*S132+(-8.685299e-01)*S133+(-3.916247e-01)*S134+(-1.423122e-01)*S135+3.740727e-02*S136+7.913833e-02*S137+(-3.715336e-01)*S138+(-5.074553e-02)*S139'
.param V15_part15='V15_part14+5.836742e-02*S140+(-5.926588e-01)*S141+(-2.402945e-01)*S142+(-1.048869e-01)*S143+(-7.936950e-01)*S144+(-4.518895e-01)*S145+(-1.665619e-01)*S146+(-9.797601e-01)*S147+(-5.882029e-01)*S148+(-2.396508e-01)*S149'
.param V15_part16='V15_part15+(-1.859008e-02)*S150+2.176444e-01*S151+1.514703e-01*S152+(-4.409101e-01)*S153+(-2.046197e-02)*S154+2.105734e-01*S155+(-1.007172e+00)*S156+(-3.201597e-01)*S157+3.078971e-02*S158+1.326697e+01*S159'
.param V15_part17='V15_part16+(-6.133785e-01)*S160+2.162856e+01*S161+(-1.838961e+00)*S162+7.238663e+00*S163+3.205875e+01*S164+2.103122e+01*S165+5.780146e+00*S166+4.142785e-01*S167+(-6.035180e-01)*S168+9.956924e-02*S169'
.param V15_part18='V15_part17+2.728905e-01*S170+(-1.075416e+00)*S171+1.715438e+01*S172+1.489915e-01*S173+1.012344e+01*S174+(-6.750014e-01)*S175+(-8.985865e-02)*S176+8.731103e+01*S177+(-1.051798e+00)*S178+(-2.775042e-01)*S179'
.param V15_part19='V15_part18+1.208955e-01*S180+2.385350e-01*S181+4.740809e-01*S182+(-5.680553e-01)*S183+8.182229e-01*S184+2.715204e+01*S185+(-9.500419e-01)*S186+(-3.682983e-01)*S187+1.984486e-01*S188+9.920144e+00*S189'
.param V15_part20='V15_part19+(-1.004394e+00)*S190+(-4.552729e-03)*S191+4.049157e+01*S192+(-1.822284e+00)*S193+(-2.847312e-01)*S194+(-1.161944e-01)*S195+1.396486e-01*S196+3.034459e-01*S197+(-4.943441e-01)*S198+(-1.693444e-02)*S199'
.param V15_part21='V15_part20+2.525188e-01*S200+(-9.789295e-01)*S201+(-4.028896e-01)*S202+1.632663e-01*S203+(-1.405738e+00)*S204+(-6.286957e-01)*S205+(-1.650324e-02)*S206+(-1.743820e+00)*S207+(-7.740622e-01)*S208+(-2.667400e-01)*S209'
.param V15_part22='V15_part21+4.745491e-01*S210+3.461962e-01*S211+5.118704e+01*S212+(-6.337648e-01)*S213+(-1.934085e+00)*S214+4.967769e+01*S215+8.887713e+00*S216+1.161161e+01*S217+1.757344e+01*S218+2.803415e+00*S219'
.param V15_part23='V15_part22+(-7.222403e-01)*S220+2.576702e+01*S221+3.495161e+01*S222+(-1.110843e+00)*S223+(-1.265844e-01)*S224+4.790357e+00*S225+(-1.489477e+01)*S226+3.684837e+00*S227+1.031515e+01*S228+(-6.277162e+02)*S229'
.param V15_part24='V15_part23+4.352261e+00*S230+1.637616e+01*S231+(-8.591899e+03)*S232+2.285688e+00*S233+1.484773e+01*S234+(-4.651437e+02)*S235+8.395319e+00*S236+5.729499e+01*S237+(-1.191495e+00)*S238+(-8.761552e-01)*S239'
.param V15_part25='V15_part24+(-5.631610e+00)*S240+5.136733e-01*S241+9.597492e-01*S242+2.195491e+00*S243+1.275893e+01*S244+7.056113e-01*S245+(-4.588178e+00)*S246+(-9.205517e-01)*S247+2.744468e-01*S248+(-7.437177e+00)*S249'
.param V15_part26='V15_part25+6.521843e+01*S250+1.915631e-02*S251+1.710524e+01*S252+(-2.789682e+00)*S253+(-3.068137e-01)*S254+5.590253e-04*S255+3.110952e-01*S256+5.617143e-01*S257+(-3.560809e-01)*S258+5.434080e-02*S259'
.param V15_part27='V15_part26+4.070713e-01*S260+(-1.069007e+00)*S261+(-4.298058e-01)*S262+1.264365e-01*S263+(-1.711644e+00)*S264+(-7.582725e-01)*S265+(-4.867166e-02)*S266+6.235838e+01*S267+(-1.123928e+00)*S268+(-1.509135e-01)*S269'
.param V15_part28='V15_part27+2.360725e-01*S270+5.766290e-01*S271+1.305014e+00*S272+(-7.671060e-01)*S273+2.471898e-01*S274+9.346651e-01*S275+(-1.957041e+00)*S276+(-1.074056e+00)*S277+2.739014e-01*S278+(-3.589058e+00)*S279'
.param V15_part29='V15_part28+(-2.119431e+00)*S280+7.687469e-02*S281+(-1.448655e+00)*S282+(-3.058373e+00)*S283+(-4.549921e-01)*S284+4.387546e-01*S285+6.502262e-01*S286+1.393447e+00*S287+(-5.075883e-01)*S288+2.202333e-01*S289'
.param V15_part30='V15_part29+1.341202e+00*S290+(-1.359803e+00)*S291+1.896754e+01*S292+5.052501e-01*S293+1.287782e+00*S294+4.811138e+01*S295+(-1.842943e-01)*S296+(-4.972386e+00)*S297+6.791536e+01*S298+(-1.773526e+00)*S299'
.param V15_part31='V15_part30+3.364503e-01*S300+1.928508e+00*S301+1.082457e+00*S302+(-5.276847e-01)*S303+1.981815e-01*S304+9.620988e-01*S305+(-1.681479e+00)*S306+(-4.956744e-01)*S307+3.706796e-01*S308+2.588376e+01*S309'
.param V15='V15_part31+(-1.534638e+00)*S310+(-6.495013e-02)*S311+(-3.028463e+00)*S312+5.151326e+01*S313+(-8.598345e-01)*S314'
.param V16_part1='2.040516e+01*S0+2.586978e-02*S1+2.402925e-01*S2+1.200258e+01*S3+1.594385e+00*S4+1.867770e+00*S5+8.586808e+00*S6+4.433166e+00*S7+3.507545e+00*S8+1.834544e+00*S9'
.param V16_part2='V16_part1+2.822126e+00*S10+1.299742e+00*S11+(-3.522613e+00)*S12+2.521282e+00*S13+1.507247e+00*S14+5.207722e-01*S15+3.701799e-01*S16+(-3.019336e-01)*S17+5.153240e-01*S18+3.882353e-01*S19'
.param V16_part3='V16_part2+6.682527e-01*S20+5.079949e-01*S21+3.926808e-01*S22+3.371160e-02*S23+5.230414e-01*S24+1.379126e+00*S25+2.037438e-01*S26+5.200273e-01*S27+3.543073e-01*S28+2.100796e-01*S29'
.param V16_part4='V16_part3+(-4.179689e+00)*S30+6.239879e-01*S31+7.210169e-01*S32+8.501339e-01*S33+(-3.076270e+00)*S34+2.929148e-01*S35+8.565627e-01*S36+(-4.328152e+00)*S37+(-5.858185e+00)*S38+(-9.134803e+00)*S39'
.param V16_part5='V16_part4+(-7.606892e+00)*S40+(-1.110616e+01)*S41+(-1.693862e+01)*S42+(-1.337885e+01)*S43+(-1.552575e+01)*S44+9.929609e-01*S45+7.882560e-01*S46+5.085262e-01*S47+1.075676e+00*S48+7.832828e-01*S49'
.param V16_part6='V16_part5+(-1.381095e+00)*S50+(-3.047615e+00)*S51+(-1.374954e+01)*S52+(-2.609672e+01)*S53+6.279666e+01*S54+(-7.779154e+00)*S55+(-2.514203e+01)*S56+(-5.225747e+01)*S57+(-4.711641e+01)*S58+5.245784e+01*S59'
.param V16_part7='V16_part6+1.223439e+00*S60+9.622513e-01*S61+5.699870e-01*S62+1.256863e+00*S63+9.077465e-01*S64+4.282552e-01*S65+1.182349e+00*S66+9.706713e-01*S67+4.526641e-01*S68+1.278417e+00*S69'
.param V16_part8='V16_part7+9.755576e-01*S70+3.681881e-01*S71+1.223318e+00*S72+7.920887e-01*S73+4.316801e-01*S74+7.537453e-01*S75+5.443193e-01*S76+3.306221e-01*S77+7.290925e-01*S78+5.258627e-01*S79'
.param V16_part9='V16_part8+8.160318e-01*S80+7.009818e-01*S81+4.961564e-01*S82+2.767514e-01*S83+6.841129e-01*S84+4.952254e-01*S85+2.761402e-01*S86+6.770534e-01*S87+4.637098e-01*S88+2.877886e-01*S89'
.param V16_part10='V16_part9+(-3.010005e+00)*S90+1.349061e+00*S91+8.379187e-01*S92+(-1.755302e+01)*S93+1.239856e+00*S94+(-4.661449e+01)*S95+(-2.740097e+01)*S96+(-5.796816e+01)*S97+6.952741e-01*S98+1.585307e+00*S99'
.param V16_part11='V16_part10+(-5.090547e+01)*S100+6.063370e-01*S101+(-4.764779e+01)*S102+(-4.151471e+01)*S103+4.128763e-01*S104+1.861380e+00*S105+1.488474e+00*S106+8.121733e-01*S107+1.903397e+00*S108+1.383322e+00*S109'
.param V16_part12='V16_part11+7.043734e-01*S110+1.836928e+00*S111+1.170776e+00*S112+5.497374e-01*S113+1.822295e+00*S114+1.075097e+00*S115+6.576514e-01*S116+2.176525e+00*S117+9.131946e-01*S118+8.085759e-01*S119'
.param V16_part13='V16_part12+2.052609e+00*S120+1.650824e+00*S121+8.312070e-01*S122+2.080630e+00*S123+1.471648e+00*S124+8.535029e-01*S125+(-2.929411e+01)*S126+1.231078e+00*S127+6.571156e-01*S128+2.180939e+00*S129'
.param V16_part14='V16_part13+1.270758e+00*S130+8.288733e-01*S131+(-4.164401e+01)*S132+1.467517e+00*S133+1.003947e+00*S134+1.501912e+00*S135+1.181080e+00*S136+9.075429e-01*S137+1.506411e+00*S138+1.133291e+00*S139'
.param V16_part15='V16_part14+5.820992e-01*S140+1.457190e+00*S141+1.037529e+00*S142+6.354731e-01*S143+1.411697e+00*S144+9.810050e-01*S145+5.826845e-01*S146+1.316048e+00*S147+8.897604e-01*S148+4.979582e-01*S149'
.param V16_part16='V16_part15+1.948179e+00*S150+1.744086e+00*S151+1.593428e+00*S152+2.432873e+00*S153+1.327953e+00*S154+1.012125e+00*S155+2.538570e+00*S156+1.777013e+00*S157+1.034077e+00*S158+(-1.160708e+01)*S159'
.param V16_part17='V16_part16+1.755777e+00*S160+(-1.381840e+01)*S161+2.713907e+00*S162+(-4.178307e+00)*S163+(-1.872073e+01)*S164+(-1.489054e+01)*S165+(-9.426273e+00)*S166+6.384490e-01*S167+2.909959e+00*S168+1.196678e+00*S169'
.param V16_part18='V16_part17+1.044383e+00*S170+2.753597e+00*S171+(-1.574523e+01)*S172+8.850547e-01*S173+(-7.882597e+00)*S174+2.017813e+00*S175+1.012626e+00*S176+(-7.859172e+01)*S177+2.035929e+00*S178+1.052048e+00*S179'
.param V16_part19='V16_part18+2.218182e+00*S180+2.146578e+00*S181+1.527807e+00*S182+3.037987e+00*S183+1.545289e+00*S184+(-8.778690e+00)*S185+2.811424e+00*S186+2.063132e+00*S187+8.531637e-01*S188+(-9.477693e+00)*S189'
.param V16_part20='V16_part19+2.701955e+00*S190+8.932672e-01*S191+(-1.842226e+01)*S192+3.323805e+00*S193+1.128710e+00*S194+2.419813e+00*S195+1.373273e+00*S196+5.093984e-01*S197+2.382452e+00*S198+1.115017e+00*S199'
.param V16_part21='V16_part20+4.453648e-01*S200+2.350831e+00*S201+1.554585e+00*S202+4.262148e-01*S203+2.365221e+00*S204+1.584494e+00*S205+7.236143e-01*S206+2.585862e+00*S207+1.320547e+00*S208+8.297128e-01*S209'
.param V16_part22='V16_part21+2.763187e+00*S210+1.802177e+00*S211+(-4.554597e+01)*S212+3.452795e+00*S213+7.559163e+00*S214+(-4.027360e+01)*S215+(-4.170611e+00)*S216+(-2.580967e+00)*S217+(-6.326653e+00)*S218+(-3.424770e-01)*S219'
.param V16_part23='V16_part22+2.370156e+00*S220+(-1.124116e+01)*S221+(-2.492007e+01)*S222+2.323448e+00*S223+1.304285e+00*S224+5.255168e+01*S225+4.795673e+01*S226+(-1.053444e+01)*S227+(-8.145550e+00)*S228+8.727516e+02*S229'
.param V16_part24='V16_part23+3.843361e+00*S230+(-1.019102e+01)*S231+3.347983e+03*S232+1.118510e+00*S233+(-1.609737e+01)*S234+5.836514e+02*S235+4.971676e+01*S236+(-5.309181e+01)*S237+2.668166e+00*S238+2.399973e+00*S239'
.param V16_part25='V16_part24+1.781254e+01*S240+2.805967e+00*S241+1.280168e+00*S242+1.093726e-01*S243+(-6.804981e+00)*S244+1.451593e+00*S245+2.028413e+00*S246+4.431776e+00*S247+1.906288e+00*S248+(-1.554836e+01)*S249'
.param V16_part26='V16_part25+(-5.298323e+01)*S250+1.792497e+00*S251+(-2.435249e+01)*S252+4.890065e+00*S253+1.699707e+00*S254+2.626804e+00*S255+1.612775e+00*S256+9.197885e-01*S257+2.406870e+00*S258+2.364655e+00*S259'
.param V16_part27='V16_part26+1.366464e+00*S260+3.205583e+00*S261+2.364927e+00*S262+1.285440e+00*S263+3.306881e+00*S264+2.310280e+00*S265+1.186705e+00*S266+(-3.796393e+01)*S267+2.205732e+00*S268+1.091780e+00*S269'
.param V16_part28='V16_part27+4.762668e+00*S270+3.021035e+00*S271+2.749927e+00*S272+5.439470e+00*S273+4.370015e+00*S274+2.648130e+00*S275+7.089243e+00*S276+6.144076e+00*S277+2.453716e+00*S278+7.995684e+00*S279'
.param V16_part29='V16_part28+5.785128e+00*S280+1.931359e+00*S281+3.355666e+00*S282+5.557019e+00*S283+2.127140e+00*S284+6.006369e+00*S285+3.143434e+00*S286+2.127869e+00*S287+7.150304e+00*S288+3.310818e+00*S289'
.param V16_part30='V16_part29+3.062020e+00*S290+(-4.746008e+00)*S291+(-2.359620e+01)*S292+2.845589e+00*S293+(-6.504612e+00)*S294+(-2.966402e+01)*S295+3.110989e+00*S296+7.885768e+00*S297+(-4.158411e+01)*S298+4.281498e+00*S299'
.param V16_part31='V16_part30+4.406965e+00*S300+1.764801e+00*S301+1.601079e+00*S302+5.106746e+00*S303+4.330275e+00*S304+2.673034e+00*S305+6.324846e+00*S306+3.128988e+00*S307+2.310619e+00*S308+(-8.380476e+00)*S309'
.param V16='V16_part31+4.351212e+00*S310+1.962204e+00*S311+4.532410e+00*S312+(-2.329369e+01)*S313+2.574291e+00*S314'
.param V17_part1='4.738230e+00*S0+5.877802e-01*S1+2.214293e-01*S2+9.337251e+00*S3+4.610307e-02*S4+2.423210e+00*S5+4.285607e+00*S6+1.423750e-01*S7+1.184789e+00*S8+4.779853e+00*S9'
.param V17_part2='V17_part1+1.046799e-01*S10+1.861910e+00*S11+1.079768e+01*S12+7.635793e-01*S13+2.774562e+00*S14+6.113533e-02*S15+6.387220e-02*S16+1.775945e+00*S17+9.101225e-02*S18+9.448006e-02*S19'
.param V17_part3='V17_part2+2.559918e+00*S20+1.229521e-01*S21+1.252457e-01*S22+1.342538e+00*S23+1.544351e-01*S24+1.641464e+00*S25+1.570107e-01*S26+1.839767e-01*S27+1.823622e-01*S28+1.868522e-01*S29'
.param V17_part4='V17_part3+2.608938e+00*S30+9.073871e-02*S31+3.946103e-02*S32+1.535560e-01*S33+6.203722e-01*S34+1.304974e-01*S35+2.015998e-01*S36+4.459694e+00*S37+4.602288e+00*S38+7.186063e+00*S39'
.param V17_part5='V17_part4+6.319149e+00*S40+1.042398e+01*S41+1.008795e+01*S42+8.073362e+00*S43+1.446424e+01*S44+1.328965e-01*S45+1.014260e-01*S46+1.054127e-01*S47+1.882605e-01*S48+1.517582e-01*S49'
.param V17_part6='V17_part5+7.539010e+00*S50+5.082466e+00*S51+6.601351e+00*S52+1.560860e+01*S53+3.379400e+01*S54+5.830524e+00*S55+1.513201e+01*S56+1.433946e+01*S57+1.831527e+01*S58+(-8.658980e-01)*S59'
.param V17_part7='V17_part6+1.514866e-01*S60+1.071821e-01*S61+1.148727e-01*S62+2.091522e-01*S63+1.656570e-01*S64+1.743628e-01*S65+2.714146e-01*S66+2.332498e-01*S67+2.707327e-01*S68+3.312934e-01*S69'
.param V17_part8='V17_part7+2.893781e-01*S70+3.709592e-01*S71+3.944869e-01*S72+3.791332e-01*S73+4.418468e-01*S74+8.413722e-02*S75+7.079291e-02*S76+6.820378e-02*S77+1.253195e-01*S78+1.099227e-01*S79'
.param V17_part9='V17_part8+1.507892e+00*S80+1.607177e-01*S81+1.436320e-01*S82+1.428596e-01*S83+1.983079e-01*S84+1.785410e-01*S85+1.759458e-01*S86+2.350707e-01*S87+2.186187e-01*S88+2.169767e-01*S89'
.param V17_part10='V17_part9+3.409667e+00*S90+1.354059e-01*S91+2.289120e-01*S92+6.397209e+00*S93+2.148142e-01*S94+1.195819e+00*S95+9.885111e+00*S96+1.455837e+01*S97+3.476049e-01*S98+4.275135e-01*S99'
.param V17_part11='V17_part10+1.701507e+01*S100+4.360184e-01*S101+1.517538e+01*S102+1.795239e+01*S103+5.207334e-01*S104+2.104265e-01*S105+1.585568e-01*S106+2.587484e-01*S107+2.886086e-01*S108+2.600872e-01*S109'
.param V17_part12='V17_part11+3.014893e-01*S110+3.857655e-01*S111+3.914502e-01*S112+4.001179e-01*S113+4.889415e-01*S114+4.843662e-01*S115+4.970856e-01*S116+6.027720e-01*S117+5.837344e-01*S118+5.797153e-01*S119'
.param V17_part13='V17_part12+2.195844e-01*S120+1.767100e-01*S121+2.709283e-01*S122+3.114846e-01*S123+2.946244e-01*S124+3.194179e-01*S125+9.381185e+00*S126+4.132014e-01*S127+4.456717e-01*S128+5.298809e-01*S129'
.param V17_part14='V17_part13+5.304893e-01*S130+5.213159e-01*S131+1.405894e+01*S132+6.101122e-01*S133+6.790820e-01*S134+1.680179e-01*S135+1.239803e-01*S136+1.691676e-01*S137+2.329348e-01*S138+1.725583e-01*S139'
.param V17_part15='V17_part14+2.673025e-01*S140+3.073294e-01*S141+2.719380e-01*S142+3.460190e-01*S143+3.778096e-01*S144+3.711911e-01*S145+3.903240e-01*S146+4.560151e-01*S147+4.645276e-01*S148+4.876696e-01*S149'
.param V17_part16='V17_part15+2.601357e-01*S150+2.215814e-01*S151+6.586719e-01*S152+3.767100e-01*S153+3.432861e-01*S154+3.601175e-01*S155+5.144758e-01*S156+4.509306e-01*S157+4.872911e-01*S158+1.317722e+01*S159'
.param V17_part17='V17_part16+5.712130e-01*S160+1.013345e+01*S161+7.665898e-01*S162+1.397377e+01*S163+1.107903e+01*S164+6.428692e+00*S165+4.152822e+00*S166+3.333168e-01*S167+4.192385e-01*S168+3.915270e-01*S169'
.param V17_part18='V17_part17+3.792986e-01*S170+5.596681e-01*S171+8.717855e+00*S172+5.135922e-01*S173+9.364530e+00*S174+6.065621e-01*S175+6.346879e-01*S176+2.289003e+01*S177+7.593545e-01*S178+7.617775e-01*S179'
.param V17_part19='V17_part18+2.904509e-01*S180+2.717633e-01*S181+4.412072e-01*S182+4.340862e-01*S183+5.675770e-01*S184+4.677575e+00*S185+5.749817e-01*S186+5.159869e-01*S187+6.012518e-01*S188+1.194979e+01*S189'
.param V17_part20='V17_part19+6.956876e-01*S190+7.337083e-01*S191+2.040279e+01*S192+8.553188e-01*S193+8.951009e-01*S194+2.367474e-01*S195+2.238494e-01*S196+2.895448e-01*S197+3.429726e-01*S198+3.412383e-01*S199'
.param V17_part21='V17_part20+3.676220e-01*S200+4.776356e-01*S201+4.417564e-01*S202+5.000009e-01*S203+5.901119e-01*S204+5.287439e-01*S205+5.649206e-01*S206+7.020047e-01*S207+6.813863e-01*S208+6.904542e-01*S209'
.param V17_part22='V17_part21+3.087079e-01*S210+3.348830e-01*S211+9.593650e-01*S212+5.064200e-01*S213+2.210742e+00*S214+1.555903e+00*S215+1.393195e+01*S216+1.109437e+01*S217+7.680832e+00*S218+1.157819e+01*S219'
.param V17_part23='V17_part22+7.484831e-01*S220+1.130284e+01*S221+2.151571e+01*S222+9.515107e-01*S223+7.971061e-01*S224+2.386255e+01*S225+3.744528e+01*S226+2.506830e+01*S227+9.552277e+00*S228+5.452513e+02*S229'
.param V17_part24='V17_part23+2.132163e+01*S230+1.073395e+01*S231+7.215568e+03*S232+5.825312e+00*S233+1.537362e+01*S234+3.765698e+02*S235+9.707729e+01*S236+2.656731e+01*S237+9.970301e-01*S238+9.690612e-01*S239'
.param V17_part25='V17_part24+3.319417e+00*S240+3.794378e-01*S241+5.078158e-01*S242+2.906637e+00*S243+9.270132e+00*S244+7.220208e-01*S245+6.585428e+00*S246+9.574260e-01*S247+9.002401e-01*S248+1.962052e+01*S249'
.param V17_part26='V17_part25+2.555826e+01*S250+8.868383e-01*S251+2.437838e+01*S252+1.133557e+00*S253+9.091453e-01*S254+3.381595e-01*S255+3.230575e-01*S256+3.246609e-01*S257+4.657802e-01*S258+4.560579e-01*S259'
.param V17_part27='V17_part26+5.312777e-01*S260+6.135692e-01*S261+5.590858e-01*S262+6.321202e-01*S263+7.818976e-01*S264+6.861223e-01*S265+7.485307e-01*S266+2.188368e+01*S267+8.572707e-01*S268+8.682385e-01*S269'
.param V17_part28='V17_part27+3.821125e-01*S270+3.980780e-01*S271+3.586229e-01*S272+6.070084e-01*S273+5.169682e-01*S274+5.751871e-01*S275+7.483774e-01*S276+7.871481e-01*S277+7.423871e-01*S278+9.962007e-01*S279'
.param V17_part29='V17_part28+1.038260e+00*S280+8.817198e-01*S281+1.068263e+00*S282+1.238780e+00*S283+1.189151e+00*S284+3.565940e-01*S285+4.235830e-01*S286+4.403051e-01*S287+5.102291e-01*S288+5.776451e-01*S289'
.param V17_part30='V17_part29+3.917938e-01*S290+6.756867e+00*S291+1.592272e+01*S292+7.723843e-01*S293+6.859935e+00*S294+1.671205e+01*S295+9.877501e-01*S296+1.489346e+00*S297+2.333326e+01*S298+1.814818e+00*S299'
.param V17_part31='V17_part30+3.247379e-01*S300+5.300760e-01*S301+5.040268e-01*S302+5.004329e-01*S303+5.505155e-01*S304+5.814303e-01*S305+6.892026e-01*S306+7.351110e-01*S307+7.062187e-01*S308+1.723009e+01*S309'
.param V17='V17_part31+9.743159e-01*S310+8.437556e-01*S311+1.234949e+00*S312+2.051443e+01*S313+1.107197e+00*S314'
.param V18_part1='1.554851e+01*S0+5.997976e-01*S1+1.033434e+00*S2+2.752455e+01*S3+1.492076e+00*S4+3.844606e+00*S5+8.459150e+00*S6+1.226141e+00*S7+1.420569e+00*S8+5.409867e+00*S9'
.param V18_part2='V18_part1+9.781748e-01*S10+6.861537e-01*S11+1.908053e+01*S12+9.235266e-01*S13+7.856655e-01*S14+9.843337e-02*S15+6.128749e-02*S16+1.208284e+00*S17+8.735505e-02*S18+5.634563e-02*S19'
.param V18_part3='V18_part2+2.649364e+00*S20+8.459130e-02*S21+5.834662e-02*S22+1.490980e+00*S23+8.627337e-02*S24+7.776221e+00*S25+3.437092e-02*S26+8.503601e-02*S27+5.128170e-02*S28+3.482496e-02*S29'
.param V18_part4='V18_part3+2.952338e+00*S30+4.207681e-02*S31+1.728104e-01*S32+7.917863e-02*S33+7.840141e-01*S34+1.779557e-02*S35+8.169086e-02*S36+5.546108e+00*S37+2.708859e-01*S38+8.928361e+00*S39'
.param V18_part5='V18_part4+6.752621e+00*S40+(-8.523967e-01)*S41+1.105169e+01*S42+3.579152e+00*S43+(-5.238287e-01)*S44+7.686528e-02*S45+5.327182e-02*S46+1.670334e-02*S47+7.447979e-02*S48+3.850923e-02*S49'
.param V18_part6='V18_part5+(-5.945024e-01)*S50+2.582316e+00*S51+2.145846e+00*S52+(-3.136615e-01)*S53+(-1.000000e+04)*S54+1.971094e-01*S55+1.448282e+00*S56+3.340334e+00*S57+1.535417e+00*S58+(-1.000000e+04)*S59'
.param V18_part7='V18_part6+8.247148e-02*S60+5.059739e-02*S61+2.383601e-02*S62+8.096514e-02*S63+4.882838e-02*S64+8.561273e-03*S65+7.180736e-02*S66+4.445974e-02*S67+(-1.036010e-02)*S68+6.981006e-02*S69'
.param V18_part8='V18_part7+3.731176e-02*S70+(-2.193506e-02)*S71+6.368527e-02*S72+1.405177e-02*S73+1.171547e-01*S74+8.941459e-02*S75+5.361150e-02*S76+2.379142e-02*S77+8.705954e-02*S78+5.172450e-02*S79'
.param V18_part9='V18_part8+6.083320e-01*S80+8.254669e-02*S81+4.644291e-02*S82+3.526471e-02*S83+8.433160e-02*S84+5.308626e-02*S85+3.435997e-02*S86+8.281722e-02*S87+4.929432e-02*S88+3.579256e-02*S89'
.param V18_part10='V18_part9+2.009964e+00*S90+3.370444e-02*S91+(-1.391637e-02)*S92+1.945931e+00*S93+1.479876e-02*S94+(-7.959537e+00)*S95+1.110666e+00*S96+4.071887e+00*S97+(-1.310331e-02)*S98+4.211333e-02*S99'
.param V18_part11='V18_part10+4.601067e+00*S100+(-1.211657e-02)*S101+4.595648e+00*S102+5.208407e+00*S103+(-2.922618e-02)*S104+7.021784e-02*S105+3.435249e-02*S106+(-1.348812e-02)*S107+5.452922e-02*S108+9.311356e-03*S109'
.param V18_part12='V18_part11+(-6.893591e-03)*S110+4.428496e-02*S111+(-2.129950e-03)*S112+(-8.302931e-03)*S113+3.158423e-02*S114+1.721975e-02*S115+(-9.903124e-03)*S116+5.302480e-02*S117+1.808269e-02*S118+(-2.223928e-02)*S119'
.param V18_part13='V18_part12+6.214500e-02*S120+3.150272e-02*S121+(-1.478223e-02)*S122+5.135364e-02*S123+1.314833e-02*S124+(-1.603687e-02)*S125+1.706968e+00*S126+8.047145e-03*S127+(-1.095042e-02)*S128+1.646950e-02*S129'
.param V18_part14='V18_part13+2.974617e-02*S130+(-1.194267e-02)*S131+9.507896e+00*S132+3.497292e-02*S133+(-4.648614e-02)*S134+8.100090e-02*S135+4.554671e-02*S136+(-4.539261e-03)*S137+6.309499e-02*S138+3.336292e-02*S139'
.param V18_part15='V18_part14+(-1.715243e-02)*S140+6.040375e-02*S141+2.287987e-02*S142+(-1.208093e-02)*S143+5.338731e-02*S144+1.966652e-02*S145+(-8.516852e-03)*S146+4.855562e-02*S147+1.406902e-02*S148+(-3.687042e-03)*S149'
.param V18_part16='V18_part15+8.944160e-02*S150+5.791579e-02*S151+5.974805e-02*S152+1.790100e-02*S153+6.318584e-02*S154+(-1.015263e-02)*S155+1.996102e-02*S156+(-7.540035e-03)*S157+(-1.782955e-02)*S158+1.020079e+01*S159'
.param V18_part17='V18_part16+4.675936e-03*S160+3.692211e+00*S161+2.005788e-02*S162+5.080644e+00*S163+5.433041e+00*S164+(-2.240374e+00)*S165+1.586470e+00*S166+8.233243e-03*S167+2.701295e-02*S168+5.787798e-02*S169'
.param V18_part18='V18_part17+(-1.893200e-03)*S170+4.153798e-02*S171+4.831118e+00*S172+(-6.249265e-03)*S173+4.394643e+00*S174+(-1.765309e-02)*S175+(-2.508329e-03)*S176+9.033963e+00*S177+1.465077e-02*S178+(-3.675122e-04)*S179'
.param V18_part19='V18_part18+1.054918e-01*S180+1.582813e-02*S181+7.042037e-02*S182+3.056248e-03*S183+3.272465e-01*S184+(-6.655739e-01)*S185+3.871472e-02*S186+1.732424e-02*S187+(-2.922870e-02)*S188+4.761773e+00*S189'
.param V18_part20='V18_part19+4.186082e-02*S190+(-2.818943e-02)*S191+1.819028e+01*S192+4.939308e-02*S193+(-7.109680e-04)*S194+6.304316e-02*S195+6.115865e-02*S196+2.994414e-02*S197+4.560275e-02*S198+6.732521e-02*S199'
.param V18_part21='V18_part20+3.246004e-02*S200+4.207603e-02*S201+8.344030e-03*S202+3.703385e-02*S203+2.017789e-02*S204+1.028468e-02*S205+(-2.113579e-02)*S206+1.390761e-03*S207+(-7.084310e-03)*S208+(-4.165873e-03)*S209'
.param V18_part22='V18_part21+1.857863e-01*S210+4.975647e-02*S211+(-1.393752e+00)*S212+3.384456e-02*S213+(-3.895240e-01)*S214+(-9.848428e-01)*S215+1.092575e+01*S216+3.051160e+00*S217+2.018908e+00*S218+7.542957e+00*S219'
.param V18_part23='V18_part22+1.590973e-02*S220+2.365745e+00*S221+1.397612e+01*S222+(-1.297781e-03)*S223+1.084955e-01*S224+(-1.199032e+00)*S225+(-2.773959e+00)*S226+(-1.376774e+00)*S227+(-6.709330e-02)*S228+4.047588e+01*S229'
.param V18_part24='V18_part23+(-5.591390e-01)*S230+3.887464e-01*S231+9.708667e+02*S232+1.232804e-01*S233+(-1.446475e-01)*S234+1.872129e+01*S235+(-1.724864e+00)*S236+4.050944e+00*S237+(-2.519833e-02)*S238+7.871387e-02*S239'
.param V18_part25='V18_part24+6.141778e-02*S240+9.469750e-02*S241+8.708910e-02*S242+1.989217e-01*S243+5.221436e+00*S244+8.213464e-02*S245+(-2.507985e-01)*S246+1.875761e-01*S247+6.051932e-02*S248+(-4.260001e+00)*S249'
.param V18_part26='V18_part25+4.982645e+00*S250+6.364366e-02*S251+(-4.202018e+00)*S252+1.087918e-01*S253+9.132673e-02*S254+9.883043e-02*S255+5.699262e-02*S256+3.784641e-02*S257+1.045536e-01*S258+8.863556e-02*S259'
.param V18_part27='V18_part26+1.589362e-02*S260+5.765255e-03*S261+1.632389e-02*S262+(-2.058084e-02)*S263+(-1.169504e-02)*S264+(-1.236783e-03)*S265+(-2.602014e-02)*S266+2.597177e+01*S267+2.858970e-03*S268+(-2.516766e-02)*S269'
.param V18_part28='V18_part27+1.177178e-01*S270+3.680302e-03*S271+4.094173e-02*S272+4.246971e-02*S273+9.503824e-02*S274+4.954225e-02*S275+1.268567e-01*S276+1.063419e-01*S277+4.563903e-02*S278+1.313117e-01*S279'
.param V18_part29='V18_part28+4.760917e-02*S280+2.970327e-02*S281+6.303449e-02*S282+1.271628e-01*S283+2.580129e-02*S284+1.445892e-01*S285+(-9.185539e-03)*S286+5.188619e-02*S287+1.550546e-01*S288+(-3.007438e-02)*S289'
.param V18_part30='V18_part29+(-3.358908e-02)*S290+1.027800e-01*S291+4.535224e-01*S292+3.627585e-02*S293+1.218874e-01*S294+1.029696e+01*S295+4.892298e-02*S296+1.074179e-02*S297+1.088181e+01*S298+1.434472e-01*S299'
.param V18_part31='V18_part30+1.114745e-01*S300+2.314771e-01*S301+8.439956e-02*S302+1.199725e-01*S303+9.159103e-02*S304+1.319913e-02*S305+1.251008e-01*S306+(-1.136656e-02)*S307+4.105909e-02*S308+1.278578e+01*S309'
.param V18='V18_part31+(-2.755317e-02)*S310+3.871403e-02*S311+(-8.779949e-02)*S312+1.258915e+01*S313+6.699531e-02*S314'
.param V19_part1='(-7.595340e-02)*S0+(-8.604971e-03)*S1+(-1.597730e-03)*S2+2.612538e-01*S3+1.836993e-03*S4+2.301030e-01*S5+5.729469e-02*S6+(-4.001803e-02)*S7+(-1.116114e-03)*S8+6.856196e-02*S9'
.param V19_part2='V19_part1+(-8.113232e-03)*S10+(-8.035981e-03)*S11+2.980769e-01*S12+4.223438e-03*S13+(-4.223007e-03)*S14+1.290125e-03*S15+8.331284e-04*S16+2.243743e-02*S17+1.539758e-03*S18+9.959256e-04*S19'
.param V19_part3='V19_part2+2.344750e-02*S20+1.345398e-03*S21+9.445826e-04*S22+1.289048e-02*S23+1.314745e-03*S24+6.561559e-03*S25+6.075093e-04*S26+1.521073e-03*S27+7.925529e-04*S28+5.048221e-04*S29'
.param V19_part4='V19_part3+(-1.070686e-01)*S30+1.362928e-02*S31+5.470082e-03*S32+1.434872e-02*S33+(-1.191609e-01)*S34+9.078398e-03*S35+1.094964e-02*S36+5.604658e-01*S37+6.544002e-02*S38+4.343016e-01*S39'
.param V19_part5='V19_part4+2.863570e-01*S40+1.344805e-01*S41+8.888155e-01*S42+5.239012e-01*S43+1.487608e-01*S44+2.101844e-02*S45+1.537662e-02*S46+8.145649e-03*S47+1.951954e-02*S48+9.014749e-03*S49'
.param V19_part6='V19_part5+3.043796e-01*S50+8.157575e-01*S51+7.890584e-01*S52+2.289832e-02*S53+1.170574e+01*S54+5.556899e-02*S55+6.087063e-02*S56+3.871617e+00*S57+1.288245e+00*S58+(-3.366417e+00)*S59'
.param V19_part7='V19_part6+3.187630e-02*S60+1.891609e-02*S61+9.164553e-03*S62+2.405341e-02*S63+1.426923e-02*S64+1.039289e-02*S65+2.053701e-02*S66+1.127664e-02*S67+4.207089e-03*S68+1.743869e-02*S69'
.param V19_part8='V19_part7+8.695756e-03*S70+8.368639e-03*S71+1.154316e-02*S72+3.675957e-03*S73+4.144622e-03*S74+1.730490e-03*S75+6.240862e-03*S76+4.383707e-03*S77+5.415677e-03*S78+6.736706e-06*S79'
.param V19_part9='V19_part8+(-3.837344e-01)*S80+3.327179e-03*S81+(-2.341452e-04)*S82+(-7.955130e-04)*S83+2.992374e-04*S84+(-1.231200e-03)*S85+(-1.101880e-03)*S86+2.434732e-03*S87+3.962286e-04*S88+(-4.944349e-04)*S89'
.param V19_part10='V19_part9+(-5.490779e-01)*S90+3.444463e-02*S91+2.810031e-02*S92+(-5.615831e-02)*S93+1.976597e-02*S94+(-1.736894e+00)*S95+(-1.929384e-02)*S96+(-2.111926e+00)*S97+2.422350e-02*S98+3.617370e-02*S99'
.param V19_part11='V19_part10+(-1.319771e+00)*S100+1.784935e-02*S101+2.090324e-03*S102+(-5.862772e-01)*S103+(-1.155874e-02)*S104+7.619840e-02*S105+4.981999e-02*S106+3.285355e-02*S107+5.525197e-02*S108+3.273823e-02*S109'
.param V19_part12='V19_part11+2.822520e-02*S110+4.589255e-02*S111+6.953618e-03*S112+1.220246e-02*S113+4.534406e-02*S114+(-2.409153e-03)*S115+1.717012e-02*S116+4.691009e-02*S117+(-4.796124e-03)*S118+2.193214e-02*S119'
.param V19_part13='V19_part12+7.101721e-02*S120+6.564396e-02*S121+3.320687e-02*S122+6.253271e-02*S123+4.522311e-02*S124+3.864778e-02*S125+(-3.681967e-01)*S126+2.250142e-03*S127+2.457490e-02*S128+5.017678e-02*S129'
.param V19_part14='V19_part13+8.567582e-04*S130+2.813286e-02*S131+1.107946e-01*S132+3.697024e-02*S133+4.051016e-02*S134+3.868381e-02*S135+3.778089e-02*S136+2.469198e-02*S137+3.292947e-02*S138+1.944963e-02*S139'
.param V19_part15='V19_part14+1.767606e-02*S140+2.353777e-02*S141+1.200821e-02*S142+1.017638e-02*S143+1.695327e-02*S144+8.026055e-03*S145+6.730586e-03*S146+1.454179e-02*S147+6.306019e-03*S148+4.008705e-03*S149'
.param V19_part16='V19_part15+8.941551e-02*S150+5.660340e-02*S151+6.126194e-02*S152+8.142809e-02*S153+6.139219e-02*S154+6.689837e-02*S155+1.048084e-01*S156+6.561928e-02*S157+6.363666e-02*S158+3.935712e-01*S159'
.param V19_part17='V19_part16+7.614438e-02*S160+(-1.299737e+00)*S161+1.228401e-01*S162+(-1.047954e-01)*S163+(-6.905760e-01)*S164+(-2.328078e+00)*S165+(-1.175058e+00)*S166+2.613993e-03*S167+1.264958e-01*S168+1.699917e-02*S169'
.param V19_part18='V19_part17+7.019846e-02*S170+1.231488e-01*S171+(-9.555859e-01)*S172+3.699599e-02*S173+(-5.888115e-01)*S174+8.747646e-02*S175+4.748473e-02*S176+(-8.308484e+00)*S177+9.953777e-02*S178+5.798246e-02*S179'
.param V19_part19='V19_part18+1.236970e-01*S180+1.243964e-01*S181+4.410164e-02*S182+1.380948e-01*S183+1.100771e-01*S184+(-2.631033e+00)*S185+1.443504e-01*S186+1.021916e-01*S187+5.201001e-02*S188+(-6.386329e-01)*S189'
.param V19_part20='V19_part19+1.320468e-01*S190+6.425642e-02*S191+3.680830e-01*S192+1.089396e-01*S193+7.582448e-02*S194+9.443554e-02*S195+3.637506e-02*S196+1.855065e-03*S197+7.309028e-02*S198+1.532731e-02*S199'
.param V19_part21='V19_part20+1.051300e-02*S200+7.957572e-02*S201+3.347974e-02*S202+3.325103e-03*S203+9.999576e-02*S204+4.756416e-02*S205+2.480200e-04*S206+9.701492e-02*S207+4.824393e-02*S208+2.810237e-02*S209'
.param V19_part22='V19_part21+2.475415e-01*S210+7.155174e-02*S211+(-2.537636e+00)*S212+2.021513e-01*S213+1.050893e-01*S214+(-1.324803e+00)*S215+(-1.535547e+00)*S216+(-1.931564e+00)*S217+(-1.526031e+00)*S218+1.707629e-01*S219'
.param V19_part23='V19_part22+1.463410e-01*S220+(-2.374679e+00)*S221+(-4.096066e+00)*S222+1.533389e-01*S223+8.329725e-02*S224+6.572673e+00*S225+(-1.053307e+01)*S226+(-5.985370e+00)*S227+(-2.855858e+00)*S228+(-7.107179e+01)*S229'
.param V19_part24='V19_part23+(-4.353543e+00)*S230+(-4.931329e+00)*S231+1.400304e+02*S232+(-4.312473e-01)*S233+(-4.989321e+00)*S234+(-9.687593e+00)*S235+(-1.791176e+01)*S236+(-8.425409e+00)*S237+1.696185e-01*S238+1.355073e-01*S239'
.param V19_part25='V19_part24+(-3.704531e-01)*S240+1.642876e-01*S241+6.690000e-02*S242+4.949118e-02*S243+(-2.043966e+00)*S244+9.120539e-02*S245+3.928285e-01*S246+2.113475e-01*S247+9.728786e-02*S248+1.844795e+00*S249'
.param V19_part26='V19_part25+(-5.193918e+00)*S250+1.300575e-01*S251+2.881153e+00*S252+1.761762e-01*S253+1.464364e-01*S254+1.055670e-01*S255+4.993887e-02*S256+3.258179e-02*S257+8.691644e-02*S258+1.207508e-01*S259'
.param V19_part27='V19_part26+8.653908e-02*S260+1.765165e-01*S261+1.455703e-01*S262+8.933243e-02*S263+1.935379e-01*S264+1.334702e-01*S265+8.902519e-02*S266+(-1.410244e+00)*S267+1.328498e-01*S268+8.621696e-02*S269'
.param V19_part28='V19_part27+4.070392e-01*S270+2.508073e-01*S271+1.457511e-01*S272+4.396535e-01*S273+2.706196e-01*S274+1.453462e-01*S275+4.771976e-01*S276+3.068866e-01*S277+1.578620e-01*S278+4.663540e-01*S279'
.param V19_part29='V19_part28+2.012370e-01*S280+1.650982e-01*S281+1.792733e-01*S282+2.586036e-01*S283+1.491329e-01*S284+5.114102e-01*S285+2.705496e-01*S286+9.719302e-02*S287+4.818863e-01*S288+2.673994e-01*S289'
.param V19_part30='V19_part29+1.884114e-01*S290+1.696107e-01*S291+(-1.276585e+00)*S292+1.408770e-01*S293+4.661697e-01*S294+1.475766e-01*S295+1.588047e-01*S296+2.084006e-01*S297+7.431472e-01*S298+8.717715e-02*S299'
.param V19_part31='V19_part30+2.844745e-01*S300+4.461107e-01*S301+9.549154e-02*S302+3.183345e-01*S303+2.839223e-01*S304+1.418236e-01*S305+3.379617e-01*S306+2.140856e-01*S307+1.193357e-01*S308+(-1.031302e+00)*S309'
.param V19='V19_part31+2.048745e-01*S310+1.386287e-01*S311+2.645195e-01*S312+(-2.161343e+00)*S313+1.661279e-01*S314'
.param V20_part1='2.772434e-01*S0+7.773394e-02*S1+1.027033e-01*S2+6.290305e-01*S3+1.036273e-01*S4+2.789910e-01*S5+2.834413e-01*S6+1.004242e-01*S7+1.723840e-01*S8+2.641536e-01*S9'
.param V20_part2='V20_part1+9.792052e-02*S10+1.156593e-01*S11+5.998623e-01*S12+9.346991e-02*S13+1.282068e-01*S14+4.032737e-02*S15+3.727746e-02*S16+7.717190e-02*S17+4.149691e-02*S18+3.649187e-02*S19'
.param V20_part3='V20_part2+1.067844e-01*S20+4.065878e-02*S21+3.398713e-02*S22+7.023267e-02*S23+4.043888e-02*S24+2.039837e-01*S25+4.392356e-02*S26+3.626025e-02*S27+3.477789e-02*S28+4.490509e-02*S29'
.param V20_part4='V20_part3+1.250945e-01*S30+4.379785e-02*S31+3.615969e-02*S32+3.417252e-02*S33+5.889970e-02*S34+4.998133e-02*S35+2.717458e-02*S36+2.314732e-01*S37+7.249897e-02*S38+2.568767e-01*S39'
.param V20_part5='V20_part4+2.799024e-01*S40+8.088726e-02*S41+3.520302e-01*S42+2.068801e-01*S43+1.805035e-01*S44+4.665126e-02*S45+5.491659e-02*S46+4.836947e-02*S47+3.493327e-02*S48+3.827934e-02*S49'
.param V20_part6='V20_part5+9.547902e-02*S50+2.291713e-01*S51+3.278247e-01*S52+2.268722e-01*S53+1.676547e+02*S54+2.148896e-01*S55+3.558005e-01*S56+7.918951e-01*S57+6.712829e-01*S58+7.534082e+02*S59'
.param V20_part7='V20_part6+4.003898e-02*S60+4.792765e-02*S61+5.093795e-02*S62+2.677952e-02*S63+2.986715e-02*S64+4.400580e-02*S65+1.450580e-02*S66+1.106503e-02*S67+1.768025e-02*S68+6.632298e-03*S69'
.param V20_part8='V20_part7+(-1.347796e-02)*S70+(-1.997199e-02)*S71+(-2.450611e-02)*S72+(-4.745642e-02)*S73+3.951032e-02*S74+9.443477e-03*S75+1.469435e-02*S76+1.407855e-02*S77+4.919763e-03*S78+7.339854e-03*S79'
.param V20_part9='V20_part8+6.757386e-02*S80+(-3.634541e-04)*S81+(-5.746027e-04)*S82+1.494825e-02*S83+(-2.670134e-03)*S84+(-4.489200e-03)*S85+1.566942e-02*S86+(-1.646769e-02)*S87+(-4.770680e-03)*S88+1.864111e-02*S89'
.param V20_part10='V20_part9+1.565032e-01*S90+4.656002e-02*S91+2.460446e-03*S92+2.154790e-01*S93+(-1.910465e-02)*S94+1.786717e-02*S95+3.834386e-01*S96+4.102028e-01*S97+(-2.838933e-02)*S98+(-4.790830e-02)*S99'
.param V20_part11='V20_part10+9.467305e-01*S100+(-6.694433e-02)*S101+1.169061e+00*S102+1.247882e+00*S103+(-1.135727e-01)*S104+4.725595e-02*S105+3.573500e-02*S106+3.772862e-02*S107+7.496648e-03*S108+(-2.784818e-02)*S109'
.param V20_part12='V20_part11+(-1.529435e-04)*S110+(-3.412651e-02)*S111+(-9.969882e-02)*S112+(-3.969841e-02)*S113+(-6.933962e-02)*S114+(-1.397362e-01)*S115+(-4.074732e-02)*S116+(-9.695274e-02)*S117+(-1.950102e-01)*S118+(-1.997277e-02)*S119'
.param V20_part13='V20_part12+3.379421e-02*S120+5.413753e-03*S121+1.494027e-02*S122+(-3.045768e-02)*S123+(-5.240000e-02)*S124+(-3.310004e-02)*S125+5.273972e-01*S126+(-1.250344e-01)*S127+(-8.137502e-02)*S128+(-8.429384e-02)*S129'
.param V20_part14='V20_part13+(-1.865517e-01)*S130+(-1.157131e-01)*S131+1.890189e+00*S132+(-1.966241e-01)*S133+(-8.773255e-02)*S134+7.197446e-03*S135+2.545340e-02*S136+(-2.885404e-02)*S137+(-2.649531e-02)*S138+(-8.555002e-03)*S139'
.param V20_part15='V20_part14+(-5.460283e-02)*S140+(-5.031978e-02)*S141+(-7.231982e-02)*S142+(-6.859009e-02)*S143+(-7.944933e-02)*S144+(-1.172108e-01)*S145+(-8.068814e-02)*S146+(-1.280996e-01)*S147+(-1.554012e-01)*S148+(-1.294004e-01)*S149'
.param V20_part16='V20_part15+3.304492e-02*S150+6.622779e-02*S151+6.994991e-03*S152+(-5.165722e-02)*S153+6.365085e-04*S154+(-8.454981e-02)*S155+(-7.248591e-02)*S156+(-1.120036e-01)*S157+(-1.154628e-01)*S158+1.127311e+00*S159'
.param V20_part17='V20_part16+(-1.575090e-01)*S160+2.064263e+00*S161+(-1.637203e-01)*S162+1.082900e+00*S163+3.780821e+00*S164+(-1.620368e-01)*S165+2.577019e-01*S166+(-7.595073e-04)*S167+(-3.324780e-02)*S168+(-1.074886e-01)*S169'
.param V20_part18='V20_part17+9.032034e-03*S170+(-6.009283e-02)*S171+1.218236e+00*S172+(-4.567412e-04)*S173+1.020591e+00*S174+(-8.102711e-02)*S175+7.344187e-03*S176+3.846246e+00*S177+(-2.333280e-01)*S178+(-2.142801e-02)*S179'
.param V20_part19='V20_part18+4.479680e-02*S180+(-2.058522e-02)*S181+(-3.406597e-02)*S182+(-5.431773e-02)*S183+(-3.370911e-02)*S184+7.278365e-01*S185+(-7.698171e-02)*S186+(-1.184716e-01)*S187+(-1.380907e-01)*S188+8.218721e-01*S189'
.param V20_part20='V20_part19+(-2.116263e-01)*S190+(-1.893518e-01)*S191+2.711819e+00*S192+(-3.399113e-01)*S193+(-1.675120e-01)*S194+(-1.408521e-02)*S195+(-5.903642e-02)*S196+(-3.065977e-02)*S197+(-7.935282e-02)*S198+(-1.281660e-01)*S199'
.param V20_part21='V20_part20+(-9.725598e-02)*S200+(-1.446808e-01)*S201+(-1.811990e-01)*S202+(-1.718583e-01)*S203+(-1.842869e-01)*S204+(-1.564542e-01)*S205+(-1.548118e-01)*S206+(-2.044594e-01)*S207+(-3.160704e-01)*S208+(-1.253091e-01)*S209'
.param V20_part22='V20_part21+6.889687e-02*S210+3.125338e-02*S211+1.232718e+00*S212+(-4.136501e-02)*S213+(-6.108490e-03)*S214+2.143283e+00*S215+1.300462e+00*S216+5.222559e-01*S217+9.963920e-01*S218+6.971487e-01*S219'
.param V20_part23='V20_part22+(-1.869651e-01)*S220+1.679321e+00*S221+2.567932e+00*S222+(-2.719216e-01)*S223+(-6.186841e-02)*S224+7.125636e-02*S225+5.982611e+00*S226+6.800427e+00*S227+3.154953e-01*S228+6.465580e+01*S229'
.param V20_part24='V20_part23+4.267649e+00*S230+1.213776e-01*S231+1.199064e+03*S232+5.599114e-01*S233+2.353818e-02*S234+1.049523e+01*S235+5.339131e+00*S236+1.413491e+00*S237+(-3.327229e-01)*S238+(-1.111991e-01)*S239'
.param V20_part25='V20_part24+3.048472e-01*S240+(-8.015877e-02)*S241+(-1.591835e-01)*S242+2.135958e-02*S243+8.957980e-01*S244+(-1.048310e-01)*S245+1.350894e-01*S246+(-2.640360e-01)*S247+(-2.307048e-01)*S248+2.077773e+00*S249'
.param V20_part26='V20_part25+1.476348e+00*S250+(-1.649578e-01)*S251+1.981247e+00*S252+(-4.887059e-01)*S253+4.245908e-02*S254+(-7.805021e-02)*S255+(-7.763105e-02)*S256+(-2.720481e-02)*S257+(-1.637509e-01)*S258+(-1.254598e-01)*S259'
.param V20_part27='V20_part26+(-2.127455e-01)*S260+(-1.638581e-01)*S261+(-1.860159e-01)*S262+(-1.131080e-01)*S263+(-2.227520e-01)*S264+(-2.094450e-01)*S265+(-1.008926e-01)*S266+3.340863e+00*S267+(-2.925546e-01)*S268+(-5.225213e-02)*S269'
.param V20_part28='V20_part27+(-4.562238e-02)*S270+(-4.866906e-03)*S271+(-1.071131e-02)*S272+(-1.469296e-01)*S273+(-1.310868e-01)*S274+(-8.589103e-02)*S275+(-3.208573e-01)*S276+(-3.305270e-01)*S277+(-9.860644e-02)*S278+(-4.834081e-01)*S279'
.param V20_part29='V20_part28+(-4.794711e-01)*S280+(-1.863640e-01)*S281+(-1.939870e-01)*S282+(-6.708332e-01)*S283+(-9.864069e-02)*S284+(-4.564982e-02)*S285+1.239782e-02*S286+(-1.038525e-01)*S287+(-2.120774e-01)*S288+(-5.457521e-02)*S289'
.param V20_part30='V20_part29+(-2.077204e-01)*S290+6.982733e-01*S291+2.943400e+00*S292+(-3.546398e-01)*S293+9.622558e-01*S294+3.213558e+00*S295+(-4.825839e-01)*S296+(-5.122376e-01)*S297+4.951027e+00*S298+(-9.643639e-01)*S299'
.param V20_part31='V20_part30+(-4.656034e-02)*S300+(-3.473818e-03)*S301+(-1.985793e-01)*S302+(-2.161220e-01)*S303+(-2.670185e-01)*S304+(-1.971714e-01)*S305+(-3.534718e-01)*S306+(-2.028331e-01)*S307+(-1.889319e-01)*S308+2.322809e+00*S309'
.param V20='V20_part31+(-4.232716e-01)*S310+(-1.595117e-01)*S311+(-2.276048e-01)*S312+3.785852e+00*S313+(-2.680209e-01)*S314'
.param V21_part1='3.726106e-01*S0+1.722049e-01*S1+1.708729e-01*S2+4.495079e-01*S3+1.951721e-01*S4+2.481836e-01*S5+2.551148e-01*S6+2.027769e-01*S7+1.964862e-01*S8+2.500145e-01*S9'
.param V21_part2='V21_part1+2.078341e-01*S10+2.011582e-01*S11+3.383047e-01*S12+2.280330e-01*S13+2.159353e-01*S14+2.929154e-01*S15+2.679758e-01*S16+2.155832e-01*S17+3.291906e-01*S18+3.085893e-01*S19'
.param V21_part3='V21_part2+2.368298e-01*S20+3.560419e-01*S21+3.332970e-01*S22+2.426065e-01*S23+3.768686e-01*S24+2.788390e-01*S25+3.035457e-01*S26+3.936835e-01*S27+3.635480e-01*S28+3.212956e-01*S29'
.param V21_part4='V21_part3+5.387334e-01*S30+5.859271e-01*S31+4.998911e-01*S32+7.143792e-01*S33+5.742109e-01*S34+5.647709e-01*S35+7.721925e-01*S36+5.891244e-01*S37+5.627480e-01*S38+6.827341e-01*S39'
.param V21_part5='V21_part4+6.285806e-01*S40+6.565344e-01*S41+7.178253e-01*S42+7.082001e-01*S43+6.783113e-01*S44+8.688831e-01*S45+8.077446e-01*S46+7.472423e-01*S47+9.912231e-01*S48+9.223079e-01*S49'
.param V21_part6='V21_part5+8.007742e-01*S50+1.006472e+00*S51+9.108287e-01*S52+7.685818e-01*S53+6.813934e+00*S54+1.009992e+00*S55+7.658613e-01*S56+1.163030e+00*S57+1.006042e+00*S58+7.310070e+00*S59'
.param V21_part7='V21_part6+1.107223e+00*S60+1.025479e+00*S61+9.373891e-01*S62+1.251689e+00*S63+1.163669e+00*S64+1.035503e+00*S65+1.356862e+00*S66+1.283536e+00*S67+1.133754e+00*S68+1.439734e+00*S69'
.param V21_part8='V21_part7+1.371938e+00*S70+1.234127e+00*S71+1.521969e+00*S72+1.430358e+00*S73+1.188410e+00*S74+3.990240e-01*S75+3.693180e-01*S76+3.328410e-01*S77+4.497525e-01*S78+4.164879e-01*S79'
.param V21_part9='V21_part8+3.033187e-01*S80+4.856049e-01*S81+4.527753e-01*S82+3.901201e-01*S83+5.067595e-01*S84+4.760915e-01*S85+4.129979e-01*S86+5.359887e-01*S87+4.942146e-01*S88+4.369039e-01*S89'
.param V21_part10='V21_part9+1.520281e+00*S90+1.600989e+00*S91+1.627571e+00*S92+1.742895e+00*S93+1.846445e+00*S94+2.617683e+00*S95+1.913368e+00*S96+1.452258e+00*S97+1.883967e+00*S98+2.245966e+00*S99'
.param V21_part11='V21_part10+1.402945e+00*S100+1.978841e+00*S101+2.102878e+00*S102+1.644885e+00*S103+2.083623e+00*S104+2.056782e+00*S105+1.961078e+00*S106+1.988725e+00*S107+2.361256e+00*S108+2.262020e+00*S109'
.param V21_part12='V21_part11+2.099696e+00*S110+2.575793e+00*S111+2.464542e+00*S112+2.279409e+00*S113+2.743544e+00*S114+2.610905e+00*S115+2.392891e+00*S116+2.929909e+00*S117+2.746969e+00*S118+2.491869e+00*S119'
.param V21_part13='V21_part12+2.428789e+00*S120+2.357976e+00*S121+2.332791e+00*S122+2.785354e+00*S123+2.671827e+00*S124+2.567361e+00*S125+2.922641e+00*S126+2.906156e+00*S127+2.709581e+00*S128+3.219227e+00*S129'
.param V21_part14='V21_part13+3.068681e+00*S130+2.871243e+00*S131+2.862152e+00*S132+3.229146e+00*S133+3.022512e+00*S134+1.331950e+00*S135+1.261420e+00*S136+1.232861e+00*S137+1.543304e+00*S138+1.437535e+00*S139'
.param V21_part15='V21_part14+1.410066e+00*S140+1.682551e+00*S141+1.598337e+00*S142+1.496893e+00*S143+1.793381e+00*S144+1.702668e+00*S145+1.580140e+00*S146+1.894424e+00*S147+1.797802e+00*S148+1.672577e+00*S149'
.param V21_part16='V21_part15+3.177064e+00*S150+2.924840e+00*S151+3.600530e+00*S152+3.743720e+00*S153+3.390429e+00*S154+3.514769e+00*S155+4.020972e+00*S156+3.831009e+00*S157+3.675777e+00*S158+4.067221e+00*S159'
.param V21_part17='V21_part16+4.054764e+00*S160+2.558098e+00*S161+4.549601e+00*S162+4.167748e+00*S163+2.054314e+00*S164+5.312927e+00*S165+3.354679e+00*S166+3.492010e+00*S167+4.301289e+00*S168+4.114598e+00*S169'
.param V21_part18='V21_part17+3.853206e+00*S170+4.614597e+00*S171+3.903574e+00*S172+3.957544e+00*S173+5.123966e+00*S174+4.620563e+00*S175+4.163809e+00*S176+4.197368e+00*S177+4.889239e+00*S178+4.441878e+00*S179'
.param V21_part19='V21_part18+4.083610e+00*S180+4.179732e+00*S181+4.466756e+00*S182+4.804862e+00*S183+4.277212e+00*S184+9.311600e+00*S185+5.180834e+00*S186+4.976565e+00*S187+4.617006e+00*S188+5.177702e+00*S189'
.param V21_part20='V21_part19+5.357466e+00*S190+4.821031e+00*S191+5.209531e+00*S192+5.690458e+00*S193+5.170345e+00*S194+2.824264e+00*S195+2.746942e+00*S196+2.606137e+00*S197+3.217726e+00*S198+3.106627e+00*S199'
.param V21_part21='V21_part20+2.876782e+00*S200+3.518495e+00*S201+3.362903e+00*S202+3.117716e+00*S203+3.726006e+00*S204+3.482721e+00*S205+3.223196e+00*S206+3.933208e+00*S207+3.695985e+00*S208+3.387344e+00*S209'
.param V21_part22='V21_part21+5.070389e+00*S210+4.902005e+00*S211+4.966119e+00*S212+5.973238e+00*S213+7.251665e+00*S214+5.774804e+00*S215+6.451663e+00*S216+6.488808e+00*S217+5.583652e+00*S218+6.440565e+00*S219'
.param V21_part23='V21_part22+6.470932e+00*S220+5.590143e+00*S221+7.565273e+00*S222+6.813558e+00*S223+6.177253e+00*S224+1.561607e+01*S225+2.175180e+01*S226+1.150413e+01*S227+7.443389e+00*S228+1.905589e+02*S229'
.param V21_part24='V21_part23+1.425177e+01*S230+7.826680e+00*S231+7.374060e+02*S232+8.746393e+00*S233+8.709040e+00*S234+1.358879e+02*S235+4.953247e+01*S236+1.071966e+01*S237+7.596229e+00*S238+7.092671e+00*S239'
.param V21_part25='V21_part24+8.735704e+00*S240+6.558668e+00*S241+6.684610e+00*S242+7.113998e+00*S243+6.328415e+00*S244+6.999958e+00*S245+7.661429e+00*S246+8.063659e+00*S247+7.491553e+00*S248+7.732958e+00*S249'
.param V21_part26='V21_part25+9.109068e+00*S250+7.478845e+00*S251+9.816345e+00*S252+8.601880e+00*S253+7.489505e+00*S254+4.802913e+00*S255+4.601317e+00*S256+4.410515e+00*S257+5.417751e+00*S258+5.305450e+00*S259'
.param V21_part27='V21_part26+5.301827e+00*S260+5.788602e+00*S261+5.527219e+00*S262+5.193796e+00*S263+6.160773e+00*S264+5.766115e+00*S265+5.314295e+00*S266+5.703867e+00*S267+6.040083e+00*S268+5.480372e+00*S269'
.param V21_part28='V21_part27+7.872029e+00*S270+7.552941e+00*S271+7.900571e+00*S272+8.806248e+00*S273+8.639704e+00*S274+8.477500e+00*S275+9.612177e+00*S276+9.467069e+00*S277+8.580509e+00*S278+1.028861e+01*S279'
.param V21_part29='V21_part28+1.001016e+01*S280+8.869354e+00*S281+1.017432e+01*S282+1.032324e+01*S283+9.182488e+00*S284+8.698170e+00*S285+8.241863e+00*S286+8.513965e+00*S287+9.685278e+00*S288+9.007327e+00*S289'
.param V21_part30='V21_part29+9.259365e+00*S290+9.048103e+00*S291+7.537046e+00*S292+9.939517e+00*S293+9.475772e+00*S294+9.544050e+00*S295+1.042649e+01*S296+1.177462e+01*S297+9.592646e+00*S298+1.156509e+01*S299'
.param V21_part31='V21_part30+7.122331e+00*S300+6.492593e+00*S301+7.336668e+00*S302+8.057315e+00*S303+8.051885e+00*S304+7.826176e+00*S305+8.790725e+00*S306+8.185882e+00*S307+7.961502e+00*S308+8.573220e+00*S309'
.param V21='V21_part31+8.903775e+00*S310+8.009553e+00*S311+9.475463e+00*S312+8.170964e+00*S313+8.595077e+00*S314'
.param V22_part1='(-1.689278e-01)*S0+(-5.231225e-03)*S1+6.159984e-03*S2+(-4.284050e-01)*S3+(-2.515863e-02)*S4+(-1.188594e-02)*S5+(-1.934858e-01)*S6+(-3.590990e-02)*S7+(-1.006831e-02)*S8+(-1.557894e-01)*S9'
.param V22_part2='V22_part1+(-5.271354e-02)*S10+(-1.189962e-02)*S11+(-2.361990e-01)*S12+(-5.369288e-02)*S13+(-2.243928e-02)*S14+(-2.012131e-02)*S15+6.592569e-04*S16+1.808227e-02*S17+(-5.946662e-02)*S18+(-2.307504e-02)*S19'
.param V22_part3='V22_part2+1.501136e-02*S20+(-9.690604e-02)*S21+(-4.468141e-02)*S22+5.279100e-03*S23+(-1.366391e-01)*S24+(-3.613384e-02)*S25+(-2.984357e-02)*S26+(-1.669716e-01)*S27+(-9.256854e-02)*S28+(-4.820229e-02)*S29'
.param V22_part4='V22_part3+2.205539e-03*S30+6.448378e-03*S31+3.518604e-02*S32+(-7.914883e-02)*S33+2.203213e-02*S34+4.694501e-03*S35+(-1.441486e-01)*S36+7.966594e-02*S37+3.452330e-02*S38+(-3.875999e-02)*S39'
.param V22_part5='V22_part4+7.144734e-02*S40+1.285096e-01*S41+(-9.409710e-04)*S42+7.707872e-02*S43+3.100056e-01*S44+3.590226e-02*S45+5.100955e-02*S46+8.213092e-02*S47+(-5.022513e-02)*S48+2.483019e-03*S49'
.param V22_part6='V22_part5+1.581860e-01*S50+(-1.050429e-01)*S51+1.554485e-01*S52+6.207886e-01*S53+(-1.128382e+00)*S54+4.234477e-02*S55+8.068525e-01*S56+4.168433e-01*S57+1.074251e+00*S58+2.192228e+00*S59'
.param V22_part7='V22_part6+5.526740e-02*S60+8.000441e-02*S61+1.059481e-01*S62+(-4.998719e-02)*S63+1.954403e-02*S64+7.013249e-02*S65+(-1.793990e-01)*S66+(-6.113529e-02)*S67+4.755738e-02*S68+(-3.073973e-01)*S69'
.param V22_part8='V22_part7+(-1.308965e-01)*S70+2.026478e-02*S71+(-4.179946e-01)*S72+(-1.852750e-01)*S73+(-8.149912e-02)*S74+(-1.015437e-02)*S75+8.825682e-04*S76+1.923709e-02*S77+(-4.809144e-02)*S78+(-1.904305e-02)*S79'
.param V22_part9='V22_part8+2.275787e-02*S80+(-8.716034e-02)*S81+(-4.417466e-02)*S82+(-8.314476e-03)*S83+(-1.262068e-01)*S84+(-6.806331e-02)*S85+(-2.695798e-02)*S86+(-1.629851e-01)*S87+(-9.841137e-02)*S88+(-5.225047e-02)*S89'
.param V22_part10='V22_part9+1.647559e-01*S90+2.055746e-01*S91+2.926315e-01*S92+1.806171e-01*S93+1.741772e-01*S94+5.759075e+00*S95+3.100744e-01*S96+2.191934e+00*S97+1.763995e-01*S98+(-3.116388e-01)*S99'
.param V22_part11='V22_part10+2.048115e+00*S100+1.254172e-01*S101+7.067703e-01*S102+1.528782e+00*S103+4.025119e-02*S104+2.830160e-01*S105+3.540514e-01*S106+3.907549e-01*S107+1.164488e-01*S108+2.988867e-01*S109'
.param V22_part12='V22_part11+3.456049e-01*S110+(-6.070568e-02)*S111+2.094511e-01*S112+2.673157e-01*S113+(-2.677368e-01)*S114+6.473610e-02*S115+1.927314e-01*S116+(-5.350151e-01)*S117+(-8.277143e-02)*S118+8.048763e-02*S119'
.param V22_part13='V22_part12+3.858189e-01*S120+4.905017e-01*S121+5.110042e-01*S122+2.407223e-01*S123+4.040610e-01*S124+4.625331e-01*S125+5.146067e-01*S126+2.832402e-01*S127+3.891475e-01*S128+(-2.648081e-01)*S129'
.param V22_part14='V22_part13+1.492209e-01*S130+3.153332e-01*S131+5.463858e-01*S132+(-2.768285e-02)*S133+1.457131e-01*S134+1.244470e-01*S135+1.135460e-01*S136+2.118837e-01*S137+8.239413e-03*S138+5.412006e-02*S139'
.param V22_part15='V22_part14+1.818498e-01*S140+(-1.333744e-01)*S141+2.340505e-02*S142+1.362396e-01*S143+(-2.623612e-01)*S144+(-3.189605e-02)*S145+6.517777e-02*S146+(-3.758803e-01)*S147+(-1.192454e-01)*S148+4.671015e-03*S149'
.param V22_part16='V22_part15+6.316143e-01*S150+6.412505e-01*S151+9.515882e-01*S152+5.339048e-01*S153+5.753052e-01*S154+8.358821e-01*S155+2.204286e-01*S156+5.284585e-01*S157+7.501566e-01*S158+(-6.261579e-01)*S159'
.param V22_part17='V22_part16+3.275145e-01*S160+4.339492e-01*S161+(-5.387744e-01)*S162+(-4.421181e-01)*S163+5.766415e-02*S164+1.861188e+00*S165+6.714046e-01*S166+1.053328e+00*S167+7.149806e-01*S168+9.262868e-01*S169'
.param V22_part18='V22_part17+9.985228e-01*S170+3.344697e-01*S171+3.633799e-01*S172+8.303996e-01*S173+(-1.230538e+00)*S174+3.824874e-01*S175+7.109681e-01*S176+2.498405e+00*S177+2.504855e-01*S178+4.992848e-01*S179'
.param V22_part19='V22_part18+9.405529e-01*S180+1.354040e+00*S181+1.426220e+00*S182+9.152495e-01*S183+7.333376e-01*S184+5.412556e+00*S185+4.258699e-01*S186+8.562249e-01*S187+1.170215e+00*S188+(-4.753358e-01)*S189'
.param V22_part20='V22_part19+6.771674e-01*S190+1.027831e+00*S191+6.421302e-02*S192+4.383892e-01*S193+6.801484e-01*S194+5.426357e-01*S195+6.461900e-01*S196+6.368638e-01*S197+3.820690e-01*S198+5.384308e-01*S199'
.param V22_part21='V22_part20+5.850383e-01*S200+1.641376e-01*S201+4.094062e-01*S202+5.187428e-01*S203+(-1.138984e-01)*S204+1.786607e-01*S205+4.176829e-01*S206+(-4.943171e-01)*S207+8.886908e-02*S208+2.544422e-01*S209'
.param V22_part22='V22_part21+1.267787e+00*S210+1.727891e+00*S211+1.077309e+01*S212+1.395745e+00*S213+2.017438e+00*S214+9.072184e+00*S215+(-5.521135e-01)*S216+1.257266e+00*S217+1.519686e+00*S218+(-5.770963e-01)*S219'
.param V22_part23='V22_part22+1.030886e+00*S220+1.828874e+00*S221+(-1.694511e+00)*S222+6.643443e-01*S223+1.135521e+00*S224+2.638868e+00*S225+1.155761e+00*S226+1.284194e+00*S227+8.945917e-01*S228+(-8.593689e+01)*S229'
.param V22_part24='V22_part23+2.363530e+00*S230+1.626461e+00*S231+(-1.610183e+03)*S232+2.945320e+00*S233+1.108594e+00*S234+(-3.301240e+01)*S235+2.340519e+00*S236+(-8.042173e-01)*S237+9.801483e-01*S238+1.522538e+00*S239'
.param V22_part25='V22_part24+2.611617e+00*S240+2.895262e+00*S241+2.979863e+00*S242+8.937540e-01*S243+1.322727e+00*S244+2.773897e+00*S245+(-1.031305e-01)*S246+2.377309e+00*S247+2.574200e+00*S248+(-3.423148e+00)*S249'
.param V22_part26='V22_part25+5.884202e+00*S250+2.218474e+00*S251+(-4.574206e+00)*S252+1.364856e+00*S253+1.707096e+00*S254+1.502821e+00*S255+1.577451e+00*S256+1.547052e+00*S257+1.114495e+00*S258+1.454436e+00*S259'
.param V22_part27='V22_part26+1.662658e+00*S260+7.263408e-01*S261+1.148077e+00*S262+1.391236e+00*S263+2.479543e-01*S264+8.181695e-01*S265+1.180593e+00*S266+1.444796e-01*S267+5.120499e-01*S268+8.701837e-01*S269'
.param V22_part28='V22_part27+3.715683e+00*S270+3.658853e+00*S271+3.982328e+00*S272+3.248548e+00*S273+3.559224e+00*S274+3.749469e+00*S275+2.885934e+00*S276+3.289029e+00*S277+3.347483e+00*S278+2.201614e+00*S279'
.param V22_part29='V22_part28+2.562635e+00*S280+2.952452e+00*S281+1.151618e-01*S282+2.181263e+00*S283+2.546604e+00*S284+4.409085e+00*S285+4.198570e+00*S286+4.598247e+00*S287+4.130732e+00*S288+3.816835e+00*S289'
.param V22_part30='V22_part29+4.552407e+00*S290+2.414563e-01*S291+1.729045e-01*S292+4.010640e+00*S293+(-8.879930e-01)*S294+7.949088e-01*S295+3.599213e+00*S296+1.054849e+00*S297+6.218727e-01*S298+3.317263e+00*S299'
.param V22_part31='V22_part30+3.086448e+00*S300+2.226111e+00*S301+3.454602e+00*S302+2.830321e+00*S303+3.271886e+00*S304+3.365924e+00*S305+2.426329e+00*S306+2.438329e+00*S307+2.916280e+00*S308+(-2.047192e-01)*S309'
.param V22='V22_part31+2.196408e+00*S310+2.539206e+00*S311+2.879990e-01*S312+1.090783e+00*S313+2.204978e+00*S314'
.param V23_part1='3.501722e-01*S0+1.063766e-01*S1+1.304664e-01*S2+7.763353e-01*S3+1.402837e-01*S4+3.367352e-01*S5+3.305212e-01*S6+1.434106e-01*S7+2.111959e-01*S8+3.244000e-01*S9'
.param V23_part2='V23_part1+1.412729e-01*S10+1.670384e-01*S11+8.108597e-01*S12+1.561048e-01*S13+1.898261e-01*S14+6.138096e-02*S15+5.695548e-02*S16+1.500965e-01*S17+6.438533e-02*S18+6.197756e-02*S19'
.param V23_part3='V23_part2+2.084168e-01*S20+6.534780e-02*S21+6.258413e-02*S22+1.650029e-01*S23+6.612004e-02*S24+4.003015e-01*S25+5.804303e-02*S26+6.671896e-02*S27+6.280971e-02*S28+5.819847e-02*S29'
.param V23_part4='V23_part3+2.065941e-01*S30+6.237316e-02*S31+4.909630e-02*S32+6.657770e-02*S33+1.470080e-01*S34+6.139783e-02*S35+6.836471e-02*S36+4.235935e-01*S37+1.735656e-01*S38+5.152012e-01*S39'
.param V23_part5='V23_part4+4.926796e-01*S40+3.439463e-01*S41+7.103847e-01*S42+4.949561e-01*S43+6.420351e-01*S44+7.718627e-02*S45+7.369398e-02*S46+6.941986e-02*S47+7.869832e-02*S48+7.691150e-02*S49'
.param V23_part6='V23_part5+2.554540e-01*S50+3.839425e-01*S51+5.253430e-01*S52+7.840671e-01*S53+(-2.242118e+02)*S54+4.500678e-01*S55+1.014182e+00*S56+1.396285e+00*S57+1.516598e+00*S58+(-1.010064e+03)*S59'
.param V23_part7='V23_part6+6.793261e-02*S60+6.487638e-02*S61+6.276678e-02*S62+6.829073e-02*S63+6.544255e-02*S64+6.548775e-02*S65+6.917453e-02*S66+6.695985e-02*S67+7.395941e-02*S68+7.047399e-02*S69'
.param V23_part8='V23_part7+7.020587e-02*S70+7.856491e-02*S71+7.375763e-02*S72+7.679869e-02*S73+5.971413e-02*S74+2.626840e-02*S75+2.633987e-02*S76+2.596374e-02*S77+2.743430e-02*S78+2.662159e-02*S79'
.param V23_part9='V23_part8+1.032691e-01*S80+2.564858e-02*S81+2.811294e-02*S82+2.245309e-02*S83+2.399847e-02*S84+2.495211e-02*S85+2.184952e-02*S86+2.260307e-02*S87+2.320661e-02*S88+2.235970e-02*S89'
.param V23_part10='V23_part9+2.348031e-01*S90+6.671659e-02*S91+7.345408e-02*S92+4.373064e-01*S93+6.933086e-02*S94+(-2.436992e-01)*S95+7.943945e-01*S96+1.226775e+00*S97+7.489239e-02*S98+8.138189e-02*S99'
.param V23_part11='V23_part10+1.693369e+00*S100+8.061447e-02*S101+1.937136e+00*S102+1.946213e+00*S103+8.591645e-02*S104+8.504811e-02*S105+8.549115e-02*S106+8.183726e-02*S107+9.030523e-02*S108+9.062457e-02*S109'
.param V23_part12='V23_part11+8.837487e-02*S110+9.227135e-02*S111+8.606018e-02*S112+8.765703e-02*S113+8.830212e-02*S114+8.108605e-02*S115+8.297112e-02*S116+8.959603e-02*S117+8.268825e-02*S118+8.001503e-02*S119'
.param V23_part13='V23_part12+7.229394e-02*S120+7.734681e-02*S121+7.584638e-02*S122+8.058212e-02*S123+8.000584e-02*S124+8.432091e-02*S125+9.391900e-01*S126+8.325940e-02*S127+8.872427e-02*S128+7.634506e-02*S129'
.param V23_part14='V23_part13+8.192049e-02*S130+9.072680e-02*S131+2.214810e+00*S132+8.715874e-02*S133+7.852874e-02*S134+3.112795e-02*S135+2.884940e-02*S136+3.308967e-02*S137+2.952493e-02*S138+3.163572e-02*S139'
.param V23_part15='V23_part14+3.624364e-02*S140+3.045001e-02*S141+3.523438e-02*S142+3.984323e-02*S143+3.216936e-02*S144+3.599982e-02*S145+4.545705e-02*S146+3.439527e-02*S147+3.801502e-02*S148+4.087808e-02*S149'
.param V23_part16='V23_part15+6.396745e-02*S150+5.946041e-02*S151+9.095775e-02*S152+8.269150e-02*S153+6.180460e-02*S154+8.132823e-02*S155+8.471685e-02*S156+7.103460e-02*S157+8.031115e-02*S158+1.231719e+00*S159'
.param V23_part17='V23_part16+7.844057e-02*S160+9.740264e-01*S161+6.360493e-02*S162+9.105639e-01*S163+1.329274e+00*S164+2.633337e-01*S165+2.505925e-01*S166+8.092753e-02*S167+8.690770e-02*S168+7.813351e-02*S169'
.param V23_part18='V23_part17+8.109740e-02*S170+7.878426e-02*S171+9.254982e-01*S172+8.676289e-02*S173+7.928759e-01*S174+6.946976e-02*S175+8.075806e-02*S176+2.863483e+00*S177+6.902295e-02*S178+7.809452e-02*S179'
.param V23_part19='V23_part18+6.671325e-02*S180+7.465525e-02*S181+7.617775e-02*S182+7.597461e-02*S183+7.956729e-02*S184+1.634714e-01*S185+7.425983e-02*S186+6.805082e-02*S187+8.661469e-02*S188+9.130997e-01*S189'
.param V23_part20='V23_part19+6.199275e-02*S190+9.831187e-02*S191+2.350080e+00*S192+5.533674e-02*S193+8.228167e-02*S194+3.172037e-02*S195+2.512334e-02*S196+3.229264e-02*S197+3.676065e-02*S198+2.541811e-02*S199'
.param V23_part21='V23_part20+3.118408e-02*S200+4.086385e-02*S201+4.354825e-02*S202+2.578767e-02*S203+3.747557e-02*S204+2.960764e-02*S205+5.019190e-02*S206+8.021613e-03*S207+4.309000e-02*S208+3.583145e-02*S209'
.param V23_part22='V23_part21+6.501433e-02*S210+6.595320e-02*S211+(-8.784595e-02)*S212+6.948987e-02*S213+4.365187e-02*S214+2.312471e-03*S215+1.112516e+00*S216+7.942296e-01*S217+7.232004e-01*S218+8.747891e-01*S219'
.param V23_part23='V23_part22+6.037034e-02*S220+1.044412e+00*S221+1.991513e+00*S222+5.214414e-02*S223+4.129529e-02*S224+4.700797e-01*S225+7.191026e-02*S226+(-6.578032e-02)*S227+6.072092e-01*S228+6.815228e+00*S229'
.param V23_part24='V23_part23+1.061585e-01*S230+5.763431e-01*S231+1.340517e+02*S232+1.237163e-01*S233+7.342107e-01*S234+4.096747e+00*S235+5.062070e-01*S236+1.984449e+00*S237+6.890700e-02*S238+7.749138e-02*S239'
.param V23_part25='V23_part24+8.715196e-02*S240+7.640797e-02*S241+9.500567e-02*S242+1.645661e-01*S243+7.094785e-01*S244+8.493592e-02*S245+1.368242e-01*S246+6.740675e-02*S247+7.660479e-02*S248+(-1.229070e-02)*S249'
.param V23_part26='V23_part25+2.226854e+00*S250+7.082056e-02*S251+2.283464e-01*S252+3.757140e-02*S253+4.956329e-02*S254+2.768955e-02*S255+3.025953e-02*S256+3.243763e-02*S257+2.680384e-02*S258+2.588140e-02*S259'
.param V23_part27='V23_part26+5.008870e-02*S260+2.235992e-02*S261+2.309060e-02*S262+3.841517e-02*S263+1.334051e-02*S264+2.294315e-02*S265+3.082082e-02*S266+2.536834e+00*S267+1.710940e-02*S268+2.701715e-02*S269'
.param V23_part28='V23_part27+6.484896e-02*S270+6.312720e-02*S271+5.909904e-02*S272+5.622943e-02*S273+6.127110e-02*S274+5.913460e-02*S275+5.999837e-02*S276+4.867625e-02*S277+6.676975e-02*S278+5.243478e-02*S279'
.param V23_part29='V23_part28+4.885493e-02*S280+5.960911e-02*S281+7.234030e-02*S282+4.266875e-02*S283+6.610412e-02*S284+8.013752e-02*S285+7.883310e-02*S286+8.949483e-02*S287+7.691839e-02*S288+6.852243e-02*S289'
.param V23_part30='V23_part29+9.909087e-02*S290+1.617441e-01*S291+2.679041e-01*S292+1.177540e-01*S293+1.931514e-01*S294+1.501070e+00*S295+1.179942e-01*S296+2.110298e-02*S297+2.125194e+00*S298+1.164757e-01*S299'
.param V23_part31='V23_part30+1.806218e-02*S300+3.792992e-02*S301+5.216746e-02*S302+1.922863e-02*S303+2.276693e-02*S304+3.802621e-02*S305+1.117548e-02*S306+1.388429e-02*S307+3.062436e-02*S308+1.539314e+00*S309'
.param V23='V23_part31+2.906455e-03*S310+2.105007e-02*S311+(-1.879272e-02)*S312+1.949318e+00*S313+2.483099e-02*S314'
.param V24_part1='3.846707e-04*S0+2.121048e-04*S1+2.839349e-04*S2+2.036311e-03*S3+1.779709e-04*S4+9.864881e-04*S5+3.249264e-04*S6+1.645457e-04*S7+(-2.614033e-04)*S8+4.003257e-04*S9'
.param V24_part2='V24_part1+3.373727e-04*S10+2.990678e-06*S11+(-2.405324e-03)*S12+(-4.681518e-05)*S13+1.481430e-04*S14+8.056811e-04*S15+7.692336e-04*S16+2.381609e-04*S17+8.920083e-04*S18+8.597910e-04*S19'
.param V24_part3='V24_part2+2.075578e-04*S20+1.036106e-03*S21+9.347286e-04*S22+5.225164e-04*S23+1.081376e-03*S24+1.667098e-05*S25+9.040096e-04*S26+1.093926e-03*S27+1.011245e-03*S28+9.375503e-04*S29'
.param V24_part4='V24_part3+4.467565e-03*S30+4.427571e-03*S31+3.614023e-03*S32+2.760828e-03*S33+2.613897e-03*S34+5.003923e-03*S35+8.545738e-04*S36+(-4.595974e-03)*S37+4.671438e-03*S38+(-6.516653e-04)*S39'
.param V24_part5='V24_part4+(-1.154220e-05)*S40+3.563895e-03*S41+(-4.047172e-03)*S42+(-5.021751e-04)*S43+2.805730e-03*S44+6.015560e-03*S45+5.912463e-03*S46+5.070135e-03*S47+3.949631e-03*S48+2.597778e-03*S49'
.param V24_part6='V24_part5+3.648774e-03*S50+(-5.284858e-03)*S51+(-1.291610e-02)*S52+(-1.134280e-02)*S53+4.429085e-02*S54+8.373426e-04*S55+(-9.373201e-03)*S56+(-6.588662e-02)*S57+(-5.402989e-02)*S58+(-9.636520e-02)*S59'
.param V24_part7='V24_part6+8.135419e-03*S60+7.824034e-03*S61+8.004105e-03*S62+5.756795e-03*S63+6.505428e-03*S64+8.468444e-03*S65+2.315725e-03*S66+4.554850e-03*S67+5.561044e-03*S68+(-3.065984e-03)*S69'
.param V24_part8='V24_part7+1.120896e-03*S70+3.693394e-03*S71+(-6.891727e-03)*S72+7.459296e-04*S73+6.070670e-03*S74+5.332287e-03*S75+4.219524e-03*S76+3.632779e-03*S77+4.363354e-03*S78+3.995273e-03*S79'
.param V24_part9='V24_part8+(-1.079080e-03)*S80+3.913742e-03*S81+2.854159e-03*S82+2.749955e-03*S83+4.278731e-03*S84+3.295162e-03*S85+2.768972e-03*S86+5.219842e-03*S87+3.447029e-03*S88+2.792510e-03*S89'
.param V24_part10='V24_part9+7.644381e-03*S90+1.852797e-02*S91+2.480299e-02*S92+(-1.189646e-03)*S93+1.484487e-02*S94+1.152581e-01*S95+(-1.600761e-02)*S96+4.323560e-03*S97+1.762574e-02*S98+(-6.166834e-03)*S99'
.param V24_part11='V24_part10+(-2.681188e-02)*S100+1.521727e-02*S101+(-6.067393e-02)*S102+(-2.244001e-02)*S103+5.767427e-03*S104+2.343523e-02*S105+2.545708e-02*S106+3.219799e-02*S107+1.216956e-02*S108+1.895251e-02*S109'
.param V24_part12='V24_part11+2.887065e-02*S110+2.709294e-03*S111+1.510563e-02*S112+2.703212e-02*S113+(-1.084730e-02)*S114+1.050392e-02*S115+2.528407e-02*S116+(-2.632310e-02)*S117+3.302384e-03*S118+2.126815e-03*S119'
.param V24_part13='V24_part12+2.741775e-02*S120+3.071551e-02*S121+3.942025e-02*S122+1.780889e-02*S123+2.425558e-02*S124+3.831164e-02*S125+(-1.577806e-03)*S126+1.814317e-02*S127+3.331684e-02*S128+(-1.416403e-02)*S129'
.param V24_part14='V24_part13+1.259692e-02*S130+2.082182e-02*S131+(-1.104840e-02)*S132+(-4.698890e-03)*S133+9.424325e-03*S134+1.253759e-02*S135+1.422820e-02*S136+1.553223e-02*S137+1.010517e-02*S138+1.314995e-02*S139'
.param V24_part15='V24_part14+1.676256e-02*S140+4.714807e-03*S141+8.759442e-03*S142+1.445209e-02*S143+(-1.667532e-03)*S144+5.211508e-03*S145+1.387975e-02*S146+(-7.668137e-03)*S147+2.013959e-03*S148+9.650477e-03*S149'
.param V24_part16='V24_part15+4.830743e-02*S150+4.938778e-02*S151+7.607553e-02*S152+2.803173e-02*S153+3.347727e-02*S154+6.017032e-02*S155+6.888473e-03*S156+2.775065e-02*S157+5.105187e-02*S158+4.250528e-02*S159'
.param V24_part17='V24_part16+1.382360e-02*S160+4.676201e-02*S161+(-3.139501e-02)*S162+9.317025e-02*S163+1.096440e-01*S164+2.339402e-01*S165+6.854845e-02*S166+7.607977e-02*S167+3.475249e-02*S168+5.718398e-02*S169'
.param V24_part18='V24_part17+7.215100e-02*S170+6.878603e-03*S171+2.509765e-02*S172+6.102945e-02*S173+6.039330e-02*S174+5.773919e-03*S175+4.746456e-02*S176+(-3.229898e-03)*S177+(-5.138671e-04)*S178+3.167854e-02*S179'
.param V24_part19='V24_part18+6.233154e-02*S180+7.603035e-02*S181+1.010353e-01*S182+4.226486e-02*S183+6.577895e-02*S184+5.650385e-02*S185+1.668061e-02*S186+3.768366e-02*S187+6.969102e-02*S188+6.219666e-02*S189'
.param V24_part20='V24_part19+1.838096e-02*S190+5.145815e-02*S191+(-4.894141e-02)*S192+(-3.003284e-03)*S193+3.506888e-02*S194+4.040754e-02*S195+4.724538e-02*S196+5.151958e-02*S197+2.587994e-02*S198+3.861248e-02*S199'
.param V24_part21='V24_part20+4.746081e-02*S200+9.672501e-03*S201+2.996362e-02*S202+4.436084e-02*S203+(-1.397033e-02)*S204+1.044690e-02*S205+3.643455e-02*S206+(-2.863635e-02)*S207+(-1.874280e-03)*S208+2.111724e-02*S209'
.param V24_part22='V24_part21+9.525098e-02*S210+1.087695e-01*S211+4.428943e-01*S212+6.531557e-02*S213+7.812788e-02*S214+3.990061e-01*S215+1.449972e-01*S216+1.401003e-01*S217+1.127307e-01*S218+7.308152e-02*S219'
.param V24_part23='V24_part22+3.468367e-02*S220+3.151428e-02*S221+7.319825e-02*S222+5.485694e-03*S223+3.422709e-02*S224+1.146269e+00*S225+(-1.119521e+00)*S226+(-8.323309e-01)*S227+3.135690e-01*S228+(-7.773822e+00)*S229'
.param V24_part24='V24_part23+(-5.767945e-01)*S230+5.687093e-02*S231+2.458531e+00*S232+1.166642e-01*S233+1.894863e-02*S234+(-2.974124e+00)*S235+(-2.234906e+00)*S236+2.131170e-01*S237+1.592264e-02*S238+5.736127e-02*S239'
.param V24_part25='V24_part24+8.343386e-02*S240+1.575547e-01*S241+1.918273e-01*S242+2.165612e-01*S243+1.787962e-01*S244+1.723008e-01*S245+2.218869e-01*S246+9.944136e-02*S247+1.571887e-01*S248+4.227548e-01*S249'
.param V24_part26='V24_part25+3.999980e-01*S250+1.297703e-01*S251+1.048063e+00*S252+1.146690e-02*S253+7.456590e-02*S254+9.419793e-02*S255+9.990475e-02*S256+1.105669e-01*S257+7.252256e-02*S258+8.092155e-02*S259'
.param V24_part27='V24_part26+1.027942e-01*S260+2.864420e-02*S261+4.704546e-02*S262+8.628326e-02*S263+(-6.445732e-03)*S264+2.854928e-02*S265+6.651977e-02*S266+(-1.086094e-01)*S267+2.030455e-03*S268+4.456459e-02*S269'
.param V24_part28='V24_part27+1.909459e-01*S270+2.031253e-01*S271+2.512698e-01*S272+1.474070e-01*S273+1.596500e-01*S274+2.167795e-01*S275+9.016502e-02*S276+1.381714e-01*S277+1.948877e-01*S278+2.449097e-02*S279'
.param V24_part29='V24_part28+7.075709e-02*S280+1.516328e-01*S281+2.439479e-03*S282+2.868768e-02*S283+1.219922e-01*S284+2.314309e-01*S285+2.351588e-01*S286+2.730534e-01*S287+1.773179e-01*S288+1.982740e-01*S289'
.param V24_part30='V24_part29+2.620310e-01*S290+2.175734e-01*S291+2.927634e-01*S292+2.361804e-01*S293+1.702940e-01*S294+2.029198e-01*S295+2.016140e-01*S296+(-3.581084e-02)*S297+5.074594e-02*S298+1.586124e-01*S299'
.param V24_part31='V24_part30+1.549919e-01*S300+1.860281e-01*S301+2.144871e-01*S302+1.182671e-01*S303+1.623844e-01*S304+2.055789e-01*S305+6.964731e-02*S306+1.037623e-01*S307+1.622235e-01*S308+6.013235e-03*S309'
.param V24='V24_part31+7.422333e-02*S310+1.249892e-01*S311+(-6.244090e-02)*S312+(-3.882431e-02)*S313+9.808850e-02*S314'
.param V25_part1='(-6.385757e-01)*S0+1.293224e-01*S1+(-2.844840e-02)*S2+(-1.346816e+00)*S3+4.021568e-03*S4+(-4.663907e-01)*S5+(-3.678321e-01)*S6+7.383362e-02*S7+(-1.830343e-01)*S8+(-2.786120e-01)*S9'
.param V25_part2='V25_part1+1.412430e-01*S10+4.954836e-02*S11+(-7.064698e-01)*S12+1.789044e-01*S13+1.957566e-02*S14+(-8.633531e-02)*S15+(-5.008402e-02)*S16+(-6.593963e-02)*S17+(-2.696435e-01)*S18+(-1.615836e-02)*S19'
.param V25_part3='V25_part2+(-1.564993e-01)*S20+(-1.230096e-01)*S21+5.055448e-02*S22+7.503034e-02*S23+(-1.842649e-02)*S24+(-2.734233e-01)*S25+2.405711e-01*S26+1.272221e-03*S27+1.356212e-01*S28+2.035663e-01*S29'
.param V25_part4='V25_part3+(-1.700088e-01)*S30+(-1.679930e-01)*S31+8.853915e-01*S32+(-1.879788e-01)*S33+1.095615e-01*S34+(-3.819163e-01)*S35+(-2.099881e-01)*S36+(-2.542365e-01)*S37+3.352743e-01*S38+(-1.769680e-01)*S39'
.param V25_part5='V25_part4+(-2.619783e-01)*S40+1.885627e-01*S41+(-2.394858e-01)*S42+(-1.250810e-01)*S43+3.151235e-02*S44+(-1.459427e-01)*S45+(-1.275699e-01)*S46+2.034341e-01*S47+4.954940e-02*S48+(-1.297581e-01)*S49'
.param V25_part6='V25_part5+2.074478e-01*S50+(-3.055380e-02)*S51+(-2.090064e-01)*S52+(-3.459497e-02)*S53+(-4.072938e-01)*S54+(-7.837109e-03)*S55+(-2.360275e-02)*S56+(-2.983588e-01)*S57+(-2.831151e-01)*S58+(-1.959699e-02)*S59'
.param V25_part7='V25_part6+(-5.163985e-02)*S60+(-1.495584e-01)*S61+8.232725e-02*S62+3.732361e-02*S63+(-8.851714e-02)*S64+1.175964e-01*S65+(-4.391125e-02)*S66+2.041722e-01*S67+1.907575e-01*S68+1.689339e-02*S69'
.param V25_part8='V25_part7+2.029723e-01*S70+(-5.585155e-02)*S71+(-5.525974e-02)*S72+(-1.486030e-01)*S73+1.847184e+00*S74+(-3.280038e-01)*S75+(-2.699576e-01)*S76+(-3.091811e-01)*S77+(-2.214749e-01)*S78+(-2.015822e-01)*S79'
.param V25_part9='V25_part8+(-2.240359e-01)*S80+(-2.594158e-01)*S81+(-2.999916e-01)*S82+(-1.944597e-01)*S83+(-1.882301e-01)*S84+(-3.709899e-01)*S85+(-1.863215e-01)*S86+(-2.064141e-01)*S87+(-3.004942e-01)*S88+(-8.304254e-02)*S89'
.param V25_part10='V25_part9+(-6.557142e-02)*S90+(-1.217803e-01)*S91+1.280738e-01*S92+(-2.054555e-02)*S93+(-5.512806e-02)*S94+2.256822e-01*S95+(-8.967814e-02)*S96+(-1.270029e-01)*S97+(-1.197989e-01)*S98+(-8.715879e-02)*S99'
.param V25_part11='V25_part10+(-2.365160e-01)*S100+(-2.664992e-01)*S101+(-2.363002e-01)*S102+(-2.332456e-01)*S103+(-2.597578e-01)*S104+(-1.077689e-01)*S105+(-9.972417e-02)*S106+1.533774e-01*S107+(-2.315874e-02)*S108+(-9.048954e-02)*S109'
.param V25_part12='V25_part11+(-1.167234e-01)*S110+(-3.557605e-02)*S111+(-2.356369e-01)*S112+(-1.691214e-01)*S113+(-9.942013e-02)*S114+(-2.158074e-01)*S115+(-6.743174e-04)*S116+8.791982e-02*S117+(-1.764657e-01)*S118+(-1.176849e-02)*S119'
.param V25_part13='V25_part12+(-5.497786e-02)*S120+1.031547e-01*S121+1.445775e-01*S122+2.047607e-02*S123+6.736699e-03*S124+1.571354e-01*S125+(-8.341195e-02)*S126+(-2.241249e-01)*S127+5.857208e-02*S128+5.964064e-02*S129'
.param V25_part14='V25_part13+(-2.695477e-01)*S130+6.689015e-02*S131+(-2.748487e-01)*S132+3.271684e-02*S133+2.395554e-01*S134+(-2.580033e-01)*S135+(-3.160732e-01)*S136+3.013386e-01*S137+(-1.246155e-01)*S138+(-1.603341e-01)*S139'
.param V25_part15='V25_part14+2.980031e-01*S140+(-7.398539e-02)*S141+(-1.406050e-02)*S142+2.002155e-01*S143+(-1.097599e-01)*S144+(-1.848272e-01)*S145+(-2.606456e-02)*S146+(-2.616924e-01)*S147+(-2.142437e-01)*S148+(-2.773025e-01)*S149'
.param V25_part16='V25_part15+(-9.410933e-02)*S150+2.275901e-01*S151+1.509362e+00*S152+(-7.097800e-02)*S153+(-1.912810e-01)*S154+1.045144e-01*S155+(-1.501797e-01)*S156+(-4.110372e-02)*S157+4.811327e-02*S158+(-8.110152e-02)*S159'
.param V25_part17='V25_part16+1.236208e-02*S160+(-2.933300e-01)*S161+2.814152e-01*S162+(-5.782919e-02)*S163+(-4.376418e-01)*S164+9.329949e-02*S165+1.498022e-02*S166+(-3.948875e-01)*S167+4.681584e-02*S168+(-2.887365e-01)*S169'
.param V25_part18='V25_part17+(-7.860023e-02)*S170+(-5.930262e-02)*S171+(-1.931786e-01)*S172+(-4.501546e-01)*S173+7.239710e-02*S174+5.667519e-02*S175+(-3.378248e-01)*S176+(-2.815875e-01)*S177+6.257465e-02*S178+(-2.758387e-01)*S179'
.param V25_part19='V25_part18+6.703122e-01*S180+8.602384e-04*S181+1.060376e+00*S182+(-5.325670e-02)*S183+1.945211e+00*S184+4.208283e-01*S185+1.079026e-01*S186+(-5.283752e-02)*S187+8.736850e-02*S188+9.028474e-02*S189'
.param V25_part20='V25_part19+1.078361e-01*S190+1.065891e-02*S191+(-2.107786e-01)*S192+(-2.833521e-01)*S193+(-8.503016e-02)*S194+(-4.449640e-02)*S195+(-4.245828e-01)*S196+(-5.716163e-01)*S197+(-4.167212e-02)*S198+(-1.916377e-01)*S199'
.param V25_part21='V25_part20+(-3.789901e-01)*S200+(-1.456521e-01)*S201+(-2.184369e-01)*S202+(-2.147251e-02)*S203+(-1.781928e-01)*S204+(-1.640581e-01)*S205+(-1.564073e-01)*S206+2.262056e-01*S207+(-1.815184e-01)*S208+(-1.349029e-01)*S209'
.param V25_part22='V25_part21+1.575407e+00*S210+1.852157e-02*S211+4.280673e-01*S212+(-4.685794e-02)*S213+2.068279e+00*S214+3.757379e-01*S215+(-4.595717e-02)*S216+5.157105e-02*S217+(-1.474015e-02)*S218+1.814732e-01*S219'
.param V25_part23='V25_part22+1.742344e-03*S220+(-8.513831e-02)*S221+(-1.051509e-01)*S222+1.186027e-01*S223+(-6.986286e-01)*S224+(-3.568897e-01)*S225+2.186893e-01*S226+2.198573e-01*S227+1.921238e-01*S228+(-1.214171e-01)*S229'
.param V25_part24='V25_part23+3.559689e-01*S230+2.863034e-01*S231+(-3.423314e-01)*S232+1.122696e+00*S233+3.181641e-01*S234+(-4.876140e-02)*S235+1.229558e-01*S236+2.875889e-02*S237+2.433163e-01*S238+(-8.175080e-01)*S239'
.param V25_part25='V25_part24+1.878971e+00*S240+5.454452e-01*S241+9.922818e-01*S242+9.073240e-01*S243+(-6.741932e-02)*S244+9.070859e-01*S245+7.475556e-01*S246+1.370091e+00*S247+7.731791e-01*S248+(-2.384760e-01)*S249'
.param V25_part26='V25_part25+(-1.067311e-01)*S250+(-1.273432e-02)*S251+(-2.328485e-02)*S252+(-7.931062e-01)*S253+(-6.979199e-01)*S254+(-2.686963e-02)*S255+(-4.356017e-01)*S256+(-1.097158e-01)*S257+(-3.454809e-01)*S258+6.572160e-01*S259'
.param V25_part27='V25_part26+5.947973e-01*S260+1.389934e-01*S261+4.649474e-02*S262+1.018867e-01*S263+1.735512e-01*S264+(-3.613044e-02)*S265+(-8.267785e-02)*S266+(-2.384981e-01)*S267+(-8.153806e-02)*S268+(-2.378565e-01)*S269'
.param V25_part28='V25_part27+(-2.276029e-01)*S270+4.417882e-02*S271+5.181797e-01*S272+(-1.016502e-02)*S273+4.323600e-01*S274+4.664654e-01*S275+(-7.263671e-01)*S276+3.019833e-01*S277+(-2.087356e-01)*S278+(-1.173326e+00)*S279'
.param V25_part29='V25_part28+(-5.143844e-02)*S280+(-5.648881e-01)*S281+7.416734e+00*S282+(-8.992530e-01)*S283+(-5.135597e-01)*S284+(-2.074789e-02)*S285+1.366640e-01*S286+6.932333e-01*S287+(-3.504248e-01)*S288+1.207250e-01*S289'
.param V25_part30='V25_part29+5.659823e-01*S290+(-7.135649e-01)*S291+(-3.411225e-01)*S292+2.348436e-01*S293+(-1.120703e+00)*S294+(-9.175979e-02)*S295+1.411622e-02*S296+(-6.704555e-02)*S297+(-1.264549e-01)*S298+2.806287e-01*S299'
.param V25_part31='V25_part30+(-2.810969e-01)*S300+1.999010e+00*S301+9.497429e-01*S302+(-1.940440e-01)*S303+1.063927e+00*S304+8.410823e-01*S305+(-4.181527e-01)*S306+9.085697e-02*S307+1.585534e-01*S308+(-3.223565e-02)*S309'
.param V25='V25_part31+1.553298e-01*S310+(-4.557012e-01)*S311+2.022761e-01*S312+(-1.360078e-01)*S313+(-7.363634e-01)*S314'
.param V26_part1='5.464042e-01*S0+6.257599e-01*S1+3.988333e-01*S2+9.157425e-01*S3+4.838389e-01*S4+3.380032e-01*S5+3.840861e-01*S6+4.646029e-01*S7+3.233056e-01*S8+3.394945e-01*S9'
.param V26_part2='V26_part1+4.554697e-01*S10+2.852577e-01*S11+3.823305e-01*S12+3.573899e-01*S13+2.746768e-01*S14+6.474877e-01*S15+2.251681e-01*S16+6.429139e-01*S17+6.408403e-01*S18+6.643126e-01*S19'
.param V26_part3='V26_part2+5.153103e-01*S20+5.267335e-01*S21+5.715021e-01*S22+5.820662e-01*S23+5.197050e-01*S24+4.345562e-01*S25+5.671699e-01*S26+4.465611e-01*S27+4.918319e-01*S28+5.000829e-01*S29'
.param V26_part4='V26_part3+1.205247e+00*S30+1.243466e+00*S31+3.801702e+00*S32+8.731246e-01*S33+1.131213e+00*S34+7.991350e-01*S35+6.800046e-01*S36+6.497850e-01*S37+5.990096e-01*S38+5.421277e-01*S39'
.param V26_part5='V26_part4+5.389428e-01*S40+3.197991e-01*S41+4.526309e-01*S42+4.107658e-01*S43+3.008331e-01*S44+1.198848e+00*S45+1.180230e+00*S46+9.070812e-01*S47+9.214977e-01*S48+8.871199e-01*S49'
.param V26_part6='V26_part5+6.095850e-01*S50+6.412126e-01*S51+6.117207e-01*S52+4.926922e-01*S53+(-1.290658e-02)*S54+4.657742e-01*S55+3.892761e-01*S56+4.234342e-01*S57+4.280916e-01*S58+(-2.211288e-01)*S59'
.param V26_part7='V26_part6+1.433190e+00*S60+1.375197e+00*S61+1.054865e+00*S62+1.026376e+00*S63+9.396846e-01*S64+6.084333e-01*S65+6.962873e-01*S66+8.491577e-01*S67+4.811500e-01*S68+6.105847e-01*S69'
.param V26_part8='V26_part7+5.334093e-01*S70+4.116142e-01*S71+4.192972e-01*S72+3.797981e-01*S73+(-5.643863e-01)*S74+1.912416e+00*S75+1.839291e+00*S76+1.450382e+00*S77+1.256098e+00*S78+1.254178e+00*S79'
.param V26_part9='V26_part8+1.055042e+00*S80+8.533037e-01*S81+8.351299e-01*S82+7.633375e-01*S83+6.213995e-01*S84+6.546645e-01*S85+5.828862e-01*S86+5.073024e-01*S87+5.116229e-01*S88+5.244837e-01*S89'
.param V26_part10='V26_part9+1.603830e+00*S90+1.496974e+00*S91+1.011702e+00*S92+9.920450e-01*S93+9.094294e-01*S94+1.620596e-01*S95+7.102705e-01*S96+7.925541e-01*S97+6.897665e-01*S98+5.333243e-01*S99'
.param V26_part11='V26_part10+6.708149e-01*S100+6.305663e-01*S101+4.668518e-01*S102+4.960031e-01*S103+5.135317e-01*S104+1.575085e+00*S105+1.377318e+00*S106+8.928293e-01*S107+9.442644e-01*S108+9.357896e-01*S109'
.param V26_part12='V26_part11+7.721346e-01*S110+6.499603e-01*S111+8.050171e-01*S112+5.860577e-01*S113+5.159790e-01*S114+6.458041e-01*S115+4.355445e-01*S116+5.095106e-01*S117+4.430810e-01*S118+4.823740e-01*S119'
.param V26_part13='V26_part12+1.518615e+00*S120+1.251131e+00*S121+7.943312e-01*S122+8.518230e-01*S123+8.170907e-01*S124+6.208207e-01*S125+6.761226e-01*S126+7.517058e-01*S127+4.356897e-01*S128+5.534729e-01*S129'
.param V26_part14='V26_part13+6.874483e-01*S130+4.556241e-01*S131+5.031236e-01*S132+3.913795e-01*S133+5.119557e-01*S134+2.095112e+00*S135+1.945069e+00*S136+1.269692e+00*S137+1.187888e+00*S138+1.175786e+00*S139'
.param V26_part15='V26_part14+8.213912e-01*S140+7.275053e-01*S141+6.217473e-01*S142+5.637891e-01*S143+5.332109e-01*S144+6.038169e-01*S145+4.966418e-01*S146+4.894691e-01*S147+4.964977e-01*S148+5.247574e-01*S149'
.param V26_part16='V26_part15+(-1.016340e-01)*S150+7.208637e-01*S151+(-2.111928e-01)*S152+9.508540e-01*S153+(-1.225958e-01)*S154+6.280700e-01*S155+7.723856e-01*S156+6.833496e-01*S157+5.892722e-01*S158+5.672703e-01*S159'
.param V26_part17='V26_part16+5.579464e-01*S160+5.908380e-01*S161+6.176510e-01*S162+3.984291e-01*S163+5.819945e-01*S164+7.128723e-01*S165+1.269849e+00*S166+1.088203e+00*S167+9.522822e-01*S168+5.254344e-01*S169'
.param V26_part18='V26_part17+7.789345e-01*S170+7.332622e-01*S171+7.058333e-01*S172+8.023389e-01*S173+4.450994e-01*S174+6.085487e-01*S175+6.207437e-01*S176+5.316219e-01*S177+5.991367e-01*S178+5.270006e-01*S179'
.param V26_part19='V26_part18+(-7.117193e-01)*S180+1.138219e+00*S181+6.772617e-02*S182+9.571572e-01*S183+(-6.417758e-01)*S184+(-2.649618e-03)*S185+6.911918e-01*S186+6.467443e-01*S187+3.132028e-01*S188+5.986800e-01*S189'
.param V26_part20='V26_part19+1.000591e+00*S190+3.467370e-01*S191+4.920513e-01*S192+1.431416e+00*S193+5.590378e-01*S194+1.634435e+00*S195+1.030758e+00*S196+1.060344e+00*S197+1.018161e+00*S198+4.792220e-01*S199'
.param V26_part21='V26_part20+5.360536e-01*S200+7.732666e-01*S201+8.046585e-01*S202+1.222139e-01*S203+6.019894e-01*S204+5.652893e-01*S205+4.994432e-01*S206+6.542642e-01*S207+4.415376e-01*S208+4.362113e-01*S209'
.param V26_part22='V26_part21+(-1.347204e+00)*S210+(-2.051842e-01)*S211+1.077544e-01*S212+9.726954e-01*S213+(-6.830114e-01)*S214+2.186844e-01*S215+6.718850e-01*S216+5.088879e-01*S217+4.304283e-01*S218+6.887189e-01*S219'
.param V26_part23='V26_part22+6.214466e-01*S220+4.273702e-01*S221+4.176742e-01*S222+5.658125e-01*S223+7.534673e-01*S224+8.765086e-01*S225+(-3.793456e-01)*S226+(-1.176583e-01)*S227+6.178152e-01*S228+(-3.262275e-01)*S229'
.param V26_part24='V26_part23+(-1.713701e-01)*S230+5.243041e-01*S231+(-2.448334e-01)*S232+(-1.907104e-01)*S233+3.680062e-01*S234+(-1.773184e-01)*S235+(-1.457540e-01)*S236+2.519482e-01*S237+6.382483e-01*S238+1.408183e+00*S239'
.param V26_part25='V26_part24+(-1.069801e+00)*S240+6.620603e-01*S241+(-7.300601e-02)*S242+8.591029e-01*S243+9.293039e-01*S244+2.222725e-01*S245+6.134127e-01*S246+1.647214e-01*S247+4.516864e-01*S248+8.303718e-01*S249'
.param V26_part26='V26_part25+4.495267e-01*S250+8.369635e-01*S251+3.966590e-01*S252+2.206959e+00*S253+8.195055e-01*S254+7.800229e-01*S255+1.061111e+00*S256+2.833953e-01*S257+6.550152e-01*S258+4.691075e-01*S259'
.param V26_part27='V26_part26+3.575360e-01*S260+8.079428e-01*S261+7.904286e-01*S262+6.244839e-01*S263+6.626430e-01*S264+6.437361e-01*S265+5.449331e-01*S266+5.161749e-01*S267+5.346359e-01*S268+4.943760e-01*S269'
.param V26_part28='V26_part27+2.095927e+00*S270+1.220734e+00*S271+1.024666e+00*S272+1.980301e+00*S273+1.506780e+00*S274+9.232938e-01*S275+3.061478e+00*S276+2.158907e+00*S277+1.219206e+00*S278+3.230909e+00*S279'
.param V26_part29='V26_part28+1.874352e+00*S280+1.062195e+00*S281+(-7.131458e-01)*S282+2.148727e+00*S283+9.552409e-01*S284+2.624670e+00*S285+1.136540e+00*S286+5.038269e-01*S287+2.729537e+00*S288+1.091566e+00*S289'
.param V26_part30='V26_part29+8.621701e-01*S290+2.982195e+00*S291+1.091088e+00*S292+8.974962e-01*S293+3.078300e+00*S294+5.427027e-01*S295+9.087349e-01*S296+2.017580e+00*S297+4.757407e-01*S298+6.783065e-01*S299'
.param V26_part31='V26_part30+1.715430e+00*S300+(-3.283077e-01)*S301+6.573383e-02*S302+1.913101e+00*S303+7.978310e-01*S304+6.859758e-01*S305+2.443515e+00*S306+8.535198e-01*S307+9.137993e-01*S308+6.167712e-01*S309'
.param V26='V26_part31+1.302062e+00*S310+9.923129e-01*S311+7.655692e-01*S312+4.567648e-01*S313+1.285671e+00*S314'
.param V27_part1='5.203623e-01*S0+1.497284e-01*S1+1.255952e-01*S2+8.416355e-01*S3+1.305011e-01*S4+1.264358e-01*S5+1.925015e-01*S6+7.954734e-02*S7+8.510897e-02*S8+6.732248e-02*S9'
.param V27_part2='V27_part1+7.980803e-02*S10+5.355644e-02*S11+4.631727e-02*S12+5.280304e-03*S13+3.164754e-02*S14+1.449165e-01*S15+(-1.322116e-02)*S16+9.134837e-02*S17+1.132392e-01*S18+3.620602e-02*S19'
.param V27_part3='V27_part2+5.530508e-02*S20+1.224534e-02*S21+(-2.612009e-02)*S22+9.780205e-03*S23+(-4.523607e-02)*S24+(-6.887727e-02)*S25+4.865844e-03*S26+(-1.139231e-01)*S27+(-8.761408e-02)*S28+(-3.400140e-02)*S29'
.param V27_part4='V27_part3+(-2.135097e-02)*S30+8.954607e-02*S31+2.590674e-01*S32+(-7.382830e-02)*S33+(-1.549537e-02)*S34+(-3.085166e-02)*S35+(-1.688154e-01)*S36+(-7.814650e-02)*S37+(-1.749772e-01)*S38+(-2.330667e-01)*S39'
.param V27_part5='V27_part4+(-7.466583e-02)*S40+(-2.409535e-01)*S41+(-2.466238e-01)*S42+(-1.250052e-01)*S43+(-3.346987e-01)*S44+3.167837e-02*S45+9.737541e-02*S46+(-7.051085e-02)*S47+(-1.264587e-01)*S48+(-3.168790e-02)*S49'
.param V27_part6='V27_part5+(-2.179116e-01)*S50+(-1.688100e-01)*S51+(-9.591420e-02)*S52+(-3.975948e-01)*S53+2.213248e-02*S54+(-1.384064e-01)*S55+(-4.737721e-01)*S56+(-4.187375e-01)*S57+(-4.605658e-01)*S58+(-2.434995e-01)*S59'
.param V27_part7='V27_part6+1.498784e-03*S60+9.337902e-02*S61+(-2.969127e-02)*S62+(-1.410365e-01)*S63+(-1.452735e-02)*S64+(-1.398047e-01)*S65+(-1.933849e-01)*S66+(-8.504084e-02)*S67+(-2.201098e-01)*S68+(-2.601210e-01)*S69'
.param V27_part8='V27_part7+(-1.527052e-01)*S70+(-3.005315e-01)*S71+(-2.874293e-01)*S72+(-3.428116e-01)*S73+(-2.599246e-01)*S74+2.754672e-01*S75+1.796663e-01*S76+8.848845e-02*S77+2.564449e-02*S78+1.202134e-02*S79'
.param V27_part9='V27_part8+4.285828e-02*S80+(-4.181278e-02)*S81+(-5.688369e-02)*S82+(-7.200135e-03)*S83+(-1.297171e-01)*S84+(-1.047646e-01)*S85+(-3.854840e-02)*S86+(-1.658298e-01)*S87+(-8.293643e-02)*S88+(-4.416389e-02)*S89'
.param V27_part10='V27_part9+(-2.223662e-01)*S90+(-8.595574e-02)*S91+(-2.031791e-01)*S92+(-3.720469e-01)*S93+(-2.499941e-01)*S94+(-9.338215e-02)*S95+(-4.454471e-01)*S96+(-9.969687e-01)*S97+(-1.762526e-01)*S98+(-5.462134e-01)*S99'
.param V27_part11='V27_part10+(-7.576447e-01)*S100+(-2.426656e-01)*S101+(-4.998778e-01)*S102+(-5.576306e-01)*S103+(-3.728018e-01)*S104+(-1.686894e-01)*S105+(-2.076481e-01)*S106+(-1.381022e-01)*S107+(-3.943975e-01)*S108+(-2.713589e-01)*S109'
.param V27_part12='V27_part11+(-1.846745e-01)*S110+(-4.470033e-01)*S111+(-6.300942e-01)*S112+(-2.460117e-01)*S113+(-3.828045e-01)*S114+(-8.178309e-01)*S115+(-1.948598e-01)*S116+(-1.739301e-01)*S117+(-7.324226e-01)*S118+(-1.102249e-01)*S119'
.param V27_part13='V27_part12+(-1.975084e-01)*S120+(-3.571098e-01)*S121+(-1.264476e-01)*S122+(-6.008863e-01)*S123+(-3.388820e-01)*S124+(-1.579756e-01)*S125+(-5.032368e-01)*S126+(-5.463840e-01)*S127+(-2.143519e-01)*S128+(-3.392527e-01)*S129'
.param V27_part14='V27_part13+(-7.153546e-01)*S130+(-1.380581e-01)*S131+(-4.389549e-01)*S132+(-2.706914e-01)*S133+(-1.040772e-01)*S134+9.021895e-02*S135+1.149323e-01*S136+(-2.384756e-01)*S137+(-2.219625e-01)*S138+(-4.692777e-02)*S139'
.param V27_part15='V27_part14+(-1.529378e-01)*S140+(-3.496001e-01)*S141+(-3.653334e-01)*S142+(-1.718076e-01)*S143+(-4.336636e-01)*S144+(-5.639294e-01)*S145+(-1.752137e-01)*S146+(-6.191966e-01)*S147+(-5.199479e-01)*S148+(-2.447882e-01)*S149'
.param V27_part16='V27_part15+3.423085e-01*S150+4.674796e-01*S151+(-3.107287e-01)*S152+(-4.599085e-01)*S153+4.961052e-01*S154+(-9.683439e-02)*S155+(-4.586631e-01)*S156+(-1.677038e-01)*S157+(-9.974234e-02)*S158+(-3.382683e-01)*S159'
.param V27_part17='V27_part16+(-2.186341e-01)*S160+(-1.430630e-01)*S161+(-3.165813e-01)*S162+(-1.682837e-01)*S163+(-1.294374e-01)*S164+(-7.790034e-01)*S165+(-7.151283e-02)*S166+(-1.191793e+00)*S167+(-2.299758e-01)*S168+(-8.843879e-01)*S169'
.param V27_part18='V27_part17+(-4.310389e-03)*S170+(-3.101526e-01)*S171+(-1.753089e-01)*S172+(-1.098491e-01)*S173+(-3.504357e-01)*S174+(-1.139963e-01)*S175+(-3.295560e-02)*S176+(-6.795703e-01)*S177+(-1.291029e-01)*S178+(-3.737456e-03)*S179'
.param V27_part19='V27_part18+3.834653e-01*S180+(-8.392081e-02)*S181+(-1.134937e-01)*S182+(-1.839994e-01)*S183+(-4.935813e-01)*S184+7.727288e-02*S185+(-4.195480e-01)*S186+(-6.564461e-02)*S187+(-1.285679e-01)*S188+(-3.827042e-01)*S189'
.param V27_part20='V27_part19+1.806585e-03*S190+(-1.898960e-01)*S191+(-3.600184e-01)*S192+2.299013e-01*S193+1.046968e-03*S194+(-1.970512e-01)*S195+(-7.035909e-01)*S196+(-7.233417e-01)*S197+(-4.773807e-01)*S198+(-1.148279e+00)*S199'
.param V27_part21='V27_part20+(-9.403650e-01)*S200+(-4.828474e-01)*S201+(-4.492796e-01)*S202+(-5.221230e-01)*S203+(-4.198610e-01)*S204+(-2.803401e-01)*S205+(-1.964755e-01)*S206+(-1.622582e-01)*S207+(-4.945363e-01)*S208+(-1.657231e-01)*S209'
.param V27_part22='V27_part21+4.695093e-01*S210+7.966475e-02*S211+1.499705e-02*S212+(-1.958566e-01)*S213+(-1.365110e-01)*S214+2.904721e-02*S215+(-2.571382e-01)*S216+(-2.773020e-01)*S217+(-1.625277e-01)*S218+(-4.078443e-01)*S219'
.param V27_part23='V27_part22+(-9.707382e-02)*S220+(-2.183701e-01)*S221+(-2.838746e-01)*S222+(-1.642707e-01)*S223+1.760320e-01*S224+(-6.442605e-01)*S225+4.731507e-01*S226+4.403786e-01*S227+(-3.631768e-01)*S228+4.247561e-01*S229'
.param V27_part24='V27_part23+3.563025e-01*S230+(-7.394719e-01)*S231+4.929368e-01*S232+2.529457e-01*S233+(-7.084329e-01)*S234+3.058725e-01*S235+1.947021e-01*S236+(-3.320735e-01)*S237+(-8.844933e-02)*S238+4.159514e-01*S239'
.param V27_part25='V27_part24+3.993052e-01*S240+(-8.699631e-02)*S241+(-5.473277e-02)*S242+(-1.197173e-01)*S243+(-1.997250e-02)*S244+1.545702e-02*S245+1.318409e-01*S246+(-5.050636e-02)*S247+7.393217e-02*S248+5.695354e-01*S249'
.param V27_part26='V27_part25+(-5.029914e-01)*S250+2.311606e-01*S251+1.074966e-01*S252+2.525734e-01*S253+3.142522e-01*S254+(-7.249386e-01)*S255+(-6.916490e-01)*S256+(-1.293065e-01)*S257+(-9.416002e-01)*S258+(-8.412710e-02)*S259'
.param V27_part27='V27_part26+8.808812e-03*S260+(-3.594585e-01)*S261+(-1.255555e-01)*S262+(-2.263947e-02)*S263+(-4.108623e-01)*S264+(-1.343869e-01)*S265+(-4.036740e-02)*S266+(-3.894562e-01)*S267+(-1.493149e-01)*S268+(-2.337753e-02)*S269'
.param V27_part28='V27_part27+8.864825e-01*S270+6.104171e-02*S271+5.647133e-01*S272+3.139244e-01*S273+5.876382e-01*S274+5.414071e-01*S275+1.230172e+00*S276+5.205848e-01*S277+4.653555e-01*S278+1.399301e+00*S279'
.param V27_part29='V27_part28+4.388492e-01*S280+3.430174e-01*S281+3.154134e+01*S282+6.111777e-01*S283+3.606483e-01*S284+1.451382e+00*S285+6.954675e-02*S286+3.393713e-01*S287+2.023812e+00*S288+3.968505e-02*S289'
.param V27_part30='V27_part29+6.779491e-01*S290+1.508701e+00*S291+2.561893e-01*S292+5.768401e-01*S293+1.418971e+00*S294+(-1.372259e-01)*S295+6.076530e-01*S296+1.081258e+00*S297+(-2.263434e-01)*S298+6.836595e-01*S299'
.param V27_part31='V27_part30+1.225829e+00*S300+(-3.106006e-01)*S301+6.250398e-02*S302+8.460849e-01*S303+1.537211e-01*S304+3.929315e-01*S305+1.021497e+00*S306+(-5.553871e-02)*S307+4.275180e-01*S308+(-4.278197e-01)*S309'
.param V27='V27_part31+7.486631e-02*S310+2.791522e-01*S311+(-2.407689e-01)*S312+(-2.490790e-01)*S313+4.425516e-01*S314'
.param V28_part1='(-1.695983e-02)*S0+(-3.284057e-02)*S1+(-3.772426e-02)*S2+(-1.176655e-01)*S3+(-8.436988e-02)*S4+(-6.402257e-02)*S5+(-9.144456e-02)*S6+(-1.368051e-01)*S7+(-8.231047e-02)*S8+(-9.885216e-02)*S9'
.param V28_part2='V28_part1+(-1.833283e-01)*S10+(-1.246708e-01)*S11+(-1.509760e-01)*S12+(-1.862389e-01)*S13+(-1.302239e-01)*S14+(-8.956066e-02)*S15+(-2.481163e-01)*S16+(-9.933616e-02)*S17+(-1.251720e-01)*S18+(-1.609103e-01)*S19'
.param V28_part3='V28_part2+(-1.074966e-01)*S20+(-1.619953e-01)*S21+(-1.989487e-01)*S22+(-1.951611e-01)*S23+(-2.092107e-01)*S24+(-1.443662e-01)*S25+(-2.983895e-01)*S26+(-2.195177e-01)*S27+(-2.746776e-01)*S28+(-2.798974e-01)*S29'
.param V28_part4='V28_part3+(-1.448142e-01)*S30+(-1.743511e-01)*S31+(-1.228998e-01)*S32+(-1.809071e-01)*S33+(-2.417001e-01)*S34+(-1.581296e-01)*S35+(-1.801302e-01)*S36+(-1.706471e-01)*S37+(-2.517814e-01)*S38+(-1.872948e-01)*S39'
.param V28_part5='V28_part4+(-1.614007e-01)*S40+(-2.161678e-01)*S41+(-1.853603e-01)*S42+(-1.751786e-01)*S43+(-2.431623e-01)*S44+(-1.425361e-01)*S45+(-1.420073e-01)*S46+(-1.857534e-01)*S47+(-2.140726e-01)*S48+(-1.960841e-01)*S49'
.param V28_part6='V28_part5+(-2.267216e-01)*S50+(-2.099692e-01)*S51+(-1.837352e-01)*S52+(-2.821737e-01)*S53+(-1.039505e-01)*S54+(-2.158651e-01)*S55+(-2.800082e-01)*S56+(-2.262880e-01)*S57+(-2.728001e-01)*S58+(-1.634411e-01)*S59'
.param V28_part7='V28_part6+(-1.907410e-01)*S60+(-1.863141e-01)*S61+(-2.100258e-01)*S62+(-2.347100e-01)*S63+(-2.029068e-01)*S64+(-2.056126e-01)*S65+(-2.276378e-01)*S66+(-3.296266e-01)*S67+(-2.393229e-01)*S68+(-2.564392e-01)*S69'
.param V28_part8='V28_part7+(-2.919513e-01)*S70+(-2.329519e-01)*S71+(-2.288596e-01)*S72+(-2.329261e-01)*S73+(-1.955277e-01)*S74+(-3.851564e-01)*S75+(-4.155458e-01)*S76+(-3.516602e-01)*S77+(-3.571843e-01)*S78+(-3.625370e-01)*S79'
.param V28_part9='V28_part8+(-3.173684e-01)*S80+(-3.216745e-01)*S81+(-3.177600e-01)*S82+(-2.682084e-01)*S83+(-2.808232e-01)*S84+(-2.747809e-01)*S85+(-2.542141e-01)*S86+(-2.460836e-01)*S87+(-2.502692e-01)*S88+(-2.588112e-01)*S89'
.param V28_part10='V28_part9+(-1.926832e-01)*S90+(-2.012179e-01)*S91+(-1.618879e-01)*S92+(-2.298760e-01)*S93+(-2.150100e-01)*S94+(-1.700093e-02)*S95+(-2.279363e-01)*S96+(-2.275964e-01)*S97+(-1.388649e-01)*S98+(-2.338497e-01)*S99'
.param V28_part11='V28_part10+(-2.466033e-01)*S100+(-1.535914e-01)*S101+(-2.262448e-01)*S102+(-2.492687e-01)*S103+(-2.240348e-01)*S104+(-1.981992e-01)*S105+(-1.865507e-01)*S106+(-1.227839e-01)*S107+(-2.324558e-01)*S108+(-2.145658e-01)*S109'
.param V28_part12='V28_part11+(-1.329804e-01)*S110+(-2.170424e-01)*S111+(-2.341099e-01)*S112+(-1.303307e-01)*S113+(-2.092129e-01)*S114+(-2.042679e-01)*S115+(-1.179503e-01)*S116+(-2.543111e-01)*S117+(-1.935318e-01)*S118+(-1.491986e-01)*S119'
.param V28_part13='V28_part12+(-2.133648e-01)*S120+(-1.929450e-01)*S121+(-1.291313e-01)*S122+(-1.974722e-01)*S123+(-1.865245e-01)*S124+(-1.423728e-01)*S125+(-2.014959e-01)*S126+(-2.063656e-01)*S127+(-1.321161e-01)*S128+(-2.355235e-01)*S129'
.param V28_part14='V28_part13+(-1.930615e-01)*S130+(-1.520515e-01)*S131+(-2.040927e-01)*S132+(-1.776538e-01)*S133+(-2.261894e-01)*S134+(-3.022665e-01)*S135+(-2.634133e-01)*S136+(-3.022246e-01)*S137+(-2.824108e-01)*S138+(-2.773779e-01)*S139'
.param V28_part15='V28_part14+(-2.731117e-01)*S140+(-2.624029e-01)*S141+(-2.500621e-01)*S142+(-2.243946e-01)*S143+(-2.428519e-01)*S144+(-2.713703e-01)*S145+(-1.935313e-01)*S146+(-2.603686e-01)*S147+(-2.645481e-01)*S148+(-2.034714e-01)*S149'
.param V28_part16='V28_part15+(-5.539458e-02)*S150+(-3.035938e-02)*S151+(-5.462082e-02)*S152+(-2.185887e-01)*S153+(-4.294195e-02)*S154+(-1.109148e-01)*S155+(-2.102976e-01)*S156+(-1.795520e-01)*S157+(-1.195207e-01)*S158+(-1.937325e-01)*S159'
.param V28_part17='V28_part16+(-1.784174e-01)*S160+(-1.217130e-01)*S161+(-3.020887e-01)*S162+(-1.168022e-01)*S163+(-1.118603e-01)*S164+(-9.205608e-03)*S165+(-1.488935e-01)*S166+4.940880e-02*S167+(-1.945403e-01)*S168+(-6.115626e-03)*S169'
.param V28_part18='V28_part17+(-9.971836e-02)*S170+(-1.710527e-01)*S171+(-1.533521e-01)*S172+(-1.119181e-01)*S173+(-1.334387e-01)*S174+(-2.047431e-01)*S175+(-9.677437e-02)*S176+(-1.352507e-01)*S177+(-1.717946e-01)*S178+(-1.011319e-01)*S179'
.param V28_part19='V28_part18+(-6.278106e-02)*S180+(-1.172111e-01)*S181+2.219741e-02*S182+(-2.137016e-01)*S183+(-2.492053e-01)*S184+(-3.038378e-02)*S185+(-1.950474e-01)*S186+(-1.114288e-01)*S187+(-8.811315e-02)*S188+(-1.866640e-01)*S189'
.param V28_part20='V28_part19+(-1.249856e-01)*S190+(-9.789383e-02)*S191+(-1.541723e-01)*S192+(-1.043917e-01)*S193+(-1.129424e-01)*S194+(-2.063737e-01)*S195+3.087753e-02*S196+3.468214e-02*S197+(-2.106412e-01)*S198+2.499866e-02*S199'
.param V28_part21='V28_part20+4.220986e-02*S200+(-2.055592e-01)*S201+(-1.916050e-01)*S202+2.010552e-02*S203+(-1.815373e-01)*S204+(-1.679707e-01)*S205+(-1.306831e-01)*S206+(-2.450109e-01)*S207+(-1.812450e-01)*S208+(-9.727401e-02)*S209'
.param V28_part22='V28_part21+(-1.723027e-01)*S210+(-2.657589e-02)*S211+(-1.635850e-02)*S212+(-1.623077e-01)*S213+(-1.825581e-01)*S214+(-1.496014e-02)*S215+(-1.703708e-01)*S216+(-1.125566e-01)*S217+(-8.470791e-02)*S218+(-2.233735e-01)*S219'
.param V28_part23='V28_part22+(-1.384504e-01)*S220+(-8.596749e-02)*S221+(-1.301053e-01)*S222+(-1.623002e-01)*S223+6.631879e-02*S224+1.192753e-02*S225+(-2.804194e-02)*S226+(-2.712815e-02)*S227+(-1.315051e-01)*S228+(-3.644491e-02)*S229'
.param V28_part24='V28_part23+(-2.938716e-02)*S230+(-7.923134e-02)*S231+(-5.425321e-02)*S232+(-6.842020e-02)*S233+(-8.264359e-02)*S234+(-3.862244e-02)*S235+(-2.327688e-02)*S236+(-9.438684e-02)*S237+(-2.037165e-01)*S238+2.023863e-02*S239'
.param V28_part25='V28_part24+(-1.374303e-01)*S240+1.854041e-03*S241+3.210672e-02*S242+(-1.736645e-01)*S243+(-1.628246e-01)*S244+1.383317e-02*S245+6.314055e-03*S246+1.350725e-02*S247+(-2.684227e-02)*S248+1.119516e-01*S249'
.param V28_part26='V28_part25+(-9.168681e-02)*S250+(-2.154040e-02)*S251+4.265723e-02*S252+(-3.000681e-02)*S253+3.151366e-02*S254+(-6.235520e-03)*S255+5.550539e-03*S256+2.065109e-02*S257+(-2.087873e-03)*S258+(-3.342619e-02)*S259'
.param V28_part27='V28_part26+(-7.819276e-02)*S260+(-2.337097e-01)*S261+(-1.479431e-01)*S262+(-1.062311e-01)*S263+(-2.377999e-01)*S264+(-1.764469e-01)*S265+(-1.111622e-01)*S266+(-1.540041e-01)*S267+(-1.603704e-01)*S268+(-1.118012e-01)*S269'
.param V28_part28='V28_part27+(-1.071165e-02)*S270+(-1.317966e-01)*S271+(-3.755252e-02)*S272+(-1.683540e-01)*S273+(-6.222381e-02)*S274+(-1.890342e-02)*S275+(-5.089058e-02)*S276+(-9.051502e-02)*S277+1.296688e-03*S278+(-2.963267e-02)*S279'
.param V28_part29='V28_part28+(-1.703168e-01)*S280+(-1.000436e-02)*S281+3.677786e+01*S282+(-6.768123e-04)*S283+2.346448e-03*S284+(-1.493033e-02)*S285+(-1.548775e-01)*S286+1.886875e-02*S287+(-4.130765e-02)*S288+(-1.869579e-01)*S289'
.param V28_part30='V28_part29+(-1.083552e-01)*S290+(-1.418244e-02)*S291+2.151560e-03*S292+(-1.075498e-01)*S293+(-3.634561e-02)*S294+(-1.019699e-01)*S295+(-1.124355e-01)*S296+(-1.862337e-01)*S297+(-9.839137e-02)*S298+(-8.311538e-02)*S299'
.param V28_part31='V28_part30+(-2.884133e-02)*S300+(-1.385972e-01)*S301+1.114809e-02*S302+(-2.073866e-02)*S303+(-8.060426e-02)*S304+(-6.270464e-02)*S305+(-3.035625e-02)*S306+(-1.671138e-01)*S307+(-1.280531e-02)*S308+(-1.457226e-01)*S309'
.param V28='V28_part31+(-1.806196e-01)*S310+(-1.389656e-02)*S311+(-2.766355e-01)*S312+(-1.097673e-01)*S313+1.062747e-02*S314'
.param V29_part1='(-7.883829e-04)*S0+(-1.414002e-03)*S1+(-1.765055e-03)*S2+(-2.258613e-03)*S3+(-4.692291e-04)*S4+(-7.518645e-04)*S5+1.859231e-04*S6+(-9.863878e-04)*S7+5.026373e-04*S8+(-8.686851e-05)*S9'
.param V29_part2='V29_part1+(-2.084608e-03)*S10+(-1.291020e-04)*S11+2.374316e-03*S12+(-2.156566e-04)*S13+(-3.352764e-04)*S14+1.759408e-03*S15+1.452562e-03*S16+2.574702e-03*S17+1.947621e-03*S18+1.797014e-03*S19'
.param V29_part3='V29_part2+1.839910e-03*S20+1.835016e-03*S21+2.014885e-03*S22+8.806383e-04*S23+1.624253e-03*S24+1.598739e-03*S25+2.487336e-03*S26+1.933321e-03*S27+1.379003e-03*S28+1.035399e-03*S29'
.param V29_part4='V29_part3+9.445474e-03*S30+1.061222e-02*S31+(-1.242842e-02)*S32+5.476969e-03*S33+2.071108e-03*S34+5.139804e-03*S35+6.230652e-04*S36+9.604987e-03*S37+7.194404e-03*S38+5.596514e-03*S39'
.param V29_part5='V29_part4+6.657561e-03*S40+6.111774e-03*S41+5.816449e-03*S42+6.803596e-03*S43+5.020292e-03*S44+1.613966e-02*S45+2.101920e-02*S46+2.066191e-02*S47+1.578434e-02*S48+1.281802e-02*S49'
.param V29_part6='V29_part5+1.999242e-02*S50+9.733682e-03*S51+1.457847e-02*S52+1.872859e-02*S53+1.488214e-03*S54+1.088060e-02*S55+1.225415e-02*S56+1.230506e-02*S57+1.179738e-02*S58+(-2.999076e-03)*S59'
.param V29_part7='V29_part6+3.730584e-02*S60+3.506682e-02*S61+4.111994e-02*S62+2.615875e-02*S63+2.400252e-02*S64+2.910766e-02*S65+1.328950e-02*S66+2.004630e-02*S67+2.535666e-02*S68+1.671203e-02*S69'
.param V29_part8='V29_part7+1.544711e-02*S70+2.299954e-02*S71+1.258703e-02*S72+6.829361e-03*S73+(-2.724282e-02)*S74+1.081995e-01*S75+1.189348e-01*S76+8.295120e-02*S77+6.478130e-02*S78+6.176922e-02*S79'
.param V29_part9='V29_part8+6.019263e-02*S80+4.005666e-02*S81+3.689935e-02*S82+3.744175e-02*S83+2.604439e-02*S84+2.825895e-02*S85+3.116441e-02*S86+1.988733e-02*S87+2.182488e-02*S88+2.417850e-02*S89'
.param V29_part10='V29_part9+5.787399e-02*S90+4.693218e-02*S91+3.173308e-02*S92+2.876627e-02*S93+1.888954e-02*S94+(-1.064144e-02)*S95+1.700701e-02*S96+1.352614e-02*S97+2.036304e-02*S98+2.057857e-02*S99'
.param V29_part11='V29_part10+4.352426e-03*S100+1.525253e-02*S101+1.121449e-02*S102+1.513275e-03*S103+(-1.093720e-02)*S104+6.451025e-02*S105+5.893874e-02*S106+3.300633e-02*S107+3.197432e-02*S108+3.508636e-02*S109'
.param V29_part12='V29_part11+2.519557e-02*S110+2.065406e-02*S111+1.318021e-02*S112+1.095811e-02*S113+8.688632e-03*S114+(-8.901819e-03)*S115+8.133432e-03*S116+1.323519e-02*S117+(-7.596751e-03)*S118+2.407633e-02*S119'
.param V29_part13='V29_part12+4.916628e-02*S120+5.840507e-02*S121+3.225356e-02*S122+3.106468e-02*S123+3.184528e-02*S124+2.027823e-02*S125+2.037003e-02*S126+9.358534e-03*S127+8.357021e-03*S128+2.472981e-03*S129'
.param V29_part14='V29_part13+4.836816e-03*S130+1.348561e-02*S131+9.417721e-03*S132+1.914740e-02*S133+2.726150e-02*S134+8.033393e-02*S135+8.973458e-02*S136+5.871151e-02*S137+3.559754e-02*S138+3.114289e-02*S139'
.param V29_part15='V29_part14+1.642628e-02*S140+1.710703e-02*S141+1.556977e-02*S142+5.265654e-03*S143+9.919637e-03*S144+1.020562e-02*S145+2.723715e-03*S146+6.411137e-03*S147+7.059058e-03*S148+3.692617e-03*S149'
.param V29_part16='V29_part15+(-5.677793e-02)*S150+(-4.885375e-02)*S151+(-1.121903e-01)*S152+2.561866e-02*S153+(-4.741648e-03)*S154+1.820538e-02*S155+2.102605e-02*S156+2.480169e-02*S157+1.918935e-02*S158+1.105823e-02*S159'
.param V29_part17='V29_part16+2.208220e-02*S160+2.084131e-02*S161+1.605395e-02*S162+7.216743e-03*S163+7.248739e-03*S164+(-1.474185e-02)*S165+6.875194e-02*S166+(-7.501153e-02)*S167+2.760968e-02*S168+(-6.199715e-02)*S169'
.param V29_part18='V29_part17+3.626227e-02*S170+3.337887e-02*S171+3.149870e-02*S172+4.305133e-02*S173+1.194664e-02*S174+2.655012e-02*S175+2.159683e-02*S176+1.234300e-02*S177+1.233174e-02*S178+1.561428e-02*S179'
.param V29_part19='V29_part18+(-1.240816e-02)*S180+6.877197e-02*S181+(-1.222856e-01)*S182+2.843031e-02*S183+(-1.142415e-01)*S184+(-3.190255e-02)*S185+4.562163e-02*S186+3.287939e-02*S187+2.260279e-02*S188+1.429105e-02*S189'
.param V29_part20='V29_part19+3.139407e-02*S190+2.233447e-02*S191+2.109463e-02*S192+(-1.664360e-02)*S193+2.032611e-02*S194+3.994754e-02*S195+(-1.653417e-02)*S196+(-3.394651e-02)*S197+1.400361e-02*S198+(-4.784410e-02)*S199'
.param V29_part21='V29_part20+(-4.120879e-02)*S200+7.987135e-03*S201+7.175903e-03*S202+(-4.776931e-02)*S203+2.253181e-02*S204+1.623179e-02*S205+9.419723e-03*S206+1.340845e-02*S207+2.489146e-02*S208+1.572672e-02*S209'
.param V29_part22='V29_part21+(-9.584644e-02)*S210+(-4.916739e-02)*S211+(-4.757677e-02)*S212+4.613708e-02*S213+(-1.406135e-01)*S214+(-4.154570e-02)*S215+1.715303e-02*S216+2.697018e-02*S217+3.297069e-02*S218+3.401389e-02*S219'
.param V29_part23='V29_part22+2.788940e-02*S220+3.590923e-02*S221+2.074681e-02*S222+3.085747e-02*S223+1.006713e-03*S224+(-4.130359e-02)*S225+7.917730e-03*S226+1.122349e-02*S227+(-1.168916e-02)*S228+(-2.628096e-02)*S229'
.param V29_part24='V29_part23+(-8.150288e-03)*S230+4.910261e-02*S231+(-4.190395e-02)*S232+(-9.733105e-02)*S233+4.688608e-02*S234+(-2.555896e-02)*S235+(-1.260523e-02)*S236+3.636134e-03*S237+3.263346e-02*S238+(-5.640702e-04)*S239'
.param V29_part25='V29_part24+(-1.556293e-01)*S240+(-3.915543e-02)*S241+(-1.142088e-01)*S242+(-1.464842e-01)*S243+5.099714e-02*S244+(-1.051473e-01)*S245+(-1.168468e-01)*S246+(-1.204390e-01)*S247+(-1.008954e-01)*S248+(-6.091514e-02)*S249'
.param V29_part26='V29_part25+7.894847e-03*S250+(-1.265049e-02)*S251+(-8.343591e-02)*S252+(-3.337089e-02)*S253+2.014434e-02*S254+(-2.542324e-02)*S255+(-2.822560e-02)*S256+(-1.159857e-02)*S257+(-7.772799e-02)*S258+(-5.558926e-02)*S259'
.param V29_part27='V29_part26+(-4.552978e-02)*S260+2.121003e-02*S261+5.372164e-02*S262+1.732288e-02*S263+4.183838e-02*S264+3.370345e-02*S265+2.746393e-02*S266+2.776552e-02*S267+3.045766e-02*S268+3.176085e-02*S269'
.param V29_part28='V29_part27+9.785855e-02*S270+7.768481e-02*S271+(-9.447507e-02)*S272+8.914358e-02*S273+(-5.041898e-02)*S274+(-9.521553e-02)*S275+3.071423e-02*S276+(-9.726954e-02)*S277+(-2.755097e-02)*S278+(-9.022148e-03)*S279'
.param V29_part29='V29_part28+(-3.781352e-02)*S280+1.828217e-02*S281+(-4.129266e-01)*S282+(-4.886466e-03)*S283+(-1.007370e-02)*S284+2.982293e-02*S285+6.858215e-02*S286+(-1.193987e-01)*S287+(-2.357135e-02)*S288+5.747333e-02*S289'
.param V29_part30='V29_part29+(-1.017750e-01)*S290+(-1.202251e-02)*S291+3.624329e-02*S292+(-1.075095e-01)*S293+(-6.878474e-03)*S294+3.585207e-02*S295+(-7.729664e-02)*S296+(-1.366260e-01)*S297+3.837215e-02*S298+(-1.437858e-01)*S299'
.param V29_part31='V29_part30+2.525103e-02*S300+(-2.581087e-01)*S301+(-1.080513e-01)*S302+(-7.311586e-03)*S303+(-7.803641e-02)*S304+(-1.184128e-01)*S305+(-7.400693e-02)*S306+4.450371e-02*S307+(-4.904172e-02)*S308+4.847194e-02*S309'
.param V29='V29_part31+(-2.648914e-02)*S310+6.568667e-03*S311+5.274582e-02*S312+4.273407e-02*S313+(-1.664450e-02)*S314'
.param V30_part1='2.006778e-01*S0+9.584916e-02*S1+6.510155e-01*S2+1.335221e-01*S3+1.048109e+00*S4+9.579531e-01*S5+9.556045e-01*S6+1.075325e+00*S7+4.008060e-01*S8+(-4.236090e-01)*S9'
.param V30_part2='V30_part1+1.095072e+00*S10+(-8.290027e-01)*S11+(-8.646378e-01)*S12+(-5.177855e-01)*S13+(-1.501704e+00)*S14+2.537588e+00*S15+(-2.608105e-01)*S16+(-1.390656e+00)*S17+3.409781e-01*S18+5.597008e-01*S19'
.param V30_part3='V30_part2+(-2.212194e+00)*S20+(-5.393044e-01)*S21+(-2.234845e-01)*S22+(-9.994719e-01)*S23+(-5.995481e-01)*S24+(-7.304834e-01)*S25+(-2.218094e-01)*S26+(-1.158573e-01)*S27+(-2.410034e-01)*S28+(-1.200215e+00)*S29'
.param V30_part4='V30_part3+(-1.518397e-01)*S30+(-3.335167e-01)*S31+(-4.668062e+00)*S32+(-5.811731e-01)*S33+(-2.827690e+00)*S34+(-1.268740e+00)*S35+(-7.579792e-01)*S36+(-3.220913e+00)*S37+(-7.003120e+00)*S38+(-2.850204e+00)*S39'
.param V30_part5='V30_part4+(-4.792198e+00)*S40+(-7.086941e+00)*S41+(-3.400662e+00)*S42+(-3.209552e+00)*S43+(-9.807791e+00)*S44+(-5.631742e-01)*S45+(-1.149406e+00)*S46+(-5.558231e+00)*S47+(-1.173855e+00)*S48+(-2.006440e+00)*S49'
.param V30_part6='V30_part5+(-9.723426e+00)*S50+(-1.390670e+00)*S51+(-4.024412e+00)*S52+(-1.009648e+01)*S53+(-1.178371e+01)*S54+(-3.403561e+00)*S55+(-1.015484e+01)*S56+(-1.856442e+00)*S57+(-4.593158e+00)*S58+(-1.177964e+01)*S59'
.param V30_part7='V30_part6+(-4.272188e-01)*S60+(-3.260102e-01)*S61+(-5.702254e+00)*S62+(-1.223293e+00)*S63+(-1.769412e+00)*S64+(-8.070661e+00)*S65+(-1.837768e+00)*S66+(-2.926134e+00)*S67+(-5.301619e+00)*S68+(-1.608995e+00)*S69'
.param V30_part8='V30_part7+(-3.129542e+00)*S70+(-1.119291e+01)*S71+(-2.314462e+00)*S72+(-5.313109e+00)*S73+(-1.429567e+01)*S74+(-9.809148e-01)*S75+(-1.404857e+00)*S76+(-8.597786e-01)*S77+(-1.806891e+00)*S78+(-7.598380e-01)*S79'
.param V30_part9='V30_part8+1.012666e+00*S80+(-1.364550e+00)*S81+(-2.887358e-01)*S82+(-3.459495e+00)*S83+(-1.232305e+00)*S84+(-1.501562e+00)*S85+(-4.654845e+00)*S86+(-9.572093e-01)*S87+(-2.475165e+00)*S88+(-5.729649e+00)*S89'
.param V30_part10='V30_part9+(-1.525508e+00)*S90+(-3.893593e+00)*S91+(-9.998263e+00)*S92+(-1.931808e+00)*S93+(-4.078085e+00)*S94+(-1.346301e+01)*S95+(-1.969814e+00)*S96+(-6.605622e+00)*S97+(-1.590583e+01)*S98+(-2.654429e+00)*S99'
.param V30_part11='V30_part10+(-4.971129e+00)*S100+(-1.903936e+01)*S101+(-1.817946e+00)*S102+(-4.918679e+00)*S103+(-1.712449e+01)*S104+(-2.014064e+00)*S105+(-4.162880e+00)*S106+(-1.030847e+01)*S107+(-2.322416e+00)*S108+(-4.885311e+00)*S109'
.param V30_part12='V30_part11+(-5.839653e+00)*S110+(-1.837717e+00)*S111+(-4.153454e+00)*S112+(-1.090640e+01)*S113+(-1.782080e+00)*S114+(-4.035341e+00)*S115+(-1.066230e+01)*S116+(-1.932934e+00)*S117+(-4.168315e+00)*S118+(-8.355696e+00)*S119'
.param V30_part13='V30_part12+(-1.255443e+00)*S120+(-5.408880e+00)*S121+(-1.297484e+01)*S122+(-1.903564e+00)*S123+(-5.752542e+00)*S124+(-1.494580e+01)*S125+(-2.751621e+00)*S126+(-5.371982e+00)*S127+(-1.308669e+01)*S128+(-1.694363e+00)*S129'
.param V30_part14='V30_part13+(-5.583856e+00)*S130+(-1.568136e+01)*S131+(-1.946757e+00)*S132+(-6.440521e+00)*S133+(-9.291076e+00)*S134+(-3.070514e-01)*S135+(-6.434602e-02)*S136+(-5.662613e+00)*S137+(-7.129193e-01)*S138+(-2.640791e+00)*S139'
.param V30_part15='V30_part14+(-1.118790e+01)*S140+(-2.213384e+00)*S141+(-4.053224e+00)*S142+(-1.297086e+01)*S143+(-3.177630e+00)*S144+(-5.292682e+00)*S145+(-1.209693e+01)*S146+(-4.283249e+00)*S147+(-6.534478e+00)*S148+(-1.470700e+01)*S149'
.param V30_part16='V30_part15+(-2.320522e+00)*S150+(-6.216465e+00)*S151+(-1.929538e+01)*S152+(-2.702030e+00)*S153+(-5.952125e+00)*S154+(-2.409533e+01)*S155+(-2.958158e+00)*S156+(-6.508653e+00)*S157+(-1.721113e+01)*S158+(-2.975892e+00)*S159'
.param V30_part17='V30_part16+(-6.659976e+00)*S160+(-1.703815e+01)*S161+(-3.437697e+00)*S162+(-6.608181e+00)*S163+(-1.452973e+01)*S164+(-3.002059e+00)*S165+(-4.432047e+00)*S166+(-1.875540e+01)*S167+(-1.868039e+00)*S168+(-6.973914e+00)*S169'
.param V30_part18='V30_part17+(-7.755581e+00)*S170+(-9.975791e-01)*S171+(-6.630259e+00)*S172+(-1.002791e+01)*S173+(-7.822100e-01)*S174+(-4.660464e+00)*S175+(-1.122417e+01)*S176+(-5.864959e+00)*S177+(-6.005657e+00)*S178+(-9.772942e+00)*S179'
.param V30_part19='V30_part18+(-3.468097e+00)*S180+(-3.514373e+00)*S181+(-1.138052e+01)*S182+(-1.795214e+00)*S183+(-8.006230e+00)*S184+(-9.378559e+00)*S185+(-2.050279e+00)*S186+(-4.187946e+00)*S187+(-1.779029e+01)*S188+(-3.140941e+00)*S189'
.param V30_part20='V30_part19+(-3.688791e+00)*S190+(-1.750019e+01)*S191+(-2.977638e+00)*S192+(-3.993418e+00)*S193+(-1.212050e+01)*S194+(-3.004989e-01)*S195+(-6.944908e+00)*S196+(-1.544838e+01)*S197+(-2.513286e+00)*S198+(-1.011295e+01)*S199'
.param V30_part21='V30_part20+(-1.806848e+01)*S200+(-4.287633e+00)*S201+(-7.594703e+00)*S202+(-2.033422e+01)*S203+(-3.437510e+00)*S204+(-2.200814e+00)*S205+(-1.272869e+01)*S206+7.826647e-01*S207+(-5.096364e+00)*S208+(-7.900626e+00)*S209'
.param V30_part22='V30_part21+(-3.559329e+00)*S210+(-8.107675e+00)*S211+(-2.593116e+01)*S212+(-1.814070e+00)*S213+(-7.980751e+00)*S214+(-2.211668e+01)*S215+(-3.570353e+00)*S216+(-8.971378e+00)*S217+(-2.523710e+01)*S218+(-2.131213e+00)*S219'
.param V30_part23='V30_part22+(-6.703486e+00)*S220+(-2.739217e+01)*S221+(-5.180742e+00)*S222+(-8.315562e+00)*S223+(-1.797482e+01)*S224+(-2.478513e+00)*S225+(-8.116045e+00)*S226+(-2.497185e+01)*S227+(-4.570974e+00)*S228+(-6.991727e+00)*S229'
.param V30_part24='V30_part23+(-1.786495e+01)*S230+(-6.330931e+00)*S231+(-6.020317e+00)*S232+(-2.013913e+01)*S233+(-7.297120e+00)*S234+(-1.032924e+01)*S235+(-2.349770e+01)*S236+(-7.474504e+00)*S237+(-8.078820e+00)*S238+(-1.337178e+01)*S239'
.param V30_part25='V30_part24+(-2.212041e+00)*S240+(-8.577847e+00)*S241+(-2.416617e+01)*S242+(-3.308729e+00)*S243+(-6.135146e+00)*S244+(-1.671647e+01)*S245+(-3.735633e+00)*S246+(-7.063818e+00)*S247+(-1.972616e+01)*S248+(-5.973708e+00)*S249'
.param V30_part26='V30_part25+(-1.017655e+01)*S250+(-2.616499e+01)*S251+(-7.697655e+00)*S252+(-7.137532e+00)*S253+(-1.872273e+01)*S254+(-4.594424e+00)*S255+(-1.099318e+01)*S256+(-1.022545e+01)*S257+(-4.479318e+00)*S258+(-2.234848e+00)*S259'
.param V30_part27='V30_part26+(-1.807565e+01)*S260+(-2.180358e+00)*S261+(-5.176907e+00)*S262+(-1.156187e+01)*S263+(-2.419694e+00)*S264+(-6.553653e+00)*S265+(-1.411902e+01)*S266+(-2.353903e+00)*S267+(-7.488605e+00)*S268+(-7.854116e+00)*S269'
.param V30_part28='V30_part27+(-2.035952e+00)*S270+(-5.632054e+00)*S271+(-4.569051e+00)*S272+(-2.961097e+00)*S273+(-7.371328e+00)*S274+(-1.498345e+01)*S275+(-2.906509e+00)*S276+(-7.581966e+00)*S277+(-2.256124e+01)*S278+(-3.353394e+00)*S279'
.param V30_part29='V30_part28+(-8.284412e+00)*S280+(-2.663088e+01)*S281+(-5.291409e+00)*S282+(-9.687004e+00)*S283+(-2.330659e+01)*S284+(-7.094181e-01)*S285+(-6.874164e+00)*S286+(-2.313159e+01)*S287+(-2.636893e+00)*S288+(-7.803467e+00)*S289'
.param V30_part30='V30_part29+(-1.841199e+01)*S290+(-3.211252e+00)*S291+(-7.551415e+00)*S292+(-2.314561e+01)*S293+(-3.709790e+00)*S294+(-9.839299e+00)*S295+(-2.555031e+01)*S296+(-6.414715e+00)*S297+(-1.173161e+01)*S298+(-2.463994e+01)*S299'
.param V30_part31='V30_part30+(-1.318964e+00)*S300+(-6.416334e+00)*S301+(-2.106992e+01)*S302+(-2.286878e+00)*S303+(-6.251872e+00)*S304+(-1.399924e+01)*S305+(-2.301767e+00)*S306+(-6.543841e+00)*S307+(-1.640923e+01)*S308+(-3.609911e+00)*S309'
.param V30='V30_part31+(-7.445489e+00)*S310+(-2.479702e+01)*S311+(-4.189943e+00)*S312+(-8.812564e+00)*S313+(-2.282880e+01)*S314'
.param V31_part1='3.542951e-01*S0+2.260426e+00*S1+2.600902e+00*S2+1.099290e+00*S3+1.463562e+00*S4+1.524920e+00*S5+7.973962e-01*S6+1.018559e+00*S7+1.349186e+00*S8+1.479521e+00*S9'
.param V31_part2='V31_part1+1.035233e+00*S10+2.202413e+00*S11+1.708541e+00*S12+1.125454e+00*S13+2.264744e+00*S14+1.148867e+00*S15+3.325372e+00*S16+5.924586e+00*S17+1.986440e+00*S18+8.384411e-01*S19'
.param V31_part3='V31_part2+5.571507e+00*S20+1.824192e+00*S21+1.455533e+00*S22+2.593496e+00*S23+1.718689e+00*S24+2.019510e+00*S25+2.045279e+00*S26+1.353742e+00*S27+2.131605e+00*S28+2.717652e+00*S29'
.param V31_part4='V31_part3+4.891434e+00*S30+3.435738e+00*S31+1.114702e+01*S32+4.386011e+00*S33+7.134113e+00*S34+3.956615e+00*S35+4.088272e+00*S36+6.137425e+00*S37+8.933630e+00*S38+5.688395e+00*S39'
.param V31_part5='V31_part4+5.713495e+00*S40+8.689125e+00*S41+5.397537e+00*S42+3.093482e+00*S43+9.423762e+00*S44+6.534769e+00*S45+6.567780e+00*S46+1.367757e+01*S47+7.779081e+00*S48+5.798594e+00*S49'
.param V31_part6='V31_part5+1.627130e+01*S50+6.543781e+00*S51+7.816282e+00*S52+1.188579e+01*S53+2.198022e+01*S54+5.676651e+00*S55+1.107468e+01*S56+5.600706e+00*S57+6.810950e+00*S58+1.299312e+01*S59'
.param V31_part7='V31_part6+1.022061e+01*S60+6.733466e+00*S61+1.416731e+01*S62+8.335708e+00*S63+7.374431e+00*S64+1.464856e+01*S65+7.590179e+00*S66+7.902151e+00*S67+1.006261e+01*S68+6.708554e+00*S69'
.param V31_part8='V31_part7+7.432152e+00*S70+1.357830e+01*S71+6.850166e+00*S72+8.579640e+00*S73+1.355962e+01*S74+5.966328e+00*S75+6.091486e+00*S76+5.425624e+00*S77+6.077984e+00*S78+4.961658e+00*S79'
.param V31_part9='V31_part8+1.896254e+00*S80+4.453106e+00*S81+1.999355e+00*S82+6.147591e+00*S83+4.087781e+00*S84+3.134318e+00*S85+5.998362e+00*S86+3.543764e+00*S87+3.929623e+00*S88+5.872537e+00*S89'
.param V31_part10='V31_part9+9.934846e+00*S90+9.967593e+00*S91+1.850960e+01*S92+8.457233e+00*S93+8.769401e+00*S94+2.042302e+01*S95+7.291908e+00*S96+8.590835e+00*S97+1.890094e+01*S98+7.703452e+00*S99'
.param V31_part11='V31_part10+8.591835e+00*S100+1.972940e+01*S101+6.363377e+00*S102+7.761513e+00*S103+1.456626e+01*S104+1.161815e+01*S105+1.177496e+01*S106+1.868224e+01*S107+9.993980e+00*S108+1.072643e+01*S109'
.param V31_part12='V31_part11+9.481150e+00*S110+7.735378e+00*S111+9.069463e+00*S112+1.171137e+01*S113+7.115247e+00*S114+8.461584e+00*S115+8.829723e+00*S116+6.774358e+00*S117+7.463930e+00*S118+1.052807e+01*S119'
.param V31_part13='V31_part12+9.728567e+00*S120+8.828243e+00*S121+2.156537e+01*S122+7.843329e+00*S123+8.151802e+00*S124+1.933508e+01*S125+8.421816e+00*S126+1.041248e+01*S127+1.308121e+01*S128+7.701327e+00*S129'
.param V31_part14='V31_part13+9.705886e+00*S130+1.606802e+01*S131+6.723589e+00*S132+9.451109e+00*S133+1.182275e+01*S134+1.225347e+01*S135+5.560964e+00*S136+9.515345e+00*S137+2.944118e+00*S138+4.117203e+00*S139'
.param V31_part15='V31_part14+1.592086e+01*S140+6.136952e+00*S141+4.009801e+00*S142+1.470139e+01*S143+6.262210e+00*S144+6.008535e+00*S145+1.228299e+01*S146+6.063858e+00*S147+6.587300e+00*S148+1.256983e+01*S149'
.param V31_part16='V31_part15+1.272015e+01*S150+1.402824e+01*S151+2.943079e+01*S152+9.454777e+00*S153+1.214281e+01*S154+2.849352e+01*S155+8.570105e+00*S156+1.063974e+01*S157+1.442846e+01*S158+7.567997e+00*S159'
.param V31_part17='V31_part16+8.828548e+00*S160+1.503140e+01*S161+6.983843e+00*S162+8.419775e+00*S163+1.347143e+01*S164+1.129282e+01*S165+8.718577e+00*S166+2.602319e+01*S167+9.212751e+00*S168+1.277978e+01*S169'
.param V31_part18='V31_part17+8.691814e+00*S170+7.550194e+00*S171+1.112134e+01*S172+1.208485e+01*S173+6.991208e+00*S174+8.858616e+00*S175+1.372255e+01*S176+8.327367e+00*S177+7.609226e+00*S178+1.277396e+01*S179'
.param V31_part19='V31_part18+1.383286e+01*S180+1.354273e+01*S181+1.513642e+01*S182+9.608217e+00*S183+1.347792e+01*S184+1.530398e+01*S185+7.573375e+00*S186+9.839030e+00*S187+1.636825e+01*S188+7.740450e+00*S189'
.param V31_part20='V31_part19+8.272133e+00*S190+1.502326e+01*S191+7.530365e+00*S192+7.772347e+00*S193+1.388423e+01*S194+9.067231e+00*S195+1.828812e+01*S196+2.318182e+01*S197+6.181383e+00*S198+1.926547e+01*S199'
.param V31_part21='V31_part20+2.232916e+01*S200+7.960383e+00*S201+9.266007e+00*S202+2.196927e+01*S203+6.769630e+00*S204+4.833168e+00*S205+1.459990e+01*S206+5.070316e+00*S207+7.688914e+00*S208+9.932436e+00*S209'
.param V31_part22='V31_part21+1.283933e+01*S210+1.512231e+01*S211+3.677501e+01*S212+9.263535e+00*S213+1.313768e+01*S214+2.347716e+01*S215+8.878451e+00*S216+1.062687e+01*S217+2.093323e+01*S218+7.429664e+00*S219'
.param V31_part23='V31_part22+9.342672e+00*S220+1.995018e+01*S221+8.370060e+00*S222+9.746526e+00*S223+1.527904e+01*S224+1.223093e+01*S225+1.642148e+01*S226+2.666534e+01*S227+9.719014e+00*S228+1.313195e+01*S229'
.param V31_part24='V31_part23+1.760096e+01*S230+1.013061e+01*S231+1.107311e+01*S232+1.739502e+01*S233+9.033588e+00*S234+9.565755e+00*S235+1.736538e+01*S236+8.845696e+00*S237+9.781559e+00*S238+1.181937e+01*S239'
.param V31_part25='V31_part24+1.137454e+01*S240+1.564492e+01*S241+2.838576e+01*S242+9.851860e+00*S243+6.985020e+00*S244+1.741221e+01*S245+8.150624e+00*S246+1.236514e+01*S247+1.972373e+01*S248+8.957010e+00*S249'
.param V31_part26='V31_part25+1.175784e+01*S250+1.952355e+01*S251+9.549636e+00*S252+8.766279e+00*S253+1.293277e+01*S254+1.895958e+01*S255+2.439139e+01*S256+1.387395e+01*S257+1.260358e+01*S258+2.724845e+00*S259'
.param V31_part27='V31_part26+1.977896e+01*S260+7.437618e+00*S261+9.208749e+00*S262+9.951983e+00*S263+7.640479e+00*S264+7.308009e+00*S265+1.251123e+01*S266+7.784863e+00*S267+7.157862e+00*S268+7.450094e+00*S269'
.param V31_part28='V31_part27+5.211753e+00*S270+8.422633e+00*S271+1.594308e+01*S272+7.174993e+00*S273+1.112138e+01*S274+1.515266e+01*S275+7.075613e+00*S276+5.763895e+00*S277+2.181759e+01*S278+7.414393e+00*S279'
.param V31_part29='V31_part28+1.095296e+01*S280+2.262347e+01*S281+1.044447e+01*S282+1.004046e+01*S283+1.831399e+01*S284+3.872192e+00*S285+8.031297e+00*S286+2.336220e+01*S287+8.340343e+00*S288+9.323090e+00*S289'
.param V31_part30='V31_part29+1.764651e+01*S290+7.704684e+00*S291+1.011718e+01*S292+2.222169e+01*S293+7.601800e+00*S294+1.224172e+01*S295+2.176669e+01*S296+9.703810e+00*S297+1.245589e+01*S298+1.996958e+01*S299'
.param V31_part31='V31_part30+9.610671e+00*S300+1.505127e+01*S301+2.572055e+01*S302+7.991195e+00*S303+1.137791e+01*S304+1.426315e+01*S305+7.322655e+00*S306+1.168739e+01*S307+1.559312e+01*S308+8.842604e+00*S309'
.param V31='V31_part31+1.109200e+01*S310+2.057052e+01*S311+9.351173e+00*S312+1.082578e+01*S313+1.890650e+01*S314'
.param V32_part1='2.041347e+00*S0+2.220809e+00*S1+4.918634e-01*S2+1.844647e+00*S3+(-3.099847e-01)*S4+2.806189e-01*S5+(-3.705096e-01)*S6+(-5.464501e-01)*S7+9.716188e-01*S8+2.309496e+00*S9'
.param V32_part2='V32_part1+(-9.022269e-01)*S10+1.706472e+00*S11+2.005101e+00*S12+2.062974e+00*S13+2.043746e+00*S14+(-6.462372e+00)*S15+3.705770e+00*S16+2.610184e+00*S17+1.468649e+00*S18+2.352940e+00*S19'
.param V32_part3='V32_part2+3.351758e+00*S20+2.652681e+00*S21+3.255053e+00*S22+3.279709e+00*S23+2.551468e+00*S24+2.799336e+00*S25+2.387847e+00*S26+1.735780e+00*S27+7.271936e-01*S28+2.251297e+00*S29'
.param V32_part4='V32_part3+4.691708e+00*S30+5.573946e+00*S31+9.822386e+00*S32+5.737749e+00*S33+1.013309e+01*S34+6.888179e+00*S35+6.832857e+00*S36+1.162386e+01*S37+1.119643e+01*S38+6.688992e+00*S39'
.param V32_part5='V32_part4+1.215773e+01*S40+1.206829e+01*S41+9.145972e+00*S42+1.371830e+01*S43+1.432511e+01*S44+4.305836e+00*S45+6.224871e+00*S46+1.014840e+01*S47+6.053763e+00*S48+8.112726e+00*S49'
.param V32_part6='V32_part5+1.307874e+01*S50+7.637500e+00*S51+1.220584e+01*S52+1.738983e+01*S53+2.722825e+01*S54+9.226353e+00*S55+1.846392e+01*S56+1.124887e+01*S57+1.613330e+01*S58+1.885580e+01*S59'
.param V32_part7='V32_part6+6.475754e+00*S60+7.398445e+00*S61+1.066168e+01*S62+8.252564e+00*S63+1.013606e+01*S64+1.348489e+01*S65+9.531369e+00*S66+1.102776e+01*S67+1.348308e+01*S68+1.074494e+01*S69'
.param V32_part8='V32_part7+1.344037e+01*S70+2.159148e+01*S71+1.366952e+01*S72+1.892406e+01*S73+2.192039e+01*S74+4.779253e+00*S75+5.929157e+00*S76+4.928195e+00*S77+6.515339e+00*S78+4.252051e+00*S79'
.param V32_part9='V32_part8+3.558184e+00*S80+5.278691e+00*S81+4.451368e+00*S82+7.333950e+00*S83+5.682362e+00*S84+7.165322e+00*S85+8.274793e+00*S86+6.652783e+00*S87+8.161922e+00*S88+9.966903e+00*S89'
.param V32_part10='V32_part9+1.241310e+01*S90+1.810820e+01*S91+1.736006e+01*S92+1.468733e+01*S93+2.100605e+01*S94+2.369731e+01*S95+1.644806e+01*S96+1.964993e+01*S97+2.708645e+01*S98+1.919133e+01*S99'
.param V32_part11='V32_part10+2.444795e+01*S100+2.992687e+01*S101+1.883932e+01*S102+2.545318e+01*S103+3.491444e+01*S104+1.308697e+01*S105+1.782886e+01*S106+1.991480e+01*S107+1.521457e+01*S108+2.234108e+01*S109'
.param V32_part12='V32_part11+1.902873e+01*S110+1.609227e+01*S111+2.299618e+01*S112+2.537491e+01*S113+1.805980e+01*S114+2.293457e+01*S115+2.656459e+01*S116+1.988178e+01*S117+2.475602e+01*S118+2.820450e+01*S119'
.param V32_part13='V32_part12+1.276527e+01*S120+1.902217e+01*S121+2.495928e+01*S122+1.287813e+01*S123+2.126567e+01*S124+2.815471e+01*S125+1.904284e+01*S126+2.721863e+01*S127+2.942648e+01*S128+1.945541e+01*S129'
.param V32_part14='V32_part13+2.833906e+01*S130+3.598299e+01*S131+1.951575e+01*S132+2.977447e+01*S133+2.960826e+01*S134+7.312056e+00*S135+5.644671e+00*S136+1.134115e+01*S137+6.959237e+00*S138+1.161498e+01*S139'
.param V32_part15='V32_part14+1.732530e+01*S140+9.583509e+00*S141+1.628137e+01*S142+2.048598e+01*S143+1.314227e+01*S144+1.936756e+01*S145+2.102143e+01*S146+1.809020e+01*S147+2.206032e+01*S148+2.554967e+01*S149'
.param V32_part16='V32_part15+1.772161e+01*S150+3.154346e+01*S151+3.727909e+01*S152+2.572001e+01*S153+3.398223e+01*S154+4.258692e+01*S155+2.614839e+01*S156+3.020654e+01*S157+3.996614e+01*S158+2.513824e+01*S159'
.param V32_part17='V32_part16+3.267148e+01*S160+4.331783e+01*S161+2.711994e+01*S162+3.367080e+01*S163+4.206148e+01*S164+1.437391e+01*S165+2.270494e+01*S166+4.211682e+01*S167+2.027008e+01*S168+3.478691e+01*S169'
.param V32_part18='V32_part17+2.932056e+01*S170+2.125021e+01*S171+3.103049e+01*S172+3.544638e+01*S173+2.525518e+01*S174+2.762568e+01*S175+3.691767e+01*S176+3.652421e+01*S177+3.234742e+01*S178+3.652606e+01*S179'
.param V32_part19='V32_part18+2.320530e+01*S180+2.587079e+01*S181+3.395069e+01*S182+2.276485e+01*S183+3.976939e+01*S184+3.267977e+01*S185+2.219701e+01*S186+2.849546e+01*S187+4.936554e+01*S188+2.628704e+01*S189'
.param V32_part20='V32_part19+2.880728e+01*S190+5.115217e+01*S191+2.541470e+01*S192+3.070056e+01*S193+3.825680e+01*S194+1.449645e+01*S195+2.203754e+01*S196+3.077713e+01*S197+1.658829e+01*S198+2.874846e+01*S199'
.param V32_part21='V32_part20+3.433646e+01*S200+2.075766e+01*S201+2.688637e+01*S202+3.659026e+01*S203+2.170021e+01*S204+2.020978e+01*S205+3.525614e+01*S206+2.068576e+01*S207+3.216101e+01*S208+3.662209e+01*S209'
.param V32_part22='V32_part21+2.819497e+01*S210+4.117055e+01*S211+5.504081e+01*S212+2.628650e+01*S213+3.818864e+01*S214+6.146869e+01*S215+3.103391e+01*S216+4.353076e+01*S217+6.256583e+01*S218+1.955661e+01*S219'
.param V32_part23='V32_part22+3.818575e+01*S220+6.369626e+01*S221+3.772433e+01*S222+4.111394e+01*S223+5.350682e+01*S224+2.497478e+01*S225+3.890717e+01*S226+6.263290e+01*S227+3.675386e+01*S228+3.745281e+01*S229'
.param V32_part24='V32_part23+4.702907e+01*S230+4.119969e+01*S231+3.439355e+01*S232+4.542216e+01*S233+4.544495e+01*S234+3.809075e+01*S235+4.796016e+01*S236+4.725087e+01*S237+3.939913e+01*S238+4.904275e+01*S239'
.param V32_part25='V32_part24+2.557218e+01*S240+4.192438e+01*S241+5.883231e+01*S242+3.645836e+01*S243+2.800317e+01*S244+4.799886e+01*S245+3.852733e+01*S246+4.042101e+01*S247+4.604973e+01*S248+4.284656e+01*S249'
.param V32_part26='V32_part25+5.076285e+01*S250+5.162515e+01*S251+4.698720e+01*S252+4.160457e+01*S253+4.810856e+01*S254+2.368412e+01*S255+3.864287e+01*S256+3.227299e+01*S257+2.760888e+01*S258+2.048843e+01*S259'
.param V32_part27='V32_part26+4.948166e+01*S260+2.559040e+01*S261+3.133286e+01*S262+3.985109e+01*S263+2.698788e+01*S264+2.711745e+01*S265+3.752300e+01*S266+2.580354e+01*S267+2.925581e+01*S268+2.849254e+01*S269'
.param V32_part28='V32_part27+2.534652e+01*S270+3.006488e+01*S271+3.450218e+01*S272+2.675064e+01*S273+4.258944e+01*S274+4.946240e+01*S275+2.792328e+01*S276+3.963923e+01*S277+4.947128e+01*S278+3.759036e+01*S279'
.param V32_part29='V32_part28+4.608657e+01*S280+5.114526e+01*S281+1.398596e+01*S282+5.137937e+01*S283+5.343294e+01*S284+2.234979e+01*S285+3.385814e+01*S286+6.422444e+01*S287+3.279604e+01*S288+3.228642e+01*S289'
.param V32_part30='V32_part29+5.900325e+01*S290+3.453216e+01*S291+4.443005e+01*S292+6.171209e+01*S293+3.733661e+01*S294+4.632200e+01*S295+6.432854e+01*S296+3.986212e+01*S297+5.003436e+01*S298+6.585936e+01*S299'
.param V32_part31='V32_part30+2.575476e+01*S300+3.986514e+01*S301+5.700786e+01*S302+3.048782e+01*S303+3.766944e+01*S304+3.968138e+01*S305+3.200793e+01*S306+3.866811e+01*S307+4.187712e+01*S308+3.261152e+01*S309'
.param V32='V32_part31+4.143111e+01*S310+4.835946e+01*S311+3.391970e+01*S312+4.306259e+01*S313+4.783886e+01*S314'
.param V33_part1='8.393929e-03*S0+8.989177e-01*S1+1.967407e-01*S2+6.989733e-02*S3+6.940224e-02*S4+4.298506e-01*S5+1.904097e-01*S6+2.816121e-01*S7+3.431300e-01*S8+2.185282e-01*S9'
.param V33_part2='V33_part1+3.575744e-01*S10+6.496334e-01*S11+4.756425e-01*S12+4.061529e-01*S13+6.570982e-01*S14+4.849536e-01*S15+5.329117e-01*S16+7.293291e-01*S17+(-2.680363e-02)*S18+8.933775e-02*S19'
.param V33_part3='V33_part2+7.421578e-01*S20+6.390194e-01*S21+2.459489e-01*S22+6.470662e-01*S23+5.110418e-01*S24+3.770724e-01*S25+(-3.096900e-02)*S26+4.068383e-01*S27+7.231758e-01*S28+2.188580e-01*S29'
.param V33_part4='V33_part3+4.091612e-01*S30+1.891621e-02*S31+2.942811e-01*S32+3.051144e-03*S33+4.640896e-01*S34+2.633078e-02*S35+(-2.025368e-01)*S36+(-1.030750e-01)*S37+1.823392e-01*S38+(-4.416076e-01)*S39'
.param V33_part5='V33_part4+(-6.176163e-02)*S40+(-2.850810e-01)*S41+(-9.384757e-01)*S42+(-3.794683e-02)*S43+2.196330e-02*S44+3.621652e-01*S45+3.807254e-01*S46+4.501161e-01*S47+4.520225e-02*S48+3.648986e-02*S49'
.param V33_part6='V33_part5+(-4.871123e-01)*S50+2.179297e-01*S51+5.495284e-01*S52+1.001652e+00*S53+3.001956e-01*S54+(-8.816003e-01)*S55+1.296081e+00*S56+4.169860e-01*S57+6.333320e-01*S58+1.057128e+00*S59'
.param V33_part7='V33_part6+(-2.167704e-01)*S60+(-3.840861e-01)*S61+(-6.263596e-01)*S62+(-4.708065e-01)*S63+(-2.544925e-01)*S64+(-3.640873e-01)*S65+2.048535e-01*S66+(-3.067426e-01)*S67+(-3.711691e-01)*S68+1.672627e-01*S69'
.param V33_part8='V33_part7+(-1.809451e-01)*S70+2.747604e-01*S71+3.029611e-01*S72+2.093036e-01*S73+(-2.104692e-01)*S74+1.036304e-02*S75+2.734786e-01*S76+7.853662e-01*S77+4.199948e-01*S78+(-5.920522e-05)*S79'
.param V33_part9='V33_part8+1.141622e+00*S80+1.141853e+00*S81+1.796186e-01*S82+2.219607e+00*S83+1.471794e+00*S84+1.489979e+00*S85+2.663240e+00*S86+1.452156e+00*S87+9.369181e-01*S88+2.398868e+00*S89'
.param V33_part10='V33_part9+(-5.762486e-01)*S90+(-6.006952e-01)*S91+4.639252e-01*S92+(-1.613171e-01)*S93+(-1.023977e+00)*S94+1.262448e+00*S95+5.604639e-02*S96+(-2.419505e-01)*S97+1.699661e+00*S98+4.184666e-01*S99'
.param V33_part11='V33_part10+(-2.051967e-01)*S100+1.751762e+00*S101+3.693362e-03*S102+(-3.036642e-01)*S103+8.891630e-01*S104+1.270806e-02*S105+(-5.372442e-01)*S106+1.263240e+00*S107+4.687073e-02*S108+(-3.004231e-01)*S109'
.param V33_part12='V33_part11+1.209599e-01*S110+1.943996e-01*S111+(-9.844121e-01)*S112+1.461834e+00*S113+(-7.389373e-01)*S114+(-1.265148e+00)*S115+1.183019e+00*S116+(-1.870293e-01)*S117+(-1.007026e+00)*S118+(-9.666781e-01)*S119'
.param V33_part13='V33_part12+(-1.973631e-01)*S120+1.931460e+00*S121+2.500953e+00*S122+(-2.825567e-01)*S123+1.473681e+00*S124+2.540392e+00*S125+4.299304e-02*S126+1.115936e-01*S127+1.792655e+00*S128+(-1.331864e+00)*S129'
.param V33_part14='V33_part13+2.768830e-01*S130+2.292456e-02*S131+(-1.675496e-01)*S132+2.499289e-01*S133+(-9.999835e-01)*S134+7.759423e-01*S135+4.314996e-02*S136+(-3.943532e-01)*S137+7.041126e-02*S138+(-4.038658e-01)*S139'
.param V33_part15='V33_part14+9.124262e-01*S140+6.929959e-03*S141+(-3.233532e-01)*S142+9.776448e-01*S143+1.329823e-01*S144+4.546118e-02*S145+1.484092e+00*S146+9.454559e-02*S147+1.038964e-01*S148+1.333514e+00*S149'
.param V33_part16='V33_part15+(-7.214133e-01)*S150+(-1.409069e+00)*S151+1.613309e+00*S152+(-2.032013e-01)*S153+(-1.214866e+00)*S154+1.770237e+00*S155+(-2.481147e-01)*S156+(-2.708042e-01)*S157+7.865433e-01*S158+(-3.467756e-01)*S159'
.param V33_part17='V33_part16+(-1.923853e-01)*S160+(-8.650888e-01)*S161+(-1.788286e-01)*S162+(-8.209360e-01)*S163+(-1.443654e+00)*S164+6.395816e-01*S165+(-1.152162e+00)*S166+1.051392e+00*S167+(-3.370389e-01)*S168+(-2.051400e-01)*S169'
.param V33_part18='V33_part17+(-1.773028e-01)*S170+(-1.481734e-01)*S171+6.446913e-02*S172+(-5.573700e-02)*S173+(-1.666003e+00)*S174+(-2.574147e-01)*S175+8.164901e-01*S176+7.608874e-01*S177+2.634376e-01*S178+1.156212e+00*S179'
.param V33_part19='V33_part18+(-6.155876e-02)*S180+(-1.432881e+00)*S181+(-2.047773e+00)*S182+(-1.186073e+00)*S183+4.212343e-01*S184+2.084014e-01*S185+(-2.218898e-01)*S186+(-1.231248e+00)*S187+(-2.596916e+00)*S188+(-3.478248e-01)*S189'
.param V33_part20='V33_part19+(-7.643927e-01)*S190+(-3.154159e+00)*S191+(-3.660682e-02)*S192+(-8.139404e-01)*S193+(-1.985589e-01)*S194+2.628860e-01*S195+(-2.892712e-01)*S196+1.347684e+00*S197+1.161640e+00*S198+4.350695e-01*S199'
.param V33_part21='V33_part20+1.497888e+00*S200+(-5.588429e-02)*S201+1.945204e+00*S202+1.443421e+00*S203+(-1.238674e-01)*S204+7.628679e-01*S205+(-5.383660e-01)*S206+3.922512e-01*S207+(-1.188141e+00)*S208+3.605505e-01*S209'
.param V33_part22='V33_part21+(-3.732906e-02)*S210+(-5.393902e-01)*S211+5.629216e-01*S212+(-4.508620e-01)*S213+(-1.323526e-01)*S214+(-1.077919e+00)*S215+(-7.659689e-01)*S216+(-7.560587e-01)*S217+(-1.590442e+00)*S218+5.211595e-02*S219'
.param V33_part23='V33_part22+(-8.631738e-02)*S220+(-1.922562e+00)*S221+(-8.549819e-01)*S222+(-4.778480e-02)*S223+(-4.217540e-01)*S224+(-3.649320e-01)*S225+1.413831e-01*S226+2.027447e+00*S227+(-1.290958e+00)*S228+(-1.776241e-01)*S229'
.param V33_part24='V33_part23+2.687681e-01*S230+(-8.678392e-01)*S231+(-1.731651e-01)*S232+(-7.155916e-01)*S233+(-9.793739e-01)*S234+(-6.868311e-01)*S235+(-1.181291e+00)*S236+(-1.148020e+00)*S237+4.828149e-02*S238+(-1.012788e-01)*S239'
.param V33_part25='V33_part24+(-5.427396e-01)*S240+(-6.957129e-01)*S241+(-2.243216e-01)*S242+(-2.005617e+00)*S243+(-7.478928e-02)*S244+(-7.781967e-01)*S245+(-2.029569e+00)*S246+(-6.351986e-01)*S247+(-9.399980e-01)*S248+(-1.197307e+00)*S249'
.param V33_part26='V33_part25+(-1.239800e+00)*S250+(-5.111889e-01)*S251+(-1.128366e+00)*S252+(-2.676998e-01)*S253+(-5.255333e-01)*S254+(-1.622049e-01)*S255+(-1.673919e+00)*S256+(-2.051163e+00)*S257+(-4.324761e-01)*S258+(-6.957905e-01)*S259'
.param V33_part27='V33_part26+1.619651e+00*S260+5.770974e-01*S261+8.840402e-01*S262+4.924204e-01*S263+6.801486e-01*S264+(-8.400416e-01)*S265+(-5.028821e-01)*S266+8.150320e-01*S267+(-6.359354e-01)*S268+(-1.350942e+00)*S269'
.param V33_part28='V33_part27+1.441434e-01*S270+(-1.358338e-01)*S271+(-2.436458e+00)*S272+1.065244e-01*S273+(-1.924695e-01)*S274+(-2.586247e+00)*S275+(-5.115412e-02)*S276+(-6.818706e-01)*S277+(-2.373580e+00)*S278+(-2.226247e-01)*S279'
.param V33_part29='V33_part28+(-1.171894e-01)*S280+(-2.642553e+00)*S281+1.366681e-01*S282+(-3.471642e-01)*S283+(-2.014032e+00)*S284+5.614884e-01*S285+(-2.716137e-01)*S286+5.675158e-02*S287+4.299762e-01*S288+(-1.019196e-01)*S289'
.param V33_part30='V33_part29+9.499488e-01*S290+(-3.693624e-02)*S291+(-1.269296e-01)*S292+1.554853e+00*S293+5.971666e-02*S294+4.568325e-01*S295+1.761762e+00*S296+3.970574e-01*S297+3.656817e-01*S298+1.784243e+00*S299'
.param V33_part31='V33_part30+4.362788e-01*S300+5.461549e-01*S301+1.128043e+00*S302+6.331646e-01*S303+5.880232e-01*S304+(-1.195880e+00)*S305+8.131677e-01*S306+8.635255e-01*S307+(-1.876204e+00)*S308+9.092404e-01*S309'
.param V33='V33_part31+7.433968e-01*S310+(-2.071224e+00)*S311+5.140674e-01*S312+9.639396e-01*S313+(-2.268919e+00)*S314'
.param V34_part1='3.598584e-02*S0+(-2.064878e-02)*S1+(-1.436955e-04)*S2+(-4.448981e-03)*S3+2.582139e-04*S4+(-2.863520e-03)*S5+2.471141e-05*S6+1.664476e-05*S7+2.663351e-06*S8+(-1.276186e-02)*S9'
.param V34_part2='V34_part1+8.085930e-03*S10+(-1.434364e-05)*S11+(-2.696473e-02)*S12+(-5.265850e-06)*S13+1.051338e-05*S14+4.253122e-02*S15+2.318530e-02*S16+2.060284e-03*S17+2.494668e-02*S18+(-1.007012e-02)*S19'
.param V34_part3='V34_part2+(-2.359275e-03)*S20+2.291922e-03*S21+(-6.812769e-03)*S22+4.600572e-03*S23+(-6.958227e-04)*S24+(-4.309101e-03)*S25+(-2.857043e-02)*S26+(-8.870006e-04)*S27+(-1.355326e-03)*S28+1.809780e-02*S29'
.param V34_part4='V34_part3+5.295792e-02*S30+(-6.751125e-03)*S31+7.760662e-02*S32+(-1.454105e-01)*S33+1.273180e-02*S34+1.348585e-01*S35+(-3.221114e-01)*S36+(-5.394136e-01)*S37+2.496053e-02*S38+(-2.809084e-02)*S39'
.param V34_part5='V34_part4+5.934356e-02*S40+1.274990e-01*S41+(-1.473430e-02)*S42+9.547681e-02*S43+1.448613e-01*S44+(-7.806773e-03)*S45+(-7.937897e-02)*S46+(-2.616528e-01)*S47+(-5.256926e-01)*S48+(-2.979043e-01)*S49'
.param V34_part6='V34_part5+(-6.471717e-01)*S50+(-8.257916e-01)*S51+(-8.616053e-01)*S52+(-9.665876e-01)*S53+(-1.828035e+00)*S54+2.713234e-01*S55+(-8.839435e-01)*S56+(-1.221081e+00)*S57+(-1.335805e+00)*S58+(-1.667527e-01)*S59'
.param V34_part7='V34_part6+(-3.895650e-01)*S60+(-3.809671e-01)*S61+(-3.919593e-01)*S62+(-6.038430e-01)*S63+(-7.285615e-01)*S64+(-6.494033e-01)*S65+(-9.200141e-01)*S66+(-7.953518e-01)*S67+(-1.047484e+00)*S68+(-1.152249e+00)*S69'
.param V34_part8='V34_part7+(-1.029994e+00)*S70+(-1.387550e+00)*S71+(-1.285198e+00)*S72+(-1.348978e+00)*S73+4.794262e-01*S74+9.377871e-02*S75+6.628003e-02*S76+(-1.928845e-02)*S77+6.926376e-02*S78+(-9.797211e-02)*S79'
.param V34_part9='V34_part8+(-2.552117e-01)*S80+(-1.662995e-01)*S81+(-2.081188e-02)*S82+(-2.419851e-01)*S83+(-3.929326e-01)*S84+(-3.044419e-01)*S85+(-3.780345e-01)*S86+(-6.469372e-01)*S87+(-2.942878e-01)*S88+(-4.504075e-01)*S89'
.param V34_part10='V34_part9+(-4.672089e-01)*S90+(-3.978882e-01)*S91+6.325594e-01*S92+(-7.146053e-01)*S93+(-7.271762e-01)*S94+8.082403e-01*S95+(-8.499468e-01)*S96+5.632673e-01*S97+9.037181e-01*S98+(-1.082918e+00)*S99'
.param V34_part11='V34_part10+(-1.268395e+00)*S100+9.716664e-01*S101+(-1.257411e+00)*S102+(-1.470367e+00)*S103+(-4.670873e-01)*S104+(-5.347195e-01)*S105+(-7.205436e-01)*S106+5.674505e-01*S107+(-6.886114e-01)*S108+(-6.732626e-01)*S109'
.param V34_part12='V34_part11+4.298756e-01*S110+(-7.924562e-01)*S111+(-8.708748e-01)*S112+7.341246e-01*S113+(-8.344614e-01)*S114+(-9.953812e-01)*S115+7.800169e-01*S116+(-1.133679e+00)*S117+(-1.029546e+00)*S118+(-2.164329e+00)*S119'
.param V34_part13='V34_part12+(-2.794885e-01)*S120+4.274293e-01*S121+8.000176e-01*S122+(-2.717672e-01)*S123+4.940136e-01*S124+8.692346e-01*S125+(-5.335012e-01)*S126+(-9.990606e-01)*S127+8.199074e-01*S128+(-7.624490e-01)*S129'
.param V34_part14='V34_part13+(-1.278261e+00)*S130+(-1.362646e+00)*S131+(-9.054243e-01)*S132+(-1.323078e+00)*S133+(-1.809021e+00)*S134+(-6.693351e-01)*S135+(-2.222918e-01)*S136+1.732034e-01*S137+5.748969e-01*S138+4.544124e-01*S139'
.param V34_part15='V34_part14+4.678501e-01*S140+4.312928e-01*S141+6.290320e-01*S142+6.395771e-01*S143+4.294625e-01*S144+4.706788e-01*S145+6.459214e-01*S146+4.952077e-01*S147+4.920602e-01*S148+8.312272e-01*S149'
.param V34_part16='V34_part15+5.843102e-01*S150+(-3.287532e-01)*S151+1.474253e+00*S152+(-5.521951e-01)*S153+(-8.314236e-01)*S154+1.721220e+00*S155+(-4.766406e-01)*S156+(-7.952938e-01)*S157+1.099452e+00*S158+(-7.064188e-01)*S159'
.param V34_part17='V34_part16+(-6.794323e-01)*S160+(-1.167271e+00)*S161+(-6.072686e-01)*S162+(-8.243056e-01)*S163+(-1.396622e+00)*S164+8.197637e-01*S165+4.531502e-01*S166+6.210033e-01*S167+(-4.779497e-01)*S168+(-7.027139e-01)*S169'
.param V34_part18='V34_part17+4.626749e-01*S170+(-1.013706e+00)*S171+(-7.328223e-01)*S172+(-1.187686e+00)*S173+(-8.082462e-01)*S174+(-1.020136e+00)*S175+(-1.388501e+00)*S176+(-6.308356e-01)*S177+(-6.867848e-01)*S178+(-1.798225e+00)*S179'
.param V34_part19='V34_part18+1.201049e-01*S180+(-8.789557e-01)*S181+1.224965e+00*S182+(-3.744835e-01)*S183+(-5.357491e-01)*S184+1.492002e+00*S185+(-5.270492e-01)*S186+(-6.895039e-01)*S187+(-6.880494e-01)*S188+(-5.183629e-01)*S189'
.param V34_part20='V34_part19+(-8.672839e-01)*S190+(-1.219841e+00)*S191+(-8.051560e-01)*S192+(-9.178442e-01)*S193+(-1.658776e+00)*S194+(-7.628155e-01)*S195+6.246611e-01*S196+1.205219e+00*S197+4.705072e-01*S198+1.123048e+00*S199'
.param V34_part21='V34_part20+1.360739e+00*S200+7.553547e-01*S201+8.855403e-01*S202+1.464688e+00*S203+9.314559e-01*S204+3.574904e-01*S205+(-1.400767e+00)*S206+(-1.450290e+00)*S207+(-9.411496e-01)*S208+(-2.063437e+00)*S209'
.param V34_part22='V34_part21+1.039047e-02*S210+(-1.796717e-01)*S211+2.612392e+00*S212+(-6.511514e-01)*S213+(-3.375326e-01)*S214+5.310377e-02*S215+(-3.454879e-01)*S216+(-1.374841e-01)*S217+(-5.704829e-01)*S218+7.333274e-01*S219'
.param V34_part23='V34_part22+(-5.499752e-01)*S220+(-5.045917e-01)*S221+(-3.270152e-01)*S222+(-7.039165e-01)*S223+(-8.053695e-01)*S224+(-1.272035e-02)*S225+(-4.026304e-01)*S226+3.095856e-01*S227+2.248043e-01*S228+(-5.145826e-01)*S229'
.param V34_part24='V34_part23+1.826139e+00*S230+(-9.561608e-02)*S231+(-7.258109e-01)*S232+1.699108e+00*S233+1.626937e-01*S234+1.089592e+00*S235+1.854526e+00*S236+(-1.706510e-01)*S237+(-7.445082e-01)*S238+(-1.042427e+00)*S239'
.param V34_part25='V34_part24+2.772930e-02*S240+(-4.451475e-02)*S241+2.674558e-01*S242+3.611362e-01*S243+6.978105e-01*S244+1.994221e+00*S245+(-1.960191e-03)*S246+(-4.918255e-01)*S247+1.809561e+00*S248+3.932208e-02*S249'
.param V34_part26='V34_part25+(-1.818821e-01)*S250+1.682911e+00*S251+2.627906e-02*S252+(-6.168112e-01)*S253+1.663575e+00*S254+1.740743e+00*S255+1.560477e+00*S256+6.565386e-01*S257+9.181167e-01*S258+5.895699e-01*S259'
.param V34_part27='V34_part26+(-1.170170e+00)*S260+(-6.546218e-01)*S261+(-9.149262e-01)*S262+7.932401e-01*S263+(-9.873249e-01)*S264+6.971522e-01*S265+7.957737e-01*S266+(-1.225081e+00)*S267+8.017181e-01*S268+6.063888e-01*S269'
.param V34_part28='V34_part27+1.124932e+00*S270+6.492532e-01*S271+2.825878e-01*S272+8.451925e-01*S273+2.539655e-02*S274+5.461598e-01*S275+6.359496e-01*S276+8.067842e-01*S277+1.175890e+00*S278+1.433369e-01*S279'
.param V34_part29='V34_part28+(-6.345809e-01)*S280+2.134288e+00*S281+1.899429e+00*S282+(-4.072240e-01)*S283+2.042264e+00*S284+7.371603e-01*S285+7.914091e-01*S286+1.528128e-01*S287+(-1.037532e-01)*S288+8.252044e-01*S289'
.param V34_part30='V34_part29+(-9.646383e-01)*S290+2.843971e-01*S291+(-1.454207e-01)*S292+(-4.432460e-01)*S293+2.005672e-01*S294+(-2.240620e-01)*S295+(-5.240660e-01)*S296+(-1.547096e-01)*S297+(-2.753637e-01)*S298+(-3.591125e-01)*S299'
.param V34_part31='V34_part30+(-5.729357e-01)*S300+(-3.227403e-01)*S301+(-6.597693e-01)*S302+(-3.623169e-01)*S303+(-5.953233e-01)*S304+9.053478e-01*S305+(-3.107951e-01)*S306+(-9.360069e-01)*S307+9.911183e-01*S308+(-4.799656e-01)*S309'
.param V34='V34_part31+(-9.411518e-01)*S310+2.038756e+00*S311+(-8.667196e-01)*S312+(-7.597079e-01)*S313+2.072496e+00*S314'
.param V35_part1='4.333760e-01*S0+(-8.979205e+02)*S1+1.344272e+01*S2+(-9.045082e+01)*S3+2.192501e+01*S4+2.171462e+01*S5+1.704092e+01*S6+2.207037e+01*S7+2.538091e+01*S8+3.279784e+01*S9'
.param V35_part2='V35_part1+5.658674e+01*S10+4.923415e+01*S11+1.233136e+01*S12+3.490239e+01*S13+3.867638e+01*S14+5.921403e+01*S15+1.621767e+01*S16+2.276461e+01*S17+2.109344e+01*S18+8.924424e+00*S19'
.param V35_part3='V35_part2+2.251441e+01*S20+3.817665e+00*S21+1.172336e+01*S22+2.277953e+03*S23+2.345697e+00*S24+3.270309e+01*S25+1.684395e+01*S26+2.273065e+00*S27+3.460036e+00*S28+5.194610e+00*S29'
.param V35_part4='V35_part3+5.630724e+00*S30+9.235059e+00*S31+4.838897e+00*S32+7.186224e+00*S33+5.848820e+00*S34+5.628115e+00*S35+7.049404e+00*S36+1.676690e+01*S37+1.058952e+01*S38+1.251820e+01*S39'
.param V35_part5='V35_part4+1.463716e+01*S40+1.094582e+01*S41+1.320205e+01*S42+9.383601e+00*S43+9.330522e+00*S44+(-1.714326e+01)*S45+(-3.217731e+01)*S46+1.623747e+03*S47+2.326720e+01*S48+1.005356e+01*S49'
.param V35_part6='V35_part5+1.254609e+01*S50+2.653510e+03*S51+8.089754e+00*S52+5.634000e+00*S53+3.408581e+01*S54+1.253118e+01*S55+9.331415e+00*S56+6.373214e+00*S57+5.997881e+00*S58+6.348518e+00*S59'
.param V35_part7='V35_part6+1.571276e+01*S60+1.085437e+01*S61+3.056692e+00*S62+1.195285e+01*S63+7.324472e+00*S64+2.852391e+00*S65+2.977621e+01*S66+1.163622e+01*S67+3.529226e+00*S68+3.028130e+01*S69'
.param V35_part8='V35_part7+7.660963e+00*S70+2.271623e+01*S71+1.212562e+01*S72+8.552321e+00*S73+5.974192e+00*S74+1.100999e+01*S75+8.885960e+00*S76+2.761450e+01*S77+7.545911e+00*S78+8.523335e+00*S79'
.param V35_part9='V35_part8+6.516483e+01*S80+1.215996e+01*S81+2.126645e+01*S82+2.237480e+01*S83+1.005640e+01*S84+1.064170e+01*S85+1.515035e+01*S86+8.392559e+00*S87+9.725482e+00*S88+1.226042e+01*S89'
.param V35_part10='V35_part9+1.000984e+01*S90+4.800530e+00*S91+7.610606e+03*S92+1.368589e+01*S93+4.575917e+00*S94+1.970107e+02*S95+1.570012e+01*S96+7.631717e+00*S97+3.438103e+00*S98+9.449238e+00*S99'
.param V35_part11='V35_part10+1.150061e+01*S100+5.352169e+00*S101+8.325660e+00*S102+7.758144e+00*S103+1.240870e+03*S104+1.085291e+01*S105+7.492749e+00*S106+5.634982e+00*S107+9.133562e+00*S108+7.632479e+00*S109'
.param V35_part12='V35_part11+4.169741e+00*S110+5.217042e+00*S111+5.783982e+00*S112+4.635000e+00*S113+6.182007e+00*S114+5.629356e+00*S115+5.079727e+00*S116+2.443060e+03*S117+4.665772e+00*S118+3.080362e+00*S119'
.param V35_part13='V35_part12+5.249645e+00*S120+5.757156e+00*S121+5.040123e+00*S122+3.120728e+00*S123+5.377617e+00*S124+4.375230e+00*S125+8.054679e+00*S126+1.937606e+01*S127+4.423457e+00*S128+6.177058e+00*S129'
.param V35_part14='V35_part13+2.502445e+03*S130+2.503388e+03*S131+3.271223e+00*S132+2.500870e+03*S133+4.315192e+00*S134+9.097587e+00*S135+1.138724e+01*S136+8.238702e+00*S137+8.688739e+00*S138+8.527990e+00*S139'
.param V35_part15='V35_part14+6.676852e+00*S140+8.015954e+00*S141+6.103887e+00*S142+5.459787e+00*S143+7.111179e+00*S144+6.289325e+00*S145+5.502165e+00*S146+5.718821e+00*S147+6.180047e+00*S148+5.502998e+00*S149'
.param V35_part16='V35_part15+7.510971e+03*S150+7.512865e+03*S151+1.743631e+03*S152+1.603607e+02*S153+7.516955e+03*S154+1.160887e+02*S155+1.541582e+02*S156+1.768528e+02*S157+2.506279e+03*S158+3.590597e+00*S159'
.param V35_part17='V35_part16+2.504254e+03*S160+7.855484e+00*S161+1.742195e+01*S162+5.058872e+00*S163+6.478329e+00*S164+5.652210e+02*S165+4.811714e+00*S166+3.201382e+02*S167+2.523996e+03*S168+2.884041e+02*S169'
.param V35_part18='V35_part17+3.103014e+00*S170+4.367930e+00*S171+7.544715e+03*S172+2.565985e+00*S173+6.211008e+00*S174+3.299415e+00*S175+2.858428e+00*S176+7.523164e+03*S177+3.122784e+00*S178+2.841212e+00*S179'
.param V35_part19='V35_part18+6.136447e+00*S180+4.095959e+00*S181+3.239259e+00*S182+5.462543e+00*S183+1.063791e+01*S184+3.298427e+00*S185+3.816649e+00*S186+4.463627e+00*S187+4.619207e+00*S188+2.598705e+00*S189'
.param V35_part20='V35_part19+3.942744e+00*S190+3.893153e+00*S191+2.662304e+00*S192+3.464567e+00*S193+2.772617e+00*S194+1.087193e+02*S195+7.876205e+00*S196+5.804674e+00*S197+7.176786e+00*S198+5.766039e+00*S199'
.param V35_part21='V35_part20+5.385066e+00*S200+7.610025e+00*S201+6.261772e+00*S202+4.713325e+00*S203+6.502665e+00*S204+5.982323e+00*S205+4.082487e+00*S206+5.377105e+00*S207+5.123352e+00*S208+3.923074e+00*S209'
.param V35_part22='V35_part21+5.737220e+00*S210+2.512249e+03*S211+3.179691e+00*S212+3.678066e+00*S213+2.507184e+03*S214+3.258958e+00*S215+2.155230e+02*S216+5.212313e+00*S217+4.441474e+00*S218+2.991563e+00*S219'
.param V35_part23='V35_part22+2.508241e+00*S220+3.944890e+00*S221+4.770442e+00*S222+2.162877e+00*S223+2.099242e+00*S224+4.642892e+00*S225+2.503849e+03*S226+2.505156e+03*S227+7.121313e+00*S228+4.685436e+00*S229'
.param V35_part24='V35_part23+2.482221e+00*S230+6.854837e+00*S231+2.741700e+00*S232+1.927984e+00*S233+6.005316e+00*S234+2.130357e+00*S235+1.788079e+00*S236+5.396700e+00*S237+2.329991e+00*S238+1.829695e+00*S239'
.param V35_part25='V35_part24+4.148956e+00*S240+2.509084e+03*S241+3.172922e+00*S242+6.669236e+00*S243+3.078999e+00*S244+2.138504e+00*S245+6.945250e+00*S246+3.620719e+00*S247+1.730787e+00*S248+6.315350e+00*S249'
.param V35_part26='V35_part25+5.231175e+00*S250+1.150738e+00*S251+5.226912e+00*S252+2.257133e+00*S253+1.187516e+00*S254+7.921434e+00*S255+5.391687e+00*S256+2.905727e+00*S257+6.650509e+00*S258+4.833916e+00*S259'
.param V35_part27='V35_part26+5.644587e+00*S260+3.590810e+00*S261+3.462018e+00*S262+2.448328e+00*S263+3.007779e+00*S264+2.405445e+00*S265+1.975371e+00*S266+2.674427e+00*S267+1.974131e+00*S268+2.157081e+00*S269'
.param V35_part28='V35_part27+4.611469e+00*S270+3.382566e+00*S271+2.613397e+00*S272+3.430353e+00*S273+2.565168e+00*S274+2.215259e+00*S275+3.341697e+00*S276+2.370972e+00*S277+2.032729e+00*S278+2.729391e+00*S279'
.param V35_part29='V35_part28+2.744593e+00*S280+1.698191e+00*S281+1.534086e+00*S282+2.130892e+00*S283+1.732588e+00*S284+4.842170e+00*S285+3.288724e+00*S286+2.404337e+00*S287+4.429899e+00*S288+2.664418e+00*S289'
.param V35_part30='V35_part29+2.650927e+00*S290+2.976052e+00*S291+2.506227e+00*S292+2.595483e+00*S293+2.768189e+00*S294+2.416715e+00*S295+2.554473e+00*S296+2.671210e+00*S297+2.030642e+00*S298+2.738065e+00*S299'
.param V35_part31='V35_part30+4.843328e+00*S300+5.858075e+00*S301+2.761720e+00*S302+3.943479e+00*S303+3.311221e+00*S304+2.745206e+00*S305+3.888460e+00*S306+2.999800e+00*S307+2.354076e+00*S308+2.743492e+00*S309'
.param V35='V35_part31+2.782487e+00*S310+1.680922e+00*S311+2.931590e+00*S312+2.268387e+00*S313+1.900030e+00*S314'
.param V36_part1='6.089634e+01*S0+1.000000e+04*S1+2.505073e+01*S2+5.313287e+02*S3+(-4.761317e+00)*S4+(-5.826170e+00)*S5+(-4.471812e+00)*S6+(-1.485868e+00)*S7+1.625422e+01*S8+(-2.419693e+01)*S9'
.param V36_part2='V36_part1+(-7.977656e+00)*S10+(-3.407000e+00)*S11+2.030033e+00*S12+(-3.528695e+00)*S13+3.049719e+00*S14+(-7.755236e+01)*S15+(-4.752980e+00)*S16+(-1.920643e+01)*S17+(-2.875477e+01)*S18+(-2.039259e+01)*S19'
.param V36_part3='V36_part2+(-1.412787e+01)*S20+1.808682e-01*S21+(-6.769995e+00)*S22+(-2.097121e+02)*S23+7.856619e-01*S24+(-1.785821e+01)*S25+(-8.339506e+00)*S26+9.570081e-02*S27+5.804973e-02*S28+(-1.737074e+00)*S29'
.param V36_part4='V36_part3+1.286561e+00*S30+(-1.104083e+01)*S31+(-3.412171e+00)*S32+(-6.267817e+00)*S33+(-3.388092e+00)*S34+(-3.046944e+00)*S35+(-3.456633e+00)*S36+(-7.111990e+00)*S37+(-4.160126e+00)*S38+(-4.146731e+00)*S39'
.param V36_part5='V36_part4+(-5.729958e+00)*S40+(-3.344837e+00)*S41+(-5.926691e+00)*S42+(-2.200121e+00)*S43+(-2.671545e+00)*S44+6.505305e+01*S45+6.792626e+01*S46+(-2.813580e+01)*S47+(-3.353256e+00)*S48+(-7.567362e+00)*S49'
.param V36_part6='V36_part5+(-6.420797e+00)*S50+(-2.042029e+01)*S51+(-4.404591e+00)*S52+(-2.378453e+00)*S53+(-4.950507e+00)*S54+(-4.408520e+00)*S55+(-2.636696e+00)*S56+(-2.172702e+00)*S57+(-2.139037e+00)*S58+(-3.358693e-01)*S59'
.param V36_part7='V36_part6+(-1.402375e+01)*S60+(-1.222278e+01)*S61+(-1.416069e+00)*S62+(-5.440967e+00)*S63+(-5.715132e+00)*S64+(-1.161058e+00)*S65+(-7.742765e+00)*S66+(-8.573776e+00)*S67+(-1.036750e+00)*S68+(-7.006223e+00)*S69'
.param V36_part8='V36_part7+(-3.151726e+00)*S70+(-3.609299e+00)*S71+(-2.871910e+00)*S72+(-2.219526e+00)*S73+(-1.260520e+00)*S74+(-1.077568e+01)*S75+(-9.196762e+00)*S76+(-3.038851e+01)*S77+(-3.981664e+00)*S78+(-5.901904e+00)*S79'
.param V36_part9='V36_part8+(-5.202345e+01)*S80+(-7.934309e+00)*S81+(-1.833099e+01)*S82+(-1.155453e+01)*S83+(-3.666311e+00)*S84+(-4.689984e+00)*S85+(-6.358012e+00)*S86+(-1.799402e+00)*S87+(-3.648009e+00)*S88+(-3.690522e+00)*S89'
.param V36_part10='V36_part9+(-5.645499e+00)*S90+(-4.399964e+00)*S91+(-4.791072e+01)*S92+(-5.872658e+00)*S93+(-2.801098e+00)*S94+6.769870e-01*S95+(-5.102614e+00)*S96+(-3.268307e+00)*S97+(-5.175540e-01)*S98+(-2.501591e+00)*S99'
.param V36_part11='V36_part10+(-3.961865e+00)*S100+(-6.873962e-01)*S101+(-2.843393e+00)*S102+(-2.110244e+00)*S103+(-9.502896e-01)*S104+(-4.658501e+00)*S105+(-4.298818e+00)*S106+(-1.529440e+00)*S107+(-3.095326e+00)*S108+(-1.795308e+00)*S109'
.param V36_part12='V36_part11+(-5.798021e-01)*S110+(-2.146366e+00)*S111+(-1.946640e+00)*S112+(-6.372486e-01)*S113+(-2.114960e+00)*S114+(-2.048283e+00)*S115+(-7.770199e-01)*S116+1.646814e-01*S117+(-1.388053e+00)*S118+(-8.263124e-01)*S119'
.param V36_part13='V36_part12+(-1.679591e+00)*S120+(-1.832885e+00)*S121+(-1.353615e+00)*S122+(-1.521992e+00)*S123+(-9.105307e-01)*S124+(-6.929070e-01)*S125+(-1.314079e+00)*S126+(-4.486050e+00)*S127+(-6.306742e-01)*S128+(-1.705050e+00)*S129'
.param V36_part14='V36_part13+2.876870e+00*S130+(-1.540751e+00)*S131+(-1.072210e+00)*S132+1.032281e+00*S133+(-1.136610e+00)*S134+(-1.321668e+00)*S135+(-8.125134e+00)*S136+(-2.647241e+00)*S137+2.553929e+00*S138+(-1.762505e+00)*S139'
.param V36_part15='V36_part14+(-1.741169e+00)*S140+(-1.745936e+00)*S141+(-2.817007e-01)*S142+(-1.157968e+00)*S143+(-1.556591e+00)*S144+(-2.011200e+00)*S145+(-9.912149e-01)*S146+(-1.535309e+00)*S147+(-1.711423e+00)*S148+(-1.098748e+00)*S149'
.param V36_part16='V36_part15+7.002825e+00*S150+1.065992e+00*S151+9.002191e+00*S152+(-8.934516e+00)*S153+(-1.329938e+00)*S154+3.843843e+00*S155+4.026022e-01*S156+(-4.993110e+00)*S157+(-2.911929e+00)*S158+(-1.129602e+00)*S159'
.param V36_part17='V36_part16+(-2.451438e+00)*S160+(-1.975914e+00)*S161+6.232734e-02*S162+(-1.345247e+00)*S163+(-1.394823e+00)*S164+(-1.564302e+01)*S165+(-1.994128e+00)*S166+2.065343e+00*S167+(-1.679563e+01)*S168+3.248858e-01*S169'
.param V36_part18='V36_part17+(-9.647958e-02)*S170+(-1.595547e+00)*S171+(-1.155797e+01)*S172+(-3.988853e-01)*S173+(-2.350097e+00)*S174+(-1.014123e+00)*S175+(-3.557621e-01)*S176+(-3.929477e+00)*S177+(-8.304953e-01)*S178+(-3.916600e-01)*S179'
.param V36_part19='V36_part18+(-4.028636e-01)*S180+(-2.262159e+00)*S181+3.822546e-01*S182+(-1.396065e+00)*S183+(-1.509177e+00)*S184+(-3.294018e-01)*S185+(-1.595374e+00)*S186+(-1.506141e+00)*S187+(-8.169427e-01)*S188+(-8.146416e-01)*S189'
.param V36_part20='V36_part19+(-1.166004e+00)*S190+(-6.097773e-01)*S191+(-6.172845e-01)*S192+(-8.829903e-01)*S193+(-4.372910e-01)*S194+(-1.890659e+01)*S195+(-1.771015e+00)*S196+(-1.820691e+00)*S197+(-3.339194e-01)*S198+(-1.064774e-01)*S199'
.param V36_part21='V36_part20+(-1.282306e+00)*S200+(-1.719532e+00)*S201+(-1.782595e+00)*S202+(-1.170698e+00)*S203+(-2.004998e+00)*S204+(-1.839385e+00)*S205+(-5.971678e-01)*S206+(-1.962846e+00)*S207+(-1.478641e+00)*S208+(-7.413257e-01)*S209'
.param V36_part22='V36_part21+(-2.018608e+00)*S210+(-1.397224e-01)*S211+(-7.859518e-01)*S212+(-1.329503e+00)*S213+(-1.166042e+00)*S214+(-8.301310e-01)*S215+2.373424e+01*S216+(-1.682100e+00)*S217+(-7.120133e-01)*S218+(-7.037395e-01)*S219'
.param V36_part23='V36_part22+(-7.917585e-01)*S220+(-5.097949e-01)*S221+(-1.278690e+00)*S222+(-5.945152e-01)*S223+(-5.035757e-01)*S224+(-1.673336e+00)*S225+9.173075e+00*S226+(-7.137201e-01)*S227+(-3.067122e+00)*S228+(-1.805194e+00)*S229'
.param V36_part24='V36_part23+(-9.134569e-01)*S230+(-2.178384e+00)*S231+(-1.046587e+00)*S232+(-5.452629e-01)*S233+(-1.861107e+00)*S234+(-7.497202e-01)*S235+(-5.487007e-01)*S236+(-1.710742e+00)*S237+(-5.082339e-01)*S238+(-4.672562e-01)*S239'
.param V36_part25='V36_part24+(-1.533575e+00)*S240+3.133753e+00*S241+(-9.405551e-01)*S242+(-2.656894e+00)*S243+(-1.231341e+00)*S244+(-5.913127e-01)*S245+(-2.376797e+00)*S246+(-1.133921e+00)*S247+(-4.049499e-01)*S248+(-1.851796e+00)*S249'
.param V36_part26='V36_part25+(-1.425385e+00)*S250+(-3.098820e-01)*S251+(-1.440571e+00)*S252+(-7.425830e-01)*S253+(-3.276507e-01)*S254+(-5.619897e-01)*S255+6.067808e-02*S256+(-2.703119e-01)*S257+(-1.067334e+00)*S258+(-5.825872e-01)*S259'
.param V36_part27='V36_part26+(-9.640057e-01)*S260+(-1.317429e+00)*S261+(-9.306891e-01)*S262+(-7.701414e-01)*S263+(-6.643936e-01)*S264+(-9.378090e-01)*S265+(-5.277218e-01)*S266+(-6.050451e-01)*S267+(-7.778600e-01)*S268+(-4.659768e-01)*S269'
.param V36_part28='V36_part27+(-2.954048e+00)*S270+(-1.230775e+00)*S271+(-6.849105e-01)*S272+(-1.936537e+00)*S273+(-1.051059e+00)*S274+(-3.398802e-01)*S275+(-1.668171e+00)*S276+(-1.119067e+00)*S277+(-3.062875e-01)*S278+(-1.047222e+00)*S279'
.param V36_part29='V36_part28+(-5.039030e-01)*S280+(-1.629854e-01)*S281+(-7.929364e-02)*S282+(-6.633353e-01)*S283+(-2.374037e-01)*S284+(-3.061411e+00)*S285+(-1.017761e+00)*S286+(-6.638772e-01)*S287+(-1.593381e+00)*S288+(-1.138441e+00)*S289'
.param V36_part30='V36_part29+(-5.267453e-01)*S290+(-1.309315e+00)*S291+(-9.193400e-01)*S292+(-2.305420e-01)*S293+(-1.094971e+00)*S294+(-7.449389e-01)*S295+(-2.376824e-01)*S296+(-4.437112e-01)*S297+(-5.331828e-01)*S298+(-2.813642e-01)*S299'
.param V36_part31='V36_part30+(-2.428757e+00)*S300+(-2.206177e+00)*S301+(-8.198508e-01)*S302+(-1.540918e+00)*S303+(-1.259653e+00)*S304+(-7.477347e-01)*S305+(-1.370999e+00)*S306+(-6.810259e-01)*S307+(-4.009927e-01)*S308+(-9.893456e-01)*S309'
.param V36='V36_part31+(-5.745135e-01)*S310+(-2.210617e-01)*S311+(-6.357364e-01)*S312+(-6.879688e-01)*S313+(-2.869144e-01)*S314'
.param V37_part1='2.618007e+00*S0+(-1.207706e+03)*S1+5.208007e-01*S2+(-1.043702e+01)*S3+1.202783e+00*S4+6.500263e+00*S5+(-5.254253e-01)*S6+2.572362e+00*S7+6.000155e-01*S8+3.478413e+01*S9'
.param V37_part2='V37_part1+1.856742e+01*S10+(-6.676983e+00)*S11+6.782315e+01*S12+(-1.580120e+01)*S13+(-7.729594e+00)*S14+7.323647e+01*S15+5.175811e+01*S16+(-5.578872e+00)*S17+(-3.076866e-01)*S18+4.337403e+01*S19'
.param V37_part3='V37_part2+(-5.845660e+00)*S20+(-1.224685e+00)*S21+8.744694e+00*S22+4.775231e+02*S23+(-6.757932e-01)*S24+(-8.349926e+00)*S25+2.196455e+00*S26+(-4.669493e-01)*S27+(-1.269132e+00)*S28+6.489512e-01*S29'
.param V37_part4='V37_part3+(-5.540502e+00)*S30+(-3.710948e+00)*S31+(-1.204783e+00)*S32+(-1.737470e+00)*S33+(-1.988617e+00)*S34+(-7.494835e-01)*S35+(-4.194698e+00)*S36+(-9.423117e+00)*S37+(-4.002286e+00)*S38+(-1.031055e+01)*S39'
.param V37_part5='V37_part4+(-7.534193e+00)*S40+(-4.144899e+00)*S41+(-5.488892e+00)*S42+(-4.926526e+00)*S43+(-3.359583e+00)*S44+5.681148e+01*S45+1.069290e+02*S46+9.593657e+00*S47+(-2.815843e+01)*S48+(-4.558927e+00)*S49'
.param V37_part6='V37_part5+(-5.682335e+00)*S50+(-8.742428e+01)*S51+(-3.741407e+00)*S52+(-1.824464e+00)*S53+(-3.115690e+01)*S54+(-6.628797e+00)*S55+(-4.112307e+00)*S56+(-3.379275e+00)*S57+(-2.232785e+00)*S58+3.080563e+00*S59'
.param V37_part7='V37_part6+(-1.252579e+01)*S60+(-4.845894e+00)*S61+(-9.629903e-01)*S62+(-7.985621e+00)*S63+(-3.158095e+00)*S64+(-6.674012e-01)*S65+(-1.291638e+01)*S66+3.208955e+00*S67+(-1.076292e+00)*S68+(-1.310356e+01)*S69'
.param V37_part8='V37_part7+3.852633e+00*S70+(-9.772080e+00)*S71+(-5.229949e+00)*S72+(-3.745861e+00)*S73+(-2.221249e+00)*S74+(-8.096136e+00)*S75+(-3.682759e+00)*S76+(-3.785998e+00)*S77+(-3.191986e+00)*S78+(-3.435224e+00)*S79'
.param V37_part9='V37_part8+(-2.152893e+01)*S80+(-1.888069e+00)*S81+(-4.957162e+00)*S82+(-6.452039e+00)*S83+(-2.931236e+00)*S84+(-3.180249e+00)*S85+(-4.939325e+00)*S86+(-4.947644e+00)*S87+(-2.593791e+00)*S88+(-4.164524e+00)*S89'
.param V37_part10='V37_part9+(-9.508045e+00)*S90+(-1.573738e+00)*S91+(-7.380336e+01)*S92+(-1.127652e+01)*S93+(-1.393813e+00)*S94+3.427473e+00*S95+(-1.467027e+01)*S96+(-4.138213e+00)*S97+(-4.072337e-01)*S98+(-8.438398e+00)*S99'
.param V37_part11='V37_part10+(-6.633062e+00)*S100+4.721117e-01*S101+(-4.430923e+00)*S102+(-4.502593e+00)*S103+1.097793e+01*S104+(-1.164758e+01)*S105+(-5.277830e+00)*S106+(-2.550526e+00)*S107+(-9.102051e+00)*S108+(-4.591979e+00)*S109'
.param V37_part12='V37_part11+(-1.927411e+00)*S110+(-3.114816e+00)*S111+(-3.343809e+00)*S112+(-2.134126e+00)*S113+(-5.001120e+00)*S114+(-3.142745e+00)*S115+(-2.330127e+00)*S116+6.453904e+00*S117+(-2.377629e+00)*S118+(-8.511510e-01)*S119'
.param V37_part13='V37_part12+(-4.157087e+00)*S120+(-3.462220e+00)*S121+(-2.362549e+00)*S122+(-2.259198e+00)*S123+(-3.400113e+00)*S124+(-1.952274e+00)*S125+(-6.577023e-01)*S126+4.075959e+00*S127+(-1.921867e+00)*S128+(-5.878612e+00)*S129'
.param V37_part14='V37_part13+1.425316e+01*S130+8.770426e+00*S131+(-1.730314e+00)*S132+1.351362e+01*S133+(-1.514445e+00)*S134+(-1.088886e+01)*S135+(-5.045352e+00)*S136+(-3.826887e+00)*S137+(-1.151226e+01)*S138+(-5.592869e+00)*S139'
.param V37_part15='V37_part14+(-2.643103e+00)*S140+(-7.354635e+00)*S141+(-3.699859e+00)*S142+(-1.975127e+00)*S143+(-6.039772e+00)*S144+(-2.753926e+00)*S145+(-2.085742e+00)*S146+(-3.235597e+00)*S147+(-2.604522e+00)*S148+(-1.997168e+00)*S149'
.param V37_part16='V37_part15+(-9.583479e+00)*S150+(-4.059075e+00)*S151+9.618559e+00*S152+(-1.105060e+00)*S153+(-8.235716e+00)*S154+9.592727e+00*S155+(-3.357946e+00)*S156+3.777916e-01*S157+5.667071e+00*S158+(-2.014588e+00)*S159'
.param V37_part17='V37_part16+8.971158e+00*S160+(-3.659293e+00)*S161+9.494850e+00*S162+(-2.876176e+00)*S163+(-3.087392e+00)*S164+(-5.993578e+01)*S165+(-2.672858e+00)*S166+7.551595e+00*S167+(-1.631754e+01)*S168+7.864506e+00*S169'
.param V37_part18='V37_part17+(-1.270402e+00)*S170+(-2.988336e+00)*S171+(-3.683893e+01)*S172+(-1.009291e+00)*S173+(-4.675430e+00)*S174+(-1.711577e+00)*S175+(-1.311826e+00)*S176+(-1.895098e+01)*S177+(-1.290563e+00)*S178+(-1.263704e+00)*S179'
.param V37_part19='V37_part18+(-4.694506e+00)*S180+(-2.197166e+00)*S181+(-1.236317e+00)*S182+(-5.376400e+00)*S183+(-6.037659e+00)*S184+(-1.475960e+00)*S185+(-2.363964e+00)*S186+(-2.853484e+00)*S187+(-2.369251e+00)*S188+(-5.498309e-01)*S189'
.param V37_part20='V37_part19+(-2.444889e+00)*S190+(-1.878865e+00)*S191+(-1.109949e+00)*S192+(-1.957110e+00)*S193+(-1.215604e+00)*S194+(-4.546830e+01)*S195+(-5.798880e+00)*S196+(-2.800357e+00)*S197+(-8.765874e+00)*S198+(-4.184346e+00)*S199'
.param V37_part21='V37_part20+(-2.516693e+00)*S200+(-7.897197e+00)*S201+(-3.959830e+00)*S202+(-1.949239e+00)*S203+(-5.177741e+00)*S204+(-3.617718e+00)*S205+(-1.946979e+00)*S206+(-2.494682e+00)*S207+(-2.630074e+00)*S208+(-1.570163e+00)*S209'
.param V37_part22='V37_part21+(-6.210779e+00)*S210+(-2.002490e+00)*S211+(-1.472723e+00)*S212+(-2.846884e+00)*S213+3.773175e+00*S214+(-1.460165e+00)*S215+3.719844e+01*S216+(-3.698231e+00)*S217+(-2.345335e+00)*S218+(-1.755680e+00)*S219'
.param V37_part23='V37_part22+(-9.613501e-01)*S220+(-2.040887e+00)*S221+(-3.243013e+00)*S222+(-6.753999e-01)*S223+(-7.765765e-01)*S224+(-4.739341e+00)*S225+1.069776e+01*S226+6.774835e+00*S227+(-6.655171e+00)*S228+(-3.196371e+00)*S229'
.param V37_part24='V37_part23+(-1.039973e+00)*S230+(-6.576778e+00)*S231+(-1.214436e+00)*S232+(-7.653254e-01)*S233+(-5.013720e+00)*S234+(-9.158391e-01)*S235+(-5.838050e-01)*S236+(-3.436795e+00)*S237+(-9.777982e-01)*S238+(-4.917936e-01)*S239'
.param V37_part25='V37_part24+(-4.068648e+00)*S240+4.350513e+00*S241+(-1.432331e+00)*S242+(-6.700326e+00)*S243+(-1.744640e+00)*S244+(-9.432903e-01)*S245+(-5.634454e+00)*S246+(-2.310803e+00)*S247+(-6.817170e-01)*S248+(-5.325558e+00)*S249'
.param V37_part26='V37_part25+(-3.380283e+00)*S250+(-3.300331e-01)*S251+(-3.141689e+00)*S252+(-5.804213e-01)*S253+(-3.530791e-01)*S254+(-1.073617e+01)*S255+(-4.141454e+00)*S256+(-1.299229e+00)*S257+(-7.472055e+00)*S258+(-3.460676e+00)*S259'
.param V37_part27='V37_part26+(-1.523071e+00)*S260+(-1.656249e+00)*S261+(-1.719014e+00)*S262+(-9.169645e-01)*S263+(-1.019989e+00)*S264+(-8.885109e-01)*S265+(-6.642488e-01)*S266+(-1.316641e+00)*S267+(-5.361030e-01)*S268+(-7.836175e-01)*S269'
.param V37_part28='V37_part27+(-4.537824e+00)*S270+(-1.807167e+00)*S271+(-9.979841e-01)*S272+(-2.177605e+00)*S273+(-1.445868e+00)*S274+(-9.519805e-01)*S275+(-1.531467e+00)*S276+(-8.880367e-01)*S277+(-8.232611e-01)*S278+(-1.234890e+00)*S279'
.param V37_part29='V37_part28+(-1.823878e+00)*S280+(-6.805313e-01)*S281+(-1.456542e+00)*S282+(-6.245334e-01)*S283+(-6.692633e-01)*S284+(-5.205296e+00)*S285+(-2.096621e+00)*S286+(-1.155510e+00)*S287+(-4.142286e+00)*S288+(-1.486550e+00)*S289'
.param V37_part30='V37_part29+(-1.322150e+00)*S290+(-1.529487e+00)*S291+(-1.191849e+00)*S292+(-1.371688e+00)*S293+(-1.079465e+00)*S294+(-1.041926e+00)*S295+(-1.331057e+00)*S296+(-1.994562e+00)*S297+(-5.617261e-01)*S298+(-1.453072e+00)*S299'
.param V37_part31='V37_part30+(-4.456021e+00)*S300+(-4.482333e+00)*S301+(-1.273371e+00)*S302+(-2.837484e+00)*S303+(-1.880781e+00)*S304+(-1.087015e+00)*S305+(-2.568725e+00)*S306+(-1.880056e+00)*S307+(-8.954094e-01)*S308+(-1.188588e+00)*S309'
.param V37='V37_part31+(-1.619310e+00)*S310+(-6.447730e-01)*S311+(-2.476283e+00)*S312+(-7.744729e-01)*S313+(-7.476855e-01)*S314'
.param V38_part1='(-2.093821e+00)*S0+(-1.672579e+02)*S1+(-8.697837e-02)*S2+2.780482e+00*S3+(-4.581587e+00)*S4+(-6.995430e+00)*S5+(-5.964338e+00)*S6+(-9.051965e+00)*S7+(-1.114903e+01)*S8+1.914841e-01*S9'
.param V38_part2='V38_part1+(-4.289548e+01)*S10+(-1.049830e+01)*S11+(-1.559989e+01)*S12+(-7.340813e+00)*S13+(-1.007863e+01)*S14+2.164978e+02*S15+1.084567e+02*S16+(-1.189155e-01)*S17+9.995283e+00*S18+3.414105e+01*S19'
.param V38_part3='V38_part2+(-4.046456e-01)*S20+1.002766e+01*S21+2.625639e+01*S22+(-2.319296e+03)*S23+7.590359e+00*S24+2.401374e+00*S25+(-1.353616e+00)*S26+6.224094e+00*S27+7.155232e+00*S28+5.200009e+00*S29'
.param V38_part4='V38_part3+1.198734e+00*S30+3.089209e+00*S31+9.817903e-01*S32+2.786996e+00*S33+1.030368e+00*S34+2.897334e+00*S35+2.359553e+00*S36+(-1.404378e+00)*S37+1.040742e+00*S38+3.858015e-01*S39'
.param V38_part5='V38_part4+6.420943e-01*S40+3.232872e-01*S41+(-4.152205e-01)*S42+1.205951e+00*S43+4.359136e-01*S44+3.002753e+00*S45+3.668683e+01*S46+6.316985e+03*S47+4.262150e+00*S48+1.369239e+00*S49'
.param V38_part6='V38_part5+(-3.684705e-01)*S50+9.999976e+03*S51+5.302626e-01*S52+4.494936e-01*S53+(-6.464120e+00)*S54+6.277647e-01*S55+(-1.843306e-01)*S56+(-4.372184e-02)*S57+1.791907e-01*S58+1.274413e+01*S59'
.param V38_part7='V38_part6+1.051917e+00*S60+1.570151e-01*S61+5.860264e-01*S62+(-1.098288e+00)*S63+1.070901e+00*S64+7.548314e-01*S65+(-1.706137e+01)*S66+1.493012e+01*S67+1.391189e+00*S68+(-1.821864e+01)*S69'
.param V38_part8='V38_part7+1.369967e+01*S70+(-6.967109e+00)*S71+(-4.854376e+00)*S72+(-1.370274e+00)*S73+2.640484e-01*S74+1.032532e+00*S75+1.401923e+00*S76+1.161597e+00*S77+5.247982e-01*S78+(-2.201367e-01)*S79'
.param V38_part9='V38_part8+(-1.103267e+00)*S80+(-6.208114e-01)*S81+1.251906e+00*S82+4.029474e+00*S83+(-2.053141e-01)*S84+9.885526e-02*S85+1.741053e+00*S86+1.999422e+00*S87+2.144981e+00*S88+1.372695e+00*S89'
.param V38_part10='V38_part9+(-3.071611e-01)*S90+5.255565e-01*S91+(-1.000000e+04)*S92+(-1.681096e+00)*S93+5.624274e-01*S94+7.654311e+02*S95+(-1.761424e+00)*S96+7.289255e-01*S97+2.340808e+00*S98+(-7.170256e-01)*S99'
.param V38_part11='V38_part10+(-9.130682e-01)*S100+7.157691e+00*S101+(-7.928402e-01)*S102+(-3.437559e-01)*S103+4.965263e+03*S104+2.772298e-01*S105+7.474612e-01*S106+1.692800e-01*S107+5.313482e-03*S108+(-5.934049e-01)*S109'
.param V38_part12='V38_part11+8.469477e-01*S110+3.026848e-01*S111+3.272944e-01*S112+3.211516e-01*S113+5.600990e-01*S114+5.302803e-01*S115+2.969324e-01*S116+9.745279e+03*S117+6.890560e-01*S118+6.026824e-01*S119'
.param V38_part13='V38_part12+(-7.090589e-02)*S120+(-1.113732e-01)*S121+1.397183e-01*S122+4.022021e-01*S123+1.391266e-02*S124+1.248503e-01*S125+1.301275e+01*S126+3.728043e+01*S127+2.280895e-01*S128+9.471999e-01*S129'
.param V38_part14='V38_part13+1.000000e+04*S130+1.000000e+04*S131+3.084605e-01*S132+1.000000e+04*S133+1.186451e+00*S134+4.699023e-01*S135+2.654914e+00*S136+2.000515e+00*S137+8.118175e-01*S138+1.051076e+00*S139'
.param V38_part15='V38_part14+1.311491e+00*S140+9.714098e-01*S141+9.682710e-01*S142+1.060080e+00*S143+6.348235e-01*S144+4.629047e-01*S145+2.073468e-01*S146+5.976892e-01*S147+3.071211e-01*S148+2.081043e-01*S149'
.param V38_part16='V38_part15+(-1.000000e+04)*S150+(-1.000000e+04)*S151+6.978276e+03*S152+5.719834e+02*S153+(-1.000000e+04)*S154+4.658737e+02*S155+5.833202e+02*S156+6.643059e+02*S157+1.000000e+04*S158+1.808181e+00*S159'
.param V38_part17='V38_part16+1.000000e+04*S160+(-5.892398e-01)*S161+6.558344e+01*S162+(-4.323320e-03)*S163+(-3.068865e-01)*S164+2.093001e+03*S165+1.284747e+00*S166+1.273622e+03*S167+1.000000e+04*S168+1.098673e+03*S169'
.param V38_part18='V38_part17+9.897134e-01*S170+1.566739e+00*S171+(-1.000000e+04)*S172+7.096365e-01*S173+3.540600e-02*S174+1.092294e+00*S175+6.893982e-01*S176+(-1.000000e+04)*S177+1.145843e+00*S178+7.055282e-01*S179'
.param V38_part19='V38_part18+4.972101e+00*S180+1.012149e+00*S181+1.024275e+00*S182+9.410675e-01*S183+(-2.898436e+00)*S184+7.104993e-01*S185+1.314424e+00*S186+6.096516e-01*S187+2.372133e-03*S188+1.382588e+00*S189'
.param V38_part20='V38_part19+8.532543e-01*S190+1.003684e-01*S191+1.494670e+00*S192+8.325632e-01*S193+6.143677e-01*S194+(-9.036449e+01)*S195+2.855641e-01*S196+2.660378e-01*S197+1.287601e-01*S198+1.777826e-02*S199'
.param V38_part21='V38_part20+1.995447e-01*S200+3.337417e-01*S201+1.380899e-01*S202+1.886060e-01*S203+3.254969e-01*S204+6.702406e-01*S205+1.312686e-01*S206+(-3.408072e-01)*S207+6.501120e-02*S208+(-1.171941e-02)*S209'
.param V38_part22='V38_part21+3.147444e-01*S210+1.000000e+04*S211+5.590184e-01*S212+1.366781e+00*S213+1.000000e+04*S214+3.377493e-01*S215+9.222654e+02*S216+1.132551e-01*S217+(-7.436939e-02)*S218+2.010993e+00*S219'
.param V38_part23='V38_part22+9.240641e-01*S220+(-6.399095e-02)*S221+(-3.790611e-02)*S222+7.735348e-01*S223+3.538968e-01*S224+1.157224e-01*S225+1.000000e+04*S226+1.000000e+04*S227+(-1.308606e-01)*S228+1.088196e+00*S229'
.param V38_part24='V38_part23+3.433020e-01*S230+(-2.325437e-01)*S231+8.277718e-01*S232+3.543367e-01*S233+7.835089e-02*S234+6.135096e-01*S235+3.405661e-01*S236+2.480970e-01*S237+9.267417e-01*S238+4.261027e-01*S239'
.param V38_part25='V38_part24+1.425319e+00*S240+1.000000e+04*S241+7.545860e-01*S242+1.292883e-01*S243+1.513740e+00*S244+2.675701e-01*S245+(-5.925248e-01)*S246+9.169400e-01*S247+3.089104e-01*S248+(-8.056658e-02)*S249'
.param V38_part26='V38_part25+6.135221e-02*S250+2.211738e-01*S251+1.931211e-02*S252+7.837651e-01*S253+2.117000e-01*S254+1.476061e+00*S255+5.158487e-01*S256+6.029922e-01*S257+1.206312e+00*S258+1.777382e+00*S259'
.param V38_part27='V38_part26+4.002592e+00*S260+1.996329e+00*S261+1.501820e+00*S262+4.109317e-01*S263+1.990755e+00*S264+8.664995e-01*S265+4.094576e-01*S266+1.226997e+00*S267+6.608426e-01*S268+5.429373e-01*S269'
.param V38_part28='V38_part27+1.337531e+00*S270+1.537851e+00*S271+7.836789e-01*S272+1.447481e+00*S273+7.174204e-01*S274+5.622622e-01*S275+1.549021e+00*S276+7.942101e-01*S277+5.333416e-01*S278+1.057400e+00*S279'
.param V38_part29='V38_part28+8.160450e-01*S280+4.675612e-01*S281+1.380149e+00*S282+6.614211e-01*S283+4.349672e-01*S284+1.493603e+00*S285+1.454304e+00*S286+4.170352e-01*S287+1.717126e+00*S288+1.306774e+00*S289'
.param V38_part30='V38_part29+5.172705e-01*S290+1.166592e+00*S291+7.618418e-01*S292+5.732934e-01*S293+1.096637e+00*S294+7.550818e-01*S295+5.793345e-01*S296+1.272559e+00*S297+7.220537e-01*S298+5.717811e-01*S299'
.param V38_part31='V38_part30+1.659516e+00*S300+(-8.990176e-03)*S301+5.714399e-01*S302+1.744822e+00*S303+1.096335e+00*S304+8.207562e-01*S305+1.832610e+00*S306+9.761512e-01*S307+7.260081e-01*S308+1.163140e+00*S309'
.param V38='V38_part31+9.313998e-01*S310+4.416567e-01*S311+1.181850e+00*S312+7.581489e-01*S313+4.615944e-01*S314'
.param V39_part1='9.629652e-02*S0+(-6.074530e-01)*S1+(-4.739620e-01)*S2+(-1.935031e+01)*S3+(-2.311593e-01)*S4+(-2.561907e-01)*S5+(-2.780780e-02)*S6+(-1.638250e-02)*S7+3.874540e-02*S8+(-1.724309e-01)*S9'
.param V39_part2='V39_part1+(-4.269571e-02)*S10+(-6.401910e-02)*S11+(-1.707024e-01)*S12+2.628977e-01*S13+4.022557e-02*S14+(-5.623650e-02)*S15+2.802421e-01*S16+7.188153e-04*S17+(-3.288815e-02)*S18+(-1.479345e-02)*S19'
.param V39_part3='V39_part2+6.580910e-03*S20+5.475016e-02*S21+1.773846e-02*S22+(-3.399573e+02)*S23+(-2.172723e-03)*S24+3.464329e-03*S25+1.562567e-02*S26+(-1.367550e-02)*S27+3.934033e-03*S28+5.256527e-02*S29'
.param V39_part4='V39_part3+1.003845e-02*S30+(-4.694112e-02)*S31+(-5.988548e-02)*S32+1.629129e-01*S33+8.832375e-03*S34+1.353544e-02*S35+2.125760e-01*S36+4.726745e-01*S37+5.718089e-02*S38+(-8.127277e-02)*S39'
.param V39_part5='V39_part4+2.651500e-03*S40+6.091060e-03*S41+(-1.458187e-01)*S42+2.617769e-02*S43+(-1.473584e-02)*S44+4.457756e+00*S45+3.112698e+00*S46+(-5.016359e+00)*S47+(-6.253518e-01)*S48+5.263265e-01*S49'
.param V39_part6='V39_part5+2.898165e-01*S50+(-5.486515e+01)*S51+5.729722e-01*S52+3.328945e-01*S53+(-5.890282e-01)*S54+(-2.139123e-01)*S55+4.521041e-01*S56+5.292891e-01*S57+4.221964e-01*S58+(-4.952532e-01)*S59'
.param V39_part7='V39_part6+3.694674e-01*S60+5.532580e-01*S61+(-3.960809e-02)*S62+2.299141e-01*S63+(-1.107909e-02)*S64+(-3.691117e-02)*S65+2.654018e-01*S66+(-3.976796e-01)*S67+4.105030e-01*S68+8.773208e-01*S69'
.param V39_part8='V39_part7+(-3.514873e-01)*S70+1.552028e+00*S71+1.477319e+00*S72+7.258744e-01*S73+(-5.123844e-02)*S74+(-2.201019e-01)*S75+(-1.768988e-01)*S76+(-2.533199e-01)*S77+(-1.352553e-01)*S78+(-2.096290e-01)*S79'
.param V39_part9='V39_part8+(-4.229306e-01)*S80+2.729089e-02*S81+(-2.352990e-01)*S82+5.223578e-01*S83+4.684562e-01*S84+7.622990e-01*S85+4.945592e-01*S86+8.628702e-01*S87+3.699888e-01*S88+4.675574e-01*S89'
.param V39_part10='V39_part9+(-1.519188e-01)*S90+(-3.723582e-01)*S91+1.286231e+00*S92+(-5.591403e-01)*S93+(-3.948392e-01)*S94+1.428446e-01*S95+(-4.155947e-01)*S96+(-1.451304e-01)*S97+(-2.479790e-03)*S98+1.251862e-01*S99'
.param V39_part11='V39_part10+(-9.024152e-02)*S100+(-6.967077e-03)*S101+4.238265e-01*S102+2.236576e-01*S103+(-5.409434e-01)*S104+(-3.334752e-01)*S105+(-8.279986e-02)*S106+(-2.992487e-02)*S107+(-2.250827e-01)*S108+(-4.659089e-02)*S109'
.param V39_part12='V39_part11+5.771427e-02*S110+(-4.331160e-01)*S111+(-5.975672e-02)*S112+1.190213e-02*S113+1.646574e-02*S114+(-4.175024e-02)*S115+(-1.836693e-02)*S116+(-2.041966e+00)*S117+2.389372e-02*S118+(-1.677703e-01)*S119'
.param V39_part13='V39_part12+(-6.331438e-01)*S120+(-4.332185e-02)*S121+(-2.773536e-02)*S122+(-9.712822e-02)*S123+(-8.448097e-02)*S124+(-1.570172e-02)*S125+(-2.899876e-01)*S126+(-2.564786e+00)*S127+(-1.948599e-02)*S128+(-1.912427e-01)*S129'
.param V39_part14='V39_part13+(-2.853341e+00)*S130+(-1.319348e+00)*S131+(-1.714068e-01)*S132+(-1.484469e+00)*S133+(-1.765110e-01)*S134+(-3.740870e-01)*S135+(-3.354744e-01)*S136+(-3.504733e-02)*S137+(-2.141584e-02)*S138+(-1.187773e-01)*S139'
.param V39_part15='V39_part14+(-5.369131e-02)*S140+(-4.551809e-01)*S141+(-2.083237e-01)*S142+(-3.916182e-02)*S143+(-3.955314e-01)*S144+(-3.306035e-01)*S145+(-6.166783e-02)*S146+(-3.081252e-01)*S147+(-2.972702e-01)*S148+(-4.721860e-02)*S149'
.param V39_part16='V39_part15+7.606637e-01*S150+(-1.205291e+00)*S151+(-2.667182e-01)*S152+(-4.976579e+00)*S153+(-1.819869e+00)*S154+(-2.543025e-01)*S155+(-4.915498e-01)*S156+(-1.215886e+00)*S157+(-3.719644e-01)*S158+8.269808e-03*S159'
.param V39_part17='V39_part16+(-4.965716e-01)*S160+(-1.487373e-01)*S161+3.599217e-01*S162+(-7.377989e-02)*S163+(-1.779249e-01)*S164+(-1.459107e-01)*S165+(-1.332146e-01)*S166+(-5.017281e-01)*S167+(-1.469204e+00)*S168+(-4.995750e+00)*S169'
.param V39_part18='V39_part17+1.522026e-02*S170+(-1.554728e-01)*S171+(-2.352867e+00)*S172+4.988422e-02*S173+2.185348e-01*S174+(-1.627555e-01)*S175+6.949999e-02*S176+(-2.262294e-01)*S177+9.232071e-02*S178+7.112007e-02*S179'
.param V39_part19='V39_part18+(-3.904015e-01)*S180+1.248838e-03*S181+4.373893e-02*S182+8.312602e-03*S183+(-4.937132e-01)*S184+(-7.534501e-03)*S185+1.778716e-01*S186+1.941412e-02*S187+(-1.403084e-02)*S188+(-2.540242e-02)*S189'
.param V39_part20='V39_part19+9.341192e-03*S190+2.248392e-02*S191+2.043465e-01*S192+5.260150e-02*S193+7.371878e-02*S194+(-3.214599e+00)*S195+(-1.423742e-01)*S196+(-3.614227e-02)*S197+(-9.366861e-02)*S198+(-1.503948e-01)*S199'
.param V39_part21='V39_part20+(-4.133055e-02)*S200+(-2.165384e-01)*S201+(-1.440604e-01)*S202+(-2.962836e-02)*S203+(-1.896350e-01)*S204+(-2.271732e-01)*S205+1.696370e-01*S206+9.210621e-02*S207+(-2.876894e-03)*S208+1.375070e-01*S209'
.param V39_part22='V39_part21+(-1.733502e-01)*S210+(-1.890338e+00)*S211+(-4.891091e-02)*S212+5.774456e-02*S213+(-9.994329e-01)*S214+(-7.885134e-02)*S215+2.160134e+00*S216+(-3.280513e-02)*S217+(-3.416847e-02)*S218+(-1.031372e-01)*S219'
.param V39_part23='V39_part22+(-6.232501e-02)*S220+(-1.539625e-03)*S221+1.644086e-03*S222+(-8.058188e-02)*S223+(-4.129092e-02)*S224+(-3.096599e-01)*S225+(-2.047259e+00)*S226+(-4.332621e-01)*S227+(-1.041114e-01)*S228+(-2.133948e-01)*S229'
.param V39_part24='V39_part23+(-3.819518e-02)*S230+9.635474e-02*S231+(-1.170958e-01)*S232+(-3.740153e-02)*S233+(-6.023706e-04)*S234+(-7.095329e-02)*S235+(-2.827639e-02)*S236+(-9.623712e-02)*S237+(-7.689977e-02)*S238+(-6.282350e-02)*S239'
.param V39_part25='V39_part24+1.217747e-03*S240+(-2.148265e+00)*S241+(-8.904919e-02)*S242+9.788866e-03*S243+(-9.708859e-02)*S244+(-4.066919e-02)*S245+(-2.855405e-01)*S246+(-1.104542e-01)*S247+(-3.693845e-02)*S248+(-1.285120e-01)*S249'
.param V39_part26='V39_part25+(-6.821601e-02)*S250+(-3.081448e-02)*S251+(-1.947838e-01)*S252+(-1.257242e-01)*S253+(-2.886302e-02)*S254+(-1.469942e-01)*S255+(-1.788938e-01)*S256+(-4.444458e-02)*S257+(-2.876078e-01)*S258+(-1.158417e-01)*S259'
.param V39_part27='V39_part26+(-1.941635e-01)*S260+1.069843e-02*S261+4.144042e-02*S262+(-5.744725e-02)*S263+1.203979e-01*S264+(-6.865880e-02)*S265+(-4.863289e-02)*S266+2.900004e-01*S267+(-4.861053e-02)*S268+(-4.993441e-02)*S269'
.param V39_part28='V39_part27+(-1.722038e-01)*S270+(-9.972809e-02)*S271+(-3.132420e-02)*S272+(-1.637000e-01)*S273+(-9.934086e-02)*S274+(-5.466112e-02)*S275+(-1.656346e-01)*S276+(-1.037322e-01)*S277+(-4.948193e-02)*S278+(-1.150372e-01)*S279'
.param V39_part29='V39_part28+4.980298e-02*S280+(-3.718223e-02)*S281+(-4.702676e-03)*S282+(-1.138703e-01)*S283+(-3.184675e-02)*S284+(-2.017095e-01)*S285+(-7.769400e-02)*S286+(-8.777704e-02)*S287+(-1.365948e-01)*S288+(-1.077895e-01)*S289'
.param V39_part30='V39_part29+1.920920e-02*S290+(-1.520974e-01)*S291+(-1.248170e-01)*S292+3.563862e-02*S293+(-1.690941e-01)*S294+(-1.389872e-01)*S295+1.879105e-02*S296+(-1.616567e-01)*S297+(-1.468363e-01)*S298+2.524959e-02*S299'
.param V39_part31='V39_part30+(-2.390830e-01)*S300+(-1.824400e-01)*S301+(-9.534784e-02)*S302+(-1.274981e-01)*S303+(-1.543681e-01)*S304+(-4.173384e-02)*S305+1.900380e-02*S306+(-1.045878e-01)*S307+(-5.884885e-02)*S308+(-1.842675e-01)*S309'
.param V39='V39_part31+(-1.038761e-01)*S310+(-2.721100e-02)*S311+(-2.419839e-01)*S312+(-1.030713e-01)*S313+(-2.906098e-02)*S314'
.param V40_part1='2.094333e+01*S0+1.537617e+01*S1+1.176635e+01*S2+6.736041e+00*S3+1.121325e+01*S4+1.126673e+01*S5+3.688112e+00*S6+2.221131e+00*S7+9.132415e+00*S8+2.420140e+00*S9'
.param V40_part2='V40_part1+4.635563e+00*S10+3.727800e+00*S11+6.626372e-01*S12+0.000000e+00*S13+0.000000e+00*S14+2.372251e+01*S15+4.540737e+00*S16+0.000000e+00*S17+2.280802e+00*S18+1.847888e+01*S19'
.param V40_part3='V40_part2+(-2.199142e-01)*S20+6.380264e-01*S21+9.724475e+00*S22+1.811679e+01*S23+4.208068e+00*S24+3.757619e+00*S25+3.843640e+00*S26+8.552782e+00*S27+8.751510e+00*S28+6.849345e+00*S29'
.param V40_part4='V40_part3+0.000000e+00*S30+1.100006e+01*S31+1.024637e+01*S32+2.066804e+01*S33+0.000000e+00*S34+3.311346e+01*S35+2.127895e+01*S36+0.000000e+00*S37+(-1.114851e+01)*S38+0.000000e+00*S39'
.param V40_part5='V40_part4+0.000000e+00*S40+0.000000e+00*S41+(-6.438643e+00)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+1.690792e+01*S48+1.065302e+01*S49'
.param V40_part6='V40_part5+(-1.468222e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+(-1.102231e+00)*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V40_part7='V40_part6+1.510172e+01*S60+2.209490e+01*S61+0.000000e+00*S62+6.753809e+00*S63+1.694849e+01*S64+3.268440e+01*S65+1.166651e+01*S66+0.000000e+00*S67+4.324613e+01*S68+7.355217e+00*S69'
.param V40_part8='V40_part7+2.796684e+01*S70+0.000000e+00*S71+3.524285e+01*S72+3.184464e+01*S73+0.000000e+00*S74+(-1.507100e-02)*S75+0.000000e+00*S76+1.996893e+01*S77+6.250012e-01*S78+1.177704e-02*S79'
.param V40_part9='V40_part8+2.593574e+01*S80+1.119455e+00*S81+1.479382e+00*S82+2.886138e+01*S83+0.000000e+00*S84+1.875197e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V40_part10='V40_part9+3.546130e+00*S90+1.099095e+01*S91+3.383306e+00*S92+7.300335e+00*S93+0.000000e+00*S94+2.328609e+01*S95+1.341474e+01*S96+4.111957e+00*S97+0.000000e+00*S98+3.198393e+01*S99'
.param V40_part11='V40_part10+1.046976e+01*S100+0.000000e+00*S101+3.122144e+01*S102+2.200743e+01*S103+0.000000e+00*S104+5.651549e+00*S105+4.449536e+00*S106+0.000000e+00*S107+9.409511e+00*S108+0.000000e+00*S109'
.param V40_part12='V40_part11+2.373685e+01*S110+0.000000e+00*S111+7.252765e+00*S112+1.314004e+01*S113+1.739291e+01*S114+8.461753e+00*S115+(-4.758494e+00)*S116+0.000000e+00*S117+1.441566e+01*S118+6.900541e+01*S119'
.param V40_part13='V40_part12+1.572537e+01*S120+1.244211e+01*S121+(-7.375501e-01)*S122+5.378010e+01*S123+2.118658e+01*S124+1.216709e+01*S125+0.000000e+00*S126+0.000000e+00*S127+2.740476e+01*S128+4.165567e+00*S129'
.param V40_part14='V40_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+1.452357e+01*S135+1.199343e+01*S136+1.355437e+00*S137+1.849647e+01*S138+1.523082e+01*S139'
.param V40_part15='V40_part14+0.000000e+00*S140+9.666868e+00*S141+2.085686e+01*S142+0.000000e+00*S143+6.788609e+00*S144+6.264472e+00*S145+2.388135e+01*S146+1.853455e+01*S147+5.436104e+00*S148+0.000000e+00*S149'
.param V40_part16='V40_part15+1.192535e+01*S150+6.758435e+00*S151+0.000000e+00*S152+5.210456e+00*S153+2.557353e+01*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+3.301717e+01*S159'
.param V40_part17='V40_part16+0.000000e+00*S160+0.000000e+00*S161+1.493126e+01*S162+4.643324e+01*S163+0.000000e+00*S164+5.509003e+00*S165+2.153773e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V40_part18='V40_part17+2.101541e+00*S170+(-4.405234e-01)*S171+0.000000e+00*S172+1.041263e+01*S173+(-6.319719e+00)*S174+2.021011e+01*S175+(-8.459523e+00)*S176+0.000000e+00*S177+(-3.288903e+00)*S178+(-4.692737e+01)*S179'
.param V40_part19='V40_part18+2.391504e+01*S180+3.259896e+01*S181+1.002588e+01*S182+2.922926e+01*S183+0.000000e+00*S184+1.309680e+01*S185+1.879919e+01*S186+2.407204e+01*S187+(-4.759115e+01)*S188+5.432435e+01*S189'
.param V40_part20='V40_part19+4.448761e+01*S190+(-5.894541e+01)*S191+4.633824e+01*S192+5.185735e+01*S193+5.250573e+00*S194+3.684541e-01*S195+0.000000e+00*S196+0.000000e+00*S197+2.053678e+01*S198+1.130295e+01*S199'
.param V40_part21='V40_part20+0.000000e+00*S200+1.720701e+01*S201+2.050522e+00*S202+0.000000e+00*S203+9.907417e+00*S204+(-1.077038e+01)*S205+(-9.239154e-01)*S206+0.000000e+00*S207+(-1.076442e+00)*S208+0.000000e+00*S209'
.param V40_part22='V40_part21+2.088206e+01*S210+0.000000e+00*S211+0.000000e+00*S212+3.783562e+01*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+1.007459e+01*S217+(-3.006170e+01)*S218+1.846416e+01*S219'
.param V40_part23='V40_part22+4.775459e+01*S220+(-4.898605e+01)*S221+(-3.809143e+01)*S222+3.679217e+01*S223+8.258709e+01*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+3.853624e+01*S228+4.179649e+01*S229'
.param V40_part24='V40_part23+1.290376e+02*S230+(-2.117282e+01)*S231+3.313231e+01*S232+6.205931e+01*S233+(-1.178146e+01)*S234+1.298071e+02*S235+1.498894e+02*S236+(-2.952000e+01)*S237+2.775749e+01*S238+1.114878e+02*S239'
.param V40_part25='V40_part24+3.993912e+01*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+(-2.024995e+00)*S244+2.027303e+02*S245+(-1.380522e+01)*S246+6.254212e+01*S247+2.295650e+02*S248+(-5.996616e+00)*S249'
.param V40_part26='V40_part25+(-5.662303e+01)*S250+0.000000e+00*S251+(-2.055783e+01)*S252+4.217856e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+5.557215e+00*S257+0.000000e+00*S258+1.717492e+01*S259'
.param V40_part27='V40_part26+0.000000e+00*S260+3.228788e+01*S261+2.511828e+01*S262+1.703278e+02*S263+3.680827e+01*S264+7.599958e+01*S265+2.009136e+02*S266+4.820931e+01*S267+1.078504e+02*S268+9.775965e+01*S269'
.param V40_part28='V40_part27+1.784908e+01*S270+3.105880e+01*S271+1.791121e+01*S272+1.943097e+01*S273+3.336079e+01*S274+2.322595e+01*S275+1.666090e+01*S276+2.758404e+01*S277+3.097961e+01*S278+3.545214e+01*S279'
.param V40_part29='V40_part28+6.242705e+01*S280+3.916799e+01*S281+(-2.673669e+00)*S282+7.960369e+01*S283+1.591489e+02*S284+7.293793e-01*S285+2.678932e+01*S286+0.000000e+00*S287+(-3.273725e+01)*S288+(-1.045335e+01)*S289'
.param V40_part30='V40_part29+(-7.358203e+00)*S290+2.156235e+01*S291+3.964984e+01*S292+(-3.056089e+01)*S293+1.576477e+01*S294+1.117969e+01*S295+(-7.563726e+01)*S296+(-1.806255e+01)*S297+1.345742e+01*S298+(-3.546957e+01)*S299'
.param V40_part31='V40_part30+2.442791e+01*S300+0.000000e+00*S301+0.000000e+00*S302+2.631942e+00*S303+4.093314e+01*S304+(-2.956056e+00)*S305+(-7.103106e+00)*S306+4.128169e+01*S307+2.680398e+01*S308+1.826804e+00*S309'
.param V40='V40_part31+6.847418e+01*S310+9.434312e+01*S311+(-3.868166e+01)*S312+3.435212e+01*S313+2.640220e+01*S314'
.param V41_part1='(-1.132890e+01)*S0+1.260319e+00*S1+4.118355e-01*S2+(-4.294555e+00)*S3+3.232538e+00*S4+7.289619e-01*S5+1.710354e+01*S6+1.189891e+01*S7+(-3.446717e+00)*S8+4.768846e+00*S9'
.param V41_part2='V41_part1+3.580855e+00*S10+(-4.671759e-01)*S11+5.849113e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.865768e+01*S15+2.337909e+01*S16+0.000000e+00*S17+3.711197e+01*S18+(-1.352756e+01)*S19'
.param V41_part3='V41_part2+1.531466e+01*S20+2.026036e+01*S21+2.800444e-01*S22+(-5.127438e+00)*S23+1.328320e+01*S24+5.617983e+00*S25+9.448493e+00*S26+1.354768e+01*S27+1.167711e+01*S28+9.295564e+00*S29'
.param V41_part4='V41_part3+0.000000e+00*S30+4.332262e+01*S31+5.554594e+01*S32+2.685599e+01*S33+0.000000e+00*S34+9.353732e+00*S35+2.274500e+01*S36+0.000000e+00*S37+3.057109e+01*S38+0.000000e+00*S39'
.param V41_part5='V41_part4+0.000000e+00*S40+0.000000e+00*S41+1.376884e+01*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+2.040062e+00*S48+2.897541e+01*S49'
.param V41_part6='V41_part5+5.443867e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+3.716070e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V41_part7='V41_part6+1.779729e+01*S60+2.699226e+01*S61+0.000000e+00*S62+1.663956e+01*S63+3.150899e+01*S64+3.761811e+01*S65+1.216984e+01*S66+0.000000e+00*S67+2.053107e+01*S68+1.121293e+01*S69'
.param V41_part8='V41_part7+3.903096e+01*S70+0.000000e+00*S71+1.050495e+01*S72+1.434976e+01*S73+0.000000e+00*S74+6.388502e+01*S75+0.000000e+00*S76+1.181243e-01*S77+4.065713e+01*S78+5.616857e+01*S79'
.param V41_part9='V41_part8+(-9.938052e+00)*S80+3.328615e+01*S81+2.418620e+01*S82+(-7.369567e+00)*S83+0.000000e+00*S84+(-7.540340e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V41_part10='V41_part9+3.246350e+01*S90+7.363619e+01*S91+2.166598e+01*S92+2.107907e+01*S93+0.000000e+00*S94+5.098352e+00*S95+1.026877e+01*S96+1.175480e+01*S97+0.000000e+00*S98+5.252768e+00*S99'
.param V41_part11='V41_part10+1.648858e+01*S100+0.000000e+00*S101+9.521914e+00*S102+1.014422e+01*S103+0.000000e+00*S104+2.265226e+01*S105+4.388557e+01*S106+0.000000e+00*S107+1.702929e+01*S108+0.000000e+00*S109'
.param V41_part12='V41_part11+1.758029e+01*S110+0.000000e+00*S111+4.129371e+01*S112+2.125409e+00*S113+3.506790e+01*S114+4.145564e+01*S115+1.822982e+01*S116+0.000000e+00*S117+3.693735e+01*S118+6.495397e-01*S119'
.param V41_part13='V41_part12+5.158287e+01*S120+4.559938e+00*S121+3.790225e+01*S122+3.936021e+01*S123+(-1.182877e+01)*S124+1.417905e+01*S125+0.000000e+00*S126+0.000000e+00*S127+(-1.557751e+00)*S128+5.179873e+01*S129'
.param V41_part14='V41_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+2.386262e+01*S135+4.405855e+01*S136+1.619351e+01*S137+(-1.474535e+01)*S138+4.937694e+00*S139'
.param V41_part15='V41_part14+0.000000e+00*S140+(-3.394796e+00)*S141+(-9.035327e+00)*S142+0.000000e+00*S143+(-2.130840e+00)*S144+(-2.011057e+00)*S145+(-4.374550e+00)*S146+7.206201e-01*S147+(-1.870582e+00)*S148+0.000000e+00*S149'
.param V41_part16='V41_part15+1.460068e+01*S150+2.228677e+01*S151+0.000000e+00*S152+1.134362e+01*S153+(-1.598808e+01)*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+2.440524e+01*S159'
.param V41_part17='V41_part16+0.000000e+00*S160+0.000000e+00*S161+6.093543e+01*S162+1.200210e+01*S163+0.000000e+00*S164+9.615644e+00*S165+2.994927e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V41_part18='V41_part17+7.481567e+01*S170+6.336273e+01*S171+0.000000e+00*S172+5.343249e+01*S173+1.344778e+01*S174+2.576559e+01*S175+7.905714e+01*S176+0.000000e+00*S177+6.658912e+01*S178+1.024142e+02*S179'
.param V41_part19='V41_part18+2.000998e+01*S180+4.926554e+01*S181+8.935223e+01*S182+2.528839e+01*S183+0.000000e+00*S184+5.907807e+01*S185+4.755371e+01*S186+5.163257e+01*S187+6.609799e+01*S188+2.567503e+01*S189'
.param V41_part20='V41_part19+7.716918e+00*S190+7.522387e+01*S191+2.808622e+01*S192+3.573399e+00*S193+7.184342e+01*S194+6.771794e+01*S195+0.000000e+00*S196+0.000000e+00*S197+(-2.206751e+01)*S198+(-2.617269e+01)*S199'
.param V41_part21='V41_part20+0.000000e+00*S200+(-9.822135e-01)*S201+1.650354e+01*S202+0.000000e+00*S203+2.319142e+01*S204+3.839834e+01*S205+4.810345e+01*S206+0.000000e+00*S207+3.848391e+01*S208+0.000000e+00*S209'
.param V41_part22='V41_part21+1.535126e+01*S210+0.000000e+00*S211+0.000000e+00*S212+3.340407e+01*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+6.857411e+01*S217+6.535945e+01*S218+3.055617e+01*S219'
.param V41_part23='V41_part22+(-3.878128e+01)*S220+8.798196e+01*S221+4.732150e+01*S222+(-2.474620e+01)*S223+2.104269e+01*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-6.984373e+00)*S228+3.798029e+00*S229'
.param V41_part24='V41_part23+(-2.970536e+01)*S230+3.281731e+01*S231+3.088230e+01*S232+(-4.774004e+00)*S233+4.862456e+01*S234+(-5.795682e+01)*S235+(-6.642649e+01)*S236+8.128100e+01*S237+7.157838e+01*S238+(-3.980891e+01)*S239'
.param V41_part25='V41_part24+1.071507e+01*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+5.280887e+01*S244+(-1.360530e+02)*S245+7.508732e+01*S246+(-8.687558e-03)*S247+(-1.370591e+02)*S248+7.256850e+01*S249'
.param V41_part26='V41_part25+4.934719e+01*S250+0.000000e+00*S251+8.699621e+01*S252+1.809403e+01*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+7.511284e+01*S257+0.000000e+00*S258+1.490757e+01*S259'
.param V41_part27='V41_part26+0.000000e+00*S260+2.027579e+01*S261+3.133835e+01*S262+(-9.886097e+01)*S263+1.870664e+01*S264+(-2.755629e+01)*S265+(-1.162204e+02)*S266+2.978162e+01*S267+(-1.401279e+01)*S268+2.611854e+01*S269'
.param V41_part28='V41_part27+(-2.928968e-03)*S270+(-2.607464e+00)*S271+2.739149e+01*S272+2.093086e+01*S273+(-1.066548e+00)*S274+3.295834e+00*S275+2.465638e+01*S276+(-1.245436e+01)*S277+2.461124e+01*S278+2.519521e+01*S279'
.param V41_part29='V41_part28+3.781559e+01*S280+3.325831e+01*S281+9.875235e+01*S282+(-9.836520e+00)*S283+(-1.167914e+01)*S284+2.284389e+01*S285+3.657492e+01*S286+0.000000e+00*S287+8.697876e+01*S288+7.092358e+01*S289'
.param V41_part30='V41_part29+1.101035e+02*S290+3.191377e+01*S291+2.498037e+01*S292+1.090895e+02*S293+3.456017e+01*S294+1.744099e+01*S295+1.317319e+02*S296+5.134266e+01*S297+4.390562e+01*S298+9.983756e+01*S299'
.param V41_part31='V41_part30+3.502930e+01*S300+0.000000e+00*S301+0.000000e+00*S302+6.940784e+01*S303+(-2.030518e+01)*S304+3.300570e+01*S305+5.670502e+01*S306+(-2.663196e+01)*S307+(-1.280102e+01)*S308+1.752055e+01*S309'
.param V41='V41_part31+(-3.243757e+01)*S310+(-8.749415e+00)*S311+1.064350e+02*S312+(-1.217298e+01)*S313+5.703609e+01*S314'
.param V42_part1='(-1.309856e+01)*S0+7.090682e+00*S1+(-3.581040e+00)*S2+3.225560e+00*S3+(-7.554782e+00)*S4+(-6.965854e+00)*S5+(-1.671251e+01)*S6+(-7.076186e+00)*S7+(-4.610038e+00)*S8+(-1.158887e+00)*S9'
.param V42_part2='V42_part1+(-7.768640e+00)*S10+(-1.304141e+00)*S11+(-9.105471e+00)*S12+0.000000e+00*S13+0.000000e+00*S14+4.924250e+01*S15+1.361886e+01*S16+0.000000e+00*S17+(-1.786721e+01)*S18+(-6.520777e+00)*S19'
.param V42_part3='V42_part2+(-4.053209e+00)*S20+(-1.101319e+00)*S21+(-1.369445e+00)*S22+(-9.076502e+00)*S23+2.779859e+00*S24+(-3.555727e+00)*S25+(-2.603969e+00)*S26+(-1.605348e+00)*S27+(-7.397952e+00)*S28+(-2.668078e+00)*S29'
.param V42_part4='V42_part3+0.000000e+00*S30+2.131942e+01*S31+2.752158e+01*S32+1.213527e+01*S33+0.000000e+00*S34+4.861077e+00*S35+2.010813e+01*S36+0.000000e+00*S37+1.560511e+01*S38+0.000000e+00*S39'
.param V42_part5='V42_part4+0.000000e+00*S40+0.000000e+00*S41+3.230651e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+1.211084e+00*S48+1.778558e+01*S49'
.param V42_part6='V42_part5+2.484175e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+2.291201e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V42_part7='V42_part6+5.721842e+00*S60+1.974298e+00*S61+0.000000e+00*S62+1.044532e+01*S63+1.634113e+01*S64+4.260114e+01*S65+1.797487e+01*S66+0.000000e+00*S67+1.608773e+01*S68+2.096934e+01*S69'
.param V42_part8='V42_part7+4.230638e+01*S70+0.000000e+00*S71+(-2.836705e+00)*S72+1.961511e+01*S73+0.000000e+00*S74+1.446805e+01*S75+0.000000e+00*S76+3.672016e-01*S77+2.636829e+01*S78+5.295289e+00*S79'
.param V42_part9='V42_part8+(-1.329968e+01)*S80+(-5.579440e+00)*S81+9.217553e+00*S82+(-1.197844e+01)*S83+0.000000e+00*S84+(-6.034203e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V42_part10='V42_part9+3.057936e+01*S90+4.951898e+01*S91+1.797881e+01*S92+3.816010e+01*S93+0.000000e+00*S94+(-5.601695e+00)*S95+3.815914e+01*S96+2.287493e+01*S97+0.000000e+00*S98+4.404212e+01*S99'
.param V42_part11='V42_part10+3.647086e+01*S100+0.000000e+00*S101+1.882445e+01*S102+3.851493e+01*S103+0.000000e+00*S104+3.708667e+01*S105+5.382173e+01*S106+0.000000e+00*S107+4.578407e+01*S108+0.000000e+00*S109'
.param V42_part12='V42_part11+3.713359e+01*S110+0.000000e+00*S111+5.115443e+01*S112+5.261866e+01*S113+4.921918e+01*S114+5.552787e+01*S115+5.793753e+01*S116+0.000000e+00*S117+5.726964e+01*S118+(-3.666133e+01)*S119'
.param V42_part13='V42_part12+6.056899e+01*S120+3.146080e+01*S121+3.898079e+01*S122+6.800451e+01*S123+3.230363e+01*S124+3.558305e+01*S125+0.000000e+00*S126+0.000000e+00*S127+3.448258e+01*S128+8.267810e+01*S129'
.param V42_part14='V42_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+4.329351e+01*S135+(-7.555998e+00)*S136+8.729457e+00*S137+1.017676e+01*S138+1.898455e+01*S139'
.param V42_part15='V42_part14+0.000000e+00*S140+1.302606e+01*S141+1.863720e+01*S142+0.000000e+00*S143+1.775019e+01*S144+1.990457e+01*S145+1.083006e+01*S146+2.212505e+01*S147+1.863691e+01*S148+0.000000e+00*S149'
.param V42_part16='V42_part15+4.068943e+01*S150+4.305945e+01*S151+0.000000e+00*S152+4.843964e+01*S153+1.752808e+01*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+4.883072e+01*S159'
.param V42_part17='V42_part16+0.000000e+00*S160+0.000000e+00*S161+9.054519e+01*S162+6.204521e+00*S163+0.000000e+00*S164+3.488103e+01*S165+3.943893e+01*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V42_part18='V42_part17+5.669086e+01*S170+9.068938e+01*S171+0.000000e+00*S172+6.899460e+01*S173+2.441650e+01*S174+8.348613e+01*S175+7.580425e+01*S176+0.000000e+00*S177+7.518560e+01*S178+9.351903e+01*S179'
.param V42_part19='V42_part18+8.242604e+01*S180+4.150991e+01*S181+6.178992e+01*S182+5.253309e+01*S183+0.000000e+00*S184+5.677569e+01*S185+7.830907e+01*S186+6.735594e+01*S187+8.965728e+01*S188+1.479065e+01*S189'
.param V42_part20='V42_part19+6.403129e+01*S190+1.017657e+02*S191+2.721482e+01*S192+6.884768e+01*S193+6.289996e+01*S194+8.018387e+01*S195+0.000000e+00*S196+0.000000e+00*S197+4.257747e+01*S198+1.312588e+01*S199'
.param V42_part21='V42_part20+0.000000e+00*S200+4.772035e+01*S201+5.007131e+01*S202+0.000000e+00*S203+6.837484e+01*S204+8.737320e+01*S205+5.305467e+01*S206+0.000000e+00*S207+6.460268e+01*S208+0.000000e+00*S209'
.param V42_part22='V42_part21+5.378456e+01*S210+0.000000e+00*S211+0.000000e+00*S212+5.918123e+01*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+6.400766e+01*S217+7.159946e+01*S218+1.206429e+02*S219'
.param V42_part23='V42_part22+1.219335e+02*S220+8.252907e+01*S221+1.047547e+02*S222+1.325356e+02*S223+4.760587e+01*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-2.737676e+00)*S228+1.019991e+01*S229'
.param V42_part24='V42_part23+(-8.582991e+01)*S230+4.958694e+01*S231+8.734783e+01*S232+1.146672e+01*S233+7.586432e+01*S234+(-5.034691e-01)*S235+(-6.698673e+01)*S236+1.068248e+02*S237+4.629634e+01*S238+6.852144e+01*S239'
.param V42_part25='V42_part24+8.851203e+00*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+1.218508e+02*S244+(-1.073452e+02)*S245+1.311488e+02*S246+9.920912e+00*S247+(-1.159766e+02)*S248+1.091568e+02*S249'
.param V42_part26='V42_part25+1.424493e+02*S250+0.000000e+00*S251+1.032761e+02*S252+1.021073e+02*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+7.105751e+01*S257+0.000000e+00*S258+6.960364e+01*S259'
.param V42_part27='V42_part26+0.000000e+00*S260+3.541202e+01*S261+5.327295e+01*S262+(-7.701627e+01)*S263+4.264391e+01*S264+1.485206e+01*S265+(-6.818663e+01)*S266+1.712818e+01*S267+(-4.677772e+01)*S268+(-2.596805e+01)*S269'
.param V42_part28='V42_part27+9.350260e+01*S270+7.844204e+01*S271+7.596234e+01*S272+9.217161e+01*S273+8.189367e+01*S274+8.056867e+01*S275+8.310413e+01*S276+1.095757e+02*S277+5.505368e+01*S278+1.295607e+02*S279'
.param V42_part29='V42_part28+2.009603e+01*S280+9.186549e+00*S281+(-1.083879e+02)*S282+8.660600e+01*S283+(-4.958992e+01)*S284+1.297937e+02*S285+7.331365e+01*S286+0.000000e+00*S287+2.011258e+02*S288+1.352585e+02*S289'
.param V42_part30='V42_part29+1.049344e+02*S290+1.377841e+02*S291+1.005511e+02*S292+1.268203e+02*S293+1.631502e+02*S294+7.943556e+01*S295+1.663001e+02*S296+1.545179e+02*S297+9.316215e+01*S298+1.643795e+02*S299'
.param V42_part31='V42_part30+4.625403e+01*S300+0.000000e+00*S301+0.000000e+00*S302+1.191273e+02*S303+3.191155e+01*S304+8.562492e+01*S305+9.932429e+01*S306+8.018347e+01*S307+8.594388e+01*S308+1.363922e+02*S309'
.param V42='V42_part31+3.578189e+01*S310+(-5.048252e+01)*S311+1.726440e+02*S312+9.464269e+01*S313+(-2.171625e+01)*S314'
.param V43_part1='(-3.910141e+00)*S0+2.677840e+00*S1+(-4.869300e+00)*S2+(-3.888925e+00)*S3+(-2.411900e+00)*S4+(-1.589050e+00)*S5+3.143281e+00*S6+4.205285e-01*S7+(-2.124327e+00)*S8+(-4.458622e+00)*S9'
.param V43_part2='V43_part1+(-2.581612e-01)*S10+(-1.098751e+00)*S11+7.543836e-01*S12+0.000000e+00*S13+0.000000e+00*S14+(-6.422428e+00)*S15+6.735583e+00*S16+0.000000e+00*S17+7.783148e-02*S18+(-9.063354e+00)*S19'
.param V43_part3='V43_part2+(-4.136426e-01)*S20+6.395127e-01*S21+(-3.072811e+00)*S22+(-4.979698e+00)*S23+(-2.748114e+00)*S24+(-2.805779e+00)*S25+(-2.987283e+00)*S26+(-7.363807e+00)*S27+(-2.316154e+00)*S28+1.783965e+00*S29'
.param V43_part4='V43_part3+0.000000e+00*S30+(-1.505416e+01)*S31+(-1.404031e+01)*S32+(-1.564843e+01)*S33+0.000000e+00*S34+(-2.169976e+01)*S35+(-1.806960e+01)*S36+0.000000e+00*S37+(-3.761764e+00)*S38+0.000000e+00*S39'
.param V43_part5='V43_part4+0.000000e+00*S40+0.000000e+00*S41+1.431090e+01*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-7.082263e+00)*S48+(-9.942670e+00)*S49'
.param V43_part6='V43_part5+(-1.449832e+01)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+(-1.494570e+01)*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V43_part7='V43_part6+(-8.571450e+00)*S60+(-1.188389e+01)*S61+0.000000e+00*S62+(-7.567757e+00)*S63+(-1.426036e+01)*S64+(-2.526863e+01)*S65+(-2.439367e+00)*S66+0.000000e+00*S67+(-3.094021e+01)*S68+(-3.288648e-01)*S69'
.param V43_part8='V43_part7+(-2.782608e+01)*S70+0.000000e+00*S71+(-4.249146e+00)*S72+(-1.269236e+01)*S73+0.000000e+00*S74+(-7.873582e+00)*S75+0.000000e+00*S76+(-4.779251e+00)*S77+(-5.859033e+00)*S78+(-5.075790e+00)*S79'
.param V43_part9='V43_part8+(-5.226483e+00)*S80+1.557127e+01*S81+(-8.156567e+00)*S82+8.062426e+00*S83+0.000000e+00*S84+3.120663e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V43_part10='V43_part9+(-8.783740e+00)*S90+(-1.780180e+01)*S91+(-1.396737e+01)*S92+(-1.042245e+01)*S93+0.000000e+00*S94+1.678909e+01*S95+(-1.116231e+01)*S96+(-1.351814e+01)*S97+0.000000e+00*S98+(-1.047399e+01)*S99'
.param V43_part11='V43_part10+(-1.643420e+01)*S100+0.000000e+00*S101+(-9.149774e+00)*S102+(-1.542231e+01)*S103+0.000000e+00*S104+(-7.658034e+00)*S105+(-1.351348e+01)*S106+0.000000e+00*S107+(-8.098874e+00)*S108+0.000000e+00*S109'
.param V43_part12='V43_part11+(-2.458799e+01)*S110+0.000000e+00*S111+(-1.478854e+01)*S112+(-1.205637e+01)*S113+(-2.471756e+01)*S114+(-2.960962e+01)*S115+(-1.412065e+00)*S116+0.000000e+00*S117+(-3.396660e+01)*S118+(-2.350566e+01)*S119'
.param V43_part13='V43_part12+(-1.704813e+01)*S120+3.742387e-01*S121+(-1.073802e+00)*S122+(-2.819292e+01)*S123+(-5.054173e+00)*S124+5.130353e-02*S125+0.000000e+00*S126+0.000000e+00*S127+(-1.296748e+01)*S128+(-3.432569e+01)*S129'
.param V43_part14='V43_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+(-5.789602e+00)*S135+(-6.115799e+00)*S136+(-8.092915e+00)*S137+(-1.843513e+00)*S138+(-1.148320e+01)*S139'
.param V43_part15='V43_part14+0.000000e+00*S140+1.031227e+00*S141+(-5.816131e+00)*S142+0.000000e+00*S143+1.465176e+00*S144+1.563605e+00*S145+(-3.484442e+00)*S146+(-5.399775e+00)*S147+1.268068e+00*S148+0.000000e+00*S149'
.param V43_part16='V43_part15+8.426842e+00*S150+1.028048e+01*S151+0.000000e+00*S152+2.280496e+01*S153+1.483578e+01*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+(-5.005816e+01)*S159'
.param V43_part17='V43_part16+0.000000e+00*S160+0.000000e+00*S161+(-3.761487e+01)*S162+(-3.369489e+01)*S163+0.000000e+00*S164+(-7.058522e+00)*S165+(-2.332473e+01)*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V43_part18='V43_part17+(-2.994250e+01)*S170+(-2.631399e+01)*S171+0.000000e+00*S172+(-4.432917e+01)*S173+1.622597e+01*S174+(-1.741143e+01)*S175+(-4.768584e+01)*S176+0.000000e+00*S177+(-3.100893e+01)*S178+(-5.291190e+01)*S179'
.param V43_part19='V43_part18+(-3.214326e+01)*S180+(-2.688318e+01)*S181+(-2.207534e+01)*S182+(-3.659130e+01)*S183+0.000000e+00*S184+(-3.515547e+01)*S185+(-3.022997e+01)*S186+(-3.705385e+01)*S187+1.110232e+01*S188+(-2.969433e+01)*S189'
.param V43_part20='V43_part19+(-3.958508e+01)*S190+(-1.074954e+00)*S191+(-3.459887e+01)*S192+(-4.589710e+01)*S193+(-5.093718e+01)*S194+(-1.366821e+01)*S195+0.000000e+00*S196+0.000000e+00*S197+(-6.327326e+00)*S198+1.699418e+01*S199'
.param V43_part21='V43_part20+0.000000e+00*S200+(-1.073196e+01)*S201+1.055596e+00*S202+0.000000e+00*S203+(-1.389513e+01)*S204+(-1.885988e+01)*S205+(-2.000307e+01)*S206+0.000000e+00*S207+(-8.503637e+00)*S208+0.000000e+00*S209'
.param V43_part22='V43_part21+(-1.809867e+01)*S210+0.000000e+00*S211+0.000000e+00*S212+(-3.100429e+01)*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+(-1.979262e+01)*S217+7.699175e+00*S218+(-2.283247e+01)*S219'
.param V43_part23='V43_part22+(-3.915644e+01)*S220+(-1.583972e+00)*S221+2.213455e+00*S222+(-3.754332e+01)*S223+(-5.289925e+01)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-9.704375e+00)*S228+(-9.440795e+00)*S229'
.param V43_part24='V43_part23+(-1.610086e+01)*S230+6.583461e+00*S231+(-4.601446e+01)*S232+(-2.260126e+01)*S233+(-6.274276e-02)*S234+(-4.535927e+01)*S235+(-3.791985e+00)*S236+(-2.203783e+01)*S237+(-5.666207e+01)*S238+(-5.629385e+01)*S239'
.param V43_part25='V43_part24+(-3.120178e+01)*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+(-1.051567e+01)*S244+(-1.802620e+01)*S245+(-1.666029e+01)*S246+(-2.381223e+01)*S247+(-8.752986e+00)*S248+(-2.756361e+01)*S249'
.param V43_part26='V43_part25+1.294629e+01*S250+0.000000e+00*S251+(-2.538664e+01)*S252+(-5.456005e+01)*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+(-3.119698e+01)*S257+0.000000e+00*S258+(-1.389868e+01)*S259'
.param V43_part27='V43_part26+0.000000e+00*S260+(-3.729112e+01)*S261+(-4.333663e+01)*S262+(-1.752240e+01)*S263+(-3.707302e+01)*S264+(-1.378930e+01)*S265+(-1.199455e+01)*S266+(-2.965674e+01)*S267+(-2.786103e+01)*S268+(-3.210126e+01)*S269'
.param V43_part28='V43_part27+(-1.256972e+01)*S270+(-2.178703e+01)*S271+(-4.661958e+01)*S272+(-1.366094e+01)*S273+(-4.540382e+01)*S274+(-4.257104e+01)*S275+(-1.116280e+01)*S276+9.377490e-01*S277+(-9.221875e-01)*S278+(-4.668071e+01)*S279'
.param V43_part29='V43_part28+(-4.166401e+01)*S280+9.038466e+00*S281+(-2.835439e+00)*S282+(-5.629191e+01)*S283+(-3.577803e+01)*S284+(-2.403425e+00)*S285+(-1.603381e+01)*S286+0.000000e+00*S287+(-2.826233e+01)*S288+(-5.801141e+00)*S289'
.param V43_part30='V43_part29+(-4.550164e+01)*S290+(-4.094493e+01)*S291+(-5.125060e+01)*S292+(-6.732698e+01)*S293+(-4.518909e+01)*S294+(-1.830892e+01)*S295+(-7.573365e+01)*S296+(-2.771165e+01)*S297+(-3.248031e+01)*S298+(-9.858263e+01)*S299'
.param V43_part31='V43_part30+(-2.457913e+01)*S300+0.000000e+00*S301+0.000000e+00*S302+(-2.852225e+01)*S303+(-2.602927e+01)*S304+(-3.856602e+00)*S305+(-5.549658e+01)*S306+(-2.064460e+01)*S307+1.644735e-01*S308+(-5.298992e+00)*S309'
.param V43='V43_part31+(-2.198621e+01)*S310+4.557996e+00*S311+(-6.614406e+01)*S312+7.099251e+00*S313+3.500055e+00*S314'
.param V44_part1='4.783217e-01*S0+(-4.264352e-01)*S1+(-8.047540e-02)*S2+1.822208e-01*S3+(-7.866113e-02)*S4+(-6.040986e-02)*S5+7.193534e-02*S6+(-2.073436e-02)*S7+1.115141e-01*S8+(-3.770145e-03)*S9'
.param V44_part2='V44_part1+2.151456e-02*S10+5.014764e-02*S11+(-8.608090e-02)*S12+0.000000e+00*S13+0.000000e+00*S14+1.233115e-01*S15+2.653685e-01*S16+0.000000e+00*S17+5.763614e-01*S18+(-6.161263e-02)*S19'
.param V44_part3='V44_part2+(-5.364001e-02)*S20+1.156741e-02*S21+(-7.485506e-02)*S22+(-1.349150e-03)*S23+8.052656e-02*S24+1.413777e-02*S25+(-1.706729e-01)*S26+1.185843e-01*S27+1.708290e-01*S28+(-1.442271e-02)*S29'
.param V44_part4='V44_part3+0.000000e+00*S30+2.896021e-01*S31+2.783760e-01*S32+(-1.556090e+00)*S33+0.000000e+00*S34+1.100822e-01*S35+(-2.483851e+00)*S36+0.000000e+00*S37+(-8.513816e-01)*S38+0.000000e+00*S39'
.param V44_part5='V44_part4+0.000000e+00*S40+0.000000e+00*S41+(-5.000401e-01)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-4.508006e+00)*S48+(-3.190593e+00)*S49'
.param V44_part6='V44_part5+(-4.262661e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+9.382198e-01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V44_part7='V44_part6+(-3.812861e+00)*S60+(-4.626539e+00)*S61+0.000000e+00*S62+(-1.465237e+00)*S63+(-5.376690e+00)*S64+4.441342e+00*S65+(-3.708300e+00)*S66+0.000000e+00*S67+(-8.379891e+00)*S68+(-3.922237e+00)*S69'
.param V44_part8='V44_part7+7.102143e+00*S70+0.000000e+00*S71+(-1.196158e+01)*S72+(-1.156493e+01)*S73+0.000000e+00*S74+8.638991e-02*S75+0.000000e+00*S76+(-5.357404e-01)*S77+1.065769e+00*S78+(-4.725933e-01)*S79'
.param V44_part9='V44_part8+(-1.450775e+00)*S80+(-1.879599e+00)*S81+8.842248e-01*S82+(-4.266327e+00)*S83+0.000000e+00*S84+(-4.014220e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V44_part10='V44_part9+(-1.182903e+00)*S90+1.820599e+00*S91+5.522269e-01*S92+(-2.003808e+00)*S93+0.000000e+00*S94+1.132121e+00*S95+(-2.568712e+00)*S96+7.710829e-01*S97+0.000000e+00*S98+(-1.048935e+01)*S99'
.param V44_part11='V44_part10+(-2.520624e+00)*S100+0.000000e+00*S101+(-1.032240e+01)*S102+(-7.464070e+00)*S103+0.000000e+00*S104+(-2.466995e+00)*S105+(-1.470101e+00)*S106+0.000000e+00*S107+(-3.967861e+00)*S108+0.000000e+00*S109'
.param V44_part12='V44_part11+5.902115e-02*S110+0.000000e+00*S111+4.244704e+00*S112+(-9.222669e-01)*S113+(-9.743550e+00)*S114+(-3.173684e+00)*S115+6.933590e-01*S116+0.000000e+00*S117+(-1.432746e+00)*S118+(-6.559110e+00)*S119'
.param V44_part13='V44_part12+2.220852e+00*S120+(-1.689648e-01)*S121+7.303842e-01*S122+2.776073e-02*S123+(-3.756420e-01)*S124+4.050443e-01*S125+0.000000e+00*S126+0.000000e+00*S127+(-3.638476e-01)*S128+5.564700e+00*S129'
.param V44_part14='V44_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+(-2.965136e+00)*S135+(-2.892594e+00)*S136+(-3.677868e-01)*S137+4.598425e-02*S138+(-2.750823e-01)*S139'
.param V44_part15='V44_part14+0.000000e+00*S140+1.549799e+00*S141+8.583974e-01*S142+0.000000e+00*S143+1.553967e+00*S144+1.358140e+00*S145+3.390402e-01*S146+2.342328e+00*S147+1.602253e+00*S148+0.000000e+00*S149'
.param V44_part16='V44_part15+9.341551e-01*S150+3.002912e+00*S151+0.000000e+00*S152+1.287513e+00*S153+(-6.625960e-01)*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+(-8.044895e+00)*S159'
.param V44_part17='V44_part16+0.000000e+00*S160+0.000000e+00*S161+9.965393e+00*S162+(-2.813774e+00)*S163+0.000000e+00*S164+(-7.670358e-02)*S165+1.590092e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V44_part18='V44_part17+3.827391e+00*S170+4.207625e+00*S171+0.000000e+00*S172+(-8.462451e-01)*S173+(-5.734721e-01)*S174+(-3.171478e+00)*S175+3.256465e+00*S176+0.000000e+00*S177+9.136648e+00*S178+1.073323e+01*S179'
.param V44_part19='V44_part18+(-5.229473e-02)*S180+(-2.994964e+00)*S181+5.304674e+00*S182+(-4.244379e+00)*S183+0.000000e+00*S184+4.068396e+00*S185+2.520427e+00*S186+1.038197e+00*S187+2.503701e+00*S188+(-2.656358e-01)*S189'
.param V44_part20='V44_part19+(-5.779694e+00)*S190+9.074141e+00*S191+(-9.239747e+00)*S192+(-6.692011e+00)*S193+2.012166e+00*S194+6.499679e+00*S195+0.000000e+00*S196+0.000000e+00*S197+(-1.231304e+00)*S198+1.601582e+00*S199'
.param V44_part21='V44_part20+0.000000e+00*S200+8.791672e-01*S201+1.748293e+00*S202+0.000000e+00*S203+2.841586e+00*S204+6.198311e+00*S205+9.909663e+00*S206+0.000000e+00*S207+(-2.690398e+00)*S208+0.000000e+00*S209'
.param V44_part22='V44_part21+(-2.293988e+00)*S210+0.000000e+00*S211+0.000000e+00*S212+(-4.998846e+00)*S213+0.000000e+00*S214+0.000000e+00*S215+0.000000e+00*S216+1.116687e+01*S217+1.325257e+01*S218+5.465064e+00*S219'
.param V44_part23='V44_part22+(-8.699491e+00)*S220+1.696914e+01*S221+8.813365e+00*S222+(-1.133569e+01)*S223+(-1.202170e+00)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-3.129019e+00)*S228+(-6.089379e+00)*S229'
.param V44_part24='V44_part23+(-6.520669e+00)*S230+6.441069e+00*S231+1.095547e+00*S232+(-2.981370e+00)*S233+1.026202e+01*S234+(-8.066617e+00)*S235+(-1.102268e+01)*S236+2.176541e+01*S237+1.788780e+01*S238+(-1.363323e+00)*S239'
.param V44_part25='V44_part24+(-1.176440e+00)*S240+0.000000e+00*S241+0.000000e+00*S242+0.000000e+00*S243+6.657632e+00*S244+(-8.109556e+00)*S245+1.210594e+01*S246+(-1.055100e+01)*S247+(-1.093662e+01)*S248+1.640879e+01*S249'
.param V44_part26='V44_part25+1.182135e+01*S250+0.000000e+00*S251+2.406344e+01*S252+2.308708e+00*S253+0.000000e+00*S254+0.000000e+00*S255+0.000000e+00*S256+4.634178e+00*S257+0.000000e+00*S258+2.288013e+00*S259'
.param V44_part27='V44_part26+0.000000e+00*S260+(-4.276219e+00)*S261+(-4.625182e+00)*S262+(-8.002721e+00)*S263+(-2.816445e+00)*S264+(-1.578128e+00)*S265+(-1.117927e+01)*S266+(-1.228668e+01)*S267+(-5.768135e+00)*S268+(-8.557281e+00)*S269'
.param V44_part28='V44_part27+2.091172e+00*S270+2.939942e+00*S271+2.343729e+00*S272+1.568300e+00*S273+1.030663e+00*S274+(-3.821455e+00)*S275+2.390757e+00*S276+(-1.741759e+00)*S277+(-8.083243e+00)*S278+1.369578e-01*S279'
.param V44_part29='V44_part28+(-8.645843e+00)*S280+(-4.676319e+00)*S281+1.352250e+01*S282+(-5.867628e+00)*S283+(-5.712244e+00)*S284+4.884703e+00*S285+3.285460e+00*S286+0.000000e+00*S287+3.484869e+00*S288+6.514924e+00*S289'
.param V44_part30='V44_part29+6.122934e+00*S290+2.909448e+00*S291+3.204090e+00*S292+1.377851e+01*S293+3.394371e+00*S294+(-1.210132e+01)*S295+2.424898e+01*S296+1.591715e+00*S297+1.426458e+00*S298+2.592668e+01*S299'
.param V44_part31='V44_part30+(-3.141637e+00)*S300+0.000000e+00*S301+0.000000e+00*S302+1.157278e+01*S303+3.832085e-01*S304+(-8.588122e-01)*S305+3.399546e+00*S306+(-8.518958e+00)*S307+(-2.658289e+00)*S308+(-5.375690e+00)*S309'
.param V44='V44_part31+(-6.993873e+00)*S310+(-3.954752e+00)*S311+2.858619e+01*S312+(-1.630219e+01)*S313+(-5.250886e+00)*S314'
.param V45_part1='3.598241e-02*S0+(-7.309953e-01)*S1+4.972186e-01*S2+(-1.401021e-01)*S3+8.243463e-02*S4+5.545428e-01*S5+6.989509e-01*S6+1.165284e+00*S7+1.186852e-01*S8+(-2.909468e-01)*S9'
.param V45_part2='V45_part1+7.516972e-01*S10+(-1.562633e+00)*S11+(-8.377669e-01)*S12+(-9.800605e-01)*S13+(-1.581762e+00)*S14+2.505612e+00*S15+(-5.565966e-01)*S16+(-2.195706e+00)*S17+5.394034e-02*S18+(-2.954849e-01)*S19'
.param V45_part3='V45_part2+(-2.629722e+00)*S20+(-8.228632e-01)*S21+(-6.968791e-01)*S22+(-3.079806e+00)*S23+(-8.641365e-01)*S24+(-9.504080e-01)*S25+(-1.628410e-01)*S26+(-2.118307e-01)*S27+(-9.561605e-03)*S28+(-1.097900e-02)*S29'
.param V45_part4='V45_part3+(-1.384990e+00)*S30+1.427920e+00*S31+(-4.257582e+00)*S32+(-8.378752e-01)*S33+(-2.770953e+00)*S34+(-1.698941e+00)*S35+(-1.133108e+00)*S36+(-3.416224e+00)*S37+(-6.183677e+00)*S38+(-2.585440e+00)*S39'
.param V45_part5='V45_part4+(-4.343749e+00)*S40+(-7.140312e+00)*S41+(-2.875611e+00)*S42+(-3.597646e+00)*S43+(-9.535504e+00)*S44+(-2.152944e-01)*S45+(-1.013458e+00)*S46+(-6.844120e+00)*S47+(-1.343614e+00)*S48+(-2.183729e+00)*S49'
.param V45_part6='V45_part5+(-1.032014e+01)*S50+(-1.870723e+00)*S51+(-4.589491e+00)*S52+(-9.980460e+00)*S53+(-1.147671e+01)*S54+(-3.408628e+00)*S55+(-1.023124e+01)*S56+(-1.861740e+00)*S57+(-4.726557e+00)*S58+(-1.020852e+01)*S59'
.param V45_part7='V45_part6+(-7.047755e-01)*S60+(-7.335609e-02)*S61+(-4.923243e+00)*S62+(-7.816632e-01)*S63+(-2.706444e+00)*S64+(-7.706073e+00)*S65+(-1.591384e+00)*S66+(-2.064027e+00)*S67+(-4.654040e+00)*S68+(-1.587864e+00)*S69'
.param V45_part8='V45_part7+(-2.129629e+00)*S70+(-9.884475e+00)*S71+(-1.826984e+00)*S72+(-6.056766e+00)*S73+(-1.313986e+01)*S74+(-3.963013e-01)*S75+(-1.114285e+00)*S76+(-2.320764e+00)*S77+(-5.637843e-01)*S78+(-4.895965e-01)*S79'
.param V45_part9='V45_part8+6.020313e-01*S80+(-1.470295e+00)*S81+(-6.682848e-02)*S82+(-3.386568e+00)*S83+(-1.237458e+00)*S84+(-1.491559e+00)*S85+(-4.798855e+00)*S86+(-1.059904e+00)*S87+(-2.489149e+00)*S88+(-6.062468e+00)*S89'
.param V45_part10='V45_part9+(-1.935805e+00)*S90+(-4.025671e+00)*S91+(-1.089059e+01)*S92+(-2.244036e+00)*S93+(-3.349648e+00)*S94+(-1.147092e+01)*S95+(-2.094632e+00)*S96+(-8.000735e+00)*S97+(-1.447232e+01)*S98+(-2.295253e+00)*S99'
.param V45_part11='V45_part10+(-4.827722e+00)*S100+(-1.643122e+01)*S101+(-2.001303e+00)*S102+(-5.066979e+00)*S103+(-1.574891e+01)*S104+(-2.122334e+00)*S105+(-4.537623e+00)*S106+(-1.224685e+01)*S107+(-2.244920e+00)*S108+(-4.870927e+00)*S109'
.param V45_part12='V45_part11+(-1.093710e+01)*S110+(-1.432931e+00)*S111+(-3.463397e+00)*S112+(-1.243270e+01)*S113+(-1.725335e+00)*S114+(-4.057953e+00)*S115+(-1.217638e+01)*S116+(-1.231379e+00)*S117+(-3.940155e+00)*S118+(-6.052550e+00)*S119'
.param V45_part13='V45_part12+(-9.265261e-01)*S120+(-6.667094e+00)*S121+(-1.542578e+01)*S122+(-5.306425e+00)*S123+(-6.017255e+00)*S124+(-1.535059e+01)*S125+(-2.046010e+00)*S126+(-4.901116e+00)*S127+(-1.396823e+01)*S128+(-1.600830e+00)*S129'
.param V45_part14='V45_part13+(-3.523809e+00)*S130+(-1.054137e+01)*S131+(-1.213680e+00)*S132+(-4.327316e+00)*S133+(-5.917846e+00)*S134+(-4.939816e-01)*S135+(-1.853489e+00)*S136+(-7.988074e+00)*S137+(-9.070320e-01)*S138+(-5.331808e+00)*S139'
.param V45_part15='V45_part14+(-9.506211e+00)*S140+(-2.159258e+00)*S141+(-4.215207e+00)*S142+(-1.113815e+01)*S143+(-3.134134e+00)*S144+(-5.479532e+00)*S145+(-1.125466e+01)*S146+(-4.323480e+00)*S147+(-6.433948e+00)*S148+(-1.256697e+01)*S149'
.param V45_part16='V45_part15+(-2.508896e+00)*S150+(-6.899915e+00)*S151+(-1.948743e+01)*S152+(-2.121850e+00)*S153+(-5.191109e+00)*S154+(-2.298185e+01)*S155+(-2.497896e+00)*S156+(-5.592378e+00)*S157+(-1.282846e+01)*S158+(-2.415876e+00)*S159'
.param V45_part17='V45_part16+(-5.588369e+00)*S160+(-1.400218e+01)*S161+(-2.429313e+00)*S162+(-5.752274e+00)*S163+(-1.058705e+01)*S164+(-3.345468e+00)*S165+(-5.540369e+00)*S166+(-2.130442e+01)*S167+(-1.088033e+00)*S168+(-6.286888e+00)*S169'
.param V45_part18='V45_part17+(-7.991517e+00)*S170+(-1.050373e+00)*S171+(-4.426762e+00)*S172+(-1.044613e+01)*S173+(-2.649258e+00)*S174+(-3.494901e+00)*S175+(-1.038783e+01)*S176+(-5.973538e+00)*S177+(-5.707660e+00)*S178+(-9.547283e+00)*S179'
.param V45_part19='V45_part18+(-3.820572e+00)*S180+(-5.183094e+00)*S181+(-6.199378e+00)*S182+(-1.467795e+00)*S183+(-6.009200e+00)*S184+(-1.049589e+01)*S185+(-2.359842e+00)*S186+(-3.609776e+00)*S187+(-1.673446e+01)*S188+(-2.297688e+00)*S189'
.param V45_part20='V45_part19+(-3.179022e+00)*S190+(-1.802205e+01)*S191+(-3.234790e+00)*S192+(-3.172659e+00)*S193+(-1.130272e+01)*S194+3.562985e-01*S195+(-8.281953e+00)*S196+(-1.526852e+01)*S197+(-2.565176e+00)*S198+(-1.198008e+01)*S199'
.param V45_part21='V45_part20+(-1.700063e+01)*S200+(-4.351649e+00)*S201+(-8.316406e+00)*S202+(-2.078929e+01)*S203+(-3.844869e+00)*S204+(-2.604613e+00)*S205+(-1.218936e+01)*S206+(-8.852070e-01)*S207+(-6.183098e+00)*S208+(-8.885609e+00)*S209'
.param V45_part22='V45_part21+(-3.819928e+00)*S210+(-8.136241e+00)*S211+(-2.628711e+01)*S212+(-1.862487e+00)*S213+(-6.566348e+00)*S214+(-2.206094e+01)*S215+(-3.048149e+00)*S216+(-8.414871e+00)*S217+(-2.257240e+01)*S218+(-1.288860e+00)*S219'
.param V45_part23='V45_part22+(-5.912535e+00)*S220+(-2.516361e+01)*S221+(-5.453871e+00)*S222+(-7.105031e+00)*S223+(-1.420816e+01)*S224+(-1.220707e+00)*S225+(-7.387204e+00)*S226+(-2.419546e+01)*S227+(-5.884665e+00)*S228+(-6.589384e+00)*S229'
.param V45_part24='V45_part23+(-1.734107e+01)*S230+(-7.279938e+00)*S231+(-5.325226e+00)*S232+(-1.917827e+01)*S233+(-8.394928e+00)*S234+(-1.002197e+01)*S235+(-2.249111e+01)*S236+(-7.529277e+00)*S237+(-7.964433e+00)*S238+(-1.040973e+01)*S239'
.param V45_part25='V45_part24+(-1.849576e+00)*S240+(-7.196118e+00)*S241+(-2.282406e+01)*S242+(-4.897083e+00)*S243+(-4.386514e+00)*S244+(-1.460870e+01)*S245+(-4.542031e+00)*S246+(-6.197490e+00)*S247+(-1.687076e+01)*S248+(-6.208260e+00)*S249'
.param V45_part26='V45_part25+(-1.112012e+01)*S250+(-1.767427e+01)*S251+(-7.276285e+00)*S252+(-5.572425e+00)*S253+(-1.111430e+01)*S254+(-6.383791e+00)*S255+(-1.358695e+01)*S256+(-1.109336e+01)*S257+(-4.742580e+00)*S258+(-1.947754e+00)*S259'
.param V45_part27='V45_part26+(-1.288825e+01)*S260+(-1.930258e+00)*S261+(-5.041275e+00)*S262+(-9.171924e+00)*S263+(-2.760413e+00)*S264+(-5.712227e+00)*S265+(-1.173354e+01)*S266+(-3.298987e+00)*S267+(-7.032760e+00)*S268+(-4.324720e+00)*S269'
.param V45_part28='V45_part27+(-1.270969e+00)*S270+(-5.408684e+00)*S271+(-2.395172e+00)*S272+(-2.047034e+00)*S273+(-5.810992e+00)*S274+(-1.244015e+01)*S275+(-2.416240e+00)*S276+(-5.883377e+00)*S277+(-1.929279e+01)*S278+(-2.755629e+00)*S279'
.param V45_part29='V45_part28+(-8.337205e+00)*S280+(-2.445370e+01)*S281+(-4.473783e+00)*S282+(-7.816213e+00)*S283+(-1.943807e+01)*S284+(-1.938002e-01)*S285+(-6.874932e+00)*S286+(-1.806476e+01)*S287+(-2.300520e+00)*S288+(-5.939317e+00)*S289'
.param V45_part30='V45_part29+(-1.795620e+01)*S290+(-2.946594e+00)*S291+(-7.048335e+00)*S292+(-2.247410e+01)*S293+(-3.494404e+00)*S294+(-8.771356e+00)*S295+(-2.431488e+01)*S296+(-5.478563e+00)*S297+(-1.044951e+01)*S298+(-2.100933e+01)*S299'
.param V45_part31='V45_part30+(-1.072881e+00)*S300+(-7.323662e+00)*S301+(-1.891575e+01)*S302+(-2.245746e+00)*S303+(-5.229981e+00)*S304+(-1.111703e+01)*S305+(-1.889908e+00)*S306+(-5.215359e+00)*S307+(-1.367130e+01)*S308+(-3.052082e+00)*S309'
.param V45='V45_part31+(-5.993094e+00)*S310+(-2.356283e+01)*S311+(-3.913062e+00)*S312+(-7.555546e+00)*S313+(-2.023075e+01)*S314'
.param V46_part1='2.783959e-01*S0+3.540806e+00*S1+3.960200e+00*S2+1.729478e+00*S3+2.868469e+00*S4+2.247524e+00*S5+9.553915e-01*S6+8.620277e-01*S7+1.558764e+00*S8+1.346809e+00*S9'
.param V46_part2='V46_part1+1.156028e+00*S10+2.900560e+00*S11+1.611471e+00*S12+1.621005e+00*S13+2.122338e+00*S14+9.895655e-01*S15+4.220946e+00*S16+4.048769e+00*S17+2.239279e+00*S18+2.256585e+00*S19'
.param V46_part3='V46_part2+3.931104e+00*S20+2.240724e+00*S21+2.411160e+00*S22+4.711046e+00*S23+1.820407e+00*S24+2.108205e+00*S25+1.260803e+00*S26+1.357364e+00*S27+1.773245e+00*S28+1.395424e+00*S29'
.param V46_part4='V46_part3+7.675368e+00*S30+5.465610e-01*S31+1.163387e+01*S32+4.995054e+00*S33+8.802166e+00*S34+4.800014e+00*S35+4.471040e+00*S36+5.787902e+00*S37+8.443213e+00*S38+4.983430e+00*S39'
.param V46_part5='V46_part4+4.779758e+00*S40+7.643023e+00*S41+4.599160e+00*S42+2.927896e+00*S43+8.503020e+00*S44+6.532337e+00*S45+7.113218e+00*S46+1.295211e+01*S47+7.809220e+00*S48+6.406059e+00*S49'
.param V46_part6='V46_part5+1.588421e+01*S50+7.195424e+00*S51+8.529873e+00*S52+1.297704e+01*S53+2.528469e+01*S54+5.606199e+00*S55+1.177857e+01*S56+5.775043e+00*S57+6.867690e+00*S58+1.148936e+01*S59'
.param V46_part7='V46_part6+1.014115e+01*S60+5.540876e+00*S61+1.130868e+01*S62+9.993639e+00*S63+8.986538e+00*S64+1.526220e+01*S65+7.298811e+00*S66+7.644338e+00*S67+8.037152e+00*S68+6.371217e+00*S69'
.param V46_part8='V46_part7+7.027300e+00*S70+1.251881e+01*S71+6.599131e+00*S72+8.805266e+00*S73+1.212462e+01*S74+4.322994e+00*S75+5.714184e+00*S76+6.405219e+00*S77+4.000026e+00*S78+3.890760e+00*S79'
.param V46_part9='V46_part8+2.607174e+00*S80+4.590860e+00*S81+2.075716e+00*S82+6.017283e+00*S83+4.045761e+00*S84+3.168569e+00*S85+6.011807e+00*S86+3.624362e+00*S87+3.968408e+00*S88+6.206949e+00*S89'
.param V46_part10='V46_part9+1.168380e+01*S90+9.641640e+00*S91+1.399540e+01*S92+8.745825e+00*S93+7.840063e+00*S94+1.615963e+01*S95+7.173470e+00*S96+8.577030e+00*S97+1.734718e+01*S98+7.336695e+00*S99'
.param V46_part11='V46_part10+8.108885e+00*S100+1.666158e+01*S101+6.217373e+00*S102+7.587088e+00*S103+1.424859e+01*S104+1.262256e+01*S105+1.300897e+01*S106+1.519554e+01*S107+1.042913e+01*S108+1.041059e+01*S109'
.param V46_part12='V46_part11+1.147724e+01*S110+8.277095e+00*S111+8.637325e+00*S112+1.193919e+01*S113+7.240859e+00*S114+8.663630e+00*S115+9.760488e+00*S116+6.814156e+00*S117+7.630463e+00*S118+9.136379e+00*S119'
.param V46_part13='V46_part12+8.878170e+00*S120+7.439121e+00*S121+1.704651e+01*S122+2.137821e+01*S123+6.668842e+00*S124+1.506890e+01*S125+8.247960e+00*S126+9.592299e+00*S127+1.248713e+01*S128+7.387990e+00*S129'
.param V46_part14='V46_part13+8.383837e+00*S130+1.172853e+01*S131+6.546992e+00*S132+8.215603e+00*S133+9.299079e+00*S134+1.242708e+01*S135+1.055649e+01*S136+8.093326e+00*S137+3.472392e+00*S138+7.304919e+00*S139'
.param V46_part15='V46_part14+1.109163e+01*S140+6.184802e+00*S141+2.865280e+00*S142+1.190344e+01*S143+6.205577e+00*S144+5.609249e+00*S145+1.059922e+01*S146+6.045583e+00*S147+6.309965e+00*S148+1.171754e+01*S149'
.param V46_part16='V46_part15+1.339037e+01*S150+1.490320e+01*S151+2.353776e+01*S152+8.907160e+00*S153+1.181482e+01*S154+2.464698e+01*S155+8.330291e+00*S156+9.590004e+00*S157+8.273136e+00*S158+7.158472e+00*S159'
.param V46_part17='V46_part16+7.933945e+00*S160+1.265807e+01*S161+6.324025e+00*S162+7.588591e+00*S163+1.139780e+01*S164+1.303721e+01*S165+7.653987e+00*S166+2.768515e+01*S167+9.015505e+00*S168+1.246077e+01*S169'
.param V46_part18='V46_part17+6.393010e+00*S170+7.504074e+00*S171+9.706053e+00*S172+1.215214e+01*S173+7.973487e+00*S174+8.122801e+00*S175+1.300037e+01*S176+8.749901e+00*S177+7.574163e+00*S178+1.297791e+01*S179'
.param V46_part19='V46_part18+1.618508e+01*S180+1.012849e+01*S181+8.654881e+00*S182+9.171999e+00*S183+1.122484e+01*S184+1.377974e+01*S185+8.019786e+00*S186+9.208491e+00*S187+1.423148e+01*S188+6.983336e+00*S189'
.param V46_part20='V46_part19+7.836493e+00*S190+1.419197e+01*S191+7.409105e+00*S192+7.308343e+00*S193+1.329777e+01*S194+1.143682e+01*S195+2.039837e+01*S196+2.079473e+01*S197+6.210732e+00*S198+2.139862e+01*S199'
.param V46_part21='V46_part20+2.061676e+01*S200+8.091527e+00*S201+9.512527e+00*S202+2.277165e+01*S203+7.197195e+00*S204+5.231030e+00*S205+1.354130e+01*S206+6.116739e+00*S207+8.207307e+00*S208+1.044486e+01*S209'
.param V46_part22='V46_part21+1.522325e+01*S210+1.466116e+01*S211+3.403938e+01*S212+8.670160e+00*S213+1.187717e+01*S214+2.179438e+01*S215+7.718692e+00*S216+9.412740e+00*S217+1.814560e+01*S218+6.755558e+00*S219'
.param V46_part23='V46_part22+8.788144e+00*S220+1.806238e+01*S221+8.356406e+00*S222+8.934471e+00*S223+1.410428e+01*S224+1.112192e+01*S225+1.646364e+01*S226+2.216557e+01*S227+9.797035e+00*S228+1.298917e+01*S229'
.param V46_part24='V46_part23+1.574373e+01*S230+1.004881e+01*S231+1.069852e+01*S232+1.536855e+01*S233+9.165610e+00*S234+9.515334e+00*S235+1.709586e+01*S236+8.759924e+00*S237+9.455759e+00*S238+1.055824e+01*S239'
.param V46_part25='V46_part24+1.047496e+01*S240+1.308401e+01*S241+2.508106e+01*S242+9.363219e+00*S243+4.431655e+00*S244+1.212473e+01*S245+7.745031e+00*S246+1.123144e+01*S247+1.569967e+01*S248+8.365767e+00*S249'
.param V46_part26='V46_part25+1.172948e+01*S250+1.212721e+01*S251+8.865050e+00*S252+7.759701e+00*S253+8.365233e+00*S254+2.278369e+01*S255+2.614351e+01*S256+1.030727e+01*S257+1.329614e+01*S258+1.747458e+00*S259'
.param V46_part27='V46_part26+1.421584e+01*S260+7.222635e+00*S261+8.851759e+00*S262+5.714644e+00*S263+8.025993e+00*S264+6.560115e+00*S265+9.831412e+00*S266+8.232724e+00*S267+7.051712e+00*S268+5.059590e+00*S269'
.param V46_part28='V46_part27+1.503404e+00*S270+4.592592e+00*S271+9.596633e+00*S272+4.809084e+00*S273+8.255711e+00*S274+1.123430e+01*S275+5.922181e+00*S276+3.809125e+00*S277+1.847438e+01*S278+6.468717e+00*S279'
.param V46_part29='V46_part28+1.099508e+01*S280+2.131464e+01*S281+9.922931e+00*S282+8.890041e+00*S283+1.606357e+01*S284+1.782845e+00*S285+6.065570e+00*S286+1.866078e+01*S287+8.121890e+00*S288+6.706432e+00*S289'
.param V46_part30='V46_part29+1.480507e+01*S290+6.910089e+00*S291+9.294356e+00*S292+2.108922e+01*S293+7.204603e+00*S294+1.113054e+01*S295+2.106829e+01*S296+9.004135e+00*S297+1.139163e+01*S298+1.748291e+01*S299'
.param V46_part31='V46_part30+8.431103e+00*S300+1.478260e+01*S301+2.281226e+01*S302+7.457531e+00*S303+9.707577e+00*S304+9.453180e+00*S305+6.626916e+00*S306+1.085300e+01*S307+1.227401e+01*S308+8.169527e+00*S309'
.param V46='V46_part31+1.031150e+01*S310+1.953545e+01*S311+8.954847e+00*S312+9.832119e+00*S313+1.749017e+01*S314'
.param V47_part1='2.765740e+00*S0+3.327289e+00*S1+2.041327e-01*S2+2.034188e+00*S3+5.010684e-01*S4+5.573544e-01*S5+3.297865e-01*S6+(-3.413493e-01)*S7+1.393949e+00*S8+2.363315e+00*S9'
.param V47_part2='V47_part1+(-1.178367e-01)*S10+2.207055e+00*S11+2.511204e+00*S12+2.744165e+00*S13+2.305442e+00*S14+(-5.967170e+00)*S15+3.358899e+00*S16+4.064292e+00*S17+1.604226e+00*S18+2.059430e+00*S19'
.param V47_part3='V47_part2+4.613710e+00*S20+3.006417e+00*S21+2.663794e+00*S22+3.638663e+00*S23+3.152022e+00*S24+2.602049e+00*S25+2.213233e+00*S26+1.524519e+00*S27+1.051405e+00*S28+1.922790e+00*S29'
.param V47_part4='V47_part3+5.181152e+00*S30+2.487623e+00*S31+8.627633e+00*S32+4.516499e+00*S33+6.810243e+00*S34+5.556163e+00*S35+5.961472e+00*S36+1.154597e+01*S37+9.209173e+00*S38+5.678300e+00*S39'
.param V47_part5='V47_part4+1.081051e+01*S40+1.087927e+01*S41+7.294676e+00*S42+1.228112e+01*S43+1.295014e+01*S44+3.001084e+00*S45+5.361891e+00*S46+1.201554e+01*S47+6.075852e+00*S48+7.205612e+00*S49'
.param V47_part6='V47_part5+1.368613e+01*S50+7.501237e+00*S51+1.223337e+01*S52+1.561087e+01*S53+1.770283e+01*S54+8.305216e+00*S55+1.723722e+01*S56+1.035208e+01*S57+1.591226e+01*S58+1.810470e+01*S59'
.param V47_part7='V47_part6+5.884156e+00*S60+6.125793e+00*S61+1.008607e+01*S62+6.705329e+00*S63+9.639518e+00*S64+1.237864e+01*S65+6.773605e+00*S66+8.192221e+00*S67+1.235034e+01*S68+7.964074e+00*S69'
.param V47_part8='V47_part7+1.071919e+01*S70+1.941514e+01*S71+1.017443e+01*S72+1.776268e+01*S73+1.972778e+01*S74+4.766009e+00*S75+5.598089e+00*S76+6.216399e+00*S77+5.535574e+00*S78+3.880368e+00*S79'
.param V47_part9='V47_part8+3.652126e+00*S80+5.686946e+00*S81+3.871493e+00*S82+7.433190e+00*S83+5.817723e+00*S84+7.158691e+00*S85+8.600301e+00*S86+6.860414e+00*S87+8.281636e+00*S88+1.018231e+01*S89'
.param V47_part10='V47_part9+1.581427e+01*S90+1.743970e+01*S91+2.064867e+01*S92+1.346946e+01*S93+1.847126e+01*S94+2.214628e+01*S95+1.445967e+01*S96+1.997562e+01*S97+2.461427e+01*S98+1.635892e+01*S99'
.param V47_part11='V47_part10+2.287580e+01*S100+2.706203e+01*S101+1.639839e+01*S102+2.310575e+01*S103+3.034144e+01*S104+1.271544e+01*S105+1.646668e+01*S106+2.422369e+01*S107+1.317870e+01*S108+2.125614e+01*S109'
.param V47_part12='V47_part11+2.329644e+01*S110+1.383066e+01*S111+2.125381e+01*S112+2.527586e+01*S113+1.622859e+01*S114+2.148959e+01*S115+2.543952e+01*S116+1.663789e+01*S117+2.259596e+01*S118+2.489389e+01*S119'
.param V47_part13='V47_part12+1.049556e+01*S120+2.100196e+01*S121+2.900562e+01*S122+2.496205e+01*S123+2.110466e+01*S124+2.989275e+01*S125+1.544210e+01*S126+2.574974e+01*S127+2.813518e+01*S128+1.630132e+01*S129'
.param V47_part14='V47_part13+2.413262e+01*S130+3.108432e+01*S131+1.492330e+01*S132+2.474053e+01*S133+2.435720e+01*S134+7.566963e+00*S135+6.740406e+00*S136+1.484176e+01*S137+6.750914e+00*S138+1.461474e+01*S139'
.param V47_part15='V47_part14+1.788752e+01*S140+8.702737e+00*S141+1.774409e+01*S142+1.989735e+01*S143+1.231831e+01*S144+1.945929e+01*S145+2.131259e+01*S146+1.753681e+01*S147+2.141352e+01*S148+2.267992e+01*S149'
.param V47_part16='V47_part15+1.565940e+01*S150+3.162535e+01*S151+3.791185e+01*S152+2.222453e+01*S153+3.154866e+01*S154+4.078113e+01*S155+2.223406e+01*S156+2.574215e+01*S157+3.569378e+01*S158+2.066233e+01*S159'
.param V47_part17='V47_part16+2.770946e+01*S160+3.730744e+01*S161+2.208323e+01*S162+2.914713e+01*S163+3.517047e+01*S164+1.117356e+01*S165+2.424182e+01*S166+4.193200e+01*S167+1.718937e+01*S168+3.262905e+01*S169'
.param V47_part18='V47_part17+2.826110e+01*S170+1.846620e+01*S171+2.603455e+01*S172+3.291203e+01*S173+2.405913e+01*S174+2.361209e+01*S175+3.342329e+01*S176+3.341637e+01*S177+2.881926e+01*S178+3.270530e+01*S179'
.param V47_part19='V47_part18+1.955247e+01*S180+2.790291e+01*S181+2.678785e+01*S182+1.859401e+01*S183+3.480949e+01*S184+3.110917e+01*S185+1.892513e+01*S186+2.426836e+01*S187+4.525027e+01*S188+2.209367e+01*S189'
.param V47_part20='V47_part19+2.420528e+01*S190+4.683595e+01*S191+2.175371e+01*S192+2.534817e+01*S193+3.256160e+01*S194+1.263258e+01*S195+2.311295e+01*S196+3.064936e+01*S197+1.532670e+01*S198+3.024766e+01*S199'
.param V47_part21='V47_part20+3.253847e+01*S200+1.952749e+01*S201+2.668798e+01*S202+3.451094e+01*S203+1.993258e+01*S204+1.838501e+01*S205+3.266933e+01*S206+2.011902e+01*S207+3.027888e+01*S208+3.451207e+01*S209'
.param V47_part22='V47_part21+2.654490e+01*S210+3.913119e+01*S211+5.276773e+01*S212+2.252143e+01*S213+3.205482e+01*S214+5.756893e+01*S215+2.537711e+01*S216+3.857541e+01*S217+5.617909e+01*S218+1.344960e+01*S219'
.param V47_part23='V47_part22+3.248833e+01*S220+5.662636e+01*S221+3.240012e+01*S222+3.497756e+01*S223+4.481459e+01*S224+2.124574e+01*S225+3.614431e+01*S226+6.131198e+01*S227+3.563336e+01*S228+3.351550e+01*S229'
.param V47_part24='V47_part23+4.387133e+01*S230+3.833618e+01*S231+2.983968e+01*S232+4.116690e+01*S233+4.303284e+01*S234+3.334564e+01*S235+4.270407e+01*S236+4.244598e+01*S237+3.527942e+01*S238+4.227375e+01*S239'
.param V47_part25='V47_part24+2.200926e+01*S240+3.789863e+01*S241+5.418980e+01*S242+3.479069e+01*S243+2.170345e+01*S244+4.323684e+01*S245+3.352901e+01*S246+3.540008e+01*S247+3.982619e+01*S248+3.756443e+01*S249'
.param V47_part26='V47_part25+4.603960e+01*S250+4.281758e+01*S251+4.040958e+01*S252+3.434178e+01*S253+3.788286e+01*S254+2.315095e+01*S255+4.042600e+01*S256+3.291599e+01*S257+2.543818e+01*S258+1.871250e+01*S259'
.param V47_part27='V47_part26+4.549896e+01*S260+2.212735e+01*S261+2.837787e+01*S262+3.723014e+01*S263+2.386125e+01*S264+2.341371e+01*S265+3.391126e+01*S266+2.399174e+01*S267+2.540796e+01*S268+2.339316e+01*S269'
.param V47_part28='V47_part27+2.139769e+01*S270+2.685922e+01*S271+2.927244e+01*S272+2.190134e+01*S273+3.642949e+01*S274+4.268247e+01*S275+2.271367e+01*S276+3.263051e+01*S277+4.157000e+01*S278+3.207951e+01*S279'
.param V47_part29='V47_part28+3.962478e+01*S280+4.289396e+01*S281+6.903820e+00*S282+4.323808e+01*S283+4.425275e+01*S284+1.793719e+01*S285+3.081691e+01*S286+5.795294e+01*S287+2.769702e+01*S288+2.620363e+01*S289'
.param V47_part30='V47_part29+5.507170e+01*S290+3.056786e+01*S291+3.920776e+01*S292+5.640947e+01*S293+3.282483e+01*S294+4.090145e+01*S295+5.785255e+01*S296+3.360748e+01*S297+4.448929e+01*S298+5.812822e+01*S299'
.param V47_part31='V47_part30+2.280419e+01*S300+3.836154e+01*S301+5.348213e+01*S302+2.653523e+01*S303+3.361002e+01*S304+3.524737e+01*S305+2.754770e+01*S306+3.347333e+01*S307+3.699253e+01*S308+2.871193e+01*S309'
.param V47='V47_part31+3.597701e+01*S310+4.349009e+01*S311+2.965604e+01*S312+3.826469e+01*S313+4.183262e+01*S314'
.param V48_part1='(-5.093190e-02)*S0+6.262571e-01*S1+(-8.623094e-02)*S2+3.648740e-02*S3+1.076472e-01*S4+3.682461e-01*S5+1.666124e-01*S6+2.447412e-01*S7+2.090850e-01*S8+7.957507e-02*S9'
.param V48_part2='V48_part1+2.038856e-01*S10+4.471227e-01*S11+4.195427e-01*S12+1.755147e-01*S13+6.413736e-01*S14+5.853948e-01*S15+7.111131e-01*S16+7.293898e-01*S17+5.832044e-02*S18+4.021478e-01*S19'
.param V48_part3='V48_part2+5.122657e-01*S20+3.591371e-01*S21+2.522083e-01*S22+1.531970e+00*S23+3.799393e-01*S24+6.622005e-01*S25+1.090166e+00*S26+4.931953e-01*S27+4.527864e-01*S28+3.950148e-01*S29'
.param V48_part4='V48_part3+8.507243e-01*S30+9.139586e-02*S31+1.781252e+00*S32+1.617052e-01*S33+1.174087e+00*S34+4.032762e-01*S35+1.918758e-01*S36+4.777725e-01*S37+8.464504e-01*S38+(-2.273960e-01)*S39'
.param V48_part5='V48_part4+2.044269e-01*S40+1.023626e+00*S41+(-4.813593e-01)*S42+5.493526e-01*S43+1.074473e+00*S44+5.689231e-01*S45+4.411693e-01*S46+1.736386e+00*S47+1.826515e-01*S48+4.034631e-01*S49'
.param V48_part6='V48_part5+7.539288e-01*S50+2.072662e-01*S51+6.488875e-01*S52+1.257983e+00*S53+(-5.760055e-01)*S54+(-5.524879e-01)*S55+1.000670e+00*S56+4.180554e-01*S57+6.628005e-01*S58+9.391925e-01*S59'
.param V48_part7='V48_part6+5.308537e-01*S60+3.413491e-01*S61+7.947914e-01*S62+1.131102e+00*S63+6.673343e-01*S64+1.253417e+00*S65+7.657343e-01*S66+2.710545e-01*S67+5.589503e-01*S68+8.021704e-01*S69'
.param V48_part8='V48_part7+2.561187e-01*S70+1.348909e+00*S71+1.027220e+00*S72+1.159267e+00*S73+2.287429e-01*S74+8.121550e-01*S75+8.410516e-01*S76+2.707241e-01*S77+6.953036e-01*S78+(-1.571513e-02)*S79'
.param V48_part9='V48_part8+3.072975e-01*S80+1.209632e+00*S81+3.368271e-01*S82+1.880354e+00*S83+1.447429e+00*S84+1.390525e+00*S85+2.488018e+00*S86+1.376930e+00*S87+8.423953e-01*S88+2.220772e+00*S89'
.param V48_part10='V48_part9+1.235324e+00*S90+(-5.712044e-01)*S91+2.297554e+00*S92+7.685679e-01*S93+(-4.178317e-01)*S94+1.115202e+00*S95+6.348484e-01*S96+8.428351e-01*S97+9.143794e-01*S98+6.905117e-01*S99'
.param V48_part11='V48_part10+6.836211e-01*S100+9.756875e-01*S101+4.782726e-01*S102+3.729845e-01*S103+8.817952e-01*S104+6.267655e-01*S105+2.382758e-01*S106+1.792778e+00*S107+5.310352e-01*S108+5.584980e-01*S109'
.param V48_part12='V48_part11+8.745538e-01*S110+1.918801e-01*S111+(-1.111579e+00)*S112+2.037272e+00*S113+(-6.330613e-01)*S114+(-9.539370e-01)*S115+1.375648e+00*S116+(-4.810481e-01)*S117+(-6.097140e-01)*S118+(-1.568570e+00)*S119'
.param V48_part13='V48_part12+(-1.425597e-01)*S120+2.359029e+00*S121+1.657164e+00*S122+9.929970e-01*S123+1.672198e+00*S124+1.880135e+00*S125+1.719797e-01*S126+2.756706e-01*S127+2.355954e+00*S128+(-9.812794e-01)*S129'
.param V48_part14='V48_part13+(-8.527115e-03)*S130+(-7.102316e-01)*S131+(-6.993634e-02)*S132+(-2.185557e-01)*S133+(-1.064352e+00)*S134+1.899566e+00*S135+8.769960e-01*S136+1.576833e+00*S137+2.624381e-01*S138+4.619128e-01*S139'
.param V48_part15='V48_part14+1.247074e+00*S140+1.564232e-01*S141+5.786075e-01*S142+1.497513e+00*S143+1.504441e-01*S144+3.137337e-01*S145+8.586496e-01*S146+1.658608e-01*S147+1.967797e-02*S148+1.832541e-01*S149'
.param V48_part16='V48_part15+(-1.053083e+00)*S150+(-2.172663e+00)*S151+7.642180e-01*S152+(-1.122395e-01)*S153+(-1.786140e+00)*S154+1.006238e+00*S155+(-1.168062e-01)*S156+(-2.258356e-01)*S157+3.040423e-01*S158+(-1.875328e-01)*S159'
.param V48_part17='V48_part16+(-7.403014e-02)*S160+(-4.351692e-01)*S161+(-3.742351e-02)*S162+(-4.922143e-01)*S163+(-7.043022e-01)*S164+8.613741e-01*S165+(-7.696483e-01)*S166+3.278917e-01*S167+(-4.786751e-01)*S168+(-8.167614e-01)*S169'
.param V48_part18='V48_part17+(-6.877798e-01)*S170+(-3.906672e-01)*S171+(-1.674059e-01)*S172+1.683088e-01*S173+(-5.552887e-01)*S174+(-3.580075e-01)*S175+2.801321e-01*S176+8.252964e-01*S177+(-4.937262e-02)*S178+6.089348e-01*S179'
.param V48_part19='V48_part18+5.020011e-01*S180+(-1.208273e+00)*S181+(-2.925774e+00)*S182+(-9.039390e-01)*S183+(-1.324331e-01)*S184+(-2.133225e-02)*S185+7.535669e-01*S186+(-6.739071e-01)*S187+(-1.754250e+00)*S188+(-4.413835e-01)*S189'
.param V48_part20='V48_part19+(-4.743948e-01)*S190+(-1.296520e+00)*S191+1.970765e-03*S192+(-5.135831e-01)*S193+2.341340e-01*S194+6.080788e-01*S195+(-5.674987e-01)*S196+1.141092e-01*S197+1.332564e+00*S198+2.079311e-01*S199'
.param V48_part21='V48_part20+(-1.626369e-01)*S200+(-1.487712e-01)*S201+1.471981e+00*S202+2.361853e-01*S203+2.184202e-01*S204+6.448732e-01*S205+3.386875e-02*S206+7.719516e-01*S207+(-4.504832e-01)*S208+1.414578e+00*S209'
.param V48_part22='V48_part21+1.592577e+00*S210+(-9.150898e-01)*S211+4.747341e-01*S212+(-3.031365e-01)*S213+(-2.659907e-01)*S214+(-6.613908e-01)*S215+(-2.148373e-01)*S216+(-3.615637e-01)*S217+(-5.689275e-01)*S218+2.476207e-01*S219'
.param V48_part23='V48_part22+(-8.089642e-02)*S220+(-6.240882e-01)*S221+(-2.282901e-01)*S222+(-1.756604e-02)*S223+3.028424e-01*S224+(-7.194137e-01)*S225+(-3.740521e-01)*S226+1.515047e+00*S227+(-1.956830e-01)*S228+(-3.093609e-01)*S229'
.param V48_part24='V48_part23+(-2.793875e-01)*S230+1.599268e-01*S231+(-3.894595e-01)*S232+(-1.229293e+00)*S233+(-2.660816e-01)*S234+(-8.871175e-01)*S235+(-1.591060e+00)*S236+(-7.204838e-01)*S237+(-1.407892e-02)*S238+(-4.691736e-01)*S239'
.param V48_part25='V48_part24+(-9.815278e-01)*S240+(-1.204018e+00)*S241+(-8.471596e-01)*S242+(-2.417466e-01)*S243+1.436833e-01*S244+(-1.048699e+00)*S245+(-7.204698e-01)*S246+(-6.319480e-01)*S247+(-9.547666e-01)*S248+(-3.119164e-01)*S249'
.param V48_part26='V48_part25+(-1.564488e-01)*S250+(-3.454306e-01)*S251+(-4.148653e-01)*S252+(-1.113183e-01)*S253+(-3.021560e-01)*S254+6.955525e-01*S255+(-2.753126e-01)*S256+(-2.500329e+00)*S257+(-1.123731e-01)*S258+(-1.360903e+00)*S259'
.param V48_part27='V48_part26+6.891244e-01*S260+4.610894e-01*S261+4.761792e-01*S262+(-1.032819e-01)*S263+4.753796e-01*S264+(-1.131440e+00)*S265+(-9.558513e-01)*S266+4.678091e-01*S267+(-8.870266e-01)*S268+(-1.506698e+00)*S269'
.param V48_part28='V48_part27+1.047052e-02*S270+3.648801e-02*S271+(-2.043541e+00)*S272+3.052690e-02*S273+(-1.672985e-01)*S274+(-2.356730e+00)*S275+(-5.622590e-03)*S276+(-7.848278e-01)*S277+(-2.008913e+00)*S278+(-2.564099e-01)*S279'
.param V48_part29='V48_part28+3.302293e-01*S280+(-2.199544e+00)*S281+1.509710e-01*S282+(-1.738676e-01)*S283+(-1.774208e+00)*S284+4.622410e-01*S285+(-2.166264e-01)*S286+(-1.597318e+00)*S287+(-3.773166e-02)*S288+(-1.407364e-01)*S289'
.param V48_part30='V48_part29+8.616556e-01*S290+(-2.752327e-01)*S291+(-3.262034e-01)*S292+1.007819e+00*S293+(-1.534617e-01)*S294+2.158074e-02*S295+9.416281e-01*S296+3.856988e-05*S297+1.143415e-01*S298+9.066158e-01*S299'
.param V48_part31='V48_part30+5.033722e-02*S300+6.440919e-01*S301+1.904240e-02*S302+2.751534e-01*S303+1.825152e-01*S304+(-1.429105e+00)*S305+2.509757e-01*S306+6.457291e-01*S307+(-2.110381e+00)*S308+6.808402e-01*S309'
.param V48='V48_part31+5.944748e-01*S310+(-2.339837e+00)*S311+4.214605e-01*S312+7.166459e-01*S313+(-2.424034e+00)*S314'
.param V49_part1='9.490398e-04*S0+(-5.055013e-04)*S1+3.433153e-07*S2+(-8.268713e-03)*S3+(-5.682840e-06)*S4+(-9.270820e-05)*S5+4.774171e-03*S6+1.512301e-03*S7+4.517316e-03*S8+(-6.495849e-03)*S9'
.param V49_part2='V49_part1+1.362441e-02*S10+(-1.266802e-02)*S11+(-2.765567e-02)*S12+(-9.279181e-03)*S13+6.150976e-03*S14+4.534615e-02*S15+1.369684e-02*S16+2.225791e-02*S17+2.517195e-02*S18+7.239817e-03*S19'
.param V49_part3='V49_part2+2.256813e-02*S20+8.887983e-03*S21+7.687188e-03*S22+1.550029e-02*S23+(-6.265135e-03)*S24+3.818118e-03*S25+(-8.117955e-04)*S26+5.406726e-03*S27+(-6.105850e-04)*S28+1.960734e-03*S29'
.param V49_part4='V49_part3+6.981394e-02*S30+(-3.903876e-03)*S31+1.502264e-01*S32+(-1.520235e-01)*S33+8.312759e-02*S34+8.714322e-02*S35+(-3.763875e-01)*S36+(-6.488180e-01)*S37+2.249492e-02*S38+(-3.498386e-02)*S39'
.param V49_part5='V49_part4+4.263031e-02*S40+7.740702e-02*S41+(-1.480157e-03)*S42+7.536125e-02*S43+1.033277e-01*S44+(-7.958246e-02)*S45+(-5.404500e-02)*S46+(-9.632513e-02)*S47+(-5.289533e-01)*S48+(-3.471195e-01)*S49'
.param V49_part6='V49_part5+(-7.881730e-01)*S50+(-7.969351e-01)*S51+(-8.556363e-01)*S52+(-5.958923e-01)*S53+(-2.190050e+00)*S54+4.229178e-01*S55+(-8.829738e-01)*S56+(-1.240612e+00)*S57+(-1.355610e+00)*S58+(-5.723646e-02)*S59'
.param V49_part7='V49_part6+(-3.932658e-01)*S60+(-4.428159e-01)*S61+(-7.327092e-01)*S62+(-1.197652e+00)*S63+(-8.432388e-01)*S64+(-1.034630e+00)*S65+(-8.839681e-01)*S66+(-1.098226e+00)*S67+(-1.073793e+00)*S68+(-9.331163e-01)*S69'
.param V49_part8='V49_part7+(-1.409158e+00)*S70+(-1.715902e+00)*S71+(-1.341263e+00)*S72+(-1.417766e+00)*S73+4.450822e-01*S74+1.129692e-02*S75+5.631051e-02*S76+7.882407e-03*S77+(-6.250818e-03)*S78+6.517094e-04*S79'
.param V49_part9='V49_part8+(-2.216536e-01)*S80+(-1.565335e-01)*S81+(-1.245686e-01)*S82+(-2.134477e-01)*S83+(-3.501696e-01)*S84+(-2.906117e-01)*S85+(-3.280209e-01)*S86+(-6.273827e-01)*S87+(-2.855263e-01)*S88+(-4.246419e-01)*S89'
.param V49_part10='V49_part9+(-1.043290e+00)*S90+(-5.568953e-01)*S91+6.180785e-01*S92+(-7.724840e-01)*S93+(-8.764964e-01)*S94+7.612630e-01*S95+(-8.340246e-01)*S96+6.591761e-01*S97+7.795847e-01*S98+(-1.224948e+00)*S99'
.param V49_part11='V49_part10+(-1.413228e+00)*S100+8.482269e-01*S101+(-1.134906e+00)*S102+(-1.433752e+00)*S103+(-5.584918e-01)*S104+(-7.537866e-01)*S105+(-5.513959e-01)*S106+9.322954e-01*S107+(-8.299582e-01)*S108+(-1.061956e+00)*S109'
.param V49_part12='V49_part11+3.718979e-01*S110+(-1.234391e+00)*S111+(-1.302534e+00)*S112+6.954289e-01*S113+(-9.414941e-01)*S114+(-1.207306e+00)*S115+7.490457e-01*S116+(-1.447969e+00)*S117+(-1.235409e+00)*S118+(-2.272874e+00)*S119'
.param V49_part13='V49_part12+(-3.157950e-01)*S120+4.597341e-01*S121+1.143086e+00*S122+(-1.376609e+00)*S123+5.353925e-01*S124+1.046906e+00*S125+(-8.908110e-01)*S126+(-1.356269e+00)*S127+9.302423e-01*S128+(-8.939615e-01)*S129'
.param V49_part14='V49_part13+(-1.843861e+00)*S130+(-2.007375e+00)*S131+(-1.223611e+00)*S132+(-1.685474e+00)*S133+(-1.888914e+00)*S134+(-6.764805e-01)*S135+(-8.986124e-02)*S136+4.380523e-01*S137+4.012966e-01*S138+6.002986e-01*S139'
.param V49_part15='V49_part14+6.253365e-01*S140+2.741910e-01*S141+6.726168e-01*S142+6.085787e-01*S143+3.466633e-01*S144+5.604605e-01*S145+7.211411e-01*S146+4.517807e-01*S147+5.245219e-01*S148+6.871903e-01*S149'
.param V49_part16='V49_part15+6.243523e-01*S150+(-4.087362e-01)*S151+1.745776e+00*S152+(-7.941905e-01)*S153+(-1.292469e+00)*S154+1.721831e+00*S155+(-7.177999e-01)*S156+(-8.271725e-01)*S157+8.375712e-01*S158+(-7.362298e-01)*S159'
.param V49_part17='V49_part16+(-7.644471e-01)*S160+(-1.388323e+00)*S161+(-8.814874e-01)*S162+(-8.683089e-01)*S163+(-1.872764e+00)*S164+1.080390e+00*S165+5.320724e-01*S166+1.422010e+00*S167+(-9.174541e-01)*S168+(-1.062394e+00)*S169'
.param V49_part18='V49_part17+8.265793e-01*S170+(-8.084230e-01)*S171+(-1.192300e+00)*S172+(-9.564208e-01)*S173+(-6.375961e-01)*S174+(-1.139013e+00)*S175+(-1.201012e+00)*S176+(-9.471418e-01)*S177+(-6.379054e-01)*S178+(-1.704234e+00)*S179'
.param V49_part19='V49_part18+2.170797e-01*S180+(-3.282306e-01)*S181+9.622957e-01*S182+(-4.751435e-01)*S183+(-9.842089e-01)*S184+1.754429e+00*S185+(-5.334283e-01)*S186+(-8.546616e-01)*S187+(-1.102973e+00)*S188+(-6.669616e-01)*S189'
.param V49_part20='V49_part19+(-9.256346e-01)*S190+(-1.252804e+00)*S191+(-6.177352e-01)*S192+(-9.620203e-01)*S193+(-1.478629e+00)*S194+(-1.511087e+00)*S195+8.110725e-01*S196+1.280463e+00*S197+5.093145e-01*S198+1.301217e+00*S199'
.param V49_part21='V49_part20+1.247237e+00*S200+7.563304e-01*S201+9.088021e-01*S202+1.347928e+00*S203+8.574764e-01*S204+4.081568e-01*S205+(-1.480402e+00)*S206+(-1.145696e+00)*S207+(-7.574960e-01)*S208+(-2.079661e+00)*S209'
.param V49_part22='V49_part21+(-1.908287e-01)*S210+(-4.644002e-01)*S211+2.814397e+00*S212+(-4.721990e-01)*S213+(-4.621533e-01)*S214+(-1.780257e-01)*S215+(-1.906244e-01)*S216+(-2.429077e-01)*S217+(-1.008326e+00)*S218+5.891741e-01*S219'
.param V49_part23='V49_part22+(-6.483469e-01)*S220+(-6.894250e-01)*S221+(-3.674220e-01)*S222+(-8.465255e-01)*S223+(-1.651733e+00)*S224+(-5.916089e-01)*S225+(-1.075657e+00)*S226+1.948906e-01*S227+3.654986e-01*S228+(-6.634158e-01)*S229'
.param V49_part24='V49_part23+1.676470e+00*S230+(-4.943444e-02)*S231+(-8.161765e-01)*S232+2.078451e+00*S233+2.022130e-01*S234+1.005302e+00*S235+1.875454e+00*S236+(-1.980043e-01)*S237+(-6.470819e-01)*S238+(-1.045115e+00)*S239'
.param V49_part25='V49_part24+1.663599e-01*S240+(-6.750687e-01)*S241+3.057048e-01*S242+4.153442e-01*S243+5.574541e-01*S244+1.902139e+00*S245+9.417354e-02*S246+(-7.848698e-01)*S247+1.809688e+00*S248+(-1.759894e-02)*S249'
.param V49_part26='V49_part25+(-2.321812e-01)*S250+1.295429e+00*S251+(-1.089907e-01)*S252+(-5.706320e-01)*S253+1.345671e+00*S254+2.103078e+00*S255+1.693953e+00*S256+1.055207e+00*S257+8.592097e-01*S258+6.956300e-01*S259'
.param V49_part27='V49_part26+(-2.229974e+00)*S260+(-6.146989e-01)*S261+(-7.614673e-01)*S262+5.842452e-01*S263+(-8.376382e-01)*S264+6.893345e-01*S265+7.264752e-01*S266+(-9.045894e-01)*S267+7.297079e-01*S268+6.223645e-01*S269'
.param V49_part28='V49_part27+9.782486e-01*S270+6.139244e-01*S271+3.191192e-01*S272+6.684880e-01*S273+(-7.683988e-02)*S274+5.137095e-01*S275+5.463481e-01*S276+6.499721e-01*S277+1.179529e+00*S278+(-7.009665e-02)*S279'
.param V49_part29='V49_part28+(-5.219713e-01)*S280+2.177696e+00*S281+1.745832e+00*S282+(-4.627179e-01)*S283+2.033095e+00*S284+8.092791e-01*S285+8.776994e-01*S286+(-9.193077e-01)*S287+(-7.725717e-02)*S288+6.694095e-01*S289'
.param V49_part30='V49_part29+(-6.467144e-01)*S290+1.370812e-01*S291+(-4.468121e-02)*S292+(-1.655365e-02)*S293+8.054652e-02*S294+(-3.195537e-01)*S295+(-2.259667e-01)*S296+(-2.055703e-01)*S297+(-2.895335e-01)*S298+(-2.658410e-02)*S299'
.param V49_part31='V49_part30+(-5.557457e-01)*S300+(-2.173658e-01)*S301+(-1.073662e+00)*S302+(-9.761001e-02)*S303+(-7.227919e-01)*S304+1.123461e+00*S305+(-1.192539e-01)*S306+(-1.131849e+00)*S307+1.161744e+00*S308+(-6.311564e-01)*S309'
.param V49='V49_part31+(-1.231121e+00)*S310+2.207002e+00*S311+(-8.622735e-01)*S312+(-8.883700e-01)*S313+2.232121e+00*S314'
.param V50_part1='9.154115e+03*S0+3.828104e+01*S1+2.765497e+01*S2+7.446038e+02*S3+2.738614e+01*S4+2.502042e+01*S5+1.434663e+01*S6+2.504766e+01*S7+1.749407e+01*S8+2.181358e+01*S9'
.param V50_part2='V50_part1+3.285700e+01*S10+4.170195e+01*S11+(-6.281534e-01)*S12+3.532391e+01*S13+3.662456e+01*S14+6.546713e+00*S15+2.106036e+01*S16+2.365522e+01*S17+7.115305e+01*S18+7.597873e+03*S19'
.param V50_part3='V50_part2+2.311363e+01*S20+4.352676e+01*S21+1.471598e+02*S22+4.788468e+01*S23+1.540040e+01*S24+3.338188e+01*S25+2.832113e+01*S26+8.191908e+00*S27+1.760405e+01*S28+2.186413e+01*S29'
.param V50_part4='V50_part3+4.161889e+00*S30+7.589039e+02*S31+8.813698e+00*S32+(-2.073246e+01)*S33+3.101515e+00*S34+9.938946e+00*S35+(-1.109415e+01)*S36+1.486463e+01*S37+1.671043e+01*S38+1.725503e+01*S39'
.param V50_part5='V50_part4+1.634545e+01*S40+1.316692e+01*S41+2.057612e+01*S42+1.078256e+01*S43+1.237059e+01*S44+(-3.249470e+01)*S45+(-8.923250e+01)*S46+(-7.267982e+01)*S47+1.771300e+01*S48+3.057114e+01*S49'
.param V50_part6='V50_part5+6.303193e+00*S50+8.443100e+00*S51+9.889007e+00*S52+8.850366e+01*S53+2.619651e+01*S54+1.686381e+01*S55+1.873574e+03*S56+4.733268e+03*S57+7.525699e+03*S58+4.781721e+00*S59'
.param V50_part7='V50_part6+2.269178e+01*S60+1.170716e+01*S61+2.752356e+01*S62+5.283741e+01*S63+1.059590e+01*S64+1.765645e+01*S65+4.189123e+01*S66+1.504157e+01*S67+1.030113e+01*S68+3.992991e+01*S69'
.param V50_part8='V50_part7+6.618835e+00*S70+1.209271e+01*S71+9.545149e+00*S72+8.815869e+00*S73+8.307767e+00*S74+1.004225e+01*S75+1.031020e+01*S76+2.051585e+01*S77+3.937941e+02*S78+3.966145e+00*S79'
.param V50_part9='V50_part8+1.458111e+01*S80+1.297154e+01*S81+9.941512e+00*S82+2.333949e+01*S83+9.659262e+00*S84+9.680111e+00*S85+1.307729e+01*S86+7.909229e+00*S87+9.463732e+00*S88+1.154653e+01*S89'
.param V50_part10='V50_part9+2.541473e+03*S90+1.098812e+01*S91+8.209067e+01*S92+2.494137e+03*S93+8.865019e+00*S94+6.496428e+00*S95+2.496756e+03*S96+1.258150e+01*S97+5.121442e+00*S98+1.220718e+01*S99'
.param V50_part11='V50_part10+2.591735e+01*S100+4.661098e+00*S101+8.929975e+01*S102+2.108685e+01*S103+5.048392e+00*S104+2.327933e+01*S105+7.857630e+00*S106+8.871681e+00*S107+1.502328e+01*S108+1.397321e+01*S109'
.param V50_part12='V50_part11+2.188014e+03*S110+6.469482e+00*S111+1.090512e+01*S112+3.172329e+01*S113+1.387780e+01*S114+1.261879e+01*S115+1.586469e+01*S116+4.762836e+00*S117+9.514219e+00*S118+3.243022e+00*S119'
.param V50_part13='V50_part12+7.512851e+03*S120+4.271426e+01*S121+7.502804e+03*S122+1.954895e+01*S123+7.505594e+03*S124+6.603616e+01*S125+9.241634e+00*S126+6.643639e+00*S127+9.255287e+02*S128+9.369961e+00*S129'
.param V50_part14='V50_part13+5.540866e+00*S130+4.472522e+00*S131+4.704187e+00*S132+4.905022e+00*S133+3.140663e+00*S134+1.496396e+01*S135+2.298561e+01*S136+1.750250e+01*S137+1.679819e+01*S138+3.201673e+01*S139'
.param V50_part15='V50_part14+1.123951e+01*S140+8.517885e+00*S141+1.539000e+01*S142+8.757010e+00*S143+7.260758e+00*S144+7.385326e+00*S145+4.533404e+02*S146+6.437004e+00*S147+6.251644e+00*S148+2.534020e+03*S149'
.param V50_part16='V50_part15+1.153818e+01*S150+1.218219e+01*S151+5.340155e+00*S152+9.968231e+00*S153+9.982350e+00*S154+4.922629e+00*S155+1.341613e+01*S156+2.176095e+01*S157+3.786314e+00*S158+1.937568e+01*S159'
.param V50_part17='V50_part16+1.215288e+01*S160+7.317109e+00*S161+1.026983e+01*S162+1.629960e+01*S163+3.438186e+00*S164+6.484195e+01*S165+7.029699e+00*S166+6.024684e+00*S167+6.590181e+00*S168+7.166622e+00*S169'
.param V50_part18='V50_part17+6.880040e+00*S170+7.088236e+00*S171+7.921742e+00*S172+8.898561e+00*S173+6.548507e+01*S174+7.638492e+00*S175+9.066902e+00*S176+5.320053e+00*S177+7.430968e+00*S178+6.618617e+00*S179'
.param V50_part19='V50_part18+1.330895e+01*S180+1.361206e+02*S181+5.563385e+00*S182+1.366263e+01*S183+7.528031e+00*S184+1.684169e+01*S185+1.518889e+01*S186+1.889203e+01*S187+2.115466e+01*S188+1.166489e+01*S189'
.param V50_part20='V50_part19+1.458092e+01*S190+1.546079e+01*S191+1.520596e+01*S192+1.235621e+01*S193+5.810108e+00*S194+2.109393e+01*S195+1.100024e+01*S196+1.115376e+01*S197+1.063395e+01*S198+1.203897e+01*S199'
.param V50_part21='V50_part20+2.023973e+01*S200+1.112463e+01*S201+2.424592e+01*S202+2.029771e+01*S203+1.051636e+01*S204+1.082784e+01*S205+1.238418e+01*S206+2.847012e+01*S207+1.108837e+01*S208+5.757525e+01*S209'
.param V50_part22='V50_part21+3.455532e+01*S210+8.000647e+00*S211+2.632825e+01*S212+1.285011e+01*S213+1.563245e+01*S214+1.631951e+01*S215+(-2.849439e+02)*S216+1.623935e+01*S217+1.596592e+01*S218+1.631815e+01*S219'
.param V50_part23='V50_part22+1.005516e+01*S220+1.865221e+01*S221+2.991923e+01*S222+9.816252e+00*S223+3.061096e+00*S224+8.906365e+00*S225+7.365675e+00*S226+4.875616e+00*S227+2.364369e+01*S228+7.552608e+00*S229'
.param V50_part24='V50_part23+4.559582e+00*S230+5.251561e+01*S231+8.285203e+00*S232+4.192238e+00*S233+1.444723e+01*S234+8.805704e+00*S235+4.835492e+00*S236+8.775097e+00*S237+8.464914e+00*S238+5.477818e+00*S239'
.param V50_part25='V50_part24+1.520095e+01*S240+7.034653e+00*S241+5.936480e+00*S242+4.830023e+01*S243+1.083142e+01*S244+4.581260e+00*S245+1.321200e+01*S246+5.962821e+00*S247+4.912553e+00*S248+1.353987e+01*S249'
.param V50_part26='V50_part25+1.866373e+01*S250+4.216661e+00*S251+1.040074e+01*S252+7.951425e+00*S253+4.274792e+00*S254+1.097580e+01*S255+8.895575e+00*S256+4.690035e+00*S257+9.681162e+00*S258+9.160094e+00*S259'
.param V50_part27='V50_part26+4.345564e+00*S260+2.348860e+01*S261+2.769961e+01*S262+4.221773e+00*S263+4.112665e+01*S264+5.960221e+00*S265+4.537433e+00*S266+2.187955e+02*S267+5.301614e+00*S268+6.350350e+00*S269'
.param V50_part28='V50_part27+1.217055e+01*S270+1.204966e+01*S271+8.827436e+00*S272+1.468504e+01*S273+1.542291e+01*S274+6.932902e+00*S275+1.049639e+01*S276+8.064027e+00*S277+6.742859e+00*S278+9.575977e+00*S279'
.param V50_part29='V50_part28+6.778001e+00*S280+6.954086e+00*S281+9.047474e+00*S282+9.323009e+00*S283+6.450231e+00*S284+1.299111e+01*S285+8.014030e+00*S286+5.473125e+00*S287+1.666890e+01*S288+1.032677e+01*S289'
.param V50_part30='V50_part29+1.072134e+01*S290+1.118006e+01*S291+9.097936e+00*S292+1.433921e+01*S293+1.029991e+01*S294+1.025404e+01*S295+9.170623e+00*S296+1.166631e+01*S297+8.754221e+00*S298+6.735208e+00*S299'
.param V50_part31='V50_part30+2.932300e+01*S300+1.058433e+03*S301+5.392740e+00*S302+1.209356e+01*S303+1.238318e+01*S304+7.305975e+00*S305+2.097739e+01*S306+1.037803e+01*S307+7.469631e+00*S308+1.353497e+01*S309'
.param V50='V50_part31+9.531324e+00*S310+5.821917e+00*S311+1.114527e+01*S312+9.837203e+00*S313+6.132793e+00*S314'
.param V51_part1='(-2.163559e+02)*S0+(-6.816450e+01)*S1+(-2.818675e+01)*S2+(-1.474220e+03)*S3+(-2.924058e+01)*S4+(-1.217895e+01)*S5+(-3.981214e+00)*S6+(-6.299826e+00)*S7+1.998675e+01*S8+(-7.441235e+00)*S9'
.param V51_part2='V51_part1+(-1.344404e+01)*S10+(-1.239167e+01)*S11+1.415884e+00*S12+(-7.965968e+00)*S13+(-9.202126e-01)*S14+(-7.405456e+00)*S15+7.354729e+02*S16+(-7.858639e+00)*S17+(-9.477359e+01)*S18+(-6.336355e+01)*S19'
.param V51_part3='V51_part2+(-6.004883e+00)*S20+(-4.526909e+01)*S21+(-1.662803e+02)*S22+(-2.309425e+01)*S23+(-8.049426e+00)*S24+(-9.607546e+00)*S25+(-1.822469e+01)*S26+(-1.353513e+00)*S27+(-8.365952e+00)*S28+(-1.332443e+01)*S29'
.param V51_part4='V51_part3+4.213084e+01*S30+1.000000e+04*S31+(-2.871032e+00)*S32+1.037924e+02*S33+5.004610e+01*S34+2.011812e+01*S35+6.584908e+01*S36+(-6.338316e+00)*S37+(-5.165278e+00)*S38+(-1.052796e+01)*S39'
.param V51_part5='V51_part4+(-6.825449e+00)*S40+(-3.826968e+00)*S41+(-1.197279e+01)*S42+(-1.125339e+00)*S43+(-3.527952e+00)*S44+1.624132e+02*S45+2.835699e+02*S46+1.103169e+02*S47+(-1.316608e+01)*S48+(-8.804027e+00)*S49'
.param V51_part6='V51_part5+(-1.102181e+00)*S50+(-2.742925e+00)*S51+(-5.523462e+00)*S52+(-2.558504e+01)*S53+(-2.827816e+00)*S54+(-6.729024e+00)*S55+(-4.094722e+01)*S56+1.459764e+01*S57+6.105329e+01*S58+(-1.961219e+00)*S59'
.param V51_part7='V51_part6+(-1.063820e+01)*S60+(-1.994922e+00)*S61+(-1.859057e+01)*S62+8.366239e-01*S63+(-2.776617e+00)*S64+(-1.293602e+01)*S65+(-2.647871e+00)*S66+(-1.247194e+01)*S67+(-2.913391e+00)*S68+(-6.583898e+00)*S69'
.param V51_part8='V51_part7+(-4.036971e+00)*S70+(-3.866307e+00)*S71+(-1.396380e+00)*S72+(-2.672938e+00)*S73+(-2.129133e+00)*S74+(-2.912000e+00)*S75+(-6.165109e+00)*S76+(-2.921949e+01)*S77+(-4.803658e+01)*S78+(-1.902103e-01)*S79'
.param V51_part9='V51_part8+6.883586e+00*S80+(-8.975679e+00)*S81+(-2.026169e-01)*S82+(-1.238004e+01)*S83+(-3.528634e+00)*S84+(-3.889130e+00)*S85+(-5.252776e+00)*S86+(-1.400054e+00)*S87+(-3.454413e+00)*S88+(-3.346162e+00)*S89'
.param V51_part10='V51_part9+(-6.679711e+01)*S90+(-8.512127e+00)*S91+(-1.170597e+02)*S92+2.019942e+01*S93+(-5.591447e+00)*S94+(-3.708129e+00)*S95+8.714342e+00*S96+(-6.953094e+00)*S97+(-2.111613e+00)*S98+(-4.130533e+00)*S99'
.param V51_part11='V51_part10+3.927308e+00*S100+(-1.844134e+00)*S101+(-6.062661e+00)*S102+(-5.512604e+00)*S103+(-1.766934e+00)*S104+(-1.156373e+01)*S105+2.270034e+01*S106+(-3.113480e+00)*S107+(-6.384419e+00)*S108+(-6.776249e+00)*S109'
.param V51_part12='V51_part11+(-1.006276e+02)*S110+(-3.066289e+00)*S111+(-5.306704e+00)*S112+(-1.325765e+01)*S113+(-5.629034e+00)*S114+(-5.850940e+00)*S115+(-5.873421e+00)*S116+(-1.673534e+00)*S117+(-3.744870e+00)*S118+(-9.283125e-01)*S119'
.param V51_part13='V51_part12+9.667582e+00*S120+7.481303e+00*S121+(-1.222144e+00)*S122+(-5.923013e+00)*S123+4.383085e+01*S124+(-1.068156e+01)*S125+(-2.986900e+00)*S126+(-3.055362e+00)*S127+1.677677e+02*S128+(-2.959322e+00)*S129'
.param V51_part14='V51_part13+(-1.504554e+00)*S130+(-7.297755e-01)*S131+(-1.952624e+00)*S132+(-1.497904e+00)*S133+(-8.343833e-01)*S134+(-7.914112e+00)*S135+(-1.749997e+01)*S136+(-1.031622e+01)*S137+(-2.760754e+00)*S138+(-1.331402e+01)*S139'
.param V51_part15='V51_part14+(-4.429789e+00)*S140+(-2.370727e+00)*S141+(-7.619635e+00)*S142+(-2.769975e+00)*S143+(-2.082921e+00)*S144+(-2.981450e+00)*S145+(-1.080140e+01)*S146+(-2.044725e+00)*S147+(-1.965345e+00)*S148+(-1.041568e+01)*S149'
.param V51_part16='V51_part15+(-3.527323e+00)*S150+(-7.336701e+00)*S151+(-2.221946e+00)*S152+(-5.951502e+00)*S153+(-5.505768e+00)*S154+(-1.843673e+00)*S155+(-5.536182e+00)*S156+(-1.833189e+01)*S157+2.930398e-01*S158+(-1.137877e+01)*S159'
.param V51_part17='V51_part16+(-6.152272e+00)*S160+(-2.339244e+00)*S161+(-4.866425e+00)*S162+(-7.040404e+00)*S163+(-8.512693e-01)*S164+(-1.180909e+02)*S165+(-5.117397e+00)*S166+(-1.797542e+00)*S167+(-5.299322e+00)*S168+(-3.299700e+00)*S169'
.param V51_part18='V51_part17+(-4.158708e+00)*S170+(-4.222902e+00)*S171+(-3.929149e+00)*S172+(-4.497894e+00)*S173+(-2.241341e+01)*S174+(-4.758314e+00)*S175+(-4.854055e+00)*S176+(-1.525953e+00)*S177+(-2.919702e+00)*S178+(-2.604597e+00)*S179'
.param V51_part19='V51_part18+(-4.961518e-01)*S180+1.892666e+01*S181+8.183524e-01*S182+(-5.107141e+00)*S183+(-3.544264e+00)*S184+(-1.509008e+01)*S185+(-6.696555e+00)*S186+(-6.756180e+00)*S187+(-7.993209e+00)*S188+(-4.816814e+00)*S189'
.param V51_part20='V51_part19+(-4.952985e+00)*S190+(-4.891245e+00)*S191+(-5.788928e+00)*S192+(-3.685213e+00)*S193+(-1.944242e+00)*S194+(-8.318650e+00)*S195+(-3.808205e+00)*S196+(-3.612359e+00)*S197+(-1.433753e+00)*S198+(-3.427743e+00)*S199'
.param V51_part21='V51_part20+(-4.571504e+00)*S200+(-3.230570e+00)*S201+(-7.093760e+00)*S202+(-4.486180e+00)*S203+(-3.361292e+00)*S204+(-4.358441e+00)*S205+(-4.216417e+00)*S206+(-9.964500e+00)*S207+(-4.078195e+00)*S208+(-1.686005e+01)*S209'
.param V51_part22='V51_part21+(-1.366039e+01)*S210+(-3.367223e+00)*S211+(-6.611038e+00)*S212+(-1.063990e+01)*S213+(-1.332691e+01)*S214+(-5.325293e+00)*S215+(-1.119613e+01)*S216+(-7.668544e+00)*S217+(-6.206868e+00)*S218+(-1.327643e+00)*S219'
.param V51_part23='V51_part22+(-3.302867e+00)*S220+(-7.243548e+00)*S221+(-1.272450e+01)*S222+(-3.791996e+00)*S223+1.907343e-02*S224+(-9.492432e+00)*S225+(-2.097980e+00)*S226+(-1.176839e+00)*S227+(-5.562567e+00)*S228+(-4.732151e+00)*S229'
.param V51_part24='V51_part23+(-7.637995e-01)*S230+(-2.050294e+01)*S231+(-2.224216e+00)*S232+(-5.297854e-01)*S233+(-5.663175e+00)*S234+(-4.705893e+00)*S235+(-1.183599e+00)*S236+(-3.227061e+00)*S237+(-2.292665e+00)*S238+(-9.986119e-01)*S239'
.param V51_part25='V51_part24+(-1.250408e+01)*S240+(-1.847159e+00)*S241+(-9.219981e-01)*S242+(-1.408400e+01)*S243+(-3.753089e+00)*S244+(-9.824128e-01)*S245+(-5.205078e+00)*S246+(-3.129263e+00)*S247+(-1.396792e+00)*S248+(-5.413692e+00)*S249'
.param V51_part26='V51_part25+(-6.706395e+00)*S250+(-9.262454e-01)*S251+(-3.948955e+00)*S252+(-1.716743e+00)*S253+(-7.859793e-01)*S254+(-6.092565e-01)*S255+(-2.253939e-01)*S256+(-9.833509e-01)*S257+(-1.977802e+00)*S258+1.810731e-01*S259'
.param V51_part27='V51_part26+(-7.223082e-02)*S260+(-1.013910e+01)*S261+(-1.616533e+01)*S262+(-8.846183e-01)*S263+(-1.158118e+01)*S264+(-2.207172e+00)*S265+(-1.242968e+00)*S266+(-3.740369e+01)*S267+(-1.266346e+00)*S268+(-2.042353e+00)*S269'
.param V51_part28='V51_part27+(-4.732153e+00)*S270+(-4.948504e+00)*S271+(-1.660522e+00)*S272+(-7.629501e+00)*S273+(-6.577425e+00)*S274+(-3.515203e+00)*S275+(-2.873900e-01)*S276+(-2.253527e+00)*S277+(-2.616076e+00)*S278+(-2.151686e+00)*S279'
.param V51_part29='V51_part28+(-2.457989e+00)*S280+(-3.146257e+00)*S281+1.216965e+00*S282+(-3.633430e+00)*S283+(-2.441244e+00)*S284+(-3.391928e+00)*S285+(-5.885178e+00)*S286+(-1.208512e+00)*S287+(-1.380966e+01)*S288+(-4.076300e+00)*S289'
.param V51_part30='V51_part29+(-2.625167e+00)*S290+(-2.474945e+00)*S291+(-1.996282e+00)*S292+(-5.365271e+00)*S293+(-1.765413e+00)*S294+(-4.365402e+00)*S295+(-3.290196e+00)*S296+(-1.090735e+00)*S297+(-3.943257e+00)*S298+(-2.025205e+00)*S299'
.param V51_part31='V51_part30+(-3.328949e+01)*S300+(-2.858620e+02)*S301+(-1.661446e-01)*S302+(-6.418212e+00)*S303+(-5.760260e+00)*S304+(-1.331662e+00)*S305+(-9.501777e+00)*S306+(-6.469001e+00)*S307+(-2.309675e+00)*S308+(-4.498669e+00)*S309'
.param V51='V51_part31+(-5.390689e+00)*S310+(-2.245281e+00)*S311+(-5.305007e+00)*S312+(-2.501010e+00)*S313+(-2.317122e+00)*S314'
.param V52_part1='(-1.862466e+03)*S0+(-5.948052e+00)*S1+(-3.278192e+00)*S2+5.667872e+02*S3+2.646558e+00*S4+2.742823e+00*S5+(-2.386823e-01)*S6+1.899620e+00*S7+(-2.108559e+00)*S8+9.146648e+00*S9'
.param V52_part2='V52_part1+1.149760e+01*S10+(-7.022597e+00)*S11+7.821221e+01*S12+(-1.533345e+01)*S13+(-8.724387e+00)*S14+(-2.517839e+00)*S15+(-2.494080e+01)*S16+(-8.471644e+00)*S17+(-8.422457e+00)*S18+(-6.008449e+01)*S19'
.param V52_part3='V52_part2+(-9.059568e+00)*S20+(-8.937953e+00)*S21+(-3.243286e+01)*S22+(-1.620748e+01)*S23+(-3.871054e+00)*S24+(-1.711850e+01)*S25+5.258084e+00*S26+(-4.726564e+00)*S27+(-3.970183e+00)*S28+(-1.286986e+00)*S29'
.param V52_part4='V52_part3+1.776239e+01*S30+(-6.477854e+01)*S31+(-3.356877e+00)*S32+1.562606e+01*S33+(-1.101368e+01)*S34+(-6.893990e+00)*S35+1.661148e+01*S36+(-8.715689e+00)*S37+(-5.483629e+00)*S38+(-7.476475e+00)*S39'
.param V52_part5='V52_part4+(-7.573964e+00)*S40+(-4.381731e+00)*S41+(-6.165022e+00)*S42+(-5.619646e+00)*S43+(-4.110806e+00)*S44+7.238455e+01*S45+1.569646e+02*S46+3.461039e+02*S47+5.109909e+00*S48+(-1.175236e+01)*S49'
.param V52_part6='V52_part5+5.300328e+00*S50+(-7.411373e+00)*S51+(-3.844011e+00)*S52+(-4.856207e+01)*S53+(-2.787294e+01)*S54+(-7.364880e+00)*S55+(-2.251251e+02)*S56+6.527188e-01*S57+(-7.194720e+01)*S58+(-4.829904e-01)*S59'
.param V52_part7='V52_part6+(-1.856653e+01)*S60+(-7.617104e+00)*S61+(-1.154641e+01)*S62+(-5.923274e+01)*S63+(-5.649888e+00)*S64+(-4.745960e+00)*S65+(-2.074595e+01)*S66+(-2.080401e+00)*S67+(-3.427527e+00)*S68+(-1.223600e+01)*S69'
.param V52_part8='V52_part7+1.059517e+00*S70+(-4.382515e+00)*S71+3.520330e+00*S72+8.822061e-01*S73+(-2.483758e+00)*S74+(-4.701836e+00)*S75+(-4.847584e+00)*S76+(-1.898769e+00)*S77+1.019849e+01*S78+(-5.294595e-01)*S79'
.param V52_part9='V52_part8+9.128405e-02*S80+(-1.920400e+00)*S81+1.166629e+01*S82+(-7.037993e+00)*S83+(-3.078668e+00)*S84+(-2.968072e+00)*S85+(-4.126114e+00)*S86+(-4.941716e+00)*S87+(-2.598563e+00)*S88+(-3.953540e+00)*S89'
.param V52_part10='V52_part9+6.291440e+01*S90+(-5.476195e-01)*S91+(-4.981848e+00)*S92+9.992223e+01*S93+(-8.206876e-01)*S94+(-1.159007e+00)*S95+7.509030e+01*S96+(-4.220183e+00)*S97+(-9.117778e-01)*S98+(-8.138450e+00)*S99'
.param V52_part11='V52_part10+6.827014e+00*S100+(-6.743838e-01)*S101+1.796829e+01*S102+3.093370e-01*S103+(-6.024144e-01)*S104+(-2.213184e+01)*S105+(-7.438797e-01)*S106+(-3.154051e+00)*S107+(-1.242705e+01)*S108+(-6.061108e+00)*S109'
.param V52_part12='V52_part11+(-4.277985e+02)*S110+(-1.813416e+00)*S111+(-2.876002e+00)*S112+(-6.447393e+00)*S113+(-7.426294e+00)*S114+(-4.431876e+00)*S115+(-4.121569e+00)*S116+(-6.202525e-01)*S117+(-3.378879e+00)*S118+2.090002e-01*S119'
.param V52_part13='V52_part12+1.409304e+00*S120+8.900661e+00*S121+3.585413e+01*S122+(-1.879568e+01)*S123+2.167180e+01*S124+(-9.070068e-01)*S125+(-8.665944e+00)*S126+(-1.861006e+00)*S127+1.286551e+01*S128+(-5.075551e+00)*S129'
.param V52_part14='V52_part13+(-1.837658e+00)*S130+(-1.190312e+00)*S131+3.011390e+00*S132+(-9.624193e-01)*S133+1.034746e+00*S134+(-1.506909e+01)*S135+(-1.190769e+01)*S136+(-7.405356e+00)*S137+(-1.711254e+01)*S138+(-1.954185e+01)*S139'
.param V52_part15='V52_part14+(-4.249853e+00)*S140+(-5.903589e+00)*S141+(-6.776683e+00)*S142+(-2.984675e+00)*S143+(-4.539543e+00)*S144+(-2.455977e+00)*S145+2.129449e+00*S146+(-2.653677e+00)*S147+(-2.193152e+00)*S148+5.164904e+00*S149'
.param V52_part16='V52_part15+(-1.129685e+01)*S150+(-6.596389e+00)*S151+(-1.515408e+00)*S152+(-4.010547e+00)*S153+(-3.882080e+00)*S154+(-1.274243e+00)*S155+(-8.216481e+00)*S156+(-4.800268e+00)*S157+(-8.689086e-01)*S158+(-2.212730e+00)*S159'
.param V52_part17='V52_part16+1.412418e-01*S160+(-9.217618e-01)*S161+1.109951e+00*S162+(-4.244197e+00)*S163+1.125668e+00*S164+(-9.533302e+00)*S165+(-3.417577e+00)*S166+(-1.854415e+00)*S167+1.628044e+00*S168+(-2.775812e+00)*S169'
.param V52_part18='V52_part17+(-1.893553e+00)*S170+(-7.437176e-01)*S171+(-2.594547e+00)*S172+(-7.617484e-01)*S173+(-3.671643e+01)*S174+1.974724e+00*S175+(-1.427354e-01)*S176+(-3.105182e+00)*S177+(-4.858110e-01)*S178+(-2.223431e-02)*S179'
.param V52_part19='V52_part18+(-1.745876e+01)*S180+(-4.519332e+01)*S181+9.714893e-02*S182+(-6.103799e+00)*S183+(-3.268391e+00)*S184+(-2.636362e-01)*S185+2.407445e+01*S186+(-1.007270e+01)*S187+(-7.655815e+00)*S188+(-6.469680e+00)*S189'
.param V52_part20='V52_part19+(-7.254864e+00)*S190+(-5.194182e+00)*S191+(-5.994313e+00)*S192+(-6.087650e+00)*S193+(-2.691066e-02)*S194+(-2.427771e+01)*S195+(-6.814975e+00)*S196+(-4.679115e+00)*S197+(-1.080101e+01)*S198+(-7.665511e+00)*S199'
.param V52_part21='V52_part20+(-8.014045e+00)*S200+(-9.108033e+00)*S201+(-7.487980e+00)*S202+(-7.234063e+00)*S203+(-7.511460e+00)*S204+(-4.988696e+00)*S205+(-2.939544e+00)*S206+(-1.278642e+01)*S207+(-4.530151e+00)*S208+(-2.134553e+01)*S209'
.param V52_part22='V52_part21+(-3.913323e+01)*S210+(-3.323745e+00)*S211+(-9.018987e+00)*S212+(-4.869653e-01)*S213+(-2.954809e+00)*S214+(-4.998684e+00)*S215+1.249297e+03*S216+(-5.624499e+00)*S217+(-4.543782e+00)*S218+(-1.585525e+01)*S219'
.param V52_part23='V52_part22+(-5.193149e+00)*S220+(-4.541905e+00)*S221+(-7.988351e+00)*S222+(-4.270919e+00)*S223+6.342722e-01*S224+(-1.375097e+00)*S225+(-3.764258e+00)*S226+(-2.013551e+00)*S227+(-2.784751e+01)*S228+(-1.657334e+00)*S229'
.param V52_part24='V52_part23+(-1.059909e+00)*S230+(-3.440408e+01)*S231+(-4.698137e+00)*S232+(-1.067738e+00)*S233+(-7.336054e+00)*S234+(-1.033427e+00)*S235+(-8.134484e-01)*S236+(-3.111952e+00)*S237+(-4.218046e+00)*S238+(-2.199955e+00)*S239'
.param V52_part25='V52_part24+(-7.861608e-01)*S240+(-3.229147e+00)*S241+(-2.313985e+00)*S242+(-4.980112e+01)*S243+(-6.629178e+00)*S244+(-1.053527e+00)*S245+(-7.464374e+00)*S246+(-2.305778e-02)*S247+(-1.007846e+00)*S248+(-6.860082e+00)*S249'
.param V52_part26='V52_part25+(-8.653462e+00)*S250+(-1.398499e+00)*S251+(-3.533405e+00)*S252+(-4.639897e+00)*S253+(-8.732762e-01)*S254+(-1.377317e+01)*S255+(-5.679981e+00)*S256+(-2.054965e+00)*S257+(-9.428661e+00)*S258+(-5.297498e+00)*S259'
.param V52_part27='V52_part26+(-1.672896e+00)*S260+(-1.220316e+01)*S261+(-1.294272e+00)*S262+(-7.151262e-01)*S263+5.372378e-01*S264+(-1.303315e+00)*S265+(-7.185322e-01)*S266+(-2.706071e+01)*S267+(-1.483380e+00)*S268+(-1.191817e+00)*S269'
.param V52_part28='V52_part27+(-9.058667e+00)*S270+(-7.686360e+00)*S271+(-4.321277e+00)*S272+(-1.132119e+01)*S273+(-8.198439e+00)*S274+(-2.019815e+00)*S275+(-1.033762e+01)*S276+(-4.471879e+00)*S277+(-1.801324e+00)*S278+(-4.702164e+00)*S279'
.param V52_part29='V52_part28+(-3.045951e+00)*S280+(-1.188370e+00)*S281+(-3.934053e+00)*S282+(-3.051408e+00)*S283+(-1.123721e+00)*S284+(-1.364419e+01)*S285+(-3.891450e+00)*S286+(-1.673128e+00)*S287+4.519164e+00*S288+(-6.124111e+00)*S289'
.param V52_part30='V52_part29+(-1.126207e+00)*S290+(-8.244330e+00)*S291+(-5.859785e+00)*S292+1.854369e+00*S293+(-9.069164e+00)*S294+(-5.703692e+00)*S295+1.250173e+00*S296+(-9.257951e+00)*S297+(-3.207681e+00)*S298+1.625042e+00*S299'
.param V52_part31='V52_part30+(-1.099608e+01)*S300+3.571813e+03*S301+(-2.171191e+00)*S302+2.722638e+00*S303+(-4.572759e+00)*S304+(-2.829977e+00)*S305+9.085721e+00*S306+(-2.580723e+00)*S307+(-2.371293e+00)*S308+(-1.249602e+01)*S309'
.param V52='V52_part31+(-1.407480e+00)*S310+(-1.036114e+00)*S311+(-5.364479e+00)*S312+(-5.608871e+00)*S313+(-1.115352e+00)*S314'
.param V53_part1='4.481593e+03*S0+5.495072e+00*S1+6.105311e-01*S2+(-8.128014e+01)*S3+(-2.839756e+00)*S4+(-5.291391e+00)*S5+(-3.099517e+00)*S6+(-9.033461e+00)*S7+(-3.933314e+00)*S8+2.498343e+00*S9'
.param V53_part2='V53_part1+(-7.965888e+00)*S10+1.044465e+00*S11+(-2.750474e+00)*S12+(-1.872524e+00)*S13+(-5.805004e+00)*S14+(-6.210163e-01)*S15+(-1.199915e+02)*S16+(-2.964990e+00)*S17+1.391061e+00*S18+(-1.000000e+04)*S19'
.param V53_part3='V53_part2+(-1.654643e+00)*S20+1.094016e+01*S21+2.268300e+01*S22+(-2.589164e+00)*S23+9.651147e+00*S24+(-2.568566e-02)*S25+4.077675e+01*S26+9.037879e+00*S27+1.029449e+01*S28+5.794384e+00*S29'
.param V53_part4='V53_part3+(-3.527404e+00)*S30+(-3.056037e+03)*S31+(-2.856114e-01)*S32+(-4.563604e+00)*S33+5.551864e+00*S34+(-3.218956e+00)*S35+(-8.450638e+00)*S36+2.582097e-01*S37+(-1.483485e+00)*S38+9.807418e-01*S39'
.param V53_part5='V53_part4+6.372337e-01*S40+(-1.178889e-01)*S41+2.897056e-01*S42+2.563981e-01*S43+(-1.291759e-01)*S44+6.325043e+00*S45+2.306064e+01*S46+7.191451e+02*S47+(-5.630470e-01)*S48+(-9.869562e+00)*S49'
.param V53_part6='V53_part5+1.588040e+01*S50+2.251671e-01*S51+8.071831e-02*S52+(-2.176745e+00)*S53+(-4.031856e+00)*S54+(-3.269891e-01)*S55+(-2.102340e+03)*S56+(-6.298496e+03)*S57+(-1.000000e+04)*S58+6.576949e-01*S59'
.param V53_part7='V53_part6+1.061339e+00*S60+5.832489e-01*S61+2.788671e-01*S62+1.061231e+01*S63+9.492384e-01*S64+(-4.759158e-01)*S65+6.089945e+01*S66+6.181729e-02*S67+(-1.800289e+00)*S68+7.548554e+01*S69'
.param V53_part8='V53_part7+2.525656e-01*S70+(-7.983602e-01)*S71+1.444606e+01*S72+7.903868e+00*S73+(-1.199778e-01)*S74+(-7.878894e-01)*S75+(-6.744488e-01)*S76+4.841318e+00*S77+1.450324e+03*S78+1.198675e+00*S79'
.param V53_part9='V53_part8+(-9.853093e+00)*S80+(-2.872082e-01)*S81+4.041762e+01*S82+4.013336e+00*S83+9.480057e-02*S84+4.546435e-01*S85+1.440354e+00*S86+2.089230e+00*S87+2.266659e+00*S88+1.304737e+00*S89'
.param V53_part10='V53_part9+1.000000e+04*S90+(-1.220944e+00)*S91+8.316194e+00*S92+1.000000e+04*S93+(-3.796137e-01)*S94+6.337083e-02*S95+1.000000e+04*S96+1.990476e+00*S97+1.306283e-01*S98+(-7.479450e-01)*S99'
.param V53_part11='V53_part10+7.153869e+01*S100+1.358370e-01*S101+3.105527e+02*S102+2.768792e+01*S103+(-2.131582e-01)*S104+(-8.538081e-01)*S105+(-1.421391e+00)*S106+(-2.656350e-01)*S107+(-6.046477e-01)*S108+(-7.187112e-01)*S109'
.param V53_part12='V53_part11+(-2.235077e+03)*S110+(-2.297154e-02)*S111+(-1.773575e+00)*S112+(-9.760144e+00)*S113+(-1.830541e+00)*S114+(-1.165959e+00)*S115+(-3.758896e+00)*S116+1.319356e+00*S117+(-6.270684e-01)*S118+6.673532e-01*S119'
.param V53_part13='V53_part12+(-1.000000e+04)*S120+(-4.383579e+01)*S121+(-1.000000e+04)*S122+3.447699e-01*S123+(-1.000000e+04)*S124+(-5.639452e+01)*S125+3.911806e-01*S126+1.346607e-01*S127+3.746983e+03*S128+(-1.334427e+00)*S129'
.param V53_part14='V53_part13+4.023339e-01*S130+5.391562e-01*S131+5.746649e-01*S132+6.328854e-01*S133+8.374011e-01*S134+6.861152e-01*S135+1.493221e+00*S136+2.350100e+00*S137+(-1.388155e+00)*S138+(-3.245812e+00)*S139'
.param V53_part15='V53_part14+1.618081e-01*S140+(-3.709939e-01)*S141+(-1.529871e+00)*S142+9.076687e-02*S143+(-1.462622e-01)*S144+(-9.151956e-02)*S145+1.650015e+03*S146+(-2.768118e-02)*S147+2.856155e-02*S148+1.000000e+04*S149'
.param V53_part16='V53_part15+3.954664e-01*S150+2.757513e-01*S151+1.155116e-01*S152+3.708990e-01*S153+2.963686e-01*S154+1.246258e-01*S155+2.911141e+00*S156+2.052169e+00*S157+3.048481e-01*S158+2.250486e-01*S159'
.param V53_part17='V53_part16+2.167435e+00*S160+(-1.743344e-01)*S161+(-3.071875e-01)*S162+(-1.885489e+00)*S163+(-1.325388e-01)*S164+1.601000e+01*S165+8.333663e-01*S166+1.096439e-01*S167+8.658469e-01*S168+1.465169e-01*S169'
.param V53_part18='V53_part17+9.790125e-01*S170+8.773245e-01*S171+1.035331e-01*S172+1.500464e+00*S173+(-1.847622e+01)*S174+9.626855e-01*S175+1.762918e+00*S176+3.800414e-01*S177+1.546689e+00*S178+1.323450e+00*S179'
.param V53_part19='V53_part18+2.606557e-01*S180+(-1.168855e+02)*S181+8.861858e-01*S182+(-3.634436e+00)*S183+(-3.257302e-01)*S184+1.461663e+00*S185+2.105805e+01*S186+(-3.617383e+00)*S187+(-3.427899e+00)*S188+1.526028e+00*S189'
.param V53_part20='V53_part19+(-2.557151e+00)*S190+(-2.531090e+00)*S191+(-3.572095e+00)*S192+(-1.876594e+00)*S193+1.234777e+00*S194+1.059848e+00*S195+1.309771e-01*S196+(-9.216499e-01)*S197+(-6.577648e-01)*S198+(-7.613602e-01)*S199'
.param V53_part21='V53_part20+(-4.073993e+00)*S200+(-5.573367e-01)*S201+(-8.660278e+00)*S202+(-3.789973e+00)*S203+(-1.180779e+00)*S204+(-1.086914e+00)*S205+(-1.985529e+00)*S206+(-3.711883e+00)*S207+(-7.954831e-01)*S208+(-9.519327e+00)*S209'
.param V53_part22='V53_part21+1.716775e+00*S210+(-1.539708e-01)*S211+(-7.288038e+00)*S212+1.261551e+00*S213+1.429175e+00*S214+(-3.571779e+00)*S215+8.751583e+01*S216+(-3.008770e+00)*S217+(-2.450906e+00)*S218+1.147900e+00*S219'
.param V53_part23='V53_part22+(-3.588018e-01)*S220+(-3.034127e+00)*S221+(-7.450392e+00)*S222+(-4.027507e-01)*S223+3.275237e-01*S224+6.159342e-01*S225+1.080385e-01*S226+7.863594e-02*S227+(-3.949717e-01)*S228+6.790474e-01*S229'
.param V53_part24='V53_part23+2.582135e-01*S230+(-1.204524e+01)*S231+(-1.665160e-01)*S232+3.076152e-01*S233+(-2.318215e+00)*S234+1.876035e-01*S235+3.932588e-01*S236+(-1.252291e+00)*S237+(-1.026910e+00)*S238+(-1.030892e-02)*S239'
.param V53_part25='V53_part24+2.395924e+00*S240+1.131435e+00*S241+4.210011e-01*S242+(-4.660781e+00)*S243+2.098321e+00*S244+2.069092e-01*S245+(-1.063108e+00)*S246+5.963649e-01*S247+2.391307e-01*S248+(-2.074932e+00)*S249'
.param V53_part26='V53_part25+(-3.619347e+00)*S250+(-9.493238e-02)*S251+(-1.568053e+00)*S252+(-1.522938e-01)*S253+(-1.056682e-01)*S254+1.099691e-01*S255+(-1.093782e+00)*S256+2.088520e-01*S257+(-2.921501e-02)*S258+1.594219e+00*S259'
.param V53_part27='V53_part26+2.778261e-01*S260+3.340248e+00*S261+1.125613e+01*S262+3.270002e-01*S263+2.595873e+01*S264+1.362148e+00*S265+4.405254e-01*S266+(-2.066607e+02)*S267+7.668800e-01*S268+6.866934e-01*S269'
.param V53_part28='V53_part27+2.126293e+00*S270+2.925618e+00*S271+1.104791e+00*S272+2.786446e+00*S273+(-2.640506e-01)*S274+3.711074e-01*S275+4.030290e-01*S276+1.239936e-01*S277+5.257296e-01*S278+(-6.273378e-01)*S279'
.param V53_part29='V53_part28+(-6.077520e-01)*S280+6.006735e-01*S281+(-3.628591e+00)*S282+(-3.689711e-01)*S283+4.137834e-01*S284+1.262047e+00*S285+1.315573e+00*S286+2.889126e-01*S287+5.375444e+00*S288+1.764769e+00*S289'
.param V53_part30='V53_part29+3.506908e+00*S290+(-2.075259e-01)*S291+(-4.463867e-01)*S292+6.111326e+00*S293+3.326151e-03*S294+4.173286e-01*S295+3.380776e+00*S296+(-3.037646e-01)*S297+4.882253e-01*S298+2.779992e+00*S299'
.param V53_part31='V53_part30+4.618001e+00*S300+1.000000e+04*S301+3.171171e-01*S302+4.414046e+00*S303+1.852134e+00*S304+9.733459e-01*S305+1.126782e+01*S306+1.090762e+00*S307+8.568899e-01*S308+4.704149e-01*S309'
.param V53='V53_part31+5.691086e-01*S310+5.701380e-01*S311+(-7.126213e-01)*S312+7.034526e-01*S313+6.391397e-01*S314'
.param V54_part1='(-9.453050e+01)*S0+(-1.089884e+00)*S1+(-7.461954e-02)*S2+2.974564e+01*S3+2.969331e-01*S4+(-1.094947e-01)*S5+(-6.476275e-02)*S6+3.769146e-03*S7+1.519429e-03*S8+(-9.865341e-02)*S9'
.param V54_part2='V54_part1+(-2.882396e-01)*S10+(-1.865346e-01)*S11+(-1.572108e-01)*S12+1.381307e-01*S13+5.079440e-02*S14+(-1.200142e-02)*S15+(-2.202569e+00)*S16+(-5.717728e-02)*S17+(-2.493998e-01)*S18+(-8.134736e-01)*S19'
.param V54_part3='V54_part2+(-2.907335e-02)*S20+1.647332e-01*S21+1.166543e-01*S22+(-1.244539e-01)*S23+(-2.307271e-01)*S24+3.153268e-02*S25+2.614386e-02*S26+(-4.088121e-02)*S27+8.488717e-03*S28+(-1.028691e-01)*S29'
.param V54_part4='V54_part3+(-3.506269e-01)*S30+(-2.479127e+01)*S31+(-3.563833e-02)*S32+(-1.845641e+00)*S33+(-5.850683e-03)*S34+(-3.825113e-01)*S35+(-5.447215e+00)*S36+5.970588e-01*S37+5.824713e-02*S38+3.637872e-01*S39'
.param V54_part5='V54_part4+3.387936e-02*S40+1.424649e-02*S41+2.107716e-01*S42+5.719725e-03*S43+(-1.097389e-02)*S44+5.935434e+00*S45+1.461804e+01*S46+3.001864e+01*S47+1.839106e+00*S48+(-8.481663e-01)*S49'
.param V54_part6='V54_part5+4.404593e-01*S50+8.483456e-01*S51+8.104520e-01*S52+(-6.636531e+00)*S53+7.021553e-01*S54+(-2.123988e-02)*S55+4.177668e+00*S56+1.634959e+01*S57+1.030356e+01*S58+2.470541e-01*S59'
.param V54_part7='V54_part6+(-2.350122e-01)*S60+1.324829e+00*S61+1.272259e+00*S62+(-8.810014e+00)*S63+1.929526e-01*S64+(-9.954107e-02)*S65+(-3.977824e+00)*S66+7.904265e-01*S67+(-1.614119e-01)*S68+(-1.311858e+00)*S69'
.param V54_part8='V54_part7+6.841260e-01*S70+5.805442e-01*S71+(-4.888439e-01)*S72+(-3.783723e-02)*S73+(-9.145624e-02)*S74+(-4.209533e-01)*S75+(-9.117682e-02)*S76+(-5.133630e-02)*S77+5.905275e-01*S78+(-4.907584e-02)*S79'
.param V54_part9='V54_part8+8.247257e-01*S80+7.503011e-02*S81+3.200089e-01*S82+4.154486e-01*S83+4.588012e-01*S84+7.032907e-01*S85+4.325702e-01*S86+8.095381e-01*S87+3.374998e-01*S88+4.212729e-01*S89'
.param V54_part10='V54_part9+(-1.058922e+01)*S90+(-1.687791e+00)*S91+(-8.737758e+00)*S92+(-8.054553e+00)*S93+(-1.285354e+00)*S94+(-1.312606e-01)*S95+(-3.041744e+00)*S96+(-3.471352e-01)*S97+(-1.162401e-01)*S98+2.808322e-02*S99'
.param V54_part11='V54_part10+(-4.005753e-02)*S100+(-8.798073e-02)*S101+8.169402e-01*S102+(-4.802998e-01)*S103+(-2.265585e-01)*S104+(-1.457960e+00)*S105+(-2.107991e+00)*S106+(-1.246840e-01)*S107+(-6.333915e-01)*S108+(-1.191649e+00)*S109'
.param V54_part12='V54_part11+1.730430e+00*S110+6.290819e-01*S111+(-9.729754e-01)*S112+(-8.799897e-01)*S113+(-8.120042e-01)*S114+(-7.250829e-01)*S115+(-1.925062e-01)*S116+4.381845e-01*S117+(-4.144930e-01)*S118+4.705999e-01*S119'
.param V54_part13='V54_part12+(-1.393919e+00)*S120+7.152921e-01*S121+3.296220e+00*S122+(-8.767199e-01)*S123+1.365019e+00*S124+3.433895e-01*S125+2.904940e-01*S126+(-5.725434e-01)*S127+(-5.534665e+00)*S128+(-8.337419e-01)*S129'
.param V54_part14='V54_part13+(-1.040296e-01)*S130+2.243409e-01*S131+1.408733e+00*S132+3.759702e-01*S133+5.820483e-01*S134+(-5.779576e-01)*S135+(-1.133050e-01)*S136+(-1.429179e-01)*S137+(-1.908106e-01)*S138+(-1.074837e+00)*S139'
.param V54_part15='V54_part14+(-1.422742e-01)*S140+(-1.726290e-01)*S141+(-2.707902e-01)*S142+(-1.209836e-01)*S143+(-8.235838e-02)*S144+(-4.740351e-02)*S145+(-3.479312e+00)*S146+(-1.506115e-01)*S147+1.861737e-02*S148+(-1.018075e+00)*S149'
.param V54_part16='V54_part15+(-9.109532e-01)*S150+(-5.804957e-01)*S151+(-1.386377e-01)*S152+(-1.441636e+00)*S153+(-9.935890e-01)*S154+(-1.271830e-01)*S155+(-6.002732e-01)*S156+(-7.102852e-02)*S157+(-2.511561e-02)*S158+(-1.469436e+00)*S159'
.param V54_part17='V54_part16+(-1.704189e-02)*S160+4.663107e-03*S161+1.618292e+00*S162+(-3.021266e-01)*S163+5.202132e-01*S164+3.270395e-01*S165+(-4.445859e-01)*S166+(-4.587457e-01)*S167+1.030800e+00*S168+(-6.893083e-01)*S169'
.param V54_part18='V54_part17+(-2.626773e-01)*S170+(-6.265920e-01)*S171+3.064222e-01*S172+(-1.082002e+00)*S173+(-6.613427e+00)*S174+9.605005e-02*S175+(-9.538053e-01)*S176+4.722819e-01*S177+(-9.081191e-01)*S178+(-7.289657e-01)*S179'
.param V54_part19='V54_part18+(-7.835636e-01)*S180+9.987092e+00*S181+(-2.249236e-01)*S182+(-2.168251e-01)*S183+(-5.407374e-01)*S184+(-1.198955e+00)*S185+(-3.078831e+00)*S186+(-1.421982e+00)*S187+(-9.992511e-01)*S188+(-1.115385e+00)*S189'
.param V54_part20='V54_part19+(-6.640504e-01)*S190+(-7.685603e-01)*S191+2.100564e-02*S192+(-4.494963e-01)*S193+(-6.612028e-01)*S194+(-8.254390e-01)*S195+(-3.715980e-01)*S196+(-2.722525e-01)*S197+(-2.583245e-01)*S198+(-3.080045e-01)*S199'
.param V54_part21='V54_part20+(-4.952840e-01)*S200+(-4.207136e-01)*S201+(-1.105248e+00)*S202+(-6.106137e-01)*S203+(-4.762783e-01)*S204+(-6.328669e-01)*S205+(-1.048983e+00)*S206+(-2.269785e+00)*S207+(-4.319553e-01)*S208+(-2.405456e+00)*S209'
.param V54_part22='V54_part21+(-4.556163e+00)*S210+(-9.514447e-01)*S211+(-8.863352e-01)*S212+(-1.991589e+00)*S213+(-3.556226e-01)*S214+(-5.516786e-01)*S215+5.388741e+01*S216+(-1.335092e+00)*S217+(-7.946282e-01)*S218+(-8.659819e-01)*S219'
.param V54_part23='V54_part22+(-5.765022e-01)*S220+(-1.145806e+00)*S221+(-2.544680e+00)*S222+(-3.429335e-01)*S223+(-3.070903e-01)*S224+8.050086e-01*S225+(-1.174150e-01)*S226+(-2.351414e-01)*S227+(-1.419022e+00)*S228+1.438250e-01*S229'
.param V54_part24='V54_part23+(-1.731936e-01)*S230+(-5.141602e+00)*S231+(-5.854217e-01)*S232+(-1.064387e-02)*S233+(-9.386086e-01)*S234+3.258360e-02*S235+(-9.416729e-02)*S236+(-5.738188e-01)*S237+(-1.076307e-01)*S238+(-1.891441e-01)*S239'
.param V54_part25='V54_part24+(-1.742116e+00)*S240+1.709496e-01*S241+(-9.862184e-02)*S242+(-4.962930e+00)*S243+(-2.540446e-01)*S244+(-1.344209e-01)*S245+(-7.572362e-01)*S246+5.198322e-02*S247+(-1.188693e-01)*S248+(-7.984278e-01)*S249'
.param V54_part26='V54_part25+(-1.039022e+00)*S250+(-6.389163e-03)*S251+(-6.270753e-01)*S252+(-1.968442e-01)*S253+(-5.612822e-02)*S254+(-2.293349e-01)*S255+(-2.577070e-01)*S256+(-2.170977e-01)*S257+(-4.836300e-01)*S258+(-4.760710e-01)*S259'
.param V54_part27='V54_part26+7.973682e-02*S260+(-3.486101e+00)*S261+(-3.979995e+00)*S262+(-5.858952e-02)*S263+(-1.113671e+01)*S264+(-9.216838e-03)*S265+(-6.567299e-02)*S266+3.661590e-02*S267+(-9.221557e-02)*S268+(-2.626788e-02)*S269'
.param V54_part28='V54_part27+(-7.379766e-01)*S270+(-7.626820e-01)*S271+(-4.993413e-01)*S272+(-4.908519e-01)*S273+(-1.355269e+00)*S274+(-3.288904e-01)*S275+(-5.759901e-01)*S276+(-1.056071e-01)*S277+(-2.189595e-01)*S278+(-1.343948e+00)*S279'
.param V54_part29='V54_part28+(-3.363036e-01)*S280+(-1.629964e-01)*S281+(-5.658769e-01)*S282+(-6.719220e-01)*S283+(-2.095106e-01)*S284+(-6.117450e-01)*S285+(-5.609461e-01)*S286+(-1.139783e-03)*S287+(-2.137890e+00)*S288+(-2.719165e-01)*S289'
.param V54_part30='V54_part29+(-1.950312e+00)*S290+(-1.526110e+00)*S291+(-4.109255e-01)*S292+(-3.003979e+00)*S293+(-1.161664e+00)*S294+(-1.116170e-01)*S295+(-1.541828e+00)*S296+(-6.755397e-01)*S297+(-3.359252e-01)*S298+(-1.003479e+00)*S299'
.param V54_part31='V54_part30+(-3.179516e+00)*S300+4.541786e+02*S301+3.107772e-02*S302+(-2.331241e+00)*S303+(-3.780968e-01)*S304+(-2.874052e-01)*S305+(-4.327541e+00)*S306+(-2.871406e-01)*S307+(-2.332119e-01)*S308+(-9.089482e-01)*S309'
.param V54='V54_part31+1.778372e-01*S310+(-2.028897e-01)*S311+1.370335e-02*S312+(-3.917180e-01)*S313+(-1.587011e-01)*S314'
.param V55_part1='4.219153e+00*S0+2.132901e+00*S1+2.786082e-01*S2+2.256047e+00*S3+(-2.493098e+00)*S4+8.964077e+00*S5+3.355937e+00*S6+4.313264e+00*S7+1.162661e+01*S8+6.380957e+00*S9'
.param V55_part2='V55_part1+3.008144e+00*S10+7.208263e-01*S11+4.029099e+00*S12+1.078741e-01*S13+0.000000e+00*S14+0.000000e+00*S15+(-2.202135e+00)*S16+0.000000e+00*S17+(-3.501264e+00)*S18+0.000000e+00*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+(-8.290737e+00)*S21+(-3.008863e+00)*S22+0.000000e+00*S23+(-6.966930e+00)*S24+0.000000e+00*S25+0.000000e+00*S26+(-1.247041e+00)*S27+(-2.010404e+00)*S28+(-3.252980e+00)*S29'
.param V55_part4='V55_part3+0.000000e+00*S30+0.000000e+00*S31+1.174182e+01*S32+0.000000e+00*S33+0.000000e+00*S34+(-2.068527e+00)*S35+5.478743e+00*S36+0.000000e+00*S37+(-8.039782e+00)*S38+(-1.064936e+00)*S39'
.param V55_part5='V55_part4+2.310445e+00*S40+0.000000e+00*S41+(-1.343036e+00)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+1.743128e+01*S48+1.083127e+01*S49'
.param V55_part6='V55_part5+4.792093e+00*S50+2.117103e+01*S51+0.000000e+00*S52+(-7.583959e+00)*S53+0.000000e+00*S54+8.040490e-01*S55+4.945299e+00*S56+2.010853e+01*S57+2.011551e+01*S58+0.000000e+00*S59'
.param V55_part7='V55_part6+1.108008e+01*S60+1.828140e+01*S61+1.381159e+01*S62+0.000000e+00*S63+1.214166e+01*S64+(-1.288753e+00)*S65+0.000000e+00*S66+9.120539e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+1.816172e+01*S70+3.345559e+01*S71+2.471017e+01*S72+1.686330e+01*S73+0.000000e+00*S74+2.152368e+01*S75+1.405172e+01*S76+1.948426e+01*S77+0.000000e+00*S78+1.170428e+01*S79'
.param V55_part9='V55_part8+3.447976e+01*S80+1.692878e+00*S81+0.000000e+00*S82+2.894312e+01*S83+0.000000e+00*S84+1.915758e+01*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V55_part10='V55_part9+0.000000e+00*S90+1.285562e+01*S91+0.000000e+00*S92+0.000000e+00*S93+6.342757e+00*S94+(-6.633893e+00)*S95+0.000000e+00*S96+0.000000e+00*S97+1.679197e+01*S98+2.176053e+01*S99'
.param V55_part11='V55_part10+0.000000e+00*S100+1.821430e+01*S101+0.000000e+00*S102+0.000000e+00*S103+1.855654e+01*S104+6.199730e+00*S105+1.557000e+01*S106+1.816478e+01*S107+7.941258e+00*S108+7.893176e+00*S109'
.param V55_part12='V55_part11+(-4.086711e+00)*S110+2.130035e+01*S111+6.613507e+00*S112+2.686808e+01*S113+1.803256e+01*S114+1.459918e+01*S115+2.000466e+01*S116+4.726297e+01*S117+3.243664e+01*S118+3.217067e+01*S119'
.param V55_part13='V55_part12+9.478855e+00*S120+6.432576e+00*S121+(-8.750077e+00)*S122+(-4.310097e+00)*S123+1.179798e+01*S124+4.050918e+00*S125+1.178793e+01*S126+1.216116e+01*S127+3.487294e+01*S128+1.082649e+01*S129'
.param V55_part14='V55_part13+3.836469e+01*S130+7.399121e+01*S131+2.490270e+01*S132+5.301620e+01*S133+0.000000e+00*S134+1.069762e+01*S135+9.459124e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V55_part15='V55_part14+0.000000e+00*S140+0.000000e+00*S141+0.000000e+00*S142+8.995096e-01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+1.669777e+01*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V55_part16='V55_part15+2.477286e+00*S150+8.375868e+00*S151+1.526212e+01*S152+6.190668e+00*S153+(-1.331314e+00)*S154+1.669535e+01*S155+2.361267e+01*S156+0.000000e+00*S157+8.024672e+01*S158+0.000000e+00*S159'
.param V55_part17='V55_part16+0.000000e+00*S160+0.000000e+00*S161+1.485526e+01*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+1.416897e+01*S167+2.356097e+01*S168+1.287575e+01*S169'
.param V55_part18='V55_part17+(-1.034990e+01)*S170+1.301235e+01*S171+3.734060e+01*S172+0.000000e+00*S173+0.000000e+00*S174+(-2.412940e+00)*S175+(-3.059195e+00)*S176+0.000000e+00*S177+(-1.115013e+00)*S178+(-7.368936e+00)*S179'
.param V55_part19='V55_part18+6.226736e+00*S180+(-5.428147e+00)*S181+(-3.082531e-01)*S182+2.950786e+01*S183+1.052149e+01*S184+(-7.296797e+00)*S185+(-1.060505e+01)*S186+(-1.450807e+00)*S187+2.720583e+00*S188+(-3.163960e+01)*S189'
.param V55_part20='V55_part19+0.000000e+00*S190+2.512925e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+7.630186e+00*S195+0.000000e+00*S196+0.000000e+00*S197+1.391844e+01*S198+0.000000e+00*S199'
.param V55_part21='V55_part20+0.000000e+00*S200+1.467305e+01*S201+4.989050e+00*S202+2.067001e+01*S203+2.416673e+01*S204+1.096301e+01*S205+7.742349e+00*S206+0.000000e+00*S207+4.310662e+01*S208+8.431632e+01*S209'
.param V55_part22='V55_part21+0.000000e+00*S210+1.151088e+01*S211+(-8.138632e+01)*S212+0.000000e+00*S213+0.000000e+00*S214+(-5.165069e+01)*S215+0.000000e+00*S216+6.447141e+00*S217+3.058906e+01*S218+(-1.087891e+01)*S219'
.param V55_part23='V55_part22+0.000000e+00*S220+3.447776e+01*S221+0.000000e+00*S222+0.000000e+00*S223+(-3.070142e+01)*S224+1.904200e+01*S225+2.563450e+01*S226+6.474952e+01*S227+2.390579e+01*S228+0.000000e+00*S229'
.param V55_part24='V55_part23+7.022294e+00*S230+0.000000e+00*S231+(-1.824003e+01)*S232+(-4.902297e+01)*S233+1.673576e+01*S234+2.823508e+00*S235+(-4.641803e+01)*S236+3.198218e+01*S237+(-6.899833e+01)*S238+(-1.088557e+02)*S239'
.param V55_part25='V55_part24+0.000000e+00*S240+3.001109e+01*S241+0.000000e+00*S242+0.000000e+00*S243+(-1.706408e+01)*S244+3.871451e+01*S245+2.879611e+01*S246+0.000000e+00*S247+3.850568e+01*S248+8.775888e+00*S249'
.param V55_part26='V55_part25+1.770052e+01*S250+3.224711e+01*S251+1.523029e+01*S252+(-8.043006e+01)*S253+1.917076e+00*S254+0.000000e+00*S255+0.000000e+00*S256+1.284329e+00*S257+0.000000e+00*S258+1.355744e+01*S259'
.param V55_part27='V55_part26+8.369354e+01*S260+0.000000e+00*S261+0.000000e+00*S262+3.138332e+01*S263+0.000000e+00*S264+1.714306e+01*S265+3.024722e+01*S266+0.000000e+00*S267+(-5.632554e-01)*S268+(-2.092853e+01)*S269'
.param V55_part28='V55_part27+9.723390e+00*S270+8.437068e+00*S271+0.000000e+00*S272+4.112569e+00*S273+0.000000e+00*S274+0.000000e+00*S275+(-1.035789e+01)*S276+(-7.152263e+00)*S277+(-3.797365e+01)*S278+(-4.653359e+01)*S279'
.param V55_part29='V55_part28+0.000000e+00*S280+(-5.416516e+01)*S281+(-5.878487e+01)*S282+(-9.067985e+01)*S283+(-1.129177e+02)*S284+(-6.029742e+00)*S285+3.042402e+00*S286+0.000000e+00*S287+(-2.910669e+01)*S288+(-1.789688e+01)*S289'
.param V55_part30='V55_part29+(-2.337672e+01)*S290+(-3.581897e+01)*S291+(-5.038581e+01)*S292+(-1.249140e+01)*S293+(-6.050141e+01)*S294+0.000000e+00*S295+(-1.305894e+01)*S296+0.000000e+00*S297+(-7.355826e+01)*S298+2.892639e+01*S299'
.param V55_part31='V55_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+1.157757e+01*S303+0.000000e+00*S304+(-2.113429e+00)*S305+0.000000e+00*S306+0.000000e+00*S307+1.838072e+01*S308+(-2.200054e+01)*S309'
.param V55='V55_part31+0.000000e+00*S310+(-2.853606e+01)*S311+(-6.243882e+01)*S312+(-9.071593e+00)*S313+(-9.702104e+01)*S314'
.param V56_part1='1.950716e+01*S0+4.225447e+01*S1+3.148597e+01*S2+8.806238e+00*S3+2.927579e+01*S4+6.869334e+00*S5+1.831738e+01*S6+1.161604e+01*S7+(-4.811120e+00)*S8+1.589315e+00*S9'
.param V56_part2='V56_part1+6.843467e+00*S10+4.952110e+00*S11+4.939789e+00*S12+4.048969e+00*S13+0.000000e+00*S14+0.000000e+00*S15+3.201883e+01*S16+0.000000e+00*S17+3.021728e+01*S18+0.000000e+00*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+2.526062e+01*S21+1.072043e+01*S22+0.000000e+00*S23+1.441084e+01*S24+0.000000e+00*S25+0.000000e+00*S26+1.074561e+01*S27+1.070819e+01*S28+9.177975e+00*S29'
.param V56_part4='V56_part3+0.000000e+00*S30+0.000000e+00*S31+1.498628e+01*S32+0.000000e+00*S33+0.000000e+00*S34+4.913920e+01*S35+4.829723e+01*S36+0.000000e+00*S37+1.574621e+01*S38+1.576290e+01*S39'
.param V56_part5='V56_part4+2.698094e+00*S40+0.000000e+00*S41+1.392262e+01*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-3.418449e+00)*S48+4.971931e+01*S49'
.param V56_part6='V56_part5+1.832579e+01*S50+7.382388e+00*S51+0.000000e+00*S52+2.866822e+01*S53+0.000000e+00*S54+2.811831e+01*S55+1.508492e+01*S56+8.759367e+00*S57+8.149699e+00*S58+0.000000e+00*S59'
.param V56_part7='V56_part6+1.125926e-01*S60+(-3.654729e+00)*S61+(-3.366912e+00)*S62+0.000000e+00*S63+(-1.367203e-02)*S64+2.941403e+01*S65+0.000000e+00*S66+1.925278e+01*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+1.747483e+01*S70+(-1.154703e-01)*S71+3.481565e+00*S72+8.096644e+00*S73+0.000000e+00*S74+(-2.423282e+00)*S75+1.107892e+01*S76+5.817794e+00*S77+0.000000e+00*S78+1.657054e+01*S79'
.param V56_part9='V56_part8+(-2.133363e+01)*S80+3.243592e+01*S81+0.000000e+00*S82+(-6.539070e+00)*S83+0.000000e+00*S84+(-7.518507e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part10='V56_part9+0.000000e+00*S90+1.005433e+01*S91+0.000000e+00*S92+0.000000e+00*S93+2.196117e+01*S94+5.039784e+00*S95+0.000000e+00*S96+0.000000e+00*S97+1.681427e+01*S98+(-3.459292e+00)*S99'
.param V56_part11='V56_part10+0.000000e+00*S100+1.584157e+01*S101+0.000000e+00*S102+0.000000e+00*S103+9.670704e+00*S104+(-3.441731e-01)*S105+1.496142e+01*S106+(-1.294549e+01)*S107+2.276823e-01*S108+2.454633e+00*S109'
.param V56_part12='V56_part11+5.342426e+01*S110+1.590208e+01*S111+2.882412e+01*S112+(-3.455082e+01)*S113+1.462668e+01*S114+1.913222e+01*S115+(-2.015706e+01)*S116+(-1.639883e+00)*S117+7.420210e+00*S118+6.096246e-02*S119'
.param V56_part13='V56_part12+1.051279e+01*S120+(-1.571926e+01)*S121+1.849046e+01*S122+1.131684e+01*S123+(-2.046140e+01)*S124+(-2.407560e+00)*S125+1.026806e+01*S126+1.714294e+01*S127+(-3.861384e+01)*S128+2.296454e+01*S129'
.param V56_part14='V56_part13+(-1.031765e+01)*S130+(-4.486055e+01)*S131+4.932731e+00*S132+(-1.764483e+01)*S133+0.000000e+00*S134+1.038425e+01*S135+2.455632e+01*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V56_part15='V56_part14+0.000000e+00*S140+0.000000e+00*S141+0.000000e+00*S142+(-9.826551e-01)*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+(-3.073733e+00)*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V56_part16='V56_part15+(-4.710128e+00)*S150+8.992310e+00*S151+7.106435e+00*S152+1.997456e+01*S153+5.719917e+00*S154+6.678213e+00*S155+(-1.256183e+01)*S156+0.000000e+00*S157+(-7.844053e+01)*S158+0.000000e+00*S159'
.param V56_part17='V56_part16+0.000000e+00*S160+0.000000e+00*S161+2.462996e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+6.945019e-01*S167+7.639545e+00*S168+1.343059e+01*S169'
.param V56_part18='V56_part17+5.190592e+01*S170+1.372455e+01*S171+(-1.373013e+01)*S172+0.000000e+00*S173+0.000000e+00*S174+6.381162e+00*S175+1.888248e+01*S176+0.000000e+00*S177+2.974374e+01*S178+2.004271e+01*S179'
.param V56_part19='V56_part18+1.706880e+00*S180+1.773536e+01*S181+3.611097e+01*S182+(-3.012748e+00)*S183+1.344594e+01*S184+2.832672e+01*S185+3.899781e+01*S186+2.052921e+01*S187+4.533527e+00*S188+4.549203e+01*S189'
.param V56_part20='V56_part19+0.000000e+00*S190+(-4.211363e+00)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+5.849378e+00*S195+0.000000e+00*S196+0.000000e+00*S197+(-2.471574e+01)*S198+0.000000e+00*S199'
.param V56_part21='V56_part20+0.000000e+00*S200+(-1.101257e+01)*S201+(-4.487866e+00)*S202+1.785667e+00*S203+(-3.429249e+00)*S204+(-4.151198e-01)*S205+2.036513e+01*S206+0.000000e+00*S207+(-2.426791e+00)*S208+(-2.609486e+01)*S209'
.param V56_part22='V56_part21+0.000000e+00*S210+4.094675e-03*S211+2.160368e+01*S212+0.000000e+00*S213+0.000000e+00*S214+2.463300e+01*S215+0.000000e+00*S216+6.232564e+00*S217+(-4.254318e+00)*S218+(-5.875570e-01)*S219'
.param V56_part23='V56_part22+0.000000e+00*S220+(-4.676073e-01)*S221+0.000000e+00*S222+0.000000e+00*S223+3.774150e+01*S224+8.967179e+00*S225+(-1.495105e+01)*S226+(-5.182570e+01)*S227+(-1.032015e+01)*S228+0.000000e+00*S229'
.param V56_part24='V56_part23+3.338670e+01*S230+0.000000e+00*S231+4.457728e+01*S232+7.668974e+01*S233+(-2.099476e-01)*S234+3.126997e+01*S235+9.079894e+01*S236+5.645513e-01*S237+5.509916e+01*S238+1.254175e+02*S239'
.param V56_part25='V56_part24+0.000000e+00*S240+(-3.089222e+01)*S241+0.000000e+00*S242+0.000000e+00*S243+2.989375e+01*S244+(-1.507988e+01)*S245+(-1.065316e+00)*S246+0.000000e+00*S247+4.141006e+00*S248+1.570986e+01*S249'
.param V56_part26='V56_part25+(-8.516489e+00)*S250+4.691952e+01*S251+9.121480e+00*S252+1.077358e+02*S253+5.874137e+01*S254+0.000000e+00*S255+0.000000e+00*S256+4.173218e+01*S257+0.000000e+00*S258+(-1.234364e+01)*S259'
.param V56_part27='V56_part26+(-8.090998e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+2.518313e+00*S263+0.000000e+00*S264+2.250077e+01*S265+1.353181e+01*S266+0.000000e+00*S267+6.008636e+01*S268+7.096399e+01*S269'
.param V56_part28='V56_part27+(-8.768783e+00)*S270+9.071339e+00*S271+0.000000e+00*S272+1.802508e+01*S273+0.000000e+00*S274+0.000000e+00*S275+4.131031e+01*S276+1.689075e+01*S277+9.715660e+01*S278+7.084335e+01*S279'
.param V56_part29='V56_part28+0.000000e+00*S280+1.178525e+02*S281+7.735497e+01*S282+1.121524e+02*S283+1.348321e+02*S284+(-9.980055e+00)*S285+2.585485e+00*S286+0.000000e+00*S287+3.349701e+01*S288+4.501924e+01*S289'
.param V56_part30='V56_part29+2.575116e+01*S290+6.915359e+01*S291+6.863477e+01*S292+1.938380e+01*S293+8.839270e+01*S294+0.000000e+00*S295+2.220017e+01*S296+0.000000e+00*S297+9.118808e+01*S298+3.619622e+00*S299'
.param V56_part31='V56_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+6.832486e+00*S303+0.000000e+00*S304+9.642231e+00*S305+0.000000e+00*S306+0.000000e+00*S307+(-2.207152e+01)*S308+2.075695e+01*S309'
.param V56='V56_part31+0.000000e+00*S310+1.029606e+02*S311+4.065206e+01*S312+1.730926e+01*S313+1.407039e+02*S314'
.param V57_part1='1.819853e+01*S0+1.830054e+01*S1+(-2.014579e+00)*S2+3.544758e+00*S3+(-1.162290e+00)*S4+(-5.800540e+00)*S5+(-1.155140e+01)*S6+(-7.832134e+00)*S7+(-4.082211e+00)*S8+3.408981e-01*S9'
.param V57_part2='V57_part1+(-4.368185e+00)*S10+(-6.574083e-03)*S11+(-9.672126e+00)*S12+(-2.314513e-03)*S13+0.000000e+00*S14+0.000000e+00*S15+7.836735e+00*S16+0.000000e+00*S17+(-1.430971e+01)*S18+0.000000e+00*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+(-6.337018e+00)*S21+(-1.382360e+00)*S22+0.000000e+00*S23+2.590332e+00*S24+0.000000e+00*S25+0.000000e+00*S26+(-5.615737e+00)*S27+(-5.728659e+00)*S28+(-2.600911e+00)*S29'
.param V57_part4='V57_part3+0.000000e+00*S30+0.000000e+00*S31+1.564895e+01*S32+0.000000e+00*S33+0.000000e+00*S34+3.339005e+01*S35+2.523480e+01*S36+0.000000e+00*S37+4.034525e+00*S38+(-4.896753e+00)*S39'
.param V57_part5='V57_part4+(-8.388367e-01)*S40+0.000000e+00*S41+(-1.009717e+01)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-9.422982e+00)*S48+2.514659e+01*S49'
.param V57_part6='V57_part5+3.814576e+00*S50+7.159835e+00*S51+0.000000e+00*S52+3.145386e+01*S53+0.000000e+00*S54+9.423854e+00*S55+3.549451e+01*S56+1.281557e+00*S57+8.744500e+00*S58+0.000000e+00*S59'
.param V57_part7='V57_part6+(-3.646161e+00)*S60+(-7.800254e+00)*S61+2.557428e+00*S62+0.000000e+00*S63+3.357680e+00*S64+6.270597e+00*S65+0.000000e+00*S66+(-4.029342e+00)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+(-5.058573e+00)*S70+1.222741e+01*S71+(-2.429155e+01)*S72+1.927055e+00*S73+0.000000e+00*S74+3.381650e+00*S75+1.440433e+01*S76+8.471782e-01*S77+0.000000e+00*S78+1.480501e+01*S79'
.param V57_part9='V57_part8+(-1.601460e+01)*S80+(-4.902674e+00)*S81+0.000000e+00*S82+(-1.185711e+01)*S83+0.000000e+00*S84+(-5.633117e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part10='V57_part9+0.000000e+00*S90+4.521576e+00*S91+0.000000e+00*S92+0.000000e+00*S93+9.144544e+00*S94+2.317383e+01*S95+0.000000e+00*S96+0.000000e+00*S97+1.076581e+01*S98+6.278256e+00*S99'
.param V57_part11='V57_part10+0.000000e+00*S100+1.051395e+01*S101+0.000000e+00*S102+0.000000e+00*S103+8.385024e+00*S104+7.467840e+00*S105+1.379648e+01*S106+(-9.472256e+00)*S107+6.926149e+00*S108+4.286493e+00*S109'
.param V57_part12='V57_part11+3.258004e+01*S110+1.594911e-01*S111+1.271772e+01*S112+3.182066e+01*S113+2.080280e+00*S114+8.166590e+00*S115+2.339109e+01*S116+(-3.090245e+01)*S117+(-1.494151e+00)*S118+(-3.631347e-01)*S119'
.param V57_part13='V57_part12+2.137110e+01*S120+4.581159e+00*S121+1.676498e+01*S122+8.284328e+00*S123+5.030773e+00*S124+1.197539e+01*S125+1.959146e+01*S126+1.464681e+01*S127+5.363778e+00*S128+5.038347e+00*S129'
.param V57_part14='V57_part13+1.861340e+00*S130+(-1.124300e+01)*S131+(-1.869652e+01)*S132+(-1.824142e+01)*S133+0.000000e+00*S134+2.687117e+01*S135+(-1.294755e+01)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V57_part15='V57_part14+0.000000e+00*S140+0.000000e+00*S141+0.000000e+00*S142+3.126688e-01*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+1.263533e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V57_part16='V57_part15+2.346202e+01*S150+1.290206e+01*S151+1.693209e+01*S152+1.358438e+01*S153+1.788797e+01*S154+1.499333e+01*S155+8.500578e-01*S156+0.000000e+00*S157+(-1.833829e+01)*S158+0.000000e+00*S159'
.param V57_part17='V57_part16+0.000000e+00*S160+0.000000e+00*S161+(-8.593144e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+1.352490e+01*S167+(-9.881936e+00)*S168+1.771882e+01*S169'
.param V57_part18='V57_part17+4.876342e+01*S170+1.198262e+01*S171+(-1.737253e+01)*S172+0.000000e+00*S173+0.000000e+00*S174+3.876652e+01*S175+4.167899e+01*S176+0.000000e+00*S177+3.277074e+01*S178+4.242498e+01*S179'
.param V57_part19='V57_part18+2.934314e+01*S180+4.882927e+01*S181+3.120853e+01*S182+(-3.072749e+01)*S183+1.851076e+01*S184+4.485144e+01*S185+4.419933e+01*S186+3.088295e+01*S187+4.283424e+01*S188+8.117500e+01*S189'
.param V57_part20='V57_part19+0.000000e+00*S190+4.951725e+01*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+1.789589e+01*S195+0.000000e+00*S196+0.000000e+00*S197+1.117516e+01*S198+0.000000e+00*S199'
.param V57_part21='V57_part20+0.000000e+00*S200+9.697082e+00*S201+1.854378e+01*S202+(-4.990538e-03)*S203+1.246407e+01*S204+2.402083e+01*S205+2.232022e+01*S206+0.000000e+00*S207+8.233726e+00*S208+(-2.079309e+01)*S209'
.param V57_part22='V57_part21+0.000000e+00*S210+1.570336e+01*S211+1.253259e+02*S212+0.000000e+00*S213+0.000000e+00*S214+9.021285e+01*S215+0.000000e+00*S216+2.538285e+01*S217+1.625729e+01*S218+9.296993e+01*S219'
.param V57_part23='V57_part22+0.000000e+00*S220+5.894107e+00*S221+0.000000e+00*S222+0.000000e+00*S223+3.224270e+01*S224+(-4.753035e+00)*S225+1.615726e+00*S226+(-3.571914e+01)*S227+1.665499e+01*S228+0.000000e+00*S229'
.param V57_part24='V57_part23+(-1.038888e+01)*S230+0.000000e+00*S231+3.837534e+01*S232+6.002360e+01*S233+3.565109e+01*S234+1.880462e+01*S235+3.147105e+01*S236+7.999076e+00*S237+1.087905e+02*S238+5.609064e+01*S239'
.param V57_part25='V57_part24+0.000000e+00*S240+(-8.356567e+00)*S241+0.000000e+00*S242+0.000000e+00*S243+6.684112e+01*S244+(-2.048502e+01)*S245+(-1.478943e+01)*S246+0.000000e+00*S247+(-9.869841e+00)*S248+1.173192e+01*S249'
.param V57_part26='V57_part25+2.625581e+01*S250+3.227344e+00*S251+1.314172e+01*S252+7.051947e+01*S253+3.885468e+01*S254+0.000000e+00*S255+0.000000e+00*S256+4.086906e+01*S257+0.000000e+00*S258+2.048610e+01*S259'
.param V57_part27='V57_part26+(-2.441118e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-2.062653e+01)*S263+0.000000e+00*S264+2.359343e+00*S265+(-6.247637e+00)*S266+0.000000e+00*S267+(-7.643028e+00)*S268+3.225745e+01*S269'
.param V57_part28='V57_part27+7.925152e+00*S270+2.522781e+01*S271+0.000000e+00*S272+2.892041e+00*S273+0.000000e+00*S274+0.000000e+00*S275+2.200204e+00*S276+1.974178e+01*S277+7.020026e+00*S278+5.642886e+01*S279'
.param V57_part29='V57_part28+0.000000e+00*S280+4.013901e+00*S281+3.897043e+02*S282+7.593879e+01*S283+7.135946e+01*S284+6.292237e+01*S285+6.605392e+01*S286+0.000000e+00*S287+8.680802e+01*S288+7.492276e+01*S289'
.param V57_part30='V57_part29+7.188785e+01*S290+6.804210e+01*S291+8.274143e+01*S292+6.657916e+01*S293+8.425793e+01*S294+0.000000e+00*S295+6.165785e+01*S296+0.000000e+00*S297+1.278082e+02*S298+2.171449e+01*S299'
.param V57_part31='V57_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+1.437386e+01*S303+0.000000e+00*S304+1.865802e+01*S305+0.000000e+00*S306+0.000000e+00*S307+1.837994e+01*S308+4.442332e+01*S309'
.param V57='V57_part31+0.000000e+00*S310+(-1.849563e+01)*S311+1.576315e+02*S312+1.496988e+01*S313+5.522229e+00*S314'
.param V58_part1='(-1.935517e+00)*S0+(-1.176181e+00)*S1+(-5.265077e+00)*S2+(-4.656897e+00)*S3+(-1.601925e+00)*S4+(-2.118135e+00)*S5+1.097432e+00*S6+(-6.607060e-01)*S7+(-3.814618e+00)*S8+(-6.553152e+00)*S9'
.param V58_part2='V58_part1+(-3.194395e+00)*S10+(-3.111270e+00)*S11+(-1.836983e+00)*S12+(-3.687214e+00)*S13+0.000000e+00*S14+0.000000e+00*S15+9.129205e+00*S16+0.000000e+00*S17+3.460602e+00*S18+0.000000e+00*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+2.764706e+00*S21+2.970487e-01*S22+0.000000e+00*S23+2.668091e+00*S24+0.000000e+00*S25+0.000000e+00*S26+1.411247e+00*S27+3.197348e+00*S28+6.377117e+00*S29'
.param V58_part4='V58_part3+0.000000e+00*S30+0.000000e+00*S31+(-3.691764e+00)*S32+0.000000e+00*S33+0.000000e+00*S34+1.318329e+00*S35+(-7.465060e-01)*S36+0.000000e+00*S37+6.876455e+00*S38+(-3.163258e+00)*S39'
.param V58_part5='V58_part4+(-3.068293e+00)*S40+0.000000e+00*S41+1.619669e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-3.505160e+00)*S48+(-5.026110e+00)*S49'
.param V58_part6='V58_part5+(-9.865265e+00)*S50+(-2.761088e+00)*S51+0.000000e+00*S52+(-3.057313e+00)*S53+0.000000e+00*S54+(-6.477269e+00)*S55+(-4.666747e+00)*S56+(-1.996987e-01)*S57+(-1.931188e+00)*S58+0.000000e+00*S59'
.param V58_part7='V58_part6+(-2.193021e+00)*S60+(-3.149482e+00)*S61+(-2.865990e+00)*S62+0.000000e+00*S63+(-1.355974e+00)*S64+1.037269e+00*S65+0.000000e+00*S66+(-9.277071e-01)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+(-2.624192e+00)*S70+(-4.502614e+00)*S71+2.646136e-01*S72+(-1.575131e+00)*S73+0.000000e+00*S74+1.621663e-01*S75+3.288792e-01*S76+(-8.562442e+00)*S77+0.000000e+00*S78+(-1.281282e-01)*S79'
.param V58_part9='V58_part8+(-5.030129e+00)*S80+1.440629e+01*S81+0.000000e+00*S82+8.275571e+00*S83+0.000000e+00*S84+3.015400e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part10='V58_part9+0.000000e+00*S90+3.426656e+00*S91+0.000000e+00*S92+0.000000e+00*S93+1.757515e+00*S94+1.758512e+01*S95+0.000000e+00*S96+0.000000e+00*S97+(-7.701755e-01)*S98+1.391080e+00*S99'
.param V58_part11='V58_part10+0.000000e+00*S100+(-9.354890e-02)*S101+0.000000e+00*S102+0.000000e+00*S103+7.425218e+00*S104+(-1.839895e-01)*S105+(-5.362046e-01)*S106+(-3.735070e-01)*S107+(-2.135199e-01)*S108+2.805900e-01*S109'
.param V58_part12='V58_part11+(-2.010042e+00)*S110+(-1.330911e+00)*S111+3.882151e+00*S112+5.484402e+00*S113+(-8.666553e+00)*S114+(-1.689027e+01)*S115+1.470271e+01*S116+(-1.290948e+01)*S117+(-2.378079e+01)*S118+(-6.049468e+00)*S119'
.param V58_part13='V58_part12+1.225006e+00*S120+1.009288e+01*S121+1.841702e+01*S122+3.261672e-02*S123+7.057419e+00*S124+2.344398e+01*S125+(-9.027093e-01)*S126+(-3.299840e-01)*S127+1.562728e+01*S128+7.678358e+00*S129'
.param V58_part14='V58_part13+(-5.383842e+00)*S130+(-9.896687e+00)*S131+2.052243e-01*S132+(-9.128485e+00)*S133+0.000000e+00*S134+(-2.027483e+00)*S135+(-4.418645e-02)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V58_part15='V58_part14+0.000000e+00*S140+0.000000e+00*S141+0.000000e+00*S142+(-1.231036e-01)*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+(-4.647019e+00)*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V58_part16='V58_part15+1.181786e+01*S150+6.918895e+00*S151+4.307135e-01*S152+2.331483e+00*S153+1.705315e+01*S154+1.936477e+00*S155+(-3.898063e-02)*S156+0.000000e+00*S157+(-5.022140e+00)*S158+0.000000e+00*S159'
.param V58_part17='V58_part16+0.000000e+00*S160+0.000000e+00*S161+5.831247e+00*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+1.523143e+00*S167+(-2.209819e+00)*S168+(-1.259130e+00)*S169'
.param V58_part18='V58_part17+(-1.647823e+00)*S170+7.467447e-01*S171+(-5.073036e+00)*S172+0.000000e+00*S173+0.000000e+00*S174+1.124651e+01*S175+5.264454e-01*S176+0.000000e+00*S177+(-7.630610e+00)*S178+2.227087e+00*S179'
.param V58_part19='V58_part18+(-9.114735e+00)*S180+5.085107e+00*S181+4.726206e+00*S182+(-3.962585e+00)*S183+1.060065e+00*S184+(-2.561691e-01)*S185+3.751641e+00*S186+1.381989e+01*S187+(-9.781456e-01)*S188+1.088055e+00*S189'
.param V58_part20='V58_part19+0.000000e+00*S190+(-1.122200e+00)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+(-9.961758e-01)*S195+0.000000e+00*S196+0.000000e+00*S197+3.170600e+00*S198+0.000000e+00*S199'
.param V58_part21='V58_part20+0.000000e+00*S200+2.432133e+00*S201+1.950521e+01*S202+(-2.858876e+00)*S203+(-1.611759e+00)*S204+1.160355e+00*S205+5.251068e+00*S206+0.000000e+00*S207+(-1.692776e+01)*S208+(-1.129132e+01)*S209'
.param V58_part22='V58_part21+0.000000e+00*S210+1.743879e+00*S211+6.311555e+00*S212+0.000000e+00*S213+0.000000e+00*S214+5.206112e+00*S215+0.000000e+00*S216+8.440364e+00*S217+1.733504e+00*S218+2.324475e+01*S219'
.param V58_part23='V58_part22+0.000000e+00*S220+7.645189e+00*S221+0.000000e+00*S222+0.000000e+00*S223+1.962920e+01*S224+(-9.852061e-01)*S225+(-2.468545e+00)*S226+3.090775e+00*S227+(-1.496993e+01)*S228+0.000000e+00*S229'
.param V58_part24='V58_part23+1.116469e+01*S230+0.000000e+00*S231+1.701099e+01*S232+6.278981e+00*S233+(-8.220011e-01)*S234+1.170560e+01*S235+1.487233e+01*S236+3.475687e+00*S237+2.669577e+01*S238+2.709059e+01*S239'
.param V58_part25='V58_part24+0.000000e+00*S240+(-6.482602e+00)*S241+0.000000e+00*S242+0.000000e+00*S243+1.070174e+01*S244+1.565310e+01*S245+(-1.392287e+00)*S246+0.000000e+00*S247+1.659430e+01*S248+7.873643e+00*S249'
.param V58_part26='V58_part25+5.014667e+00*S250+6.842838e+00*S251+5.194223e+00*S252+1.246343e+01*S253+1.914562e+01*S254+0.000000e+00*S255+0.000000e+00*S256+(-9.076702e-01)*S257+0.000000e+00*S258+8.203896e+00*S259'
.param V58_part27='V58_part26+(-2.032904e+00)*S260+0.000000e+00*S261+0.000000e+00*S262+6.975620e+00*S263+0.000000e+00*S264+6.277000e+00*S265+1.049545e+01*S266+0.000000e+00*S267+8.720408e+00*S268+1.764453e+00*S269'
.param V58_part28='V58_part27+4.086967e+00*S270+9.315743e+00*S271+0.000000e+00*S272+6.653278e+00*S273+0.000000e+00*S274+0.000000e+00*S275+2.789968e+01*S276+2.772028e+01*S277+5.088182e+01*S278+1.993166e+01*S279'
.param V58_part29='V58_part28+0.000000e+00*S280+4.645577e+01*S281+(-9.912839e+00)*S282+1.824096e+01*S283+2.443167e+01*S284+1.775752e+01*S285+4.176404e+00*S286+0.000000e+00*S287+7.578602e+00*S288+7.814664e+00*S289'
.param V58_part30='V58_part29+(-1.469093e+00)*S290+1.568927e+01*S291+2.310099e+01*S292+5.634052e+00*S293+1.673558e+01*S294+0.000000e+00*S295+7.558200e+00*S296+0.000000e+00*S297+(-8.651665e-01)*S298+1.941587e+01*S299'
.param V58_part31='V58_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+(-2.855249e+00)*S303+0.000000e+00*S304+3.991881e+01*S305+0.000000e+00*S306+0.000000e+00*S307+4.769821e+01*S308+7.614429e+00*S309'
.param V58='V58_part31+0.000000e+00*S310+2.922034e+01*S311+1.338282e+01*S312+1.917757e+01*S313+4.756019e+01*S314'
.param V59_part1='(-7.421011e-01)*S0+1.778844e-01*S1+(-1.914670e-01)*S2+(-1.575952e-01)*S3+(-3.582861e-01)*S4+(-1.013187e-01)*S5+1.601718e-01*S6+(-7.051868e-02)*S7+6.417824e-02*S8+(-1.654840e-02)*S9'
.param V59_part2='V59_part1+6.440765e-02*S10+2.719747e-02*S11+(-1.194853e-01)*S12+5.308684e-02*S13+0.000000e+00*S14+0.000000e+00*S15+1.874397e-02*S16+0.000000e+00*S17+3.649692e-01*S18+0.000000e+00*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+(-1.113607e-02)*S21+(-2.718009e-02)*S22+0.000000e+00*S23+4.128327e-02*S24+0.000000e+00*S25+0.000000e+00*S26+7.642790e-02*S27+8.902574e-02*S28+(-9.446459e-03)*S29'
.param V59_part4='V59_part3+0.000000e+00*S30+0.000000e+00*S31+1.099942e-01*S32+0.000000e+00*S33+0.000000e+00*S34+6.179676e-01*S35+6.715649e-02*S36+0.000000e+00*S37+(-8.177839e-01)*S38+(-1.138889e+00)*S39'
.param V59_part5='V59_part4+7.579077e-02*S40+0.000000e+00*S41+(-1.026003e+00)*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-4.325748e+00)*S48+(-3.425307e-01)*S49'
.param V59_part6='V59_part5+(-3.534563e+00)*S50+(-1.021035e+01)*S51+0.000000e+00*S52+(-1.505839e+01)*S53+0.000000e+00*S54+2.968419e-01*S55+(-1.552700e+01)*S56+(-1.276281e+01)*S57+(-1.354640e+01)*S58+0.000000e+00*S59'
.param V59_part7='V59_part6+(-3.065903e+00)*S60+(-3.988053e+00)*S61+(-2.415534e+00)*S62+0.000000e+00*S63+(-4.543012e+00)*S64+(-1.970511e+00)*S65+0.000000e+00*S66+(-3.430442e+00)*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+(-5.666822e+00)*S70+(-2.108903e+01)*S71+(-9.046824e+00)*S72+(-8.916834e+00)*S73+0.000000e+00*S74+2.903430e-01*S75+(-1.201131e-02)*S76+(-4.749895e-01)*S77+0.000000e+00*S78+9.112414e-01*S79'
.param V59_part9='V59_part8+(-1.542321e+00)*S80+(-1.961968e+00)*S81+0.000000e+00*S82+(-4.296331e+00)*S83+0.000000e+00*S84+(-4.043220e+00)*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part10='V59_part9+0.000000e+00*S90+2.161426e+00*S91+0.000000e+00*S92+0.000000e+00*S93+3.081193e+00*S94+(-5.840021e-01)*S95+0.000000e+00*S96+0.000000e+00*S97+8.359939e-01*S98+(-9.332174e+00)*S99'
.param V59_part11='V59_part10+0.000000e+00*S100+6.948587e-01*S101+0.000000e+00*S102+0.000000e+00*S103+(-5.362494e-01)*S104+(-2.006908e+00)*S105+5.855430e+00*S106+(-9.449249e-01)*S107+(-3.965098e+00)*S108+(-8.188324e-01)*S109'
.param V59_part12='V59_part11+3.375772e+00*S110+(-6.088129e+00)*S111+2.874730e+00*S112+(-3.007833e+00)*S113+(-7.462567e+00)*S114+(-2.816299e+00)*S115+(-1.092951e+00)*S116+(-8.777919e+00)*S117+(-2.376953e+00)*S118+(-5.549803e+00)*S119'
.param V59_part13='V59_part12+3.444149e-01*S120+(-2.946554e-01)*S121+5.626641e-01*S122+1.926885e+00*S123+(-9.057631e-01)*S124+(-4.403470e-01)*S125+(-4.026326e+00)*S126+1.048759e+00*S127+(-1.914536e+00)*S128+4.034697e+00*S129'
.param V59_part14='V59_part13+(-6.003233e+00)*S130+(-1.179789e+01)*S131+(-6.969135e+00)*S132+(-9.147332e+00)*S133+0.000000e+00*S134+(-1.474431e+00)*S135+(-2.149229e+00)*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V59_part15='V59_part14+0.000000e+00*S140+0.000000e+00*S141+0.000000e+00*S142+1.198194e+00*S143+0.000000e+00*S144+0.000000e+00*S145+0.000000e+00*S146+1.179081e+00*S147+0.000000e+00*S148+0.000000e+00*S149'
.param V59_part16='V59_part15+1.754816e+00*S150+(-1.749075e+00)*S151+6.947567e-01*S152+2.095102e+00*S153+6.760161e-01*S154+7.079886e-01*S155+(-6.331381e+00)*S156+0.000000e+00*S157+(-4.564266e+00)*S158+0.000000e+00*S159'
.param V59_part17='V59_part16+0.000000e+00*S160+0.000000e+00*S161+(-4.591277e+00)*S162+0.000000e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+3.463580e+00*S167+(-5.456010e+00)*S168+1.402290e+00*S169'
.param V59_part18='V59_part17+3.964205e+00*S170+6.251714e+00*S171+(-7.121861e+00)*S172+0.000000e+00*S173+0.000000e+00*S174+8.181062e-01*S175+4.936959e+00*S176+0.000000e+00*S177+4.022375e+00*S178+4.873246e+00*S179'
.param V59_part19='V59_part18+2.366069e-02*S180+8.032395e+00*S181+3.119250e+00*S182+(-6.424831e+00)*S183+8.114769e-01*S184+1.771132e+00*S185+1.118267e+01*S186+5.246378e+00*S187+(-8.424181e+00)*S188+1.006704e+01*S189'
.param V59_part20='V59_part19+0.000000e+00*S190+(-6.841007e+00)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+(-1.333773e+00)*S195+0.000000e+00*S196+0.000000e+00*S197+(-1.167801e+00)*S198+0.000000e+00*S199'
.param V59_part21='V59_part20+0.000000e+00*S200+7.846974e-02*S201+8.215343e-01*S202+3.788369e-01*S203+2.608647e-01*S204+2.546053e+00*S205+2.103338e+00*S206+0.000000e+00*S207+(-1.191537e+01)*S208+(-2.002176e+01)*S209'
.param V59_part22='V59_part21+0.000000e+00*S210+1.584288e+00*S211+1.351812e+00*S212+0.000000e+00*S213+0.000000e+00*S214+(-4.954832e+00)*S215+0.000000e+00*S216+(-3.243872e-01)*S217+(-4.440522e+00)*S218+5.816942e-01*S219'
.param V59_part23='V59_part22+0.000000e+00*S220+(-4.329536e+00)*S221+0.000000e+00*S222+0.000000e+00*S223+1.690988e+01*S224+(-4.296481e+00)*S225+(-6.058950e+00)*S226+(-2.142004e+00)*S227+(-6.423735e+00)*S228+0.000000e+00*S229'
.param V59_part24='V59_part23+(-7.298547e-01)*S230+0.000000e+00*S231+8.292846e+00*S232+1.941281e+00*S233+(-5.938750e+00)*S234+2.518787e-02*S235+2.450768e-01*S236+(-3.599443e+00)*S237+6.346170e+00*S238+1.658806e+01*S239'
.param V59_part25='V59_part24+0.000000e+00*S240+(-6.706215e+00)*S241+0.000000e+00*S242+0.000000e+00*S243+2.567844e+00*S244+(-2.321619e+00)*S245+(-1.545534e-01)*S246+0.000000e+00*S247+(-1.284962e+00)*S248+(-1.104612e+00)*S249'
.param V59_part26='V59_part25+(-8.602425e+00)*S250+1.168030e+00*S251+(-4.290724e+00)*S252+2.307457e+01*S253+4.905375e-01*S254+0.000000e+00*S255+0.000000e+00*S256+4.023440e+00*S257+0.000000e+00*S258+7.898726e-02*S259'
.param V59_part27='V59_part26+(-1.238691e+01)*S260+0.000000e+00*S261+0.000000e+00*S262+(-7.006929e-01)*S263+0.000000e+00*S264+(-9.212554e-01)*S265+1.121100e-01*S266+0.000000e+00*S267+(-1.150743e+00)*S268+1.570766e+00*S269'
.param V59_part28='V59_part27+(-1.158419e+00)*S270+2.136902e+00*S271+0.000000e+00*S272+8.132582e-01*S273+0.000000e+00*S274+0.000000e+00*S275+5.286108e+00*S276+(-1.473382e+00)*S277+1.727704e-01*S278+1.223669e+01*S279'
.param V59_part29='V59_part28+0.000000e+00*S280+6.376423e+00*S281+(-3.758013e+00)*S282+2.703881e+01*S283+4.918629e+00*S284+(-1.712760e-01)*S285+9.553085e-01*S286+0.000000e+00*S287+(-2.943522e+00)*S288+2.098956e+00*S289'
.param V59_part30='V59_part29+1.251364e+01*S290+1.054879e+01*S291+1.288653e+01*S292+5.302678e+00*S293+1.412024e+01*S294+0.000000e+00*S295+4.162944e+00*S296+0.000000e+00*S297+2.918122e+01*S298+3.910628e+00*S299'
.param V59_part31='V59_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+3.912750e-01*S303+0.000000e+00*S304+7.319338e-01*S305+0.000000e+00*S306+0.000000e+00*S307+3.005764e+00*S308+9.308667e+00*S309'
.param V59='V59_part31+0.000000e+00*S310+7.299973e+00*S311+2.419572e+01*S312+7.995508e+00*S313+5.756475e+00*S314'
.param V60_part1='(-1.333998e-01)*S0+0.000000e+00*S1+(-3.355692e+00)*S2+(-5.399702e-01)*S3+(-2.182558e+00)*S4+(-4.986984e+00)*S5+(-2.724857e+00)*S6+(-3.575171e+00)*S7+(-5.043486e+00)*S8+(-6.737431e-01)*S9'
.param V60_part2='V60_part1+(-3.592674e+00)*S10+(-3.401513e+00)*S11+(-1.034872e+00)*S12+(-1.835680e+00)*S13+(-3.876822e+00)*S14+(-5.863076e+00)*S15+(-6.570483e-01)*S16+(-7.514580e-01)*S17+(-1.809155e+00)*S18+(-2.104848e+00)*S19'
.param V60_part3='V60_part2+(-9.551085e-01)*S20+(-8.889256e-01)*S21+(-1.842013e+00)*S22+(-3.665317e+00)*S23+(-2.301301e+00)*S24+(-2.015553e+00)*S25+(-8.388592e+00)*S26+(-4.823394e+00)*S27+(-4.729424e+00)*S28+(-9.211138e+00)*S29'
.param V60_part4='V60_part3+0.000000e+00*S30+(-4.246478e+00)*S31+0.000000e+00*S32+(-2.348631e+00)*S33+0.000000e+00*S34+(-8.305572e+00)*S35+(-2.455941e+00)*S36+(-5.453178e-01)*S37+(-9.116401e-01)*S38+(-1.005284e-02)*S39'
.param V60_part5='V60_part4+(-3.327903e-01)*S40+(-2.708477e+00)*S41+(-8.009914e-03)*S42+(-3.039920e+00)*S43+(-6.696743e-01)*S44+(-1.960647e+00)*S45+(-2.053861e+00)*S46+(-3.826023e-01)*S47+(-1.061001e+00)*S48+(-1.684798e+00)*S49'
.param V60_part6='V60_part5+4.799660e+00*S50+(-1.277194e+00)*S51+(-3.278047e-01)*S52+7.702707e-01*S53+(-2.387052e-01)*S54+(-3.555534e+00)*S55+(-8.632619e-01)*S56+(-1.443272e+00)*S57+(-1.753884e+00)*S58+0.000000e+00*S59'
.param V60_part7='V60_part6+(-6.100365e-01)*S60+(-4.748431e+00)*S61+(-3.257840e+00)*S62+3.471335e+00*S63+(-3.231166e+00)*S64+(-2.139166e+00)*S65+6.755873e-01*S66+(-2.711564e+00)*S67+(-1.141555e+01)*S68+(-1.330895e-01)*S69'
.param V60_part8='V60_part7+(-5.853930e+00)*S70+(-4.072529e+00)*S71+(-3.345259e+00)*S72+(-2.244302e+00)*S73+(-2.538788e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+(-4.016512e+00)*S77+0.000000e+00*S78+(-3.059528e+00)*S79'
.param V60_part9='V60_part8+(-1.082583e+01)*S80+(-1.167628e+00)*S81+(-4.462222e+00)*S82+(-4.347587e+00)*S83+(-1.696475e+00)*S84+(-2.263307e+00)*S85+(-3.606846e+00)*S86+(-2.867112e+00)*S87+(-2.856342e+00)*S88+(-3.364101e+00)*S89'
.param V60_part10='V60_part9+3.000908e+00*S90+0.000000e+00*S91+(-3.665798e-01)*S92+8.839221e-01*S93+0.000000e+00*S94+0.000000e+00*S95+(-3.474211e-01)*S96+1.728725e+00*S97+0.000000e+00*S98+(-2.839966e+00)*S99'
.param V60_part11='V60_part10+(-9.849947e-04)*S100+0.000000e+00*S101+(-3.926617e+00)*S102+(-1.430725e+00)*S103+0.000000e+00*S104+6.906450e-01*S105+(-6.197924e-01)*S106+(-2.426016e+00)*S107+3.006746e-01*S108+(-1.188050e-01)*S109'
.param V60_part12='V60_part11+(-1.382150e+01)*S110+(-4.687764e+00)*S111+(-3.352293e+00)*S112+(-1.179963e+01)*S113+(-3.513759e+00)*S114+(-3.691398e+00)*S115+(-1.813917e+01)*S116+(-8.574848e+00)*S117+(-7.445149e+00)*S118+(-3.180392e+01)*S119'
.param V60_part13='V60_part12+0.000000e+00*S120+(-2.988924e-01)*S121+(-1.466923e+00)*S122+(-1.506595e+02)*S123+(-1.057610e+00)*S124+(-4.701357e+00)*S125+(-3.619978e+00)*S126+0.000000e+00*S127+(-1.365748e+01)*S128+(-4.493372e+00)*S129'
.param V60_part14='V60_part13+(-7.589933e+00)*S130+(-2.047688e+01)*S131+(-1.130477e+01)*S132+(-1.213587e+01)*S133+(-3.373718e+01)*S134+0.000000e+00*S135+(-5.006621e+00)*S136+(-4.052682e+00)*S137+(-2.487179e+00)*S138+(-2.119092e+00)*S139'
.param V60_part15='V60_part14+(-1.774794e+00)*S140+(-1.722838e+00)*S141+(-2.575203e+00)*S142+(-2.725689e+00)*S143+(-1.754080e+00)*S144+(-2.101604e+00)*S145+(-6.658461e+00)*S146+(-1.783307e+00)*S147+(-3.172921e+00)*S148+(-6.927725e+00)*S149'
.param V60_part16='V60_part15+0.000000e+00*S150+(-1.097817e+00)*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+(-3.171550e+00)*S156+(-3.960994e+00)*S157+(-2.504578e+01)*S158+(-7.244385e+00)*S159'
.param V60_part17='V60_part16+(-1.168426e+01)*S160+(-1.959419e+01)*S161+(-1.147057e+01)*S162+(-1.559721e+01)*S163+(-2.989092e+01)*S164+2.772875e-02*S165+(-7.244315e+00)*S166+0.000000e+00*S167+(-6.605712e+00)*S168+0.000000e+00*S169'
.param V60_part18='V60_part17+(-3.384089e+01)*S170+(-1.231272e+01)*S171+(-8.800669e+00)*S172+(-3.815114e+01)*S173+(-1.156788e+01)*S174+(-1.959017e+01)*S175+(-3.862908e+01)*S176+(-8.064105e+00)*S177+(-2.039031e+01)*S178+(-5.006816e+01)*S179'
.param V60_part19='V60_part18+(-4.563871e-01)*S180+(-9.981294e+00)*S181+(-2.594022e+01)*S182+(-5.628745e+00)*S183+0.000000e+00*S184+(-2.994472e+01)*S185+(-1.116148e+01)*S186+(-1.354012e+01)*S187+(-2.089933e+01)*S188+(-1.353922e+01)*S189'
.param V60_part20='V60_part19+(-2.172599e+01)*S190+(-2.875554e+01)*S191+(-1.615537e+01)*S192+(-2.587151e+01)*S193+(-4.476700e+01)*S194+(-3.479170e+00)*S195+(-1.084659e+00)*S196+(-3.056617e+00)*S197+(-1.298664e+00)*S198+0.000000e+00*S199'
.param V60_part21='V60_part20+(-4.323489e+00)*S200+(-2.100140e+00)*S201+(-3.111431e+00)*S202+(-5.638729e+00)*S203+(-4.032150e+00)*S204+(-1.565022e+01)*S205+(-2.221920e+01)*S206+(-1.727439e+01)*S207+(-1.204646e+01)*S208+(-2.659349e+01)*S209'
.param V60_part22='V60_part21+4.470833e-01*S210+(-5.539824e-01)*S211+0.000000e+00*S212+(-1.091351e+01)*S213+(-8.921553e+00)*S214+0.000000e+00*S215+(-9.991076e+00)*S216+(-1.056665e+01)*S217+(-2.564333e+01)*S218+(-1.994516e+01)*S219'
.param V60_part23='V60_part22+(-2.392501e+01)*S220+(-3.093334e+01)*S221+(-1.427149e+01)*S222+(-2.728483e+01)*S223+(-4.741278e+01)*S224+(-5.966882e+00)*S225+(-7.202290e+00)*S226+0.000000e+00*S227+(-4.168700e+00)*S228+(-1.342597e+01)*S229'
.param V60_part24='V60_part23+(-3.617745e+01)*S230+(-6.498685e+00)*S231+(-2.178567e+01)*S232+(-3.823964e+01)*S233+(-8.150413e+00)*S234+(-1.767198e+01)*S235+(-4.361879e+01)*S236+(-1.129996e+01)*S237+(-2.954639e+01)*S238+(-6.062284e+01)*S239'
.param V60_part25='V60_part24+(-8.036099e+00)*S240+(-9.889949e+00)*S241+(-2.243134e+01)*S242+(-7.232713e+00)*S243+(-2.195613e+01)*S244+(-4.591765e+01)*S245+(-1.039829e+01)*S246+(-2.249708e+01)*S247+(-4.845759e+01)*S248+(-1.228010e+01)*S249'
.param V60_part26='V60_part25+(-1.769799e+01)*S250+(-4.222336e+01)*S251+(-1.351823e+01)*S252+(-3.525507e+01)*S253+(-6.589442e+01)*S254+0.000000e+00*S255+0.000000e+00*S256+(-3.396495e+01)*S257+(-2.233631e+00)*S258+(-2.148040e+01)*S259'
.param V60_part27='V60_part26+(-2.564948e+01)*S260+(-1.150991e+01)*S261+(-1.703776e+01)*S262+(-4.848910e+01)*S263+(-1.450939e+01)*S264+(-2.179304e+01)*S265+(-4.981486e+01)*S266+(-1.824345e+01)*S267+(-2.492860e+01)*S268+(-6.400639e+01)*S269'
.param V60_part28='V60_part27+(-1.212143e+01)*S270+(-2.165504e+01)*S271+(-7.136606e+01)*S272+(-1.651508e+01)*S273+(-2.249790e+01)*S274+(-6.260698e+01)*S275+(-2.008895e+01)*S276+(-2.832622e+01)*S277+(-5.670358e+01)*S278+(-2.355050e+01)*S279'
.param V60_part29='V60_part28+(-3.004043e+01)*S280+(-5.724153e+01)*S281+(-2.462939e+01)*S282+(-3.657533e+01)*S283+(-5.968785e+01)*S284+(-1.579965e+01)*S285+(-2.106198e+01)*S286+(-4.357277e+01)*S287+(-1.556055e+01)*S288+(-2.638652e+01)*S289'
.param V60_part30='V60_part29+(-5.651210e+01)*S290+(-2.071590e+01)*S291+(-3.016159e+01)*S292+(-5.910371e+01)*S293+(-2.416790e+01)*S294+(-3.284909e+01)*S295+(-6.614407e+01)*S296+(-2.475716e+01)*S297+(-3.536416e+01)*S298+(-6.006402e+01)*S299'
.param V60_part31='V60_part30+(-9.825320e+00)*S300+(-3.737932e+00)*S301+(-3.719126e+01)*S302+(-1.483552e+01)*S303+(-2.172077e+01)*S304+(-5.818966e+01)*S305+(-1.771424e+01)*S306+(-2.804012e+01)*S307+(-6.279273e+01)*S308+(-2.219537e+01)*S309'
.param V60='V60_part31+(-3.102516e+01)*S310+(-5.340736e+01)*S311+(-2.443653e+01)*S312+(-3.610694e+01)*S313+(-5.617034e+01)*S314'
.param V61_part1='4.622568e+00*S0+0.000000e+00*S1+1.879826e+00*S2+2.409115e+00*S3+1.336528e+00*S4+5.268113e+00*S5+2.762255e+00*S6+3.441676e+00*S7+6.165049e+00*S8+2.184156e+00*S9'
.param V61_part2='V61_part1+3.078686e+00*S10+4.027952e+00*S11+1.809069e+00*S12+3.493784e+00*S13+4.640494e+00*S14+5.606989e+00*S15+1.058220e+00*S16+3.387764e+00*S17+3.455025e+00*S18+5.294300e+00*S19'
.param V61_part3='V61_part2+4.046406e+00*S20+3.452484e+00*S21+4.444217e+00*S22+6.814410e+00*S23+4.546218e+00*S24+4.548721e+00*S25+1.030730e+01*S26+6.093399e+00*S27+5.217659e+00*S28+9.389414e+00*S29'
.param V61_part4='V61_part3+0.000000e+00*S30+9.700007e+00*S31+0.000000e+00*S32+4.670630e+00*S33+0.000000e+00*S34+1.290044e+01*S35+5.363425e+00*S36+2.991564e+00*S37+4.606813e+00*S38+1.766177e+00*S39'
.param V61_part5='V61_part4+3.319790e+00*S40+5.633732e+00*S41+1.726516e+00*S42+5.568223e+00*S43+3.960497e+00*S44+3.424328e+00*S45+2.476394e+00*S46+(-3.747345e-01)*S47+2.965298e+00*S48+4.662132e+00*S49'
.param V61_part6='V61_part5+(-5.929867e+00)*S50+1.784743e+00*S51+1.524690e+00*S52+7.389386e-01*S53+9.637731e-01*S54+6.485615e+00*S55+2.537778e+00*S56+1.972413e+00*S57+2.313149e+00*S58+0.000000e+00*S59'
.param V61_part7='V61_part6+2.448781e+00*S60+7.904188e+00*S61+3.376983e+00*S62+(-4.009255e-01)*S63+6.151001e+00*S64+(-7.466483e-01)*S65+1.214871e+00*S66+9.564686e-01*S67+1.078247e+01*S68+2.926686e+00*S69'
.param V61_part8='V61_part7+3.085120e+00*S70+3.076274e+00*S71+2.233592e+00*S72+2.242860e+00*S73+4.485547e+00*S74+0.000000e+00*S75+0.000000e+00*S76+6.212128e+00*S77+0.000000e+00*S78+3.814595e+00*S79'
.param V61_part9='V61_part8+1.371927e+01*S80+2.595123e+00*S81+7.335477e+00*S82+5.848116e+00*S83+3.031283e+00*S84+4.465514e+00*S85+6.025891e+00*S86+4.162998e+00*S87+4.601180e+00*S88+5.827444e+00*S89'
.param V61_part10='V61_part9+(-1.595676e+00)*S90+0.000000e+00*S91+3.676950e+00*S92+1.153193e+00*S93+0.000000e+00*S94+0.000000e+00*S95+2.812232e+00*S96+3.115163e+00*S97+0.000000e+00*S98+3.298190e+00*S99'
.param V61_part11='V61_part10+2.267158e+00*S100+0.000000e+00*S101+2.882541e+00*S102+2.384765e+00*S103+0.000000e+00*S104+1.162354e+00*S105+5.176886e+00*S106+5.426634e+00*S107+2.141902e+00*S108+2.593977e+00*S109'
.param V61_part12='V61_part11+1.888279e+01*S110+3.417647e+00*S111+5.190481e+00*S112+1.602713e+01*S113+4.408916e+00*S114+5.005499e+00*S115+2.241615e+01*S116+5.396410e+00*S117+7.457845e+00*S118+2.199041e+01*S119'
.param V61_part13='V61_part12+0.000000e+00*S120+4.243762e+00*S121+4.724583e+00*S122+(-8.778752e+02)*S123+5.238922e+00*S124+8.599465e+00*S125+5.048880e+00*S126+0.000000e+00*S127+1.888872e+01*S128+5.527025e+00*S129'
.param V61_part14='V61_part13+7.784113e+00*S130+1.835292e+01*S131+7.278106e+00*S132+8.546408e+00*S133+2.246003e+01*S134+0.000000e+00*S135+7.556306e+00*S136+1.423565e+01*S137+7.939269e+00*S138+8.192585e+00*S139'
.param V61_part15='V61_part14+5.443980e+00*S140+4.657360e+00*S141+7.455258e+00*S142+5.926764e+00*S143+4.396872e+00*S144+5.302828e+00*S145+8.878397e+00*S146+3.948900e+00*S147+5.741484e+00*S148+7.846851e+00*S149'
.param V61_part16='V61_part15+0.000000e+00*S150+2.525187e+00*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+5.313935e+00*S156+3.003879e+00*S157+3.032865e+01*S158+7.737968e+00*S159'
.param V61_part17='V61_part16+9.945025e+00*S160+1.786526e+01*S161+8.915566e+00*S162+1.283469e+01*S163+2.159360e+01*S164+3.444426e+00*S165+8.842839e+00*S166+0.000000e+00*S167+5.834479e+00*S168+0.000000e+00*S169'
.param V61_part18='V61_part17+4.066856e+01*S170+9.348122e+00*S171+8.365819e+00*S172+3.487880e+01*S173+8.839780e+00*S174+1.328175e+01*S175+2.661007e+01*S176+7.285776e+00*S177+1.595042e+01*S178+2.892941e+01*S179'
.param V61_part19='V61_part18+2.880964e+00*S180+2.365328e+00*S181+4.239164e+01*S182+7.228343e+00*S183+0.000000e+00*S184+2.930839e+01*S185+1.070090e+01*S186+1.220881e+01*S187+2.430980e+01*S188+1.101615e+01*S189'
.param V61_part20='V61_part19+1.584643e+01*S190+2.710975e+01*S191+1.092980e+01*S192+1.655081e+01*S193+2.688994e+01*S194+4.663075e+00*S195+4.847882e-01*S196+3.381514e+00*S197+5.841005e+00*S198+0.000000e+00*S199'
.param V61_part21='V61_part20+5.332755e+00*S200+6.042130e+00*S201+6.829592e+00*S202+6.165578e+00*S203+6.500778e+00*S204+1.515679e+01*S205+1.869601e+01*S206+1.043536e+01*S207+1.059358e+01*S208+1.832871e+01*S209'
.param V61_part22='V61_part21+6.709018e-01*S210+2.894772e+00*S211+0.000000e+00*S212+8.076098e+00*S213+8.068424e+00*S214+0.000000e+00*S215+1.177682e+01*S216+1.468875e+01*S217+2.591662e+01*S218+1.498135e+01*S219'
.param V61_part23='V61_part22+1.802057e+01*S220+2.902248e+01*S221+1.103589e+01*S222+1.852503e+01*S223+2.891795e+01*S224+5.016303e+00*S225+1.038960e+01*S226+0.000000e+00*S227+8.525419e+00*S228+1.226885e+01*S229'
.param V61_part24='V61_part23+4.137686e+01*S230+9.439515e+00*S231+1.666089e+01*S232+3.594149e+01*S233+1.127540e+01*S234+1.899096e+01*S235+3.715104e+01*S236+1.074044e+01*S237+1.863922e+01*S238+3.824575e+01*S239'
.param V61_part25='V61_part24+9.480361e+00*S240+1.175088e+01*S241+2.478290e+01*S242+9.376556e+00*S243+2.976272e+01*S244+4.631949e+01*S245+1.255714e+01*S246+1.526696e+01*S247+3.775977e+01*S248+1.307350e+01*S249'
.param V61_part26='V61_part25+1.609427e+01*S250+3.290015e+01*S251+1.212380e+01*S252+2.382062e+01*S253+4.627419e+01*S254+0.000000e+00*S255+0.000000e+00*S256+4.576554e+01*S257+4.920047e+00*S258+3.347878e+01*S259'
.param V61_part27='V61_part26+2.982330e+01*S260+1.228115e+01*S261+1.571899e+01*S262+4.915801e+01*S263+1.097834e+01*S264+2.113358e+01*S265+3.966382e+01*S266+1.101513e+01*S267+2.112041e+01*S268+4.512355e+01*S269'
.param V61_part28='V61_part27+2.501715e+01*S270+3.146969e+01*S271+5.384107e+01*S272+2.250207e+01*S273+2.258766e+01*S274+5.351851e+01*S275+2.121117e+01*S276+3.442369e+01*S277+4.014025e+01*S278+2.037515e+01*S279'
.param V61_part29='V61_part28+2.044808e+01*S280+3.528355e+01*S281+1.299651e+01*S282+2.466741e+01*S283+3.396249e+01*S284+2.721917e+01*S285+3.585251e+01*S286+4.190351e+01*S287+1.739559e+01*S288+3.007457e+01*S289'
.param V61_part30='V61_part29+4.917632e+01*S290+2.087050e+01*S291+2.632938e+01*S292+3.926860e+01*S293+2.059300e+01*S294+2.286414e+01*S295+3.899671e+01*S296+1.618738e+01*S297+2.202310e+01*S298+3.166535e+01*S299'
.param V61_part31='V61_part30+1.103924e+01*S300+6.422828e+00*S301+3.940978e+01*S302+1.728512e+01*S303+1.968107e+01*S304+5.200946e+01*S305+1.738921e+01*S306+1.860563e+01*S307+4.767256e+01*S308+1.634383e+01*S309'
.param V61='V61_part31+1.939537e+01*S310+3.520701e+01*S311+1.399338e+01*S312+2.229524e+01*S313+3.098722e+01*S314'
.param V62_part1='(-7.615574e-01)*S0+0.000000e+00*S1+6.017169e+00*S2+1.885034e+00*S3+6.347864e+00*S4+7.037210e+00*S5+8.256340e+00*S6+8.475988e+00*S7+6.644743e+00*S8+3.712277e+00*S9'
.param V62_part2='V62_part1+9.784062e+00*S10+6.454005e+00*S11+7.384913e+00*S12+5.915929e+00*S13+7.429793e+00*S14+1.967187e+01*S15+1.215926e+00*S16+3.622365e+00*S17+5.856684e+00*S18+4.985934e+00*S19'
.param V62_part3='V62_part2+3.852870e+00*S20+6.034204e+00*S21+5.571100e+00*S22+6.709757e+00*S23+9.001962e+00*S24+7.647473e+00*S25+1.048989e+01*S26+1.328245e+01*S27+1.338300e+01*S28+1.284420e+01*S29'
.param V62_part4='V62_part3+0.000000e+00*S30+5.513043e+00*S31+0.000000e+00*S32+4.839029e+00*S33+0.000000e+00*S34+8.710813e+00*S35+5.141620e+00*S36+(-8.717645e-01)*S37+3.583007e+00*S38+4.178802e+00*S39'
.param V62_part5='V62_part4+2.760514e+00*S40+4.149370e+00*S41+5.488905e+00*S42+4.015867e+00*S43+3.239033e+00*S44+6.031819e+00*S45+5.353677e+00*S46+2.594858e+00*S47+4.195175e+00*S48+5.286367e+00*S49'
.param V62_part6='V62_part5+5.784217e-01*S50+1.989515e+00*S51+1.661242e+00*S52+(-8.037372e-01)*S53+1.606771e+00*S54+1.046293e+01*S55+(-1.123177e+00)*S56+2.872728e+00*S57+2.045003e+00*S58+0.000000e+00*S59'
.param V62_part7='V62_part6+4.094913e+00*S60+7.282545e+00*S61+7.883609e+00*S62+1.360425e+00*S63+4.193946e+00*S64+7.706698e+00*S65+3.071348e+00*S66+9.739511e+00*S67+1.123677e+01*S68+4.103223e+00*S69'
.param V62_part8='V62_part7+1.055369e+01*S70+4.861883e-01*S71+7.596374e+00*S72+2.672903e+00*S73+3.218304e+00*S74+0.000000e+00*S75+0.000000e+00*S76+4.338283e+00*S77+0.000000e+00*S78+6.228752e+00*S79'
.param V62_part9='V62_part8+1.050852e+01*S80+4.087197e+00*S81+8.105321e+00*S82+5.187030e+00*S83+5.137706e+00*S84+4.388471e+00*S85+5.185948e+00*S86+5.076422e+00*S87+5.144273e+00*S88+4.399056e+00*S89'
.param V62_part10='V62_part9+1.020051e+00*S90+0.000000e+00*S91+4.047302e+00*S92+2.776765e+00*S93+0.000000e+00*S94+0.000000e+00*S95+3.635426e+00*S96+4.126197e+00*S97+0.000000e+00*S98+2.200242e+00*S99'
.param V62_part11='V62_part10+3.440451e+00*S100+0.000000e+00*S101+9.283368e+00*S102+4.350600e+00*S103+0.000000e+00*S104+2.187856e+00*S105+2.220715e+00*S106+5.286055e+00*S107+1.276686e+00*S108+3.359752e+00*S109'
.param V62_part12='V62_part11+1.307167e+01*S110+6.498697e+00*S111+3.140197e+00*S112+9.419404e+00*S113+4.828091e+00*S114+4.196885e+00*S115+1.312001e+01*S116+1.152388e+01*S117+7.359305e+00*S118+1.750476e+01*S119'
.param V62_part13='V62_part12+0.000000e+00*S120+2.668850e+00*S121+4.299866e+00*S122+1.000000e+04*S123+2.803482e+00*S124+5.852511e+00*S125+1.685451e+00*S126+0.000000e+00*S127+1.137187e+01*S128+7.684873e+00*S129'
.param V62_part14='V62_part13+4.706011e+00*S130+7.633901e+00*S131+1.993548e+01*S132+1.171834e+01*S133+2.486371e+01*S134+0.000000e+00*S135+1.194973e+01*S136+9.844981e+00*S137+5.074232e+00*S138+6.197970e+00*S139'
.param V62_part15='V62_part14+5.460665e+00*S140+4.506944e+00*S141+3.719968e+00*S142+5.039438e+00*S143+3.433188e+00*S144+2.581136e+00*S145+6.950223e+00*S146+2.928111e+00*S147+2.763965e+00*S148+5.413635e+00*S149'
.param V62_part16='V62_part15+0.000000e+00*S150+8.260254e-01*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+2.519323e+00*S156+9.587645e+00*S157+1.570265e+01*S158+1.247774e+01*S159'
.param V62_part17='V62_part16+1.550658e+01*S160+1.289310e+01*S161+2.026633e+01*S162+1.784526e+01*S163+1.975869e+01*S164+4.135106e+00*S165+1.915694e+01*S166+0.000000e+00*S167+1.218218e+01*S168+0.000000e+00*S169'
.param V62_part18='V62_part17+3.353019e+01*S170+2.174788e+01*S171+1.357001e+01*S172+3.305436e+01*S173+1.793603e+01*S174+3.183337e+01*S175+3.621159e+01*S176+9.248847e+00*S177+3.013549e+01*S178+4.465154e+01*S179'
.param V62_part19='V62_part18+(-1.707273e-01)*S180+2.209474e+01*S181+2.779415e+01*S182+1.170186e+01*S183+0.000000e+00*S184+3.277103e+01*S185+2.758063e+01*S186+2.378176e+01*S187+1.221164e+01*S188+2.885912e+01*S189'
.param V62_part20='V62_part19+3.602863e+01*S190+1.723037e+01*S191+3.936981e+01*S192+4.312861e+01*S193+5.022547e+01*S194+5.735229e+00*S195+4.318024e+00*S196+5.252018e+00*S197+2.330500e+00*S198+0.000000e+00*S199'
.param V62_part21='V62_part20+5.282296e+00*S200+3.991541e+00*S201+5.529108e+00*S202+6.725384e+00*S203+8.976920e+00*S204+2.612140e+01*S205+1.405820e+01*S206+2.426501e+01*S207+8.976378e+00*S208+1.565265e+01*S209'
.param V62_part22='V62_part21+4.861913e+00*S210+4.801993e-03*S211+0.000000e+00*S212+2.544254e+01*S213+1.668235e+01*S214+0.000000e+00*S215+2.032908e+01*S216+1.226787e+01*S217+1.506900e+01*S218+5.890209e+01*S219'
.param V62_part23='V62_part22+3.887881e+01*S220+2.163322e+01*S221+3.134226e+01*S222+4.402868e+01*S223+4.646969e+01*S224+1.398423e+01*S225+1.073218e+01*S226+0.000000e+00*S227+4.839907e+00*S228+2.340867e+01*S229'
.param V62_part24='V62_part23+4.127899e+01*S230+1.033170e+01*S231+4.076789e+01*S232+5.495096e+01*S233+1.169759e+01*S234+4.405879e+01*S235+6.146242e+01*S236+2.160570e+01*S237+5.688014e+01*S238+6.499361e+01*S239'
.param V62_part25='V62_part24+2.136689e+01*S240+1.576274e+01*S241+2.521768e+01*S242+1.221820e+01*S243+5.616281e+01*S244+5.453380e+01*S245+2.123544e+01*S246+4.069004e+01*S247+6.943263e+01*S248+2.550966e+01*S249'
.param V62_part26='V62_part25+2.734744e+01*S250+6.927294e+01*S251+3.070147e+01*S252+6.355643e+01*S253+8.477006e+01*S254+0.000000e+00*S255+0.000000e+00*S256+4.249702e+01*S257+3.799633e+00*S258+4.283175e+01*S259'
.param V62_part27='V62_part26+1.610231e+01*S260+2.261975e+01*S261+2.902619e+01*S262+4.286981e+01*S263+3.106445e+01*S264+4.925994e+01*S265+5.728777e+01*S266+4.382548e+01*S267+5.565948e+01*S268+8.110652e+01*S269'
.param V62_part28='V62_part27+3.864426e+01*S270+5.674745e+01*S271+9.784056e+01*S272+5.007575e+01*S273+4.421529e+01*S274+8.191254e+01*S275+5.932807e+01*S276+6.136251e+01*S277+9.173109e+01*S278+5.308631e+01*S279'
.param V62_part29='V62_part28+6.227322e+01*S280+9.989553e+01*S281+1.186328e+02*S282+6.621072e+01*S283+9.962105e+01*S284+5.197074e+01*S285+5.561036e+01*S286+5.407467e+01*S287+4.342874e+01*S288+7.545723e+01*S289'
.param V62_part30='V62_part29+7.310205e+01*S290+5.264263e+01*S291+6.015203e+01*S292+8.108609e+01*S293+6.066205e+01*S294+6.952063e+01*S295+8.941797e+01*S296+7.411490e+01*S297+7.613221e+01*S298+8.752167e+01*S299'
.param V62_part31='V62_part30+2.834439e+01*S300+1.196262e+01*S301+3.988425e+01*S302+3.340162e+01*S303+4.239611e+01*S304+8.580084e+01*S305+4.110486e+01*S306+5.587573e+01*S307+9.242202e+01*S308+5.375560e+01*S309'
.param V62='V62_part31+6.070032e+01*S310+8.890857e+01*S311+6.698954e+01*S312+6.866774e+01*S313+9.544668e+01*S314'
.param V63_part1='1.311102e+00*S0+0.000000e+00*S1+2.255700e+00*S2+1.189007e+00*S3+1.350635e+00*S4+1.535441e+00*S5+9.981551e-01*S6+1.027075e+00*S7+1.759133e+00*S8+1.101150e+00*S9'
.param V63_part2='V63_part1+9.664236e-01*S10+1.210243e+00*S11+2.420445e-01*S12+7.904490e-01*S13+9.212229e-01*S14+2.547035e-01*S15+3.754568e-01*S16+9.636819e-01*S17+1.367040e+00*S18+1.194697e+00*S19'
.param V63_part3='V63_part2+1.186022e+00*S20+3.135834e-01*S21+1.056612e+00*S22+1.207372e-01*S23+3.877362e-01*S24+6.101897e-01*S25+1.251798e+00*S26+4.317740e-01*S27+3.334861e-01*S28+1.711134e+00*S29'
.param V63_part4='V63_part3+0.000000e+00*S30+1.346474e+00*S31+0.000000e+00*S32+9.405769e-01*S33+0.000000e+00*S34+1.942585e+00*S35+6.474734e-01*S36+1.481773e+00*S37+1.640411e+00*S38+1.849685e+00*S39'
.param V63_part5='V63_part4+1.905276e+00*S40+1.901098e+00*S41+2.246400e+00*S42+1.608824e+00*S43+1.651973e+00*S44+2.048243e-01*S45+5.784907e-01*S46+1.374554e-01*S47+8.358959e-02*S48+7.184512e-01*S49'
.param V63_part6='V63_part5+2.080889e+00*S50+(-1.614711e-01)*S51+(-1.753517e-01)*S52+(-8.169926e-02)*S53+(-2.949838e-01)*S54+1.939102e+00*S55+5.306280e-02*S56+(-5.629053e-01)*S57+(-4.631185e-01)*S58+0.000000e+00*S59'
.param V63_part7='V63_part6+3.591091e-01*S60+1.307374e+00*S61+2.251960e+00*S62+1.731737e-02*S63+8.937232e-01*S64+1.506747e+00*S65+(-1.356560e-01)*S66+9.837717e-01*S67+2.115083e+00*S68+7.634743e-02*S69'
.param V63_part8='V63_part7+8.230938e-01*S70+6.248116e-01*S71+(-4.001447e-02)*S72+(-1.405157e-01)*S73+2.714452e+00*S74+0.000000e+00*S75+0.000000e+00*S76+1.057128e+00*S77+0.000000e+00*S78+1.328802e+00*S79'
.param V63_part9='V63_part8+6.126575e-01*S80+(-8.111985e-01)*S81+1.068101e+00*S82+(-1.906160e+00)*S83+(-1.525137e+00)*S84+(-1.361379e+00)*S85+(-2.968487e+00)*S86+(-1.075283e+00)*S87+(-2.671146e-01)*S88+(-2.425329e+00)*S89'
.param V63_part10='V63_part9+4.798400e-01*S90+0.000000e+00*S91+(-1.200747e-01)*S92+7.811963e-01*S93+0.000000e+00*S94+0.000000e+00*S95+7.153598e-01*S96+(-2.443597e+00)*S97+0.000000e+00*S98+2.678559e-01*S99'
.param V63_part11='V63_part10+8.576163e-01*S100+0.000000e+00*S101+1.104131e+00*S102+1.300995e+00*S103+0.000000e+00*S104+1.538730e-01*S105+6.887370e-01*S106+(-3.193657e-01)*S107+(-2.299832e-01)*S108+(-7.782822e-02)*S109'
.param V63_part12='V63_part11+1.404046e+00*S110+1.528066e-02*S111+9.525072e-01*S112+(-7.624057e-01)*S113+1.465703e+00*S114+2.437693e+00*S115+5.657892e-01*S116+2.207260e+00*S117+3.094121e+00*S118+5.578706e+00*S119'
.param V63_part13='V63_part12+0.000000e+00*S120+(-1.267918e+00)*S121+(-1.444143e+00)*S122+(-1.855259e+03)*S123+(-9.981353e-01)*S124+(-1.649789e+00)*S125+1.083183e+00*S126+0.000000e+00*S127+(-1.315319e+00)*S128+2.372719e+00*S129'
.param V63_part14='V63_part13+1.074111e+00*S130+3.619355e+00*S131+2.036670e+00*S132+2.017295e+00*S133+5.024773e+00*S134+0.000000e+00*S135+3.396216e-01*S136+6.266078e-01*S137+6.507817e-01*S138+3.761718e-01*S139'
.param V63_part15='V63_part14+2.692582e-01*S140+1.285743e+00*S141+1.589818e+00*S142+5.648923e-02*S143+1.135185e+00*S144+1.193245e+00*S145+2.840346e-01*S146+8.755511e-01*S147+1.484044e+00*S148+9.115822e-01*S149'
.param V63_part16='V63_part15+0.000000e+00*S150+(-1.607302e-01)*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+6.493044e-01*S156+1.240866e+00*S157+1.693807e+00*S158+1.000178e+00*S159'
.param V63_part17='V63_part16+2.446613e+00*S160+5.175769e+00*S161+2.041642e+00*S162+3.916215e+00*S163+5.698342e+00*S164+(-1.698144e-01)*S165+2.345733e+00*S166+0.000000e+00*S167+1.002733e+00*S168+0.000000e+00*S169'
.param V63_part18='V63_part17+3.394008e+00*S170+1.949767e+00*S171+1.625421e+00*S172+3.693396e+00*S173+3.068690e+00*S174+2.359049e+00*S175+2.654883e-01*S176+(-9.983566e-02)*S177+1.801178e+00*S178+5.489768e-01*S179'
.param V63_part19='V63_part18+7.324929e-01*S180+2.840491e+00*S181+7.816860e+00*S182+9.529795e-01*S183+0.000000e+00*S184+1.716072e+00*S185+2.475464e+00*S186+4.454614e+00*S187+6.698901e+00*S188+2.779515e+00*S189'
.param V63_part20='V63_part19+3.561712e+00*S190+7.788359e+00*S191+2.080999e+00*S192+3.484219e+00*S193+3.158009e+00*S194+(-3.779625e-01)*S195+7.049557e-01*S196+1.009333e+00*S197+(-6.536688e-01)*S198+0.000000e+00*S199'
.param V63_part21='V63_part20+9.479467e-01*S200+1.297754e+00*S201+(-6.362284e-01)*S202+7.931398e-01*S203+9.893996e-01*S204+2.499350e-01*S205+3.714621e+00*S206+8.119182e-01*S207+3.788627e+00*S208+1.751033e+00*S209'
.param V63_part22='V63_part21+1.149765e+00*S210+7.260908e-02*S211+0.000000e+00*S212+2.264189e+00*S213+2.352608e+00*S214+0.000000e+00*S215+1.697243e+00*S216+4.097812e+00*S217+6.122084e+00*S218+2.241607e+00*S219'
.param V63_part23='V63_part22+2.731762e+00*S220+7.144182e+00*S221+2.783466e+00*S222+2.585396e+00*S223+3.861899e+00*S224+1.001391e+00*S225+1.418574e+00*S226+0.000000e+00*S227+2.356301e+00*S228+1.577219e+00*S229'
.param V63_part24='V63_part23+3.573708e+00*S230+2.036015e+00*S231+3.414701e+00*S232+5.474565e+00*S233+3.068763e+00*S234+4.001462e+00*S235+6.449559e+00*S236+3.448059e+00*S237+2.776407e+00*S238+5.300016e+00*S239'
.param V63_part25='V63_part24+1.671454e+00*S240+2.460217e+00*S241+4.664376e+00*S242+2.343780e+00*S243+2.214827e+00*S244+5.254005e+00*S245+3.560429e+00*S246+2.724531e+00*S247+5.288630e+00*S248+3.364082e+00*S249'
.param V63_part26='V63_part25+3.456552e+00*S250+5.201256e+00*S251+3.219588e+00*S252+3.372318e+00*S253+4.963082e+00*S254+0.000000e+00*S255+0.000000e+00*S256+4.648646e+00*S257+3.629815e-01*S258+1.388225e+00*S259'
.param V63_part27='V63_part26+1.173702e+00*S260+(-2.303896e-01)*S261+(-4.431222e-03)*S262+2.615326e+00*S263+6.047680e-01*S264+4.069103e+00*S265+4.677659e+00*S266+5.116981e-01*S267+3.656145e+00*S268+6.579008e+00*S269'
.param V63_part28='V63_part27+2.210063e-01*S270+1.862762e+00*S271+8.208887e+00*S272+1.098287e+00*S273+2.524319e+00*S274+8.128952e+00*S275+1.964658e+00*S276+3.977698e+00*S277+8.379481e+00*S278+2.667416e+00*S279'
.param V63_part29='V63_part28+2.091335e+00*S280+8.773132e+00*S281+1.981620e+00*S282+3.440860e+00*S283+8.503751e+00*S284+(-6.251276e-01)*S285+1.859453e+00*S286+3.250857e+00*S287+5.988563e-01*S288+2.862018e+00*S289'
.param V63_part30='V63_part29+2.104904e+00*S290+2.509614e+00*S291+3.392791e+00*S292+4.023251e-01*S293+2.165115e+00*S294+1.983576e+00*S295+6.161568e-01*S296+1.435216e+00*S297+2.600152e+00*S298+1.404467e+00*S299'
.param V63_part31='V63_part30+(-1.057420e+00)*S300+7.647594e-01*S301+2.374082e+00*S302+4.270019e-01*S303+2.390447e-01*S304+6.423748e+00*S305+2.283383e-01*S306+4.036032e-01*S307+7.970529e+00*S308+1.292538e-01*S309'
.param V63='V63_part31+8.006970e-01*S310+7.971575e+00*S311+1.577577e+00*S312+8.267077e-01*S313+9.159783e+00*S314'
.param V64_part1='(-4.463646e-02)*S0+0.000000e+00*S1+3.475694e-03*S2+3.004715e-03*S3+5.916022e-03*S4+6.670817e-03*S5+(-4.143992e-03)*S6+(-1.295223e-03)*S7+(-2.188977e-03)*S8+1.168771e-02*S9'
.param V64_part2='V64_part1+(-2.926724e-02)*S10+5.759044e-03*S11+3.551384e-02*S12+1.336803e-02*S13+(-9.825834e-03)*S14+(-6.750891e-02)*S15+(-6.749061e-03)*S16+1.703695e-02*S17+(-2.030096e-02)*S18+2.137144e-02*S19'
.param V64_part3='V64_part2+1.877639e-02*S20+1.228660e-02*S21+3.018946e-02*S22+1.824922e-02*S23+2.349212e-02*S24+2.512514e-02*S25+6.777015e-02*S26+2.440865e-02*S27+2.079134e-02*S28+1.905167e-02*S29'
.param V64_part4='V64_part3+0.000000e+00*S30+2.327981e-01*S31+0.000000e+00*S32+2.909604e-01*S33+0.000000e+00*S34+1.123460e-01*S35+3.607570e-01*S36+8.521065e-01*S37+3.154991e-01*S38+2.799978e-01*S39'
.param V64_part5='V64_part4+2.123940e-01*S40+1.963114e-01*S41+2.524940e-01*S42+1.851321e-01*S43+1.699849e-01*S44+3.331615e-01*S45+3.922758e-01*S46+6.713959e-01*S47+6.472553e-01*S48+5.680462e-01*S49'
.param V64_part6='V64_part5+1.825916e+00*S50+1.043015e+00*S51+1.048075e+00*S52+1.848856e+00*S53+1.656996e+00*S54+(-8.062199e-02)*S55+1.950573e+00*S56+1.223821e+00*S57+1.447092e+00*S58+0.000000e+00*S59'
.param V64_part7='V64_part6+7.496659e-01*S60+1.118528e+00*S61+1.706321e+00*S62+5.243078e-02*S63+1.907915e+00*S64+2.785987e+00*S65+5.702162e-01*S66+1.617453e+00*S67+2.616786e+00*S68+3.168241e-01*S69'
.param V64_part8='V64_part7+2.145743e+00*S70+3.481551e+00*S71+1.495035e+00*S72+1.317019e+00*S73+1.579863e-01*S74+0.000000e+00*S75+0.000000e+00*S76+2.323051e-01*S77+0.000000e+00*S78+2.567950e-01*S79'
.param V64_part9='V64_part8+6.488275e-01*S80+2.536249e-01*S81+2.505334e-01*S82+5.531278e-01*S83+4.915697e-01*S84+5.164468e-01*S85+7.613601e-01*S86+6.890985e-01*S87+4.344797e-01*S88+9.251206e-01*S89'
.param V64_part10='V64_part9+8.205700e-02*S90+0.000000e+00*S91+1.454892e-01*S92+1.984028e-01*S93+0.000000e+00*S94+0.000000e+00*S95+3.292739e-01*S96+1.127127e-01*S97+0.000000e+00*S98+1.536997e+00*S99'
.param V64_part11='V64_part10+3.675481e-01*S100+0.000000e+00*S101+1.888287e+00*S102+1.270418e+00*S103+0.000000e+00*S104+4.915005e-01*S105+1.238829e+00*S106+3.020973e-01*S107+5.725490e-01*S108+2.009122e-01*S109'
.param V64_part12='V64_part11+1.104387e+00*S110+2.476429e+00*S111+1.014504e+00*S112+6.621801e-01*S113+1.283510e+00*S114+1.256943e+00*S115+7.293513e-01*S116+3.052760e+00*S117+1.711601e+00*S118+6.220330e+00*S119'
.param V64_part13='V64_part12+0.000000e+00*S120+2.319830e-01*S121+2.695511e-01*S122+(-5.894744e+01)*S123+2.523980e-01*S124+4.371597e-01*S125+2.187841e+00*S126+0.000000e+00*S127+7.330589e-01*S128+1.288845e+00*S129'
.param V64_part14='V64_part13+1.917232e+00*S130+5.270746e+00*S131+3.506619e+00*S132+3.439015e+00*S133+5.910387e+00*S134+0.000000e+00*S135+9.414351e-01*S136+5.415147e-01*S137+1.608190e-01*S138+1.454512e-01*S139'
.param V64_part15='V64_part14+1.891788e-01*S140+1.021406e-01*S141+8.071073e-03*S142+1.469416e-01*S143+1.112401e-01*S144+6.083520e-02*S145+1.208658e-01*S146+1.525129e-02*S147+1.157755e-01*S148+7.338323e-02*S149'
.param V64_part16='V64_part15+0.000000e+00*S150+7.384347e-01*S151+0.000000e+00*S152+0.000000e+00*S153+0.000000e+00*S154+0.000000e+00*S155+1.005961e+00*S156+2.587935e+00*S157+1.648066e+00*S158+2.883716e+00*S159'
.param V64_part17='V64_part16+3.153946e+00*S160+4.959390e+00*S161+3.513728e+00*S162+4.118038e+00*S163+6.206265e+00*S164+2.689227e-01*S165+6.860869e-01*S166+0.000000e+00*S167+2.714701e+00*S168+0.000000e+00*S169'
.param V64_part18='V64_part17+2.565776e+00*S170+4.066982e+00*S171+3.075102e+00*S172+3.768381e+00*S173+3.263725e+00*S174+5.331399e+00*S175+4.819879e+00*S176+3.660119e+00*S177+4.292799e+00*S178+6.844312e+00*S179'
.param V64_part19='V64_part18+3.825095e-01*S180+2.676244e+00*S181+2.236800e+00*S182+1.697953e+00*S183+0.000000e+00*S184+1.659033e+00*S185+3.391347e+00*S186+3.166025e+00*S187+4.734480e+00*S188+3.924609e+00*S189'
.param V64_part20='V64_part19+4.452522e+00*S190+5.846040e+00*S191+4.265743e+00*S192+4.967621e+00*S193+6.872405e+00*S194+2.515994e+00*S195+2.835353e-01*S196+2.212401e-01*S197+3.286104e-01*S198+0.000000e+00*S199'
.param V64_part21='V64_part20+2.294313e-01*S200+2.228369e-01*S201+2.199306e-01*S202+2.784227e-01*S203+1.990713e-01*S204+1.421905e+00*S205+5.336102e+00*S206+4.575647e+00*S207+3.131354e+00*S208+5.059369e+00*S209'
.param V64_part22='V64_part21+4.027189e-01*S210+(-1.827554e-02)*S211+0.000000e+00*S212+3.431245e+00*S213+3.380799e+00*S214+0.000000e+00*S215+2.925634e+00*S216+3.744618e+00*S217+6.301881e+00*S218+2.821799e+00*S219'
.param V64_part23='V64_part22+5.449366e+00*S220+6.669554e+00*S221+4.290412e+00*S222+6.463805e+00*S223+9.299582e+00*S224+2.890503e+00*S225+2.712692e+00*S226+0.000000e+00*S227+1.882788e+00*S228+4.494273e+00*S229'
.param V64_part24='V64_part23+3.029440e+00*S230+3.302540e+00*S231+5.828648e+00*S232+3.198262e+00*S233+3.367301e+00*S234+3.021084e+00*S235+3.390022e+00*S236+4.342336e+00*S237+6.980836e+00*S238+9.230638e+00*S239'
.param V64_part25='V64_part24+2.726862e+00*S240+3.401502e+00*S241+5.561638e+00*S242+2.188893e+00*S243+3.898818e+00*S244+3.735705e+00*S245+3.522148e+00*S246+6.138034e+00*S247+4.055677e+00*S248+4.123494e+00*S249'
.param V64_part26='V64_part25+4.731907e+00*S250+3.321305e+00*S251+4.487602e+00*S252+7.094705e+00*S253+5.456737e+00*S254+0.000000e+00*S255+0.000000e+00*S256+4.024620e+00*S257+3.214196e-01*S258+2.221395e+00*S259'
.param V64_part27='V64_part26+5.880140e+00*S260+3.733879e+00*S261+4.599322e+00*S262+4.588219e+00*S263+4.718250e+00*S264+2.959660e+00*S265+4.507847e+00*S266+5.458080e+00*S267+3.225498e+00*S268+5.020016e+00*S269'
.param V64_part28='V64_part27+1.872242e+00*S270+4.604227e+00*S271+7.761440e+00*S272+3.452488e+00*S273+5.396006e+00*S274+7.903674e+00*S275+4.098714e+00*S276+4.757130e+00*S277+6.676297e+00*S278+5.369860e+00*S279'
.param V64_part29='V64_part28+6.908888e+00*S280+5.077765e+00*S281+2.491084e+00*S282+7.773338e+00*S283+5.601775e+00*S284+2.880912e+00*S285+4.633239e+00*S286+8.755964e+00*S287+4.406748e+00*S288+4.893056e+00*S289'
.param V64_part30='V64_part29+9.093691e+00*S290+5.017935e+00*S291+6.768946e+00*S292+8.509876e+00*S293+5.717831e+00*S294+7.677121e+00*S295+9.441039e+00*S296+6.788849e+00*S297+8.239460e+00*S298+9.563424e+00*S299'
.param V64_part31='V64_part30+3.825460e+00*S300+1.033238e+00*S301+8.943733e+00*S302+4.280403e+00*S303+6.283518e+00*S304+6.196867e+00*S305+4.530875e+00*S306+7.245891e+00*S307+6.185747e+00*S308+6.571055e+00*S309'
.param V64='V64_part31+7.884484e+00*S310+4.517006e+00*S311+6.939296e+00*S312+8.541202e+00*S313+4.643122e+00*S314'
.param V65_part1='9.369872e+00*S0+0.000000e+00*S1+6.129983e+00*S2+4.845950e+00*S3+6.027874e+00*S4+4.168106e+00*S5+9.266160e+00*S6+5.242612e+00*S7+3.702414e+00*S8+7.098959e+00*S9'
.param V65_part2='V65_part1+3.385684e+00*S10+2.931470e+00*S11+4.812232e+00*S12+4.149198e+00*S13+3.304546e+00*S14+(-1.770787e+01)*S15+5.017361e+00*S16+4.130025e-02*S17+3.738598e+00*S18+3.681805e+00*S19'
.param V65_part3='V65_part2+7.028079e-02*S20+7.346436e+00*S21+3.765434e+00*S22+1.293009e+00*S23+8.205484e+00*S24+1.935421e+00*S25+3.275638e+00*S26+7.457059e+00*S27+5.712894e+00*S28+4.339062e+00*S29'
.param V65_part4='V65_part3+0.000000e+00*S30+7.602735e+00*S31+1.025869e+03*S32+9.573051e+00*S33+0.000000e+00*S34+7.319046e+00*S35+7.705020e+00*S36+1.346526e-01*S37+2.007318e-01*S38+3.230280e-01*S39'
.param V65_part5='V65_part4+1.888363e-01*S40+(-1.860034e-02)*S41+3.799637e-01*S42+7.355041e-02*S43+(-7.477975e-02)*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-1.632968e+00)*S48+6.649661e+00*S49'
.param V65_part6='V65_part5+4.807525e+00*S50+0.000000e+00*S51+0.000000e+00*S52+(-9.080400e-02)*S53+1.285567e+00*S54+3.771917e+00*S55+(-6.143288e-02)*S56+0.000000e+00*S57+0.000000e+00*S58+(-9.241862e-02)*S59'
.param V65_part7='V65_part6+1.790886e+02*S60+2.136519e+01*S61+6.808681e+01*S62+1.088190e+02*S63+3.348878e+01*S64+2.447175e+01*S65+5.309951e+00*S66+4.068008e+00*S67+9.359281e+00*S68+5.196508e+00*S69'
.param V65_part8='V65_part7+3.892549e+00*S70+1.837901e+00*S71+3.027561e+00*S72+3.776715e+00*S73+(-5.918558e-01)*S74+2.374970e+02*S75+6.445822e+03*S76+2.907635e+00*S77+8.172806e+00*S78+2.546580e+02*S79'
.param V65_part9='V65_part8+2.514879e+00*S80+1.419763e+00*S81+4.957722e+00*S82+2.534943e-01*S83+6.443763e-02*S84+0.000000e+00*S85+2.201310e-01*S86+(-4.077948e-02)*S87+2.250494e-01*S88+(-1.876119e-02)*S89'
.param V65_part10='V65_part9+1.082826e+02*S90+3.152272e+01*S91+0.000000e+00*S92+1.137937e+01*S93+7.480303e+03*S94+1.185095e-01*S95+6.250262e+00*S96+7.278297e+01*S97+1.377231e+01*S98+4.603294e+00*S99'
.param V65_part11='V65_part10+5.351470e+00*S100+5.955644e+00*S101+4.184422e+00*S102+4.875109e+00*S103+3.487702e+00*S104+(-1.659517e+03)*S105+1.791779e+01*S106+0.000000e+00*S107+(-1.959450e+03)*S108+1.000000e+04*S109'
.param V65_part12='V65_part11+4.291694e+00*S110+4.744682e+01*S111+8.181030e+00*S112+1.748118e+00*S113+3.216232e+00*S114+5.356192e+00*S115+1.593607e+00*S116+4.436033e+00*S117+6.988238e+00*S118+3.284123e+01*S119'
.param V65_part13='V65_part12+0.000000e+00*S120+0.000000e+00*S121+(-2.749929e-01)*S122+1.000000e+04*S123+0.000000e+00*S124+(-1.942753e-01)*S125+5.564881e+00*S126+4.916990e+00*S127+9.587689e-01*S128+1.343901e+01*S129'
.param V65_part14='V65_part13+4.205006e+00*S130+3.148593e+00*S131+3.490315e+02*S132+3.715771e+00*S133+8.915484e+00*S134+8.853790e+02*S135+3.435358e+00*S136+7.113100e+00*S137+1.020989e+00*S138+4.892279e+00*S139'
.param V65_part15='V65_part14+3.406823e-02*S140+2.253147e+01*S141+1.031264e+00*S142+2.826589e-02*S143+7.036123e+00*S144+5.304588e+00*S145+1.742106e-01*S146+5.632017e+00*S147+2.987060e+00*S148+(-1.692825e-01)*S149'
.param V65_part16='V65_part15+3.509069e-01*S150+6.490803e-01*S151+3.918176e+00*S152+(-1.148163e-01)*S153+2.238399e-01*S154+3.704798e+00*S155+7.949794e-02*S156+3.395442e+00*S157+3.088514e+00*S158+1.158491e+01*S159'
.param V65_part17='V65_part16+2.791174e+00*S160+2.603543e+00*S161+2.907450e+00*S162+2.333959e+00*S163+2.798440e+00*S164+0.000000e+00*S165+1.083489e+02*S166+3.941458e+00*S167+4.787919e+00*S168+5.321089e+00*S169'
.param V65_part18='V65_part17+9.882721e+00*S170+3.865886e+01*S171+3.329891e+00*S172+9.827574e+00*S173+1.053288e+00*S174+1.543920e+01*S175+6.196444e+00*S176+2.885305e+00*S177+1.022812e+01*S178+6.274663e+00*S179'
.param V65_part19='V65_part18+2.817273e+00*S180+8.165768e+00*S181+7.889261e+00*S182+7.305356e+00*S183+5.061250e-02*S184+4.461821e+00*S185+9.924220e+00*S186+5.409659e+00*S187+9.624279e-01*S188+1.777019e+01*S189'
.param V65_part20='V65_part19+3.804554e+00*S190+1.931096e+00*S191+7.617793e+00*S192+4.529159e+00*S193+6.932871e+00*S194+7.209410e+00*S195+2.409462e-01*S196+9.193705e-02*S197+0.000000e+00*S198+1.654750e-01*S199'
.param V65_part21='V65_part20+(-4.020806e-02)*S200+1.170797e+00*S201+(-3.290334e-02)*S202+(-2.282842e-01)*S203+5.171559e+00*S204+4.169338e+00*S205+2.670151e+00*S206+1.240786e+00*S207+2.376063e+00*S208+2.747850e-01*S209'
.param V65_part22='V65_part21+2.515406e+03*S210+4.750399e+00*S211+(-2.119877e-01)*S212+2.041012e+01*S213+3.141648e+00*S214+3.705481e-01*S215+1.994291e+00*S216+3.357283e+00*S217+1.436853e+00*S218+9.088255e+00*S219'
.param V65_part23='V65_part22+2.142264e+01*S220+1.810424e+00*S221+2.423593e+00*S222+2.386192e+01*S223+2.505422e+01*S224+5.191929e+02*S225+4.280181e+00*S226+3.143076e+00*S227+2.963033e+00*S228+1.384190e+01*S229'
.param V65_part24='V65_part23+9.990174e+01*S230+2.697565e+00*S231+4.362648e+01*S232+2.415616e+01*S233+3.484871e+00*S234+1.768616e+01*S235+1.598091e+01*S236+4.775878e+00*S237+1.387350e+01*S238+2.456092e+01*S239'
.param V65_part25='V65_part24+1.631232e+01*S240+3.756279e+00*S241+1.445639e+01*S242+1.179420e+00*S243+9.255250e+00*S244+1.970747e+02*S245+5.227307e+00*S246+1.678874e+01*S247+2.755293e+01*S248+3.938145e+00*S249'
.param V65_part26='V65_part25+2.052418e+00*S250+4.540799e+02*S251+4.310786e+00*S252+1.463698e+01*S253+4.575044e+01*S254+3.180449e-01*S255+2.491933e-01*S256+2.241117e+01*S257+6.859083e-01*S258+8.341464e+00*S259'
.param V65_part27='V65_part26+5.234064e+00*S260+9.570416e+00*S261+5.593321e+00*S262+5.371180e+01*S263+5.711916e+00*S264+1.394983e+01*S265+1.942028e+01*S266+5.223487e+00*S267+1.452488e+01*S268+5.737252e+00*S269'
.param V65_part28='V65_part27+1.889139e+01*S270+8.269950e+00*S271+6.691738e+00*S272+1.414384e+01*S273+2.334859e+01*S274+1.027184e+01*S275+1.200641e+01*S276+1.602282e+01*S277+6.490190e+00*S278+2.063942e+01*S279'
.param V65_part29='V65_part28+1.337704e+01*S280+5.836020e+00*S281+6.926865e+00*S282+1.318600e+01*S283+6.985370e+00*S284+1.805485e+01*S285+1.117063e+01*S286+2.526628e+01*S287+8.110573e+00*S288+8.495018e+00*S289'
.param V65_part30='V65_part29+4.568849e+00*S290+2.016670e+01*S291+2.112067e+01*S292+3.524378e+00*S293+1.650699e+01*S294+1.492867e+01*S295+3.578930e+00*S296+8.186250e+00*S297+1.189445e+01*S298+3.344246e+00*S299'
.param V65_part31='V65_part30+1.231297e+01*S300+(-4.474042e-02)*S301+2.182525e+01*S302+1.084726e+01*S303+1.106674e+01*S304+5.749134e+00*S305+6.040877e+00*S306+1.173251e+01*S307+5.314782e+00*S308+1.692641e+01*S309'
.param V65='V65_part31+1.031675e+01*S310+7.654616e+00*S311+1.261638e+01*S312+1.174182e+01*S313+6.628564e+00*S314'
.param V66_part1='(-7.863635e+00)*S0+0.000000e+00*S1+(-5.478996e+00)*S2+(-3.680131e+00)*S3+(-4.786214e+00)*S4+(-1.949721e+00)*S5+(-9.210022e+00)*S6+(-4.400160e+00)*S7+(-2.142902e+00)*S8+(-2.875143e+00)*S9'
.param V66_part2='V66_part1+(-2.273943e+00)*S10+(-1.609257e+00)*S11+(-2.761243e+00)*S12+(-2.043184e+00)*S13+(-1.731485e+00)*S14+1.264443e+02*S15+(-6.326502e+00)*S16+2.459386e-01*S17+(-5.351925e-02)*S18+(-2.666000e+00)*S19'
.param V66_part3='V66_part2+2.481221e-01*S20+(-3.308192e+00)*S21+(-1.872573e+00)*S22+(-3.693219e-02)*S23+(-3.591378e+00)*S24+(-9.953324e-01)*S25+(-9.845879e-01)*S26+(-2.383062e+00)*S27+(-2.144608e+00)*S28+(-9.284072e-01)*S29'
.param V66_part4='V66_part3+0.000000e+00*S30+(-3.616261e+00)*S31+(-3.164324e+01)*S32+(-8.302479e+00)*S33+0.000000e+00*S34+(-5.233410e+00)*S35+(-5.122133e+00)*S36+2.892876e-01*S37+5.149188e-01*S38+1.655210e-01*S39'
.param V66_part5='V66_part4+1.977724e-01*S40+3.165246e-01*S41+1.145934e-01*S42+1.646526e-01*S43+3.021087e-01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+1.594637e+01*S48+(-4.389775e+00)*S49'
.param V66_part6='V66_part5+(-2.708937e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+1.313850e-01*S53+(-5.086638e-01)*S54+(-1.125396e+00)*S55+8.634143e-02*S56+0.000000e+00*S57+0.000000e+00*S58+1.586947e-01*S59'
.param V66_part7='V66_part6+(-1.389237e+01)*S60+(-1.281261e+01)*S61+(-1.195784e+01)*S62+(-6.542068e+01)*S63+5.480185e-01*S64+1.491517e+00*S65+(-2.018937e+00)*S66+(-1.585664e+00)*S67+(-4.968794e+00)*S68+(-1.940783e+00)*S69'
.param V66_part8='V66_part7+(-1.290025e+00)*S70+(-9.294933e-01)*S71+(-1.377066e+00)*S72+(-1.696707e+00)*S73+8.181854e-01*S74+(-7.874220e+02)*S75+(-1.982715e+03)*S76+1.422841e-01*S77+(-5.358535e+00)*S78+(-3.924406e+02)*S79'
.param V66_part9='V66_part8+(-1.144705e+00)*S80+6.349874e-01*S81+(-2.532878e+00)*S82+(-5.951502e-02)*S83+9.913559e-02*S84+0.000000e+00*S85+2.720500e-01*S86+1.891159e-01*S87+9.487913e-02*S88+1.820192e-01*S89'
.param V66_part10='V66_part9+(-1.014254e+02)*S90+5.738220e+01*S91+0.000000e+00*S92+(-7.107863e+00)*S93+1.352501e+01*S94+2.513802e-01*S95+(-3.350523e+00)*S96+1.648847e-01*S97+(-4.770353e+00)*S98+(-1.650487e+00)*S99'
.param V66_part11='V66_part10+(-2.766287e+00)*S100+(-1.631652e+00)*S101+(-1.831428e+00)*S102+(-2.401922e+00)*S103+(-1.155652e+00)*S104+1.000000e+04*S105+(-1.975002e+01)*S106+0.000000e+00*S107+6.112952e+03*S108+1.000000e+04*S109'
.param V66_part12='V66_part11+(-2.210314e+00)*S110+(-1.067399e+01)*S111+(-2.369491e+00)*S112+(-1.227191e+00)*S113+1.259500e-01*S114+(-1.581971e+00)*S115+(-6.296271e-02)*S116+(-1.621416e+00)*S117+(-2.477196e+00)*S118+(-5.128035e+00)*S119'
.param V66_part13='V66_part12+0.000000e+00*S120+0.000000e+00*S121+8.619220e-01*S122+1.000000e+04*S123+0.000000e+00*S124+5.051951e-01*S125+(-1.959576e+00)*S126+(-1.879714e+00)*S127+5.826298e-02*S128+(-7.359938e+00)*S129'
.param V66_part14='V66_part13+(-1.585516e+00)*S130+(-9.378867e-01)*S131+5.319661e-01*S132+(-1.280412e+00)*S133+(-1.580361e+00)*S134+2.129677e+02*S135+(-1.798359e+00)*S136+(-1.649600e+00)*S137+4.161778e-01*S138+(-3.842514e+00)*S139'
.param V66_part15='V66_part14+1.441784e-01*S140+(-1.919439e-01)*S141+4.218769e-01*S142+1.979998e-01*S143+(-9.955635e-02)*S144+1.651780e-02*S145+8.992388e-02*S146+(-2.276380e-01)*S147+(-5.401065e-02)*S148+2.561768e-01*S149'
.param V66_part16='V66_part15+7.710172e-01*S150+5.456320e-01*S151+(-1.263604e+00)*S152+8.321860e-01*S153+4.038281e-01*S154+(-1.169649e+00)*S155+1.916063e-01*S156+(-1.392331e+00)*S157+(-1.072363e+00)*S158+(-3.455584e+00)*S159'
.param V66_part17='V66_part16+(-1.044799e+00)*S160+(-5.752227e-01)*S161+(-9.380332e-01)*S162+(-4.346585e-01)*S163+(-5.432350e-01)*S164+0.000000e+00*S165+(-1.011783e+01)*S166+(-1.491661e+00)*S167+(-1.827134e+00)*S168+(-2.558934e+00)*S169'
.param V66_part18='V66_part17+(-2.160565e+00)*S170+(-1.043969e+01)*S171+(-1.315334e+00)*S172+(-2.065399e+00)*S173+1.333251e-01*S174+(-4.338125e+00)*S175+(-1.325247e+00)*S176+(-1.058263e+00)*S177+(-2.992323e+00)*S178+(-1.392941e+00)*S179'
.param V66_part19='V66_part18+1.234252e+00*S180+(-4.872016e+00)*S181+(-3.094220e+00)*S182+(-4.869687e+00)*S183+5.630821e-01*S184+(-7.521088e-01)*S185+(-4.073147e+00)*S186+(-2.480879e+00)*S187+3.989172e-01*S188+(-5.580527e+00)*S189'
.param V66_part20='V66_part19+(-1.520834e+00)*S190+(-2.387659e-01)*S191+(-2.694931e+00)*S192+(-1.781402e+00)*S193+(-1.556122e+00)*S194+(-4.768623e+00)*S195+5.142289e-01*S196+2.277611e-01*S197+0.000000e+00*S198+7.792904e-01*S199'
.param V66_part21='V66_part20+3.149753e-01*S200+6.357686e-01*S201+6.589570e-01*S202+5.450754e-01*S203+(-2.826818e+00)*S204+(-1.777504e+00)*S205+(-5.117677e-01)*S206+2.829491e-02*S207+(-1.047096e-01)*S208+3.660967e-01*S209'
.param V66_part22='V66_part21+(-8.413501e+00)*S210+(-2.464904e+00)*S211+7.416125e-01*S212+(-7.640633e+00)*S213+(-1.327868e+00)*S214+6.510686e-02*S215+(-7.496355e-01)*S216+(-7.422322e-01)*S217+6.353427e-03*S218+(-3.890920e+00)*S219'
.param V66_part23='V66_part22+(-6.479656e+00)*S220+(-2.343276e-01)*S221+(-6.848938e-01)*S222+(-3.296658e+00)*S223+(-4.775093e+00)*S224+(-1.555198e+01)*S225+(-2.061461e+00)*S226+(-1.147626e+00)*S227+(-8.476586e-01)*S228+(-3.316365e+00)*S229'
.param V66_part24='V66_part23+(-1.337541e+01)*S230+(-9.164897e-01)*S231+(-1.765384e+01)*S232+(-7.138723e+00)*S233+(-8.908139e-01)*S234+(-3.333593e+00)*S235+(-2.786476e+00)*S236+(-1.252279e+00)*S237+(-5.386332e+00)*S238+(-4.779530e+00)*S239'
.param V66_part25='V66_part24+(-5.136953e+00)*S240+(-1.871450e+00)*S241+(-3.241615e+00)*S242+(-1.365809e-01)*S243+(-4.334880e+00)*S244+(-2.608864e+01)*S245+(-2.296177e+00)*S246+(-4.853376e+00)*S247+(-5.854521e+00)*S248+(-1.224596e+00)*S249'
.param V66_part26='V66_part25+(-4.886888e-01)*S250+(-6.936108e+01)*S251+(-1.158694e+00)*S252+(-5.098739e+00)*S253+(-7.990247e+00)*S254+8.657367e-01*S255+1.149058e+00*S256+(-1.876027e+01)*S257+3.921024e-01*S258+(-5.117277e+00)*S259'
.param V66_part27='V66_part26+(-1.621189e+00)*S260+(-3.708243e+00)*S261+(-1.976667e+00)*S262+(-9.427996e+00)*S263+(-2.595851e+00)*S264+(-4.249056e+00)*S265+(-4.308339e+00)*S266+(-1.939551e+00)*S267+(-4.154279e+00)*S268+(-1.923675e+00)*S269'
.param V66_part28='V66_part27+(-5.318543e+00)*S270+(-3.470215e+00)*S271+(-1.326460e+00)*S272+(-4.795286e+00)*S273+(-3.626265e+00)*S274+(-1.069948e+00)*S275+(-5.558837e+00)*S276+(-5.665636e+00)*S277+(-1.083868e+00)*S278+(-7.699270e+00)*S279'
.param V66_part29='V66_part28+(-6.652466e+00)*S280+(-8.902190e-01)*S281+(-3.733514e+00)*S282+(-2.136589e+00)*S283+(-1.119244e+00)*S284+(-8.502690e+00)*S285+(-4.598286e+00)*S286+(-3.454520e+00)*S287+(-2.838394e+00)*S288+(-3.411464e+00)*S289'
.param V66_part30='V66_part29+(-9.800541e-01)*S290+(-8.649575e+00)*S291+(-9.727577e+00)*S292+(-9.366449e-01)*S293+(-7.102884e+00)*S294+(-3.332100e+00)*S295+(-8.654847e-01)*S296+(-3.462977e+00)*S297+(-2.369265e+00)*S298+(-7.512127e-01)*S299'
.param V66_part31='V66_part30+(-4.075667e+00)*S300+6.985629e-01*S301+(-4.305166e+00)*S302+(-3.674630e+00)*S303+(-3.482374e+00)*S304+(-1.145806e+00)*S305+(-1.982290e+00)*S306+(-2.882449e+00)*S307+(-8.571585e-01)*S308+(-5.579170e+00)*S309'
.param V66='V66_part31+(-2.447962e+00)*S310+(-1.327407e+00)*S311+(-2.534711e+00)*S312+(-3.351607e+00)*S313+(-1.043918e+00)*S314'
.param V67_part1='(-8.783984e+00)*S0+0.000000e+00*S1+(-1.316850e+00)*S2+(-2.742855e+00)*S3+(-8.949548e-01)*S4+(-7.839343e-01)*S5+1.034942e+00*S6+1.819872e-01*S7+(-4.141538e-01)*S8+(-6.942254e+00)*S9'
.param V67_part2='V67_part1+7.581726e-01*S10+(-1.500046e-02)*S11+(-1.032955e+00)*S12+(-8.621415e-04)*S13+(-3.400932e-02)*S14+1.820485e+01*S15+(-1.705937e+00)*S16+8.422749e-02*S17+(-7.996829e-01)*S18+(-1.024144e+00)*S19'
.param V67_part3='V67_part2+8.866630e-02*S20+3.526347e-01*S21+(-7.000263e-01)*S22+8.661811e-03*S23+1.554009e-01*S24+7.716112e-01*S25+(-7.175058e-01)*S26+(-2.037770e-01)*S27+(-3.507362e-01)*S28+(-8.998083e-01)*S29'
.param V67_part4='V67_part3+0.000000e+00*S30+(-3.257883e+00)*S31+(-3.005117e+01)*S32+(-3.281723e+00)*S33+0.000000e+00*S34+(-1.574759e+00)*S35+(-2.706987e+00)*S36+(-3.113765e-02)*S37+(-5.300115e-02)*S38+3.732094e-02*S39'
.param V67_part5='V67_part4+1.367874e-01*S40+1.303522e-01*S41+1.845241e-01*S42+2.391148e-01*S43+1.600306e-01*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-3.759546e-01)*S48+(-1.962032e+00)*S49'
.param V67_part6='V67_part5+(-1.215873e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+1.086063e-01*S53+(-4.516238e-01)*S54+(-3.610757e-01)*S55+9.848927e-02*S56+0.000000e+00*S57+0.000000e+00*S58+(-7.103997e-02)*S59'
.param V67_part7='V67_part6+8.834371e-03*S60+(-8.777746e+00)*S61+(-1.773379e+01)*S62+(-3.365892e+00)*S63+(-2.001522e+01)*S64+(-8.675746e+00)*S65+(-4.288394e+00)*S66+(-1.223443e+00)*S67+(-3.493021e-02)*S68+(-3.597044e+00)*S69'
.param V67_part8='V67_part7+(-9.240706e-01)*S70+(-3.205957e-01)*S71+(-1.115596e-01)*S72+(-8.941107e-01)*S73+4.558508e-01*S74+8.513823e+01*S75+1.715956e+02*S76+(-1.243090e+00)*S77+(-3.957388e+00)*S78+(-8.956571e+00)*S79'
.param V67_part9='V67_part8+(-3.484804e-01)*S80+(-1.842122e-01)*S81+(-1.749215e+00)*S82+(-1.182470e-01)*S83+3.617718e-03*S84+0.000000e+00*S85+9.712249e-02*S86+(-2.539528e-02)*S87+(-4.212459e-02)*S88+1.800087e-03*S89'
.param V67_part10='V67_part9+(-3.404728e+00)*S90+1.398234e+02*S91+0.000000e+00*S92+(-9.625108e+00)*S93+8.813108e+01*S94+(-2.204545e-02)*S95+(-3.481279e+00)*S96+3.062156e-01*S97+(-5.959869e+00)*S98+(-8.533341e-01)*S99'
.param V67_part11='V67_part10+(-1.506788e+00)*S100+(-2.439618e+00)*S101+(-1.398244e+00)*S102+(-9.368482e-01)*S103+(-1.057985e+00)*S104+2.232924e+02*S105+(-7.461242e+00)*S106+0.000000e+00*S107+2.249471e+02*S108+1.000000e+04*S109'
.param V67_part12='V67_part11+(-8.762144e-01)*S110+(-5.117575e+00)*S111+(-1.265523e+00)*S112+7.462791e-01*S113+8.441976e-01*S114+1.034973e+00*S115+3.417151e-01*S116+(-2.288472e+00)*S117+2.141666e+00*S118+(-1.495408e+01)*S119'
.param V67_part13='V67_part12+0.000000e+00*S120+0.000000e+00*S121+4.260270e-01*S122+1.000000e+04*S123+0.000000e+00*S124+4.524119e-01*S125+(-3.662284e+00)*S126+(-2.293467e+00)*S127+3.887713e-02*S128+1.027580e+00*S129'
.param V67_part14='V67_part13+(-1.789940e+00)*S130+(-1.167207e+00)*S131+1.107242e+01*S132+(-1.541506e+00)*S133+(-4.081728e+00)*S134+2.463719e+01*S135+(-8.883180e-01)*S136+(-2.982279e+00)*S137+(-3.225963e-01)*S138+(-1.555118e+00)*S139'
.param V67_part15='V67_part14+8.150457e-02*S140+(-2.038946e-01)*S141+(-1.436150e-01)*S142+6.717691e-02*S143+(-7.336808e-02)*S144+(-9.575502e-03)*S145+8.275094e-02*S146+3.577814e-02*S147+(-1.118493e-01)*S148+2.196511e-01*S149'
.param V67_part16='V67_part15+(-2.716414e-01)*S150+(-4.776968e-01)*S151+(-1.950507e+00)*S152+8.107617e-01*S153+(-9.922626e-02)*S154+(-1.735877e+00)*S155+1.556216e-01*S156+(-1.778487e+00)*S157+(-1.239538e+00)*S158+(-1.005681e+01)*S159'
.param V67_part17='V67_part16+(-1.286924e+00)*S160+(-5.992181e-01)*S161+(-1.547913e+00)*S162+4.040622e-01*S163+(-6.118916e-01)*S164+0.000000e+00*S165+(-4.828423e+00)*S166+(-2.072561e+00)*S167+(-3.999149e+00)*S168+(-3.124576e+00)*S169'
.param V67_part18='V67_part17+(-3.883532e+00)*S170+(-2.687561e+01)*S171+(-1.615247e+00)*S172+(-4.477099e+00)*S173+4.274585e-01*S174+(-7.720617e+00)*S175+(-2.008382e+00)*S176+(-9.432174e-01)*S177+(-4.895943e+00)*S178+(-1.989893e+00)*S179'
.param V67_part19='V67_part18+4.631823e-02*S180+(-4.125257e+00)*S181+(-4.282719e+00)*S182+(-2.522713e+00)*S183+1.582413e-01*S184+(-1.921938e+00)*S185+(-6.980631e+00)*S186+(-1.491856e-01)*S187+1.771434e-01*S188+(-1.188351e+01)*S189'
.param V67_part20='V67_part19+2.183561e+00*S190+(-4.666723e-02)*S191+(-2.592714e+00)*S192+1.769266e+00*S193+(-2.485206e+00)*S194+(-7.169810e+00)*S195+1.309767e-01*S196+2.229730e-01*S197+0.000000e+00*S198+2.438146e-01*S199'
.param V67_part21='V67_part20+2.868364e-01*S200+9.380607e-01*S201+9.307410e-01*S202+3.664896e-01*S203+2.211213e+00*S204+1.572587e+00*S205+(-4.229630e-01)*S206+1.121370e+00*S207+4.416434e-01*S208+1.157312e-01*S209'
.param V67_part22='V67_part21+5.643799e+00*S210+(-3.271736e+00)*S211+5.046765e-01*S212+(-1.759964e+01)*S213+(-2.001674e+00)*S214+4.869134e-01*S215+(-1.458578e+00)*S216+(-3.121082e-01)*S217+(-1.061635e-01)*S218+(-5.779829e+00)*S219'
.param V67_part23='V67_part22+(-1.151536e+01)*S220+(-2.503693e-01)*S221+(-1.176816e-01)*S222+(-1.492658e+01)*S223+(-1.181810e+01)*S224+(-3.571514e+01)*S225+(-3.065445e+00)*S226+(-1.570789e+00)*S227+(-6.764804e-01)*S228+(-8.313728e+00)*S229'
.param V67_part24='V67_part23+(-4.834491e+01)*S230+(-1.049474e+00)*S231+(-2.075692e+01)*S232+(-1.014868e+01)*S233+(-1.067174e+00)*S234+(-8.965398e+00)*S235+(-6.696238e+00)*S236+(-1.380117e+00)*S237+(-4.803455e+00)*S238+(-9.567770e+00)*S239'
.param V67_part25='V67_part24+(-1.660211e+01)*S240+(-2.617375e+00)*S241+(-7.944397e+00)*S242+1.186848e+00*S243+(-5.135007e+00)*S244+(-5.513686e+01)*S245+(-2.422015e+00)*S246+(-9.633907e+00)*S247+(-1.054033e+01)*S248+(-9.170529e-01)*S249'
.param V67_part26='V67_part25+1.621588e-02*S250+(-6.582650e+01)*S251+(-1.851309e+00)*S252+(-5.461675e+00)*S253+(-1.751744e+01)*S254+3.777993e-01*S255+3.104250e-01*S256+(-7.453199e+00)*S257+(-2.685192e-01)*S258+(-4.239479e+00)*S259'
.param V67_part27='V67_part26+(-2.630713e+00)*S260+(-7.717822e+00)*S261+(-2.918535e+00)*S262+(-2.413251e+01)*S263+(-3.505362e+00)*S264+(-6.128364e+00)*S265+(-7.123378e+00)*S266+(-2.149860e+00)*S267+(-5.406474e+00)*S268+(-1.724178e+00)*S269'
.param V67_part28='V67_part27+(-1.575016e+01)*S270+(-5.604932e+00)*S271+(-3.609160e+00)*S272+(-1.142941e+01)*S273+(-1.511696e+01)*S274+(-5.763680e+00)*S275+(-7.302086e+00)*S276+(-7.904196e+00)*S277+(-2.846159e+00)*S278+(-1.682795e+01)*S279'
.param V67_part29='V67_part28+1.642154e+00*S280+(-2.377777e+00)*S281+(-2.325833e+00)*S282+(-9.052251e+00)*S283+(-3.015722e+00)*S284+(-1.259314e+01)*S285+(-7.247082e+00)*S286+(-1.424690e+01)*S287+(-6.366536e+00)*S288+(-5.167544e+00)*S289'
.param V67_part30='V67_part29+(-1.979349e+00)*S290+(-1.496242e+01)*S291+(-1.008917e+01)*S292+(-1.288380e+00)*S293+(-8.783630e+00)*S294+(-8.183799e+00)*S295+(-1.274864e+00)*S296+(-3.417959e+00)*S297+(-6.819211e+00)*S298+(-1.150322e+00)*S299'
.param V67_part31='V67_part30+(-1.125547e+01)*S300+5.675836e-01*S301+(-1.224013e+01)*S302+(-9.974254e+00)*S303+(-6.936375e+00)*S304+(-2.772157e+00)*S305+(-4.468393e+00)*S306+(-7.071938e+00)*S307+(-2.512672e+00)*S308+(-8.055376e+00)*S309'
.param V67='V67_part31+(-5.976515e+00)*S310+(-3.133807e+00)*S311+(-6.473170e+00)*S312+(-5.558790e+00)*S313+(-2.722283e+00)*S314'
.param V68_part1='1.223214e-02*S0+0.000000e+00*S1+(-4.116940e-01)*S2+(-1.327010e+00)*S3+(-2.997953e-01)*S4+(-1.957900e-01)*S5+2.313982e+00*S6+4.312937e-01*S7+(-2.674028e-01)*S8+(-3.287346e-01)*S9'
.param V68_part2='V68_part1+8.735374e-02*S10+(-4.181984e-01)*S11+(-6.509799e-01)*S12+(-2.030143e-01)*S13+(-2.931525e-01)*S14+2.858104e+00*S15+(-1.691374e+00)*S16+6.825957e-01*S17+(-1.269191e+00)*S18+(-9.552159e-01)*S19'
.param V68_part3='V68_part2+9.507637e-01*S20+(-4.061635e+00)*S21+(-1.344567e+00)*S22+(-7.726694e-01)*S23+(-3.659494e+00)*S24+(-5.410108e-01)*S25+(-2.260485e-01)*S26+(-3.000036e+00)*S27+(-1.781618e+00)*S28+(-7.965705e-01)*S29'
.param V68_part4='V68_part3+0.000000e+00*S30+(-1.548288e+00)*S31+(-1.291384e+03)*S32+(-3.882347e-01)*S33+0.000000e+00*S34+(-1.993854e-01)*S35+(-7.585142e-02)*S36+9.363249e-01*S37+1.551239e+00*S38+1.887422e+00*S39'
.param V68_part5='V68_part4+1.469624e+00*S40+1.100165e+00*S41+1.979760e+00*S42+1.133238e+00*S43+1.110846e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+(-1.672019e+00)*S48+8.669517e-01*S49'
.param V68_part6='V68_part5+(-1.493972e-01)*S50+0.000000e+00*S51+0.000000e+00*S52+3.770818e-02*S53+6.538685e-01*S54+9.271739e-01*S55+7.174848e-02*S56+0.000000e+00*S57+0.000000e+00*S58+4.612127e-02*S59'
.param V68_part7='V68_part6+(-1.970290e+02)*S60+6.281591e-01*S61+(-4.786661e+01)*S62+(-1.274986e+01)*S63+(-1.163516e+01)*S64+(-1.053092e+01)*S65+2.320878e-01*S66+(-4.631037e-02)*S67+1.496455e+00*S68+4.400072e-01*S69'
.param V68_part8='V68_part7+5.957773e-03*S70+2.907357e-01*S71+3.359161e-02*S72+(-3.051826e-01)*S73+1.666886e+00*S74+(-3.521270e+00)*S75+(-7.885371e+03)*S76+(-1.195981e+00)*S77+1.072849e+00*S78+3.199259e+00*S79'
.param V68_part9='V68_part8+3.897650e-01*S80+6.511308e+00*S81+7.831845e-02*S82+1.541767e-01*S83+2.009225e-02*S84+0.000000e+00*S85+(-5.905656e-01)*S86+4.044638e-01*S87+1.083878e+00*S88+(-1.352312e-01)*S89'
.param V68_part10='V68_part9+(-6.904973e+00)*S90+(-1.040628e+02)*S91+0.000000e+00*S92+6.306845e-01*S93+(-1.000000e+04)*S94+4.104224e-01*S95+5.331604e-02*S96+(-9.734067e+01)*S97+(-1.479858e+00)*S98+2.003405e+00*S99'
.param V68_part11='V68_part10+(-1.305590e-01)*S100+(-1.503548e-01)*S101+4.042405e-01*S102+4.247409e-02*S103+2.042765e-01*S104+6.242396e+00*S105+4.557644e-01*S106+0.000000e+00*S107+7.516676e+00*S108+3.578547e+03*S109'
.param V68_part12='V68_part11+2.642940e-01*S110+1.175217e+02*S111+9.503741e+00*S112+1.221897e+00*S113+6.944237e+00*S114+6.229802e+00*S115+1.928213e+00*S116+2.200819e-01*S117+5.975606e+00*S118+(-9.225780e+00)*S119'
.param V68_part13='V68_part12+0.000000e+00*S120+0.000000e+00*S121+9.006077e-01*S122+(-1.000000e+04)*S123+0.000000e+00*S124+1.121466e+00*S125+(-4.714407e-02)*S126+1.832442e-01*S127+6.062059e-01*S128+6.609007e+00*S129'
.param V68_part14='V68_part13+2.943049e-01*S130+2.940277e-02*S131+1.391990e+03*S132+1.707447e-01*S133+(-1.346293e+00)*S134+3.216393e+03*S135+(-4.884318e-02)*S136+(-1.593607e+00)*S137+3.659364e+00*S138+9.612356e-01*S139'
.param V68_part15='V68_part14+5.334399e-01*S140+8.925600e+01*S141+4.302446e+00*S142+5.701268e-01*S143+2.751227e+01*S144+2.100482e+01*S145+8.265704e-01*S146+2.105425e+01*S147+1.121076e+01*S148+5.376118e-01*S149'
.param V68_part16='V68_part15+1.485110e+00*S150+1.469060e+00*S151+1.529393e-01*S152+1.195087e+00*S153+8.360352e-01*S154+9.890571e-02*S155+5.937440e-01*S156+(-3.424357e-03)*S157+2.718375e-02*S158+(-2.039652e+00)*S159'
.param V68_part17='V68_part16+1.100012e-01*S160+1.357420e+00*S161+2.751692e-01*S162+2.374587e+00*S163+1.488326e+00*S164+0.000000e+00*S165+(-1.177416e+02)*S166+2.590230e-02*S167+8.446520e-02*S168+1.159487e-01*S169'
.param V68_part18='V68_part17+(-1.788639e+00)*S170+(-1.807521e+01)*S171+8.309566e-01*S172+(-1.188385e+00)*S173+2.354724e+00*S174+(-3.880780e+00)*S175+(-8.698812e-01)*S176+7.201997e-01*S177+(-1.756974e+00)*S178+(-8.764239e-01)*S179'
.param V68_part19='V68_part18+(-3.861821e+00)*S180+7.585091e-03*S181+(-5.090575e-02)*S182+3.417454e+00*S183+9.526205e-01*S184+(-1.844540e-02)*S185+(-4.364644e-01)*S186+2.802789e+00*S187+1.627419e+00*S188+(-4.820119e+00)*S189'
.param V68_part20='V68_part19+2.158305e+00*S190+1.613755e+00*S191+1.080352e+00*S192+1.731118e+00*S193+(-6.923575e-01)*S194+1.026229e+00*S195+1.510812e+00*S196+1.037667e+00*S197+0.000000e+00*S198+1.816047e+00*S199'
.param V68_part21='V68_part20+8.597542e-01*S200+6.978525e+00*S201+2.608229e+00*S202+8.098396e-01*S203+6.553780e+00*S204+3.413080e+00*S205+2.097522e+00*S206+2.395094e+00*S207+4.091432e+00*S208+7.932756e-01*S209'
.param V68_part22='V68_part21+1.000000e+04*S210+2.195121e-02*S211+4.049912e-01*S212+(-3.818777e+00)*S213+8.177379e-02*S214+6.836042e-01*S215+4.154430e-01*S216+3.434792e+00*S217+1.379907e+00*S218+(-7.932758e-01)*S219'
.param V68_part23='V68_part22+(-4.530215e+00)*S220+1.207059e+00*S221+2.374902e+00*S222+(-6.236540e+00)*S223+(-5.457420e+00)*S224+1.957393e+03*S225+1.777984e-01*S226+8.965626e-02*S227+3.109216e+00*S228+(-3.736552e+00)*S229'
.param V68_part24='V68_part23+(-4.178933e+01)*S230+1.793837e+00*S231+(-1.287364e+01)*S232+(-4.487109e+00)*S233+3.027906e+00*S234+(-5.107913e+00)*S235+(-3.360089e+00)*S236+3.586271e+00*S237+(-2.049728e-01)*S238+(-5.378164e+00)*S239'
.param V68_part25='V68_part24+(-4.481717e+00)*S240+3.447102e-02*S241+(-2.889195e+00)*S242+1.959766e+00*S243+(-8.746060e-01)*S244+(-1.453601e+02)*S245+3.007231e+00*S246+(-3.881508e+00)*S247+(-8.303391e+00)*S248+2.634706e+00*S249'
.param V68_part26='V68_part25+1.792971e+00*S250+(-3.936179e+02)*S251+2.675068e+00*S252+(-1.906488e+00)*S253+(-1.507334e+01)*S254+1.821259e+00*S255+1.783642e+00*S256+(-2.259108e+00)*S257+2.146517e+00*S258+(-5.400968e-01)*S259'
.param V68_part27='V68_part26+(-3.961396e-01)*S260+(-2.070064e+00)*S261+(-7.730904e-01)*S262+(-1.892240e+01)*S263+(-5.326253e-01)*S264+(-3.489187e+00)*S265+(-4.848384e+00)*S266+4.656310e-01*S267+(-3.683918e+00)*S268+(-1.522370e-01)*S269'
.param V68_part28='V68_part27+(-6.381640e+00)*S270+(-9.373023e-01)*S271+(-6.073540e-01)*S272+(-3.553084e+00)*S273+(-7.759477e+00)*S274+(-1.378542e+00)*S275+(-1.775826e+00)*S276+(-3.443927e+00)*S277+(-8.305440e-01)*S278+(-3.674116e+00)*S279'
.param V68_part29='V68_part28+3.585079e+00*S280+(-7.723676e-01)*S281+(-2.189703e-01)*S282+(-1.791601e+00)*S283+(-8.697804e-01)*S284+(-4.415987e+00)*S285+(-1.976496e+00)*S286+(-6.495975e+00)*S287+(-1.554592e+00)*S288+(-9.015702e-01)*S289'
.param V68_part30='V68_part29+(-3.445682e-01)*S290+(-4.279836e+00)*S291+(-3.085863e+00)*S292+(-2.159550e-01)*S293+(-3.290643e+00)*S294+(-3.669498e+00)*S295+(-2.704968e-01)*S296+(-5.405271e-01)*S297+(-2.195098e+00)*S298+(-2.226339e-01)*S299'
.param V68_part31='V68_part30+(-3.757389e+00)*S300+8.207285e-01*S301+(-5.127715e+00)*S302+(-2.391359e+00)*S303+(-2.822549e+00)*S304+(-5.675979e-01)*S305+(-9.538802e-01)*S306+(-2.433675e+00)*S307+(-5.091656e-01)*S308+(-5.396747e+00)*S309'
.param V68='V68_part31+(-1.705750e+00)*S310+(-1.132214e+00)*S311+6.505734e-03*S312+(-2.249101e+00)*S313+(-9.133607e-01)*S314'
.param V69_part1='(-9.307426e-02)*S0+0.000000e+00*S1+5.798243e-02*S2+5.677746e-03*S3+4.033993e-02*S4+2.968318e-02*S5+2.832429e-02*S6+3.594501e-03*S7+(-7.106411e-03)*S8+(-1.572868e-02)*S9'
.param V69_part2='V69_part1+(-2.202207e-02)*S10+(-4.302091e-03)*S11+1.205750e-02*S12+(-4.820916e-03)*S13+(-3.846004e-03)*S14+(-2.782307e-03)*S15+(-2.819506e-03)*S16+(-6.729357e-04)*S17+(-2.271122e-02)*S18+(-1.516372e-02)*S19'
.param V69_part3='V69_part2+(-3.695291e-04)*S20+(-2.878119e-02)*S21+(-3.348544e-03)*S22+1.063523e-06*S23+(-6.604205e-05)*S24+(-5.382975e-04)*S25+5.929633e-04*S26+(-8.157530e-04)*S27+(-1.588369e-02)*S28+(-6.489997e-03)*S29'
.param V69_part4='V69_part3+0.000000e+00*S30+1.295033e-02*S31+6.750327e-01*S32+(-1.651584e-01)*S33+0.000000e+00*S34+(-4.957969e-02)*S35+(-1.826518e-01)*S36+1.340845e-02*S37+2.055436e-02*S38+3.871789e-02*S39'
.param V69_part5='V69_part4+2.039140e-02*S40+1.030220e-02*S41+2.096389e-02*S42+1.576645e-02*S43+1.222157e-02*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+8.416992e-02*S48+(-2.564064e-01)*S49'
.param V69_part6='V69_part5+(-3.663078e-02)*S50+0.000000e+00*S51+0.000000e+00*S52+(-3.189296e-02)*S53+3.145578e-02*S54+(-1.310454e-01)*S55+(-1.773431e-02)*S56+0.000000e+00*S57+0.000000e+00*S58+6.448294e-02*S59'
.param V69_part7='V69_part6+1.857065e+00*S60+(-4.330943e+00)*S61+(-6.902609e-01)*S62+(-3.758532e+01)*S63+(-1.772664e+00)*S64+(-9.352562e-01)*S65+(-6.632105e-01)*S66+(-2.226618e-01)*S67+(-1.487443e+00)*S68+(-7.182054e-01)*S69'
.param V69_part8='V69_part7+(-2.894856e-01)*S70+4.064353e-02*S71+(-3.370201e-01)*S72+(-4.658663e-01)*S73+9.826402e-03*S74+9.389209e+01*S75+2.529468e+02*S76+5.517904e-02*S77+(-1.424652e-01)*S78+(-8.456772e+00)*S79'
.param V69_part9='V69_part8+(-2.828240e-02)*S80+(-6.872996e-03)*S81+(-1.229252e-02)*S82+(-4.341611e-02)*S83+7.468688e-02*S84+0.000000e+00*S85+5.470665e-03*S86+(-1.158288e-03)*S87+(-4.270108e-05)*S88+9.950030e-02*S89'
.param V69_part10='V69_part9+(-4.096885e+01)*S90+(-6.925578e+00)*S91+0.000000e+00*S92+(-1.397704e+00)*S93+(-8.270296e+00)*S94+1.465878e-02*S95+(-9.706984e-01)*S96+1.779095e-02*S97+(-6.030638e-02)*S98+(-6.513768e-01)*S99'
.param V69_part11='V69_part10+(-8.185013e-01)*S100+(-3.653867e-02)*S101+(-5.383823e-01)*S102+(-6.736182e-01)*S103+(-7.393335e-02)*S104+(-3.282287e+01)*S105+(-1.645087e+00)*S106+0.000000e+00*S107+(-7.959416e+01)*S108+1.000000e+04*S109'
.param V69_part12='V69_part11+(-1.343897e-01)*S110+(-1.042487e+00)*S111+(-2.582306e-01)*S112+(-1.198281e-01)*S113+(-5.659242e-01)*S114+(-5.238540e-01)*S115+(-5.564965e-02)*S116+(-2.511889e-01)*S117+(-9.339495e-01)*S118+(-5.295433e-01)*S119'
.param V69_part13='V69_part12+0.000000e+00*S120+0.000000e+00*S121+4.406198e-03*S122+1.000000e+04*S123+0.000000e+00*S124+1.263485e-02*S125+(-3.926240e-01)*S126+(-3.322810e-01)*S127+(-3.209904e-02)*S128+(-1.399458e+00)*S129'
.param V69_part14='V69_part13+(-2.878797e-01)*S130+(-7.010020e-02)*S131+2.654373e-01*S132+(-1.721960e-01)*S133+(-1.552848e-01)*S134+(-7.224967e+01)*S135+3.062171e-01*S136+(-2.026482e-01)*S137+(-1.826459e-02)*S138+(-1.588291e-01)*S139'
.param V69_part15='V69_part14+1.822185e-03*S140+(-1.501029e-02)*S141+(-2.679887e-02)*S142+1.661773e-03*S143+(-2.715343e-02)*S144+(-7.210552e-03)*S145+(-7.904795e-03)*S146+(-4.330312e-02)*S147+(-1.633926e-02)*S148+2.220756e-03*S149'
.param V69_part16='V69_part15+1.724352e-02*S150+7.797876e-04*S151+(-5.944346e-02)*S152+(-9.058065e-03)*S153+3.491987e-02*S154+(-4.410259e-02)*S155+(-1.047664e-03)*S156+(-1.360741e-01)*S157+(-4.809926e-02)*S158+(-2.395179e-01)*S159'
.param V69_part17='V69_part16+(-5.091139e-02)*S160+(-4.212588e-02)*S161+(-1.124948e-01)*S162+3.775102e-02*S163+(-5.496994e-02)*S164+0.000000e+00*S165+(-4.215031e-01)*S166+(-3.121972e-02)*S167+(-3.444487e-01)*S168+(-3.255023e-01)*S169'
.param V69_part18='V69_part17+(-2.039165e-01)*S170+3.803990e-01*S171+(-1.837990e-01)*S172+(-2.014483e-01)*S173+2.527107e-03*S174+(-4.886249e-01)*S175+(-1.744019e-01)*S176+(-1.196517e-01)*S177+(-1.125634e-01)*S178+(-8.854372e-02)*S179'
.param V69_part19='V69_part18+3.522345e-02*S180+(-8.923175e-01)*S181+(-2.111269e-01)*S182+(-9.064825e-01)*S183+2.915056e-02*S184+(-5.694860e-02)*S185+(-8.169128e-01)*S186+(-3.483655e-01)*S187+8.451587e-02*S188+(-1.822710e-01)*S189'
.param V69_part20='V69_part19+(-1.781558e-01)*S190+1.585853e-02*S191+(-8.837808e-01)*S192+(-3.587775e-01)*S193+(-1.875703e-01)*S194+(-4.298400e-01)*S195+(-2.345621e-02)*S196+9.586859e-03*S197+0.000000e+00*S198+(-1.378956e-02)*S199'
.param V69_part21='V69_part20+1.675426e-02*S200+(-2.196743e-02)*S201+9.879732e-03*S202+2.640733e-02*S203+(-1.430350e-01)*S204+2.668364e-01*S205+1.121561e-01*S206+1.640469e-01*S207+1.315924e-02*S208+5.084861e-02*S209'
.param V69_part22='V69_part21+(-6.434177e+00)*S210+(-2.756887e-01)*S211+4.666501e-02*S212+(-8.021436e-01)*S213+(-9.855022e-02)*S214+(-9.194042e-04)*S215+(-4.933969e-02)*S216+8.887256e-02*S217+9.744634e-02*S218+(-2.444046e-01)*S219'
.param V69_part23='V69_part22+4.207119e-01*S220+3.849759e-02*S221+1.572045e-01*S222+2.526270e-01*S223+(-2.982275e-01)*S224+(-1.378707e+00)*S225+(-2.587823e-01)*S226+(-1.076890e-01)*S227+(-2.346809e-01)*S228+(-3.430983e-01)*S229'
.param V69_part24='V69_part23+(-1.719242e+00)*S230+(-1.476893e-02)*S231+(-9.759385e-01)*S232+(-6.263414e-01)*S233+2.172914e-03*S234+(-6.468525e-01)*S235+(-3.028069e-01)*S236+9.031969e-03*S237+(-1.230067e+00)*S238+(-7.621944e-01)*S239'
.param V69_part25='V69_part24+(-3.739509e-01)*S240+(-1.837734e-01)*S241+(-2.096076e-01)*S242+(-1.647436e-01)*S243+(-4.860410e-01)*S244+(-2.911915e+00)*S245+4.828703e-03*S246+(-6.413549e-01)*S247+(-5.626937e-01)*S248+(-2.168631e-02)*S249'
.param V69_part26='V69_part25+7.533186e-02*S250+(-8.867304e+00)*S251+4.022299e-02*S252+(-7.019451e-01)*S253+(-9.742220e-01)*S254+(-2.761134e-02)*S255+7.737416e-03*S256+(-5.636652e-01)*S257+(-4.191108e-02)*S258+(-2.805410e-01)*S259'
.param V69_part27='V69_part26+(-1.447017e-01)*S260+1.041488e-01*S261+(-8.676068e-02)*S262+(-9.588838e-01)*S263+3.941597e-02*S264+(-3.289200e-01)*S265+(-3.611207e-01)*S266+(-4.659771e-01)*S267+(-3.240169e-01)*S268+(-9.722973e-02)*S269'
.param V69_part28='V69_part27+(-7.689721e-01)*S270+(-3.660972e-01)*S271+(-1.275550e-01)*S272+(-5.438047e-01)*S273+(-2.580003e-01)*S274+(-1.188503e-01)*S275+(-5.247764e-01)*S276+(-8.074229e-01)*S277+(-1.402039e-01)*S278+5.466291e-01*S279'
.param V69_part29='V69_part28+(-1.992078e+00)*S280+(-1.347448e-01)*S281+(-2.914501e-01)*S282+2.603381e-01*S283+(-1.302268e-01)*S284+(-1.375163e+00)*S285+(-5.115158e-01)*S286+(-5.515343e-01)*S287+(-2.652884e-01)*S288+(-4.205730e-01)*S289'
.param V69_part30='V69_part29+(-1.592320e-01)*S290+2.084261e-01*S291+(-1.363376e+00)*S292+(-1.343029e-01)*S293+1.867737e-02*S294+(-4.384190e-01)*S295+(-1.051450e-01)*S296+(-3.486425e-01)*S297+(-2.718102e-01)*S298+(-9.997610e-02)*S299'
.param V69_part31='V69_part30+(-4.169526e-01)*S300+7.552702e-02*S301+(-3.978361e-01)*S302+(-2.176745e-01)*S303+(-1.038095e-01)*S304+(-1.417688e-01)*S305+(-1.663866e-01)*S306+(-4.029965e-01)*S307+(-1.096414e-01)*S308+(-1.397487e-01)*S309'
.param V69='V69_part31+(-4.727717e-01)*S310+(-1.857730e-01)*S311+(-2.317926e+00)*S312+(-2.779859e-01)*S313+(-1.467157e-01)*S314'
.param V70_part1='1.256675e+00*S0+0.000000e+00*S1+3.784905e+01*S2+2.831666e+01*S3+3.985869e+01*S4+3.968602e+01*S5+3.227494e+01*S6+6.448782e+01*S7+2.957462e+01*S8+1.881797e+01*S9'
.param V70_part2='V70_part1+8.238925e+01*S10+5.524523e+01*S11+6.306333e+01*S12+5.740241e+01*S13+4.585389e+01*S14+0.000000e+00*S15+2.876335e+01*S16+3.021180e+02*S17+6.807337e+01*S18+4.794293e+01*S19'
.param V70_part3='V70_part2+2.359680e+02*S20+5.143144e+01*S21+4.949602e+01*S22+3.062481e+01*S23+4.302387e+01*S24+5.661849e+01*S25+6.257372e+01*S26+3.648466e+01*S27+3.312267e+01*S28+4.091082e+01*S29'
.param V70_part4='V70_part3+0.000000e+00*S30+2.250965e+01*S31+0.000000e+00*S32+9.925350e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+2.302303e+02*S37+1.660189e+02*S38+9.787515e+01*S39'
.param V70_part5='V70_part4+1.474482e+02*S40+1.840104e+02*S41+8.490054e+01*S42+1.978011e+02*S43+1.714924e+02*S44+1.000000e+04*S45+1.000000e+04*S46+0.000000e+00*S47+(-1.343909e+02)*S48+0.000000e+00*S49'
.param V70_part6='V70_part5+(-8.999879e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+7.186542e+01*S54+2.078845e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V70_part7='V70_part6+(-4.659417e+01)*S60+4.571283e+01*S61+1.177210e+01*S62+(-6.667314e+01)*S63+1.363667e+01*S64+0.000000e+00*S65+(-4.001808e+01)*S66+2.592087e+01*S67+(-6.026242e+00)*S68+(-1.334180e+01)*S69'
.param V70_part8='V70_part7+0.000000e+00*S70+(-1.338145e+02)*S71+(-5.441703e+01)*S72+(-1.287152e+02)*S73+2.051470e+02*S74+(-5.660797e+00)*S75+3.680800e+00*S76+(-2.462672e+01)*S77+1.500667e+01*S78+6.575033e-01*S79'
.param V70_part9='V70_part8+(-6.102701e+00)*S80+2.560084e+01*S81+1.647674e+01*S82+0.000000e+00*S83+6.081995e+02*S84+2.317513e+03*S85+(-1.791839e+01)*S86+5.357190e+02*S87+3.855169e+02*S88+6.093894e+02*S89'
.param V70_part10='V70_part9+(-3.461914e+01)*S90+0.000000e+00*S91+0.000000e+00*S92+(-4.946294e+01)*S93+1.872337e+01*S94+0.000000e+00*S95+(-5.231051e+01)*S96+(-6.544638e+01)*S97+(-1.681884e+01)*S98+(-7.013833e+01)*S99'
.param V70_part11='V70_part10+(-1.074989e+02)*S100+(-6.158295e+01)*S101+(-8.362299e-01)*S102+(-7.016015e+01)*S103+(-7.988946e+01)*S104+(-2.685926e+01)*S105+0.000000e+00*S106+0.000000e+00*S107+(-6.300079e+01)*S108+(-8.647841e+01)*S109'
.param V70_part12='V70_part11+0.000000e+00*S110+8.800592e+00*S111+0.000000e+00*S112+(-3.643483e+01)*S113+(-5.547013e+00)*S114+(-2.430957e+00)*S115+(-9.460906e-01)*S116+(-4.066851e+01)*S117+(-2.306239e+01)*S118+(-5.976230e+01)*S119'
.param V70_part13='V70_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+6.738547e+02*S124+0.000000e+00*S125+2.571263e+01*S126+2.608808e+01*S127+(-7.190307e+01)*S128+0.000000e+00*S129'
.param V70_part14='V70_part13+(-3.220285e+01)*S130+(-1.318546e+02)*S131+1.309816e+01*S132+(-6.685732e+01)*S133+4.542940e+01*S134+0.000000e+00*S135+2.459433e+01*S136+5.344224e+01*S137+4.620258e+01*S138+7.936748e+00*S139'
.param V70_part15='V70_part14+5.161679e+02*S140+2.989596e+01*S141+1.797563e+01*S142+4.527551e+02*S143+3.832271e+01*S144+4.344527e+01*S145+3.168415e+01*S146+(-1.628848e+01)*S147+5.059670e+01*S148+2.616067e+02*S149'
.param V70_part16='V70_part15+0.000000e+00*S150+0.000000e+00*S151+(-3.504277e+01)*S152+0.000000e+00*S153+0.000000e+00*S154+(-8.805133e+01)*S155+1.351622e+02*S156+1.448964e+01*S157+(-1.378380e+02)*S158+3.136997e+01*S159'
.param V70_part17='V70_part16+7.040927e+01*S160+9.289140e+01*S161+0.000000e+00*S162+(-1.265851e+01)*S163+8.469737e+01*S164+0.000000e+00*S165+2.618703e+00*S166+(-4.892687e+01)*S167+3.695660e+00*S168+(-1.367121e+01)*S169'
.param V70_part18='V70_part17+0.000000e+00*S170+0.000000e+00*S171+(-4.243290e+01)*S172+(-2.601767e+01)*S173+8.802357e+01*S174+(-8.248764e+00)*S175+0.000000e+00*S176+3.594579e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V70_part19='V70_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+(-3.838764e+01)*S183+2.697697e+02*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+5.750708e+01*S188+0.000000e+00*S189'
.param V70_part20='V70_part19+(-1.418554e+01)*S190+4.603986e+01*S191+(-3.351799e+01)*S192+(-2.641112e+01)*S193+(-8.760862e+00)*S194+0.000000e+00*S195+1.463515e+02*S196+1.756451e+02*S197+2.454013e+03*S198+8.746154e+01*S199'
.param V70_part21='V70_part20+1.971922e+02*S200+(-1.784708e+01)*S201+2.015378e+01*S202+1.451424e+02*S203+(-8.709616e+00)*S204+4.584905e+00*S205+0.000000e+00*S206+6.829590e+01*S207+(-2.348640e+01)*S208+3.459988e+01*S209'
.param V70_part22='V70_part21+(-3.837050e+01)*S210+(-7.907183e+00)*S211+5.927810e+02*S212+(-9.882815e+00)*S213+5.626462e+01*S214+4.385307e+02*S215+8.814547e+01*S216+0.000000e+00*S217+0.000000e+00*S218+(-1.926480e+01)*S219'
.param V70_part23='V70_part22+(-2.975690e+01)*S220+0.000000e+00*S221+7.537491e+01*S222+(-2.150465e+01)*S223+0.000000e+00*S224+8.603103e+00*S225+(-1.654176e+01)*S226+(-8.981342e+01)*S227+(-5.195420e+01)*S228+4.889804e+00*S229'
.param V70_part24='V70_part23+(-5.766043e+01)*S230+6.197419e+01*S231+0.000000e+00*S232+1.139355e+01*S233+1.046885e+01*S234+(-4.610187e+01)*S235+(-3.002275e+01)*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V70_part25='V70_part24+4.570564e+00*S240+(-1.366919e+01)*S241+2.906890e+01*S242+9.319344e+01*S243+7.152601e+00*S244+(-1.210757e+02)*S245+0.000000e+00*S246+(-2.143148e+01)*S247+(-1.128939e+02)*S248+0.000000e+00*S249'
.param V70_part26='V70_part25+5.573002e+01*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.346437e+02*S255+1.401746e+02*S256+0.000000e+00*S257+1.283962e+02*S258+(-1.866723e+01)*S259'
.param V70_part27='V70_part26+(-1.315752e+02)*S260+1.428598e+01*S261+(-2.725853e+00)*S262+(-1.178675e+02)*S263+(-1.421868e+01)*S264+(-4.798657e+01)*S265+(-1.230834e+02)*S266+(-4.200932e+01)*S267+(-5.734158e+01)*S268+(-9.717181e+01)*S269'
.param V70_part28='V70_part27+(-1.097550e+00)*S270+(-1.661467e+01)*S271+(-4.010109e+01)*S272+(-8.976104e+00)*S273+(-2.551578e+00)*S274+(-4.168912e+01)*S275+(-1.281811e+01)*S276+(-2.809479e+01)*S277+(-3.473138e+01)*S278+0.000000e+00*S279'
.param V70_part29='V70_part28+(-5.979602e+01)*S280+(-5.445004e+01)*S281+0.000000e+00*S282+0.000000e+00*S283+(-5.859907e+01)*S284+6.250206e+00*S285+(-9.905075e+00)*S286+4.741507e+01*S287+7.432537e+01*S288+(-3.510483e+00)*S289'
.param V70_part30='V70_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-2.689986e+01)*S295+0.000000e+00*S296+(-3.811717e+01)*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V70_part31='V70_part30+1.330439e+01*S300+2.949281e+02*S301+3.720300e+01*S302+0.000000e+00*S303+(-6.177094e+00)*S304+(-4.387519e+01)*S305+2.659796e+01*S306+(-2.651628e+01)*S307+(-1.039080e+02)*S308+8.957792e+00*S309'
.param V70='V70_part31+(-5.709405e+01)*S310+(-9.293886e+01)*S311+0.000000e+00*S312+(-5.337191e+01)*S313+5.382694e+00*S314'
.param V71_part1='1.997446e+01*S0+0.000000e+00*S1+1.046458e+01*S2+1.068685e+02*S3+6.071734e+00*S4+2.091142e+01*S5+(-1.785446e+01)*S6+(-1.643286e+01)*S7+6.066622e+01*S8+5.092609e+01*S9'
.param V71_part2='V71_part1+4.955112e+00*S10+5.716288e+01*S11+4.063765e+01*S12+5.328833e+01*S13+8.034055e+01*S14+0.000000e+00*S15+8.448426e+01*S16+(-1.577289e+02)*S17+(-8.364281e+01)*S18+1.492996e+02*S19'
.param V71_part3='V71_part2+(-1.243453e+02)*S20+(-1.509972e+01)*S21+4.625790e+01*S22+8.564874e+01*S23+1.488098e+01*S24+7.691259e+01*S25+2.523839e+01*S26+1.183006e+01*S27+2.090028e+01*S28+2.333986e+01*S29'
.param V71_part4='V71_part3+0.000000e+00*S30+9.340172e+00*S31+0.000000e+00*S32+3.781284e+01*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-5.932623e+01)*S37+(-6.518990e+01)*S38+1.560263e+01*S39'
.param V71_part5='V71_part4+1.206002e+00*S40+1.525935e+01*S41+1.764251e+01*S42+(-1.856373e+01)*S43+2.889334e+01*S44+1.000000e+04*S45+1.300387e+03*S46+0.000000e+00*S47+2.725492e+02*S48+0.000000e+00*S49'
.param V71_part6='V71_part5+7.713808e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+6.058193e+01*S54+3.203708e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V71_part7='V71_part6+8.207230e+01*S60+(-4.689503e+01)*S61+7.471797e+01*S62+1.512459e+02*S63+5.460029e+00*S64+0.000000e+00*S65+1.346371e+02*S66+4.749859e+01*S67+4.228432e+01*S68+9.399803e+01*S69'
.param V71_part8='V71_part7+0.000000e+00*S70+4.106948e+02*S71+1.295473e+02*S72+1.767057e+02*S73+(-5.350639e+00)*S74+2.527913e+00*S75+5.039989e+01*S76+1.004435e+02*S77+2.129167e+01*S78+(-1.792066e-01)*S79'
.param V71_part9='V71_part8+8.250548e+01*S80+1.420796e+00*S81+4.767997e+01*S82+0.000000e+00*S83+(-2.647642e+02)*S84+4.163785e+02*S85+2.324636e+02*S86+(-1.707659e+02)*S87+(-6.954567e+01)*S88+(-1.585306e+02)*S89'
.param V71_part10='V71_part9+1.089123e+02*S90+0.000000e+00*S91+0.000000e+00*S92+1.588113e+02*S93+5.145620e+01*S94+0.000000e+00*S95+1.654979e+02*S96+1.626387e+02*S97+7.686893e+01*S98+1.625892e+02*S99'
.param V71_part11='V71_part10+2.396649e+02*S100+1.186730e+02*S101+1.135972e+02*S102+1.970089e+02*S103+1.383150e+02*S104+1.080679e+02*S105+0.000000e+00*S106+0.000000e+00*S107+1.497414e+02*S108+2.715351e+02*S109'
.param V71_part12='V71_part11+0.000000e+00*S110+4.615218e+01*S111+0.000000e+00*S112+1.265543e+02*S113+3.407943e+00*S114+6.152376e+00*S115+8.302808e+01*S116+9.270406e+01*S117+2.550580e+01*S118+5.121010e+01*S119'
.param V71_part13='V71_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+8.545661e+02*S124+0.000000e+00*S125+4.526706e+01*S126+3.726144e+01*S127+1.732652e+02*S128+0.000000e+00*S129'
.param V71_part14='V71_part13+1.132008e+02*S130+2.074560e+02*S131+5.338265e+01*S132+1.401995e+02*S133+6.333846e+01*S134+0.000000e+00*S135+(-7.215775e+01)*S136+(-1.862056e+01)*S137+3.952144e+01*S138+6.447427e+01*S139'
.param V71_part15='V71_part14+(-9.351312e+01)*S140+8.706005e+01*S141+6.561782e+01*S142+(-9.369982e+01)*S143+8.523198e+01*S144+8.729491e+01*S145+8.822175e+01*S146+7.883337e+01*S147+8.137433e+01*S148+7.708120e+00*S149'
.param V71_part16='V71_part15+0.000000e+00*S150+0.000000e+00*S151+1.392069e+02*S152+0.000000e+00*S153+0.000000e+00*S154+2.059784e+02*S155+(-4.999109e+01)*S156+1.182041e+02*S157+2.610482e+02*S158+2.679440e+01*S159'
.param V71_part17='V71_part16+6.285919e+01*S160+2.790699e+01*S161+0.000000e+00*S162+5.284428e+01*S163+4.503445e+01*S164+0.000000e+00*S165+3.858507e+01*S166+1.596366e+02*S167+5.610471e+01*S168+1.027780e+02*S169'
.param V71_part18='V71_part17+0.000000e+00*S170+0.000000e+00*S171+1.297441e+02*S172+5.137133e+01*S173+3.065035e+01*S174+3.863556e+01*S175+0.000000e+00*S176+8.676675e+01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V71_part19='V71_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+3.359263e+01*S183+(-2.827055e+02)*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+3.289613e+00*S188+0.000000e+00*S189'
.param V71_part20='V71_part19+5.932687e+01*S190+2.332752e+01*S191+4.889434e+01*S192+6.652410e+01*S193+2.358982e+01*S194+0.000000e+00*S195+(-2.248914e+00)*S196+6.111320e+01*S197+2.309159e+03*S198+7.138949e+01*S199'
.param V71_part21='V71_part20+4.156499e+00*S200+1.018615e+02*S201+6.857409e+01*S202+1.410309e+01*S203+3.877457e+01*S204+4.072168e+01*S205+0.000000e+00*S206+4.583441e+01*S207+2.930458e+01*S208+3.699124e+01*S209'
.param V71_part22='V71_part21+1.830098e+02*S210+1.155069e+02*S211+(-1.776410e+01)*S212+2.956159e+01*S213+8.042237e+01*S214+(-2.360701e+02)*S215+3.703950e+01*S216+0.000000e+00*S217+0.000000e+00*S218+5.119834e+01*S219'
.param V71_part23='V71_part22+9.223579e+01*S220+0.000000e+00*S221+1.646537e+01*S222+7.038829e+01*S223+0.000000e+00*S224+5.089348e+01*S225+1.187398e+02*S226+2.369942e+02*S227+8.611583e+01*S228+4.792791e+01*S229'
.param V71_part24='V71_part23+1.417508e+00*S230+2.343470e+01*S231+0.000000e+00*S232+8.529972e+00*S233+2.558441e+01*S234+5.099147e+01*S235+2.204518e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V71_part25='V71_part24+3.965332e+01*S240+1.515691e+02*S241+6.062767e+01*S242+4.360479e+01*S243+4.252150e+01*S244+1.067526e+02*S245+0.000000e+00*S246+4.963483e+01*S247+7.957848e+01*S248+0.000000e+00*S249'
.param V71_part26='V71_part25+3.271371e+01*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+(-7.522495e+00)*S255+(-1.344381e+00)*S256+0.000000e+00*S257+1.269085e+00*S258+8.233200e+01*S259'
.param V71_part27='V71_part26+2.600309e+02*S260+3.606621e+01*S261+3.806547e+01*S262+8.908925e+01*S263+5.986746e+01*S264+5.641281e+01*S265+9.165619e+01*S266+4.834466e+01*S267+4.428103e+01*S268+6.657457e+01*S269'
.param V71_part28='V71_part27+5.708493e+01*S270+5.996461e+01*S271+8.490153e+01*S272+3.089370e+01*S273+5.060403e+01*S274+7.436804e+01*S275+3.008745e+01*S276+8.683688e+01*S277+4.575102e+00*S278+0.000000e+00*S279'
.param V71_part29='V71_part28+5.487175e+01*S280+(-4.349553e-01)*S281+0.000000e+00*S282+0.000000e+00*S283+(-2.503324e+00)*S284+6.722224e+01*S285+4.852693e+01*S286+2.060684e+01*S287+(-4.120644e+01)*S288+4.126907e+01*S289'
.param V71_part30='V71_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+5.527618e+01*S295+0.000000e+00*S296+8.147321e+01*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V71_part31='V71_part30+1.522013e+01*S300+(-1.457745e+02)*S301+5.148790e+01*S302+0.000000e+00*S303+7.084157e+01*S304+9.272911e+01*S305+1.596926e+01*S306+9.142083e+01*S307+1.617608e+02*S308+3.210570e+01*S309'
.param V71='V71_part31+1.075707e+02*S310+3.350112e+01*S311+0.000000e+00*S312+7.326471e+01*S313+(-4.431464e+01)*S314'
.param V72_part1='2.109564e+01*S0+0.000000e+00*S1+6.148314e+00*S2+(-2.654130e+01)*S3+(-2.219013e+00)*S4+1.492500e+01*S5+5.869727e+01*S6+4.835251e-01*S7+1.912312e+01*S8+5.255820e+01*S9'
.param V72_part2='V72_part1+(-2.882694e+01)*S10+(-9.394818e-02)*S11+(-4.733038e+00)*S12+(-2.168431e-02)*S13+(-7.873287e-02)*S14+0.000000e+00*S15+(-7.143750e+00)*S16+6.955255e+01*S17+7.774783e+01*S18+(-2.201149e+01)*S19'
.param V72_part3='V72_part2+7.745091e+01*S20+2.026115e+01*S21+1.633384e+01*S22+4.979797e+01*S23+2.923716e-01*S24+1.612271e+00*S25+2.283135e+01*S26+2.019408e+01*S27+2.675956e+01*S28+3.072120e+01*S29'
.param V72_part4='V72_part3+0.000000e+00*S30+5.930620e+00*S31+0.000000e+00*S32+1.788803e+01*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+3.692924e+01*S37+5.458922e+00*S38+1.144873e+02*S39'
.param V72_part5='V72_part4+6.872686e+01*S40+6.480528e+01*S41+7.179878e+01*S42+7.986333e+01*S43+7.817654e+01*S44+(-8.804233e+03)*S45+(-1.000000e+04)*S46+0.000000e+00*S47+2.606448e+02*S48+0.000000e+00*S49'
.param V72_part6='V72_part5+5.933070e+01*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+9.233308e+01*S54+1.408921e+01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V72_part7='V72_part6+1.592225e+02*S60+3.605624e+01*S61+4.922876e+01*S62+1.702523e+02*S63+3.996684e+01*S64+0.000000e+00*S65+1.017043e+02*S66+4.584370e+01*S67+2.940539e+01*S68+8.269031e+01*S69'
.param V72_part8='V72_part7+0.000000e+00*S70+2.544164e+02*S71+3.308375e+01*S72+8.409359e+01*S73+6.204790e+01*S74+2.580330e+01*S75+2.450372e+01*S76+4.886221e+01*S77+1.694776e+01*S78+2.143899e+01*S79'
.param V72_part9='V72_part8+7.970520e+01*S80+8.319535e+00*S81+2.655353e+01*S82+0.000000e+00*S83+7.396435e+01*S84+8.980417e+02*S85+1.947152e+02*S86+2.146119e+01*S87+1.782269e+00*S88+1.799537e+01*S89'
.param V72_part10='V72_part9+1.223897e+02*S90+0.000000e+00*S91+0.000000e+00*S92+1.024658e+02*S93+4.399987e+01*S94+0.000000e+00*S95+9.031361e+01*S96+1.785137e+02*S97+6.914587e+01*S98+1.911078e+01*S99'
.param V72_part11='V72_part10+1.065444e+02*S100+9.246595e+01*S101+3.682105e+01*S102+4.946838e+01*S103+1.141910e+02*S104+7.251456e+01*S105+0.000000e+00*S106+0.000000e+00*S107+1.050368e+02*S108+1.781301e+02*S109'
.param V72_part12='V72_part11+0.000000e+00*S110+6.300454e+01*S111+0.000000e+00*S112+(-2.038898e+01)*S113+1.450359e+01*S114+7.227631e+00*S115+(-1.196033e+01)*S116+1.371918e+02*S117+1.567597e+01*S118+1.110058e+02*S119'
.param V72_part13='V72_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+4.042796e+01*S124+0.000000e+00*S125+4.859794e+01*S126+5.485170e+01*S127+2.965639e+01*S128+0.000000e+00*S129'
.param V72_part14='V72_part13+9.224371e+01*S130+1.616581e+02*S131+8.452811e+01*S132+1.353100e+02*S133+7.449645e+01*S134+0.000000e+00*S135+8.802219e+01*S136+6.099328e+01*S137+7.942072e+01*S138+4.506986e+01*S139'
.param V72_part15='V72_part14+(-6.322668e+01)*S140+8.921346e+01*S141+5.444514e+01*S142+1.767432e+01*S143+8.228733e+01*S144+7.734341e+01*S145+6.979136e+01*S146+5.759367e+01*S147+8.138233e+01*S148+2.659736e+01*S149'
.param V72_part16='V72_part15+0.000000e+00*S150+0.000000e+00*S151+1.110662e+02*S152+0.000000e+00*S153+0.000000e+00*S154+1.426666e+02*S155+1.053926e-01*S156+1.122568e+02*S157+1.727227e+02*S158+3.194981e+01*S159'
.param V72_part17='V72_part16+6.363901e+01*S160+8.849517e+01*S161+0.000000e+00*S162+7.270342e+01*S163+6.306483e+01*S164+0.000000e+00*S165+4.486052e+01*S166+1.428489e+02*S167+9.662015e+01*S168+9.673834e+01*S169'
.param V72_part18='V72_part17+0.000000e+00*S170+0.000000e+00*S171+1.510102e+02*S172+5.126024e+01*S173+5.945570e+01*S174+(-8.483745e+00)*S175+0.000000e+00*S176+1.455465e+02*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V72_part19='V72_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+8.845469e+01*S183+(-5.209793e+01)*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+(-6.557126e+01)*S188+0.000000e+00*S189'
.param V72_part20='V72_part19+3.086051e+01*S190+(-6.982071e+01)*S191+8.868304e+01*S192+3.393370e+01*S193+5.200943e+01*S194+0.000000e+00*S195+1.768571e+02*S196+1.133042e+02*S197+4.070461e+02*S198+1.146833e+02*S199'
.param V72_part21='V72_part20+7.567314e+01*S200+3.103671e+01*S201+6.881411e+00*S202+5.260350e+01*S203+(-4.746740e+00)*S204+(-4.527734e+00)*S205+0.000000e+00*S206+5.994332e+01*S207+(-1.815765e-01)*S208+8.562387e+01*S209'
.param V72_part22='V72_part21+1.108965e+02*S210+1.240271e+02*S211+(-5.447419e+02)*S212+4.823532e+01*S213+9.675533e+01*S214+(-2.131983e+02)*S215+5.894763e+01*S216+0.000000e+00*S217+0.000000e+00*S218+5.915590e+00*S219'
.param V72_part23='V72_part22+1.781706e+01*S220+0.000000e+00*S221+(-1.136940e-01)*S222+2.359424e+01*S223+0.000000e+00*S224+1.091215e+02*S225+1.438849e+02*S226+2.423281e+02*S227+1.215469e+02*S228+9.014019e+01*S229'
.param V72_part24='V72_part23+1.510805e+02*S230+6.215902e+01*S231+0.000000e+00*S232+1.349873e+00*S233+(-1.815435e+01)*S234+4.194531e+01*S235+6.380318e+01*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V72_part25='V72_part24+8.954581e+01*S240+1.504867e+02*S241+1.306410e+02*S242+8.045491e+01*S243+(-4.770834e+00)*S244+1.540015e+02*S245+0.000000e+00*S246+9.997701e+01*S247+1.248125e+02*S248+0.000000e+00*S249'
.param V72_part26='V72_part25+(-6.588328e+01)*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.625957e+02*S255+1.271031e+02*S256+0.000000e+00*S257+2.981820e+02*S258+2.972295e+01*S259'
.param V72_part27='V72_part26+2.139223e+02*S260+5.536075e+01*S261+4.940742e+01*S262+1.533954e+02*S263+6.032609e+01*S264+6.389495e+01*S265+1.147528e+02*S266+1.091173e+02*S267+7.688876e+01*S268+9.648993e+01*S269'
.param V72_part28='V72_part27+3.073628e+01*S270+4.648596e+01*S271+9.815284e+01*S272+5.787818e+01*S273+4.382148e+01*S274+8.881778e+01*S275+8.205237e+01*S276+4.181173e+01*S277+1.084137e+02*S278+0.000000e+00*S279'
.param V72_part29='V72_part28+1.289417e+02*S280+1.579589e+02*S281+0.000000e+00*S282+0.000000e+00*S283+1.351541e+02*S284+1.208561e+00*S285+1.781310e+01*S286+1.078443e+02*S287+(-1.275548e+02)*S288+2.243057e+01*S289'
.param V72_part30='V72_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.122136e+02*S295+0.000000e+00*S296+6.709926e+01*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V72_part31='V72_part30+6.633593e+01*S300+(-6.289055e+01)*S301+1.118268e+02*S302+0.000000e+00*S303+8.127749e+01*S304+7.931552e+01*S305+2.914096e+01*S306+5.899915e+01*S307+9.209212e+01*S308+4.941568e+00*S309'
.param V72='V72_part31+9.328622e+01*S310+1.740353e+02*S311+0.000000e+00*S312+7.366460e+01*S313+1.586746e+02*S314'
.param V73_part1='3.704286e+00*S0+0.000000e+00*S1+1.826205e+01*S2+4.049364e+01*S3+5.587091e+00*S4+2.696159e+00*S5+(-1.816868e+01)*S6+(-6.429318e+00)*S7+1.551812e+00*S8+2.800968e+01*S9'
.param V73_part2='V73_part1+(-1.310016e+00)*S10+(-2.954336e+00)*S11+(-7.611929e+00)*S12+(-1.720253e+00)*S13+(-1.569800e+01)*S14+0.000000e+00*S15+(-3.799307e+00)*S16+(-9.170049e+01)*S17+(-1.560154e+01)*S18+8.240178e+01*S19'
.param V73_part3='V73_part2+(-1.063131e+02)*S20+5.346244e+00*S21+8.214934e+00*S22+1.245065e+01*S23+(-3.945908e-01)*S24+(-6.292601e+00)*S25+(-1.224035e+01)*S26+(-1.262277e-01)*S27+(-5.432509e+00)*S28+(-2.866583e+01)*S29'
.param V73_part4='V73_part3+0.000000e+00*S30+3.227510e+00*S31+0.000000e+00*S32+1.282781e-01*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-7.197276e+01)*S37+(-7.097406e+01)*S38+(-5.884313e+01)*S39'
.param V73_part5='V73_part4+(-7.424068e+01)*S40+(-1.086217e+02)*S41+(-8.179196e+01)*S42+(-9.371249e+01)*S43+(-1.120429e+02)*S44+9.721230e+03*S45+5.962792e+02*S46+0.000000e+00*S47+3.005191e+01*S48+0.000000e+00*S49'
.param V73_part6='V73_part5+9.541316e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+(-4.321324e+01)*S54+(-2.181123e+00)*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V73_part7='V73_part6+2.150285e+01*S60+(-1.113395e+01)*S61+(-1.824956e+01)*S62+4.359088e+00*S63+(-3.227386e+00)*S64+0.000000e+00*S65+(-1.208420e+01)*S66+(-2.517882e+01)*S67+9.231797e-01*S68+(-2.714857e+01)*S69'
.param V73_part8='V73_part7+0.000000e+00*S70+(-7.423493e+01)*S71+(-2.824098e+01)*S72+3.517456e+00*S73+(-1.069725e+02)*S74+(-2.933975e+00)*S75+(-1.026151e+01)*S76+(-1.059346e+01)*S77+(-6.548500e+00)*S78+(-5.230076e+00)*S79'
.param V73_part9='V73_part8+(-4.121042e+00)*S80+(-3.826832e+01)*S81+(-1.186520e+01)*S82+0.000000e+00*S83+(-1.505849e+02)*S84+(-2.322647e+03)*S85+(-1.487722e+02)*S86+(-1.862127e+02)*S87+(-1.493486e+02)*S88+(-1.335435e+02)*S89'
.param V73_part10='V73_part9+1.382492e+01*S90+0.000000e+00*S91+0.000000e+00*S92+1.470263e+01*S93+(-1.978196e+01)*S94+0.000000e+00*S95+2.245730e+01*S96+4.641667e+01*S97+(-2.288613e+01)*S98+(-9.086750e+00)*S99'
.param V73_part11='V73_part10+4.179938e+01*S100+(-2.398320e+01)*S101+(-2.879766e+01)*S102+(-1.149074e+01)*S103+(-2.871804e+01)*S104+5.565217e+00*S105+0.000000e+00*S106+0.000000e+00*S107+2.015413e+00*S108+(-2.181055e+01)*S109'
.param V73_part12='V73_part11+0.000000e+00*S110+(-2.296013e+01)*S111+0.000000e+00*S112+(-1.710547e+01)*S113+1.604743e+01*S114+2.425523e+01*S115+(-4.362573e+01)*S116+(-1.386770e+01)*S117+2.576915e+01*S118+(-7.067706e+00)*S119'
.param V73_part13='V73_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+(-1.737947e+02)*S124+0.000000e+00*S125+(-2.571104e+01)*S126+(-2.663666e+01)*S127+(-4.658095e+01)*S128+0.000000e+00*S129'
.param V73_part14='V73_part13+(-1.728087e+01)*S130+(-1.933346e+01)*S131+(-3.306930e+01)*S132+(-1.426537e+01)*S133+(-3.411202e+01)*S134+0.000000e+00*S135+(-1.550529e+01)*S136+(-2.126813e+01)*S137+(-4.442490e+01)*S138+(-1.250016e+01)*S139'
.param V73_part15='V73_part14+(-1.195531e+02)*S140+(-6.175996e+01)*S141+(-3.139158e+01)*S142+(-1.188601e+02)*S143+(-7.017908e+01)*S144+(-8.105450e+01)*S145+(-5.938809e+01)*S146+(-2.767348e+01)*S147+(-8.881663e+01)*S148+(-8.977682e+01)*S149'
.param V73_part16='V73_part15+0.000000e+00*S150+0.000000e+00*S151+(-1.859752e+01)*S152+0.000000e+00*S153+0.000000e+00*S154+(-2.171379e+01)*S155+1.054752e+02*S156+(-2.813789e+01)*S157+(-1.923692e+01)*S158+1.774681e+01*S159'
.param V73_part17='V73_part16+(-2.952112e+01)*S160+(-3.883613e+01)*S161+0.000000e+00*S162+3.666867e-01*S163+(-4.452054e+01)*S164+0.000000e+00*S165+2.901191e+00*S166+(-2.245382e+01)*S167+(-2.055943e+01)*S168+(-1.613069e+01)*S169'
.param V73_part18='V73_part17+0.000000e+00*S170+0.000000e+00*S171+(-1.611121e+01)*S172+1.167387e+01*S173+(-7.516079e+01)*S174+(-1.486305e+01)*S175+0.000000e+00*S176+(-4.538709e+01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V73_part19='V73_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+2.718311e+01*S183+2.418814e+01*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+(-8.363281e+00)*S188+0.000000e+00*S189'
.param V73_part20='V73_part19+6.220073e+00*S190+2.610463e+00*S191+2.697286e+00*S192+8.587910e+00*S193+8.232410e+00*S194+0.000000e+00*S195+(-1.071967e+02)*S196+(-9.893882e+01)*S197+(-4.422673e+02)*S198+(-1.038628e+02)*S199'
.param V73_part21='V73_part20+(-7.764727e+01)*S200+(-2.043660e+01)*S201+(-6.517554e+01)*S202+(-2.922649e+01)*S203+(-5.248509e+00)*S204+(-1.506656e+01)*S205+0.000000e+00*S206+(-4.552919e+01)*S207+6.076708e+00*S208+(-1.402758e+01)*S209'
.param V73_part22='V73_part21+(-5.967805e+00)*S210+(-1.693636e+01)*S211+(-4.375406e+01)*S212+6.916632e+00*S213+(-2.632476e+01)*S214+(-3.033262e+01)*S215+(-3.577282e+01)*S216+0.000000e+00*S217+0.000000e+00*S218+(-1.635274e+01)*S219'
.param V73_part23='V73_part22+1.240874e+01*S220+0.000000e+00*S221+(-3.874886e+01)*S222+1.001801e+01*S223+0.000000e+00*S224+(-1.940933e+01)*S225+(-1.536082e+01)*S226+(-3.746585e+01)*S227+1.575453e+01*S228+(-1.990885e+01)*S229'
.param V73_part24='V73_part23+(-1.936327e+01)*S230+(-3.776668e+01)*S231+0.000000e+00*S232+(-3.103027e+00)*S233+(-1.439673e+01)*S234+9.252938e+00*S235+(-1.006697e+01)*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V73_part25='V73_part24+8.871775e+00*S240+(-1.270903e+01)*S241+(-2.965129e+01)*S242+(-4.298753e+01)*S243+(-1.106129e+01)*S244+(-1.931848e+01)*S245+0.000000e+00*S246+(-4.414870e+00)*S247+(-1.388917e+01)*S248+0.000000e+00*S249'
.param V73_part26='V73_part25+(-3.792666e+01)*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+(-6.969323e+01)*S255+(-6.667278e+01)*S256+0.000000e+00*S257+(-7.212024e+01)*S258+(-1.572418e+01)*S259'
.param V73_part27='V73_part26+(-2.639372e+01)*S260+1.251187e+01*S261+1.014871e+01*S262+(-1.429224e+01)*S263+8.377250e+00*S264+(-5.188547e-01)*S265+(-9.843161e+00)*S266+(-6.741415e+00)*S267+7.027681e+00*S268+4.903917e+00*S269'
.param V73_part28='V73_part27+(-8.338379e+00)*S270+(-7.353380e+00)*S271+1.768848e+01*S272+(-6.668776e+00)*S273+1.540448e+01*S274+1.533873e+01*S275+(-2.480445e+01)*S276+(-2.337476e+01)*S277+(-3.585372e+01)*S278+0.000000e+00*S279'
.param V73_part29='V73_part28+7.431587e+00*S280+(-2.346062e+01)*S281+0.000000e+00*S282+0.000000e+00*S283+8.471777e+00*S284+(-2.907560e+01)*S285+(-4.465074e+00)*S286+(-2.663918e+01)*S287+(-7.580958e+00)*S288+(-7.688355e+00)*S289'
.param V73_part30='V73_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+3.786769e-01*S295+0.000000e+00*S296+5.082995e+00*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V73_part31='V73_part30+4.395707e+00*S300+(-6.160770e+00)*S301+(-2.728605e+01)*S302+0.000000e+00*S303+2.307817e+00*S304+(-4.374459e+01)*S305+2.431964e+01*S306+(-3.261483e+00)*S307+(-4.421165e+01)*S308+(-1.624546e+01)*S309'
.param V73='V73_part31+(-3.932544e+00)*S310+(-1.603278e+01)*S311+0.000000e+00*S312+(-3.182060e+01)*S313+(-3.433481e+01)*S314'
.param V74_part1='3.821409e-01*S0+0.000000e+00*S1+4.060026e-01*S2+(-5.011230e-01)*S3+8.115833e-01*S4+3.179765e-01*S5+(-1.825111e-01)*S6+3.629049e-01*S7+(-1.201262e-01)*S8+7.998616e-02*S9'
.param V74_part2='V74_part1+8.827876e-02*S10+(-7.797828e-01)*S11+(-3.251457e-01)*S12+(-8.521684e-01)*S13+4.100825e-02*S14+0.000000e+00*S15+(-2.094695e-02)*S16+1.229135e+00*S17+(-1.088356e+00)*S18+4.858209e-01*S19'
.param V74_part3='V74_part2+1.435376e-01*S20+2.766949e-01*S21+6.660211e-01*S22+4.731444e-01*S23+5.211818e-02*S24+2.597895e-01*S25+3.163907e-01*S26+(-1.039334e-01)*S27+8.325098e-03*S28+2.361922e-01*S29'
.param V74_part4='V74_part3+0.000000e+00*S30+7.744975e-01*S31+0.000000e+00*S32+5.950546e-02*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+1.435084e+00*S37+3.265478e+00*S38+2.945238e+00*S39'
.param V74_part5='V74_part4+(-6.884978e-01)*S40+(-2.536903e+00)*S41+3.425471e+00*S42+(-2.047477e+00)*S43+(-3.052933e+00)*S44+(-1.009469e+03)*S45+(-1.860312e+03)*S46+0.000000e+00*S47+3.014719e+01*S48+0.000000e+00*S49'
.param V74_part6='V74_part5+1.114633e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+(-4.401651e+00)*S54+3.665008e-01*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V74_part7='V74_part6+1.139015e+01*S60+5.117323e+00*S61+3.246288e+00*S62+1.366565e+01*S63+6.917314e+00*S64+0.000000e+00*S65+2.005375e+01*S66+4.866450e+00*S67+8.425032e+00*S68+2.195803e+01*S69'
.param V74_part8='V74_part7+0.000000e+00*S70+(-6.125032e+01)*S71+4.081341e+01*S72+7.110490e+01*S73+(-2.992406e-01)*S74+6.853121e-01*S75+1.005927e+00*S76+1.720742e+00*S77+(-9.983832e-02)*S78+3.320690e-01*S79'
.param V74_part9='V74_part8+2.865874e+00*S80+1.760195e+00*S81+(-7.816926e-01)*S82+0.000000e+00*S83+(-1.695775e+01)*S84+1.824857e+02*S85+2.595939e+01*S86+5.404744e-01*S87+(-1.907312e+01)*S88+(-5.535159e+01)*S89'
.param V74_part10='V74_part9+1.245258e+01*S90+0.000000e+00*S91+0.000000e+00*S92+2.304998e+01*S93+2.933944e+00*S94+0.000000e+00*S95+2.620187e+01*S96+6.902498e+00*S97+2.696381e+00*S98+3.388601e+01*S99'
.param V74_part11='V74_part10+3.455995e+01*S100+4.246131e+00*S101+1.107808e+01*S102+2.091175e+01*S103+4.829054e+00*S104+1.955687e+01*S105+0.000000e+00*S106+0.000000e+00*S107+3.264621e+01*S108+3.006808e+01*S109'
.param V74_part12='V74_part11+0.000000e+00*S110+8.243192e+00*S111+0.000000e+00*S112+8.322643e+00*S113+1.985957e+01*S114+6.720137e+00*S115+3.507557e+00*S116+5.884941e+00*S117+4.618274e+00*S118+5.825054e+00*S119'
.param V74_part13='V74_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+9.345944e+01*S124+0.000000e+00*S125+6.512117e+00*S126+4.950424e-01*S127+8.567821e+00*S128+0.000000e+00*S129'
.param V74_part14='V74_part13+3.767920e+00*S130+6.404996e+00*S131+9.316445e+00*S132+3.546811e+00*S133+(-5.682737e+00)*S134+0.000000e+00*S135+8.007691e+00*S136+1.704221e+00*S137+1.141274e+00*S138+4.652686e+00*S139'
.param V74_part15='V74_part14+(-2.587378e+01)*S140+1.461851e+00*S141+2.257449e+00*S142+(-2.955077e+01)*S143+3.602908e-01*S144+2.726979e-01*S145+8.486152e-01*S146+(-2.162666e+00)*S147+(-1.033107e+00)*S148+(-5.200801e+00)*S149'
.param V74_part16='V74_part15+0.000000e+00*S150+0.000000e+00*S151+7.175349e+00*S152+0.000000e+00*S153+0.000000e+00*S154+1.005732e+01*S155+1.131987e+01*S156+(-2.507869e+00)*S157+1.404838e+01*S158+(-1.801546e+00)*S159'
.param V74_part17='V74_part16+(-4.549557e+00)*S160+(-8.547800e+00)*S161+0.000000e+00*S162+6.061412e+00*S163+(-1.116701e+00)*S164+0.000000e+00*S165+3.062973e+00*S166+7.256010e+00*S167+9.181658e+00*S168+6.069325e+00*S169'
.param V74_part18='V74_part17+0.000000e+00*S170+0.000000e+00*S171+7.492037e+00*S172+5.290536e+00*S173+4.790342e-01*S174+1.041273e+01*S175+0.000000e+00*S176+(-4.083341e+00)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V74_part19='V74_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+1.757274e+01*S183+(-2.003431e+01)*S184+0.000000e+00*S185+0.000000e+00*S186+0.000000e+00*S187+1.644517e+01*S188+0.000000e+00*S189'
.param V74_part20='V74_part19+9.943417e+00*S190+1.042175e+01*S191+1.538561e+01*S192+1.192445e+01*S193+9.220782e+00*S194+0.000000e+00*S195+3.897967e+00*S196+(-5.877303e+00)*S197+2.408932e+02*S198+5.911585e-01*S199'
.param V74_part21='V74_part20+(-5.658530e+00)*S200+3.383719e+00*S201+6.006313e-01*S202+(-5.974288e+00)*S203+1.039614e-01*S204+(-2.101492e+00)*S205+0.000000e+00*S206+1.863534e+00*S207+2.020349e+01*S208+2.937843e+01*S209'
.param V74_part22='V74_part21+1.881311e+01*S210+8.806187e+00*S211+(-1.428770e+00)*S212+1.021971e+01*S213+(-3.186946e+00)*S214+(-1.604777e+01)*S215+(-3.672921e+00)*S216+0.000000e+00*S217+0.000000e+00*S218+3.844642e+00*S219'
.param V74_part23='V74_part22+1.245794e+01*S220+0.000000e+00*S221+(-4.545313e+00)*S222+1.589025e+01*S223+0.000000e+00*S224+9.191872e+00*S225+1.311541e+01*S226+1.650594e+01*S227+1.777611e+01*S228+5.105920e+00*S229'
.param V74_part24='V74_part23+7.550692e+00*S230+(-3.888151e+00)*S231+0.000000e+00*S232+4.470930e+00*S233+4.153761e+00*S234+7.043874e+00*S235+7.476616e+00*S236+0.000000e+00*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V74_part25='V74_part24+3.608877e+00*S240+1.253469e+01*S241+(-3.232327e-01)*S242+7.517906e+00*S243+3.332141e+00*S244+9.231903e+00*S245+0.000000e+00*S246+1.133873e+01*S247+7.879216e+00*S248+0.000000e+00*S249'
.param V74_part26='V74_part25+6.589809e+00*S250+0.000000e+00*S251+0.000000e+00*S252+0.000000e+00*S253+0.000000e+00*S254+1.086682e+00*S255+(-1.759193e+00)*S256+0.000000e+00*S257+4.893752e+00*S258+4.048722e+00*S259'
.param V74_part27='V74_part26+9.820184e+00*S260+(-9.012347e-02)*S261+1.189637e+01*S262+9.281698e+00*S263+5.206510e+00*S264+7.854744e+00*S265+9.946666e+00*S266+2.119354e+01*S267+8.259184e+00*S268+1.223553e+01*S269'
.param V74_part28='V74_part27+4.757728e+00*S270+4.642609e+00*S271+8.916082e+00*S272+5.616775e+00*S273+5.632504e+00*S274+1.065488e+01*S275+3.665742e+00*S276+1.038463e+01*S277+1.371386e+01*S278+0.000000e+00*S279'
.param V74_part29='V74_part28+2.070120e+01*S280+4.449220e+00*S281+0.000000e+00*S282+0.000000e+00*S283+8.803321e+00*S284+5.039887e+00*S285+6.005524e+00*S286+(-1.873470e+00)*S287+8.907366e+00*S288+7.546155e+00*S289'
.param V74_part30='V74_part29+0.000000e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.945042e+01*S295+0.000000e+00*S296+1.237482e+01*S297+0.000000e+00*S298+0.000000e+00*S299'
.param V74_part31='V74_part30+3.220345e+00*S300+(-3.251956e+01)*S301+(-3.101728e+00)*S302+0.000000e+00*S303+1.540747e+00*S304+1.044470e+01*S305+5.699830e+00*S306+1.393084e+01*S307+1.043213e+01*S308+6.272263e+00*S309'
.param V74='V74_part31+1.506917e+01*S310+2.119776e+00*S311+0.000000e+00*S312+1.930879e+01*S313+6.540363e+00*S314'
.param V75_part1='(-1.508368e+01)*S0+(-1.507445e+00)*S1+6.085278e+00*S2+(-9.909874e+01)*S3+(-1.984657e+01)*S4+2.627004e+03*S5+6.188833e+02*S6+3.131164e+01*S7+(-1.653193e+03)*S8+1.638866e+03*S9'
.param V75_part2='V75_part1+1.000000e+04*S10+6.968818e+03*S11+9.967688e+03*S12+6.414248e+03*S13+2.005167e+03*S14+9.907592e+02*S15+1.000000e+04*S16+(-4.400994e-01)*S17+(-4.201543e+00)*S18+(-3.443047e+01)*S19'
.param V75_part3='V75_part2+2.549416e+00*S20+1.621370e+00*S21+7.856599e+01*S22+(-2.089249e+01)*S23+1.041272e+03*S24+4.367947e+00*S25+1.215662e+03*S26+2.931650e+02*S27+7.598413e+03*S28+7.560078e+03*S29'
.param V75_part4='V75_part3+9.988739e+00*S30+3.148155e+01*S31+1.529276e+01*S32+(-1.767105e+00)*S33+4.896822e+01*S34+2.415989e+01*S35+3.527096e+00*S36+3.572852e+00*S37+4.151979e+01*S38+1.533463e+01*S39'
.param V75_part5='V75_part4+1.004693e+01*S40+6.733701e+01*S41+1.021307e+01*S42+6.576934e+01*S43+7.246356e+01*S44+4.786624e+01*S45+3.890574e+01*S46+1.292782e+01*S47+2.519292e+03*S48+(-2.659764e+01)*S49'
.param V75_part6='V75_part5+1.374403e+01*S50+2.532301e+01*S51+7.949344e+00*S52+6.242365e+00*S53+2.034023e+01*S54+1.442289e+01*S55+6.950741e+00*S56+8.019145e+00*S57+7.950516e+00*S58+1.600872e+02*S59'
.param V75_part7='V75_part6+1.436574e+02*S60+1.910430e+01*S61+9.003844e+00*S62+2.513767e+03*S63+1.920510e+01*S64+4.627521e+01*S65+4.653421e+02*S66+4.994739e+00*S67+3.078125e+01*S68+1.347319e+02*S69'
.param V75_part8='V75_part7+1.062064e+01*S70+2.446049e+03*S71+(-2.499778e+03)*S72+2.254098e+03*S73+(-4.580933e+03)*S74+1.720130e+01*S75+3.379604e+01*S76+(-4.457092e+01)*S77+(-4.025954e+01)*S78+7.289321e+01*S79'
.param V75_part9='V75_part8+3.319846e+02*S80+1.105277e+01*S81+1.218527e+02*S82+8.978059e+00*S83+1.485829e+01*S84+1.988434e+00*S85+(-5.799227e-03)*S86+6.781061e+00*S87+(-4.546870e+00)*S88+3.850231e+00*S89'
.param V75_part10='V75_part9+4.135838e+01*S90+6.695642e+00*S91+2.520918e+03*S92+1.294411e+01*S93+7.508585e+03*S94+2.503786e+03*S95+7.978645e+00*S96+6.672716e+03*S97+6.940481e+03*S98+9.300847e+00*S99'
.param V75_part11='V75_part10+1.089406e+01*S100+7.906654e+02*S101+5.949081e+00*S102+6.481681e+00*S103+6.059469e+00*S104+3.731387e+01*S105+1.517189e+01*S106+(-3.767468e+03)*S107+1.977801e+01*S108+2.294427e+01*S109'
.param V75_part12='V75_part11+2.294269e+03*S110+2.519499e+03*S111+1.804006e+01*S112+2.987346e+03*S113+9.542826e+00*S114+8.817654e+00*S115+2.914359e+03*S116+4.987545e+02*S117+6.399284e+00*S118+1.342975e+01*S119'
.param V75_part13='V75_part12+1.957886e+01*S120+7.697347e+01*S121+2.057732e+01*S122+2.804272e+02*S123+(-4.119242e+03)*S124+7.573661e+03*S125+6.071813e+00*S126+2.504158e+03*S127+(-2.441591e+03)*S128+8.894805e+00*S129'
.param V75_part14='V75_part13+2.516247e+03*S130+2.480123e+03*S131+5.720550e+00*S132+2.500618e+03*S133+7.500854e+03*S134+1.337748e+01*S135+3.258980e+01*S136+1.935928e+03*S137+2.517315e+03*S138+9.041611e+00*S139'
.param V75_part15='V75_part14+4.754234e+01*S140+8.992439e+01*S141+9.815336e+02*S142+8.180692e+01*S143+2.541507e+03*S144+4.257744e+02*S145+(-3.206017e+03)*S146+2.535442e+03*S147+2.525455e+03*S148+(-4.720633e+03)*S149'
.param V75_part16='V75_part15+5.195411e+01*S150+9.328839e+00*S151+1.483348e+02*S152+1.489068e+01*S153+1.216206e+01*S154+2.203407e+02*S155+8.052524e+00*S156+1.779239e+01*S157+4.732640e+02*S158+3.785958e+00*S159'
.param V75_part17='V75_part16+(-2.145865e+01)*S160+6.192327e+00*S161+3.589856e+00*S162+(-3.064791e+00)*S163+8.107766e+00*S164+1.556210e+01*S165+3.211443e+01*S166+1.029270e+02*S167+7.514821e+03*S168+7.547764e+03*S169'
.param V75_part18='V75_part17+(-1.518422e+03)*S170+5.791277e+02*S171+9.953295e+00*S172+8.674407e+00*S173+4.131094e+01*S174+7.969464e+00*S175+6.660876e+00*S176+(-1.240989e+03)*S177+(-4.380957e+00)*S178+(-4.877260e+03)*S179'
.param V75_part19='V75_part18+1.033045e+01*S180+7.484131e+03*S181+2.448781e+03*S182+2.186114e+01*S183+1.799070e+01*S184+1.056826e+02*S185+8.578295e+00*S186+3.544242e+02*S187+7.429589e+03*S188+(-2.469479e+03)*S189'
.param V75_part20='V75_part19+1.000000e+04*S190+7.431123e+03*S191+5.569389e+00*S192+1.000000e+04*S193+5.376665e+01*S194+6.363622e+01*S195+5.341092e+01*S196+(-1.945136e+02)*S197+(-4.874880e+03)*S198+(-4.557420e+03)*S199'
.param V75_part21='V75_part20+(-5.589289e+02)*S200+(-4.793056e+03)*S201+(-4.754807e+03)*S202+(-3.429142e+02)*S203+7.484915e+03*S204+7.514887e+03*S205+1.252689e+01*S206+(-4.880924e+03)*S207+7.474523e+03*S208+6.213191e+01*S209'
.param V75_part22='V75_part21+1.707665e+01*S210+9.411631e+00*S211+1.498616e+02*S212+1.235715e+01*S213+2.499728e+01*S214+1.066884e+01*S215+2.117640e+01*S216+(-1.203901e+01)*S217+1.227170e+03*S218+2.287610e+00*S219'
.param V75_part23='V75_part22+(-1.037670e+01)*S220+4.992825e+02*S221+6.464352e+00*S222+(-1.547261e+00)*S223+1.206786e+01*S224+2.219393e+01*S225+1.207721e+01*S226+4.980773e+00*S227+(-2.491688e+03)*S228+2.526690e+03*S229'
.param V75_part24='V75_part23+6.541750e+02*S230+(-2.481609e+03)*S231+4.128865e+01*S232+1.143778e+03*S233+(-2.483059e+03)*S234+1.053202e+01*S235+6.731964e+01*S236+(-2.473569e+03)*S237+6.958737e+00*S238+7.754519e-01*S239'
.param V75_part25='V75_part24+2.802574e+01*S240+7.432714e+03*S241+9.253019e+01*S242+(-2.479513e+03)*S243+4.632009e+01*S244+7.568960e+03*S245+(-2.468110e+03)*S246+3.409761e+03*S247+1.584899e+02*S248+(-2.479234e+03)*S249'
.param V75_part26='V75_part25+6.227153e+03*S250+1.024278e+03*S251+(-2.479595e+03)*S252+1.717823e+01*S253+4.983911e+01*S254+(-4.841518e+03)*S255+(-3.390097e+03)*S256+(-1.345312e+03)*S257+(-3.859454e+01)*S258+(-4.688318e+03)*S259'
.param V75_part27='V75_part26+1.046539e+01*S260+2.632203e+00*S261+(-1.285072e+00)*S262+7.557658e+03*S263+2.372387e+00*S264+7.572967e+03*S265+7.612732e+03*S266+3.600994e+00*S267+5.785365e+03*S268+3.336095e+03*S269'
.param V75_part28='V75_part27+1.308023e+01*S270+2.318335e+01*S271+(-4.695281e+03)*S272+5.470901e+00*S273+6.201194e+00*S274+(-4.709978e+03)*S275+1.214587e+01*S276+2.360089e+02*S277+2.415053e+02*S278+3.837208e+00*S279'
.param V75_part29='V75_part28+3.683900e+00*S280+1.458494e+01*S281+2.434595e+00*S282+1.269982e+01*S283+4.301895e+01*S284+(-7.434161e+03)*S285+9.286577e+01*S286+1.726042e+01*S287+1.321524e+01*S288+3.414711e+02*S289'
.param V75_part30='V75_part29+1.488129e+01*S290+4.392421e+00*S291+7.051747e+00*S292+3.700753e+01*S293+3.578318e+00*S294+2.534547e+00*S295+2.249258e+01*S296+3.842618e+00*S297+6.739819e+00*S298+2.045336e+01*S299'
.param V75_part31='V75_part30+9.762309e+00*S300+4.517589e+00*S301+3.555149e+01*S302+(-3.529349e+00)*S303+8.052237e+00*S304+1.170135e+02*S305+2.020294e+00*S306+1.638051e+01*S307+1.622638e+01*S308+1.859278e-01*S309'
.param V75='V75_part31+1.143239e+01*S310+(-1.476504e+00)*S311+3.464763e+00*S312+2.221206e+00*S313+2.393684e+03*S314'
.param V76_part1='(-1.896432e+00)*S0+1.679500e+01*S1+2.171969e+02*S2+1.520048e+02*S3+7.533463e+01*S4+5.892380e+03*S5+2.808262e+01*S6+7.023213e+01*S7+4.709196e+03*S8+4.333453e+03*S9'
.param V76_part2='V76_part1+7.964612e+03*S10+5.481043e+03*S11+9.967688e+03*S12+7.782396e+03*S13+6.434286e+03*S14+1.099046e+03*S15+4.309964e+03*S16+1.746352e+01*S17+1.362608e+01*S18+1.105546e+02*S19'
.param V76_part3='V76_part2+1.414792e+01*S20+(-4.815875e+00)*S21+1.150642e+01*S22+6.156468e+01*S23+1.732194e+01*S24+1.339697e+01*S25+6.098219e+02*S26+(-4.483633e+01)*S27+(-4.756915e+01)*S28+(-2.950867e+01)*S29'
.param V76_part4='V76_part3+1.183265e+01*S30+4.444002e+00*S31+(-5.196318e-01)*S32+4.457233e+01*S33+4.832100e+00*S34+(-1.323435e+01)*S35+3.072861e+01*S36+2.214573e+00*S37+1.342277e+01*S38+5.784413e+00*S39'
.param V76_part5='V76_part4+3.676632e+01*S40+9.523564e+00*S41+7.053679e-01*S42+6.579618e+00*S43+2.190739e+01*S44+(-1.051025e+01)*S45+(-9.092144e+00)*S46+(-5.928730e+00)*S47+(-1.249429e+01)*S48+2.180882e+02*S49'
.param V76_part6='V76_part5+(-2.306702e-01)*S50+(-1.263965e+00)*S51+6.374188e-01*S52+1.415720e+00*S53+1.155297e+01*S54+9.897503e-02*S55+2.618285e+00*S56+(-1.959829e+00)*S57+(-2.240573e-01)*S58+1.201118e+01*S59'
.param V76_part7='V76_part6+(-1.023539e+01)*S60+(-4.709910e+00)*S61+1.884873e+00*S62+(-1.199749e+01)*S63+(-3.380878e-01)*S64+(-7.119650e+00)*S65+4.252117e+01*S66+4.734717e-01*S67+4.141355e-03*S68+(-4.027621e+01)*S69'
.param V76_part8='V76_part7+(-2.636200e+00)*S70+5.111363e+01*S71+(-1.430419e+01)*S72+1.456790e+02*S73+1.308756e+03*S74+4.748882e+00*S75+(-3.228173e+00)*S76+1.435276e+02*S77+9.815008e+01*S78+2.230038e+00*S79'
.param V76_part9='V76_part8+1.170117e+01*S80+8.456136e+00*S81+(-1.545936e+00)*S82+1.767401e-02*S83+2.268308e-01*S84+5.049629e+00*S85+6.961495e+00*S86+1.288666e+01*S87+1.114187e+01*S88+3.983316e+00*S89'
.param V76_part10='V76_part9+(-9.293121e+00)*S90+(-3.053037e+00)*S91+3.931150e+01*S92+(-2.839090e+00)*S93+1.325838e+00*S94+4.779093e+01*S95+(-2.057534e+00)*S96+2.727064e+02*S97+2.633478e+01*S98+(-7.909244e-01)*S99'
.param V76_part11='V76_part10+(-1.972242e+00)*S100+4.792515e+00*S101+(-1.545008e-01)*S102+4.359797e-01*S103+2.444224e+00*S104+(-1.232066e+01)*S105+(-6.277827e+00)*S106+5.191571e+02*S107+7.117824e-01*S108+(-8.504987e+00)*S109'
.param V76_part12='V76_part11+1.893020e+01*S110+(-1.146972e+01)*S111+(-6.675425e+00)*S112+(-2.388875e+02)*S113+(-1.685710e+00)*S114+4.680890e-01*S115+(-9.025839e+01)*S116+1.595327e-01*S117+4.360104e-01*S118+(-1.122867e+00)*S119'
.param V76_part13='V76_part12+(-1.679101e+01)*S120+1.221318e+01*S121+1.156431e+02*S122+(-5.532779e+00)*S123+(-6.647091e+02)*S124+2.453998e+03*S125+(-3.987511e-01)*S126+5.332188e+00*S127+1.723338e+02*S128+(-3.251337e+00)*S129'
.param V76_part14='V76_part13+(-5.304521e+00)*S130+(-6.328381e-01)*S131+(-1.242410e+00)*S132+5.109200e+00*S133+9.628121e-01*S134+2.066265e+00*S135+1.836041e+01*S136+5.923314e+01*S137+3.712526e+01*S138+8.899776e+00*S139'
.param V76_part15='V76_part14+3.268227e+01*S140+(-1.258207e+01)*S141+4.790654e+00*S142+5.262578e+01*S143+(-1.785781e+01)*S144+2.229324e+00*S145+2.902577e+01*S146+(-5.738325e+00)*S147+9.702531e+00*S148+4.128115e+01*S149'
.param V76_part16='V76_part15+(-7.397716e+00)*S150+6.518540e+00*S151+6.235193e+01*S152+(-2.589944e+00)*S153+4.439945e+00*S154+5.245859e+01*S155+(-8.418033e-01)*S156+4.706041e+00*S157+(-1.108612e+01)*S158+(-7.539197e-01)*S159'
.param V76_part17='V76_part16+(-4.228662e+00)*S160+7.488448e-04*S161+(-6.462214e+00)*S162+(-5.779341e+00)*S163+(-2.482677e-02)*S164+2.144924e+01*S165+2.650212e+01*S166+3.894565e+01*S167+1.476344e+01*S168+5.023904e+01*S169'
.param V76_part18='V76_part17+(-1.741794e+01)*S170+(-5.282219e+00)*S171+3.359804e-01*S172+(-8.081819e+00)*S173+1.098076e+00*S174+(-1.797821e+00)*S175+(-2.973076e+01)*S176+1.450579e+01*S177+(-8.159331e+00)*S178+(-6.492084e+01)*S179'
.param V76_part19='V76_part18+8.535313e+00*S180+(-5.304146e+00)*S181+(-7.103319e+01)*S182+(-4.027327e+00)*S183+2.986672e+01*S184+(-1.321649e+01)*S185+(-1.527821e+00)*S186+(-2.929915e+01)*S187+(-4.705370e+00)*S188+(-4.761677e+01)*S189'
.param V76_part20='V76_part19+(-1.650165e+01)*S190+(-6.230696e+00)*S191+(-8.175704e+00)*S192+1.337620e+02*S193+9.716683e+00*S194+3.073124e+01*S195+(-3.566751e+01)*S196+3.611638e+01*S197+1.243773e+02*S198+(-1.242414e+02)*S199'
.param V76_part21='V76_part20+(-3.407786e+01)*S200+(-7.441355e+01)*S201+1.242834e+02*S202+2.144302e+01*S203+(-6.294262e+00)*S204+(-1.874170e+01)*S205+2.033043e+00*S206+(-8.997126e+01)*S207+(-8.116904e+00)*S208+2.162616e+01*S209'
.param V76_part22='V76_part21+1.085000e+01*S210+9.974660e+00*S211+6.486189e+00*S212+5.891588e-01*S213+8.365764e+00*S214+8.291809e+00*S215+2.947800e+00*S216+(-3.206402e+00)*S217+3.075225e+01*S218+(-1.991811e+00)*S219'
.param V76_part23='V76_part22+(-8.247486e+00)*S220+1.680538e+01*S221+(-4.094118e-01)*S222+(-8.941253e+00)*S223+2.108909e-01*S224+4.227241e+00*S225+1.076160e+01*S226+1.383019e+01*S227+(-9.898822e+00)*S228+1.664399e+02*S229'
.param V76_part24='V76_part23+(-8.102911e+00)*S230+(-1.822931e+01)*S231+3.918195e+01*S232+4.129016e+01*S233+(-1.286641e+01)*S234+2.561726e+00*S235+5.219914e+00*S236+(-1.116039e+01)*S237+1.807016e+00*S238+(-1.095324e+02)*S239'
.param V76_part25='V76_part24+1.260628e+01*S240+(-9.664273e+00)*S241+3.834359e-01*S242+(-1.820128e+01)*S243+(-6.587899e+01)*S244+(-1.586796e+02)*S245+(-2.606791e+01)*S246+(-4.496380e+01)*S247+(-3.546568e+01)*S248+(-1.402126e+01)*S249'
.param V76_part26='V76_part25+2.385104e+00*S250+3.169603e+02*S251+(-9.891484e+00)*S252+(-2.689250e+01)*S253+1.326890e+00*S254+1.078280e+02*S255+(-2.929934e+02)*S256+6.761516e+01*S257+(-1.614614e+02)*S258+(-2.118260e+02)*S259'
.param V76_part27='V76_part26+7.410782e-01*S260+(-3.146765e+00)*S261+(-4.748679e+00)*S262+(-1.885772e+01)*S263+(-4.025277e+00)*S264+(-3.503341e+01)*S265+(-1.677249e+01)*S266+1.878981e+00*S267+1.372298e+01*S268+(-5.396369e+01)*S269'
.param V76_part28='V76_part27+(-1.180013e+01)*S270+(-2.688075e+00)*S271+6.125337e+01*S272+(-1.138148e+01)*S273+(-1.554565e+01)*S274+1.603330e+02*S275+(-2.207335e+01)*S276+(-4.596690e+02)*S277+(-3.366439e+02)*S278+(-7.047142e+00)*S279'
.param V76_part29='V76_part28+(-1.184641e-01)*S280+4.570048e+01*S281+(-1.272523e+00)*S282+(-1.787156e+01)*S283+2.313729e+02*S284+(-1.401284e+02)*S285+(-4.524000e+02)*S286+2.634290e+00*S287+7.440686e-01*S288+(-9.315561e+02)*S289'
.param V76_part30='V76_part29+1.935315e+00*S290+(-9.653775e+00)*S291+(-1.067539e+01)*S292+1.026994e+01*S293+(-7.531370e+00)*S294+(-8.716727e+00)*S295+5.655901e+00*S296+(-1.283852e-01)*S297+(-1.378232e+01)*S298+8.967981e-01*S299'
.param V76_part31='V76_part30+(-2.481538e-01)*S300+6.457931e+00*S301+(-1.960392e+00)*S302+(-6.916644e+00)*S303+7.154116e-01*S304+9.345400e+02*S305+(-8.400423e+00)*S306+9.926978e+00*S307+9.589004e+01*S308+(-2.304397e+00)*S309'
.param V76='V76_part31+3.859297e+00*S310+1.367496e+02*S311+1.601468e+00*S312+(-2.930178e+00)*S313+3.390363e+02*S314'
.param V77_part1='6.989540e+01*S0+1.535241e+01*S1+5.603513e+02*S2+4.458114e+02*S3+2.296614e+02*S4+4.945406e+03*S5+1.778199e+01*S6+8.926473e+01*S7+(-1.624421e+02)*S8+9.622751e+03*S9'
.param V77_part2='V77_part1+1.000000e+04*S10+1.000000e+04*S11+9.998337e+03*S12+(-9.877978e+03)*S13+(-7.111853e+03)*S14+2.429365e+03*S15+4.624021e+03*S16+2.335836e+00*S17+9.358740e+01*S18+1.484218e+01*S19'
.param V77_part3='V77_part2+(-5.160045e-01)*S20+1.048384e+02*S21+1.277246e+01*S22+(-1.107201e-01)*S23+2.677048e+02*S24+(-7.469159e+00)*S25+2.066013e+01*S26+6.766520e+02*S27+(-4.547099e+00)*S28+(-3.876868e+00)*S29'
.param V77_part4='V77_part3+(-1.331428e+00)*S30+(-2.396383e-01)*S31+3.809702e+00*S32+(-1.996819e+01)*S33+6.741781e+00*S34+(-1.071713e+01)*S35+(-2.689249e+01)*S36+1.389891e-01*S37+(-5.096863e+00)*S38+(-2.839009e+01)*S39'
.param V77_part5='V77_part4+(-1.737384e+01)*S40+(-3.454381e+01)*S41+(-1.607972e+01)*S42+(-5.574012e+01)*S43+(-4.455229e+01)*S44+3.898144e-01*S45+1.342590e+01*S46+2.301294e+00*S47+(-5.465336e+00)*S48+(-2.693803e+01)*S49'
.param V77_part6='V77_part5+(-4.907270e-01)*S50+(-1.929254e+00)*S51+4.430413e+00*S52+3.083451e-01*S53+3.698231e+00*S54+1.126292e+00*S55+7.251369e-01*S56+(-1.928525e+00)*S57+6.691341e-01*S58+1.527657e+00*S59'
.param V77_part7='V77_part6+(-6.115052e+00)*S60+8.484992e+00*S61+3.908143e+00*S62+1.775009e+01*S63+9.856800e+00*S64+4.154291e+00*S65+1.047246e+02*S66+(-3.613831e+00)*S67+2.320148e+00*S68+1.088198e+02*S69'
.param V77_part8='V77_part7+(-8.027343e+00)*S70+5.139922e+01*S71+1.000000e+04*S72+3.387759e+02*S73+(-1.310158e+03)*S74+4.090305e+00*S75+7.479795e+00*S76+3.549037e+01*S77+1.358039e+02*S78+1.060914e+01*S79'
.param V77_part9='V77_part8+1.078542e+01*S80+(-7.882806e+00)*S81+(-1.536587e+02)*S82+3.442411e+00*S83+(-6.407351e+00)*S84+5.504728e+00*S85+4.127060e+00*S86+(-1.236316e+01)*S87+4.783737e+00*S88+3.667355e+00*S89'
.param V77_part10='V77_part9+(-6.108226e+01)*S90+(-5.215663e+00)*S91+1.980374e+01*S92+(-1.864888e+01)*S93+5.882400e-01*S94+1.394386e+01*S95+(-8.898347e+00)*S96+(-3.637200e+02)*S97+2.409455e+01*S98+(-1.247577e+01)*S99'
.param V77_part11='V77_part10+(-7.905916e+00)*S100+1.835114e+01*S101+(-7.115915e+00)*S102+(-4.615725e+00)*S103+(-6.331608e+00)*S104+(-5.912928e+01)*S105+(-1.416816e+01)*S106+(-3.902891e+02)*S107+(-3.200205e+01)*S108+(-1.994560e+01)*S109'
.param V77_part12='V77_part11+6.966621e+01*S110+(-8.742537e+00)*S111+(-1.304840e+01)*S112+7.968982e+01*S113+(-1.106080e+01)*S114+(-7.812607e+00)*S115+(-1.792617e+02)*S116+(-3.067310e+01)*S117+(-5.276567e+00)*S118+(-9.290384e+00)*S119'
.param V77_part13='V77_part12+(-3.409665e+01)*S120+(-1.060859e+02)*S121+(-1.256284e+02)*S122+(-1.271826e+01)*S123+(-7.646808e+02)*S124+(-7.168996e+03)*S125+(-6.994043e-01)*S126+2.090692e+01*S127+(-6.144091e+02)*S128+(-8.620723e+00)*S129'
.param V77_part14='V77_part13+1.675678e+01*S130+6.002453e+01*S131+(-4.458141e+00)*S132+2.566767e+01*S133+1.125023e+01*S134+(-2.055508e-01)*S135+2.947199e+01*S136+7.963958e+01*S137+(-9.018907e+00)*S138+1.671193e+01*S139'
.param V77_part15='V77_part14+1.294528e+01*S140+(-9.194617e-01)*S141+1.257659e+02*S142+1.127376e+01*S143+(-9.570624e+00)*S144+(-6.688963e+00)*S145+(-1.131367e+02)*S146+(-9.040945e+00)*S147+(-7.642013e+00)*S148+(-1.573805e+02)*S149'
.param V77_part16='V77_part15+(-1.083351e+02)*S150+(-1.150362e+01)*S151+(-1.469030e+02)*S152+(-2.473901e+01)*S153+(-1.537277e+01)*S154+(-2.158787e+02)*S155+(-1.041590e+01)*S156+(-2.572500e+01)*S157+(-4.342809e+02)*S158+(-4.396600e+00)*S159'
.param V77_part17='V77_part16+6.379656e+01*S160+(-4.523522e+00)*S161+9.384922e+00*S162+2.526153e+01*S163+(-6.268275e+00)*S164+6.349217e+00*S165+(-4.510518e+01)*S166+(-1.016644e+02)*S167+(-8.029456e+00)*S168+(-7.743674e+01)*S169'
.param V77_part18='V77_part17+(-1.579900e+02)*S170+(-2.231606e+01)*S171+(-9.851065e+00)*S172+(-6.664924e-01)*S173+(-8.278589e+01)*S174+(-7.607258e+00)*S175+(-2.868807e+00)*S176+4.952345e+03*S177+3.309225e+01*S178+(-3.857199e+01)*S179'
.param V77_part19='V77_part18+(-1.739368e+01)*S180+7.690780e+01*S181+2.277255e+00*S182+(-3.645562e+01)*S183+(-5.414898e+01)*S184+(-2.318711e+01)*S185+(-1.191705e+01)*S186+1.429561e+01*S187+1.282598e+02*S188+1.000000e+04*S189'
.param V77_part20='V77_part19+(-1.103419e+02)*S190+1.491843e+02*S191+7.323844e+00*S192+(-6.734686e+01)*S193+(-5.214009e+01)*S194+(-7.657247e-01)*S195+(-1.665901e+02)*S196+(-1.597755e+02)*S197+(-3.650141e+01)*S198+(-3.811040e+02)*S199'
.param V77_part21='V77_part20+(-2.306990e+02)*S200+1.358980e+00*S201+(-1.356374e+02)*S202+(-2.424805e+02)*S203+7.471696e+01*S204+2.922468e+01*S205+(-7.714389e+00)*S206+(-2.888773e+01)*S207+8.151398e+01*S208+(-6.869128e+01)*S209'
.param V77_part22='V77_part21+(-3.880920e+01)*S210+(-1.379178e+01)*S211+(-1.371863e+02)*S212+(-2.383608e+01)*S213+(-3.264499e+01)*S214+(-1.169639e+01)*S215+(-4.583092e+01)*S216+4.360695e+01*S217+(-1.231840e+03)*S218+5.621581e+00*S219'
.param V77_part23='V77_part22+4.591852e+01*S220+(-5.016133e+02)*S221+(-8.893631e+00)*S222+2.989922e+01*S223+(-1.017593e+01)*S224+(-4.488497e+01)*S225+(-1.497011e+01)*S226+(-8.712025e+00)*S227+1.000000e+04*S228+(-1.186999e+02)*S229'
.param V77_part24='V77_part23+(-6.232968e+02)*S230+1.000000e+04*S231+(-4.656779e+01)*S232+(-1.135595e+03)*S233+1.000000e+04*S234+(-1.242467e+01)*S235+(-6.156181e+01)*S236+1.000000e+04*S237+(-9.178407e+00)*S238+1.456374e+02*S239'
.param V77_part25='V77_part24+(-6.415899e+01)*S240+2.087843e+02*S241+(-8.119111e+01)*S242+1.000000e+04*S243+9.202578e+03*S244+6.292022e+01*S245+1.000000e+04*S246+(-5.758297e+01)*S247+(-5.288343e+01)*S248+1.000000e+04*S249'
.param V77_part26='V77_part25+3.274454e+02*S250+(-1.214976e+03)*S251+1.000000e+04*S252+2.719549e+01*S253+(-4.306221e+01)*S254+(-9.347063e+01)*S255+(-5.690464e+02)*S256+(-1.540686e+02)*S257+(-1.546249e+02)*S258+(-2.458629e+02)*S259'
.param V77_part27='V77_part26+(-6.096808e+00)*S260+1.691971e+00*S261+1.640328e+01*S262+(-2.969600e+01)*S263+4.822846e+00*S264+(-8.100432e+01)*S265+(-8.657708e+01)*S266+(-3.557427e+00)*S267+(-8.431134e+01)*S268+(-8.612846e+01)*S269'
.param V77_part28='V77_part27+2.247443e+01*S270+(-5.561692e+00)*S271+(-2.622505e+02)*S272+2.447748e+01*S273+1.025682e+01*S274+(-2.866049e+02)*S275+2.064304e+01*S276+1.036722e+00*S277+(-5.340715e+00)*S278+1.151150e+01*S279'
.param V77_part29='V77_part28+(-3.213967e+00)*S280+(-1.218612e+01)*S281+1.652981e+00*S282+1.650496e+01*S283+(-7.037870e+01)*S284+1.000000e+04*S285+1.188408e+02*S286+(-1.458173e+01)*S287+(-2.509521e+01)*S288+1.865223e+02*S289'
.param V77_part30='V77_part29+(-1.294781e+01)*S290+1.219187e+01*S291+6.165236e+00*S292+(-3.412122e+01)*S293+1.488275e+01*S294+2.105943e+01*S295+(-2.081090e+01)*S296+(-4.085367e+00)*S297+2.532752e+01*S298+(-1.805634e+01)*S299'
.param V77_part31='V77_part30+(-1.788144e+01)*S300+(-4.499598e+00)*S301+(-2.789920e+01)*S302+2.864477e+01*S303+(-8.630138e+00)*S304+(-4.253945e+02)*S305+1.511651e+01*S306+(-2.496367e+01)*S307+(-5.313307e+01)*S308+1.072744e+01*S309'
.param V77='V77_part31+(-1.596814e+01)*S310+(-4.527797e+01)*S311+(-5.385326e+00)*S312+5.884773e+00*S313+(-2.555791e+01)*S314'
.param V78_part1='2.727056e+00*S0+2.842127e+01*S1+(-2.436912e+02)*S2+(-5.449151e+01)*S3+(-5.186584e+01)*S4+3.948576e+00*S5+3.317207e-01*S6+(-5.810503e-02)*S7+4.359881e+01*S8+(-9.810693e+03)*S9'
.param V78_part2='V78_part1+2.389274e+03*S10+3.629163e+03*S11+1.000000e+04*S12+4.422076e+03*S13+5.960819e+03*S14+2.382862e+03*S15+1.000000e+04*S16+1.423128e+01*S17+(-1.625543e+01)*S18+1.696068e+01*S19'
.param V78_part3='V78_part2+1.695738e+01*S20+(-1.044750e+01)*S21+(-6.972783e+01)*S22+2.006562e+01*S23+(-1.455819e+03)*S24+1.839508e+01*S25+(-1.692988e+00)*S26+(-4.896597e+02)*S27+(-1.000000e+04)*S28+(-1.000000e+04)*S29'
.param V78_part4='V78_part3+4.108373e+01*S30+(-3.090447e-02)*S31+6.064911e+01*S32+1.052721e+01*S33+1.968438e+02*S34+3.413806e+00*S35+1.248500e+01*S36+8.569682e+00*S37+1.030388e+02*S38+1.371333e+01*S39'
.param V78_part5='V78_part4+4.416704e+01*S40+8.761848e+01*S41+5.449507e+00*S42+7.597398e+01*S43+1.098751e+02*S44+1.426453e+02*S45+1.307352e+02*S46+2.549968e+01*S47+9.999995e+03*S48+1.915472e+01*S49'
.param V78_part6='V78_part5+(-3.459110e+00)*S50+7.067848e+01*S51+2.213650e+01*S52+1.233866e+01*S53+6.580692e+01*S54+2.814287e+01*S55+1.697018e+01*S56+1.055595e+01*S57+1.457663e+01*S58+6.568706e+02*S59'
.param V78_part7='V78_part6+5.095564e+02*S60+5.879137e+01*S61+3.113279e+01*S62+1.000000e+04*S63+6.801702e+01*S64+1.514515e+02*S65+2.000236e+03*S66+6.411777e-01*S67+9.765988e+01*S68+5.059053e+02*S69'
.param V78_part8='V78_part7+1.280171e+00*S70+1.000000e+04*S71+9.721827e+01*S72+1.000000e+04*S73+8.131374e+01*S74+6.946409e+01*S75+1.331725e+02*S76+(-1.996845e+01)*S77+(-2.924405e+01)*S78+3.023787e+02*S79'
.param V78_part9='V78_part8+(-4.460503e+02)*S80+3.230726e+01*S81+1.005841e+01*S82+2.227505e+01*S83+2.493772e+01*S84+1.454302e+01*S85+1.433051e+01*S86+2.201231e+01*S87+8.250867e+00*S88+1.703583e+01*S89'
.param V78_part10='V78_part9+(-2.293951e+00)*S90+2.889869e+00*S91+1.000000e+04*S92+3.055899e-01*S93+(-1.000000e+04)*S94+1.000000e+04*S95+6.887978e-02*S96+(-8.593386e+03)*S97+(-9.264642e+03)*S98+1.036904e+00*S99'
.param V78_part11='V78_part10+(-7.733645e-01)*S100+(-1.035014e+03)*S101+(-5.980693e-01)*S102+(-1.059744e+00)*S103+5.813926e-01*S104+7.157653e-01*S105+2.797474e-01*S106+(-4.581212e+01)*S107+9.198638e-01*S108+(-1.071745e+00)*S109'
.param V78_part12='V78_part11+9.312790e+03*S110+1.000000e+04*S111+7.324607e+00*S112+1.000000e+04*S113+2.996844e+00*S114+2.943478e+00*S115+1.000000e+04*S116+(-6.347207e+02)*S117+2.829674e+00*S118+(-2.269198e-01)*S119'
.param V78_part13='V78_part12+4.733849e+00*S120+(-1.734957e+00)*S121+(-2.316096e+01)*S122+1.028104e+03*S123+(-1.831860e+01)*S124+(-8.277640e+03)*S125+(-9.613331e-01)*S126+1.000000e+04*S127+(-7.649552e+01)*S128+2.504956e+00*S129'
.param V78_part14='V78_part13+1.000000e+04*S130+1.000000e+04*S131+(-1.003703e+00)*S132+1.000000e+04*S133+(-1.000000e+04)*S134+3.654469e+01*S135+1.496856e+02*S136+7.897449e+03*S137+1.000000e+04*S138+4.340582e+01*S139'
.param V78_part15='V78_part14+(-6.889002e+01)*S140+2.547570e+02*S141+3.915398e+03*S142+(-1.216048e+02)*S143+1.000000e+04*S144+1.591759e+03*S145+(-1.528641e+02)*S146+1.000000e+04*S147+1.000000e+04*S148+(-8.636195e+01)*S149'
.param V78_part16='V78_part15+(-2.800947e+00)*S150+4.357027e-01*S151+5.030294e-01*S152+3.738840e+00*S153+4.161930e-01*S154+(-1.192986e+00)*S155+7.358361e-01*S156+2.603631e+00*S157+(-4.234623e+00)*S158+4.793270e-01*S159'
.param V78_part17='V78_part16+(-1.068352e+00)*S160+1.731585e-02*S161+(-4.691976e-01)*S162+(-1.424024e+00)*S163+7.234104e-02*S164+(-1.971985e+01)*S165+(-1.167914e+00)*S166+(-5.617602e-01)*S167+(-1.000000e+04)*S168+(-1.000000e+04)*S169'
.param V78_part18='V78_part17+(-6.235192e+01)*S170+(-7.278784e+02)*S171+(-6.333354e-01)*S172+(-5.604735e-01)*S173+2.831421e+00*S174+5.928122e-01*S175+6.458708e+00*S176+1.334568e+01*S177+(-8.884031e-01)*S178+2.283095e+01*S179'
.param V78_part19='V78_part18+(-2.797774e+00)*S180+(-1.000000e+04)*S181+(-3.160303e+03)*S182+1.553458e+00*S183+2.069273e+00*S184+(-7.493385e+01)*S185+(-2.365876e-01)*S186+(-7.618010e+01)*S187+(-1.000000e+04)*S188+1.313627e-01*S189'
.param V78_part20='V78_part19+(-2.300958e+01)*S190+(-1.000000e+04)*S191+(-4.263154e-01)*S192+(-2.875453e+01)*S193+3.113760e-01*S194+(-8.258208e+01)*S195+(-2.440442e+01)*S196+(-4.203929e+01)*S197+(-1.117683e+02)*S198+(-1.090647e+02)*S199'
.param V78_part21='V78_part20+(-7.472191e+01)*S200+(-9.491180e+01)*S201+(-2.186684e+02)*S202+(-5.008610e+01)*S203+(-1.000000e+04)*S204+(-1.000000e+04)*S205+(-7.260682e+00)*S206+(-3.657409e+00)*S207+(-1.000000e+04)*S208+(-4.300301e+00)*S209'
.param V78_part22='V78_part21+(-3.025511e-01)*S210+9.982437e-01*S211+(-5.691601e+00)*S212+2.002184e-01*S213+2.925939e+00*S214+7.942536e-01*S215+2.638925e+00*S216+(-2.861324e+00)*S217+1.653581e+00*S218+(-1.344092e-01)*S219'
.param V78_part23='V78_part22+(-1.132307e+00)*S220+1.598314e-01*S221+1.682239e-01*S222+(-1.069656e+00)*S223+(-1.267129e-01)*S224+4.977034e-01*S225+(-1.217871e+00)*S226+3.359428e-01*S227+(-9.706343e+00)*S228+1.000000e+04*S229'
.param V78_part24='V78_part23+(-8.777985e+00)*S230+(-5.791416e+00)*S231+(-5.211577e+00)*S232+(-1.362847e+01)*S233+(-1.105198e+01)*S234+3.383039e-01*S235+(-1.411012e+00)*S236+(-1.881653e+01)*S237+4.709391e-01*S238+(-3.160965e+00)*S239'
.param V78_part25='V78_part24+1.248739e+00*S240+(-1.000000e+04)*S241+(-4.630336e+00)*S242+(-2.348332e+01)*S243+(-1.581481e+01)*S244+(-1.000000e+04)*S245+(-1.966677e+01)*S246+(-4.405647e+03)*S247+(-7.821671e+01)*S248+(-1.348943e+01)*S249'
.param V78_part26='V78_part25+(-8.476457e+03)*S250+2.332475e-01*S251+(-1.594936e+01)*S252+(-1.175646e+00)*S253+(-8.474978e-01)*S254+(-8.848761e+01)*S255+(-1.079812e+01)*S256+(-6.292319e+00)*S257+(-5.807619e+01)*S258+(-3.869141e+01)*S259'
.param V78_part27='V78_part26+(-2.018554e+00)*S260+(-2.325929e-01)*S261+(-2.224492e+00)*S262+(-1.000000e+04)*S263+(-1.100356e+00)*S264+(-1.000000e+04)*S265+(-1.000000e+04)*S266+(-1.552725e+00)*S267+(-7.644807e+03)*S268+(-4.262871e+03)*S269'
.param V78_part28='V78_part27+(-1.380859e+01)*S270+(-1.123085e+01)*S271+7.499390e+01*S272+(-4.157957e+00)*S273+(-1.660753e+00)*S274+1.350562e+02*S275+(-1.070933e+00)*S276+(-1.115223e+01)*S277+(-2.046789e+00)*S278+(-4.295870e-01)*S279'
.param V78_part29='V78_part28+(-1.715510e-01)*S280+(-4.479125e-01)*S281+(-1.271123e-01)*S282+(-8.451371e-01)*S283+(-3.041624e+00)*S284+(-1.436010e+01)*S285+(-5.373836e+00)*S286+(-2.970925e-01)*S287+4.296109e-01*S288+(-6.734734e+00)*S289'
.param V78_part30='V78_part29+(-2.766929e-02)*S290+(-4.741550e-01)*S291+(-5.364865e-01)*S292+(-2.739978e-01)*S293+(-4.079642e-01)*S294+(-1.730095e+00)*S295+(-1.569487e-02)*S296+6.711677e-02*S297+(-2.220976e+00)*S298+1.025412e-01*S299'
.param V78_part31='V78_part30+(-1.013669e+00)*S300+(-9.203875e-01)*S301+(-3.386162e+00)*S302+(-1.817788e+00)*S303+(-5.985545e-01)*S304+1.880862e+01*S305+(-1.267130e+00)*S306+3.430827e+00*S307+2.166041e+00*S308+(-7.127646e-01)*S309'
.param V78='V78_part31+1.262344e+00*S310+(-9.435701e-03)*S311+3.756642e-02*S312+(-7.365375e-01)*S313+4.779156e+00*S314'
.param V79_part1='(-1.022997e-01)*S0+9.199165e-02*S1+(-1.234114e+02)*S2+1.128394e+00*S3+(-8.035501e+00)*S4+5.191039e-01*S5+3.744041e+01*S6+(-5.393981e+00)*S7+(-3.110044e+02)*S8+1.173064e+03*S9'
.param V79_part2='V79_part1+3.989532e+03*S10+7.469655e+03*S11+(-1.000000e+04)*S12+7.822866e+03*S13+5.628983e+03*S14+2.441328e+01*S15+1.349489e+02*S16+(-5.915893e-02)*S17+(-3.669860e-01)*S18+6.023719e-01*S19'
.param V79_part3='V79_part2+1.371641e-02*S20+(-2.607685e-01)*S21+(-1.281274e+00)*S22+(-9.381748e-03)*S23+(-8.864406e-01)*S24+(-2.244905e-02)*S25+2.378930e+01*S26+(-3.969441e-01)*S27+(-2.749469e-01)*S28+(-1.837669e-01)*S29'
.param V79_part4='V79_part3+4.197062e-01*S30+1.171890e-01*S31+1.207510e-01*S32+3.807704e-01*S33+5.439053e-01*S34+3.512122e-01*S35+(-1.641491e+00)*S36+3.895559e-01*S37+4.248461e-01*S38+3.854470e-01*S39'
.param V79_part5='V79_part4+1.047905e+00*S40+1.477357e+00*S41+3.114023e-01*S42+2.644644e+00*S43+9.870305e-01*S44+1.146272e+00*S45+1.131457e+00*S46+5.834447e-01*S47+1.922850e+00*S48+(-6.784981e+00)*S49'
.param V79_part6='V79_part5+7.520672e+00*S50+2.103362e+00*S51+1.078379e+00*S52+5.814738e-01*S53+1.517550e+00*S54+4.992700e-01*S55+8.054366e-01*S56+1.935974e+00*S57+1.554647e+00*S58+5.986352e+00*S59'
.param V79_part7='V79_part6+6.411430e-01*S60+3.925475e-01*S61+3.455394e-01*S62+5.603678e-01*S63+5.771149e-01*S64+8.380591e-01*S65+(-5.198222e-01)*S66+1.986665e+00*S67+3.186932e-01*S68+8.975261e+00*S69'
.param V79_part8='V79_part7+3.150951e+00*S70+(-3.957701e-01)*S71+1.000801e+02*S72+3.112705e+01*S73+1.000000e+04*S74+1.911002e-01*S75+4.703314e-01*S76+1.467026e+01*S77+1.040381e+01*S78+4.011986e-01*S79'
.param V79_part9='V79_part8+3.667410e+00*S80+1.411937e+00*S81+(-9.149725e-02)*S82+1.010649e+00*S83+7.130134e-01*S84+1.619255e+00*S85+1.600074e+00*S86+1.378326e+00*S87+4.270874e+00*S88+1.285076e+00*S89'
.param V79_part10='V79_part9+3.099057e+00*S90+9.071871e-01*S91+(-2.886521e+00)*S92+1.481555e+00*S93+4.224302e+00*S94+(-3.323705e+00)*S95+1.413477e+00*S96+8.601256e-01*S97+3.334596e+00*S98+1.827615e+00*S99'
.param V79_part11='V79_part10+9.408692e-01*S100+2.464217e+00*S101+1.232035e+00*S102+5.880975e-01*S103+1.703459e+00*S104+1.121255e+01*S105+4.492784e+00*S106+8.353069e+03*S107+3.771862e+00*S108+6.611730e+00*S109'
.param V79_part12='V79_part11+(-2.307027e+00)*S110+4.359338e+00*S111+2.524245e+00*S112+(-1.890602e+02)*S113+2.858739e+00*S114+3.642889e+00*S115+(-2.221231e+01)*S116+3.505309e+00*S117+5.402461e+00*S118+5.955611e-01*S119'
.param V79_part13='V79_part12+1.518398e+01*S120+4.175340e+01*S121+2.982423e+02*S122+3.834151e+00*S123+1.000000e+04*S124+1.000000e+04*S125+4.238396e+00*S126+1.091346e+01*S127+6.240456e+03*S128+5.096016e+00*S129'
.param V79_part14='V79_part13+6.530898e+00*S130+1.215275e+01*S131+9.868671e-01*S132+9.131928e+00*S133+7.190897e+00*S134+8.575579e-01*S135+2.720094e-01*S136+(-7.213634e+00)*S137+(-6.684286e-01)*S138+1.365252e-01*S139'
.param V79_part15='V79_part14+6.207332e+00*S140+4.610701e-01*S141+1.237137e-01*S142+9.005175e+00*S143+(-6.628227e-01)*S144+(-4.675553e-01)*S145+7.066272e+03*S146+(-2.358950e+00)*S147+(-3.182959e+00)*S148+1.000000e+04*S149'
.param V79_part16='V79_part15+1.651760e+01*S150+2.176727e+00*S151+9.060672e+00*S152+5.549639e+00*S153+2.660273e+00*S154+1.014752e+01*S155+2.095633e+00*S156+1.083201e+00*S157+4.880134e+00*S158+9.818190e-01*S159'
.param V79_part17='V79_part16+9.399002e+00*S160+1.366326e-01*S161+6.196203e+00*S162+4.074898e+00*S163+(-1.185537e-01)*S164+3.565467e+00*S165+5.558697e+00*S166+3.728756e+00*S167+(-1.460727e-01)*S168+1.527367e+01*S169'
.param V79_part18='V79_part17+3.564323e+03*S170+(-5.969097e+00)*S171+1.609281e+00*S172+4.649553e+00*S173+1.025575e+00*S174+7.641236e-01*S175+7.175396e+01*S176+1.963499e+01*S177+5.634809e+00*S178+1.000000e+04*S179'
.param V79_part19='V79_part18+1.123360e+01*S180+3.755317e+00*S181+1.345817e+00*S182+9.620759e-01*S183+4.312784e+01*S184+(-5.645899e-01)*S185+5.716186e-01*S186+(-1.697761e+02)*S187+1.476778e+01*S188+4.011791e+01*S189'
.param V79_part20='V79_part19+(-6.587144e+03)*S190+5.172511e+00*S191+8.261684e+00*S192+(-6.688324e+03)*S193+(-3.356936e+00)*S194+1.667006e+00*S195+2.485857e+02*S196+8.606552e+02*S197+1.000000e+04*S198+1.000000e+04*S199'
.param V79_part21='V79_part20+1.843728e+03*S200+1.000000e+04*S201+1.000000e+04*S202+1.322093e+03*S203+2.109553e+01*S204+6.555550e+00*S205+1.187204e+01*S206+1.000000e+04*S207+1.209069e+01*S208+7.716991e+00*S209'
.param V79_part22='V79_part21+3.639251e+00*S210+2.849209e+00*S211+1.264910e+01*S212+6.337790e-01*S213+(-7.909405e-01)*S214+7.384059e+00*S215+6.539549e-01*S216+5.598496e+00*S217+3.110925e+00*S218+2.042072e-01*S219'
.param V79_part23='V79_part22+7.547492e+00*S220+2.182504e-01*S221+1.870520e+00*S222+4.257217e+00*S223+(-1.243004e-01)*S224+8.775574e-01*S225+2.335462e+00*S226+1.961971e+01*S227+3.720960e+01*S228+1.698483e+01*S229'
.param V79_part24='V79_part23+9.055905e-01*S230+1.808556e+01*S231+(-1.369153e+01)*S232+(-7.133893e-01)*S233+1.475349e+01*S234+(-6.046873e-01)*S235+(-6.057528e-01)*S236+8.602887e+00*S237+1.264353e-01*S238+6.089762e+01*S239'
.param V79_part25='V79_part24+2.212471e+00*S240+1.710168e+01*S241+3.201254e+00*S242+5.164621e+01*S243+(-1.501856e+03)*S244+1.120183e+00*S245+1.241233e+01*S246+(-1.314011e+01)*S247+(-1.919903e+00)*S248+1.238392e+01*S249'
.param V79_part26='V79_part25+4.046692e+01*S250+(-6.272060e+00)*S251+1.290090e+01*S252+6.677507e+00*S253+(-2.985194e-01)*S254+1.000000e+04*S255+7.779566e+03*S256+3.040149e+03*S257+5.604029e+02*S258+1.000000e+04*S259'
.param V79_part27='V79_part26+5.310523e+00*S260+1.945709e+00*S261+3.350093e+00*S262+1.863378e+01*S263+4.624927e+00*S264+3.703845e+01*S265+1.693641e+01*S266+(-2.230209e-01)*S267+1.424872e+01*S268+5.389634e+01*S269'
.param V79_part28='V79_part27+1.434182e+00*S270+2.391908e-01*S271+1.000000e+04*S272+1.753637e+00*S273+3.522386e+00*S274+1.000000e+04*S275+3.035238e+00*S276+2.045149e+02*S277+3.660384e+01*S278+3.304329e+00*S279'
.param V79_part29='V79_part28+1.374607e-01*S280+(-1.504219e+01)*S281+4.284678e-02*S282+5.272169e+00*S283+(-9.564123e+01)*S284+1.000000e+04*S285+7.511458e+01*S286+9.000939e-01*S287+2.162580e-01*S288+1.645810e+02*S289'
.param V79_part30='V79_part29+4.634423e-01*S290+3.601477e+00*S291+2.392908e+00*S292+(-1.986765e+00)*S293+3.365121e+00*S294+3.305784e+00*S295+(-1.042522e+00)*S296+1.476024e-01*S297+5.612829e+00*S298+(-1.682091e-02)*S299'
.param V79_part31='V79_part30+1.255341e+00*S300+2.932996e+00*S301+2.525098e+00*S302+6.180565e+00*S303+7.722422e-01*S304+(-3.289123e+00)*S305+4.874066e+00*S306+(-1.538387e-01)*S307+3.158666e-01*S308+2.364244e+00*S309'
.param V79='V79_part31+2.761063e-01*S310+(-2.219945e+01)*S311+1.618297e-01*S312+1.688440e+00*S313+(-1.752087e+03)*S314'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V80_part2='V80_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V80_part3='V80_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V80_part4='V80_part3+0.000000e+00*S30+0.000000e+00*S31+(-5.859980e-01)*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+3.802311e-02*S37+0.000000e+00*S38+(-1.033401e-01)*S39'
.param V80_part5='V80_part4+0.000000e+00*S40+0.000000e+00*S41+(-1.245423e-01)*S42+0.000000e+00*S43+0.000000e+00*S44+(-9.105681e-02)*S45+(-1.152592e-01)*S46+(-1.870973e-01)*S47+(-9.681505e-02)*S48+0.000000e+00*S49'
.param V80_part6='V80_part5+(-3.728103e-01)*S50+(-4.096753e-02)*S51+(-2.997267e-02)*S52+(-7.067105e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+(-1.539272e-01)*S56+3.255498e-02*S57+(-1.988552e-02)*S58+(-3.836994e-01)*S59'
.param V80_part7='V80_part6+(-9.076255e-02)*S60+(-1.851089e-01)*S61+(-2.430255e-01)*S62+4.974529e-03*S63+(-1.061765e-01)*S64+(-1.214580e-02)*S65+9.283662e-02*S66+7.770121e-02*S67+1.432702e-01*S68+2.992441e-01*S69'
.param V80_part8='V80_part7+1.553115e-01*S70+(-2.880431e-01)*S71+1.553222e-01*S72+8.320239e-02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V80_part9='V80_part8+(-7.927384e-02)*S80+0.000000e+00*S81+0.000000e+00*S82+(-1.265591e-01)*S83+(-3.993057e-02)*S84+(-1.056037e-02)*S85+(-2.075201e-02)*S86+6.748398e-02*S87+8.419729e-02*S88+(-1.060301e-02)*S89'
.param V80_part10='V80_part9+(-8.464889e-02)*S90+(-3.199244e-01)*S91+(-1.866409e-01)*S92+3.070302e-02*S93+(-1.422573e-01)*S94+(-4.196980e-01)*S95+1.596780e-01*S96+(-1.441938e-01)*S97+(-8.130124e-01)*S98+(-3.878502e-02)*S99'
.param V80_part11='V80_part10+(-1.119115e-01)*S100+(-1.062894e+00)*S101+2.425737e-01*S102+(-1.565116e-03)*S103+(-9.886948e-01)*S104+(-8.312018e-02)*S105+0.000000e+00*S106+(-2.805376e-01)*S107+(-5.880411e-02)*S108+(-1.015784e-01)*S109'
.param V80_part12='V80_part11+0.000000e+00*S110+0.000000e+00*S111+(-1.535792e-01)*S112+(-5.344529e-01)*S113+(-9.962566e-02)*S114+(-1.528752e-01)*S115+(-5.974048e-01)*S116+(-1.516110e-01)*S117+(-1.520362e-01)*S118+(-5.392357e-01)*S119'
.param V80_part13='V80_part12+(-1.028807e-01)*S120+(-8.679753e-02)*S121+(-2.699182e-01)*S122+1.046567e-01*S123+(-1.329001e-01)*S124+(-4.270911e-01)*S125+1.124222e-01*S126+(-2.308689e-01)*S127+(-5.937481e-01)*S128+(-5.015345e-02)*S129'
.param V80_part14='V80_part13+(-1.988174e-01)*S130+(-6.009260e-01)*S131+2.706705e-01*S132+(-2.299308e-01)*S133+(-7.195805e-02)*S134+(-2.604763e-02)*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V80_part15='V80_part14+(-8.852049e-02)*S140+(-7.191154e-02)*S141+0.000000e+00*S142+(-2.226843e-01)*S143+(-1.828905e-01)*S144+(-2.251510e-01)*S145+(-4.663363e-01)*S146+(-3.011047e-01)*S147+(-4.257216e-01)*S148+(-6.041802e-01)*S149'
.param V80_part16='V80_part15+(-1.173116e-01)*S150+(-1.083152e-01)*S151+(-7.504156e-01)*S152+(-1.690441e-01)*S153+(-2.527251e-01)*S154+(-1.053841e+00)*S155+(-2.379814e-01)*S156+(-6.988708e-03)*S157+(-7.724099e-01)*S158+5.257436e-02*S159'
.param V80_part17='V80_part16+1.610068e-01*S160+(-7.268741e-01)*S161+0.000000e+00*S162+0.000000e+00*S163+(-7.543667e-01)*S164+7.823981e-04*S165+0.000000e+00*S166+(-5.232623e-01)*S167+(-8.778490e-02)*S168+(-2.533941e-01)*S169'
.param V80_part18='V80_part17+0.000000e+00*S170+5.671718e-03*S171+(-3.141114e-01)*S172+(-2.602355e-01)*S173+(-6.746533e-01)*S174+(-8.025867e-02)*S175+0.000000e+00*S176+(-5.391107e-01)*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V80_part19='V80_part18+2.345604e-02*S180+0.000000e+00*S181+0.000000e+00*S182+(-2.534505e-01)*S183+(-2.353972e-01)*S184+(-2.134222e-01)*S185+1.430739e-01*S186+0.000000e+00*S187+(-9.955595e-02)*S188+0.000000e+00*S189'
.param V80_part20='V80_part19+0.000000e+00*S190+(-1.346728e+00)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+(-3.462826e-01)*S197+(-8.340248e-02)*S198+0.000000e+00*S199'
.param V80_part21='V80_part20+(-5.099949e-01)*S200+(-2.273005e-01)*S201+(-2.782778e-01)*S202+(-7.649762e-01)*S203+(-3.182970e-01)*S204+(-1.177611e-01)*S205+(-3.303526e-01)*S206+0.000000e+00*S207+(-1.488320e-01)*S208+(-4.932746e-01)*S209'
.param V80_part22='V80_part21+(-3.515587e-02)*S210+(-2.561700e-01)*S211+(-1.038213e+00)*S212+6.573417e-05*S213+3.719594e-02*S214+(-6.926975e-01)*S215+9.886718e-02*S216+1.962917e-01*S217+(-5.486130e-01)*S218+5.874186e-01*S219'
.param V80_part23='V80_part22+5.657724e-01*S220+(-6.835720e-01)*S221+9.429857e-02*S222+4.133032e-01*S223+0.000000e+00*S224+(-7.530101e-02)*S225+(-1.418478e-01)*S226+(-5.453822e-02)*S227+(-8.005202e-02)*S228+3.344789e-02*S229'
.param V80_part24='V80_part23+(-4.111716e-01)*S230+0.000000e+00*S231+0.000000e+00*S232+(-4.169172e-02)*S233+(-1.688030e-01)*S234+(-5.443418e-01)*S235+(-4.957113e-01)*S236+(-3.971269e-01)*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V80_part25='V80_part24+(-3.189585e-01)*S240+(-1.245079e-01)*S241+(-7.443942e-02)*S242+(-3.723596e-01)*S243+0.000000e+00*S244+(-8.331910e-01)*S245+0.000000e+00*S246+5.083938e-02*S247+(-9.905036e-01)*S248+0.000000e+00*S249'
.param V80_part26='V80_part25+(-4.208926e-02)*S250+(-1.296952e+00)*S251+(-1.480100e-01)*S252+5.281921e-01*S253+3.392310e-02*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+(-2.826955e-01)*S258+0.000000e+00*S259'
.param V80_part27='V80_part26+(-5.540168e-01)*S260+5.155249e-01*S261+0.000000e+00*S262+(-5.677742e-01)*S263+3.960908e-01*S264+(-2.652137e-01)*S265+(-6.799431e-01)*S266+8.422138e-01*S267+(-1.592921e-01)*S268+0.000000e+00*S269'
.param V80_part28='V80_part27+(-1.814950e-01)*S270+0.000000e+00*S271+1.095633e+00*S272+(-1.258840e-01)*S273+(-1.854255e-02)*S274+3.501300e-01*S275+(-2.682401e-03)*S276+(-1.772003e-02)*S277+(-6.670005e-02)*S278+0.000000e+00*S279'
.param V80_part29='V80_part28+5.644086e-01*S280+1.425697e-01*S281+0.000000e+00*S282+2.164734e-01*S283+0.000000e+00*S284+1.535280e-01*S285+0.000000e+00*S286+(-9.464120e-02)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V80_part30='V80_part29+(-7.146931e-01)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.008431e-01*S295+0.000000e+00*S296+(-1.648834e-01)*S297+(-2.003089e-01)*S298+0.000000e+00*S299'
.param V80_part31='V80_part30+2.501247e-01*S300+1.393518e-01*S301+1.728565e-01*S302+0.000000e+00*S303+3.110692e-01*S304+(-3.806761e-02)*S305+0.000000e+00*S306+2.950721e-01*S307+8.202394e-02*S308+4.022824e-01*S309'
.param V80='V80_part31+2.205479e-02*S310+6.005020e-02*S311+6.080112e-01*S312+2.533251e-01*S313+5.522779e-01*S314'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V81_part2='V81_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V81_part3='V81_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V81_part4='V81_part3+0.000000e+00*S30+0.000000e+00*S31+1.236367e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+1.231218e-01*S37+0.000000e+00*S38+1.685567e-01*S39'
.param V81_part5='V81_part4+0.000000e+00*S40+0.000000e+00*S41+2.081316e-01*S42+0.000000e+00*S43+0.000000e+00*S44+3.245666e-01*S45+3.699094e-01*S46+5.297813e-01*S47+3.764838e-01*S48+0.000000e+00*S49'
.param V81_part6='V81_part5+7.787878e-01*S50+2.656034e-01*S51+2.996388e-01*S52+2.719549e-01*S53+0.000000e+00*S54+0.000000e+00*S55+3.156847e-01*S56+2.916688e-01*S57+2.842832e-01*S58+3.366849e-01*S59'
.param V81_part7='V81_part6+4.520067e-01*S60+6.728707e-01*S61+9.417838e-01*S62+4.417052e-01*S63+5.467546e-01*S64+4.008375e-01*S65+5.058001e-01*S66+3.616752e-01*S67+2.537723e-01*S68+4.105320e-01*S69'
.param V81_part8='V81_part7+2.675082e-01*S70+4.905440e-01*S71+3.378841e-01*S72+2.999026e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V81_part9='V81_part8+1.506044e-01*S80+0.000000e+00*S81+0.000000e+00*S82+2.227578e-01*S83+1.039946e-01*S84+1.380629e-01*S85+8.171757e-02*S86+(-1.361662e-02)*S87+(-3.979312e-03)*S88+8.824639e-02*S89'
.param V81_part10='V81_part9+8.096046e-01*S90+1.107747e+00*S91+4.174802e-01*S92+7.066748e-01*S93+6.412419e-01*S94+5.244833e-01*S95+6.161267e-01*S96+2.840106e-01*S97+9.120407e-01*S98+6.190061e-01*S99'
.param V81_part11='V81_part10+6.872223e-01*S100+1.101565e+00*S101+6.254848e-01*S102+6.025380e-01*S103+9.543554e-01*S104+6.597605e-01*S105+0.000000e+00*S106+4.751473e-01*S107+5.113350e-01*S108+5.626294e-01*S109'
.param V81_part12='V81_part11+0.000000e+00*S110+0.000000e+00*S111+4.755234e-01*S112+6.170476e-01*S113+5.168245e-01*S114+5.111769e-01*S115+5.436220e-01*S116+6.043131e-01*S117+5.138334e-01*S118+7.880551e-01*S119'
.param V81_part13='V81_part12+6.622688e-01*S120+3.033125e-01*S121+5.212710e-01*S122+3.450436e-01*S123+3.082277e-01*S124+6.380698e-01*S125+3.790480e-01*S126+6.110726e-01*S127+7.648841e-01*S128+5.193007e-01*S129'
.param V81_part14='V81_part13+6.024731e-01*S130+9.245634e-01*S131+5.254817e-01*S132+6.917898e-01*S133+7.219872e-01*S134+8.730895e-01*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V81_part15='V81_part14+2.173741e-01*S140+2.394412e-01*S141+0.000000e+00*S142+3.177382e-01*S143+2.869368e-01*S144+3.074718e-01*S145+5.099443e-01*S146+3.690890e-01*S147+4.152653e-01*S148+5.877281e-01*S149'
.param V81_part16='V81_part15+2.370860e-01*S150+4.255417e-01*S151+1.124092e+00*S152+6.301830e-01*S153+4.658512e-01*S154+1.417313e+00*S155+7.629212e-01*S156+8.261494e-01*S157+8.347730e-01*S158+8.465350e-01*S159'
.param V81_part17='V81_part16+7.381739e-01*S160+9.485669e-01*S161+0.000000e+00*S162+0.000000e+00*S163+4.853517e-01*S164+2.597114e-01*S165+0.000000e+00*S166+1.028043e+00*S167+4.796985e-01*S168+6.361283e-01*S169'
.param V81_part18='V81_part17+0.000000e+00*S170+4.017909e-01*S171+8.169756e-01*S172+1.078480e+00*S173+5.861232e-01*S174+8.134330e-01*S175+0.000000e+00*S176+6.471766e-01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V81_part19='V81_part18+3.394338e-01*S180+0.000000e+00*S181+0.000000e+00*S182+6.505206e-01*S183+6.629699e-01*S184+6.292615e-01*S185+4.176610e-01*S186+0.000000e+00*S187+4.922827e-01*S188+0.000000e+00*S189'
.param V81_part20='V81_part19+0.000000e+00*S190+1.045299e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+6.994054e-01*S197+2.495002e-01*S198+0.000000e+00*S199'
.param V81_part21='V81_part20+8.395615e-01*S200+3.929596e-01*S201+5.074279e-01*S202+1.082187e+00*S203+5.164864e-01*S204+3.612553e-01*S205+1.015662e-01*S206+0.000000e+00*S207+5.218892e-01*S208+6.847931e-01*S209'
.param V81_part22='V81_part21+4.787123e-01*S210+5.962455e-01*S211+1.618967e+00*S212+5.754449e-01*S213+6.586681e-01*S214+8.132178e-01*S215+5.890924e-01*S216+4.303994e-01*S217+6.404095e-01*S218+6.466830e-01*S219'
.param V81_part23='V81_part22+2.159944e-01*S220+3.796666e-01*S221+7.125337e-01*S222+6.260291e-01*S223+0.000000e+00*S224+4.240393e-01*S225+5.000009e-01*S226+1.000734e+00*S227+5.284433e-01*S228+4.638594e-01*S229'
.param V81_part24='V81_part23+5.292582e-01*S230+0.000000e+00*S231+0.000000e+00*S232+(-3.914282e-03)*S233+4.602430e-01*S234+3.482247e-01*S235+1.434318e-01*S236+5.909147e-01*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V81_part25='V81_part24+4.370329e-01*S240+7.604249e-01*S241+7.158683e-01*S242+8.132717e-01*S243+0.000000e+00*S244+1.141292e+00*S245+0.000000e+00*S246+6.169229e-01*S247+1.087749e+00*S248+0.000000e+00*S249'
.param V81_part26='V81_part25+5.555371e-01*S250+6.170579e-01*S251+5.378425e-01*S252+(-2.421124e-01)*S253+(-2.013037e-01)*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+4.620053e-01*S258+0.000000e+00*S259'
.param V81_part27='V81_part26+1.296256e+00*S260+7.455422e-01*S261+0.000000e+00*S262+6.491913e-01*S263+8.761180e-01*S264+2.935450e-01*S265+6.959976e-01*S266+5.816681e-01*S267+(-3.163631e-02)*S268+0.000000e+00*S269'
.param V81_part28='V81_part27+4.250836e-01*S270+0.000000e+00*S271+9.242480e-02*S272+4.663768e-01*S273+7.345721e-01*S274+(-1.149144e-01)*S275+4.223357e-01*S276+(-1.959481e-02)*S277+7.019949e-02*S278+0.000000e+00*S279'
.param V81_part29='V81_part28+7.425634e-01*S280+(-1.931916e-01)*S281+0.000000e+00*S282+9.993242e-02*S283+0.000000e+00*S284+2.742151e-01*S285+0.000000e+00*S286+(-2.628304e-01)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V81_part30='V81_part29+1.673307e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.138448e+00*S295+0.000000e+00*S296+1.475570e+00*S297+7.780430e-01*S298+0.000000e+00*S299'
.param V81_part31='V81_part30+6.895501e-01*S300+5.784134e-01*S301+6.797045e-01*S302+0.000000e+00*S303+5.941197e-01*S304+3.157288e-01*S305+0.000000e+00*S306+(-1.843650e-01)*S307+2.027828e-01*S308+7.135802e-01*S309'
.param V81='V81_part31+(-9.444597e-01)*S310+(-3.266347e-01)*S311+1.019122e+00*S312+7.359270e-01*S313+(-2.823108e-01)*S314'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V82_part2='V82_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V82_part3='V82_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V82_part4='V82_part3+0.000000e+00*S30+0.000000e+00*S31+4.294627e-01*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+9.849126e-02*S37+0.000000e+00*S38+2.081594e-01*S39'
.param V82_part5='V82_part4+0.000000e+00*S40+0.000000e+00*S41+4.187213e-01*S42+0.000000e+00*S43+0.000000e+00*S44+7.413786e-02*S45+9.119155e-02*S46+2.323215e-01*S47+1.443435e-01*S48+0.000000e+00*S49'
.param V82_part6='V82_part5+5.218003e-01*S50+1.188000e-01*S51+1.744790e-01*S52+3.344846e-01*S53+0.000000e+00*S54+0.000000e+00*S55+3.442977e-01*S56+2.474124e-01*S57+2.473952e-01*S58+4.780123e-01*S59'
.param V82_part7='V82_part6+5.356848e-02*S60+1.409736e-01*S61+1.700584e-01*S62+1.154201e-01*S63+1.932011e-01*S64+1.967168e-01*S65+1.419753e-01*S66+1.187822e-01*S67+2.348645e-02*S68+1.042421e-01*S69'
.param V82_part8='V82_part7+(-3.880502e-03)*S70+3.455617e-01*S71+2.623800e-01*S72+2.022719e-01*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V82_part9='V82_part8+9.833449e-02*S80+0.000000e+00*S81+0.000000e+00*S82+6.249685e-02*S83+1.153366e-02*S84+1.649864e-02*S85+5.983266e-02*S86+(-2.425153e-04)*S87+1.822063e-02*S88+5.072668e-02*S89'
.param V82_part10='V82_part9+5.886400e-01*S90+9.613213e-01*S91+1.066279e-01*S92+9.339209e-01*S93+9.319168e-01*S94+3.126050e-01*S95+9.297124e-01*S96+1.809143e-01*S97+6.470184e-01*S98+9.887865e-01*S99'
.param V82_part11='V82_part10+1.228507e+00*S100+7.263209e-01*S101+1.052942e+00*S102+1.403958e+00*S103+2.028939e+00*S104+4.613817e-01*S105+0.000000e+00*S106+2.488814e-01*S107+6.659308e-01*S108+5.906962e-01*S109'
.param V82_part12='V82_part11+0.000000e+00*S110+0.000000e+00*S111+6.845556e-01*S112+3.699411e-01*S113+7.796873e-01*S114+7.896440e-01*S115+4.808896e-01*S116+8.249586e-01*S117+8.438778e-01*S118+1.271983e+00*S119'
.param V82_part13='V82_part12+3.221442e-01*S120+1.341086e-01*S121+2.007757e-01*S122+4.163131e-01*S123+1.445771e-01*S124+2.799384e-01*S125+3.782999e-01*S126+5.115154e-01*S127+3.802295e-01*S128+5.786582e-01*S129'
.param V82_part14='V82_part13+5.610283e-01*S130+1.005468e+00*S131+2.401426e-01*S132+6.766184e-01*S133+9.079305e-01*S134+(-4.034255e-02)*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V82_part15='V82_part14+4.741945e-02*S140+7.146550e-02*S141+0.000000e+00*S142+1.201791e-01*S143+1.522002e-01*S144+1.933388e-01*S145+2.372980e-01*S146+2.415769e-01*S147+3.697279e-01*S148+3.174020e-01*S149'
.param V82_part16='V82_part15+5.605776e-01*S150+1.041214e+00*S151+7.262083e-01*S152+1.045005e+00*S153+1.276710e+00*S154+9.072028e-01*S155+1.399191e+00*S156+1.533109e+00*S157+7.648542e-01*S158+1.437059e+00*S159'
.param V82_part17='V82_part16+1.472444e+00*S160+2.741023e+00*S161+0.000000e+00*S162+0.000000e+00*S163+2.434180e+00*S164+1.704685e-01*S165+0.000000e+00*S166+1.393793e+00*S167+9.374862e-01*S168+8.861749e-01*S169'
.param V82_part18='V82_part17+0.000000e+00*S170+5.158717e-01*S171+1.156476e+00*S172+1.021900e+00*S173+1.726145e+00*S174+1.137403e+00*S175+0.000000e+00*S176+3.778177e-01*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V82_part19='V82_part18+5.239947e-01*S180+0.000000e+00*S181+0.000000e+00*S182+1.156983e+00*S183+7.327490e-01*S184+1.656596e-01*S185+5.639202e-01*S186+0.000000e+00*S187+7.088568e-01*S188+0.000000e+00*S189'
.param V82_part20='V82_part19+0.000000e+00*S190+1.223354e+00*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+2.264703e-01*S197+2.092458e-01*S198+0.000000e+00*S199'
.param V82_part21='V82_part20+3.459710e-01*S200+3.393188e-01*S201+2.937034e-01*S202+5.496254e-01*S203+3.204802e-01*S204+2.477824e-01*S205+1.161373e+00*S206+0.000000e+00*S207+6.104637e-01*S208+9.704654e-01*S209'
.param V82_part22='V82_part21+1.402518e+00*S210+1.505547e+00*S211+1.089793e+00*S212+1.182569e+00*S213+1.631807e+00*S214+1.976872e+00*S215+1.429211e+00*S216+9.826525e-01*S217+1.954130e+00*S218+(-1.589376e+00)*S219'
.param V82_part23='V82_part22+9.238898e-01*S220+2.286638e+00*S221+1.345643e+00*S222+9.357548e-01*S223+0.000000e+00*S224+1.013846e+00*S225+1.067298e+00*S226+5.215480e-01*S227+6.706559e-01*S228+9.547112e-01*S229'
.param V82_part24='V82_part23+1.022179e+00*S230+0.000000e+00*S231+0.000000e+00*S232+5.517279e-01*S233+6.730157e-01*S234+1.407061e+00*S235+1.089278e+00*S236+9.923291e-01*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V82_part25='V82_part24+1.028970e+00*S240+8.793649e-01*S241+1.245961e+00*S242+6.663217e-01*S243+0.000000e+00*S244+1.142698e+00*S245+0.000000e+00*S246+5.500566e-01*S247+1.038546e+00*S248+0.000000e+00*S249'
.param V82_part26='V82_part25+5.038369e-01*S250+1.782164e+00*S251+5.817855e-01*S252+9.660379e-01*S253+5.687678e-01*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+6.082613e-01*S258+0.000000e+00*S259'
.param V82_part27='V82_part26+1.228183e+00*S260+4.864941e-01*S261+0.000000e+00*S262+1.030779e+00*S263+5.521459e-01*S264+5.344052e-01*S265+8.294697e-01*S266+(-7.305623e-01)*S267+6.695465e-01*S268+0.000000e+00*S269'
.param V82_part28='V82_part27+7.806322e-01*S270+0.000000e+00*S271+(-9.490452e-01)*S272+6.861743e-01*S273+1.900900e+00*S274+5.588344e-01*S275+3.821069e-01*S276+1.025712e+00*S277+5.927724e-01*S278+0.000000e+00*S279'
.param V82_part29='V82_part28+(-1.096436e-02)*S280+5.130585e-01*S281+0.000000e+00*S282+1.420132e+00*S283+0.000000e+00*S284+(-4.367922e-02)*S285+0.000000e+00*S286+1.550295e+00*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V82_part30='V82_part29+1.604504e+00*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.657710e-01*S295+0.000000e+00*S296+4.213897e-02*S297+4.164237e-01*S298+0.000000e+00*S299'
.param V82_part31='V82_part30+1.000081e+00*S300+1.007665e+00*S301+1.140458e+00*S302+0.000000e+00*S303+1.027166e+00*S304+1.702899e-01*S305+0.000000e+00*S306+1.357223e+00*S307+2.006415e-01*S308+4.503025e-01*S309'
.param V82='V82_part31+2.547694e+00*S310+8.270846e-01*S311+(-6.418943e-01)*S312+7.035580e-01*S313+2.591579e-01*S314'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V83_part2='V83_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V83_part3='V83_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V83_part4='V83_part3+0.000000e+00*S30+0.000000e+00*S31+5.448608e-02*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.143097e-02)*S37+0.000000e+00*S38+(-1.970011e-02)*S39'
.param V83_part5='V83_part4+0.000000e+00*S40+0.000000e+00*S41+(-5.724874e-02)*S42+0.000000e+00*S43+0.000000e+00*S44+2.875147e-02*S45+4.791717e-02*S46+4.388913e-02*S47+3.315388e-02*S48+0.000000e+00*S49'
.param V83_part6='V83_part5+4.429842e-02*S50+4.322970e-02*S51+2.346033e-02*S52+2.275368e-02*S53+0.000000e+00*S54+0.000000e+00*S55+6.404811e-02*S56+4.400410e-02*S57+6.169975e-02*S58+1.321991e-01*S59'
.param V83_part7='V83_part6+2.941494e-02*S60+4.583702e-02*S61+(-1.411628e-02)*S62+7.822389e-03*S63+2.470738e-02*S64+(-1.237853e-02)*S65+(-5.500631e-02)*S66+2.240552e-02*S67+2.485592e-02*S68+(-5.089685e-02)*S69'
.param V83_part8='V83_part7+5.139447e-02*S70+7.643980e-02*S71+(-3.132357e-02)*S72+3.419689e-02*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V83_part9='V83_part8+1.493924e-01*S80+0.000000e+00*S81+0.000000e+00*S82+8.204434e-02*S83+7.043441e-02*S84+7.462068e-02*S85+1.145220e-01*S86+6.657534e-02*S87+9.649243e-02*S88+1.062844e-01*S89'
.param V83_part10='V83_part9+(-9.218666e-03)*S90+1.019848e-01*S91+6.565669e-02*S92+(-4.020205e-02)*S93+1.525419e-01*S94+1.042954e-01*S95+(-1.710837e-02)*S96+3.974864e-02*S97+3.116329e-01*S98+1.012976e-02*S99'
.param V83_part11='V83_part10+4.846285e-02*S100+2.930271e-01*S101+6.562446e-02*S102+1.018458e-01*S103+6.441124e-02*S104+(-2.042052e-03)*S105+0.000000e+00*S106+1.059248e-01*S107+3.543834e-03*S108+4.087608e-02*S109'
.param V83_part12='V83_part11+0.000000e+00*S110+0.000000e+00*S111+1.286222e-01*S112+1.954107e-01*S113+2.493594e-01*S114+2.674342e-01*S115+1.880711e-01*S116+2.423824e-01*S117+2.667419e-01*S118+2.124612e-01*S119'
.param V83_part13='V83_part12+8.452894e-02*S120+1.044426e-01*S121+8.676726e-02*S122+5.662025e-02*S123+1.046729e-01*S124+7.824636e-02*S125+5.009041e-02*S126+7.974845e-02*S127+7.673303e-02*S128+1.581388e-01*S129'
.param V83_part14='V83_part13+9.700351e-02*S130+1.223294e-01*S131+9.404791e-02*S132+1.577303e-01*S133+1.392821e-01*S134+2.836001e-02*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V83_part15='V83_part14+1.795683e-01*S140+2.177175e-02*S141+0.000000e+00*S142+1.715175e-01*S143+(-4.067112e-03)*S144+(-2.922685e-04)*S145+9.324401e-02*S146+1.301832e-02*S147+(-1.881679e-02)*S148+1.531962e-01*S149'
.param V83_part16='V83_part15+1.435815e-01*S150+1.180060e-01*S151+1.573507e-01*S152+9.004445e-02*S153+1.505228e-01*S154+1.271082e-01*S155+1.311322e-01*S156+2.081638e-01*S157+1.485428e-01*S158+2.241696e-01*S159'
.param V83_part17='V83_part16+1.596022e-01*S160+1.418396e-01*S161+0.000000e+00*S162+0.000000e+00*S163+(-2.178457e-01)*S164+1.791840e-01*S165+0.000000e+00*S166+5.387849e-02*S167+1.212911e-01*S168+1.194882e-01*S169'
.param V83_part18='V83_part17+0.000000e+00*S170+1.391471e-01*S171+1.373254e-01*S172+1.256328e-01*S173+2.262551e-01*S174+1.622061e-01*S175+0.000000e+00*S176+7.787404e-02*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V83_part19='V83_part18+9.798521e-02*S180+0.000000e+00*S181+0.000000e+00*S182+1.447461e-01*S183+7.090443e-02*S184+1.415714e-01*S185+3.944902e-02*S186+0.000000e+00*S187+8.876165e-02*S188+0.000000e+00*S189'
.param V83_part20='V83_part19+0.000000e+00*S190+(-1.216037e-02)*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+3.736736e-03*S197+9.062850e-02*S198+0.000000e+00*S199'
.param V83_part21='V83_part20+2.970977e-02*S200+4.881620e-02*S201+9.675067e-02*S202+1.355306e-01*S203+2.798529e-01*S204+3.058446e-01*S205+(-1.784145e-01)*S206+0.000000e+00*S207+3.411406e-01*S208+1.985754e-01*S209'
.param V83_part22='V83_part21+9.490503e-03*S210+1.189536e-01*S211+1.049178e-01*S212+1.051394e-01*S213+1.051496e-01*S214+9.115415e-02*S215+2.052948e-01*S216+1.013299e-01*S217+(-4.318288e-02)*S218+(-1.163045e-02)*S219'
.param V83_part23='V83_part22+2.318581e-02*S220+(-2.046776e-01)*S221+8.435911e-02*S222+7.634416e-02*S223+0.000000e+00*S224+9.275645e-02*S225+6.532236e-02*S226+4.700698e-02*S227+2.137419e-01*S228+(-6.126934e-02)*S229'
.param V83_part24='V83_part23+(-2.079001e-02)*S230+0.000000e+00*S231+0.000000e+00*S232+(-3.313389e-02)*S233+1.072497e-02*S234+2.218150e-02*S235+(-1.226352e-01)*S236+(-1.415331e-01)*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V83_part25='V83_part24+1.211856e-01*S240+1.210175e-01*S241+5.190168e-02*S242+2.210029e-01*S243+0.000000e+00*S244+5.586556e-03*S245+0.000000e+00*S246+(-2.652126e-03)*S247+(-5.028246e-02)*S248+0.000000e+00*S249'
.param V83_part26='V83_part25+(-2.795096e-02)*S250+9.127393e-02*S251+(-9.648134e-02)*S252+7.559514e-02*S253+3.028224e-02*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+4.567428e-02*S258+0.000000e+00*S259'
.param V83_part27='V83_part26+1.946301e-01*S260+3.388802e-01*S261+0.000000e+00*S262+8.370070e-02*S263+4.937747e-01*S264+(-4.990571e-02)*S265+(-1.953673e-02)*S266+4.308399e-01*S267+3.323701e-02*S268+0.000000e+00*S269'
.param V83_part28='V83_part27+1.507690e-01*S270+0.000000e+00*S271+(-1.685646e-01)*S272+6.797370e-02*S273+1.225489e-01*S274+(-1.459148e-01)*S275+(-1.042284e-01)*S276+(-1.680802e-01)*S277+(-4.409194e-01)*S278+0.000000e+00*S279'
.param V83_part29='V83_part28+1.433789e-01*S280+(-4.759645e-01)*S281+0.000000e+00*S282+7.613976e-03*S283+0.000000e+00*S284+1.109167e-01*S285+0.000000e+00*S286+2.554998e-01*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V83_part30='V83_part29+3.770290e-01*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+1.653875e-01*S295+0.000000e+00*S296+8.637595e-02*S297+1.669625e-01*S298+0.000000e+00*S299'
.param V83_part31='V83_part30+3.307254e-01*S300+1.670969e-01*S301+2.153003e-01*S302+0.000000e+00*S303+2.575472e-01*S304+(-2.874089e-01)*S305+0.000000e+00*S306+1.746316e-01*S307+(-3.842656e-01)*S308+1.817748e-01*S309'
.param V83='V83_part31+9.469093e-03*S310+(-3.381995e-01)*S311+1.854121e-01*S312+1.146332e-01*S313+(-4.768985e-01)*S314'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V84_part2='V84_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V84_part3='V84_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V84_part4='V84_part3+0.000000e+00*S30+0.000000e+00*S31+4.545691e-04*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+7.289873e-04*S37+0.000000e+00*S38+(-1.545925e-03)*S39'
.param V84_part5='V84_part4+0.000000e+00*S40+0.000000e+00*S41+(-2.698092e-03)*S42+0.000000e+00*S43+0.000000e+00*S44+2.977901e-03*S45+4.982170e-03*S46+(-1.974296e-03)*S47+(-1.974658e-02)*S48+0.000000e+00*S49'
.param V84_part6='V84_part5+(-6.557309e-02)*S50+(-2.377737e-02)*S51+(-2.695565e-02)*S52+(-1.864973e-02)*S53+0.000000e+00*S54+0.000000e+00*S55+(-2.666521e-02)*S56+(-7.333812e-02)*S57+(-5.348707e-02)*S58+(-9.465394e-02)*S59'
.param V84_part7='V84_part6+(-1.203015e-02)*S60+(-8.997021e-04)*S61+(-7.729301e-02)*S62+(-6.019921e-02)*S63+(-4.335110e-02)*S64+(-1.388103e-01)*S65+(-9.699885e-02)*S66+(-1.566412e-01)*S67+(-1.873250e-01)*S68+(-1.660840e-01)*S69'
.param V84_part8='V84_part7+(-1.784537e-01)*S70+(-2.700941e-02)*S71+(-1.285049e-01)*S72+(-1.066066e-01)*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V84_part9='V84_part8+(-1.376520e-02)*S80+0.000000e+00*S81+0.000000e+00*S82+(-3.317654e-03)*S83+(-5.116506e-03)*S84+(-1.311554e-02)*S85+(-1.032692e-02)*S86+(-8.036737e-03)*S87+(-2.946141e-02)*S88+(-2.153598e-02)*S89'
.param V84_part10='V84_part9+(-6.161055e-02)*S90+(-7.653429e-02)*S91+2.099976e-02*S92+(-1.267085e-01)*S93+(-1.235498e-01)*S94+2.471744e-02*S95+(-1.853620e-01)*S96+1.410894e-02*S97+2.843628e-02*S98+(-1.438909e-01)*S99'
.param V84_part11='V84_part10+(-1.955756e-01)*S100+3.610987e-02*S101+(-3.031882e-01)*S102+(-2.627049e-01)*S103+(-2.498590e-01)*S104+(-4.460786e-02)*S105+0.000000e+00*S106+2.304052e-02*S107+(-6.468271e-02)*S108+(-7.498239e-02)*S109'
.param V84_part12='V84_part11+0.000000e+00*S110+0.000000e+00*S111+(-1.183377e-01)*S112+4.260788e-02*S113+(-1.299627e-01)*S114+(-1.466614e-01)*S115+3.383871e-02*S116+(-2.417560e-01)*S117+(-1.903045e-01)*S118+(-2.851994e-01)*S119'
.param V84_part13='V84_part12+(-4.004580e-02)*S120+3.202934e-03*S121+1.080669e-02*S122+(-1.225113e-01)*S123+1.147084e-02*S124+3.720473e-02*S125+(-1.853046e-01)*S126+(-8.666770e-02)*S127+3.217452e-02*S128+(-1.943983e-01)*S129'
.param V84_part14='V84_part13+(-1.503207e-01)*S130+(-2.003331e-01)*S131+(-3.211768e-01)*S132+(-2.087659e-01)*S133+(-3.208482e-01)*S134+(-6.805082e-02)*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V84_part15='V84_part14+3.180246e-03*S140+2.026591e-03*S141+0.000000e+00*S142+3.127074e-03*S143+1.478282e-02*S144+5.669829e-03*S145+(-3.026726e-04)*S146+2.029285e-02*S147+2.070071e-02*S148+(-4.616127e-03)*S149'
.param V84_part16='V84_part15+(-2.005439e-02)*S150+(-8.422488e-02)*S151+8.286819e-02*S152+(-8.346592e-02)*S153+(-1.003902e-01)*S154+9.631868e-02*S155+(-1.137519e-01)*S156+(-2.838405e-01)*S157+7.105809e-02*S158+(-2.835162e-01)*S159'
.param V84_part17='V84_part16+(-3.576242e-01)*S160+(-4.377355e-01)*S161+0.000000e+00*S162+0.000000e+00*S163+(-1.952919e-01)*S164+1.035874e-02*S165+0.000000e+00*S166+(-1.664494e-01)*S167+(-1.333388e-01)*S168+(-7.579569e-02)*S169'
.param V84_part18='V84_part17+0.000000e+00*S170+(-2.069254e-01)*S171+(-1.633490e-01)*S172+(-2.377979e-01)*S173+3.416934e-02*S174+(-2.489794e-01)*S175+0.000000e+00*S176+3.623993e-02*S177+0.000000e+00*S178+0.000000e+00*S179'
.param V84_part19='V84_part18+(-7.394416e-02)*S180+0.000000e+00*S181+0.000000e+00*S182+(-4.761986e-02)*S183+(-6.409002e-02)*S184+5.907943e-02*S185+(-2.184554e-01)*S186+0.000000e+00*S187+(-1.192430e-01)*S188+0.000000e+00*S189'
.param V84_part20='V84_part19+0.000000e+00*S190+2.506986e-02*S191+0.000000e+00*S192+0.000000e+00*S193+0.000000e+00*S194+0.000000e+00*S195+0.000000e+00*S196+1.004434e-02*S197+(-9.075417e-04)*S198+0.000000e+00*S199'
.param V84_part21='V84_part20+2.212249e-02*S200+6.961507e-03*S201+1.255190e-02*S202+3.252410e-02*S203+1.434412e-03*S204+(-3.514220e-02)*S205+(-2.622560e-01)*S206+0.000000e+00*S207+(-1.249906e-01)*S208+(-1.264265e-01)*S209'
.param V84_part22='V84_part21+(-7.317242e-02)*S210+(-8.378826e-02)*S211+1.452402e-01*S212+(-1.991744e-01)*S213+(-2.365646e-01)*S214+(-2.002974e-01)*S215+(-2.033810e-01)*S216+(-2.332593e-01)*S217+(-2.460820e-01)*S218+1.169655e-02*S219'
.param V84_part23='V84_part22+(-2.060165e-01)*S220+(-2.649587e-01)*S221+(-3.058239e-01)*S222+(-2.732650e-01)*S223+0.000000e+00*S224+(-1.119828e-01)*S225+(-7.540863e-02)*S226+(-5.042821e-02)*S227+(-5.263409e-02)*S228+(-6.670451e-02)*S229'
.param V84_part24='V84_part23+8.310836e-02*S230+0.000000e+00*S231+0.000000e+00*S232+7.021641e-02*S233+(-1.616171e-03)*S234+4.686902e-02*S235+8.924006e-02*S236+(-4.710288e-02)*S237+0.000000e+00*S238+0.000000e+00*S239'
.param V84_part25='V84_part24+1.016747e-01*S240+(-9.027946e-02)*S241+(-2.030143e-01)*S242+2.969515e-02*S243+0.000000e+00*S244+1.496071e-01*S245+0.000000e+00*S246+(-8.616849e-02)*S247+1.304805e-01*S248+0.000000e+00*S249'
.param V84_part26='V84_part25+(-7.660410e-02)*S250+4.969805e-02*S251+(-1.041389e-01)*S252+(-3.772235e-01)*S253+5.631942e-02*S254+0.000000e+00*S255+0.000000e+00*S256+0.000000e+00*S257+1.783091e-02*S258+0.000000e+00*S259'
.param V84_part27='V84_part26+(-2.021990e-01)*S260+(-3.316435e-01)*S261+0.000000e+00*S262+5.970328e-02*S263+(-4.523396e-01)*S264+2.412617e-02*S265+4.990570e-02*S266+(-5.427724e-01)*S267+3.181567e-02*S268+0.000000e+00*S269'
.param V84_part28='V84_part27+6.585181e-02*S270+0.000000e+00*S271+(-2.353099e-02)*S272+9.681722e-03*S273+(-1.484802e-01)*S274+(-4.331141e-03)*S275+(-5.827660e-02)*S276+3.245382e-03*S277+1.797166e-02*S278+0.000000e+00*S279'
.param V84_part29='V84_part28+(-4.440669e-01)*S280+7.788543e-02*S281+0.000000e+00*S282+(-4.069046e-01)*S283+0.000000e+00*S284+2.128726e-02*S285+0.000000e+00*S286+(-5.189365e-02)*S287+0.000000e+00*S288+0.000000e+00*S289'
.param V84_part30='V84_part29+(-2.966969e-01)*S290+0.000000e+00*S291+0.000000e+00*S292+0.000000e+00*S293+0.000000e+00*S294+(-1.432342e-01)*S295+0.000000e+00*S296+(-3.087755e-01)*S297+(-3.635843e-01)*S298+0.000000e+00*S299'
.param V84_part31='V84_part30+(-1.732001e-01)*S300+(-1.563658e-01)*S301+(-2.705674e-01)*S302+0.000000e+00*S303+(-2.223785e-01)*S304+6.356975e-03*S305+0.000000e+00*S306+(-1.256906e-01)*S307+(-5.700696e-03)*S308+(-3.665005e-01)*S309'
.param V84='V84_part31+(-3.564442e-02)*S310+6.104510e-02*S311+(-5.513808e-01)*S312+(-4.009810e-01)*S313+5.453939e-02*S314'
.param V85_part1='6.288917e+00*S0+9.407797e+00*S1+4.564018e-01*S2+3.426281e+00*S3+2.768613e+00*S4+3.789467e+00*S5+1.821414e+01*S6+7.701814e+00*S7+5.114407e+00*S8+8.353780e+00*S9'
.param V85_part2='V85_part1+7.630980e+00*S10+6.974446e+00*S11+1.013462e+01*S12+1.145524e+01*S13+1.039787e+01*S14+0.000000e+00*S15+(-3.828691e-01)*S16+4.355642e+02*S17+4.403496e+00*S18+2.272167e+00*S19'
.param V85_part3='V85_part2+1.569732e+02*S20+4.924642e+01*S21+1.971228e+00*S22+7.488962e+00*S23+3.224557e+01*S24+8.857000e+00*S25+3.651283e+00*S26+1.138210e+01*S27+2.917227e+00*S28+3.146348e+00*S29'
.param V85_part4='V85_part3+3.825875e+02*S30+4.749931e+00*S31+0.000000e+00*S32+1.922744e+01*S33+(-2.712183e+02)*S34+5.524220e+00*S35+1.940130e+01*S36+8.009592e+00*S37+1.178697e+02*S38+8.015897e+02*S39'
.param V85_part5='V85_part4+1.943413e+01*S40+1.646372e+01*S41+2.071664e+03*S42+5.311104e+01*S43+1.984768e+01*S44+2.051610e+01*S45+1.377529e+01*S46+8.059089e+00*S47+1.148193e+01*S48+1.032544e+01*S49'
.param V85_part6='V85_part5+2.517600e+00*S50+6.005345e+00*S51+1.518412e+02*S52+6.198182e+02*S53+9.136799e+01*S54+1.000000e+04*S55+7.073836e+00*S56+5.142739e+01*S57+3.680765e+01*S58+5.302521e+00*S59'
.param V85_part7='V85_part6+(-1.033951e+00)*S60+1.918159e+01*S61+0.000000e+00*S62+9.105814e+00*S63+1.665776e+00*S64+1.162721e+03*S65+1.343105e+00*S66+0.000000e+00*S67+1.068593e+01*S68+7.714227e-01*S69'
.param V85_part8='V85_part7+0.000000e+00*S70+1.348829e+00*S71+8.239556e-01*S72+1.591474e+00*S73+4.953430e+01*S74+0.000000e+00*S75+0.000000e+00*S76+3.342893e+00*S77+1.929089e+01*S78+1.847680e+01*S79'
.param V85_part9='V85_part8+2.443687e+00*S80+(-2.925097e+01)*S81+2.120886e+00*S82+8.327345e+00*S83+3.068609e+02*S84+1.199613e+03*S85+2.003729e+01*S86+7.499511e+03*S87+5.960740e+03*S88+2.696888e+01*S89'
.param V85_part10='V85_part9+1.305525e+01*S90+7.520766e+03*S91+5.584396e+00*S92+2.459002e+00*S93+0.000000e+00*S94+4.109152e+00*S95+1.580803e+00*S96+4.739853e+02*S97+(-3.192197e-01)*S98+1.641069e+00*S99'
.param V85_part11='V85_part10+2.070958e+00*S100+(-1.825411e-01)*S101+1.718631e+00*S102+2.016790e+00*S103+(-7.453600e-03)*S104+1.927837e+01*S105+2.508611e+03*S106+4.204702e+02*S107+1.824777e+01*S108+4.419076e+00*S109'
.param V85_part12='V85_part11+8.566615e+03*S110+0.000000e+00*S111+1.514940e+03*S112+7.488046e+03*S113+7.497227e+03*S114+7.484120e+03*S115+7.464572e+03*S116+(-2.942525e-01)*S117+7.505697e+03*S118+7.182460e-01*S119'
.param V85_part13='V85_part12+2.520821e+03*S120+2.513393e+03*S121+1.946909e+03*S122+9.275098e+03*S123+2.516506e+03*S124+2.281090e+03*S125+0.000000e+00*S126+0.000000e+00*S127+9.885416e+02*S128+2.745967e+03*S129'
.param V85_part14='V85_part13+(-2.102854e-01)*S130+6.793668e-02*S131+0.000000e+00*S132+(-1.383571e-01)*S133+1.207128e+00*S134+(-3.862968e+03)*S135+3.361588e+01*S136+1.913166e+02*S137+(-6.325647e+02)*S138+(-4.162625e+03)*S139'
.param V85_part15='V85_part14+7.591579e+03*S140+4.873699e+00*S141+(-4.857536e+03)*S142+7.585461e+03*S143+8.401846e+00*S144+1.264284e+01*S145+1.452489e+03*S146+(-4.330586e+00)*S147+7.742960e+00*S148+2.027543e+01*S149'
.param V85_part16='V85_part15+6.832971e+00*S150+5.065754e+00*S151+1.659730e-02*S152+6.086988e+00*S153+4.953891e+00*S154+8.829352e-02*S155+5.860820e+00*S156+2.257041e-01*S157+2.429674e-01*S158+1.324048e+03*S159'
.param V85_part17='V85_part16+7.341577e-01*S160+6.310861e-01*S161+0.000000e+00*S162+1.282053e+00*S163+5.050444e-01*S164+9.025731e+00*S165+3.157928e+02*S166+1.091369e-01*S167+0.000000e+00*S168+(-7.408621e-02)*S169'
.param V85_part18='V85_part17+1.021339e+03*S170+1.747082e+01*S171+(-1.401059e-01)*S172+2.635006e+01*S173+7.510187e+03*S174+5.694888e+00*S175+1.776743e+01*S176+7.684891e-01*S177+1.082875e+01*S178+2.039613e+01*S179'
.param V85_part19='V85_part18+1.356203e+01*S180+1.452148e+01*S181+(-8.465642e+01)*S182+2.529138e+03*S183+6.322592e+00*S184+(-8.360987e+01)*S185+1.864528e+01*S186+3.681857e+00*S187+(-1.984879e+00)*S188+1.678486e+00*S189'
.param V85_part20='V85_part19+2.877643e+00*S190+1.385669e+01*S191+5.303450e+00*S192+2.784871e+00*S193+1.208824e+01*S194+0.000000e+00*S195+9.379831e+01*S196+1.154089e+01*S197+2.521488e+03*S198+2.501509e+03*S199'
.param V85_part21='V85_part20+9.594667e+00*S200+2.503086e+03*S201+2.516566e+03*S202+3.189689e+01*S203+(-2.556849e+02)*S204+1.544305e+01*S205+(-1.139231e+01)*S206+2.505288e+03*S207+6.960550e-01*S208+1.473568e+01*S209'
.param V85_part22='V85_part21+2.502186e+03*S210+(-5.672126e-02)*S211+7.831155e+01*S212+7.025996e+01*S213+6.310012e-01*S214+7.524694e+03*S215+1.152452e+00*S216+4.726737e+00*S217+(-1.316243e+00)*S218+1.545231e+02*S219'
.param V85_part23='V85_part22+1.981628e+00*S220+(-1.630876e+00)*S221+(-1.375877e+00)*S222+1.228503e+00*S223+3.231042e+00*S224+0.000000e+00*S225+4.367266e-02*S226+5.359558e-01*S227+1.344651e+01*S228+4.124623e+00*S229'
.param V85_part24='V85_part23+3.365748e+00*S230+7.459096e+03*S231+2.331006e+00*S232+5.529288e+00*S233+4.244301e+02*S234+5.320171e+00*S235+3.969237e+00*S236+2.770312e+03*S237+1.286907e+00*S238+1.973427e+00*S239'
.param V85_part25='V85_part24+7.507016e+03*S240+1.069023e-01*S241+1.031105e+00*S242+7.501022e+03*S243+1.105468e+01*S244+4.157690e+00*S245+7.511884e+03*S246+4.626484e+00*S247+4.336664e+00*S248+7.511559e+03*S249'
.param V85_part26='V85_part25+1.584478e+01*S250+4.032667e+00*S251+7.515484e+03*S252+3.164098e+00*S253+3.490885e+00*S254+7.531420e+03*S255+7.500990e+03*S256+3.064990e+02*S257+7.534786e+03*S258+7.520790e+03*S259'
.param V85_part27='V85_part26+2.660487e-01*S260+1.312558e+01*S261+5.039235e+00*S262+3.632628e+00*S263+6.187527e+00*S264+8.709994e+00*S265+4.719752e+00*S266+5.377839e-01*S267+6.763801e+00*S268+6.719781e+00*S269'
.param V85_part28='V85_part27+1.423656e+01*S270+3.647771e+01*S271+3.867606e+00*S272+1.196671e+01*S273+1.343388e+00*S274+3.765712e+00*S275+1.264103e+01*S276+5.051029e+00*S277+5.633833e+00*S278+5.157749e+00*S279'
.param V85_part29='V85_part28+2.161330e+03*S280+5.882316e+00*S281+(-2.821582e+00)*S282+2.347384e+00*S283+3.187777e+00*S284+6.074628e+00*S285+1.412360e+01*S286+7.460021e-01*S287+1.161956e+03*S288+8.554728e+00*S289'
.param V85_part30='V85_part29+1.100025e+01*S290+5.658123e+00*S291+3.484261e+00*S292+9.925958e+00*S293+5.006312e+00*S294+1.728340e+00*S295+1.236064e+01*S296+4.946801e+00*S297+2.164626e+00*S298+3.814801e+01*S299'
.param V85_part31='V85_part30+3.112328e+00*S300+1.469523e+03*S301+9.307080e-01*S302+1.363523e+02*S303+2.320336e+00*S304+7.135498e+00*S305+1.128019e+03*S306+1.655364e+00*S307+6.925147e+00*S308+3.319060e+00*S309'
.param V85='V85_part31+1.417183e+00*S310+5.081464e+00*S311+1.332879e+00*S312+3.199815e+00*S313+3.473699e+00*S314'
.param V86_part1='(-3.364209e+00)*S0+(-1.870796e+00)*S1+8.014275e+00*S2+6.591177e+00*S3+4.672090e+00*S4+(-9.281049e-01)*S5+(-1.491565e+01)*S6+(-6.092844e-02)*S7+(-1.148038e+00)*S8+1.619097e+00*S9'
.param V86_part2='V86_part1+7.809972e-01*S10+(-5.647053e-04)*S11+(-2.122036e+00)*S12+1.303219e-03*S13+1.437026e-03*S14+0.000000e+00*S15+6.211324e+00*S16+(-2.375366e+02)*S17+1.375366e+00*S18+7.402788e+00*S19'
.param V86_part3='V86_part2+(-8.358956e+01)*S20+7.994515e+00*S21+4.967127e+00*S22+(-6.254088e+00)*S23+(-6.797660e-01)*S24+4.228976e-01*S25+1.425887e+00*S26+6.553682e+00*S27+1.139465e+01*S28+2.325330e+00*S29'
.param V86_part4='V86_part3+(-9.627054e+02)*S30+4.861131e+00*S31+0.000000e+00*S32+2.995759e+00*S33+(-7.909155e+01)*S34+5.110715e+00*S35+(-5.182191e+00)*S36+(-1.588445e+00)*S37+(-1.048197e+01)*S38+(-1.411585e+00)*S39'
.param V86_part5='V86_part4+(-2.545322e+00)*S40+(-4.314337e-01)*S41+(-3.070330e+00)*S42+(-5.887679e+00)*S43+3.977172e-01*S44+(-2.916827e+01)*S45+(-1.683404e+01)*S46+(-5.475262e+00)*S47+(-8.464759e+00)*S48+2.273995e+00*S49'
.param V86_part6='V86_part5+(-7.869240e-02)*S50+(-1.683146e+00)*S51+(-2.540625e+00)*S52+(-1.597356e+01)*S53+(-1.260189e+02)*S54+2.373093e+03*S55+(-2.573604e+00)*S56+(-1.497387e+01)*S57+(-1.010687e+01)*S58+(-1.169794e+00)*S59'
.param V86_part7='V86_part6+6.528935e+01*S60+(-8.009871e+00)*S61+0.000000e+00*S62+8.167210e-01*S63+1.423204e+01*S64+5.912974e+02*S65+4.154844e-02*S66+0.000000e+00*S67+(-6.370810e+00)*S68+1.436466e-01*S69'
.param V86_part8='V86_part7+0.000000e+00*S70+(-3.891034e-03)*S71+2.932547e-01*S72+2.859568e-03*S73+3.647432e+00*S74+0.000000e+00*S75+0.000000e+00*S76+4.092816e-01*S77+6.166702e+00*S78+(-1.733815e-01)*S79'
.param V86_part9='V86_part8+(-2.518472e-01)*S80+9.164884e+01*S81+1.758779e+00*S82+3.371424e-01*S83+2.074672e+01*S84+8.019925e+01*S85+4.719462e+00*S86+1.427674e+01*S87+8.548063e+00*S88+(-4.763258e-01)*S89'
.param V86_part10='V86_part9+1.423092e-01*S90+(-1.112910e+01)*S91+(-1.862011e+00)*S92+7.126271e-01*S93+0.000000e+00*S94+(-1.275432e+00)*S95+4.435073e-01*S96+8.100195e-01*S97+4.272775e-01*S98+7.315273e-01*S99'
.param V86_part11='V86_part10+2.266763e-01*S100+4.107781e-01*S101+(-4.059057e-02)*S102+8.267395e-02*S103+2.705697e-01*S104+(-2.399091e+00)*S105+3.728161e+00*S106+(-4.029960e+00)*S107+(-7.192294e-01)*S108+(-1.421836e-01)*S109'
.param V86_part12='V86_part11+8.149553e+03*S110+0.000000e+00*S111+2.514290e+01*S112+9.101518e+01*S113+1.341827e+01*S114+2.057422e+01*S115+6.464288e+01*S116+3.365635e-01*S117+6.387277e+00*S118+6.315004e-01*S119'
.param V86_part13='V86_part12+(-1.220881e+01)*S120+(-8.236517e+00)*S121+(-2.089324e+00)*S122+1.000000e+04*S123+(-9.993977e+00)*S124+(-3.089927e+00)*S125+0.000000e+00*S126+0.000000e+00*S127+(-9.466287e+00)*S128+3.425395e+00*S129'
.param V86_part14='V86_part13+4.876952e-01*S130+3.238110e-01*S131+0.000000e+00*S132+4.526583e-01*S133+(-1.201840e-01)*S134+1.158061e+02*S135+1.503422e+01*S136+(-1.145009e+01)*S137+5.228803e+01*S138+(-4.158430e+01)*S139'
.param V86_part15='V86_part14+(-1.939629e+01)*S140+(-1.534490e+01)*S141+(-6.224603e+01)*S142+(-2.440792e+01)*S143+(-9.009632e+00)*S144+7.941635e-01*S145+(-5.967024e+00)*S146+(-4.278440e+01)*S147+3.082611e+00*S148+(-1.019251e+00)*S149'
.param V86_part16='V86_part15+(-2.549570e+00)*S150+(-2.727869e+00)*S151+3.736104e-01*S152+(-3.086610e+00)*S153+(-2.325168e+00)*S154+4.478566e-01*S155+(-1.629659e+00)*S156+3.092623e-01*S157+4.861756e-01*S158+1.488134e+00*S159'
.param V86_part17='V86_part16+(-2.081550e-01)*S160+(-2.324056e-01)*S161+0.000000e+00*S162+1.754114e-01*S163+(-1.558671e-01)*S164+(-2.743665e+00)*S165+(-8.541026e+01)*S166+2.887190e-01*S167+0.000000e+00*S168+6.134814e-01*S169'
.param V86_part18='V86_part17+3.911548e+01*S170+2.326428e-01*S171+5.231431e-01*S172+(-2.056725e+00)*S173+(-9.745882e-01)*S174+(-2.278383e+00)*S175+1.631906e-01*S176+(-2.035524e-01)*S177+(-5.680364e-01)*S178+4.756444e-01*S179'
.param V86_part19='V86_part18+(-1.441370e+00)*S180+8.243389e-01*S181+9.107868e+01*S182+2.228147e+00*S183+(-2.653996e+00)*S184+(-2.217301e+01)*S185+(-3.828941e+01)*S186+(-3.382048e+00)*S187+5.767076e+00*S188+(-1.155676e+00)*S189'
.param V86_part20='V86_part19+(-2.910027e+00)*S190+3.657276e+00*S191+8.303244e-01*S192+(-2.185541e+00)*S193+(-1.447603e+00)*S194+0.000000e+00*S195+9.803916e+00*S196+1.129007e+00*S197+(-5.890589e+00)*S198+1.131490e+01*S199'
.param V86_part21='V86_part20+1.442225e+00*S200+1.047932e+01*S201+(-9.700425e+00)*S202+2.136671e+00*S203+(-1.340699e+02)*S204+(-1.720848e+00)*S205+1.658875e+01*S206+(-3.403869e+00)*S207+(-5.990226e-03)*S208+4.104677e+00*S209'
.param V86_part22='V86_part21+7.196293e+00*S210+5.705570e-01*S211+(-1.055618e+00)*S212+(-3.299030e+00)*S213+(-5.268632e-02)*S214+3.276183e+01*S215+(-3.508052e-02)*S216+1.712850e+00*S217+2.903062e+00*S218+(-4.762750e+01)*S219'
.param V86_part23='V86_part22+(-9.765318e-01)*S220+2.803057e+00*S221+6.265107e-01*S222+2.950679e-01*S223+(-2.225533e+00)*S224+0.000000e+00*S225+4.669909e-01*S226+1.063437e-01*S227+8.661604e+00*S228+(-1.244413e+00)*S229'
.param V86_part24='V86_part23+(-2.740712e-01)*S230+5.390709e+01*S231+(-2.338702e+00)*S232+(-2.364561e+00)*S233+3.992986e+00*S234+(-2.183806e+00)*S235+(-1.286254e+00)*S236+(-5.875360e-01)*S237+(-3.966917e+00)*S238+(-7.704547e-01)*S239'
.param V86_part25='V86_part24+2.179568e+00*S240+6.359576e-01*S241+(-3.662956e-01)*S242+8.185276e+00*S243+(-4.994754e+00)*S244+(-6.398745e-01)*S245+(-1.370009e+01)*S246+(-1.138134e+00)*S247+(-6.546202e-01)*S248+(-9.305362e+00)*S249'
.param V86_part26='V86_part25+1.991749e+01*S250+(-1.390333e+00)*S251+(-3.370661e+00)*S252+(-6.219401e-01)*S253+(-9.714042e-01)*S254+2.538701e+01*S255+3.812411e+01*S256+5.637182e+00*S257+1.179071e+00*S258+(-3.537555e+00)*S259'
.param V86_part27='V86_part26+5.664598e-01*S260+1.764766e+00*S261+5.886074e-01*S262+(-3.161142e-01)*S263+1.014686e+00*S264+(-3.470757e+00)*S265+(-9.708416e-01)*S266+(-2.819569e+00)*S267+(-2.856975e+00)*S268+1.802235e+00*S269'
.param V86_part28='V86_part27+(-1.413345e+01)*S270+(-1.147325e+02)*S271+(-1.141417e+01)*S272+(-3.796262e+00)*S273+(-2.791396e-02)*S274+7.378192e-01*S275+(-5.127056e+00)*S276+(-1.951365e+00)*S277+1.890425e-01*S278+(-2.064534e+00)*S279'
.param V86_part29='V86_part28+6.708004e+03*S280+(-5.795059e-01)*S281+1.200578e+01*S282+2.289209e-01*S283+(-9.233496e-02)*S284+(-6.020020e+00)*S285+2.632604e+01*S286+1.776594e-01*S287+(-8.441696e+01)*S288+(-2.915219e+00)*S289'
.param V86_part30='V86_part29+(-1.371986e+01)*S290+(-2.457371e+00)*S291+(-2.476485e-01)*S292+(-2.266638e+00)*S293+(-2.002489e+00)*S294+5.791190e-01*S295+(-3.410642e+00)*S296+(-1.285870e+01)*S297+1.136801e+00*S298+(-1.671354e+01)*S299'
.param V86_part31='V86_part30+1.752321e+00*S300+(-4.849246e+00)*S301+(-1.431976e-01)*S302+(-9.858413e-01)*S303+(-4.217200e+00)*S304+(-5.867827e+00)*S305+(-2.949952e+00)*S306+(-1.674567e+00)*S307+(-4.625884e+00)*S308+(-2.338417e-01)*S309'
.param V86='V86_part31+(-1.482662e+00)*S310+(-1.104203e+00)*S311+(-2.041783e+00)*S312+(-4.745220e-01)*S313+(-2.331004e-01)*S314'
.param V87_part1='3.579334e-01*S0+(-3.222551e+00)*S1+2.422118e+00*S2+(-3.837782e+00)*S3+2.864233e-01*S4+3.168189e+00*S5+(-8.779614e+00)*S6+(-1.489977e+00)*S7+2.881042e+00*S8+(-7.165294e+00)*S9'
.param V87_part2='V87_part1+(-5.068724e+00)*S10+(-4.193348e-02)*S11+(-1.672254e+00)*S12+2.106507e+00*S13+(-2.352326e+00)*S14+0.000000e+00*S15+(-4.489476e-03)*S16+(-1.803581e+01)*S17+(-2.922743e+00)*S18+(-3.179708e+00)*S19'
.param V87_part3='V87_part2+1.388507e+01*S20+(-1.023465e+02)*S21+(-3.035263e+00)*S22+(-9.960439e-02)*S23+(-5.266558e+01)*S24+(-2.315158e+00)*S25+(-1.856900e+00)*S26+(-1.630830e+01)*S27+(-7.138662e+00)*S28+(-1.545779e+00)*S29'
.param V87_part4='V87_part3+(-8.076390e+01)*S30+(-3.881069e+00)*S31+0.000000e+00*S32+(-5.397297e+00)*S33+8.936943e+02*S34+6.995209e-01*S35+(-5.146403e+00)*S36+(-1.337160e+00)*S37+1.628235e+01*S38+(-7.888298e-01)*S39'
.param V87_part5='V87_part4+9.807711e+00*S40+2.067139e+00*S41+2.312255e+00*S42+2.382224e+01*S43+3.676068e+00*S44+(-5.342818e+00)*S45+(-5.261479e+00)*S46+(-3.053331e+00)*S47+(-4.894424e+00)*S48+5.575330e+00*S49'
.param V87_part6='V87_part5+2.668108e-03*S50+(-5.102252e+00)*S51+8.734931e+01*S52+7.047076e+00*S53+(-3.761471e+01)*S54+2.039047e+02*S55+2.525142e-01*S56+(-1.708689e+01)*S57+3.220652e+00*S58+(-2.117134e+00)*S59'
.param V87_part7='V87_part6+(-1.435770e+01)*S60+(-1.762404e+01)*S61+0.000000e+00*S62+(-1.299596e+01)*S63+(-7.473387e+00)*S64+7.595420e+02*S65+(-6.480017e-01)*S66+0.000000e+00*S67+(-3.272847e+00)*S68+1.207545e-03*S69'
.param V87_part8='V87_part7+0.000000e+00*S70+(-2.416575e-01)*S71+9.788096e-02*S72+1.674461e-01*S73+5.939240e+00*S74+0.000000e+00*S75+0.000000e+00*S76+(-3.813843e-01)*S77+(-3.643728e+00)*S78+(-2.055850e+01)*S79'
.param V87_part9='V87_part8+9.963851e-03*S80+5.699340e+01*S81+4.662312e-01*S82+1.320695e+00*S83+8.253377e+01*S84+1.315272e+01*S85+3.582853e+00*S86+1.526900e+01*S87+(-2.610116e+00)*S88+(-4.290965e-01)*S89'
.param V87_part10='V87_part9+(-1.817889e+00)*S90+(-1.985538e+01)*S91+(-2.449545e+00)*S92+(-7.260126e-01)*S93+0.000000e+00*S94+(-1.635400e+00)*S95+(-5.249720e-03)*S96+8.019997e-01*S97+2.259549e-01*S98+(-4.459113e-02)*S99'
.param V87_part11='V87_part10+(-4.498369e-01)*S100+7.964946e-02*S101+(-2.821910e-01)*S102+(-4.610911e-01)*S103+(-8.298674e-02)*S104+(-6.457549e+00)*S105+9.273916e+00*S106+5.665401e+00*S107+(-6.188146e+00)*S108+(-1.622988e+00)*S109'
.param V87_part12='V87_part11+(-8.169672e+03)*S110+0.000000e+00*S111+6.148510e+00*S112+(-1.244724e+01)*S113+3.679914e+00*S114+2.013381e+01*S115+1.457029e+01*S116+4.535565e-01*S117+(-2.706075e+00)*S118+(-8.380328e-01)*S119'
.param V87_part13='V87_part12+(-1.773167e+01)*S120+2.997997e-01*S121+5.673122e+00*S122+1.000000e+04*S123+(-9.661013e-02)*S124+5.398492e+00*S125+0.000000e+00*S126+0.000000e+00*S127+1.203228e+01*S128+9.698215e+00*S129'
.param V87_part14='V87_part13+(-6.021604e-04)*S130+(-4.830536e-02)*S131+0.000000e+00*S132+(-4.642988e-02)*S133+(-8.085329e-01)*S134+(-2.850271e+01)*S135+(-4.552425e+01)*S136+(-7.914411e+01)*S137+5.040459e+01*S138+(-8.753859e+01)*S139'
.param V87_part15='V87_part14+(-6.283537e+01)*S140+4.656192e+00*S141+(-7.544001e+01)*S142+(-5.262860e+01)*S143+1.653893e+01*S144+(-1.973730e+01)*S145+8.139438e+00*S146+7.771380e+01*S147+(-6.009587e+00)*S148+4.226079e+00*S149'
.param V87_part16='V87_part15+(-8.570735e+00)*S150+(-3.610702e+00)*S151+3.168440e-02*S152+(-4.383680e+00)*S153+(-2.842639e+00)*S154+(-5.890213e-02)*S155+(-5.611122e+00)*S156+(-2.602315e-01)*S157+(-2.285127e-01)*S158+(-2.044622e+00)*S159'
.param V87_part17='V87_part16+(-7.012481e-01)*S160+(-1.891786e-01)*S161+0.000000e+00*S162+(-1.859090e+00)*S163+(-2.345678e-01)*S164+(-1.090954e+01)*S165+1.713658e+03*S166+(-3.425930e-02)*S167+0.000000e+00*S168+(-1.381942e-01)*S169'
.param V87_part18='V87_part17+(-9.972439e+02)*S170+(-3.455309e+01)*S171+8.200184e-02*S172+(-2.112961e+01)*S173+(-8.784138e+00)*S174+(-2.457551e-01)*S175+(-1.488487e+01)*S176+(-5.055752e-01)*S177+(-1.310808e+01)*S178+(-1.813100e+01)*S179'
.param V87_part19='V87_part18+(-2.334624e+01)*S180+(-1.686434e+01)*S181+(-9.070970e+00)*S182+9.526306e+00*S183+(-2.489406e+00)*S184+(-1.616849e+02)*S185+3.826239e+01*S186+8.411970e-01*S187+8.626614e-01*S188+2.449427e+00*S189'
.param V87_part20='V87_part19+1.158850e+00*S190+(-1.190300e+01)*S191+(-4.576298e+00)*S192+8.190601e-01*S193+(-9.021832e+00)*S194+0.000000e+00*S195+1.411459e+01*S196+1.146976e+01*S197+(-1.521963e+01)*S198+1.185711e+01*S199'
.param V87_part21='V87_part20+7.209101e+00*S200+1.565767e+01*S201+1.085960e+01*S202+1.015519e+01*S203+(-1.175324e+01)*S204+(-1.542606e+01)*S205+5.678212e+00*S206+(-9.261112e-01)*S207+2.107632e+00*S208+4.891127e+00*S209'
.param V87_part22='V87_part21+(-4.256856e+00)*S210+(-1.035664e-03)*S211+(-1.464499e+01)*S212+1.973903e+01*S213+(-6.671091e-01)*S214+(-2.704602e+01)*S215+(-8.528196e-01)*S216+(-6.634762e+00)*S217+8.896044e-01*S218+(-1.083844e+02)*S219'
.param V87_part23='V87_part22+9.057611e-02*S220+9.329810e-01*S221+1.614352e+01*S222+(-4.411178e-01)*S223+(-2.108898e-01)*S224+0.000000e+00*S225+(-6.431062e-02)*S226+(-3.218553e-01)*S227+(-2.366619e-01)*S228+(-4.590067e+00)*S229'
.param V87_part24='V87_part23+(-2.182813e+00)*S230+7.160002e+01*S231+4.087202e-01*S232+(-1.948347e+00)*S233+2.696826e+01*S234+(-1.889549e+00)*S235+(-1.262345e+00)*S236+1.345215e+01*S237+8.732402e+00*S238+(-2.560987e-01)*S239'
.param V87_part25='V87_part24+(-1.157351e+01)*S240+(-2.025123e-01)*S241+(-4.795316e-01)*S242+7.334226e-03*S243+(-5.486018e+00)*S244+(-2.701217e+00)*S245+1.191075e+00*S246+(-4.646304e+00)*S247+(-2.507073e+00)*S248+(-4.724453e+00)*S249'
.param V87_part26='V87_part25+(-4.223043e+01)*S250+(-1.248537e+00)*S251+(-2.641536e+01)*S252+(-1.480128e+00)*S253+(-1.303176e+00)*S254+(-7.293077e+01)*S255+(-4.668842e+00)*S256+(-2.225035e+01)*S257+(-5.788493e+01)*S258+(-4.861502e+00)*S259'
.param V87_part27='V87_part26+(-1.180339e-01)*S260+(-1.920873e+00)*S261+(-6.746169e+00)*S262+(-2.334003e+00)*S263+(-4.249122e+00)*S264+(-4.755049e+00)*S265+(-2.395947e+00)*S266+7.267685e+00*S267+(-2.738217e+00)*S268+(-4.891430e+00)*S269'
.param V87_part28='V87_part27+(-1.184259e+01)*S270+2.734297e+01*S271+5.001114e+00*S272+(-1.157336e+01)*S273+(-5.066046e-01)*S274+(-2.065796e+00)*S275+(-1.236439e+01)*S276+(-2.964376e+00)*S277+(-3.500292e+00)*S278+(-4.535248e+00)*S279'
.param V87_part29='V87_part28+2.632639e+00*S280+(-3.699290e+00)*S281+(-5.295303e+00)*S282+(-1.927277e+00)*S283+(-1.882198e+00)*S284+(-2.940579e+00)*S285+(-2.323364e+01)*S286+(-1.125700e-01)*S287+3.992977e+02*S288+(-4.891794e+00)*S289'
.param V87_part30='V87_part29+(-5.323770e-01)*S290+(-5.029228e+00)*S291+(-2.416913e+00)*S292+(-6.983706e+00)*S293+(-3.747657e+00)*S294+(-8.134001e-01)*S295+(-8.168374e+00)*S296+3.245474e+01*S297+(-2.213942e+00)*S298+(-3.041988e+01)*S299'
.param V87_part31='V87_part30+6.953250e+00*S300+(-7.837273e+00)*S301+(-3.507919e-01)*S302+(-3.358049e+02)*S303+1.419893e+00*S304+(-8.298839e-01)*S305+(-2.812943e+03)*S306+1.712671e+00*S307+(-5.682871e-01)*S308+(-1.226724e+00)*S309'
.param V87='V87_part31+1.908277e+00*S310+(-2.693055e+00)*S311+8.568158e+00*S312+(-1.146605e+00)*S313+(-1.915913e+00)*S314'
.param V88_part1='1.232998e+01*S0+(-6.937322e-01)*S1+9.034247e+00*S2+9.840619e+00*S3+1.271633e+01*S4+1.103545e+01*S5+9.449652e+00*S6+1.500198e+01*S7+1.050213e+01*S8+1.245906e+01*S9'
.param V88_part2='V88_part1+9.192877e+00*S10+8.276429e+00*S11+9.698770e+00*S12+2.027836e+01*S13+8.973004e+00*S14+0.000000e+00*S15+3.219278e+00*S16+1.179250e+03*S17+9.246646e+00*S18+1.024832e+01*S19'
.param V88_part3='V88_part2+3.709030e+02*S20+4.776786e+00*S21+7.614980e+00*S22+4.909409e+00*S23+(-3.956463e-01)*S24+2.409987e+01*S25+7.267810e+00*S26+(-3.464081e-01)*S27+1.513557e+00*S28+6.773397e+00*S29'
.param V88_part4='V88_part3+7.995243e+01*S30+9.416008e+00*S31+0.000000e+00*S32+6.178119e+01*S33+1.138866e+02*S34+1.935957e+01*S35+4.354222e+01*S36+1.135326e+01*S37+4.326306e+02*S38+3.189199e+03*S39'
.param V88_part5='V88_part4+6.592498e+01*S40+3.822099e+01*S41+8.263106e+03*S42+2.051313e+02*S43+5.946934e+01*S44+7.789130e-01*S45+1.328162e+00*S46+2.355013e-01*S47+9.732587e-01*S48+3.582662e+01*S49'
.param V88_part6='V88_part5+5.677615e+00*S50+5.103538e-01*S51+5.784324e+02*S52+2.359254e+03*S53+(-1.100829e+01)*S54+5.423273e+03*S55+6.963309e+00*S56+7.392013e+01*S57+6.445355e+01*S58+4.187107e-02*S59'
.param V88_part7='V88_part6+1.119519e+01*S60+7.426399e+00*S61+0.000000e+00*S62+8.692310e+00*S63+4.029570e+00*S64+2.194387e+02*S65+2.974434e+00*S66+0.000000e+00*S67+1.154165e+00*S68+2.219374e+00*S69'
.param V88_part8='V88_part7+0.000000e+00*S70+1.009512e+00*S71+2.934783e+00*S72+3.508206e+00*S73+2.030911e+02*S74+0.000000e+00*S75+0.000000e+00*S76+5.999974e+00*S77+7.064311e+01*S78+(-5.312114e+00)*S79'
.param V88_part9='V88_part8+2.237771e+00*S80+(-3.713242e+01)*S81+4.795490e+00*S82+(-5.407589e+00)*S83+(-4.272095e+02)*S84+(-1.645119e+03)*S85+(-2.340432e+01)*S86+(-1.000000e+04)*S87+(-7.942092e+03)*S88+(-2.226370e+01)*S89'
.param V88_part10='V88_part9+4.347510e+01*S90+(-1.000000e+04)*S91+1.139427e+00*S92+7.561708e+00*S93+0.000000e+00*S94+(-1.909711e-01)*S95+5.345926e+00*S96+1.871270e+03*S97+1.457693e-01*S98+6.374025e+00*S99'
.param V88_part11='V88_part10+4.398119e+00*S100+1.654089e-01*S101+4.192806e+00*S102+4.112256e+00*S103+2.434331e-01*S104+5.028513e+01*S105+1.000000e+04*S106+1.628645e+03*S107+4.906113e+01*S108+7.279857e+00*S109'
.param V88_part12='V88_part11+(-1.000000e+04)*S110+0.000000e+00*S111+(-2.022208e+03)*S112+(-1.000000e+04)*S113+(-1.000000e+04)*S114+(-1.000000e+04)*S115+(-1.000000e+04)*S116+3.921120e-01*S117+(-1.000000e+04)*S118+7.522736e-02*S119'
.param V88_part13='V88_part12+1.000000e+04*S120+1.000000e+04*S121+7.747709e+03*S122+(-7.786832e+00)*S123+1.000000e+04*S124+9.074541e+03*S125+0.000000e+00*S126+0.000000e+00*S127+3.907914e+03*S128+(-3.660117e+03)*S129'
.param V88_part14='V88_part13+2.813357e-01*S130+2.246538e-01*S131+0.000000e+00*S132+3.537495e-01*S133+1.714731e-01*S134+(-4.223703e+01)*S135+(-1.055672e+01)*S136+(-1.494823e+02)*S137+(-1.979702e+01)*S138+(-1.778121e+01)*S139'
.param V88_part15='V88_part14+(-1.000000e+04)*S140+(-3.077756e+00)*S141+(-2.069495e+01)*S142+(-1.000000e+04)*S143+(-5.747084e+00)*S144+(-4.884583e+00)*S145+5.761688e+03*S146+(-6.889221e+00)*S147+(-3.066520e+00)*S148+5.954390e+01*S149'
.param V88_part16='V88_part15+(-5.565114e-02)*S150+(-3.900666e-01)*S151+1.848619e-01*S152+(-1.801432e+00)*S153+3.283429e-01*S154+2.038584e-01*S155+(-1.082630e+00)*S156+2.188504e-01*S157+2.592663e-01*S158+(-1.763257e+03)*S159'
.param V88_part17='V88_part16+2.127430e-01*S160+4.834952e-01*S161+0.000000e+00*S162+3.451879e-01*S163+3.726414e-01*S164+(-2.825775e-02)*S165+(-6.421190e+01)*S166+1.892888e-01*S167+0.000000e+00*S168+2.492875e-01*S169'
.param V88_part18='V88_part17+(-4.567361e+00)*S170+1.087981e+00*S171+4.786881e-01*S172+2.583020e-01*S173+(-1.000000e+04)*S174+(-7.286165e-01)*S175+3.506912e-01*S176+4.725207e-01*S177+8.463739e-02*S178+3.377428e-01*S179'
.param V88_part19='V88_part18+1.483001e+00*S180+5.023822e-02*S181+(-5.566422e+00)*S182+(-3.377394e+03)*S183+3.779794e+00*S184+(-1.719894e+01)*S185+(-1.188816e+00)*S186+(-4.494774e-01)*S187+1.748777e+00*S188+(-5.459328e-01)*S189'
.param V88_part20='V88_part19+2.561943e-01*S190+(-2.169166e+00)*S191+(-1.168072e+00)*S192+1.235402e-01*S193+3.522291e-01*S194+0.000000e+00*S195+3.679759e+02*S196+5.464508e+01*S197+1.000000e+04*S198+1.000000e+04*S199'
.param V88_part21='V88_part20+3.797786e+01*S200+1.000000e+04*S201+1.000000e+04*S202+1.308305e+02*S203+(-2.410489e+01)*S204+(-6.877419e-01)*S205+8.608247e+00*S206+1.000000e+04*S207+(-8.241137e-01)*S208+6.511369e+01*S209'
.param V88_part22='V88_part21+1.000000e+04*S210+2.375204e-01*S211+(-6.600148e+01)*S212+(-8.754506e+01)*S213+2.153644e-01*S214+(-1.000000e+04)*S215+(-6.029790e-01)*S216+4.655787e-01*S217+3.813379e-01*S218+(-3.013529e+00)*S219'
.param V88_part23='V88_part22+9.912957e-02*S220+1.879459e-01*S221+(-3.884274e+00)*S222+1.678052e-01*S223+(-1.412721e-01)*S224+0.000000e+00*S225+2.812892e-01*S226+1.462874e-01*S227+(-1.862533e+01)*S228+4.514748e-01*S229'
.param V88_part24='V88_part23+5.844358e-02*S230+(-1.000000e+04)*S231+3.308177e-01*S232+1.629907e-01*S233+(-5.785339e+02)*S234+3.912093e-01*S235+1.427277e-01*S236+(-3.697109e+03)*S237+4.997952e-01*S238+6.689805e-02*S239'
.param V88_part25='V88_part24+(-1.000000e+04)*S240+2.782447e-01*S241+1.891968e-01*S242+(-1.000000e+04)*S243+(-1.114850e+00)*S244+3.606786e-02*S245+(-1.000000e+04)*S246+3.848213e-01*S247+1.527613e-01*S248+(-1.000000e+04)*S249'
.param V88_part26='V88_part25+(-4.479177e+00)*S250+7.146261e-02*S251+(-1.000000e+04)*S252+2.116981e-01*S253+1.288113e-01*S254+(-1.000000e+04)*S255+(-1.000000e+04)*S256+(-3.541248e+02)*S257+(-1.000000e+04)*S258+(-1.000000e+04)*S259'
.param V88_part27='V88_part26+1.787935e-01*S260+(-1.624576e+01)*S261+(-1.289676e+00)*S262+5.471266e-02*S263+(-5.622267e+00)*S264+1.979257e-01*S265+1.514604e-01*S266+(-1.548930e+00)*S267+4.340441e-01*S268+2.841021e-01*S269'
.param V88_part28='V88_part27+5.507393e-01*S270+1.069256e+00*S271+(-3.670951e-01)*S272+2.758192e-01*S273+6.077534e-02*S274+2.236240e-01*S275+1.179893e+00*S276+3.054521e-01*S277+1.810126e-01*S278+4.634755e-01*S279'
.param V88_part29='V88_part28+(-3.108546e+03)*S280+1.460251e-01*S281+(-7.603324e-01)*S282+1.977101e-01*S283+1.059461e-01*S284+(-6.273087e-01)*S285+6.638753e-01*S286+1.120465e-01*S287+1.000000e+04*S288+4.568128e-02*S289'
.param V88_part30='V88_part29+(-1.520384e+00)*S290+4.363546e-01*S291+4.497495e-01*S292+2.410945e-01*S293+3.789073e-01*S294+8.291518e-02*S295+4.265225e-01*S296+(-2.873941e-01)*S297+6.315354e-02*S298+2.749995e+00*S299'
.param V88_part31='V88_part30+(-5.771341e+00)*S300+5.817339e+03*S301+1.793189e-01*S302+(-1.281935e+00)*S303+(-7.858104e-01)*S304+4.691286e-01*S305+(-1.247097e+00)*S306+(-4.700914e-01)*S307+3.603073e-01*S308+8.856398e-02*S309'
.param V88='V88_part31+(-1.302156e-01)*S310+7.029248e-02*S311+(-5.864062e-01)*S312+4.971626e-02*S313+5.440186e-02*S314'
.param V89_part1='(-9.128101e-02)*S0+(-1.090090e-01)*S1+3.161192e-04*S2+(-1.473234e-02)*S3+2.171466e-03*S4+2.426250e-02*S5+1.397209e-03*S6+(-2.170097e-04)*S7+7.540172e-02*S8+2.854772e-02*S9'
.param V89_part2='V89_part1+5.427134e-02*S10+(-4.995069e-04)*S11+4.205425e-02*S12+(-2.700305e-02)*S13+(-4.220417e-02)*S14+0.000000e+00*S15+(-2.250584e-03)*S16+(-5.336047e-03)*S17+(-3.014222e-02)*S18+3.427267e-02*S19'
.param V89_part3='V89_part2+7.646789e-03*S20+(-7.637488e-01)*S21+6.653274e-02*S22+3.502720e-03*S23+6.073145e-01*S24+4.702398e-02*S25+2.259485e-03*S26+4.216792e-01*S27+(-2.271134e-01)*S28+7.137332e-03*S29'
.param V89_part4='V89_part3+(-6.432417e-01)*S30+1.191013e-01*S31+0.000000e+00*S32+3.630075e-01*S33+(-2.363310e+00)*S34+1.522221e-01*S35+6.010150e-01*S36+4.035770e-01*S37+1.368768e+00*S38+9.474170e-01*S39'
.param V89_part5='V89_part4+6.658802e-01*S40+2.429769e-01*S41+8.127904e-01*S42+7.350298e-01*S43+3.274253e-01*S44+1.011925e+00*S45+5.657305e-01*S46+2.282826e-01*S47+2.077596e+00*S48+4.826779e-02*S49'
.param V89_part6='V89_part5+3.128116e-01*S50+4.952723e-01*S51+(-1.425669e+01)*S52+(-5.996142e+00)*S53+1.739050e+02*S54+2.829037e+03*S55+6.235254e-01*S56+(-3.016296e+00)*S57+(-2.302977e+00)*S58+2.015799e-01*S59'
.param V89_part7='V89_part6+1.713773e+00*S60+2.163703e-02*S61+0.000000e+00*S62+4.423065e-01*S63+3.561360e+00*S64+1.507441e+02*S65+5.985094e-02*S66+0.000000e+00*S67+2.449914e+00*S68+1.642012e-02*S69'
.param V89_part8='V89_part7+0.000000e+00*S70+5.694764e-02*S71+9.629754e-02*S72+2.508077e-01*S73+2.163292e-01*S74+0.000000e+00*S75+0.000000e+00*S76+8.133509e-02*S77+4.270674e-01*S78+8.631793e-02*S79'
.param V89_part9='V89_part8+3.221493e-01*S80+9.077940e+00*S81+2.444284e-01*S82+8.829437e-01*S83+8.905748e+00*S84+8.805592e+00*S85+1.735378e+00*S86+3.191159e+00*S87+4.313357e+00*S88+2.076649e+00*S89'
.param V89_part10='V89_part9+2.250199e-01*S90+8.450655e+00*S91+(-4.991570e-02)*S92+7.743682e-02*S93+0.000000e+00*S94+(-4.512585e-02)*S95+6.128699e-02*S96+6.729069e-01*S97+1.914375e-02*S98+3.432504e-02*S99'
.param V89_part11='V89_part10+8.149039e-02*S100+1.517988e-02*S101+(-2.707574e-03)*S102+2.516209e-02*S103+4.771722e-02*S104+2.766704e-03*S105+(-1.028609e-01)*S106+(-8.137067e-01)*S107+4.157420e-02*S108+1.937044e-01*S109'
.param V89_part12='V89_part11+8.629885e+03*S110+0.000000e+00*S111+1.337191e+00*S112+1.502005e+01*S113+(-2.607287e+00)*S114+6.983663e-01*S115+1.230613e+01*S116+2.990571e-03*S117+3.952106e+00*S118+2.171067e-02*S119'
.param V89_part13='V89_part12+(-3.905352e+00)*S120+(-2.277871e-01)*S121+(-1.009137e+00)*S122+(-1.000000e+04)*S123+(-3.499317e-01)*S124+(-1.939541e+00)*S125+0.000000e+00*S126+0.000000e+00*S127+(-1.338674e+00)*S128+2.078732e+00*S129'
.param V89_part14='V89_part13+(-9.769876e-03)*S130+2.061971e-02*S131+0.000000e+00*S132+7.963233e-03*S133+(-9.344569e-04)*S134+7.830771e+03*S135+2.625324e+01*S136+4.219344e+01*S137+1.303131e+03*S138+8.559548e+03*S139'
.param V89_part15='V89_part14+(-3.536079e-01)*S140+3.872360e+01*S141+1.000000e+04*S142+2.927321e-01*S143+2.009186e+01*S144+2.949930e+01*S145+(-2.479556e-01)*S146+9.749608e+01*S147+3.823521e+00*S148+(-1.192976e-01)*S149'
.param V89_part16='V89_part15+(-3.448019e-01)*S150+(-1.521707e-01)*S151+1.700729e-02*S152+(-5.406211e-01)*S153+(-3.748654e-01)*S154+1.934938e-02*S155+(-1.120600e-01)*S156+(-9.478348e-03)*S157+2.275536e-02*S158+(-5.016624e-01)*S159'
.param V89_part17='V89_part16+(-2.202436e-02)*S160+(-3.023760e-02)*S161+0.000000e+00*S162+5.229309e-03*S163+2.278477e-02*S164+(-1.147844e-01)*S165+1.767557e+01*S166+5.200499e-02*S167+0.000000e+00*S168+4.789433e-02*S169'
.param V89_part18='V89_part17+9.769703e-01*S170+5.706248e-01*S171+1.218328e-02*S172+(-2.319218e-02)*S173+4.673817e-01*S174+(-4.862247e-01)*S175+2.190311e-01*S176+1.834009e-02*S177+1.796824e+00*S178+1.802516e-02*S179'
.param V89_part19='V89_part18+(-3.078438e-01)*S180+5.046947e+00*S181+1.956761e+02*S182+1.270600e+00*S183+(-4.966229e-01)*S184+6.173369e+02*S185+7.116564e+00*S186+1.057316e+00*S187+3.179377e+00*S188+7.166069e-01*S189'
.param V89_part20='V89_part19+6.239935e-01*S190+7.720702e+00*S191+(-3.726924e-01)*S192+5.602536e-01*S193+2.666915e+00*S194+0.000000e+00*S195+(-8.698345e-01)*S196+9.400748e-02*S197+(-5.276031e-01)*S198+(-4.651852e-01)*S199'
.param V89_part21='V89_part20+1.494430e-01*S200+(-4.274582e-01)*S201+(-1.519686e+00)*S202+5.835006e-02*S203+8.253907e+02*S204+4.850383e+00*S205+2.407413e+00*S206+1.769024e-01*S207+6.405771e+00*S208+1.553998e+00*S209'
.param V89_part22='V89_part21+(-1.969550e-01)*S210+6.292591e-02*S211+(-1.022834e-01)*S212+2.149591e+00*S213+(-4.095441e-02)*S214+3.692741e+00*S215+1.946879e-02*S216+1.418154e+00*S217+1.285980e+00*S218+(-3.854090e+01)*S219'
.param V89_part23='V89_part22+6.799196e-02*S220+1.330086e+00*S221+2.511125e+00*S222+(-1.392563e-02)*S223+2.732459e-01*S224+0.000000e+00*S225+5.829798e-02*S226+3.063664e-02*S227+1.846472e+00*S228+7.136670e-02*S229'
.param V89_part24='V89_part23+(-3.320655e-03)*S230+3.034749e+00*S231+5.147385e-01*S232+(-2.377445e-01)*S233+1.394796e+01*S234+(-2.515241e-01)*S235+(-1.172218e-01)*S236+1.441393e+01*S237+9.847413e-01*S238+6.049471e-02*S239'
.param V89_part25='V89_part24+(-9.655227e-01)*S240+4.493212e-02*S241+2.346317e-02*S242+2.586024e+00*S243+6.005302e-02*S244+(-4.676230e-02)*S245+2.318451e+00*S246+1.202253e-01*S247+(-8.762467e-02)*S248+9.593458e+00*S249'
.param V89_part26='V89_part25+1.778872e+01*S250+(-1.912981e-01)*S251+1.064805e+01*S252+(-8.221889e-02)*S253+(-8.460186e-02)*S254+2.891255e+00*S255+4.068639e+00*S256+3.013437e+00*S257+(-1.142159e+00)*S258+2.799312e+00*S259'
.param V89_part27='V89_part26+3.255887e-02*S260+2.212978e-01*S261+1.846712e+00*S262+(-6.681949e-02)*S263+4.762136e-01*S264+(-5.738222e-01)*S265+(-1.504213e-01)*S266+6.923546e+00*S267+(-2.447963e-01)*S268+(-4.665589e-01)*S269'
.param V89_part28='V89_part27+(-8.212170e-01)*S270+7.642659e+00*S271+4.664919e-02*S272+(-1.169723e+00)*S273+1.133187e-01*S274+(-6.197737e-02)*S275+(-8.007984e-01)*S276+(-2.257169e-01)*S277+(-1.739222e-01)*S278+8.680075e-02*S279'
.param V89_part29='V89_part28+6.639582e+01*S280+2.902497e-02*S281+(-4.614561e-01)*S282+(-4.338960e-02)*S283+1.433526e-02*S284+4.723132e-02*S285+8.022554e-01*S286+7.705339e-02*S287+2.582808e+03*S288+(-3.967554e-01)*S289'
.param V89_part30='V89_part29+5.285351e-01*S290+1.814018e-01*S291+(-4.402754e-02)*S292+1.499058e+00*S293+1.914571e-01*S294+(-1.608042e-01)*S295+1.944978e+00*S296+2.793669e+00*S297+(-1.142053e-01)*S298+3.032877e+01*S299'
.param V89_part31='V89_part30+3.323246e-01*S300+(-1.004851e-01)*S301+9.155618e-02*S302+1.196323e+00*S303+7.910101e-01*S304+1.754179e-02*S305+1.607642e+00*S306+4.354221e-01*S307+(-2.365314e-01)*S308+(-1.336051e-01)*S309'
.param V89='V89_part31+2.944933e-01*S310+3.366415e-02*S311+1.297361e+00*S312+(-2.294854e-01)*S313+(-3.411117e-03)*S314'
.param V90_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V90_part2='V90_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+3.840418e-02*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V90_part3='V90_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V90_part4='V90_part3+1.875269e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+1.062746e-01*S34+0.000000e+00*S35+0.000000e+00*S36+(-5.311633e-02)*S37+0.000000e+00*S38+(-2.981586e-02)*S39'
.param V90_part5='V90_part4+(-1.625853e-01)*S40+(-1.188295e-01)*S41+(-2.699697e-02)*S42+1.200480e-01*S43+(-4.077777e-01)*S44+2.465204e-01*S45+1.940523e-01*S46+2.573159e-02*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V90_part6='V90_part5+0.000000e+00*S50+2.244757e-01*S51+1.073262e-01*S52+(-7.637992e-03)*S53+(-1.085437e-01)*S54+0.000000e+00*S55+4.519965e-02*S56+2.795833e-01*S57+2.671374e-01*S58+(-5.875613e-02)*S59'
.param V90_part7='V90_part6+0.000000e+00*S60+0.000000e+00*S61+3.867243e-01*S62+0.000000e+00*S63+0.000000e+00*S64+1.948184e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V90_part8='V90_part7+1.000000e+04*S70+8.841254e-01*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.157592e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V90_part9='V90_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+1.588812e-01*S84+0.000000e+00*S85+2.472021e-01*S86+2.171236e-01*S87+8.702729e-02*S88+1.550898e-01*S89'
.param V90_part10='V90_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+(-4.755955e-01)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V90_part11='V90_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+(-1.233601e-01)*S106+1.991604e-01*S107+0.000000e+00*S108+5.941670e-01*S109'
.param V90_part12='V90_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V90_part13='V90_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+(-1.342547e-01)*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V90_part14='V90_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V90_part15='V90_part14+(-5.105850e-02)*S140+1.827336e-01*S141+0.000000e+00*S142+(-3.041198e-02)*S143+2.371851e-01*S144+2.390248e-01*S145+0.000000e+00*S146+1.280042e-01*S147+4.180850e-01*S148+(-1.142111e-01)*S149'
.param V90_part16='V90_part15+(-2.320092e-01)*S150+(-3.145513e-02)*S151+0.000000e+00*S152+(-3.047590e-01)*S153+(-6.244457e-01)*S154+0.000000e+00*S155+1.950520e-01*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V90_part17='V90_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+1.346961e-01*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V90_part18='V90_part17+0.000000e+00*S170+(-5.697254e-01)*S171+0.000000e+00*S172+0.000000e+00*S173+6.839473e-01*S174+0.000000e+00*S175+(-1.124226e+00)*S176+2.787049e+00*S177+2.721218e-02*S178+(-1.538501e+00)*S179'
.param V90_part19='V90_part18+0.000000e+00*S180+1.720611e-01*S181+0.000000e+00*S182+0.000000e+00*S183+(-2.485539e-01)*S184+0.000000e+00*S185+0.000000e+00*S186+(-6.471419e-02)*S187+(-1.403525e-01)*S188+8.181684e-01*S189'
.param V90_part20='V90_part19+4.022375e-01*S190+2.100213e+00*S191+4.100727e-01*S192+6.997670e-01*S193+(-1.209239e+00)*S194+5.172162e+02*S195+1.361357e-01*S196+1.299450e-01*S197+0.000000e+00*S198+(-2.605516e-01)*S199'
.param V90_part21='V90_part20+(-5.958393e-02)*S200+0.000000e+00*S201+0.000000e+00*S202+(-5.147774e-01)*S203+0.000000e+00*S204+0.000000e+00*S205+7.579073e-01*S206+(-2.829706e+00)*S207+3.800607e-01*S208+(-5.993934e-01)*S209'
.param V90_part22='V90_part21+0.000000e+00*S210+0.000000e+00*S211+(-6.749744e-01)*S212+0.000000e+00*S213+0.000000e+00*S214+(-7.609414e-01)*S215+(-1.799734e+00)*S216+3.014838e-01*S217+(-1.677977e+00)*S218+0.000000e+00*S219'
.param V90_part23='V90_part22+0.000000e+00*S220+9.192502e-01*S221+1.657258e+00*S222+0.000000e+00*S223+(-4.131910e+00)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-6.500714e-01)*S228+0.000000e+00*S229'
.param V90_part24='V90_part23+0.000000e+00*S230+1.598927e+00*S231+5.542894e-01*S232+0.000000e+00*S233+8.656394e-01*S234+5.950515e-01*S235+0.000000e+00*S236+8.430919e-01*S237+2.637014e+00*S238+2.729212e+00*S239'
.param V90_part25='V90_part24+(-4.680872e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+2.733804e-01*S243+0.000000e+00*S244+0.000000e+00*S245+(-2.454691e+00)*S246+0.000000e+00*S247+0.000000e+00*S248+1.030955e+00*S249'
.param V90_part26='V90_part25+1.051530e+00*S250+0.000000e+00*S251+1.394630e+00*S252+0.000000e+00*S253+(-2.896010e+00)*S254+(-7.182779e-02)*S255+(-2.190086e-01)*S256+0.000000e+00*S257+2.450210e-01*S258+0.000000e+00*S259'
.param V90_part27='V90_part26+0.000000e+00*S260+0.000000e+00*S261+1.017395e-01*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+(-2.378901e-02)*S268+0.000000e+00*S269'
.param V90_part28='V90_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+1.032857e+00*S279'
.param V90_part29='V90_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+2.948442e+00*S284+0.000000e+00*S285+0.000000e+00*S286+0.000000e+00*S287+(-7.142471e-01)*S288+0.000000e+00*S289'
.param V90_part30='V90_part29+0.000000e+00*S290+7.775795e-01*S291+1.278987e+00*S292+(-3.129817e+00)*S293+1.101289e+00*S294+0.000000e+00*S295+(-4.492477e+00)*S296+0.000000e+00*S297+0.000000e+00*S298+(-5.569932e+00)*S299'
.param V90_part31='V90_part30+0.000000e+00*S300+(-5.875973e-02)*S301+0.000000e+00*S302+(-4.984186e-01)*S303+0.000000e+00*S304+0.000000e+00*S305+(-1.174047e+00)*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V90='V90_part31+9.932005e-01*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V91_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V91_part2='V91_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+2.447983e-01*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V91_part3='V91_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V91_part4='V91_part3+2.295675e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+5.226849e-01*S34+0.000000e+00*S35+0.000000e+00*S36+6.122244e-01*S37+0.000000e+00*S38+5.369064e-01*S39'
.param V91_part5='V91_part4+4.523902e-01*S40+3.412555e-01*S41+4.001561e-01*S42+1.248031e-01*S43+4.879358e-01*S44+6.694424e-02*S45+1.902009e-01*S46+5.009315e-01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V91_part6='V91_part5+0.000000e+00*S50+1.535216e-01*S51+2.157264e-01*S52+3.471751e-01*S53+5.313836e-01*S54+0.000000e+00*S55+2.801971e-01*S56+1.186580e-01*S57+1.288532e-01*S58+5.662669e-01*S59'
.param V91_part7='V91_part6+0.000000e+00*S60+0.000000e+00*S61+6.457379e+01*S62+0.000000e+00*S63+0.000000e+00*S64+(-6.519397e-01)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V91_part8='V91_part7+5.484414e+03*S70+(-9.401319e-02)*S71+0.000000e+00*S72+0.000000e+00*S73+1.229768e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V91_part9='V91_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+1.640012e-01*S84+0.000000e+00*S85+(-2.124036e-02)*S86+6.959687e-02*S87+1.138032e-01*S88+(-2.177751e-03)*S89'
.param V91_part10='V91_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+9.103138e-01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V91_part11='V91_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+5.452617e-01*S106+8.238356e-02*S107+0.000000e+00*S108+(-2.074013e-01)*S109'
.param V91_part12='V91_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V91_part13='V91_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+2.755380e-01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V91_part14='V91_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V91_part15='V91_part14+1.568072e-01*S140+3.125547e-03*S141+0.000000e+00*S142+1.849789e-01*S143+2.521544e-02*S144+(-9.960748e-04)*S145+0.000000e+00*S146+4.643145e-02*S147+(-7.169954e-02)*S148+2.910298e-01*S149'
.param V91_part16='V91_part15+7.918913e-01*S150+6.603775e-01*S151+0.000000e+00*S152+1.047190e+00*S153+1.530077e+00*S154+0.000000e+00*S155+3.322610e-01*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V91_part17='V91_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+3.478242e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V91_part18='V91_part17+0.000000e+00*S170+7.550009e-01*S171+0.000000e+00*S172+0.000000e+00*S173+6.204693e-01*S174+0.000000e+00*S175+2.077108e+00*S176+(-1.217618e+00)*S177+1.008965e+00*S178+2.513408e+00*S179'
.param V91_part19='V91_part18+0.000000e+00*S180+5.945191e-01*S181+0.000000e+00*S182+0.000000e+00*S183+1.173563e+00*S184+0.000000e+00*S185+0.000000e+00*S186+1.155072e+00*S187+1.615964e+00*S188+3.709267e-01*S189'
.param V91_part20='V91_part19+8.968818e-01*S190+4.325316e-01*S191+5.956822e-01*S192+5.309769e-01*S193+1.908931e+00*S194+6.781263e+01*S195+7.059376e-01*S196+5.234473e-01*S197+0.000000e+00*S198+1.322862e+00*S199'
.param V91_part21='V91_part20+5.764213e-01*S200+0.000000e+00*S201+0.000000e+00*S202+1.010076e+00*S203+0.000000e+00*S204+0.000000e+00*S205+1.259206e+00*S206+4.910108e+00*S207+6.629169e-01*S208+1.506989e+00*S209'
.param V91_part22='V91_part21+0.000000e+00*S210+0.000000e+00*S211+1.943628e+00*S212+0.000000e+00*S213+0.000000e+00*S214+1.100496e+00*S215+4.143148e+00*S216+1.504524e+00*S217+3.961684e+00*S218+0.000000e+00*S219'
.param V91_part23='V91_part22+0.000000e+00*S220+2.293787e+00*S221+6.284295e-02*S222+0.000000e+00*S223+3.954052e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+1.265821e+00*S228+0.000000e+00*S229'
.param V91_part24='V91_part23+0.000000e+00*S230+5.106390e-01*S231+4.856930e-01*S232+0.000000e+00*S233+6.716703e-01*S234+(-2.743431e-01)*S235+0.000000e+00*S236+6.114998e-01*S237+6.611885e-01*S238+(-1.386005e+00)*S239'
.param V91_part25='V91_part24+1.418555e+00*S240+0.000000e+00*S241+0.000000e+00*S242+5.942426e-01*S243+0.000000e+00*S244+0.000000e+00*S245+3.643140e+00*S246+0.000000e+00*S247+0.000000e+00*S248+1.314986e+00*S249'
.param V91_part26='V91_part25+7.444428e-01*S250+0.000000e+00*S251+5.766795e-01*S252+0.000000e+00*S253+2.363753e+00*S254+8.349442e-01*S255+1.306059e+00*S256+0.000000e+00*S257+2.409229e-01*S258+0.000000e+00*S259'
.param V91_part27='V91_part26+0.000000e+00*S260+0.000000e+00*S261+1.112970e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+2.671209e-01*S268+0.000000e+00*S269'
.param V91_part28='V91_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+3.534709e-01*S279'
.param V91_part29='V91_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+(-1.036870e+00)*S284+0.000000e+00*S285+0.000000e+00*S286+0.000000e+00*S287+1.809114e+00*S288+0.000000e+00*S289'
.param V91_part30='V91_part29+0.000000e+00*S290+3.079556e-01*S291+3.267300e-01*S292+4.016946e+00*S293+1.136099e-01*S294+0.000000e+00*S295+4.442964e+00*S296+0.000000e+00*S297+0.000000e+00*S298+4.442820e+00*S299'
.param V91_part31='V91_part30+0.000000e+00*S300+7.972388e-01*S301+0.000000e+00*S302+1.989941e+00*S303+0.000000e+00*S304+0.000000e+00*S305+2.793833e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V91='V91_part31+1.454745e+00*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V92_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V92_part2='V92_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-7.307131e-02)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V92_part3='V92_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V92_part4='V92_part3+2.528700e-01*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+2.302024e-01*S34+0.000000e+00*S35+0.000000e+00*S36+5.730624e-01*S37+0.000000e+00*S38+2.965278e-02*S39'
.param V92_part5='V92_part4+2.948564e-01*S40+2.224891e-01*S41+3.202346e-02*S42+2.518487e-01*S43+3.738631e-01*S44+(-3.160086e-01)*S45+(-1.222819e-01)*S46+1.417699e-01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V92_part6='V92_part5+0.000000e+00*S50+2.175806e-01*S51+1.881069e-01*S52+4.510575e-01*S53+6.430647e-01*S54+0.000000e+00*S55+5.458018e-01*S56+1.487201e-01*S57+2.219935e-01*S58+3.997427e-01*S59'
.param V92_part7='V92_part6+0.000000e+00*S60+0.000000e+00*S61+4.701475e+01*S62+0.000000e+00*S63+0.000000e+00*S64+2.693323e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V92_part8='V92_part7+1.561910e+02*S70+3.147716e-01*S71+0.000000e+00*S72+0.000000e+00*S73+9.084506e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V92_part9='V92_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+(-2.187886e-01)*S84+0.000000e+00*S85+(-7.881415e-02)*S86+(-1.437811e-01)*S87+(-3.659507e-02)*S88+(-8.332134e-03)*S89'
.param V92_part10='V92_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+8.612370e-01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V92_part11='V92_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+4.682267e-01*S106+1.143293e-01*S107+0.000000e+00*S108+4.381422e-01*S109'
.param V92_part12='V92_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V92_part13='V92_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+3.578173e-01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V92_part14='V92_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V92_part15='V92_part14+1.929304e-01*S140+(-6.828172e-02)*S141+0.000000e+00*S142+2.467552e-01*S143+9.040728e-03*S144+5.572512e-02*S145+0.000000e+00*S146+(-8.606333e-03)*S147+8.333899e-02*S148+5.158332e-01*S149'
.param V92_part16='V92_part15+8.171880e-01*S150+5.155713e-01*S151+0.000000e+00*S152+8.789791e-01*S153+1.106338e+00*S154+0.000000e+00*S155+1.235366e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V92_part17='V92_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+6.428788e+00*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V92_part18='V92_part17+0.000000e+00*S170+1.342773e+00*S171+0.000000e+00*S172+0.000000e+00*S173+4.467124e-01*S174+0.000000e+00*S175+1.583232e+00*S176+(-8.344976e-01)*S177+1.390418e+00*S178+1.871852e+00*S179'
.param V92_part19='V92_part18+0.000000e+00*S180+2.584465e-03*S181+0.000000e+00*S182+0.000000e+00*S183+1.419133e+00*S184+0.000000e+00*S185+0.000000e+00*S186+1.079249e+00*S187+9.150650e-01*S188+(-7.555840e-01)*S189'
.param V92_part20='V92_part19+7.099004e-01*S190+(-1.479429e-01)*S191+(-2.576762e-01)*S192+6.883631e-01*S193+1.138747e+00*S194+3.804977e+02*S195+2.806220e-01*S196+4.339040e-01*S197+0.000000e+00*S198+6.987108e-01*S199'
.param V92_part21='V92_part20+7.065593e-01*S200+0.000000e+00*S201+0.000000e+00*S202+8.985046e-01*S203+0.000000e+00*S204+0.000000e+00*S205+(-6.868577e-01)*S206+7.314065e+00*S207+2.628215e-01*S208+1.395679e+00*S209'
.param V92_part22='V92_part21+0.000000e+00*S210+0.000000e+00*S211+1.665859e+00*S212+0.000000e+00*S213+0.000000e+00*S214+2.831069e+00*S215+6.697903e+00*S216+8.051865e-01*S217+3.463922e+00*S218+0.000000e+00*S219'
.param V92_part23='V92_part22+0.000000e+00*S220+2.518171e+00*S221+7.151256e-01*S222+0.000000e+00*S223+5.457860e+00*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+2.890033e+00*S228+0.000000e+00*S229'
.param V92_part24='V92_part23+0.000000e+00*S230+1.438053e+00*S231+1.433268e+00*S232+0.000000e+00*S233+3.085899e-01*S234+(-5.728825e-02)*S235+0.000000e+00*S236+8.803471e-02*S237+(-1.893545e+00)*S238+1.230233e+00*S239'
.param V92_part25='V92_part24+3.030921e+00*S240+0.000000e+00*S241+0.000000e+00*S242+3.127895e+00*S243+0.000000e+00*S244+0.000000e+00*S245+7.226775e+00*S246+0.000000e+00*S247+0.000000e+00*S248+1.993881e+00*S249'
.param V92_part26='V92_part25+8.523099e-01*S250+0.000000e+00*S251+7.594099e-01*S252+0.000000e+00*S253+1.748474e+00*S254+1.348141e+00*S255+1.343956e+00*S256+0.000000e+00*S257+6.709802e-01*S258+0.000000e+00*S259'
.param V92_part27='V92_part26+0.000000e+00*S260+0.000000e+00*S261+2.078348e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+(-1.994344e-02)*S268+0.000000e+00*S269'
.param V92_part28='V92_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+1.198818e+00*S279'
.param V92_part29='V92_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+(-1.422989e+00)*S284+0.000000e+00*S285+0.000000e+00*S286+0.000000e+00*S287+3.705750e+00*S288+0.000000e+00*S289'
.param V92_part30='V92_part29+0.000000e+00*S290+1.009631e+00*S291+6.199388e-01*S292+3.663077e+00*S293+6.723747e-01*S294+0.000000e+00*S295+4.827713e+00*S296+0.000000e+00*S297+0.000000e+00*S298+5.969360e+00*S299'
.param V92_part31='V92_part30+0.000000e+00*S300+1.095725e+00*S301+0.000000e+00*S302+4.237778e+00*S303+0.000000e+00*S304+0.000000e+00*S305+6.142322e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V92='V92_part31+(-2.836955e+00)*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V93_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V93_part2='V93_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-2.873564e-02)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V93_part3='V93_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V93_part4='V93_part3+(-8.036628e-02)*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+(-1.076396e-01)*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.766100e-01)*S37+0.000000e+00*S38+(-8.475734e-02)*S39'
.param V93_part5='V93_part4+(-4.265290e-02)*S40+(-2.590765e-02)*S41+(-3.854775e-01)*S42+(-7.384010e-02)*S43+2.554754e-02*S44+(-4.442553e-02)*S45+(-8.951789e-02)*S46+(-9.495206e-02)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V93_part6='V93_part5+0.000000e+00*S50+(-9.138434e-02)*S51+(-8.636505e-02)*S52+(-1.538899e-01)*S53+4.737424e-03*S54+0.000000e+00*S55+(-2.013208e-01)*S56+(-1.005345e-01)*S57+(-1.273734e-01)*S58+(-2.297398e-01)*S59'
.param V93_part7='V93_part6+0.000000e+00*S60+0.000000e+00*S61+5.893919e-02*S62+0.000000e+00*S63+0.000000e+00*S64+(-1.421344e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V93_part8='V93_part7+7.305007e+02*S70+(-3.522367e-01)*S71+0.000000e+00*S72+0.000000e+00*S73+1.222736e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V93_part9='V93_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+5.909319e-02*S84+0.000000e+00*S85+2.914871e-02*S86+8.482729e-02*S87+6.683847e-02*S88+2.254281e-02*S89'
.param V93_part10='V93_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+(-3.254949e-01)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V93_part11='V93_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+2.392287e-02*S106+(-1.236099e-01)*S107+0.000000e+00*S108+(-2.231915e-01)*S109'
.param V93_part12='V93_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V93_part13='V93_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+3.667502e-03*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V93_part14='V93_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V93_part15='V93_part14+(-4.393679e-02)*S140+(-9.474870e-02)*S141+0.000000e+00*S142+(-4.426092e-02)*S143+2.336117e-02*S144+2.016132e-02*S145+0.000000e+00*S146+4.422910e-02*S147+1.379615e-01*S148+(-1.074729e-01)*S149'
.param V93_part16='V93_part15+(-1.331962e-01)*S150+(-1.527097e-01)*S151+0.000000e+00*S152+(-4.585615e-01)*S153+(-3.180646e-01)*S154+0.000000e+00*S155+(-2.185672e-01)*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V93_part17='V93_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+(-2.946756e+00)*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V93_part18='V93_part17+0.000000e+00*S170+3.586838e-02*S171+0.000000e+00*S172+0.000000e+00*S173+(-5.154207e-01)*S174+0.000000e+00*S175+5.728526e-01*S176+4.709847e-01*S177+9.975023e-01*S178+7.522578e-01*S179'
.param V93_part19='V93_part18+0.000000e+00*S180+6.900651e-02*S181+0.000000e+00*S182+0.000000e+00*S183+(-1.106358e-01)*S184+0.000000e+00*S185+0.000000e+00*S186+(-2.773601e-01)*S187+(-1.118870e+00)*S188+3.303268e-01*S189'
.param V93_part20='V93_part19+(-3.664720e-01)*S190+(-1.144220e+00)*S191+1.710699e-01*S192+(-3.760217e-01)*S193+4.111468e-01*S194+(-1.790789e+00)*S195+(-3.390054e-02)*S196+(-7.530685e-02)*S197+0.000000e+00*S198+(-2.095762e-01)*S199'
.param V93_part21='V93_part20+(-5.756202e-02)*S200+0.000000e+00*S201+0.000000e+00*S202+(-1.248542e-01)*S203+0.000000e+00*S204+0.000000e+00*S205+(-1.510732e-01)*S206+2.609334e-01*S207+(-5.300257e-01)*S208+(-4.355901e-01)*S209'
.param V93_part22='V93_part21+0.000000e+00*S210+0.000000e+00*S211+(-2.373276e-01)*S212+0.000000e+00*S213+0.000000e+00*S214+(-3.719841e-01)*S215+(-2.022570e+00)*S216+(-1.315115e+00)*S217+(-1.566453e+00)*S218+0.000000e+00*S219'
.param V93_part23='V93_part22+0.000000e+00*S220+(-2.521247e+00)*S221+(-1.977390e+00)*S222+0.000000e+00*S223+(-7.049047e-02)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-2.854278e-01)*S228+0.000000e+00*S229'
.param V93_part24='V93_part23+0.000000e+00*S230+(-7.117796e-01)*S231+(-4.832966e-01)*S232+0.000000e+00*S233+(-5.110915e-01)*S234+(-4.524329e-01)*S235+0.000000e+00*S236+(-3.085230e-01)*S237+(-9.436197e-01)*S238+(-5.888448e-01)*S239'
.param V93_part25='V93_part24+2.510256e-01*S240+0.000000e+00*S241+0.000000e+00*S242+(-3.044994e-01)*S243+0.000000e+00*S244+0.000000e+00*S245+1.392875e-01*S246+0.000000e+00*S247+0.000000e+00*S248+(-1.173343e+00)*S249'
.param V93_part26='V93_part25+(-1.138979e+00)*S250+0.000000e+00*S251+(-8.647666e-01)*S252+0.000000e+00*S253+(-3.158791e-01)*S254+7.330348e-02*S255+1.347997e-01*S256+0.000000e+00*S257+(-6.197020e-02)*S258+0.000000e+00*S259'
.param V93_part27='V93_part26+0.000000e+00*S260+0.000000e+00*S261+1.545873e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+(-2.413679e-01)*S268+0.000000e+00*S269'
.param V93_part28='V93_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+(-5.087616e-01)*S279'
.param V93_part29='V93_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+(-6.933398e-01)*S284+0.000000e+00*S285+0.000000e+00*S286+0.000000e+00*S287+8.659663e-01*S288+0.000000e+00*S289'
.param V93_part30='V93_part29+0.000000e+00*S290+(-3.672828e-01)*S291+(-6.815138e-01)*S292+8.875196e-01*S293+(-4.001821e-01)*S294+0.000000e+00*S295+1.172703e+00*S296+0.000000e+00*S297+0.000000e+00*S298+1.188069e+00*S299'
.param V93_part31='V93_part30+0.000000e+00*S300+(-2.011094e-01)*S301+0.000000e+00*S302+1.893921e+00*S303+0.000000e+00*S304+0.000000e+00*S305+2.477019e+00*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V93='V93_part31+(-2.259800e-03)*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V94_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V94_part2='V94_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-7.647506e-04)*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V94_part3='V94_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V94_part4='V94_part3+8.601153e-04*S30+0.000000e+00*S31+0.000000e+00*S32+0.000000e+00*S33+(-7.517988e-03)*S34+0.000000e+00*S35+0.000000e+00*S36+(-9.907904e-02)*S37+0.000000e+00*S38+(-1.689361e-02)*S39'
.param V94_part5='V94_part4+(-1.246496e-03)*S40+2.142524e-03*S41+(-5.034858e-03)*S42+1.710265e-03*S43+7.229212e-03*S44+(-3.034483e-02)*S45+(-2.784279e-02)*S46+(-5.009777e-02)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V94_part6='V94_part5+0.000000e+00*S50+(-1.074612e-01)*S51+(-9.456652e-02)*S52+(-1.666837e-01)*S53+(-1.200415e-01)*S54+0.000000e+00*S55+(-1.759175e-01)*S56+(-1.398949e-01)*S57+(-1.487612e-01)*S58+2.671678e-02*S59'
.param V94_part7='V94_part6+0.000000e+00*S60+0.000000e+00*S61+(-2.061854e+01)*S62+0.000000e+00*S63+0.000000e+00*S64+(-5.041706e-01)*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V94_part8='V94_part7+1.361100e+03*S70+(-2.556645e-01)*S71+0.000000e+00*S72+0.000000e+00*S73+1.655943e-02*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V94_part9='V94_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+(-4.971152e-02)*S84+0.000000e+00*S85+(-5.875444e-02)*S86+(-7.756616e-02)*S87+(-3.454165e-02)*S88+(-3.741639e-02)*S89'
.param V94_part10='V94_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+2.829311e-02*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V94_part11='V94_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+(-1.086909e-01)*S106+(-7.075362e-03)*S107+0.000000e+00*S108+(-1.064825e-01)*S109'
.param V94_part12='V94_part11+0.000000e+00*S110+0.000000e+00*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V94_part13='V94_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+1.202250e-01*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V94_part14='V94_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+0.000000e+00*S138+0.000000e+00*S139'
.param V94_part15='V94_part14+3.922245e-03*S140+(-1.286818e-02)*S141+0.000000e+00*S142+1.336659e-02*S143+(-1.165395e-02)*S144+(-4.227161e-03)*S145+0.000000e+00*S146+(-1.083251e-02)*S147+(-1.572200e-02)*S148+2.703881e-02*S149'
.param V94_part16='V94_part15+4.330984e-02*S150+(-5.469634e-02)*S151+0.000000e+00*S152+6.469846e-02*S153+1.102057e-01*S154+0.000000e+00*S155+(-8.611130e-02)*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V94_part17='V94_part16+0.000000e+00*S160+0.000000e+00*S161+0.000000e+00*S162+(-1.209980e+00)*S163+0.000000e+00*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V94_part18='V94_part17+0.000000e+00*S170+2.728498e-02*S171+0.000000e+00*S172+0.000000e+00*S173+(-3.337993e-01)*S174+0.000000e+00*S175+(-3.995424e-01)*S176+(-6.009131e-01)*S177+(-4.728458e-01)*S178+(-5.626463e-01)*S179'
.param V94_part19='V94_part18+0.000000e+00*S180+(-1.587256e-01)*S181+0.000000e+00*S182+0.000000e+00*S183+6.396649e-02*S184+0.000000e+00*S185+0.000000e+00*S186+(-2.546563e-01)*S187+(-6.203598e-02)*S188+(-2.916787e-01)*S189'
.param V94_part20='V94_part19+(-3.018190e-01)*S190+(-3.362689e-01)*S191+(-3.629418e-01)*S192+(-3.503164e-01)*S193+(-4.402323e-01)*S194+2.089117e+02*S195+(-7.599469e-03)*S196+2.201561e-02*S197+0.000000e+00*S198+2.015590e-02*S199'
.param V94_part21='V94_part20+3.903174e-02*S200+0.000000e+00*S201+0.000000e+00*S202+5.467188e-02*S203+0.000000e+00*S204+0.000000e+00*S205+(-8.868448e-02)*S206+(-5.733967e-01)*S207+(-2.836616e-01)*S208+(-2.673728e-01)*S209'
.param V94_part22='V94_part21+0.000000e+00*S210+0.000000e+00*S211+1.493794e-01*S212+0.000000e+00*S213+0.000000e+00*S214+4.952068e-02*S215+7.861253e-03*S216+2.628596e-02*S217+(-6.276674e-02)*S218+0.000000e+00*S219'
.param V94_part23='V94_part22+0.000000e+00*S220+(-1.213593e-01)*S221+4.443827e-02*S222+0.000000e+00*S223+(-4.686889e-01)*S224+0.000000e+00*S225+0.000000e+00*S226+0.000000e+00*S227+(-1.330099e-01)*S228+0.000000e+00*S229'
.param V94_part24='V94_part23+0.000000e+00*S230+(-3.572108e-01)*S231+(-2.714970e-01)*S232+0.000000e+00*S233+(-3.323546e-01)*S234+1.799736e-03*S235+0.000000e+00*S236+(-3.420084e-01)*S237+(-3.289499e-01)*S238+(-4.092814e-01)*S239'
.param V94_part25='V94_part24+(-3.634827e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+(-2.965808e-01)*S243+0.000000e+00*S244+0.000000e+00*S245+(-3.194585e-01)*S246+0.000000e+00*S247+0.000000e+00*S248+(-3.664747e-01)*S249'
.param V94_part26='V94_part25+(-1.519914e-01)*S250+0.000000e+00*S251+(-3.476048e-01)*S252+0.000000e+00*S253+2.651387e-01*S254+4.229378e-02*S255+8.277791e-02*S256+0.000000e+00*S257+6.235289e-03*S258+0.000000e+00*S259'
.param V94_part27='V94_part26+0.000000e+00*S260+0.000000e+00*S261+(-3.677246e-01)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+3.115573e-03*S268+0.000000e+00*S269'
.param V94_part28='V94_part27+0.000000e+00*S270+0.000000e+00*S271+0.000000e+00*S272+0.000000e+00*S273+0.000000e+00*S274+0.000000e+00*S275+0.000000e+00*S276+0.000000e+00*S277+0.000000e+00*S278+(-4.009634e-01)*S279'
.param V94_part29='V94_part28+0.000000e+00*S280+0.000000e+00*S281+0.000000e+00*S282+0.000000e+00*S283+1.060159e-01*S284+0.000000e+00*S285+0.000000e+00*S286+0.000000e+00*S287+(-1.985228e-01)*S288+0.000000e+00*S289'
.param V94_part30='V94_part29+0.000000e+00*S290+(-3.027878e-01)*S291+(-3.681600e-01)*S292+(-3.488274e-01)*S293+(-3.508395e-01)*S294+0.000000e+00*S295+(-4.011271e-01)*S296+0.000000e+00*S297+0.000000e+00*S298+(-4.705994e-01)*S299'
.param V94_part31='V94_part30+0.000000e+00*S300+(-1.094274e-02)*S301+0.000000e+00*S302+(-2.370380e-01)*S303+0.000000e+00*S304+0.000000e+00*S305+(-3.526884e-01)*S306+0.000000e+00*S307+0.000000e+00*S308+0.000000e+00*S309'
.param V94='V94_part31+(-1.623327e-02)*S310+0.000000e+00*S311+0.000000e+00*S312+0.000000e+00*S313+0.000000e+00*S314'
.param V95_part1='7.032116e+00*S0+8.421746e+00*S1+7.027491e+00*S2+4.608451e+00*S3+7.547158e+00*S4+5.228929e+00*S5+7.368215e+00*S6+4.057177e+00*S7+4.183219e+00*S8+4.570502e+00*S9'
.param V95_part2='V95_part1+7.776494e+00*S10+7.212054e+00*S11+8.926243e+00*S12+6.683878e+00*S13+1.056658e+01*S14+0.000000e+00*S15+7.920789e-01*S16+2.367838e+03*S17+7.588644e+00*S18+1.235486e+01*S19'
.param V95_part3='V95_part2+4.105275e+02*S20+3.855348e+00*S21+2.643705e+00*S22+1.203034e+01*S23+7.714665e+00*S24+1.547519e+02*S25+5.760550e+00*S26+1.010742e+01*S27+5.862590e+00*S28+4.499626e+00*S29'
.param V95_part4='V95_part3+1.616476e+01*S30+0.000000e+00*S31+2.263965e+01*S32+3.092248e+02*S33+1.021350e+01*S34+0.000000e+00*S35+0.000000e+00*S36+6.299174e+01*S37+4.674667e+01*S38+1.310653e+03*S39'
.param V95_part5='V95_part4+4.841284e+01*S40+2.370156e+01*S41+6.356775e+02*S42+3.927197e+00*S43+3.946064e+01*S44+1.886711e+01*S45+1.549219e+01*S46+1.142385e+01*S47+1.702972e+01*S48+0.000000e+00*S49'
.param V95_part6='V95_part5+7.852897e+00*S50+(-5.241997e+01)*S51+6.476510e+03*S52+7.362699e+00*S53+3.591214e+03*S54+(-3.211361e+03)*S55+5.876548e+00*S56+7.434019e+00*S57+6.670919e+00*S58+5.630042e+01*S59'
.param V95_part7='V95_part6+9.347290e+00*S60+4.900359e+01*S61+9.324449e+00*S62+8.106814e+00*S63+1.858607e+01*S64+5.010483e+00*S65+3.510598e+00*S66+8.596511e+02*S67+0.000000e+00*S68+3.111370e+00*S69'
.param V95_part8='V95_part7+2.512065e+03*S70+4.244430e+00*S71+4.053567e+00*S72+3.718619e+00*S73+2.528846e+01*S74+(-3.202741e+01)*S75+(-1.984348e+01)*S76+(-9.708428e-01)*S77+0.000000e+00*S78+5.883432e+01*S79'
.param V95_part9='V95_part8+2.947268e+00*S80+(-5.983097e+01)*S81+0.000000e+00*S82+7.477829e+00*S83+7.345279e+03*S84+1.008461e+03*S85+2.883521e+01*S86+7.498832e+03*S87+7.505054e+03*S88+2.819863e+01*S89'
.param V95_part10='V95_part9+6.088671e+00*S90+0.000000e+00*S91+1.259165e+01*S92+5.195610e+00*S93+8.808357e+00*S94+1.364898e+02*S95+5.222324e+00*S96+5.154576e+01*S97+8.397383e+01*S98+4.687252e+00*S99'
.param V95_part11='V95_part10+5.294556e+00*S100+1.690596e+02*S101+2.668932e+00*S102+3.628199e+00*S103+8.440167e+00*S104+1.130417e+01*S105+0.000000e+00*S106+2.568110e+03*S107+1.356758e+01*S108+1.506961e+01*S109'
.param V95_part12='V95_part11+2.602698e-01*S110+2.298705e+01*S111+1.344471e+01*S112+5.068301e+00*S113+9.899745e+00*S114+1.192918e+01*S115+7.099129e+00*S116+1.049131e+01*S117+6.686577e+00*S118+3.289381e+03*S119'
.param V95_part13='V95_part12+9.712575e+00*S120+1.384149e+01*S121+8.650953e+00*S122+7.932429e+00*S123+9.476110e+00*S124+7.996379e+00*S125+2.510964e+03*S126+2.608539e+01*S127+5.295040e+00*S128+9.592512e+00*S129'
.param V95_part14='V95_part13+2.545113e+01*S130+1.207425e+01*S131+3.983394e+02*S132+1.153087e+01*S133+9.041343e+00*S134+0.000000e+00*S135+(-1.869746e+01)*S136+1.712429e+01*S137+(-6.815821e+01)*S138+(-3.071249e+01)*S139'
.param V95_part15='V95_part14+8.772647e+02*S140+1.183079e+02*S141+2.197535e+01*S142+1.266686e+02*S143+1.000000e+04*S144+5.915826e+00*S145+6.807629e+00*S146+1.000000e+04*S147+1.157698e+02*S148+5.832516e+00*S149'
.param V95_part16='V95_part15+7.493145e+03*S150+7.487392e+03*S151+7.610777e+03*S152+4.591288e+02*S153+7.508250e+03*S154+6.470543e+03*S155+2.597117e+01*S156+2.145772e+00*S157+7.452094e+03*S158+7.602827e+00*S159'
.param V95_part17='V95_part16+4.233097e+00*S160+(-4.091965e+00)*S161+4.064339e+00*S162+3.375615e+00*S163+1.139079e+01*S164+2.422954e+01*S165+0.000000e+00*S166+6.568753e-01*S167+1.952215e+01*S168+2.636043e+01*S169'
.param V95_part18='V95_part17+1.617108e+00*S170+2.834637e+00*S171+2.649428e+02*S172+1.468485e+00*S173+3.026604e+00*S174+1.588748e+01*S175+8.261924e-01*S176+3.535519e+02*S177+1.427269e+00*S178+1.053685e+00*S179'
.param V95_part19='V95_part18+2.495958e+03*S180+0.000000e+00*S181+1.493458e+01*S182+(-3.164360e+00)*S183+1.819779e+02*S184+3.258014e+00*S185+5.590868e+01*S186+3.848943e+00*S187+3.670067e+00*S188+6.286502e+00*S189'
.param V95_part20='V95_part19+4.171281e+00*S190+2.365805e+00*S191+0.000000e+00*S192+3.971083e+00*S193+(-6.225290e-04)*S194+9.811611e+00*S195+2.509812e+03*S196+1.284993e+01*S197+2.575355e+03*S198+1.394234e+01*S199'
.param V95_part21='V95_part20+7.431659e+00*S200+5.121615e+01*S201+1.122105e+01*S202+6.917815e+00*S203+4.181701e+00*S204+4.671873e+00*S205+2.021920e+00*S206+1.154105e+00*S207+5.253647e-01*S208+3.353366e+00*S209'
.param V95_part22='V95_part21+3.208189e+00*S210+7.509227e+03*S211+6.200979e+00*S212+0.000000e+00*S213+3.457986e+00*S214+6.380224e+00*S215+3.090269e+00*S216+6.148417e+00*S217+2.295722e+00*S218+2.549433e+01*S219'
.param V95_part23='V95_part22+4.927239e+00*S220+1.590787e+00*S221+3.161267e+00*S222+3.958869e+00*S223+(-5.243485e+00)*S224+7.511946e+03*S225+2.533767e+03*S226+2.316390e+03*S227+4.074341e+00*S228+5.783027e+00*S229'
.param V95_part24='V95_part23+9.629679e+00*S230+2.971293e+00*S231+6.680894e+00*S232+1.250911e+03*S233+2.180209e+00*S234+(-4.809044e+03)*S235+(-4.777776e+03)*S236+2.178388e+00*S237+2.819707e+00*S238+6.652775e+00*S239'
.param V95_part25='V95_part24+1.877752e+00*S240+1.362566e+01*S241+(-4.472981e+00)*S242+4.914331e+00*S243+1.574813e+01*S244+6.089511e+01*S245+1.838733e+00*S246+1.212289e+01*S247+9.132690e+01*S248+2.922959e+00*S249'
.param V95_part26='V95_part25+4.232200e+00*S250+3.760833e+01*S251+3.501926e+00*S252+5.846786e+00*S253+1.181082e+02*S254+6.838403e+02*S255+2.285510e+01*S256+1.510236e+01*S257+2.518174e+03*S258+1.634416e+01*S259'
.param V95_part27='V95_part26+7.769971e+03*S260+3.375909e+00*S261+2.815042e+00*S262+5.163724e+01*S263+9.340062e-01*S264+3.388735e+01*S265+9.845570e+01*S266+0.000000e+00*S267+5.946447e+01*S268+6.704166e+02*S269'
.param V95_part28='V95_part27+4.007692e+03*S270+4.256346e+01*S271+8.931847e+00*S272+4.006585e+03*S273+5.531386e+00*S274+7.010453e+00*S275+4.003653e+03*S276+8.734351e+00*S277+1.721294e+01*S278+2.585891e+02*S279'
.param V95_part29='V95_part28+0.000000e+00*S280+3.161690e+01*S281+3.050058e+01*S282+6.060883e+00*S283+1.972351e+01*S284+6.522931e+00*S285+9.978924e+00*S286+9.328594e+00*S287+3.941615e+00*S288+1.317439e+01*S289'
.param V95_part30='V95_part29+4.712421e-02*S290+4.001408e+03*S291+1.475600e+01*S292+3.039272e-01*S293+1.142303e+02*S294+5.582465e+00*S295+3.267084e-01*S296+8.122991e-01*S297+7.755594e+00*S298+2.914534e-01*S299'
.param V95_part31='V95_part30+(-1.809015e+00)*S300+1.110483e+01*S301+(-6.196180e+00)*S302+2.806084e+00*S303+(-7.012531e-01)*S304+9.929722e+00*S305+3.339260e+00*S306+4.127582e+00*S307+1.221885e+01*S308+4.441516e+01*S309'
.param V95='V95_part31+4.135579e+00*S310+3.366845e+01*S311+3.047285e+00*S312+1.589459e+01*S313+1.993072e+01*S314'
.param V96_part1='3.146676e-01*S0+3.109163e+00*S1+(-1.652221e+00)*S2+2.902503e+00*S3+8.513529e-01*S4+(-1.283083e+00)*S5+(-2.930793e-01)*S6+2.528219e+00*S7+(-2.911126e-01)*S8+3.996694e+00*S9'
.param V96_part2='V96_part1+1.157808e+00*S10+(-6.570641e-01)*S11+(-5.408403e-01)*S12+(-3.175677e-01)*S13+(-2.426470e-01)*S14+0.000000e+00*S15+3.550967e+00*S16+(-1.850164e+02)*S17+(-1.597656e+00)*S18+(-3.962397e+00)*S19'
.param V96_part3='V96_part2+(-1.432187e+02)*S20+9.280215e+00*S21+7.663325e+00*S22+(-2.229435e+00)*S23+7.666413e-01*S24+(-3.117375e+01)*S25+(-1.965222e-01)*S26+3.136959e-01*S27+7.197918e-01*S28+3.833694e+00*S29'
.param V96_part4='V96_part3+(-2.004769e+01)*S30+0.000000e+00*S31+(-9.256524e+00)*S32+1.141870e+03*S33+(-6.256845e+00)*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.968557e+01)*S37+(-2.454832e+01)*S38+(-1.031943e+01)*S39'
.param V96_part5='V96_part4+(-1.522293e+01)*S40+(-1.188122e+01)*S41+(-8.228195e+00)*S42+7.729217e+00*S43+(-1.925934e+01)*S44+(-2.459638e+01)*S45+(-1.818572e+01)*S46+(-8.645885e+00)*S47+(-5.568705e+00)*S48+0.000000e+00*S49'
.param V96_part6='V96_part5+(-4.209075e+00)*S50+8.380881e+01*S51+1.897881e+03*S52+(-3.334796e+00)*S53+(-4.858146e+01)*S54+(-1.235147e+02)*S55+(-1.948945e+00)*S56+(-2.955566e+00)*S57+(-2.939062e+00)*S58+4.416145e+00*S59'
.param V96_part7='V96_part6+2.132467e-02*S60+(-9.381712e+01)*S61+(-8.532091e+00)*S62+(-2.641254e+00)*S63+(-2.170427e+01)*S64+1.164745e+00*S65+(-1.275453e+00)*S66+(-6.978489e+00)*S67+0.000000e+00*S68+(-1.272974e+00)*S69'
.param V96_part8='V96_part7+(-1.304180e+01)*S70+(-7.026989e-01)*S71+(-1.043125e+00)*S72+(-5.694325e-01)*S73+(-4.707873e+00)*S74+8.639562e+01*S75+1.012879e+02*S76+5.276106e+00*S77+0.000000e+00*S78+3.430597e+00*S79'
.param V96_part9='V96_part8+(-1.250899e+00)*S80+1.635700e+02*S81+0.000000e+00*S82+2.685894e-01*S83+1.367397e+01*S84+2.906653e+01*S85+6.611957e+00*S86+1.291669e+01*S87+6.325421e+00*S88+(-1.851596e-01)*S89'
.param V96_part10='V96_part9+(-1.307942e+00)*S90+0.000000e+00*S91+(-2.443189e+00)*S92+(-2.567357e+00)*S93+(-4.019069e+00)*S94+6.172954e+01*S95+(-2.721807e+00)*S96+(-1.153015e+01)*S97+6.344672e+00*S98+(-9.048912e-01)*S99'
.param V96_part11='V96_part10+(-2.289047e+00)*S100+2.868916e-01*S101+(-1.257880e+00)*S102+(-1.015674e+00)*S103+6.139822e+00*S104+3.018326e-01*S105+0.000000e+00*S106+(-7.390949e+01)*S107+(-2.260714e+00)*S108+(-7.662017e+00)*S109'
.param V96_part12='V96_part11+(-1.149410e-02)*S110+(-3.091333e+00)*S111+(-7.784481e+00)*S112+1.811389e-01*S113+(-9.530489e+00)*S114+(-6.630996e+00)*S115+(-1.209182e+00)*S116+(-2.534388e+00)*S117+(-2.813778e+00)*S118+2.138065e+01*S119'
.param V96_part13='V96_part12+(-4.494931e+00)*S120+(-6.900058e+00)*S121+(-4.147640e+00)*S122+1.578685e+00*S123+(-3.590897e+00)*S124+(-2.907347e+00)*S125+(-9.156388e+00)*S126+(-8.255771e-01)*S127+(-1.891090e+00)*S128+2.252218e+00*S129'
.param V96_part14='V96_part13+(-5.439456e+00)*S130+(-9.220052e-02)*S131+(-7.816701e+00)*S132+1.004411e+00*S133+(-1.295810e+00)*S134+0.000000e+00*S135+1.962544e+02*S136+8.243330e+01*S137+4.169484e+02*S138+1.384614e+02*S139'
.param V96_part15='V96_part14+(-9.882898e+00)*S140+9.074827e+01*S141+1.608135e+01*S142+(-1.240508e+01)*S143+8.880580e+01*S144+1.741586e+02*S145+(-2.136006e+00)*S146+8.138612e+01*S147+4.140967e+01*S148+(-1.772026e+00)*S149'
.param V96_part16='V96_part15+4.305456e+01*S150+2.602587e+01*S151+(-3.133812e+01)*S152+2.007114e+01*S153+8.879124e+00*S154+4.914631e+01*S155+(-2.976962e+00)*S156+1.272435e-01*S157+1.537916e+02*S158+2.905507e-01*S159'
.param V96_part17='V96_part16+(-7.221091e-01)*S160+(-8.328253e-01)*S161+1.012200e-01*S162+4.691811e-01*S163+(-6.013918e+00)*S164+(-1.712904e+00)*S165+0.000000e+00*S166+3.081299e+00*S167+(-1.901535e+00)*S168+(-4.786460e+00)*S169'
.param V96_part18='V96_part17+5.933388e-01*S170+3.801155e-01*S171+(-8.407129e+00)*S172+4.837129e-01*S173+(-2.136749e+00)*S174+(-1.484602e-01)*S175+3.507072e-01*S176+(-3.767484e+00)*S177+1.481839e-01*S178+3.593950e-01*S179'
.param V96_part19='V96_part18+2.320723e+01*S180+0.000000e+00*S181+(-8.766375e-01)*S182+6.480209e-01*S183+(-8.270510e+00)*S184+1.266150e-02*S185+3.129078e-01*S186+1.379418e-02*S187+(-7.320467e-01)*S188+3.072168e-01*S189'
.param V96_part20='V96_part19+3.717446e-01*S190+(-1.689748e-01)*S191+0.000000e+00*S192+3.802170e-01*S193+3.760675e-01*S194+(-1.832053e+00)*S195+8.019621e-02*S196+(-5.124702e+00)*S197+(-4.858625e+01)*S198+(-9.036924e-01)*S199'
.param V96_part21='V96_part20+(-2.868086e+00)*S200+(-5.077307e+00)*S201+(-5.171894e+00)*S202+(-2.863537e+00)*S203+(-2.845407e+00)*S204+(-1.736301e+00)*S205+(-3.829746e-01)*S206+(-6.341373e-01)*S207+(-2.070530e-01)*S208+(-1.297066e+00)*S209'
.param V96_part22='V96_part21+5.129064e-01*S210+1.821064e+01*S211+(-2.182797e+00)*S212+0.000000e+00*S213+1.356008e+00*S214+(-1.652249e+00)*S215+(-1.815064e+00)*S216+(-1.537788e+00)*S217+(-2.203355e-01)*S218+7.608349e+00*S219'
.param V96_part23='V96_part22+7.735153e-01*S220+(-1.627020e-01)*S221+(-1.269200e+00)*S222+8.041512e-01*S223+(-1.140912e+01)*S224+2.384983e+01*S225+7.041410e+01*S226+2.943621e+02*S227+(-3.701610e+00)*S228+5.433039e+00*S229'
.param V96_part24='V96_part23+1.980145e+01*S230+(-1.509097e+00)*S231+1.793722e+00*S232+1.423721e+02*S233+(-3.919444e-01)*S234+7.083459e+01*S235+(-1.609391e+01)*S236+7.163495e-02*S237+(-4.325488e-01)*S238+7.538809e-02*S239'
.param V96_part25='V96_part24+(-6.379051e+00)*S240+1.371617e+00*S241+1.116076e+01*S242+(-2.598109e+00)*S243+3.049078e-01*S244+(-2.695343e+00)*S245+(-7.062208e-01)*S246+5.612156e+00*S247+2.112151e+00*S248+(-1.019712e+00)*S249'
.param V96_part26='V96_part25+(-8.669650e-01)*S250+(-3.674223e+00)*S251+(-3.030054e-01)*S252+6.598991e-01*S253+(-8.537212e+00)*S254+3.366253e+00*S255+(-1.717543e+00)*S256+(-2.861358e+00)*S257+(-2.222509e+01)*S258+1.733447e+00*S259'
.param V96_part27='V96_part26+4.974931e+01*S260+3.292061e+00*S261+(-6.478392e-01)*S262+4.355639e-01*S263+1.039591e+00*S264+5.236114e+00*S265+(-3.512050e+00)*S266+0.000000e+00*S267+1.150319e+00*S268+3.409914e+00*S269'
.param V96_part28='V96_part27+1.694249e+00*S270+3.859254e+02*S271+(-1.091136e+00)*S272+2.078302e+00*S273+2.672305e-01*S274+(-4.370117e-01)*S275+(-6.055687e-02)*S276+(-8.563957e-01)*S277+(-1.325823e+00)*S278+5.463546e-01*S279'
.param V96_part29='V96_part28+0.000000e+00*S280+(-2.509177e+00)*S281+9.225485e+00*S282+6.106194e-01*S283+(-1.690797e+00)*S284+(-1.759547e+00)*S285+(-3.515571e+00)*S286+(-1.134111e+00)*S287+(-6.873847e+00)*S288+(-2.783915e-02)*S289'
.param V96_part30='V96_part29+6.638734e-01*S290+2.634617e-01*S291+(-1.717170e+00)*S292+2.139252e-01*S293+3.458906e-02*S294+4.729706e-01*S295+9.327100e-02*S296+1.960638e+00*S297+6.751661e-01*S298+6.685738e-02*S299'
.param V96_part31='V96_part30+(-9.939732e-01)*S300+(-6.633279e+00)*S301+1.201067e+01*S302+(-1.707541e+00)*S303+(-1.768910e+00)*S304+(-8.096895e-01)*S305+(-9.558486e-01)*S306+3.729421e+00*S307+(-1.395156e+00)*S308+2.088877e+00*S309'
.param V96='V96_part31+5.772248e+00*S310+(-4.314904e+00)*S311+(-4.034516e-01)*S312+1.936136e+00*S313+(-2.819182e+00)*S314'
.param V97_part1='(-1.514963e+01)*S0+(-4.880140e-01)*S1+(-1.615163e+00)*S2+(-4.703780e+00)*S3+(-4.950446e+00)*S4+9.652978e-01*S5+(-5.055439e+00)*S6+(-2.040296e-01)*S7+2.351100e+00*S8+(-2.729654e+00)*S9'
.param V97_part2='V97_part1+(-6.255121e+00)*S10+(-1.247765e-01)*S11+(-4.757208e+00)*S12+4.176764e+00*S13+(-2.249242e+00)*S14+0.000000e+00*S15+(-2.866085e-02)*S16+3.459658e+02*S17+(-6.536089e+00)*S18+(-1.032208e+01)*S19'
.param V97_part3='V97_part2+8.579027e+01*S20+(-1.025107e+01)*S21+(-5.188139e+00)*S22+(-4.082511e-01)*S23+(-1.007256e+01)*S24+3.674853e+01*S25+(-1.417434e+00)*S26+(-1.116703e+01)*S27+(-4.697926e+00)*S28+(-4.292644e+00)*S29'
.param V97_part4='V97_part3+(-5.180122e+00)*S30+0.000000e+00*S31+(-1.436948e+01)*S32+7.774491e+02*S33+(-5.017188e+00)*S34+0.000000e+00*S35+0.000000e+00*S36+7.407342e+01*S37+(-1.330378e+01)*S38+5.814858e+01*S39'
.param V97_part5='V97_part4+3.786997e+01*S40+1.085325e+01*S41+1.062321e+02*S42+2.933622e+01*S43+3.688358e+00*S44+(-2.975047e+00)*S45+(-5.190661e+00)*S46+(-3.671368e+00)*S47+(-1.997223e+01)*S48+0.000000e+00*S49'
.param V97_part6='V97_part5+(-3.364591e+00)*S50+1.381010e+02*S51+2.481656e+02*S52+(-2.369308e+00)*S53+(-7.344237e+03)*S54+(-2.452441e+01)*S55+(-2.041306e+00)*S56+(-3.580147e+00)*S57+(-1.505318e+00)*S58+(-4.418566e+01)*S59'
.param V97_part7='V97_part6+(-4.268185e+00)*S60+(-1.261996e+01)*S61+(-2.150032e+00)*S62+(-7.510273e+00)*S63+(-5.453925e+00)*S64+(-2.446426e+00)*S65+(-3.395155e+00)*S66+9.281978e+00*S67+0.000000e+00*S68+(-2.510160e+00)*S69'
.param V97_part8='V97_part7+8.657154e+00*S70+(-3.921674e-01)*S71+(-4.147924e+00)*S72+(-1.535088e+00)*S73+8.428510e-01*S74+7.778688e+01*S75+1.164706e+01*S76+3.117488e+00*S77+0.000000e+00*S78+(-6.735460e+01)*S79'
.param V97_part9='V97_part8+(-3.487834e-02)*S80+1.598327e+01*S81+0.000000e+00*S82+1.721396e+00*S83+1.002890e+02*S84+6.394820e+00*S85+5.799913e+00*S86+1.795547e+01*S87+(-1.879599e+00)*S88+2.203633e-01*S89'
.param V97_part10='V97_part9+(-3.646855e+00)*S90+0.000000e+00*S91+(-5.899659e+00)*S92+(-2.777978e+00)*S93+(-7.813770e+00)*S94+(-1.388801e+02)*S95+(-3.036959e+00)*S96+(-4.692866e+01)*S97+(-6.845825e+01)*S98+2.639464e+00*S99'
.param V97_part11='V97_part10+(-2.003505e+00)*S100+(-1.421327e+02)*S101+(-2.087062e-01)*S102+(-1.523020e+00)*S103+6.634984e+00*S104+2.616872e-01*S105+0.000000e+00*S106+1.100740e+00*S107+3.473640e-01*S108+5.804645e-01*S109'
.param V97_part12='V97_part11+(-1.061756e-01)*S110+(-3.556653e+01)*S111+(-3.510599e+00)*S112+(-3.736905e+00)*S113+2.254004e+00*S114+(-6.184024e+00)*S115+(-3.957327e+00)*S116+(-1.229059e+01)*S117+(-4.018670e+00)*S118+3.602690e+01*S119'
.param V97_part13='V97_part12+(-7.661878e+00)*S120+(-8.223823e+00)*S121+(-3.620225e+00)*S122+(-1.166702e+01)*S123+(-5.094766e+00)*S124+(-3.237582e+00)*S125+7.088350e+00*S126+(-4.461354e+01)*S127+(-1.999472e+00)*S128+4.000547e+00*S129'
.param V97_part14='V97_part13+(-2.395474e+01)*S130+(-6.280774e+00)*S131+(-7.700843e+00)*S132+(-8.320992e+00)*S133+(-5.416989e+00)*S134+0.000000e+00*S135+6.132274e+00*S136+(-1.910349e+01)*S137+(-2.920977e+01)*S138+(-2.371253e+00)*S139'
.param V97_part15='V97_part14+3.174453e+01*S140+2.245361e+02*S141+(-1.034061e+01)*S142+3.486436e+01*S143+1.427206e+02*S144+(-2.402738e+01)*S145+(-1.999192e+00)*S146+2.482137e+02*S147+7.906206e+00*S148+(-1.763800e+00)*S149'
.param V97_part16='V97_part15+2.061938e+01*S150+3.923065e+01*S151+(-6.743026e+01)*S152+(-3.620467e+01)*S153+1.756963e+01*S154+(-8.650940e+01)*S155+(-1.527607e+01)*S156+5.402846e-02*S157+(-2.577185e+00)*S158+1.994225e-02*S159'
.param V97_part17='V97_part16+(-3.629013e+00)*S160+8.616511e+00*S161+(-4.190726e+00)*S162+(-3.847306e+00)*S163+(-5.536568e+00)*S164+(-3.609974e+01)*S165+0.000000e+00*S166+3.916141e-01*S167+(-3.442801e+01)*S168+(-3.364730e+01)*S169'
.param V97_part18='V97_part17+(-1.657358e+00)*S170+(-4.651262e+00)*S171+(-1.009625e+01)*S172+(-1.668657e+00)*S173+1.523123e+00*S174+(-3.420157e+00)*S175+(-9.369097e-01)*S176+3.302468e+01*S177+(-1.991181e+00)*S178+(-1.157425e+00)*S179'
.param V97_part19='V97_part18+2.037452e+01*S180+0.000000e+00*S181+(-1.115408e+01)*S182+3.111136e+01*S183+(-4.173982e+00)*S184+(-2.656508e+00)*S185+6.295161e-01*S186+(-4.991717e+00)*S187+(-1.727703e+00)*S188+(-5.117840e+00)*S189'
.param V97_part20='V97_part19+(-6.036820e+00)*S190+(-1.061673e+00)*S191+0.000000e+00*S192+(-5.961289e+00)*S193+(-2.443717e-01)*S194+(-1.443766e+01)*S195+3.234447e+01*S196+(-1.755293e+00)*S197+(-6.587773e+01)*S198+6.724179e-02*S199'
.param V97_part21='V97_part20+(-2.267175e+00)*S200+(-9.709013e+00)*S201+(-6.813417e+00)*S202+(-1.996008e+00)*S203+5.974935e+00*S204+(-7.571714e-01)*S205+(-4.696043e-01)*S206+8.469698e-01*S207+1.438327e+00*S208+(-6.987303e-01)*S209'
.param V97_part22='V97_part21+7.642617e+00*S210+1.176855e+00*S211+(-3.028766e+00)*S212+0.000000e+00*S213+(-2.896892e+00)*S214+(-3.079357e+00)*S215+4.275675e-01*S216+(-6.258228e+00)*S217+(-8.249078e-01)*S218+(-4.252556e+00)*S219'
.param V97_part23='V97_part22+(-8.132895e+00)*S220+(-3.603722e-01)*S221+1.372476e+00*S222+(-6.638212e+00)*S223+(-3.432656e+01)*S224+(-2.014712e-01)*S225+(-2.830878e+01)*S226+1.829023e+02*S227+1.026203e+00*S228+(-6.921739e+00)*S229'
.param V97_part24='V97_part23+(-1.175481e+01)*S230+(-1.372948e+00)*S231+(-1.078535e+01)*S232+(-5.725177e+03)*S233+(-1.727040e-01)*S234+(-3.396599e+02)*S235+(-1.712347e+02)*S236+(-2.595793e-01)*S237+(-2.224752e+00)*S238+(-6.332987e+00)*S239'
.param V97_part25='V97_part24+8.109677e+00*S240+(-1.382272e+01)*S241+5.471884e+00*S242+(-3.701485e+00)*S243+(-1.035167e+01)*S244+(-5.143376e+01)*S245+1.750597e+00*S246+(-1.748231e+01)*S247+(-8.426312e+01)*S248+(-1.228150e+00)*S249'
.param V97_part26='V97_part25+(-3.089049e+00)*S250+(-2.923008e+01)*S251+(-2.789391e+00)*S252+(-8.867125e+00)*S253+(-1.038664e+02)*S254+8.993786e+01*S255+(-8.639121e+00)*S256+(-9.938356e+00)*S257+1.014510e+02*S258+(-1.100071e+01)*S259'
.param V97_part27='V97_part26+(-1.849464e+02)*S260+1.658734e+00*S261+(-2.235204e+00)*S262+(-4.262180e+01)*S263+(-1.718146e-01)*S264+(-3.599576e+01)*S265+(-8.415837e+01)*S266+0.000000e+00*S267+(-6.750519e+01)*S268+(-6.582155e+02)*S269'
.param V97_part28='V97_part27+(-1.000000e+04)*S270+(-1.869958e+02)*S271+(-7.840402e+00)*S272+(-1.000000e+04)*S273+(-7.592145e+00)*S274+(-6.053100e+00)*S275+(-1.000000e+04)*S276+(-1.034719e+01)*S277+(-1.477952e+01)*S278+(-6.447686e+02)*S279'
.param V97_part29='V97_part28+0.000000e+00*S280+(-2.736821e+01)*S281+8.219363e+01*S282+(-9.393466e+00)*S283+(-1.702257e+01)*S284+(-1.452103e+00)*S285+(-9.803664e+00)*S286+2.807899e+00*S287+1.775899e+00*S288+(-1.072087e+01)*S289'
.param V97_part30='V97_part29+4.372876e-02*S290+(-1.000000e+04)*S291+(-1.951435e+01)*S292+(-1.536606e-01)*S293+(-2.824461e+02)*S294+(-8.088563e+00)*S295+(-3.653702e-02)*S296+(-2.853326e+00)*S297+(-1.183323e+01)*S298+1.773649e-01*S299'
.param V97_part31='V97_part30+2.205496e+01*S300+(-7.710596e+00)*S301+8.291963e+00*S302+(-2.302912e+00)*S303+1.506599e+01*S304+(-7.127775e+00)*S305+(-3.384283e+00)*S306+(-5.556316e+00)*S307+(-9.046576e+00)*S308+(-1.093867e+02)*S309'
.param V97='V97_part31+(-4.377844e+00)*S310+(-2.685347e+01)*S311+9.896243e-01*S312+(-2.461034e+01)*S313+(-1.551401e+01)*S314'
.param V98_part1='(-1.475147e+00)*S0+(-1.439380e+00)*S1+1.627691e+01*S2+8.869641e+00*S3+1.550669e+01*S4+9.479972e+00*S5+1.099284e+01*S6+1.288131e+01*S7+9.850403e+00*S8+1.339318e+01*S9'
.param V98_part2='V98_part1+1.152721e+01*S10+9.031032e+00*S11+1.040665e+01*S12+1.404960e+01*S13+9.778154e+00*S14+0.000000e+00*S15+3.138688e+00*S16+1.000000e+04*S17+9.365058e+00*S18+1.214689e+01*S19'
.param V98_part3='V98_part2+1.435573e+03*S20+1.080684e+01*S21+7.669903e+00*S22+2.151174e+01*S23+7.287678e+00*S24+5.371801e+02*S25+(-2.206788e-01)*S26+2.546517e+00*S27+4.366120e+00*S28+5.147363e+00*S29'
.param V98_part4='V98_part3+4.047894e-01*S30+0.000000e+00*S31+5.447437e+00*S32+2.025768e+03*S33+1.000727e+00*S34+0.000000e+00*S35+0.000000e+00*S36+2.602918e+02*S37+1.859830e+01*S38+5.231022e+03*S39'
.param V98_part5='V98_part4+1.585040e+02*S40+3.323636e+01*S41+2.582094e+03*S42+5.387348e+01*S43+3.595114e+01*S44+1.458402e-01*S45+8.005205e-01*S46+7.952741e-02*S47+2.832139e+00*S48+0.000000e+00*S49'
.param V98_part6='V98_part5+6.644416e-01*S50+(-1.259479e+01)*S51+(-1.000000e+04)*S52+2.553227e-01*S53+2.097010e+03*S54+3.097243e+01*S55+3.304519e-01*S56+3.762493e-01*S57+4.933062e-01*S58+(-5.128851e+00)*S59'
.param V98_part7='V98_part6+4.170440e+00*S60+(-3.411338e+00)*S61+5.109928e-01*S62+1.403249e+00*S63+(-4.387553e-01)*S64+8.140814e-01*S65+3.304642e-01*S66+3.419087e+03*S67+0.000000e+00*S68+4.087456e-02*S69'
.param V98_part8='V98_part7+1.000000e+04*S70+2.467839e+00*S71+2.220245e-01*S72+2.985900e-03*S73+4.471143e+01*S74+1.421594e+00*S75+(-2.782020e-01)*S76+6.362601e+00*S77+0.000000e+00*S78+(-1.601221e+01)*S79'
.param V98_part9='V98_part8+2.381473e+00*S80+(-2.624895e+01)*S81+0.000000e+00*S82+(-5.144325e+00)*S83+(-9.812708e+03)*S84+(-1.344073e+03)*S85+(-3.825677e+01)*S86+(-1.000000e+04)*S87+(-1.000000e+04)*S88+(-2.483520e+01)*S89'
.param V98_part10='V98_part9+3.351147e+00*S90+0.000000e+00*S91+(-3.994384e-01)*S92+2.481058e+00*S93+2.226148e+00*S94+(-4.789388e+00)*S95+1.792059e+00*S96+6.173700e+00*S97+(-8.225238e-01)*S98+7.860251e+00*S99'
.param V98_part11='V98_part10+1.010887e+00*S100+4.932072e-02*S101+1.943908e-01*S102+1.849594e-01*S103+5.580911e+01*S104+2.291546e+01*S105+0.000000e+00*S106+1.000000e+04*S107+2.863671e+01*S108+2.223250e+01*S109'
.param V98_part12='V98_part11+(-2.578834e-02)*S110+2.231297e-01*S111+(-9.074503e+00)*S112+(-7.405753e-01)*S113+(-4.953414e+00)*S114+(-2.432911e+00)*S115+(-1.427032e+00)*S116+1.394205e+00*S117+(-1.132957e+00)*S118+(-4.427854e+03)*S119'
.param V98_part13='V98_part12+1.345166e+00*S120+1.195992e+00*S121+(-7.964474e-01)*S122+4.847136e-01*S123+4.877133e-01*S124+(-9.252844e-01)*S125+1.000000e+04*S126+(-7.714401e-01)*S127+(-9.963918e-01)*S128+(-1.687572e+01)*S129'
.param V98_part14='V98_part13+(-2.148127e+00)*S130+(-2.397343e+00)*S131+1.539074e+03*S132+(-3.519666e+00)*S133+1.882212e-02*S134+0.000000e+00*S135+(-3.460565e+00)*S136+(-3.198599e+00)*S137+3.233529e+00*S138+(-2.230992e+00)*S139'
.param V98_part15='V98_part14+3.407057e+03*S140+(-1.071262e+01)*S141+4.139130e+01*S142+4.495932e+02*S143+(-2.388737e+01)*S144+(-2.277400e+01)*S145+(-1.403353e+00)*S146+(-2.621147e+01)*S147+(-1.593606e+01)*S148+(-6.736121e-01)*S149'
.param V98_part16='V98_part15+(-1.000000e+04)*S150+(-1.000000e+04)*S151+(-1.000000e+04)*S152+(-5.877727e+02)*S153+(-1.000000e+04)*S154+(-8.495146e+03)*S155+(-1.419428e+01)*S156+(-1.052180e+00)*S157+(-1.000000e+04)*S158+(-7.289066e+00)*S159'
.param V98_part17='V98_part16+(-3.133353e-01)*S160+(-7.989442e-01)*S161+(-1.232044e-01)*S162+(-3.863215e-01)*S163+1.604295e+00*S164+(-3.462451e-02)*S165+0.000000e+00*S166+8.892987e-01*S167+9.192160e-01*S168+5.427221e+00*S169'
.param V98_part18='V98_part17+2.603281e-01*S170+(-3.782891e-01)*S171+9.365882e+02*S172+1.628717e-01*S173+(-1.343395e+00)*S174+(-1.638604e+01)*S175+1.616128e-01*S176+1.389703e+03*S177+3.432817e-01*S178+1.623051e-01*S179'
.param V98_part19='V98_part18+1.000000e+04*S180+0.000000e+00*S181+(-5.019426e-01)*S182+6.249053e-01*S183+5.849870e+02*S184+2.486125e-01*S185+2.242333e+02*S186+(-2.855666e-01)*S187+(-7.710664e-01)*S188+(-4.877082e+00)*S189'
.param V98_part20='V98_part19+(-3.128725e-01)*S190+(-8.231492e-01)*S191+0.000000e+00*S192+(-2.954034e-01)*S193+1.330390e-01*S194+1.314806e+00*S195+1.000000e+04*S196+6.982883e+00*S197+1.000000e+04*S198+1.368286e+01*S199'
.param V98_part21='V98_part20+5.117538e-01*S200+1.038150e+02*S201+(-2.288929e+00)*S202+1.458381e-01*S203+(-6.976564e+00)*S204+(-3.074306e+00)*S205+(-1.140491e+00)*S206+(-4.388513e-01)*S207+(-1.493021e+00)*S208+(-1.748375e-01)*S209'
.param V98_part22='V98_part21+4.246430e+00*S210+(-1.000000e+04)*S211+3.668000e-02*S212+0.000000e+00*S213+(-9.315285e-01)*S214+2.667254e-02*S215+(-1.209397e+00)*S216+(-1.006588e+00)*S217+(-4.404780e-01)*S218+(-3.293390e+01)*S219'
.param V98_part23='V98_part22+(-1.152142e-01)*S220+(-5.606608e-01)*S221+(-2.325263e+00)*S222+(-2.310415e-01)*S223+(-2.984732e-01)*S224+(-1.000000e+04)*S225+1.000000e+04*S226+1.000000e+04*S227+(-8.719768e-01)*S228+(-1.475849e+00)*S229'
.param V98_part24='V98_part23+(-1.366150e+00)*S230+(-7.562543e-01)*S231+(-4.211963e-01)*S232+1.025261e+01*S233+(-1.279056e+00)*S234+(-3.102089e+00)*S235+8.062087e-01*S236+(-1.931308e+00)*S237+(-1.276679e+00)*S238+(-2.348274e-01)*S239'
.param V98_part25='V98_part24+(-1.612566e+00)*S240+(-1.717470e+00)*S241+(-9.923148e-01)*S242+(-2.035432e-01)*S243+(-8.292998e+00)*S244+(-2.591787e+00)*S245+(-1.234271e+00)*S246+(-2.903837e-01)*S247+7.159447e-02*S248+(-1.397186e+00)*S249'
.param V98_part26='V98_part25+(-8.424972e-01)*S250+(-1.298180e+00)*S251+(-1.612121e+00)*S252+(-5.327256e-01)*S253+4.725714e-02*S254+2.705265e+03*S255+1.686683e+01*S256+(-2.938304e+00)*S257+1.000000e+04*S258+(-7.886322e+00)*S259'
.param V98_part27='V98_part26+(-1.000000e+04)*S260+(-4.261327e+00)*S261+3.527065e-01*S262+(-1.537801e+00)*S263+4.095228e-01*S264+(-1.258306e+00)*S265+(-2.817865e-01)*S266+0.000000e+00*S267+4.309479e+00*S268+1.617953e-01*S269'
.param V98_part28='V98_part27+(-6.557833e+00)*S270+(-2.316024e+00)*S271+(-3.314192e-01)*S272+(-4.740805e+00)*S273+(-7.595432e-02)*S274+(-3.160025e-01)*S275+(-3.791658e+00)*S276+(-6.236968e-01)*S277+(-5.911636e-01)*S278+(-9.783654e-01)*S279'
.param V98_part29='V98_part28+0.000000e+00*S280+(-2.943791e-01)*S281+1.693641e-01*S282+(-3.232307e-01)*S283+(-9.567959e-02)*S284+(-5.236655e+00)*S285+(-2.206120e+00)*S286+(-8.267045e+00)*S287+2.351794e-01*S288+(-4.398718e+00)*S289'
.param V98_part30='V98_part29+3.036343e-01*S290+(-1.457718e+00)*S291+(-6.725631e-01)*S292+1.602358e-01*S293+(-1.148046e+00)*S294+(-3.666707e-01)*S295+1.934736e-01*S296+(-1.039056e+00)*S297+(-4.454802e-01)*S298+1.997014e-01*S299'
.param V98_part31='V98_part30+(-3.629058e+00)*S300+(-8.599514e-01)*S301+(-2.192622e+00)*S302+(-2.382825e-01)*S303+(-4.040203e+00)*S304+(-1.812304e+00)*S305+3.330249e-02*S306+(-2.318490e+00)*S307+(-1.505705e+00)*S308+(-2.443765e+00)*S309'
.param V98='V98_part31+(-3.395806e+00)*S310+(-6.931400e-01)*S311+(-3.854152e+00)*S312+(-1.022706e+00)*S313+(-3.536009e-01)*S314'
.param V99_part1='1.737986e-01*S0+(-1.929470e-01)*S1+8.814500e-03*S2+4.448933e-02*S3+1.579336e-01*S4+2.961856e-02*S5+1.341390e-01*S6+1.645827e-01*S7+1.239494e-01*S8+9.918262e-02*S9'
.param V99_part2='V99_part1+1.093279e-01*S10+3.098772e-04*S11+3.137995e-02*S12+(-2.282155e-01)*S13+(-9.262699e-02)*S14+0.000000e+00*S15+8.159317e-06*S16+9.762686e-01*S17+9.940328e-04*S18+5.944186e-03*S19'
.param V99_part3='V99_part2+1.245473e-01*S20+1.050078e-01*S21+5.514553e-02*S22+1.169925e-02*S23+1.574088e-01*S24+(-1.505361e-01)*S25+2.528387e-03*S26+(-1.356791e-01)*S27+2.969231e-03*S28+9.868225e-03*S29'
.param V99_part4='V99_part3+1.443183e-01*S30+0.000000e+00*S31+7.042491e-01*S32+2.162978e+02*S33+1.175248e-01*S34+0.000000e+00*S35+0.000000e+00*S36+4.332339e-01*S37+1.525608e+00*S38+3.038667e+00*S39'
.param V99_part5='V99_part4+1.622233e+00*S40+2.978356e-01*S41+3.656889e+00*S42+1.408122e+00*S43+6.385563e-01*S44+9.771809e-01*S45+7.160263e-01*S46+4.495340e-01*S47+1.206528e+00*S48+0.000000e+00*S49'
.param V99_part6='V99_part5+(-1.716579e-02)*S50+6.108544e+00*S51+1.752227e+02*S52+1.475536e+00*S53+(-1.676894e+01)*S54+6.701458e+03*S55+4.586037e-01*S56+5.955589e-01*S57+5.062629e-01*S58+(-5.197207e-01)*S59'
.param V99_part7='V99_part6+3.918107e+00*S60+(-7.124097e-01)*S61+1.065742e+00*S62+1.217111e+00*S63+1.794132e+00*S64+1.071003e+00*S65+8.423285e-01*S66+2.374377e+00*S67+0.000000e+00*S68+8.370428e-01*S69'
.param V99_part8='V99_part7+3.177038e+00*S70+5.323627e-01*S71+8.922980e-01*S72+9.369004e-01*S73+(-1.652373e-02)*S74+(-1.120064e+00)*S75+1.880768e+00*S76+8.003674e-02*S77+0.000000e+00*S78+2.664275e+01*S79'
.param V99_part9='V99_part8+2.470198e-01*S80+1.053714e+01*S81+0.000000e+00*S82+8.335288e-01*S83+1.058906e+01*S84+7.940223e+00*S85+2.115857e+00*S86+3.260308e+00*S87+3.729995e+00*S88+2.264460e+00*S89'
.param V99_part10='V99_part9+9.809183e-02*S90+0.000000e+00*S91+9.497514e-02*S92+2.434035e-01*S93+1.324646e+00*S94+2.976331e+00*S95+4.127960e-01*S96+1.706041e+00*S97+4.181759e+00*S98+6.395870e-01*S99'
.param V99_part11='V99_part10+2.238229e-01*S100+5.793825e+00*S101+6.975918e-01*S102+5.976277e-01*S103+3.147727e+00*S104+2.999188e-01*S105+0.000000e+00*S106+(-6.452942e+00)*S107+8.500316e-01*S108+5.980732e-01*S109'
.param V99_part12='V99_part11+(-1.045181e-02)*S110+2.168779e+00*S111+3.221044e+00*S112+1.640226e-01*S113+5.012609e+00*S114+9.026792e-01*S115+7.005837e-03*S116+4.391219e+00*S117+7.861741e-01*S118+1.733628e+00*S119'
.param V99_part13='V99_part12+(-1.227864e+00)*S120+(-6.729124e-01)*S121+(-2.122139e-01)*S122+9.260197e-01*S123+(-2.301429e-01)*S124+(-1.308352e-01)*S125+7.357341e+00*S126+3.992569e+01*S127+(-6.669956e-02)*S128+8.139461e-01*S129'
.param V99_part14='V99_part13+1.187367e+01*S130+2.894983e+00*S131+7.543132e+00*S132+4.343453e+00*S133+6.037094e-01*S134+0.000000e+00*S135+4.642055e+00*S136+2.868346e-01*S137+(-1.921284e+01)*S138+(-9.750635e-01)*S139'
.param V99_part15='V99_part14+(-6.518343e+00)*S140+(-1.311474e+02)*S141+(-1.320320e+00)*S142+(-4.118542e+00)*S143+(-6.708472e+03)*S144+(-4.826721e+01)*S145+(-9.728202e-02)*S146+(-6.732673e+03)*S147+(-8.411775e+01)*S148+(-1.078925e-01)*S149'
.param V99_part16='V99_part15+3.952186e+00*S150+1.284111e+00*S151+1.583420e+01*S152+7.941370e+00*S153+(-3.815627e+00)*S154+2.861044e+01*S155+(-3.748860e-01)*S156+8.155536e-01*S157+2.481135e+01*S158+1.763616e+00*S159'
.param V99_part17='V99_part16+5.686376e-01*S160+6.824831e+00*S161+1.332900e-01*S162+6.039672e-01*S163+1.224218e+01*S164+(-6.868667e-01)*S165+0.000000e+00*S166+7.130886e+00*S167+6.526321e-01*S168+1.531594e+01*S169'
.param V99_part18='V99_part17+(-3.033407e-03)*S170+2.478103e-01*S171+1.789457e+00*S172+4.248357e-02*S173+7.908024e-01*S174+2.810434e-01*S175+1.913670e-02*S176+8.995431e+00*S177+1.643465e-01*S178+1.397975e-02*S179'
.param V99_part19='V99_part18+7.213326e+00*S180+0.000000e+00*S181+8.049231e-02*S182+7.566406e+00*S183+(-3.268687e+00)*S184+5.342120e-02*S185+2.627706e-01*S186+5.862770e-02*S187+1.220763e-01*S188+(-1.723357e-01)*S189'
.param V99_part20='V99_part19+5.899809e-02*S190+1.991297e-01*S191+0.000000e+00*S192+7.238332e-02*S193+6.665207e-02*S194+3.164132e+00*S195+(-2.186441e+00)*S196+(-2.755937e-01)*S197+(-1.201223e+00)*S198+(-7.957516e-01)*S199'
.param V99_part21='V99_part20+(-1.989699e-01)*S200+(-1.087918e+00)*S201+(-2.841931e-01)*S202+(-1.789094e-01)*S203+3.651658e+00*S204+9.048297e-01*S205+2.849924e-01*S206+6.550701e-01*S207+1.340298e+00*S208+1.827352e-01*S209'
.param V99_part22='V99_part21+1.368649e+00*S210+1.479686e+01*S211+(-2.010409e-01)*S212+0.000000e+00*S213+1.379233e+00*S214+(-3.478863e-01)*S215+6.626842e-01*S216+2.312506e-01*S217+7.278479e-02*S218+(-5.001726e-01)*S219'
.param V99_part23='V99_part22+1.155876e-01*S220+1.107003e-01*S221+5.285112e-01*S222+1.653714e-01*S223+1.086066e+02*S224+4.373451e+00*S225+(-2.346428e+00)*S226+2.808343e+01*S227+1.128054e+00*S228+8.926088e-01*S229'
.param V99_part24='V99_part23+1.458677e+01*S230+3.412396e-01*S231+2.309064e-01*S232+8.898440e+03*S233+8.429883e-01*S234+9.999927e+03*S235+1.000000e+04*S236+6.263925e-01*S237+4.111103e-01*S238+1.342123e-01*S239'
.param V99_part25='V99_part24+3.572362e+00*S240+2.091881e+00*S241+5.453826e+00*S242+1.045586e+00*S243+(-7.129521e-02)*S244+1.319516e+00*S245+7.794198e-01*S246+1.390679e+00*S247+5.764796e-01*S248+6.388063e-01*S249'
.param V99_part26='V99_part25+2.500657e-01*S250+(-1.646744e-01)*S251+6.244740e-01*S252+2.416342e-01*S253+(-1.737076e-01)*S254+(-3.116346e+00)*S255+(-1.984494e+00)*S256+1.021022e-01*S257+(-2.388428e+00)*S258+(-2.779782e-01)*S259'
.param V99_part27='V99_part26+(-4.599204e+01)*S260+8.535101e-01*S261+(-4.820733e-02)*S262+3.181052e-01*S263+(-6.151255e-01)*S264+(-4.810291e+00)*S265+(-9.207576e-01)*S266+0.000000e+00*S267+(-4.446170e+00)*S268+(-2.753848e+00)*S269'
.param V99_part28='V99_part27+2.892838e-01*S270+2.343280e-02*S271+7.307569e-03*S272+(-7.848954e-02)*S273+1.003482e-01*S274+8.621571e-02*S275+2.474204e-01*S276+3.760100e-02*S277+5.426747e-02*S278+7.109352e-02*S279'
.param V99_part29='V99_part28+0.000000e+00*S280+(-5.293634e-02)*S281+3.906620e+00*S282+1.226646e-01*S283+2.949067e-02*S284+2.179369e-01*S285+(-9.596547e-02)*S286+1.965453e+00*S287+7.776724e-01*S288+(-3.235190e-01)*S289'
.param V99_part30='V99_part29+(-2.351661e-02)*S290+2.219986e-01*S291+1.142089e-01*S292+5.958303e-02*S293+2.663480e-01*S294+1.833908e-01*S295+9.140003e-02*S296+9.531130e-01*S297+1.925515e-01*S298+8.265286e-02*S299'
.param V99_part31='V99_part30+1.414964e+00*S300+(-9.217025e-01)*S301+4.737177e+00*S302+9.075591e-01*S303+1.716065e+00*S304+6.469299e-02*S305+2.703429e-01*S306+1.601779e-01*S307+1.060217e-02*S308+4.888037e-01*S309'
.param V99='V99_part31+(-8.217060e-01)*S310+1.824731e-01*S311+1.158104e+00*S312+3.347130e-01*S313+(-2.137639e-02)*S314'
.param V100_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V100_part2='V100_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V100_part3='V100_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+3.179380e-03*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V100_part4='V100_part3+(-7.250172e-03)*S30+0.000000e+00*S31+0.000000e+00*S32+1.385360e+02*S33+(-2.362742e-02)*S34+1.953890e+02*S35+4.657741e+02*S36+(-1.108028e-01)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V100_part5='V100_part4+(-1.141101e-01)*S40+(-2.802574e-02)*S41+0.000000e+00*S42+1.496777e-01*S43+(-3.010894e-01)*S44+2.307008e-01*S45+2.008817e-01*S46+8.211176e-02*S47+0.000000e+00*S48+1.000000e+04*S49'
.param V100_part6='V100_part5+0.000000e+00*S50+0.000000e+00*S51+9.614854e-02*S52+0.000000e+00*S53+(-6.549901e-02)*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+4.470133e-02*S59'
.param V100_part7='V100_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+1.691008e-01*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V100_part8='V100_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+(-5.605938e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V100_part9='V100_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+1.582729e-01*S84+0.000000e+00*S85+2.477863e-01*S86+2.248748e-01*S87+8.541680e-02*S88+1.461853e-01*S89'
.param V100_part10='V100_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+1.473405e-01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V100_part11='V100_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+2.860961e-02*S108+0.000000e+00*S109'
.param V100_part12='V100_part11+0.000000e+00*S110+(-9.731832e-03)*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V100_part13='V100_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V100_part14='V100_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+2.280834e-01*S138+5.257733e-01*S139'
.param V100_part15='V100_part14+0.000000e+00*S140+3.154465e-01*S141+3.251970e-01*S142+8.081946e-02*S143+3.561785e-01*S144+3.620622e-01*S145+3.646297e-01*S146+2.105686e-01*S147+5.418447e-01*S148+1.411882e-01*S149'
.param V100_part16='V100_part15+3.701057e-02*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+4.724793e-02*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V100_part17='V100_part16+0.000000e+00*S160+0.000000e+00*S161+3.505440e-01*S162+5.335924e-01*S163+3.994143e-02*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V100_part18='V100_part17+3.513842e+00*S170+3.506780e-01*S171+0.000000e+00*S172+0.000000e+00*S173+1.285516e+00*S174+0.000000e+00*S175+4.149405e+00*S176+9.407120e-01*S177+2.633131e+00*S178+3.165166e+00*S179'
.param V100_part19='V100_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+4.378432e-01*S186+(-2.154141e-01)*S187+0.000000e+00*S188+(-3.637788e+00)*S189'
.param V100_part20='V100_part19+(-1.180425e+00)*S190+2.403531e+00*S191+0.000000e+00*S192+(-2.010347e+00)*S193+0.000000e+00*S194+2.544090e-01*S195+1.033317e-01*S196+2.508754e-01*S197+0.000000e+00*S198+(-7.855605e-02)*S199'
.param V100_part21='V100_part20+2.298543e-01*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+1.292901e+00*S206+1.300121e+00*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V100_part22='V100_part21+0.000000e+00*S210+0.000000e+00*S211+1.050381e+00*S212+0.000000e+00*S213+0.000000e+00*S214+6.617434e-01*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V100_part23='V100_part22+(-3.580697e+00)*S220+0.000000e+00*S221+0.000000e+00*S222+(-3.120631e+00)*S223+3.198907e+00*S224+0.000000e+00*S225+0.000000e+00*S226+(-1.188267e+00)*S227+0.000000e+00*S228+(-8.572700e-03)*S229'
.param V100_part24='V100_part23+0.000000e+00*S230+9.770625e-02*S231+(-7.842413e-01)*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+(-1.064346e+00)*S238+(-6.367541e+00)*S239'
.param V100_part25='V100_part24+8.940539e-01*S240+0.000000e+00*S241+0.000000e+00*S242+7.020683e-01*S243+0.000000e+00*S244+0.000000e+00*S245+1.435797e-01*S246+(-4.016540e-01)*S247+0.000000e+00*S248+(-2.996422e-02)*S249'
.param V100_part26='V100_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+(-1.463556e+00)*S253+0.000000e+00*S254+(-1.041517e-02)*S255+(-9.186346e-02)*S256+(-1.628901e+00)*S257+2.860336e-01*S258+0.000000e+00*S259'
.param V100_part27='V100_part26+0.000000e+00*S260+0.000000e+00*S261+1.553794e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V100_part28='V100_part27+0.000000e+00*S270+(-7.205401e-01)*S271+(-8.429336e+00)*S272+0.000000e+00*S273+0.000000e+00*S274+(-7.116290e+00)*S275+(-7.144050e-01)*S276+0.000000e+00*S277+(-6.310180e+00)*S278+(-1.332224e+00)*S279'
.param V100_part29='V100_part28+0.000000e+00*S280+(-6.066719e+00)*S281+3.903494e+03*S282+(-3.544891e+00)*S283+(-8.995123e+00)*S284+0.000000e+00*S285+(-1.114755e+00)*S286+(-9.402924e-01)*S287+1.018175e+00*S288+0.000000e+00*S289'
.param V100_part30='V100_part29+0.000000e+00*S290+(-8.988126e-01)*S291+(-5.776119e-01)*S292+0.000000e+00*S293+(-1.098277e+00)*S294+(-1.517566e+00)*S295+0.000000e+00*S296+0.000000e+00*S297+(-2.852825e+00)*S298+0.000000e+00*S299'
.param V100_part31='V100_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+1.021682e+00*S303+0.000000e+00*S304+(-1.366867e+00)*S305+1.143631e+00*S306+(-9.700826e-01)*S307+(-3.334010e+00)*S308+(-9.952236e-01)*S309'
.param V100='V100_part31+(-3.322027e-01)*S310+(-4.583947e+00)*S311+0.000000e+00*S312+(-5.842605e-01)*S313+(-8.460099e+00)*S314'
.param V101_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V101_part2='V101_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V101_part3='V101_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+8.302454e-02*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V101_part4='V101_part3+6.273690e-01*S30+0.000000e+00*S31+0.000000e+00*S32+(-1.649221e+01)*S33+4.662698e-01*S34+(-1.867105e+02)*S35+1.443793e+01*S36+3.426894e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V101_part5='V101_part4+1.513119e-01*S40+1.104467e-01*S41+0.000000e+00*S42+(-6.873277e-02)*S43+2.794331e-01*S44+5.125856e-03*S45+8.487851e-02*S46+2.676241e-01*S47+0.000000e+00*S48+1.000000e+04*S49'
.param V101_part6='V101_part5+0.000000e+00*S50+0.000000e+00*S51+1.321211e-01*S52+0.000000e+00*S53+4.269917e-01*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+3.720959e-01*S59'
.param V101_part7='V101_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-4.833222e-02)*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V101_part8='V101_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+5.998606e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V101_part9='V101_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+1.680540e-01*S84+0.000000e+00*S85+(-1.766337e-02)*S86+6.557843e-02*S87+1.202397e-01*S88+1.185457e-02*S89'
.param V101_part10='V101_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+2.367328e-01*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V101_part11='V101_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+1.155386e-02*S108+0.000000e+00*S109'
.param V101_part12='V101_part11+0.000000e+00*S110+4.026251e-01*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V101_part13='V101_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V101_part14='V101_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+(-2.227731e-01)*S138+(-2.403684e-01)*S139'
.param V101_part15='V101_part14+0.000000e+00*S140+(-1.594644e-01)*S141+(-1.699874e-01)*S142+(-1.314828e-02)*S143+(-1.236030e-01)*S144+(-1.811974e-01)*S145+(-2.012735e-01)*S146+(-5.735360e-02)*S147+(-2.395648e-01)*S148+2.375008e-02*S149'
.param V101_part16='V101_part15+3.578912e-01*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+2.775829e-01*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V101_part17='V101_part16+0.000000e+00*S160+0.000000e+00*S161+6.515548e-01*S162+9.138621e-01*S163+5.995099e-01*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V101_part18='V101_part17+(-1.932788e+00)*S170+(-9.726678e-01)*S171+0.000000e+00*S172+0.000000e+00*S173+(-1.037291e-01)*S174+0.000000e+00*S175+(-1.162720e+00)*S176+(-5.733999e-03)*S177+9.421670e-01*S178+3.302897e-01*S179'
.param V101_part19='V101_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+4.862310e-01*S186+1.864437e+00*S187+0.000000e+00*S188+3.741924e+00*S189'
.param V101_part20='V101_part19+2.187151e+00*S190+(-9.986401e-01)*S191+0.000000e+00*S192+3.181732e+00*S193+0.000000e+00*S194+4.116635e-01*S195+4.191895e-01*S196+9.571460e-03*S197+0.000000e+00*S198+6.764181e-01*S199'
.param V101_part21='V101_part20+(-7.571976e-03)*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+3.991927e-01*S206+6.845002e-01*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V101_part22='V101_part21+0.000000e+00*S210+0.000000e+00*S211+(-3.187625e-05)*S212+0.000000e+00*S213+0.000000e+00*S214+1.409567e-01*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V101_part23='V101_part22+1.983942e+00*S220+0.000000e+00*S221+0.000000e+00*S222+1.183982e+00*S223+(-3.213961e+00)*S224+0.000000e+00*S225+0.000000e+00*S226+7.147438e-01*S227+0.000000e+00*S228+4.156365e-01*S229'
.param V101_part24='V101_part23+0.000000e+00*S230+9.357265e-01*S231+1.251543e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+1.521569e+00*S238+2.940283e+00*S239'
.param V101_part25='V101_part24+(-1.389253e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+(-4.623209e-01)*S243+0.000000e+00*S244+0.000000e+00*S245+6.085557e-01*S246+7.219627e-01*S247+0.000000e+00*S248+6.752467e-01*S249'
.param V101_part26='V101_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+1.846179e+00*S253+0.000000e+00*S254+4.691742e-01*S255+7.127520e-01*S256+1.657621e+00*S257+(-7.659288e-02)*S258+0.000000e+00*S259'
.param V101_part27='V101_part26+0.000000e+00*S260+0.000000e+00*S261+1.847516e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V101_part28='V101_part27+0.000000e+00*S270+1.235508e+00*S271+9.472894e+00*S272+0.000000e+00*S273+0.000000e+00*S274+7.401533e+00*S275+3.749345e-01*S276+0.000000e+00*S277+6.525285e+00*S278+1.950766e+00*S279'
.param V101_part29='V101_part28+0.000000e+00*S280+5.380390e+00*S281+5.208358e+03*S282+2.541706e+00*S283+6.190828e+00*S284+0.000000e+00*S285+1.014910e+00*S286+2.725926e+00*S287+(-7.946834e-02)*S288+0.000000e+00*S289'
.param V101_part30='V101_part29+0.000000e+00*S290+1.549650e+00*S291+1.006203e+00*S292+0.000000e+00*S293+1.447906e+00*S294+(-3.838770e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+1.019162e+00*S298+0.000000e+00*S299'
.param V101_part31='V101_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+5.192993e-01*S303+0.000000e+00*S304+8.456553e-01*S305+8.365801e-01*S306+3.050424e+00*S307+2.918567e+00*S308+2.685543e-01*S309'
.param V101='V101_part31+3.859353e+00*S310+4.404451e+00*S311+0.000000e+00*S312+(-2.425701e-01)*S313+6.621285e+00*S314'
.param V102_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V102_part2='V102_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V102_part3='V102_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+(-4.574237e-02)*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V102_part4='V102_part3+2.845365e-02*S30+0.000000e+00*S31+0.000000e+00*S32+(-4.318076e+01)*S33+2.043102e-01*S34+2.378299e+01*S35+9.584778e+02*S36+4.546083e-01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V102_part5='V102_part4+1.601381e-01*S40+4.875438e-02*S41+0.000000e+00*S42+9.112182e-02*S43+1.807210e-01*S44+(-3.235287e-01)*S45+(-1.715268e-01)*S46+3.690584e-02*S47+0.000000e+00*S48+1.000000e+04*S49'
.param V102_part6='V102_part5+0.000000e+00*S50+0.000000e+00*S51+8.771973e-02*S52+0.000000e+00*S53+5.095123e-01*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+1.801754e-01*S59'
.param V102_part7='V102_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+2.238728e-02*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V102_part8='V102_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+3.697642e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V102_part9='V102_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+(-2.124167e-01)*S84+0.000000e+00*S85+(-7.170920e-02)*S86+(-1.385825e-01)*S87+(-2.997202e-02)*S88+(-3.107642e-03)*S89'
.param V102_part10='V102_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+(-4.931313e-02)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V102_part11='V102_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+2.468118e-02*S108+0.000000e+00*S109'
.param V102_part12='V102_part11+0.000000e+00*S110+6.006633e-01*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V102_part13='V102_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V102_part14='V102_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+(-6.349777e-02)*S138+1.643440e-01*S139'
.param V102_part15='V102_part14+0.000000e+00*S140+(-1.657746e-01)*S141+1.559349e-02*S142+2.815825e-03*S143+(-6.017056e-02)*S144+5.871416e-02*S145+(-6.085297e-02)*S146+(-3.119508e-02)*S147+1.107040e-02*S148+1.564264e-01*S149'
.param V102_part16='V102_part15+(-4.072266e-02)*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+(-3.941656e-02)*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V102_part17='V102_part16+0.000000e+00*S160+0.000000e+00*S161+9.348399e-01*S162+1.686842e+00*S163+2.708192e-01*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V102_part18='V102_part17+(-5.507076e-01)*S170+6.755130e-01*S171+0.000000e+00*S172+0.000000e+00*S173+(-1.332700e+00)*S174+0.000000e+00*S175+(-1.879192e-01)*S176+2.716011e-01*S177+(-5.310338e-01)*S178+(-1.361414e+00)*S179'
.param V102_part19='V102_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+3.998199e-01*S186+2.285654e+00*S187+0.000000e+00*S188+1.295031e+01*S189'
.param V102_part20='V102_part19+5.731459e+00*S190+(-1.106391e+00)*S191+0.000000e+00*S192+7.099190e+00*S193+0.000000e+00*S194+3.008199e-01*S195+(-5.055304e-05)*S196+3.018870e-04*S197+0.000000e+00*S198+4.171639e-01*S199'
.param V102_part21='V102_part20+1.080622e-01*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+(-1.272550e+00)*S206+(-4.810438e-01)*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V102_part22='V102_part21+0.000000e+00*S210+0.000000e+00*S211+(-1.119615e+00)*S212+0.000000e+00*S213+0.000000e+00*S214+(-7.878422e-01)*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V102_part23='V102_part22+7.474671e+00*S220+0.000000e+00*S221+0.000000e+00*S222+7.054302e+00*S223+6.125400e+00*S224+0.000000e+00*S225+0.000000e+00*S226+1.764011e+00*S227+0.000000e+00*S228+4.372256e-01*S229'
.param V102_part24='V102_part23+0.000000e+00*S230+1.327010e+00*S231+5.025926e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+6.138519e+00*S238+1.245034e+01*S239'
.param V102_part25='V102_part24+(-7.116065e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+3.586815e-02*S243+0.000000e+00*S244+0.000000e+00*S245+6.015431e-01*S246+1.440938e+00*S247+0.000000e+00*S248+9.923331e-01*S249'
.param V102_part26='V102_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+4.296455e+00*S253+0.000000e+00*S254+5.628665e-01*S255+5.893464e-01*S256+2.799882e+00*S257+(-6.258857e-02)*S258+0.000000e+00*S259'
.param V102_part27='V102_part26+0.000000e+00*S260+0.000000e+00*S261+1.100751e+00*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V102_part28='V102_part27+0.000000e+00*S270+1.361441e+00*S271+9.022927e+00*S272+0.000000e+00*S273+0.000000e+00*S274+7.008196e+00*S275+2.720863e+00*S276+0.000000e+00*S277+4.117153e+00*S278+7.849707e+00*S279'
.param V102_part29='V102_part28+0.000000e+00*S280+3.135029e+00*S281+1.000000e+04*S282+8.662763e+00*S283+7.009993e+00*S284+0.000000e+00*S285+3.022710e+00*S286+8.455449e-01*S287+1.421947e+00*S288+0.000000e+00*S289'
.param V102_part30='V102_part29+0.000000e+00*S290+5.832017e+00*S291+5.513085e+00*S292+0.000000e+00*S293+7.025232e+00*S294+7.116011e+00*S295+0.000000e+00*S296+0.000000e+00*S297+1.136655e+01*S298+0.000000e+00*S299'
.param V102_part31='V102_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+6.535097e-01*S303+0.000000e+00*S304+2.111675e+00*S305+6.757219e-01*S306+8.176397e-01*S307+2.904506e+00*S308+3.777739e+00*S309'
.param V102='V102_part31+(-1.078182e+00)*S310+1.933689e+00*S311+0.000000e+00*S312+3.380640e+00*S313+4.534119e+00*S314'
.param V103_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V103_part2='V103_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V103_part3='V103_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+6.614798e-02*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V103_part4='V103_part3+4.025522e-02*S30+0.000000e+00*S31+0.000000e+00*S32+(-1.356580e+02)*S33+2.287531e-02*S34+1.640261e+01*S35+(-3.563011e+02)*S36+(-2.642042e-02)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V103_part5='V103_part4+5.374457e-02*S40+5.459786e-02*S41+0.000000e+00*S42+4.067455e-02*S43+1.045894e-01*S44+(-2.785455e-02)*S45+(-6.317573e-02)*S46+(-4.992580e-02)*S47+0.000000e+00*S48+(-1.966384e+03)*S49'
.param V103_part6='V103_part5+0.000000e+00*S50+0.000000e+00*S51+(-1.935050e-02)*S52+0.000000e+00*S53+5.693234e-02*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+(-8.932684e-02)*S59'
.param V103_part7='V103_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+3.351126e-02*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V103_part8='V103_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+1.256552e-01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V103_part9='V103_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+5.793261e-02*S84+0.000000e+00*S85+2.504394e-02*S86+8.436339e-02*S87+6.867770e-02*S88+2.175990e-02*S89'
.param V103_part10='V103_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+(-1.709178e-01)*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V103_part11='V103_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+3.991897e-02*S108+0.000000e+00*S109'
.param V103_part12='V103_part11+0.000000e+00*S110+8.322752e-02*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V103_part13='V103_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V103_part14='V103_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+2.060802e-01*S138+2.711714e-02*S139'
.param V103_part15='V103_part14+0.000000e+00*S140+1.878521e-01*S141+5.064929e-01*S142+2.608681e-02*S143+3.155172e-01*S144+3.396487e-01*S145+3.007627e-01*S146+3.691858e-01*S147+4.580493e-01*S148+5.446775e-02*S149'
.param V103_part16='V103_part15+(-7.925580e-02)*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+(-1.450319e-01)*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V103_part17='V103_part16+0.000000e+00*S160+0.000000e+00*S161+8.931441e-02*S162+1.082847e+00*S163+5.425519e-01*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V103_part18='V103_part17+(-1.156767e+00)*S170+(-1.402459e-01)*S171+0.000000e+00*S172+0.000000e+00*S173+(-1.211165e-01)*S174+0.000000e+00*S175+(-1.172911e+00)*S176+1.355928e-01*S177+(-1.239157e+00)*S178+(-3.530093e-01)*S179'
.param V103_part19='V103_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+9.423004e-01*S186+1.893068e+00*S187+0.000000e+00*S188+5.046251e-01*S189'
.param V103_part20='V103_part19+3.070686e+00*S190+2.808200e-01*S191+0.000000e+00*S192+4.171150e+00*S193+0.000000e+00*S194+2.782201e-01*S195+2.920284e-02*S196+3.955762e-02*S197+0.000000e+00*S198+2.098242e-01*S199'
.param V103_part21='V103_part20+9.036547e-02*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+1.259373e+00*S206+4.790097e-01*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V103_part22='V103_part21+0.000000e+00*S210+0.000000e+00*S211+(-1.283396e-02)*S212+0.000000e+00*S213+0.000000e+00*S214+(-4.179024e-02)*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V103_part23='V103_part22+7.319892e-01*S220+0.000000e+00*S221+0.000000e+00*S222+5.450923e-01*S223+2.016928e-01*S224+0.000000e+00*S225+0.000000e+00*S226+(-1.619827e-02)*S227+0.000000e+00*S228+6.002891e-01*S229'
.param V103_part24='V103_part23+0.000000e+00*S230+3.590800e-01*S231+1.496919e+00*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+8.752140e-01*S238+1.650854e+00*S239'
.param V103_part25='V103_part24+(-9.195935e-02)*S240+0.000000e+00*S241+0.000000e+00*S242+(-2.097817e-01)*S243+0.000000e+00*S244+0.000000e+00*S245+2.349259e-01*S246+6.997002e-01*S247+0.000000e+00*S248+1.006990e-01*S249'
.param V103_part26='V103_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+1.588131e+00*S253+0.000000e+00*S254+1.020443e-01*S255+1.464714e-01*S256+(-1.001444e-01)*S257+3.118383e-02*S258+0.000000e+00*S259'
.param V103_part27='V103_part26+0.000000e+00*S260+0.000000e+00*S261+(-4.813231e-01)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V103_part28='V103_part27+0.000000e+00*S270+1.309727e-01*S271+3.193211e-01*S272+0.000000e+00*S273+0.000000e+00*S274+(-1.133216e-01)*S275+9.224035e-01*S276+0.000000e+00*S277+4.850962e-01*S278+1.630939e+00*S279'
.param V103_part29='V103_part28+0.000000e+00*S280+3.116410e-01*S281+7.179754e+03*S282+1.843661e+00*S283+(-1.470253e-01)*S284+0.000000e+00*S285+(-2.866198e-01)*S286+(-9.886389e-02)*S287+(-6.919135e-01)*S288+0.000000e+00*S289'
.param V103_part30='V103_part29+0.000000e+00*S290+1.200448e+00*S291+1.295264e+00*S292+0.000000e+00*S293+1.190350e+00*S294+1.752504e-02*S295+0.000000e+00*S296+0.000000e+00*S297+8.109819e-01*S298+0.000000e+00*S299'
.param V103_part31='V103_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+(-2.424185e-02)*S303+0.000000e+00*S304+6.411157e-01*S305+(-1.245037e-01)*S306+4.873654e-01*S307+5.936610e-01*S308+2.351990e-01*S309'
.param V103='V103_part31+1.177097e+00*S310+1.802100e-01*S311+0.000000e+00*S312+3.065172e-01*S313+3.398475e-01*S314'
.param V104_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V104_part2='V104_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V104_part3='V104_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+(-2.307430e-03)*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V104_part4='V104_part3+2.373509e-03*S30+0.000000e+00*S31+0.000000e+00*S32+(-9.408553e-02)*S33+(-3.197259e-03)*S34+(-1.943914e-01)*S35+4.140033e-01*S36+(-8.866594e-02)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V104_part5='V104_part4+(-6.113455e-03)*S40+(-4.689768e-03)*S41+0.000000e+00*S42+(-4.135390e-03)*S43+(-2.724578e-03)*S44+(-2.894245e-02)*S45+(-2.958635e-02)*S46+(-4.898890e-02)*S47+0.000000e+00*S48+1.000000e+04*S49'
.param V104_part6='V104_part5+0.000000e+00*S50+0.000000e+00*S51+(-8.748346e-02)*S52+0.000000e+00*S53+(-1.176788e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+2.115496e-02*S59'
.param V104_part7='V104_part6+0.000000e+00*S60+0.000000e+00*S61+0.000000e+00*S62+0.000000e+00*S63+0.000000e+00*S64+0.000000e+00*S65+(-7.675091e-02)*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V104_part8='V104_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+2.379368e-03*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V104_part9='V104_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+(-4.868257e-02)*S84+0.000000e+00*S85+(-5.857604e-02)*S86+(-7.736785e-02)*S87+(-3.436357e-02)*S88+(-3.667414e-02)*S89'
.param V104_part10='V104_part9+0.000000e+00*S90+0.000000e+00*S91+0.000000e+00*S92+0.000000e+00*S93+0.000000e+00*S94+2.012468e-02*S95+0.000000e+00*S96+0.000000e+00*S97+0.000000e+00*S98+0.000000e+00*S99'
.param V104_part11='V104_part10+0.000000e+00*S100+0.000000e+00*S101+0.000000e+00*S102+0.000000e+00*S103+0.000000e+00*S104+0.000000e+00*S105+0.000000e+00*S106+0.000000e+00*S107+3.797661e-03*S108+0.000000e+00*S109'
.param V104_part12='V104_part11+0.000000e+00*S110+(-1.666923e-01)*S111+0.000000e+00*S112+0.000000e+00*S113+0.000000e+00*S114+0.000000e+00*S115+0.000000e+00*S116+0.000000e+00*S117+0.000000e+00*S118+0.000000e+00*S119'
.param V104_part13='V104_part12+0.000000e+00*S120+0.000000e+00*S121+0.000000e+00*S122+0.000000e+00*S123+0.000000e+00*S124+0.000000e+00*S125+0.000000e+00*S126+0.000000e+00*S127+0.000000e+00*S128+0.000000e+00*S129'
.param V104_part14='V104_part13+0.000000e+00*S130+0.000000e+00*S131+0.000000e+00*S132+0.000000e+00*S133+0.000000e+00*S134+0.000000e+00*S135+0.000000e+00*S136+0.000000e+00*S137+9.653920e-03*S138+(-3.308195e-02)*S139'
.param V104_part15='V104_part14+0.000000e+00*S140+1.156224e-02*S141+1.696391e-02*S142+(-7.719889e-03)*S143+3.543446e-03*S144+1.154098e-02*S145+7.102839e-03*S146+(-4.172229e-03)*S147+(-3.265071e-04)*S148+2.002978e-02*S149'
.param V104_part16='V104_part15+4.041031e-03*S150+0.000000e+00*S151+0.000000e+00*S152+0.000000e+00*S153+2.722545e-02*S154+0.000000e+00*S155+0.000000e+00*S156+0.000000e+00*S157+0.000000e+00*S158+0.000000e+00*S159'
.param V104_part17='V104_part16+0.000000e+00*S160+0.000000e+00*S161+(-4.029373e-01)*S162+(-5.337579e-01)*S163+(-3.514094e-01)*S164+0.000000e+00*S165+0.000000e+00*S166+0.000000e+00*S167+0.000000e+00*S168+0.000000e+00*S169'
.param V104_part18='V104_part17+(-4.338052e-02)*S170+5.102018e-01*S171+0.000000e+00*S172+0.000000e+00*S173+(-3.670387e-01)*S174+0.000000e+00*S175+(-5.357624e-01)*S176+(-3.911264e-01)*S177+(-9.338326e-01)*S178+(-6.003541e-01)*S179'
.param V104_part19='V104_part18+0.000000e+00*S180+0.000000e+00*S181+0.000000e+00*S182+0.000000e+00*S183+0.000000e+00*S184+0.000000e+00*S185+(-2.797107e-01)*S186+(-4.464921e-01)*S187+0.000000e+00*S188+(-8.948994e-01)*S189'
.param V104_part20='V104_part19+(-3.899699e-01)*S190+(-2.869774e-01)*S191+0.000000e+00*S192+(-5.630613e-01)*S193+0.000000e+00*S194+(-2.280313e-01)*S195+(-7.523207e-03)*S196+9.989143e-03*S197+0.000000e+00*S198+3.331098e-02*S199'
.param V104_part21='V104_part20+1.473361e-02*S200+0.000000e+00*S201+0.000000e+00*S202+0.000000e+00*S203+0.000000e+00*S204+0.000000e+00*S205+(-1.318317e-02)*S206+(-6.520353e-01)*S207+0.000000e+00*S208+0.000000e+00*S209'
.param V104_part22='V104_part21+0.000000e+00*S210+0.000000e+00*S211+2.153076e-02*S212+0.000000e+00*S213+0.000000e+00*S214+1.385154e-01*S215+0.000000e+00*S216+0.000000e+00*S217+0.000000e+00*S218+0.000000e+00*S219'
.param V104_part23='V104_part22+(-1.926715e-01)*S220+0.000000e+00*S221+0.000000e+00*S222+(-2.369889e-01)*S223+(-8.163803e-01)*S224+0.000000e+00*S225+0.000000e+00*S226+(-1.121639e-02)*S227+0.000000e+00*S228+(-1.061328e-01)*S229'
.param V104_part24='V104_part23+0.000000e+00*S230+(-2.222612e-01)*S231+(-4.674811e-01)*S232+0.000000e+00*S233+0.000000e+00*S234+0.000000e+00*S235+0.000000e+00*S236+0.000000e+00*S237+(-1.163946e+00)*S238+(-1.271143e+00)*S239'
.param V104_part25='V104_part24+(-3.315055e-01)*S240+0.000000e+00*S241+0.000000e+00*S242+(-2.129719e-01)*S243+0.000000e+00*S244+0.000000e+00*S245+(-1.893731e-01)*S246+(-9.643179e-02)*S247+0.000000e+00*S248+(-1.929312e-01)*S249'
.param V104_part26='V104_part25+0.000000e+00*S250+0.000000e+00*S251+0.000000e+00*S252+(-4.200015e-01)*S253+0.000000e+00*S254+2.688324e-02*S255+5.077852e-02*S256+5.853893e-02*S257+(-1.449944e-02)*S258+0.000000e+00*S259'
.param V104_part27='V104_part26+0.000000e+00*S260+0.000000e+00*S261+(-9.342381e-01)*S262+0.000000e+00*S263+0.000000e+00*S264+0.000000e+00*S265+0.000000e+00*S266+0.000000e+00*S267+0.000000e+00*S268+0.000000e+00*S269'
.param V104_part28='V104_part27+0.000000e+00*S270+1.024939e-01*S271+4.232891e-01*S272+0.000000e+00*S273+0.000000e+00*S274+2.221931e-01*S275+(-4.673487e-03)*S276+0.000000e+00*S277+2.640401e-01*S278+(-5.425136e-01)*S279'
.param V104_part29='V104_part28+0.000000e+00*S280+3.672116e-01*S281+4.614173e+02*S282+(-2.423187e-01)*S283+5.961112e-01*S284+0.000000e+00*S285+1.479871e-01*S286+(-1.401013e-01)*S287+(-9.385189e-02)*S288+0.000000e+00*S289'
.param V104_part30='V104_part29+0.000000e+00*S290+(-3.922642e-01)*S291+(-6.357058e-01)*S292+0.000000e+00*S293+(-5.200104e-01)*S294+(-3.856007e-01)*S295+0.000000e+00*S296+0.000000e+00*S297+(-5.249346e-01)*S298+0.000000e+00*S299'
.param V104_part31='V104_part30+0.000000e+00*S300+0.000000e+00*S301+0.000000e+00*S302+(-5.386705e-01)*S303+0.000000e+00*S304+2.869390e-01*S305+(-5.853674e-01)*S306+(-2.768839e-01)*S307+2.782971e-01*S308+1.832584e-04*S309'
.param V104='V104_part31+(-6.104092e-01)*S310+3.215396e-01*S311+0.000000e+00*S312+(-4.914550e-02)*S313+4.744734e-01*S314'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='0.7064*_P21'
.param _P23='0.7064*_P21'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='V35+V36*rad_+V37*w_'
.param _P28='_P27+V38*gdis_+V39*spacing_'
.param _P29='0.5*(_P28+sqrt(_P28*_P28+0.001))'
.param _P30='V40+V41*rad_+V42*w_'
.param _P31='_P30+V43*gdis_+V44*spacing_'
.param _P32='0.5*(_P31+sqrt(_P31*_P31+0.001))'
.param _P33='V45+V46*rad_+V47*w_'
.param _P34='_P33+V48*gdis_+V49*spacing_'
.param _P35='0.5*(_P34+sqrt(_P34*_P34+0.001))'
.param _P36='V50+V51*rad_+V52*w_'
.param _P37='_P36+V53*gdis_+V54*spacing_'
.param _P38='0.5*(_P37+sqrt(_P37*_P37+0.001))'
.param _P39='V55+V56*rad_+V57*w_'
.param _P40='_P39+V58*gdis_+V59*spacing_'
.param _P41='0.5*(_P40+sqrt(_P40*_P40+0.001))'
.param _P42='V60+V61*rad_+V62*w_'
.param _P43='_P42+V63*gdis_+V64*spacing_'
.param _P44='0.5*(_P43+sqrt(_P43*_P43+0.001))'
.param _P45='V65+V66*rad_+V67*w_'
.param _P46='_P45+V68*gdis_+V69*spacing_'
.param _P47='0.5*(_P46+sqrt(_P46*_P46+0.001))'
.param _P48='V70+V71*rad_+V72*w_'
.param _P49='_P48+V73*gdis_+V74*spacing_'
.param _P50='0.5*(_P49+sqrt(_P49*_P49+0.001))'
.param _P51='1e-14*_P26'
.param _P52='100*_P29'
.param _P53='1e-15*_P32'
.param _P54='1e-14*_P35'
.param _P55='100*_P38'
.param _P56='1e-15*_P41'
.param _P57='1e-14*_P44'
.param _P58='100*_P47'
.param _P59='1e-15*_P50'
.param _P60='V75+V76*rad_+V77*w_'
.param _P61='_P60+V78*gdis_+V79*spacing_'
.param _P62='0.5*(_P61+sqrt(_P61*_P61+0.001))'
.param _P63='V80+V81*rad_+V82*w_'
.param _P64='_P63+V83*gdis_+V84*spacing_'
.param _P65='0.5*(_P64+sqrt(_P64*_P64+0.001))'
.param _P66='100*_P62'
.param _P67='1e-13*_P65'
.param _P68='V85+V86*rad_+V87*w_'
.param _P69='_P68+V88*gdis_+V89*spacing_'
.param _P70='0.5*(_P69+sqrt(_P69*_P69+0.001))'
.param _P71='V90+V91*rad_+V92*w_'
.param _P72='_P71+V93*gdis_+V94*spacing_'
.param _P73='0.5*(_P72+sqrt(_P72*_P72+0.001))'
.param _P74='100*_P70'
.param _P75='1e-13*_P73'
.param _P76='V95+V96*rad_+V97*w_'
.param _P77='_P76+V98*gdis_+V99*spacing_'
.param _P78='0.5*(_P77+sqrt(_P77*_P77+0.001))'
.param _P79='V100+V101*rad_+V102*w_'
.param _P80='_P79+V103*gdis_+V104*spacing_'
.param _P81='0.5*(_P80+sqrt(_P80*_P80+0.001))'
.param _P82='100*_P78'
.param _P83='1e-13*_P81'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P22
k2 ls2_1 ls1_2 K=_P23
c_1_sub top _n1_1_sub '_P51*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P52*rsub_indfac'
cs_1_sub _n1_1_sub gnode '_P53* csub_indfac'
c_2_sub bottom _n1_2_sub '_P54*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P55*rsub_indfac'
cs_2_sub _n1_2_sub gnode '_P56* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P57*((1/(12.503905+(1.7014125)*(lay-2+(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P58*rsub_indfac'
cs_3_sub _n1_3_sub gnode '_P59* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P66*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P67* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P74*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P75* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P82*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P83* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_std_mza_a

.subckt spiral_sym_mza_a top bottom gnode rad=6e-05 w=9e-06 nr=1 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+4.952313e-01*S9'
.param V0_part2='V0_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-7.028282e+00)*S17+0.000000e+00*S18+3.290131e+00*S19'
.param V0_part3='V0_part2+4.446931e+00*S20+0.000000e+00*S21+0.000000e+00*S22+2.342934e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V0_part4='V0_part3+(-5.059648e-01)*S30+7.438661e+00*S31+(-1.075994e+01)*S32+4.830632e+00*S33+3.424914e+00*S34+3.188419e+00*S35+7.306666e+00*S36+(-2.517529e+00)*S37+7.731952e+00*S38+(-1.858655e+01)*S39'
.param V0_part5='V0_part4+0.000000e+00*S40+0.000000e+00*S41+(-1.906054e+01)*S42+0.000000e+00*S43+1.648050e+00*S44+2.225816e+00*S45+(-5.947264e+00)*S46+1.685062e+01*S47+(-1.639869e+01)*S48+2.798626e+01*S49'
.param V0_part6='V0_part5+(-7.874431e+01)*S50+(-3.425037e-01)*S51+(-2.370221e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+(-1.052561e+01)*S55+0.000000e+00*S56+(-2.916631e-01)*S57+(-1.598684e+01)*S58+(-8.562768e+01)*S59'
.param V0_part7='V0_part6+1.023574e+01*S60+(-3.552444e+01)*S61+0.000000e+00*S62+2.430147e+00*S63+(-3.410050e+01)*S64+0.000000e+00*S65+3.368019e+01*S66+0.000000e+00*S67+0.000000e+00*S68+4.694114e+01*S69'
.param V0_part8='V0_part7+0.000000e+00*S70+0.000000e+00*S71+5.414101e+01*S72+0.000000e+00*S73+0.000000e+00*S74+4.556354e+01*S75+3.448217e+01*S76+2.158418e+01*S77+3.767629e+01*S78+5.406255e+01*S79'
.param V0='V0_part8+3.241366e+01*S80+6.169724e+01*S81+0.000000e+00*S82+3.762672e+01*S83+6.777559e+01*S84+0.000000e+00*S85+6.156588e+01*S86+4.345486e+01*S87+3.853020e+01*S88+0.000000e+00*S89'
.param V1_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+4.596469e+00*S9'
.param V1_part2='V1_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+1.919167e+01*S17+0.000000e+00*S18+1.053324e+01*S19'
.param V1_part3='V1_part2+5.977725e+00*S20+0.000000e+00*S21+0.000000e+00*S22+1.038714e+01*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V1_part4='V1_part3+4.569331e+01*S30+1.818799e+01*S31+5.553389e+01*S32+3.667998e+01*S33+3.821451e+01*S34+4.668936e+01*S35+3.142447e+01*S36+4.836441e+01*S37+3.349033e+01*S38+3.866969e+01*S39'
.param V1_part5='V1_part4+0.000000e+00*S40+0.000000e+00*S41+2.842993e+01*S42+0.000000e+00*S43+4.048611e+01*S44+8.365709e+01*S45+1.087847e+02*S46+5.812541e+01*S47+4.431834e+01*S48+2.575746e+01*S49'
.param V1_part6='V1_part5+8.422755e+01*S50+2.333603e+01*S51+5.343775e+01*S52+0.000000e+00*S53+0.000000e+00*S54+2.950799e+01*S55+0.000000e+00*S56+1.489956e+01*S57+2.941771e+01*S58+6.556098e+01*S59'
.param V1_part7='V1_part6+7.996998e+01*S60+8.358161e+01*S61+0.000000e+00*S62+1.847721e+01*S63+7.333438e+01*S64+0.000000e+00*S65+1.150677e+00*S66+0.000000e+00*S67+0.000000e+00*S68+1.619181e+00*S69'
.param V1_part8='V1_part7+0.000000e+00*S70+0.000000e+00*S71+2.729645e+01*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.414246e+01)*S75+2.939250e+01*S76+6.931390e+01*S77+1.620945e+00*S78+1.338857e+01*S79'
.param V1='V1_part8+1.380001e+01*S80+2.530005e+00*S81+0.000000e+00*S82+1.102348e+01*S83+1.425542e+01*S84+0.000000e+00*S85+2.120307e+01*S86+6.560566e+01*S87+5.463709e+01*S88+0.000000e+00*S89'
.param V2_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-4.429746e+00)*S9'
.param V2_part2='V2_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+2.082556e+01*S17+0.000000e+00*S18+6.156655e+00*S19'
.param V2_part3='V2_part2+7.419002e+00*S20+0.000000e+00*S21+0.000000e+00*S22+8.317426e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V2_part4='V2_part3+3.341317e+00*S30+1.805373e+01*S31+6.201157e+01*S32+8.291409e+00*S33+9.341009e+00*S34+9.295195e+00*S35+(-9.203402e+00)*S36+(-3.026727e+00)*S37+1.067136e+01*S38+4.704129e+01*S39'
.param V2_part5='V2_part4+0.000000e+00*S40+0.000000e+00*S41+6.460579e+01*S42+0.000000e+00*S43+(-1.125769e+01)*S44+3.235140e+00*S45+1.047491e+01*S46+(-8.786623e-01)*S47+8.337666e+01*S48+(-1.672684e+01)*S49'
.param V2_part6='V2_part5+1.353652e+02*S50+6.835759e+01*S51+1.000447e+02*S52+0.000000e+00*S53+0.000000e+00*S54+1.088933e+02*S55+0.000000e+00*S56+7.561054e+01*S57+1.231387e+02*S58+1.571913e+02*S59'
.param V2_part7='V2_part6+8.131852e+00*S60+1.297340e+02*S61+0.000000e+00*S62+1.014194e+02*S63+1.437780e+02*S64+0.000000e+00*S65+(-1.129077e+01)*S66+0.000000e+00*S67+0.000000e+00*S68+(-2.659510e+01)*S69'
.param V2_part8='V2_part7+0.000000e+00*S70+0.000000e+00*S71+6.263070e+01*S72+0.000000e+00*S73+0.000000e+00*S74+7.678661e+00*S75+(-8.301678e+00)*S76+(-4.382772e+00)*S77+3.662074e+01*S78+(-2.175070e+01)*S79'
.param V2='V2_part8+(-9.603959e+00)*S80+(-1.108409e+01)*S81+0.000000e+00*S82+(-1.258108e+01)*S83+(-3.907825e+01)*S84+0.000000e+00*S85+(-5.127929e+01)*S86+1.637605e+02*S87+1.618397e+02*S88+0.000000e+00*S89'
.param V3_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+3.881689e-01*S9'
.param V3_part2='V3_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-4.780587e-01)*S17+0.000000e+00*S18+(-1.820922e+00)*S19'
.param V3_part3='V3_part2+(-2.595671e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+4.564224e-01*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V3_part4='V3_part3+(-1.389692e-01)*S30+(-2.696143e+00)*S31+(-9.015771e-01)*S32+(-1.330829e+00)*S33+1.322208e+00*S34+(-2.846701e+00)*S35+(-2.734481e+00)*S36+(-1.269486e+00)*S37+(-1.741748e+00)*S38+(-2.179191e-01)*S39'
.param V3_part5='V3_part4+0.000000e+00*S40+0.000000e+00*S41+3.032913e-02*S42+0.000000e+00*S43+(-5.619527e-01)*S44+(-1.672603e-01)*S45+(-1.120580e-01)*S46+1.658282e-01*S47+(-4.057245e-01)*S48+(-8.246484e-02)*S49'
.param V3_part6='V3_part5+6.720079e-01*S50+(-1.843195e+00)*S51+(-1.549609e-01)*S52+0.000000e+00*S53+0.000000e+00*S54+3.132534e-01*S55+0.000000e+00*S56+(-5.265399e-02)*S57+1.410384e+00*S58+1.569095e-01*S59'
.param V3_part7='V3_part6+(-1.608422e-01)*S60+1.120056e+00*S61+0.000000e+00*S62+3.834522e-01*S63+(-9.327577e-01)*S64+0.000000e+00*S65+4.616354e-01*S66+0.000000e+00*S67+0.000000e+00*S68+1.980202e+00*S69'
.param V3_part8='V3_part7+0.000000e+00*S70+0.000000e+00*S71+4.970995e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.127334e+00*S75+(-1.065482e+00)*S76+(-2.426324e+00)*S77+9.221926e-01*S78+9.194758e-01*S79'
.param V3='V3_part8+(-1.404320e-01)*S80+1.373846e+00*S81+0.000000e+00*S82+(-4.400327e-01)*S83+1.169367e+00*S84+0.000000e+00*S85+(-1.600707e+00)*S86+9.160938e+00*S87+1.742008e+01*S88+0.000000e+00*S89'
.param V4_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+(-1.215840e-01)*S9'
.param V4_part2='V4_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+(-4.386690e+00)*S17+0.000000e+00*S18+(-4.042339e+00)*S19'
.param V4_part3='V4_part2+(-5.434052e+00)*S20+0.000000e+00*S21+0.000000e+00*S22+(-7.330733e+00)*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V4_part4='V4_part3+(-6.428331e+00)*S30+(-7.414410e+00)*S31+(-1.041809e+01)*S32+(-1.082063e+01)*S33+(-9.515932e+00)*S34+(-1.320728e+01)*S35+(-9.783268e+00)*S36+(-1.103412e+01)*S37+(-1.484050e+01)*S38+(-1.347236e+01)*S39'
.param V4_part5='V4_part4+0.000000e+00*S40+0.000000e+00*S41+(-1.462295e+01)*S42+0.000000e+00*S43+(-1.149564e+01)*S44+(-1.279123e+01)*S45+(-1.258904e+01)*S46+(-2.018186e+01)*S47+(-1.385191e+01)*S48+(-1.615898e+01)*S49'
.param V4_part6='V4_part5+(-2.757463e+01)*S50+(-1.730239e+01)*S51+(-2.122037e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+(-2.488890e+01)*S55+0.000000e+00*S56+(-2.214514e+01)*S57+(-2.838874e+01)*S58+(-3.861005e+01)*S59'
.param V4_part7='V4_part6+(-1.903823e+01)*S60+(-1.863265e+01)*S61+0.000000e+00*S62+(-2.437825e+01)*S63+(-3.065740e+01)*S64+0.000000e+00*S65+(-6.892854e+00)*S66+0.000000e+00*S67+0.000000e+00*S68+(-1.225320e+01)*S69'
.param V4_part8='V4_part7+0.000000e+00*S70+0.000000e+00*S71+(-3.829569e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-2.247919e+01)*S75+(-1.380718e+01)*S76+(-2.133814e+01)*S77+(-1.909951e+01)*S78+(-2.745402e+01)*S79'
.param V4='V4_part8+(-9.772797e+00)*S80+(-3.214390e+01)*S81+0.000000e+00*S82+(-1.009995e+01)*S83+(-3.794926e+01)*S84+0.000000e+00*S85+(-1.765865e+01)*S86+(-4.859081e+01)*S87+(-5.455188e+01)*S88+0.000000e+00*S89'
.param V5_part1='(-6.019760e-01)*S0+3.121107e+00*S1+1.108870e+00*S2+(-1.797989e+00)*S3+3.861878e-01*S4+4.491455e-01*S5+(-7.040429e-01)*S6+2.880753e-02*S7+4.825635e-01*S8+(-8.278623e-01)*S9'
.param V5_part2='V5_part1+1.752970e-01*S10+1.304031e+00*S11+(-3.034422e-01)*S12+2.744573e+00*S13+3.184146e+00*S14+(-6.962602e-01)*S15+1.934595e+00*S16+2.916786e-01*S17+2.139266e-02*S18+1.021967e+00*S19'
.param V5_part3='V5_part2+1.230364e-02*S20+(-2.628273e-01)*S21+3.804176e+00*S22+6.328914e-01*S23+(-4.481347e-01)*S24+(-2.073048e-01)*S25+(-4.170904e-02)*S26+(-4.691123e-01)*S27+(-2.300542e-01)*S28+3.315872e+00*S29'
.param V5_part4='V5_part3+2.941414e+00*S30+2.812793e+00*S31+1.278445e+00*S32+1.960962e+00*S33+7.187382e-01*S34+8.533639e-01*S35+4.765476e-01*S36+2.267520e+00*S37+6.569372e-01*S38+1.424240e+00*S39'
.param V5_part5='V5_part4+(-3.403543e+00)*S40+1.562198e+00*S41+(-8.489246e-01)*S42+(-2.665282e-01)*S43+2.998783e-01*S44+7.109428e-02*S45+8.799654e-01*S46+5.243440e-01*S47+3.595476e+00*S48+6.602342e+00*S49'
.param V5_part6='V5_part5+1.306260e+00*S50+(-4.718496e-01)*S51+2.685379e+00*S52+2.983633e-01*S53+1.966690e+01*S54+4.277775e-01*S55+3.713092e+00*S56+1.441018e+01*S57+3.904485e-01*S58+2.318626e+00*S59'
.param V5_part7='V5_part6+5.511249e-01*S60+9.832859e-01*S61+9.903633e-01*S62+1.748667e+01*S63+8.645331e-01*S64+1.130673e+01*S65+9.876954e+00*S66+7.182048e+01*S67+2.163647e+00*S68+4.248054e+01*S69'
.param V5_part8='V5_part7+1.123015e+02*S70+4.462278e+00*S71+2.988249e+02*S72+1.542187e+02*S73+3.531628e+00*S74+1.674069e+01*S75+8.191540e+00*S76+1.066572e+01*S77+3.805810e+01*S78+2.655519e+01*S79'
.param V5='V5_part8+1.058735e+01*S80+8.410193e+01*S81+1.052606e+02*S82+1.289967e+01*S83+1.517947e+02*S84+1.037817e+02*S85+1.853872e+01*S86+2.598570e+02*S87+(-8.623139e+00)*S88+1.292101e+00*S89'
.param V6_part1='7.223404e-01*S0+7.527014e+00*S1+(-1.823430e-01)*S2+7.178201e-01*S3+(-6.726599e-01)*S4+1.869037e+00*S5+2.174826e-01*S6+1.323758e+01*S7+(-6.330673e-01)*S8+(-3.825815e-01)*S9'
.param V6_part2='V6_part1+(-4.083013e-01)*S10+(-4.706173e-01)*S11+(-2.085379e+00)*S12+1.850420e+00*S13+(-4.128389e+00)*S14+(-1.917825e+00)*S15+9.826322e+00*S16+9.002395e-02*S17+(-4.612261e+00)*S18+(-2.138094e+00)*S19'
.param V6_part3='V6_part2+1.902770e-01*S20+6.019140e-01*S21+(-4.927335e+00)*S22+(-6.335821e-04)*S23+7.919046e-01*S24+4.091587e-01*S25+2.180499e-01*S26+6.265933e-01*S27+3.684439e-01*S28+(-1.505967e+00)*S29'
.param V6_part4='V6_part3+8.237957e+00*S30+8.731753e-01*S31+7.865051e-01*S32+(-4.841596e+00)*S33+3.490001e-01*S34+1.917643e-02*S35+(-1.433307e+00)*S36+(-1.585046e+00)*S37+1.615492e-01*S38+(-3.095361e+00)*S39'
.param V6_part5='V6_part4+4.951371e+00*S40+(-4.374226e-02)*S41+1.082629e+00*S42+5.768908e-01*S43+1.016430e-01*S44+1.392324e+00*S45+2.848248e-01*S46+1.041773e+00*S47+(-8.635705e+00)*S48+(-4.441027e+00)*S49'
.param V6_part6='V6_part5+1.369277e-01*S50+1.348096e+00*S51+(-8.491144e-01)*S52+3.791922e-01*S53+(-1.937501e+01)*S54+1.043342e+00*S55+(-1.990470e+00)*S56+(-1.066472e+01)*S57+1.170936e+00*S58+(-9.366208e-01)*S59'
.param V6_part7='V6_part6+1.572449e+00*S60+1.166936e+00*S61+(-2.047002e+00)*S62+(-2.267609e+01)*S63+9.922258e-01*S64+(-8.289345e+00)*S65+(-5.994899e+00)*S66+(-7.377759e+01)*S67+(-1.438077e-01)*S68+(-2.955089e+01)*S69'
.param V6_part8='V6_part7+(-9.366961e+01)*S70+(-2.690792e+00)*S71+(-1.221726e+02)*S72+(-1.186050e+02)*S73+(-1.672160e+00)*S74+(-6.399926e+00)*S75+(-3.262205e+00)*S76+(-1.643850e+00)*S77+(-2.847016e+01)*S78+(-2.627683e+01)*S79'
.param V6='V6_part8+(-3.355259e+00)*S80+(-6.071134e+01)*S81+(-1.121350e+02)*S82+(-4.234437e+00)*S83+(-1.039815e+02)*S84+(-1.010856e+02)*S85+(-8.034250e+00)*S86+(-9.880381e+01)*S87+3.379477e+01*S88+(-1.676202e-01)*S89'
.param V7_part1='6.357912e-01*S0+(-4.365495e-01)*S1+1.463038e+00*S2+1.548468e+00*S3+4.907667e-01*S4+(-3.300256e-01)*S5+6.103061e-01*S6+(-2.377805e-01)*S7+8.477341e-01*S8+1.389355e+00*S9'
.param V7_part2='V7_part1+7.163819e-01*S10+1.014179e+00*S11+3.363288e+00*S12+5.873171e-01*S13+5.967331e+00*S14+1.427173e+00*S15+6.962373e-01*S16+3.196499e-01*S17+2.566495e+00*S18+1.327163e+00*S19'
.param V7_part3='V7_part2+1.390509e-01*S20+1.584741e-01*S21+3.483153e+00*S22+4.969245e-01*S23+1.925967e-01*S24+2.010311e-01*S25+1.893374e-01*S26+2.261339e-01*S27+2.229458e-01*S28+1.899523e+00*S29'
.param V7_part4='V7_part3+1.452626e+00*S30+2.849391e+00*S31+3.321778e-01*S32+2.344153e+00*S33+8.826995e-01*S34+4.062892e-01*S35+1.501947e+00*S36+1.775298e+00*S37+5.088261e-01*S38+2.039156e+00*S39'
.param V7_part5='V7_part4+1.095705e+00*S40+1.095794e+00*S41+4.182621e-01*S42+3.242886e-01*S43+5.368808e-01*S44+2.557189e-01*S45+9.226210e-01*S46+1.745588e-01*S47+3.206684e+00*S48+4.695079e+00*S49'
.param V7_part6='V7_part5+5.798248e-01*S50+3.074534e-01*S51+1.193535e+00*S52+2.706704e-01*S53+7.979956e+00*S54+4.530827e-01*S55+1.630533e+00*S56+5.250484e+00*S57+5.481718e-01*S58+1.216529e+00*S59'
.param V7_part7='V7_part6+4.151696e-01*S60+3.634235e-01*S61+6.197892e+00*S62+6.019229e+00*S63+4.089287e-01*S64+7.342056e+00*S65+2.176177e+00*S66+9.659100e+00*S67+7.542804e-01*S68+5.403435e+00*S69'
.param V7_part8='V7_part7+8.600251e+00*S70+2.321296e+00*S71+8.909455e+01*S72+1.144974e+01*S73+9.718469e-01*S74+4.568371e+00*S75+4.183291e+00*S76+3.570823e+00*S77+3.964016e+00*S78+1.049623e+01*S79'
.param V7='V7_part8+4.804293e+00*S80+5.411453e+00*S81+1.398571e+01*S82+5.150355e+00*S83+3.859562e+00*S84+2.492963e+01*S85+6.096555e+00*S86+6.520991e+01*S87+4.253100e+01*S88+2.153420e+00*S89'
.param V8_part1='4.180016e-01*S0+3.370661e-01*S1+2.929362e-01*S2+5.869436e-01*S3+(-2.921932e-01)*S4+(-4.937027e-02)*S5+1.619033e-01*S6+6.686460e-01*S7+(-2.179709e-01)*S8+3.912168e-01*S9'
.param V8_part2='V8_part1+(-1.430615e-01)*S10+1.660989e-01*S11+7.698634e-01*S12+1.415687e+00*S13+(-3.640873e-02)*S14+3.552270e-03*S15+(-2.525991e-01)*S16+2.798628e-02*S17+(-1.068187e-01)*S18+2.877515e-01*S19'
.param V8_part3='V8_part2+1.280172e-02*S20+3.319489e-02*S21+4.825001e-01*S22+1.236661e-02*S23+4.224853e-02*S24+2.371748e-02*S25+1.235774e-02*S26+3.242955e-02*S27+2.381734e-02*S28+9.868480e-01*S29'
.param V8_part4='V8_part3+(-6.341772e-01)*S30+(-2.806331e-01)*S31+(-5.741703e-02)*S32+(-2.093635e-02)*S33+4.589426e-02*S34+1.850122e-02*S35+3.803786e-02*S36+4.585664e-01*S37+3.693186e-02*S38+(-4.274439e-02)*S39'
.param V8_part5='V8_part4+2.038418e-01*S40+(-8.972269e-03)*S41+2.696694e-02*S42+3.888997e-02*S43+1.833566e-02*S44+3.973888e-02*S45+6.249703e-02*S46+5.416391e-02*S47+2.773024e-01*S48+1.099393e-01*S49'
.param V8_part6='V8_part5+(-8.321827e-02)*S50+5.802185e-02*S51+1.003990e-01*S52+2.240390e-02*S53+(-1.493002e+00)*S54+4.465051e-02*S55+2.833451e-02*S56+(-9.603056e-01)*S57+6.525916e-02*S58+(-2.873768e-02)*S59'
.param V8_part7='V8_part6+1.130998e-02*S60+1.811186e-02*S61+(-2.418264e-01)*S62+8.607210e-02*S63+6.243698e-02*S64+(-5.885967e-01)*S65+(-1.011592e-01)*S66+(-2.639744e+00)*S67+(-6.697038e-02)*S68+(-3.790121e-01)*S69'
.param V8_part8='V8_part7+(-4.461680e+00)*S70+(-5.467639e-02)*S71+5.204109e+00*S72+(-7.014106e+00)*S73+(-3.424247e-03)*S74+(-3.105840e-01)*S75+(-4.032495e-02)*S76+(-4.968066e-01)*S77+(-2.377717e-01)*S78+1.230927e-01*S79'
.param V8='V8_part8+(-2.293571e-01)*S80+(-1.255578e+00)*S81+(-4.871872e+00)*S82+(-2.870014e-01)*S83+(-3.528689e+00)*S84+(-4.977727e+00)*S85+(-3.488629e-01)*S86+1.459949e+01*S87+7.421431e+00*S88+(-4.242423e-01)*S89'
.param V9_part1='(-5.330225e-02)*S0+2.820707e-01*S1+(-6.110691e-03)*S2+(-9.302617e-02)*S3+7.460176e-03*S4+4.007832e-02*S5+(-5.610133e-02)*S6+9.475024e-03*S7+3.300233e-03*S8+(-1.275607e-01)*S9'
.param V9_part2='V9_part1+7.388601e-05*S10+(-2.101287e-02)*S11+(-2.898135e-01)*S12+(-7.545244e-02)*S13+(-1.180093e-01)*S14+(-1.620728e-01)*S15+5.622475e-02*S16+2.050371e-03*S17+(-3.025726e-01)*S18+(-5.991418e-02)*S19'
.param V9_part3='V9_part2+3.525092e-03*S20+2.118866e-02*S21+(-3.818238e-01)*S22+(-1.705013e-02)*S23+1.842949e-02*S24+1.044636e-03*S25+3.439258e-03*S26+2.111016e-02*S27+1.232645e-02*S28+(-1.732934e-01)*S29'
.param V9_part4='V9_part3+(-2.445509e-01)*S30+(-2.053574e-01)*S31+(-5.325364e-02)*S32+(-7.494247e-01)*S33+(-2.796115e-02)*S34+(-3.878727e-02)*S35+(-1.830259e-01)*S36+(-3.870050e-01)*S37+(-2.150387e-02)*S38+6.079836e-02*S39'
.param V9_part5='V9_part4+4.859093e-01*S40+(-1.260478e-01)*S41+5.092905e-02*S42+2.014312e-02*S43+(-4.530274e-03)*S44+1.010106e-01*S45+(-1.119962e-01)*S46+1.050165e-01*S47+(-3.613782e-01)*S48+5.989555e-02*S49'
.param V9_part6='V9_part5+(-4.184257e-02)*S50+1.088810e-01*S51+(-3.170321e-01)*S52+(-6.055438e-03)*S53+5.692522e+00*S54+8.317805e-02*S55+(-1.813486e-01)*S56+4.093664e+00*S57+1.169727e-01*S58+(-6.532060e-02)*S59'
.param V9_part7='V9_part6+3.857153e-02*S60+(-7.406674e-03)*S61+(-2.508005e+00)*S62+1.669888e+00*S63+3.570612e-02*S64+2.280370e-01*S65+9.682900e-02*S66+3.432008e+00*S67+(-2.055136e-01)*S68+3.623323e-01*S69'
.param V9_part8='V9_part7+4.776397e+00*S70+(-4.715176e-01)*S71+(-3.567217e+01)*S72+1.446881e+01*S73+(-7.589941e-02)*S74+(-1.814230e+00)*S75+(-1.061193e-01)*S76+(-5.534632e-01)*S77+(-2.887917e+00)*S78+1.113800e+00*S79'
.param V9='V9_part8+(-3.263697e-02)*S80+(-5.059853e+00)*S81+8.865547e+00*S82+2.177239e-03*S83+(-6.205145e+00)*S84+7.641491e+00*S85+1.077652e-02*S86+(-2.003223e+01)*S87+4.316891e+01*S88+1.271525e+00*S89'
.param V10_part1='1.901830e-02*S0+(-1.896478e-03)*S1+4.746142e-02*S2+5.004805e-02*S3+8.981666e-02*S4+(-2.122949e-02)*S5+1.997724e-02*S6+(-5.359740e-02)*S7+1.265860e-01*S8+6.382546e-02*S9'
.param V10_part2='V10_part1+1.169370e-01*S10+5.853086e-02*S11+1.633960e-01*S12+1.118320e-01*S13+1.296204e-01*S14+1.032700e-01*S15+(-1.573640e-02)*S16+1.200504e-02*S17+2.358105e-01*S18+6.484140e-02*S19'
.param V10_part3='V10_part2+7.494137e-03*S20+(-1.090748e-02)*S21+2.637117e-01*S22+3.602600e-03*S23+(-3.019223e-02)*S24+(-5.967415e-02)*S25+8.809063e-03*S26+(-2.358603e-02)*S27+(-2.951001e-02)*S28+3.429183e-01*S29'
.param V10_part4='V10_part3+(-8.265486e-02)*S30+(-4.802854e-02)*S31+(-1.743500e-02)*S32+3.908359e-01*S33+4.855785e-03*S34+1.102093e-02*S35+1.969684e-01*S36+2.225443e-01*S37+1.908028e-02*S38+3.041705e-01*S39'
.param V10_part5='V10_part4+(-1.579176e-01)*S40+1.077404e-01*S41+(-5.415050e-02)*S42+(-5.358560e-02)*S43+(-1.630432e-02)*S44+4.470655e-03*S45+3.173699e-02*S46+1.923537e-02*S47+4.736276e-01*S48+2.182880e-01*S49'
.param V10_part6='V10_part5+1.206636e-02*S50+(-4.833176e-03)*S51+6.706312e-02*S52+3.601246e-04*S53+1.132776e+00*S54+(-7.518886e-02)*S55+2.975149e-01*S56+6.878476e-01*S57+(-8.594391e-02)*S58+1.467299e-01*S59'
.param V10_part7='V10_part6+1.480097e-02*S60+1.388845e-02*S61+2.059127e+00*S62+7.708860e-01*S63+(-1.845671e-02)*S64+5.867646e-01*S65+3.452967e-02*S66+(-1.069105e+00)*S67+1.118254e-04*S68+2.267227e-01*S69'
.param V10_part8='V10_part7+(-3.028250e+00)*S70+2.391238e-01*S71+(-6.100433e-01)*S72+(-4.132347e+00)*S73+4.575309e-01*S74+(-1.590302e-01)*S75+(-6.387562e-03)*S76+1.339967e-01*S77+2.647339e-01*S78+2.942533e-01*S79'
.param V10='V10_part8+3.466835e-01*S80+1.275404e+00*S81+(-4.080312e+00)*S82+4.058065e-01*S83+4.437007e-01*S84+(-9.631542e+00)*S85+8.509079e-01*S86+(-9.011281e-01)*S87+1.946279e-01*S88+1.432843e-01*S89'
.param V11_part1='2.117988e-01*S0+5.827920e-01*S1+2.068271e-01*S2+2.328817e-01*S3+1.885794e-01*S4+2.878929e-01*S5+2.251716e-01*S6+5.523338e-01*S7+1.687047e-01*S8+2.401546e-01*S9'
.param V11_part2='V11_part1+2.302748e-01*S10+1.991765e-01*S11+2.692656e-01*S12+2.503173e-01*S13+2.756857e-01*S14+5.985140e-01*S15+1.039115e+00*S16+5.874045e-01*S17+6.327074e-01*S18+6.756102e-01*S19'
.param V11_part3='V11_part2+6.473130e-01*S20+8.206466e-01*S21+8.205901e-01*S22+6.997183e-01*S23+9.031880e-01*S24+8.728524e-01*S25+7.394042e-01*S26+9.011497e-01*S27+8.516567e-01*S28+6.485992e-01*S29'
.param V11_part4='V11_part3+2.065303e+00*S30+2.220213e+00*S31+1.352975e+00*S32+1.310414e+00*S33+1.488567e+00*S34+1.323002e+00*S35+1.513209e+00*S36+1.399995e+00*S37+1.387097e+00*S38+1.568202e+00*S39'
.param V11_part5='V11_part4+2.480185e+00*S40+1.452662e+00*S41+1.837940e+00*S42+1.748587e+00*S43+1.546020e+00*S44+2.327405e+00*S45+2.209253e+00*S46+2.527717e+00*S47+2.353540e+00*S48+2.829674e+00*S49'
.param V11_part6='V11_part5+2.234444e+00*S50+2.801543e+00*S51+2.540101e+00*S52+2.573223e+00*S53+2.965598e+00*S54+2.760024e+00*S55+2.324315e+00*S56+3.128763e+00*S57+2.875265e+00*S58+2.490688e+00*S59'
.param V11_part7='V11_part6+3.501002e+00*S60+3.342477e+00*S61+3.931835e+00*S62+4.175544e+00*S63+3.653141e+00*S64+3.771178e+00*S65+4.644396e+00*S66+2.691790e+00*S67+3.540411e+00*S68+5.764307e+00*S69'
.param V11_part8='V11_part7+3.220158e+00*S70+3.527538e+00*S71+2.739254e+00*S72+1.831169e+00*S73+3.653472e+00*S74+6.509349e+00*S75+5.558381e+00*S76+5.868486e+00*S77+7.216837e+00*S78+5.971110e+00*S79'
.param V11='V11_part8+6.105361e+00*S80+6.729891e+00*S81+3.888148e+00*S82+6.506119e+00*S83+8.307733e+00*S84+9.755267e+00*S85+6.376088e+00*S86+4.286898e+00*S87+3.834288e+00*S88+5.428725e+00*S89'
.param V12_part1='(-2.489707e-02)*S0+1.022724e-01*S1+1.315047e-02*S2+(-7.304548e-02)*S3+(-6.084171e-02)*S4+4.139954e-02*S5+(-6.751372e-02)*S6+5.494813e-03*S7+(-4.910217e-02)*S8+(-1.433795e-01)*S9'
.param V12_part2='V12_part1+(-1.258531e-01)*S10+(-1.836011e-02)*S11+(-2.259959e-01)*S12+(-5.859055e-02)*S13+(-5.417663e-04)*S14+(-1.186728e-01)*S15+1.138037e-01*S16+5.724648e-02*S17+(-3.177366e-01)*S18+3.065577e-03*S19'
.param V12_part3='V12_part2+6.292849e-02*S20+(-6.382855e-02)*S21+2.276684e-02*S22+2.966152e-02*S23+(-1.199849e-01)*S24+(-1.648336e-02)*S25+1.401926e-02*S26+(-2.086138e-01)*S27+(-8.475562e-02)*S28+(-7.045238e-02)*S29'
.param V12_part4='V12_part3+4.282148e-01*S30+3.916804e-01*S31+2.257528e-01*S32+(-4.370855e-01)*S33+1.224394e-01*S34+1.807154e-01*S35+(-3.613982e-01)*S36+(-3.818824e-02)*S37+1.334723e-01*S38+(-6.327371e-01)*S39'
.param V12_part5='V12_part4+(-5.189856e-02)*S40+3.820599e-02*S41+(-2.951353e-01)*S42+(-4.020609e-02)*S43+4.811294e-02*S44+5.526146e-01*S45+4.883046e-01*S46+9.067928e-01*S47+(-4.301598e-01)*S48+3.302941e-01*S49'
.param V12_part6='V12_part5+4.953534e-01*S50+2.533130e-01*S51+2.683490e-01*S52+5.944260e-01*S53+(-1.732744e+00)*S54+1.803134e-01*S55+2.189442e-01*S56+(-1.314220e+00)*S57+9.850666e-04*S58+1.883445e-01*S59'
.param V12_part7='V12_part6+1.077498e+00*S60+1.151912e+00*S61+1.094979e+00*S62+(-4.842938e-01)*S63+1.017431e+00*S64+8.715592e-01*S65+(-2.917647e-01)*S66+6.061893e+00*S67+9.819385e-01*S68+(-1.546083e+00)*S69'
.param V12_part8='V12_part7+9.641405e+00*S70+7.773475e-01*S71+(-1.647457e+00)*S72+1.233566e+01*S73+5.872583e-01*S74+2.080605e+00*S75+1.997472e+00*S76+1.959693e+00*S77+(-4.915202e-02)*S78+2.258578e+00*S79'
.param V12='V12_part8+1.460430e+00*S80+(-2.431729e+00)*S81+1.262813e+01*S82+1.151632e+00*S83+(-5.492139e+00)*S84+1.570568e+01*S85+8.525275e-01*S86+(-2.173358e+00)*S87+(-2.948901e-01)*S88+1.017078e+00*S89'
.param V13_part1='2.881859e-02*S0+6.182965e-02*S1+4.429535e-02*S2+4.074179e-02*S3+1.427565e-02*S4+2.530550e-02*S5+2.367338e-02*S6+4.591230e-02*S7+1.562638e-02*S8+3.384926e-02*S9'
.param V13_part2='V13_part1+1.666670e-02*S10+3.596785e-02*S11+6.922243e-02*S12+7.324991e-02*S13+8.365845e-02*S14+2.332902e-02*S15+2.417770e-02*S16+2.028435e-02*S17+2.769797e-02*S18+4.383003e-02*S19'
.param V13_part3='V13_part2+2.017603e-02*S20+2.096516e-02*S21+1.302010e-01*S22+2.662294e-02*S23+2.155970e-02*S24+2.264694e-02*S25+2.239777e-02*S26+2.090574e-02*S27+2.112350e-02*S28+1.092168e-01*S29'
.param V13_part4='V13_part3+2.125031e-02*S30+2.748407e-02*S31+2.270674e-02*S32+2.800258e-02*S33+2.487410e-02*S34+2.506713e-02*S35+2.861068e-02*S36+5.155431e-02*S37+2.717157e-02*S38+3.410350e-02*S39'
.param V13_part5='V13_part4+2.438718e-02*S40+2.700357e-02*S41+2.428208e-02*S42+1.944320e-02*S43+2.825303e-02*S44+2.070756e-02*S45+2.366863e-02*S46+2.723801e-02*S47+4.015110e-02*S48+1.677217e-02*S49'
.param V13_part6='V13_part5+2.720147e-02*S50+1.845525e-02*S51+3.527719e-02*S52+2.080034e-02*S53+6.424993e-02*S54+2.945630e-02*S55+4.117557e-02*S56+6.694488e-02*S57+3.335078e-02*S58+3.381347e-02*S59'
.param V13_part7='V13_part6+2.177599e-02*S60+2.471511e-02*S61+(-3.242599e-02)*S62+4.522944e-02*S63+2.654619e-02*S64+9.977427e-03*S65+2.382600e-02*S66+9.476196e-02*S67+3.810921e-02*S68+2.155662e-02*S69'
.param V13_part8='V13_part7+1.833659e-01*S70+3.797787e-02*S71+(-5.563556e-02)*S72+4.703867e-02*S73+7.798913e-02*S74+(-6.844455e-03)*S75+2.723982e-02*S76+1.363128e-02*S77+(-1.021757e-02)*S78+1.128350e-03*S79'
.param V13='V13_part8+3.932030e-02*S80+1.125534e-02*S81+(-4.765670e-03)*S82+3.645829e-02*S83+1.578196e-01*S84+5.396931e-02*S85+5.868837e-02*S86+(-1.172766e-01)*S87+(-8.332073e-02)*S88+4.250864e-02*S89'
.param V14_part1='2.623133e-03*S0+1.386412e-02*S1+2.376793e-03*S2+1.629992e-03*S3+3.261741e-03*S4+4.333537e-03*S5+2.291786e-03*S6+4.587267e-03*S7+2.510614e-03*S8+1.266488e-03*S9'
.param V14_part2='V14_part1+3.513806e-03*S10+2.016453e-03*S11+(-2.904460e-03)*S12+3.268614e-04*S13+2.464424e-04*S14+9.934048e-03*S15+2.390310e-02*S16+1.417023e-02*S17+2.133806e-03*S18+9.893008e-03*S19'
.param V14_part3='V14_part2+1.199884e-02*S20+1.006297e-02*S21+(-1.160682e-02)*S22+1.493528e-02*S23+7.302985e-03*S24+1.189749e-02*S25+1.070717e-02*S26+5.016583e-03*S27+7.406466e-03*S28+(-1.939035e-03)*S29'
.param V14_part4='V14_part3+5.997589e-02*S30+1.033525e-01*S31+4.890343e-02*S32+1.167775e-02*S33+4.160713e-02*S34+3.919421e-02*S35+2.461137e-02*S36+2.212650e-02*S37+3.734025e-02*S38+2.942501e-02*S39'
.param V14_part5='V14_part4+2.436844e-02*S40+3.714506e-02*S41+1.058645e-02*S42+1.735836e-02*S43+3.002127e-02*S44+6.633961e-02*S45+8.170507e-02*S46+9.507758e-02*S47+9.188977e-02*S48+3.147919e-01*S49'
.param V14_part6='V14_part5+8.350953e-02*S50+3.927373e-02*S51+6.535111e-02*S52+7.893438e-02*S53+1.064725e+00*S54+6.073688e-02*S55+8.115398e-02*S56+7.253423e-01*S57+5.883638e-02*S58+7.276371e-02*S59'
.param V14_part7='V14_part6+1.318968e-01*S60+1.315720e-01*S61+(-1.901238e-01)*S62+7.320188e-01*S63+1.238164e-01*S64+1.041191e+00*S65+4.275502e-01*S66+4.072708e+00*S67+1.338866e-01*S68+1.805642e+00*S69'
.param V14_part8='V14_part7+6.698690e+00*S70+1.168800e-01*S71+4.058550e-01*S72+1.236912e+01*S73+8.847439e-02*S74+1.043335e+00*S75+6.084860e-01*S76+5.497998e-01*S77+1.660241e+00*S78+2.025915e+00*S79'
.param V14='V14_part8+7.083748e-01*S80+4.667390e+00*S81+8.680414e+00*S82+9.366420e-01*S83+9.705885e+00*S84+1.073607e+01*S85+1.318811e+00*S86+4.455417e-01*S87+(-2.505488e-01)*S88+6.562404e-01*S89'
.param V15_part1='(-1.369838e-01)*S0+(-4.348029e-02)*S1+8.641291e-03*S2+(-2.785762e-01)*S3+(-2.034665e-01)*S4+(-5.485025e-02)*S5+(-5.272757e-01)*S6+(-1.952735e-01)*S7+(-1.229936e-01)*S8+(-5.372642e-01)*S9'
.param V15_part2='V15_part1+(-4.075770e-01)*S10+(-1.408598e-01)*S11+(-6.189311e-01)*S12+(-3.587645e-01)*S13+(-1.623485e-01)*S14+(-6.317926e-02)*S15+3.239369e-02*S16+4.032328e-02*S17+(-4.452906e-01)*S18+(-2.057841e-01)*S19'
.param V15_part3='V15_part2+5.008537e+01*S20+1.518177e+03*S21+(-3.622750e-01)*S22+(-2.016717e-01)*S23+5.546760e+00*S24+4.783478e+01*S25+3.648041e+00*S26+1.955845e+02*S27+6.283130e+02*S28+(-3.065197e-01)*S29'
.param V15_part4='V15_part3+(-1.288715e-01)*S30+1.483219e-01*S31+2.508267e-01*S32+(-6.991597e-01)*S33+(-1.941192e-01)*S34+(-2.034299e-02)*S35+(-1.495306e+00)*S36+(-5.969589e-01)*S37+(-1.313206e-01)*S38+(-2.003832e+00)*S39'
.param V15_part5='V15_part4+2.372830e-01*S40+(-8.330933e-02)*S41+(-6.736517e+00)*S42+3.044086e+02*S43+(-2.203893e+00)*S44+(-9.385484e-01)*S45+3.910464e-01*S46+1.399273e+00*S47+(-7.021334e-01)*S48+1.673184e-01*S49'
.param V15_part6='V15_part5+2.509764e-01*S50+(-3.571824e+02)*S51+(-1.024653e+00)*S52+2.435151e+01*S53+(-1.416833e+00)*S54+(-3.324576e+00)*S55+(-1.783736e-01)*S56+(-2.158506e+00)*S57+(-3.310606e+00)*S58+(-1.355713e+00)*S59'
.param V15_part7='V15_part6+(-8.888346e-01)*S60+2.929878e-01*S61+1.120089e+00*S62+(-5.825186e-01)*S63+(-2.062560e+00)*S64+9.930182e-01*S65+(-1.546621e+00)*S66+3.346344e-02*S67+7.581431e-02*S68+(-1.708054e+00)*S69'
.param V15_part8='V15_part7+(-1.921473e-01)*S70+(-3.746774e-01)*S71+(-8.764105e-01)*S72+(-1.707885e-02)*S73+(-4.473188e+00)*S74+3.314951e-01*S75+9.366663e-01*S76+1.510379e+00*S77+(-4.302329e-01)*S78+4.660618e-01*S79'
.param V15='V15_part8+1.414524e+00*S80+(-1.093540e+00)*S81+6.521665e-02*S82+1.335579e+00*S83+(-1.628508e+00)*S84+4.330847e-02*S85+8.937412e-01*S86+(-1.093327e+00)*S87+8.553856e-01*S88+1.161005e+00*S89'
.param V16_part1='7.587652e-01*S0+4.371263e-01*S1+2.174989e-01*S2+7.485317e-01*S3+7.236775e-01*S4+2.408850e-01*S5+1.076116e+00*S6+4.928451e-01*S7+3.674814e-01*S8+8.030955e-01*S9'
.param V16_part2='V16_part1+7.127568e-01*S10+2.919552e-01*S11+7.132274e-01*S12+4.916026e-01*S13+2.333008e-01*S14+1.495348e+00*S15+8.945289e-01*S16+8.053924e-01*S17+1.762577e+00*S18+1.389203e+00*S19'
.param V16_part3='V16_part2+(-1.575305e+01)*S20+(-7.804790e+03)*S21+1.090271e+00*S22+7.685913e-01*S23+(-1.604431e+01)*S24+(-4.754683e+01)*S25+1.372272e+01*S26+(-1.175958e+02)*S27+(-3.031344e+02)*S28+6.526751e-01*S29'
.param V16_part4='V16_part3+1.780167e+00*S30+1.229448e+00*S31+8.897862e-01*S32+2.963780e+00*S33+2.158978e+00*S34+1.921385e+00*S35+4.041775e+00*S36+2.236286e+00*S37+1.831774e+00*S38+3.849759e+00*S39'
.param V16_part5='V16_part4+1.109589e+00*S40+1.168774e+00*S41+2.234754e+01*S42+(-5.523110e+01)*S43+5.785691e+00*S44+1.199501e+01*S45+3.208542e+00*S46+1.548973e+00*S47+3.897476e+00*S48+2.056235e+00*S49'
.param V16_part6='V16_part5+2.155111e+00*S50+(-1.419196e+03)*S51+3.658760e+00*S52+(-1.119567e+01)*S53+2.947328e+00*S54+5.207929e+00*S55+1.773734e+00*S56+3.250836e+00*S57+3.765668e+00*S58+2.860736e+00*S59'
.param V16_part7='V16_part6+1.118591e+01*S60+6.065353e+00*S61+1.287829e+00*S62+3.953719e+00*S63+8.981645e+00*S64+8.238151e-01*S65+4.421980e+00*S66+1.955974e+00*S67+3.185271e+00*S68+3.550150e+00*S69'
.param V16_part8='V16_part7+1.825384e+00*S70+3.074281e+00*S71+2.976098e+00*S72+1.501880e+00*S73+5.970041e+00*S74+4.147112e+00*S75+3.007024e+00*S76+5.858141e-01*S77+4.435692e+00*S78+3.019182e+00*S79'
.param V16='V16_part8+5.607170e-01*S80+4.359375e+00*S81+2.418202e+00*S82+7.163250e-01*S83+4.064074e+00*S84+1.807418e+00*S85+1.177110e+00*S86+3.589450e+00*S87+2.131183e+00*S88+2.121770e+00*S89'
.param V17_part1='8.963738e-02*S0+7.743168e-02*S1+8.739531e-02*S2+1.293476e-01*S3+1.163982e-01*S4+1.546133e-01*S5+1.756449e-01*S6+1.383173e-01*S7+1.548963e-01*S8+2.048130e-01*S9'
.param V17_part2='V17_part1+1.970463e-01*S10+1.960265e-01*S11+2.397468e-01*S12+2.181755e-01*S13+2.443055e-01*S14+1.632896e-01*S15+1.720864e-01*S16+3.373974e-01*S17+2.339568e-01*S18+2.142939e-01*S19'
.param V17_part3='V17_part2+9.866877e-01*S20+4.360720e+03*S21+3.070697e-01*S22+4.297861e-01*S23+8.648572e+00*S24+1.265230e+01*S25+2.440917e+01*S26+1.944490e+01*S27+(-2.585751e+01)*S28+4.706538e-01*S29'
.param V17_part4='V17_part3+3.115469e-01*S30+2.745008e-01*S31+4.073590e-01*S32+3.676822e-01*S33+3.816676e-01*S34+4.878567e-01*S35+4.787568e-01*S36+4.413281e-01*S37+6.406258e-01*S38+5.950713e-01*S39'
.param V17_part5='V17_part4+5.988878e-01*S40+5.885204e-01*S41+9.909593e-01*S42+2.348890e+01*S43+4.080854e-01*S44+1.183819e+00*S45+3.297303e-01*S46+9.317569e-01*S47+4.882029e-01*S48+4.135859e-01*S49'
.param V17_part6='V17_part5+7.578531e-01*S50+1.095677e+03*S51+6.805886e-01*S52+9.401528e+00*S53+7.804671e-01*S54+2.050424e+00*S55+7.955968e-01*S56+9.512652e-01*S57+2.341679e+00*S58+1.177409e+00*S59'
.param V17_part7='V17_part6+9.050597e-01*S60+8.819095e-01*S61+4.132394e-01*S62+6.399117e-01*S63+1.533062e+00*S64+5.784539e-01*S65+9.324520e-01*S66+7.977587e-01*S67+1.140815e+00*S68+1.041733e+00*S69'
.param V17_part8='V17_part7+9.510495e-01*S70+9.560583e-01*S71+9.898687e-01*S72+1.013771e+00*S73+2.211050e+00*S74+5.920530e-01*S75+5.530701e-01*S76+6.884838e-01*S77+7.953623e-01*S78+6.975361e-01*S79'
.param V17='V17_part8+8.958008e-01*S80+9.831779e-01*S81+9.909894e-01*S82+9.896223e-01*S83+1.187491e+00*S84+1.226104e+00*S85+1.165802e+00*S86+1.220053e+00*S87+1.036294e+00*S88+1.759772e+00*S89'
.param V18_part1='8.985434e-02*S0+5.800405e-02*S1+3.362833e-02*S2+8.999270e-02*S3+9.397905e-02*S4+4.148204e-02*S5+1.144397e-01*S6+5.652456e-02*S7+4.912688e-02*S8+9.074651e-02*S9'
.param V18_part2='V18_part1+8.850202e-02*S10+3.178783e-02*S11+7.659055e-02*S12+4.767054e-02*S13+2.949921e-02*S14+1.194895e-01*S15+5.885119e-02*S16+4.033231e-02*S17+1.017471e-01*S18+4.390528e-02*S19'
.param V18_part3='V18_part2+(-2.337378e+00)*S20+(-2.066875e+02)*S21+3.548723e-02*S22+3.666249e-02*S23+6.235570e-01*S24+9.083568e-01*S25+3.033103e-01*S26+2.211854e+01*S27+(-1.151709e+01)*S28+1.400675e-02*S29'
.param V18_part4='V18_part3+9.954889e-02*S30+6.587936e-02*S31+4.309576e-02*S32+1.113431e-01*S33+8.463068e-02*S34+4.163086e-02*S35+1.344634e-01*S36+5.481174e-02*S37+4.088697e-02*S38+1.206434e-01*S39'
.param V18_part5='V18_part4+7.604486e-02*S40+6.645115e-02*S41+3.053481e+00*S42+3.678772e+01*S43+1.826348e-01*S44+5.494619e-01*S45+9.849099e-02*S46+(-3.047091e-04)*S47+8.260689e-02*S48+8.436233e-02*S49'
.param V18_part6='V18_part5+1.856180e-01*S50+(-7.055204e+01)*S51+8.797098e-02*S52+(-3.926872e-01)*S53+7.563982e-02*S54+1.703801e-01*S55+5.698335e-02*S56+9.652102e-02*S57+9.680139e-02*S58+1.521933e-01*S59'
.param V18_part7='V18_part6+4.436453e-01*S60+1.931904e-01*S61+4.260772e-02*S62+8.674297e-02*S63+7.797116e-02*S64+3.380694e-02*S65+1.296883e-01*S66+2.922251e-02*S67+2.333891e-01*S68+1.131838e-01*S69'
.param V18_part8='V18_part7+1.043036e-02*S70+9.895917e-02*S71+(-1.664865e-02)*S72+2.923352e-03*S73+8.461784e-02*S74+1.168441e-01*S75+8.200118e-02*S76+2.049245e-02*S77+1.194924e-01*S78+8.539577e-02*S79'
.param V18='V18_part8+3.483433e-02*S80+1.148000e-01*S81+2.319534e-02*S82+3.760176e-02*S83+1.061377e-01*S84+1.272346e-02*S85+4.694328e-02*S86+(-3.229302e-02)*S87+(-7.724872e-02)*S88+1.913800e-01*S89'
.param V19_part1='1.205267e-02*S0+4.459558e-03*S1+3.204773e-03*S2+9.774071e-03*S3+7.503630e-03*S4+2.345718e-03*S5+2.479943e-02*S6+3.917520e-03*S7+3.437757e-03*S8+1.258774e-02*S9'
.param V19_part2='V19_part1+6.306751e-03*S10+3.351630e-03*S11+8.706765e-03*S12+4.664596e-03*S13+2.092336e-03*S14+7.423625e-02*S15+2.653897e-02*S16+2.881270e-02*S17+6.565864e-02*S18+5.198451e-02*S19'
.param V19_part3='V19_part2+(-4.143815e+00)*S20+4.644704e+02*S21+2.811255e-02*S22+2.685080e-02*S23+7.371278e-01*S24+1.543236e-02*S25+8.554001e-01*S26+4.750521e+01*S27+8.117625e+01*S28+1.819742e-02*S29'
.param V19_part4='V19_part3+1.164830e-01*S30+5.041394e-02*S31+4.286878e-02*S32+1.758644e-01*S33+1.115507e-01*S34+8.095308e-02*S35+2.316631e-01*S36+1.263760e-01*S37+8.452958e-02*S38+1.658411e-01*S39'
.param V19_part5='V19_part4+2.197309e-02*S40+5.505722e-02*S41+3.252660e+00*S42+(-5.074112e+00)*S43+2.500734e-01*S44+1.002781e+00*S45+2.639406e-01*S46+(-2.055676e-02)*S47+2.539819e-01*S48+6.683389e-02*S49'
.param V19_part6='V19_part5+1.628278e-01*S50+(-1.184897e+02)*S51+2.904948e-01*S52+1.059403e+00*S53+1.288863e-01*S54+3.349592e-01*S55+1.168316e-01*S56+1.394309e-01*S57+2.529311e-01*S58+1.684093e-01*S59'
.param V19_part7='V19_part6+1.467203e+00*S60+9.221298e-01*S61+1.677035e-01*S62+2.698894e-01*S63+1.008882e+00*S64+(-1.585693e-02)*S65+3.304655e-01*S66+5.840300e-02*S67+5.703418e-01*S68+2.611513e-01*S69'
.param V19_part8='V19_part7+1.080560e-01*S70+2.354891e-01*S71+1.433591e-01*S72+1.517108e-01*S73+9.782360e-02*S74+4.160261e-01*S75+2.138704e-01*S76+3.241352e-02*S77+3.665124e-01*S78+1.633763e-01*S79'
.param V19='V19_part8+1.853413e-03*S80+3.427107e-01*S81+1.880234e-01*S82+1.447033e-03*S83+3.831389e-01*S84+2.470381e-01*S85+(-7.222949e-04)*S86+2.561624e-01*S87+1.208501e-01*S88+(-5.532429e-01)*S89'
.param V20_part1='1.629790e-02*S0+1.767532e-02*S1+1.859414e-02*S2+6.599407e-03*S3+1.412672e-02*S4+2.284865e-02*S5+(-3.485958e-03)*S6+2.152598e-02*S7+3.185700e-02*S8+(-9.068945e-03)*S9'
.param V20_part2='V20_part1+1.084809e-02*S10+3.510497e-02*S11+(-1.484917e-02)*S12+2.178944e-02*S13+3.547768e-03*S14+2.176521e-02*S15+3.832901e-02*S16+(-4.378735e-02)*S17+(-1.293650e-02)*S18+(-1.380629e-02)*S19'
.param V20_part3='V20_part2+(-1.441209e+00)*S20+3.200075e+02*S21+(-4.193694e-02)*S22+(-4.391995e-02)*S23+1.278968e+00*S24+7.589101e-01*S25+1.918470e-02*S26+2.349632e+00*S27+(-1.538804e+01)*S28+2.856341e-02*S29'
.param V20_part4='V20_part3+(-3.569726e-04)*S30+(-2.712725e-02)*S31+2.801193e-02*S32+(-5.036419e-02)*S33+(-8.264250e-02)*S34+(-1.996622e-03)*S35+(-9.550984e-02)*S36+(-5.781965e-02)*S37+1.005961e-02*S38+(-1.763009e-01)*S39'
.param V20_part5='V20_part4+(-9.008953e-02)*S40+4.031753e-02*S41+(-1.101459e+00)*S42+(-1.281439e+01)*S43+(-5.742592e-01)*S44+3.520757e-02*S45+(-1.135978e-02)*S46+1.928824e-02*S47+(-9.615492e-02)*S48+(-5.353078e-02)*S49'
.param V20_part6='V20_part5+(-3.776280e-02)*S50+3.119303e+02*S51+(-1.471226e-01)*S52+1.639982e+00*S53+(-1.375608e-01)*S54+(-3.841654e-01)*S55+(-1.174479e-01)*S56+(-2.141781e-01)*S57+(-4.401559e-01)*S58+(-2.627918e-01)*S59'
.param V20_part7='V20_part6+(-4.056857e-02)*S60+(-8.997262e-03)*S61+2.990162e-01*S62+(-5.937084e-02)*S63+(-2.676511e-01)*S64+(-1.353761e-01)*S65+(-2.842937e-01)*S66+(-3.787207e-01)*S67+(-2.383003e-01)*S68+(-3.739059e-01)*S69'
.param V20_part8='V20_part7+(-5.675722e-01)*S70+(-4.092631e-01)*S71+(-1.508282e-01)*S72+(-6.285687e-01)*S73+(-3.737170e-01)*S74+1.716321e-02*S75+1.620655e-03*S76+(-9.392136e-02)*S77+(-1.164467e-01)*S78+(-1.199748e-01)*S79'
.param V20='V20_part8+(-2.299761e-01)*S80+(-1.934305e-01)*S81+(-4.169076e-01)*S82+(-3.531957e-01)*S83+(-4.620858e-01)*S84+(-7.556224e-01)*S85+(-4.543225e-01)*S86+(-1.939186e-01)*S87+(-1.615670e-01)*S88+(-4.030740e-01)*S89'
.param V21_part1='4.062740e-01*S0+3.605691e-01*S1+3.518571e-01*S2+4.562646e-01*S3+3.904571e-01*S4+3.461731e-01*S5+5.046344e-01*S6+4.386094e-01*S7+3.622173e-01*S8+5.260966e-01*S9'
.param V21_part2='V21_part1+4.465515e-01*S10+4.116459e-01*S11+5.426936e-01*S12+4.876337e-01*S13+4.490759e-01*S14+1.373899e+00*S15+1.304042e+00*S16+1.451492e+00*S17+1.565148e+00*S18+1.514223e+00*S19'
.param V21_part3='V21_part2+7.295756e+00*S20+3.641123e+02*S21+1.605396e+00*S22+1.635829e+00*S23+1.356796e+00*S24+1.903808e+00*S25+6.404602e+00*S26+5.552093e+00*S27+1.283335e+01*S28+1.607075e+00*S29'
.param V21_part4='V21_part3+2.933907e+00*S30+2.904801e+00*S31+2.894568e+00*S32+3.299831e+00*S33+3.333886e+00*S34+3.224929e+00*S35+3.620701e+00*S36+3.371113e+00*S37+3.401136e+00*S38+3.860400e+00*S39'
.param V21_part5='V21_part4+3.296767e+00*S40+3.303387e+00*S41+5.808562e+00*S42+2.587220e+01*S43+4.592795e+00*S44+5.948737e+00*S45+4.991438e+00*S46+4.185957e+00*S47+5.551659e+00*S48+5.201462e+00*S49'
.param V21_part6='V21_part5+5.333669e+00*S50+4.107054e+00*S51+5.800216e+00*S52+5.571775e+00*S53+6.142864e+00*S54+6.944718e+00*S55+5.704278e+00*S56+6.463609e+00*S57+7.094634e+00*S58+6.184234e+00*S59'
.param V21_part7='V21_part6+8.418152e+00*S60+8.023258e+00*S61+6.213287e+00*S62+8.071701e+00*S63+9.204473e+00*S64+7.466857e+00*S65+9.066548e+00*S66+8.385624e+00*S67+8.545479e+00*S68+9.357889e+00*S69'
.param V21_part8='V21_part7+8.911462e+00*S70+8.469397e+00*S71+9.334750e+00*S72+9.297084e+00*S73+1.014970e+01*S74+1.018259e+01*S75+9.963788e+00*S76+1.005547e+01*S77+1.133593e+01*S78+1.065258e+01*S79'
.param V21='V21_part8+1.071924e+01*S80+1.200787e+01*S81+1.151219e+01*S82+1.125140e+01*S83+1.289605e+01*S84+1.226664e+01*S85+1.146642e+01*S86+1.292694e+01*S87+1.214769e+01*S88+1.320397e+01*S89'
.param V22_part1='6.448447e-03*S0+1.308720e-02*S1+2.162954e-02*S2+(-2.537991e-02)*S3+(-4.892157e-03)*S4+1.060272e-02*S5+(-5.234198e-02)*S6+(-4.960224e-02)*S7+(-8.272564e-03)*S8+(-1.076813e-01)*S9'
.param V22_part2='V22_part1+(-6.498753e-02)*S10+(-3.622179e-02)*S11+(-1.535877e-01)*S12+(-1.194602e-01)*S13+(-4.100607e-02)*S14+1.446220e-01*S15+1.197141e-01*S16+2.491357e-01*S17+4.430415e-02*S18+1.108471e-01*S19'
.param V22_part3='V22_part2+5.249371e+00*S20+(-3.200970e+02)*S21+3.859886e-02*S22+1.034599e-01*S23+(-1.888267e+00)*S24+2.326939e+00*S25+3.389220e-02*S26+1.047084e+01*S27+6.962048e+01*S28+(-6.755566e-02)*S29'
.param V22_part4='V22_part3+5.777876e-01*S30+6.485861e-01*S31+6.625788e-01*S32+4.421556e-01*S33+5.800701e-01*S34+6.028711e-01*S35+2.316092e-01*S36+3.649370e-01*S37+4.744606e-01*S38+(-6.525484e-02)*S39'
.param V22_part5='V22_part4+(-6.410159e-03)*S40+3.062208e-01*S41+2.370567e+00*S42+4.392760e+01*S43+3.453152e-01*S44+2.128452e+00*S45+1.749449e+00*S46+1.139462e+00*S47+1.223724e+00*S48+1.308750e+00*S49'
.param V22_part6='V22_part5+1.606065e+00*S50+(-4.605192e+02)*S51+1.196487e+00*S52+1.650805e-01*S53+1.223517e-01*S54+8.926514e-01*S55+1.147952e+00*S56+(-2.953170e-01)*S57+4.652587e-01*S58+1.009603e+00*S59'
.param V22_part7='V22_part6+3.671831e+00*S60+3.688797e+00*S61+2.468478e+00*S62+2.417070e+00*S63+3.477229e+00*S64+2.938633e+00*S65+1.791755e+00*S66+2.465931e+00*S67+3.020453e+00*S68+1.029713e+00*S69'
.param V22_part8='V22_part7+2.028081e+00*S70+2.830521e+00*S71+(-9.630762e-02)*S72+1.379595e+00*S73+2.400745e+00*S74+5.200442e+00*S75+5.397684e+00*S76+5.391502e+00*S77+4.323180e+00*S78+4.920300e+00*S79'
.param V22='V22_part8+5.149989e+00*S80+3.338482e+00*S81+4.512982e+00*S82+4.826604e+00*S83+2.214375e+00*S84+4.101497e+00*S85+4.594238e+00*S86+1.057918e+00*S87+2.639674e+00*S88+4.291209e+00*S89'
.param V23_part1='4.162805e-02*S0+3.744314e-02*S1+3.700949e-02*S2+4.243863e-02*S3+3.685566e-02*S4+3.587474e-02*S5+4.380750e-02*S6+3.858696e-02*S7+3.511313e-02*S8+4.180943e-02*S9'
.param V23_part2='V23_part1+3.643872e-02*S10+3.951207e-02*S11+4.134090e-02*S12+3.889998e-02*S13+4.220981e-02*S14+4.530066e-02*S15+4.262780e-02*S16+5.061163e-02*S17+4.436944e-02*S18+4.703904e-02*S19'
.param V23_part3='V23_part2+1.125284e-01*S20+7.451217e+01*S21+4.923695e-02*S22+5.535103e-02*S23+1.264488e-01*S24+5.084184e-01*S25+1.988425e-01*S26+2.449980e+00*S27+1.625044e+00*S28+3.416304e-02*S29'
.param V23_part4='V23_part3+4.639076e-02*S30+4.310729e-02*S31+5.843699e-02*S32+4.516440e-02*S33+4.807475e-02*S34+5.402533e-02*S35+4.932076e-02*S36+3.657955e-02*S37+4.619473e-02*S38+5.735912e-02*S39'
.param V23_part5='V23_part4+4.809244e-02*S40+3.879657e-02*S41+2.929567e-01*S42+1.896100e+00*S43+5.331688e-02*S44+8.341930e-02*S45+4.459002e-02*S46+5.226250e-02*S47+4.842339e-02*S48+3.723398e-02*S49'
.param V23_part6='V23_part5+5.540142e-02*S50+(-1.158371e+01)*S51+4.177013e-02*S52+1.800705e-02*S53+5.238115e-02*S54+5.026591e-02*S55+3.692498e-02*S56+5.495095e-02*S57+4.002656e-02*S58+2.454701e-02*S59'
.param V23_part7='V23_part6+7.742235e-02*S60+6.862988e-02*S61+4.047194e-02*S62+4.650804e-02*S63+5.389800e-02*S64+4.677302e-02*S65+4.171538e-02*S66+5.916869e-02*S67+5.799811e-02*S68+3.677388e-02*S69'
.param V23_part8='V23_part7+6.833180e-02*S70+3.565529e-02*S71+4.962804e-02*S72+7.149162e-02*S73+1.962488e-01*S74+3.905473e-02*S75+3.972500e-02*S76+5.262913e-02*S77+3.669548e-02*S78+3.065083e-02*S79'
.param V23='V23_part8+4.119267e-02*S80+3.719680e-02*S81+6.072570e-02*S82+3.346687e-02*S83+4.554890e-02*S84+5.829268e-02*S85+3.344462e-02*S86+4.867311e-02*S87+4.588084e-02*S88+2.629428e-01*S89'
.param V24_part1='7.313650e-03*S0+6.553753e-03*S1+5.800530e-03*S2+7.716002e-03*S3+6.531182e-03*S4+5.782952e-03*S5+7.443394e-03*S6+6.980055e-03*S7+5.736300e-03*S8+8.240848e-03*S9'
.param V24_part2='V24_part1+6.898698e-03*S10+6.063066e-03*S11+7.987307e-03*S12+6.908673e-03*S13+6.353100e-03*S14+2.514914e-02*S15+2.416021e-02*S16+3.228475e-02*S17+2.428142e-02*S18+2.247336e-02*S19'
.param V24_part3='V24_part2+(-4.225754e-02)*S20+1.353619e+01*S21+2.259814e-02*S22+3.005805e-02*S23+1.804395e-02*S24+1.819800e-01*S25+2.627035e-01*S26+1.637126e+00*S27+5.484173e+00*S28+2.058641e-02*S29'
.param V24_part4='V24_part3+6.808887e-02*S30+7.565363e-02*S31+8.855221e-02*S32+5.649444e-02*S33+6.926765e-02*S34+9.493521e-02*S35+4.236493e-02*S36+5.605604e-02*S37+8.785477e-02*S38+2.596625e-02*S39'
.param V24_part5='V24_part4+4.945238e-02*S40+7.164380e-02*S41+5.922396e-02*S42+2.323761e+00*S43+1.001127e-01*S44+2.189562e-01*S45+1.571047e-01*S46+1.597390e-01*S47+1.176410e-01*S48+1.431568e-01*S49'
.param V24_part6='V24_part5+1.781149e-01*S50+(-4.079665e+00)*S51+1.304323e-01*S52+8.588675e-01*S53+7.139736e-02*S54+1.334841e-01*S55+1.460900e-01*S56+3.959421e-02*S57+8.728308e-02*S58+1.411392e-01*S59'
.param V24_part7='V24_part6+3.744317e-01*S60+3.344906e-01*S61+1.886099e-01*S62+2.178040e-01*S63+3.212987e-01*S64+3.400110e-01*S65+2.223953e-01*S66+2.764998e-01*S67+2.997085e-01*S68+1.798416e-01*S69'
.param V24_part8='V24_part7+2.461540e-01*S70+2.635594e-01*S71+8.061761e-02*S72+1.955294e-01*S73+2.626716e-01*S74+4.141639e-01*S75+4.439243e-01*S76+4.921510e-01*S77+4.096269e-01*S78+4.322325e-01*S79'
.param V24='V24_part8+5.000222e-01*S80+3.907976e-01*S81+3.781515e-01*S82+5.097153e-01*S83+3.734223e-01*S84+2.974195e-01*S85+5.180854e-01*S86+1.525677e-01*S87+2.027374e-01*S88+3.323389e-01*S89'
.param V25_part1='8.909953e-02*S0+4.560950e-01*S1+(-1.455113e-01)*S2+(-7.505539e-02)*S3+(-1.687040e-01)*S4+1.958825e+00*S5+1.767968e-01*S6+(-5.048855e-02)*S7+(-1.258732e-01)*S8+(-3.660017e-02)*S9'
.param V25_part2='V25_part1+(-2.475525e-01)*S10+(-2.482552e-03)*S11+(-1.740706e-01)*S12+(-2.483601e-01)*S13+(-4.005345e-02)*S14+(-6.024993e-01)*S15+7.628742e-02*S16+1.468405e+00*S17+(-5.090358e-01)*S18+3.517738e-02*S19'
.param V25_part3='V25_part2+1.583240e-01*S20+(-6.719809e-01)*S21+(-1.826969e-01)*S22+8.150223e-01*S23+(-4.527385e-01)*S24+(-1.541738e-01)*S25+(-6.910427e-01)*S26+(-8.902310e-02)*S27+(-1.899978e-01)*S28+(-2.188767e-01)*S29'
.param V25_part4='V25_part3+3.608732e-01*S30+5.548546e-02*S31+7.734890e-01*S32+(-5.755192e-01)*S33+6.340888e-01*S34+7.544951e-01*S35+(-8.256927e-01)*S36+(-2.397049e-01)*S37+7.929027e-01*S38+(-7.035299e-01)*S39'
.param V25_part5='V25_part4+1.323834e+00*S40+2.531701e-01*S41+1.093313e+00*S42+4.450402e-02*S43+1.102325e+00*S44+1.178253e+00*S45+3.982888e-01*S46+1.103829e+00*S47+(-3.606528e-01)*S48+(-2.354400e-02)*S49'
.param V25_part6='V25_part5+1.045818e+00*S50+(-4.623915e-01)*S51+2.880779e-01*S52+(-1.499343e-01)*S53+(-1.412862e-01)*S54+2.267977e+00*S55+(-2.277095e-02)*S56+5.898638e-02*S57+2.442445e+00*S58+1.857360e-01*S59'
.param V25_part7='V25_part6+1.158664e+00*S60+1.660367e+00*S61+3.587403e-01*S62+(-9.785718e-02)*S63+1.893754e+00*S64+(-1.232748e-02)*S65+6.428826e-01*S66+3.900287e-02*S67+1.405104e+00*S68+1.716418e-01*S69'
.param V25_part8='V25_part7+1.701556e-01*S70+(-3.113473e-02)*S71+8.916715e-01*S72+1.267657e-01*S73+4.710812e-03*S74+2.002719e-01*S75+3.125362e-01*S76+2.942190e-01*S77+1.056445e-01*S78+(-5.758576e-02)*S79'
.param V25='V25_part8+2.827593e-01*S80+(-1.205299e-01)*S81+1.247196e-01*S82+2.623641e-01*S83+(-8.888215e-02)*S84+4.297745e-01*S85+1.568586e-01*S86+5.975263e+01*S87+(-5.009640e+03)*S88+1.479750e+00*S89'
.param V26_part1='6.889169e-01*S0+(-9.390591e-02)*S1+6.556866e-01*S2+6.553086e-01*S3+1.629703e+00*S4+(-4.484849e-01)*S5+1.191105e+00*S6+(-7.199594e-02)*S7+1.376256e+00*S8+5.613498e-01*S9'
.param V26_part2='V26_part1+1.106122e+00*S10+4.460524e-01*S11+3.574071e-01*S12+4.155630e-01*S13+1.569005e-01*S14+2.498217e+00*S15+2.565767e-01*S16+(-9.149376e-02)*S17+1.477853e+00*S18+1.103097e+00*S19'
.param V26_part3='V26_part2+(-3.444509e-02)*S20+(-1.121121e-01)*S21+5.759096e-01*S22+2.046888e-02*S23+7.331259e-01*S24+4.805962e-01*S25+2.565409e-01*S26+1.275551e-01*S27+1.150176e-01*S28+5.286006e-01*S29'
.param V26_part4='V26_part3+2.162331e-01*S30+3.203360e-01*S31+(-1.198385e-02)*S32+1.740469e+00*S33+5.655028e-01*S34+6.856441e-01*S35+2.317775e+00*S36+1.297467e+00*S37+4.542608e-01*S38+1.749188e+00*S39'
.param V26_part5='V26_part4+(-4.158754e-01)*S40+5.129192e-01*S41+1.065918e-02*S42+1.043183e-02*S43+(-3.186703e-02)*S44+6.899266e-01*S45+1.707828e+00*S46+2.030384e-02*S47+1.584737e+00*S48+6.396172e-01*S49'
.param V26_part6='V26_part5+5.575027e-01*S50+(-8.393530e-02)*S51+1.285804e+00*S52+3.575530e-01*S53+5.716095e-01*S54+(-5.150229e-01)*S55+8.580668e-01*S56+4.945542e-01*S57+(-6.308829e-01)*S58+9.816802e-01*S59'
.param V26_part7='V26_part6+8.349501e-01*S60+4.838586e-01*S61+1.363626e-01*S62+8.518341e-01*S63+(-8.598222e-03)*S64+4.170385e-01*S65+3.091870e-01*S66+8.036907e-01*S67+3.824045e-01*S68+2.976620e-01*S69'
.param V26_part8='V26_part7+5.934057e-01*S70+1.432631e+00*S71+2.367872e+00*S72+5.539417e-01*S73+7.743364e-01*S74+6.936520e-01*S75+5.935131e-01*S76+2.073700e-03*S77+5.064405e-01*S78+6.733379e-01*S79'
.param V26='V26_part8+1.271339e-02*S80+6.122290e-01*S81+7.942859e-01*S82+3.983643e-02*S83+4.218675e-01*S84+2.809064e-01*S85+1.661635e-01*S86+6.051616e+00*S87+3.786049e+00*S88+(-5.858020e-02)*S89'
.param V27_part1='5.403636e-01*S0+(-1.719495e-01)*S1+4.047607e-02*S2+2.040697e-01*S3+1.186824e+00*S4+(-6.763277e-01)*S5+4.220045e-01*S6+7.097147e-02*S7+5.193735e-01*S8+4.960674e-01*S9'
.param V27_part2='V27_part1+1.466973e+00*S10+1.507221e-01*S11+7.085587e-02*S12+1.134543e-01*S13+(-9.939401e-02)*S14+1.335732e+00*S15+(-1.094575e-01)*S16+(-4.894244e-01)*S17+7.140117e-01*S18+(-3.487052e-02)*S19'
.param V27_part3='V27_part2+(-5.238608e-02)*S20+7.154176e-01*S21+(-2.446546e-01)*S22+(-1.821877e-01)*S23+4.878149e-01*S24+(-1.001507e+00)*S25+(-2.463721e-01)*S26+(-1.234288e-02)*S27+(-1.258123e-01)*S28+(-2.166368e-03)*S29'
.param V27_part4='V27_part3+(-7.842343e-01)*S30+(-3.104250e-01)*S31+(-1.183135e-01)*S32+7.460638e-01*S33+(-1.250695e-01)*S34+8.073674e-02*S35+1.401779e+00*S36+9.638550e-02*S37+2.405575e-01*S38+1.143903e+00*S39'
.param V27_part5='V27_part4+6.057682e-01*S40+2.037989e-01*S41+(-4.357030e-01)*S42+(-9.724572e-02)*S43+4.487676e-01*S44+8.649400e-01*S45+4.099192e-01*S46+3.861405e-01*S47+8.178210e-01*S48+(-1.860964e-02)*S49'
.param V27_part6='V27_part5+3.057874e-02*S50+9.359515e-01*S51+(-1.536790e-01)*S52+6.425722e-02*S53+(-4.308426e-02)*S54+(-3.270531e-01)*S55+2.640120e-01*S56+(-1.330937e-01)*S57+(-4.706567e-01)*S58+1.918114e-01*S59'
.param V27_part7='V27_part6+1.475734e+00*S60+(-1.933163e-02)*S61+8.995013e-01*S62+6.446978e-02*S63+(-1.857751e-01)*S64+2.579032e-02*S65+1.158887e-01*S66+(-8.557560e-01)*S67+(-5.540439e-03)*S68+(-1.736399e-01)*S69'
.param V27_part8='V27_part7+(-1.063386e+00)*S70+1.210215e-01*S71+2.884967e+00*S72+(-1.030038e+00)*S73+9.585933e-02*S74+(-2.239848e-01)*S75+(-6.725530e-03)*S76+5.092628e-02*S77+1.206197e-02*S78+(-1.177224e-01)*S79'
.param V27='V27_part8+1.136149e-01*S80+(-5.968594e-02)*S81+(-1.032026e+00)*S82+9.798227e-02*S83+(-6.930596e-02)*S84+(-1.091623e+00)*S85+6.769638e-02*S86+1.474752e+01*S87+3.699571e+01*S88+3.069041e-01*S89'
.param V28_part1='(-1.518292e-01)*S0+(-1.283540e-02)*S1+(-7.408270e-02)*S2+(-1.123931e-01)*S3+1.573509e-01*S4+(-2.226403e-02)*S5+(-2.061718e-01)*S6+4.046415e-03*S7+8.384997e-02*S8+(-1.115367e-01)*S9'
.param V28_part2='V28_part1+4.054149e-02*S10+(-9.746933e-02)*S11+(-8.840907e-02)*S12+(-9.123874e-02)*S13+(-6.102674e-02)*S14+8.882506e-03*S15+1.749860e-02*S16+(-5.918522e-02)*S17+(-6.744090e-03)*S18+(-1.340462e-01)*S19'
.param V28_part3='V28_part2+(-3.641231e-03)*S20+(-1.112179e-02)*S21+(-9.752956e-02)*S22+(-3.840506e-02)*S23+(-3.698630e-02)*S24+(-6.503833e-02)*S25+3.854949e-02*S26+(-4.603320e-02)*S27+(-2.163585e-02)*S28+(-7.946296e-02)*S29'
.param V28_part4='V28_part3+9.455540e-03*S30+2.151371e-02*S31+1.019844e-02*S32+(-3.021606e-04)*S33+(-6.630820e-03)*S34+(-1.773158e-02)*S35+(-4.707955e-02)*S36+(-5.071410e-02)*S37+(-2.244704e-02)*S38+(-5.580689e-02)*S39'
.param V28_part5='V28_part4+(-2.184081e-02)*S40+4.943165e-02*S41+(-1.047039e-01)*S42+(-2.735724e-02)*S43+(-3.797202e-02)*S44+(-6.073902e-02)*S45+5.795618e-03*S46+2.402470e-02*S47+(-2.749225e-02)*S48+2.470522e-02*S49'
.param V28_part6='V28_part5+1.127425e-01*S50+(-4.958326e-03)*S51+(-1.343329e-02)*S52+2.545341e-02*S53+(-1.646218e-03)*S54+(-4.697685e-02)*S55+1.053120e-02*S56+(-4.539701e-03)*S57+(-5.642592e-02)*S58+7.300847e-02*S59'
.param V28_part7='V28_part6+(-2.566131e-02)*S60+(-3.661440e-02)*S61+4.183851e-03*S62+4.314980e-04*S63+(-7.936525e-02)*S64+1.681628e-02*S65+1.486758e-02*S66+2.520513e-03*S67+8.644392e-02*S68+1.235137e-02*S69'
.param V28_part8='V28_part7+(-4.564099e-03)*S70+5.752700e-02*S71+(-1.712514e-01)*S72+7.330254e-03*S73+(-9.452096e-02)*S74+1.833249e-02*S75+1.333408e-02*S76+1.918198e-02*S77+1.426814e-02*S78+1.749393e-02*S79'
.param V28='V28_part8+1.148802e-02*S80+1.163574e-02*S81+1.282479e-02*S82+1.354530e-02*S83+2.145810e-03*S84+7.305941e-03*S85+1.072300e-02*S86+(-4.818457e-01)*S87+9.954889e-01*S88+(-8.257165e-03)*S89'
.param V29_part1='6.917066e-02*S0+(-1.202834e-02)*S1+2.210762e-02*S2+3.898502e-02*S3+2.480545e-02*S4+7.886095e-04*S5+1.307562e-01*S6+8.780294e-03*S7+2.683990e-02*S8+4.023569e-02*S9'
.param V29_part2='V29_part1+2.040808e-02*S10+1.879966e-02*S11+2.345939e-02*S12+1.560436e-02*S13+9.254132e-03*S14+7.083330e-02*S15+(-4.099669e-03)*S16+(-6.673002e-02)*S17+5.913151e-02*S18+6.096451e-02*S19'
.param V29_part3='V29_part2+(-1.039734e-03)*S20+(-7.789597e-03)*S21+2.959228e-02*S22+(-2.202030e-02)*S23+2.830791e-03*S24+(-4.459240e-02)*S25+(-2.067335e-02)*S26+(-3.049441e-02)*S27+(-2.639430e-02)*S28+2.706136e-02*S29'
.param V29_part4='V29_part3+7.881031e-03*S30+(-3.275496e-02)*S31+(-6.712763e-02)*S32+9.788332e-02*S33+(-3.651046e-02)*S34+(-7.133152e-02)*S35+6.988611e-02*S36+6.187693e-02*S37+(-7.120290e-02)*S38+4.154447e-03*S39'
.param V29_part5='V29_part4+4.702704e-02*S40+2.251563e-03*S41+(-4.133124e-02)*S42+(-2.875266e-02)*S43+(-6.520471e-02)*S44+(-2.790230e-01)*S45+(-2.686138e-02)*S46+(-1.121219e-01)*S47+1.087551e-02*S48+(-8.929482e-02)*S49'
.param V29_part6='V29_part5+(-8.049133e-02)*S50+(-4.823721e-02)*S51+5.749552e-02*S52+(-7.745540e-02)*S53+(-1.725932e-01)*S54+(-1.798989e-01)*S55+2.518197e-03*S56+(-1.745576e-01)*S57+(-1.447154e-01)*S58+(-3.403630e-02)*S59'
.param V29_part7='V29_part6+(-3.469276e-01)*S60+(-1.009379e-01)*S61+(-6.607492e-03)*S62+(-1.195109e-01)*S63+(-1.145222e-01)*S64+(-1.691080e-01)*S65+(-2.514950e-01)*S66+(-3.388890e-01)*S67+7.977100e-02*S68+(-2.039555e-01)*S69'
.param V29_part8='V29_part7+(-3.964566e-01)*S70+1.012060e-01*S71+(-1.706687e+00)*S72+(-5.249155e-01)*S73+(-4.268423e-02)*S74+(-1.398414e-01)*S75+(-1.282413e-01)*S76+(-6.906773e-02)*S77+(-1.893265e-01)*S78+(-1.688049e-01)*S79'
.param V29='V29_part8+(-1.078589e-01)*S80+(-2.708939e-01)*S81+(-3.864390e-01)*S82+(-1.244662e-01)*S83+(-3.729055e-01)*S84+(-3.656522e-01)*S85+(-1.394548e-01)*S86+(-4.395988e+01)*S87+1.000000e+04*S88+(-7.155984e-01)*S89'
.param V30_part1='(-9.133158e-01)*S0+1.875074e-02*S1+(-1.908738e-01)*S2+(-9.168661e-01)*S3+(-6.699660e-01)*S4+(-2.957833e+00)*S5+(-1.235515e+00)*S6+(-1.297252e+00)*S7+(-3.279844e+00)*S8+(-9.494843e-01)*S9'
.param V30_part2='V30_part1+(-1.788395e+00)*S10+(-3.851278e+00)*S11+(-1.251524e+00)*S12+(-2.011821e+00)*S13+(-4.419605e+00)*S14+(-6.622565e-01)*S15+(-2.341172e+00)*S16+(-6.826923e+00)*S17+(-9.467154e-02)*S18+(-4.743269e+00)*S19'
.param V30_part3='V30_part2+(-9.635692e+00)*S20+(-6.389060e-01)*S21+(-3.074407e+00)*S22+(-8.006835e+00)*S23+(-1.191923e-01)*S24+(-2.665612e+00)*S25+(-6.412396e+00)*S26+(-4.608110e-01)*S27+(-2.449655e+00)*S28+(-5.441226e+00)*S29'
.param V30_part4='V30_part3+(-1.928577e-01)*S30+(-7.066217e+00)*S31+(-6.355998e+00)*S32+(-2.324379e-01)*S33+(-3.038665e+00)*S34+(-6.224159e+00)*S35+(-6.049725e-01)*S36+(-7.937607e-01)*S37+(-8.240595e+00)*S38+3.745702e+00*S39'
.param V30_part5='V30_part4+(-1.159899e+00)*S40+(-7.802384e+00)*S41+3.766988e+00*S42+(-4.327834e+00)*S43+(-6.663059e+00)*S44+4.415285e-01*S45+(-6.571645e-01)*S46+(-1.000936e+01)*S47+3.156502e+00*S48+(-9.283908e+00)*S49'
.param V30_part6='V30_part5+5.947668e+00*S50+(-3.646762e-01)*S51+2.654232e+00*S52+(-1.102995e+01)*S53+(-8.682299e-01)*S54+(-1.543673e+00)*S55+(-1.100695e+01)*S56+(-1.183368e+00)*S57+(-1.273354e+00)*S58+6.622952e+00*S59'
.param V30_part7='V30_part6+(-1.345945e+00)*S60+5.045263e+00*S61+(-1.872725e+01)*S62+(-1.661180e+00)*S63+5.174021e+00*S64+(-2.316644e+01)*S65+(-7.662317e+00)*S66+(-8.526521e+00)*S67+(-1.360518e+01)*S68+(-1.031330e+01)*S69'
.param V30_part8='V30_part7+(-1.022908e+01)*S70+(-1.450870e+01)*S71+(-9.068033e+00)*S72+(-1.320296e+01)*S73+(-2.743992e+01)*S74+(-1.120452e+01)*S75+(-1.266461e+01)*S76+(-2.141500e+01)*S77+(-8.764164e+00)*S78+(-1.705368e+01)*S79'
.param V30='V30_part8+(-2.516243e+01)*S80+(-1.394421e+01)*S81+(-1.228956e+01)*S82+(-2.955154e+01)*S83+(-1.517531e+01)*S84+(-1.351485e+01)*S85+(-3.637619e+01)*S86+(-5.448054e+00)*S87+(-9.588920e+00)*S88+(-4.480590e+01)*S89'
.param V31_part1='2.320058e+00*S0+2.620098e+00*S1+2.200263e+00*S2+1.131103e+00*S3+3.270292e+00*S4+5.249201e+00*S5+2.825795e+00*S6+3.221510e+00*S7+5.507908e+00*S8+1.843231e+00*S9'
.param V31_part2='V31_part1+2.798507e+00*S10+4.803467e+00*S11+2.133382e+00*S12+3.056890e+00*S13+4.464240e+00*S14+1.274228e+01*S15+9.483337e+00*S16+1.234970e+01*S17+6.741243e+00*S18+6.592124e+00*S19'
.param V31_part3='V31_part2+1.315483e+01*S20+6.714323e+00*S21+8.059560e+00*S22+9.297849e+00*S23+5.608694e+00*S24+7.220543e+00*S25+1.021640e+01*S26+5.564016e+00*S27+6.833188e+00*S28+8.559373e+00*S29'
.param V31_part4='V31_part3+2.561650e+00*S30+1.300897e+01*S31+8.666002e+00*S32+1.190224e+00*S33+2.634991e+00*S34+3.859132e+00*S35+1.402042e+00*S36+(-5.586046e-01)*S37+7.574603e+00*S38+1.036679e+00*S39'
.param V31_part5='V31_part4+1.006055e+01*S40+1.453410e+01*S41+3.367994e+00*S42+1.133561e+01*S43+4.848502e+00*S44+(-5.066484e+00)*S45+(-7.192375e+00)*S46+1.049429e+01*S47+5.362596e+00*S48+1.159270e+01*S49'
.param V31_part6='V31_part5+4.404145e+00*S50+9.776913e+00*S51+3.729930e+00*S52+2.347832e+01*S53+1.406146e+01*S54+1.008295e+01*S55+2.185540e+01*S56+1.159587e+01*S57+1.026249e+01*S58+5.725803e+00*S59'
.param V31_part7='V31_part6+1.743398e+00*S60+4.503765e+00*S61+3.206583e+01*S62+1.721532e+01*S63+4.911872e+00*S64+3.132955e+01*S65+1.904320e+01*S66+2.107611e+01*S67+2.832957e+01*S68+1.851316e+01*S69'
.param V31_part8='V31_part7+2.081733e+01*S70+2.702381e+01*S71+1.162031e+01*S72+2.098306e+01*S73+3.010044e+01*S74+2.989840e+01*S75+2.428242e+01*S76+2.937108e+01*S77+2.511906e+01*S78+2.562210e+01*S79'
.param V31='V31_part8+3.850483e+01*S80+2.412763e+01*S81+2.651376e+01*S82+3.827780e+01*S83+2.109029e+01*S84+2.600989e+01*S85+3.528402e+01*S86+7.892892e+00*S87+1.208981e+01*S88+3.635067e+01*S89'
.param V32_part1='5.002870e+00*S0+3.087965e+00*S1+2.211941e+00*S2+5.726549e+00*S3+3.397989e+00*S4+5.614101e+00*S5+4.942050e+00*S6+5.156607e+00*S7+5.878464e+00*S8+5.538699e+00*S9'
.param V32_part2='V32_part1+6.007500e+00*S10+6.871228e+00*S11+7.039710e+00*S12+6.921626e+00*S13+6.659963e+00*S14+7.898333e+00*S15+9.555360e+00*S16+1.374337e+01*S17+6.238124e+00*S18+1.400899e+01*S19'
.param V32_part3='V32_part2+1.734389e+01*S20+7.831983e+00*S21+1.408591e+01*S22+1.653323e+01*S23+8.366529e+00*S24+1.383054e+01*S25+1.512678e+01*S26+9.188326e+00*S27+1.290128e+01*S28+1.496726e+01*S29'
.param V32_part4='V32_part3+1.243758e+01*S30+2.177550e+01*S31+1.454297e+01*S32+1.172328e+01*S33+1.811004e+01*S34+2.281055e+01*S35+1.690299e+01*S36+2.011176e+01*S37+2.303650e+01*S38+7.874112e+00*S39'
.param V32_part5='V32_part4+1.965547e+01*S40+2.624626e+01*S41+5.551724e+00*S42+2.338089e+01*S43+2.876503e+01*S44+1.936148e+01*S45+2.460690e+01*S46+3.531471e+01*S47+6.158274e+00*S48+3.217355e+01*S49'
.param V32_part6='V32_part5+1.181208e+01*S50+1.140908e+01*S51+1.115349e+01*S52+3.887048e+01*S53+2.780245e+01*S54+1.167775e+01*S55+4.103182e+01*S56+1.500426e+01*S57+1.181774e+01*S58+1.235933e+01*S59'
.param V32_part7='V32_part6+2.830939e+01*S60+1.184594e+01*S61+5.784501e+01*S62+1.371328e+01*S63+1.209237e+01*S64+6.302455e+01*S65+3.921983e+01*S66+5.009713e+01*S67+5.377205e+01*S68+4.523938e+01*S69'
.param V32_part8='V32_part7+5.450633e+01*S70+5.681906e+01*S71+2.166500e+01*S72+6.055505e+01*S73+8.269351e+01*S74+4.176553e+01*S75+5.589017e+01*S76+7.218615e+01*S77+3.849232e+01*S78+6.228705e+01*S79'
.param V32='V32_part8+7.639686e+01*S80+5.269580e+01*S81+6.952822e+01*S82+8.163677e+01*S83+6.227387e+01*S84+7.411259e+01*S85+9.218140e+01*S86+1.400609e+01*S87+2.413248e+01*S88+1.021246e+02*S89'
.param V33_part1='2.827454e-01*S0+3.496800e-01*S1+1.121027e+00*S2+2.188952e-01*S3+9.703139e-01*S4+1.208375e+00*S5+8.246682e-01*S6+9.686522e-01*S7+1.272096e+00*S8+5.167468e-01*S9'
.param V33_part2='V33_part1+7.307841e-01*S10+1.039777e+00*S11+7.681864e-01*S12+8.347927e-01*S13+1.312095e+00*S14+2.907412e-01*S15+4.687193e-01*S16+1.378950e+00*S17+3.843322e-01*S18+1.318110e+00*S19'
.param V33_part3='V33_part2+1.988947e+00*S20+3.750314e-01*S21+7.004971e-01*S22+6.062323e-01*S23+3.714815e-01*S24+6.034231e-01*S25+3.668321e-01*S26+4.355144e-01*S27+4.421562e-01*S28+2.825635e-01*S29'
.param V33_part4='V33_part3+5.496134e-01*S30+1.512632e+00*S31+1.534582e+00*S32+7.554846e-01*S33+1.125472e-01*S34+1.382421e+00*S35+1.082355e+00*S36+7.669347e-01*S37+1.137047e+00*S38+5.434733e-01*S39'
.param V33_part5='V33_part4+3.995595e-01*S40+6.810487e-01*S41+4.814989e-01*S42+5.319007e-01*S43+1.006409e+00*S44+4.017358e-01*S45+3.765413e-01*S46+6.091184e-01*S47+4.762298e-01*S48+4.612126e-01*S49'
.param V33_part6='V33_part5+1.579120e-01*S50+8.036319e-01*S51+5.412287e-01*S52+8.873182e-01*S53+5.528119e-01*S54+4.743357e-01*S55+9.392544e-01*S56+5.752967e-01*S57+3.282020e-01*S58+4.156461e-01*S59'
.param V33_part7='V33_part6+4.166881e-01*S60+3.024405e-01*S61+1.324387e+00*S62+3.671892e-01*S63+8.687210e-01*S64+1.472375e+00*S65+4.659719e-01*S66+7.772020e-01*S67+5.509615e-01*S68+1.802480e-01*S69'
.param V33_part8='V33_part7+9.501061e-01*S70+6.912081e-01*S71+(-4.286488e-01)*S72+1.049648e+00*S73+2.156970e+00*S74+2.129023e-01*S75+7.931155e-01*S76+1.767382e+00*S77+3.772597e-01*S78+4.294173e-01*S79'
.param V33='V33_part8+1.181960e+00*S80+3.247608e-01*S81+9.250608e-01*S82+1.322321e+00*S83+4.348546e-01*S84+9.693149e-01*S85+1.620846e+00*S86+(-1.236803e+00)*S87+(-2.619376e+00)*S88+2.027315e+00*S89'
.param V34_part1='9.508156e-03*S0+9.215028e-02*S1+2.506680e-02*S2+2.669626e-02*S3+7.890877e-02*S4+4.427903e-02*S5+6.540459e-03*S6+4.759970e-02*S7+3.402648e-02*S8+6.454764e-03*S9'
.param V34_part2='V34_part1+2.111270e-02*S10+2.539048e-02*S11+(-3.593347e-03)*S12+6.832755e-03*S13+1.226144e-02*S14+(-7.072983e-01)*S15+(-1.801589e-01)*S16+3.970402e-01*S17+(-8.582099e-01)*S18+3.666447e-01*S19'
.param V34_part3='V34_part2+6.170497e-01*S20+(-9.560636e-01)*S21+(-9.891419e-01)*S22+6.007554e-01*S23+(-1.116257e+00)*S24+(-1.132333e+00)*S25+(-1.282399e+00)*S26+(-1.258210e+00)*S27+(-1.365290e+00)*S28+(-1.452340e+00)*S29'
.param V34_part4='V34_part3+4.531659e-01*S30+8.375635e-01*S31+7.863293e-01*S32+7.962438e-01*S33+5.714872e-01*S34+4.490639e-01*S35+1.814932e-01*S36+2.673178e-01*S37+3.360245e-01*S38+3.551537e-01*S39'
.param V34_part5='V34_part4+(-2.749223e+00)*S40+(-3.091140e+00)*S41+7.301605e-02*S42+(-2.576546e+00)*S43+(-1.276953e+00)*S44+1.298442e+00*S45+6.307533e-01*S46+2.752230e-01*S47+4.019107e-01*S48+1.257866e+00*S49'
.param V34_part6='V34_part5+1.394707e+00*S50+5.189365e-01*S51+6.508994e-01*S52+(-4.462935e+00)*S53+(-3.363910e+00)*S54+9.165515e-01*S55+(-5.623181e+00)*S56+1.022722e-01*S57+8.170653e-01*S58+1.617397e+00*S59'
.param V34_part7='V34_part6+1.947026e+00*S60+2.634323e-01*S61+(-2.037404e+00)*S62+1.945570e+00*S63+1.577056e+00*S64+(-1.266453e+00)*S65+(-2.165193e+00)*S66+(-1.452718e+00)*S67+(-7.349892e+00)*S68+(-1.906581e+00)*S69'
.param V34_part8='V34_part7+(-1.380741e+00)*S70+(-8.198780e+00)*S71+1.319975e+00*S72+(-1.066457e+00)*S73+(-5.610522e+00)*S74+3.771131e+00*S75+(-6.376704e-02)*S76+(-1.985736e+00)*S77+1.037491e+00*S78+1.776748e+00*S79'
.param V34='V34_part8+(-5.437418e+00)*S80+2.689254e+00*S81+(-7.948029e-01)*S82+(-5.894802e+00)*S83+2.761828e+00*S84+(-2.098953e+00)*S85+(-5.098270e+00)*S86+1.336587e+00*S87+1.989691e+00*S88+2.475418e+00*S89'
.param V35_part1='1.447987e+01*S0+1.503235e+03*S1+4.475605e+02*S2+6.971697e+00*S3+2.140822e+01*S4+6.822801e+02*S5+4.409403e+01*S6+1.929529e+01*S7+2.600168e+02*S8+2.865979e+02*S9'
.param V35_part2='V35_part1+8.032699e+02*S10+2.595134e+02*S11+2.992111e+01*S12+2.760264e+01*S13+2.162756e+01*S14+1.843902e+01*S15+7.599499e+03*S16+4.132178e+01*S17+1.878123e+01*S18+3.601121e+01*S19'
.param V35_part3='V35_part2+4.819290e+01*S20+3.112705e+01*S21+1.941546e+01*S22+4.875859e+01*S23+3.211976e+01*S24+2.423879e+01*S25+2.664490e+01*S26+1.820837e+01*S27+2.385253e+01*S28+1.037189e+01*S29'
.param V35_part4='V35_part3+4.678377e+01*S30+1.556575e+02*S31+1.014127e+01*S32+3.281721e+01*S33+9.897031e+00*S34+1.012033e+01*S35+8.143555e+00*S36+8.230388e+00*S37+5.027915e+00*S38+5.167713e+00*S39'
.param V35_part5='V35_part4+1.095367e+01*S40+4.061830e+00*S41+4.608081e+00*S42+7.619071e+00*S43+4.981479e+00*S44+1.266466e+01*S45+1.218200e+01*S46+4.505867e+00*S47+1.070549e+01*S48+8.008895e+00*S49'
.param V35_part6='V35_part5+5.102447e+00*S50+8.926654e+00*S51+5.591338e+00*S52+4.137835e+00*S53+1.445257e+01*S54+5.116853e+00*S55+8.344930e+00*S56+7.257716e+00*S57+5.068356e+00*S58+4.041493e+00*S59'
.param V35_part7='V35_part6+2.242794e+01*S60+6.401245e+00*S61+5.316045e+00*S62+6.478888e+00*S63+6.168548e+00*S64+9.868562e+00*S65+6.044285e+00*S66+5.731690e+00*S67+5.398347e+00*S68+4.796939e+00*S69'
.param V35_part8='V35_part7+6.019489e+00*S70+1.266545e+01*S71+8.059675e-01*S72+4.680139e+00*S73+1.476630e+01*S74+1.148600e+01*S75+8.534027e+00*S76+3.062520e+00*S77+4.924276e+00*S78+6.538198e+00*S79'
.param V35='V35_part8+2.934255e+00*S80+8.955782e+00*S81+1.087283e+01*S82+2.841070e+00*S83+7.436647e+00*S84+4.688802e+00*S85+2.703700e+00*S86+0.000000e+00*S87+7.240341e+02*S88+3.410870e+00*S89'
.param V36_part1='(-1.182638e+01)*S0+2.405718e+01*S1+(-6.541350e+02)*S2+(-4.500267e+00)*S3+1.156352e+00*S4+(-5.212118e+01)*S5+6.859794e-01*S6+(-8.796579e+00)*S7+1.221516e+01*S8+(-5.797678e+00)*S9'
.param V36_part2='V36_part1+1.314459e+01*S10+(-1.156711e+01)*S11+(-8.568480e+00)*S12+(-8.031050e+00)*S13+(-6.991820e+00)*S14+(-4.524248e+00)*S15+1.071285e+01*S16+(-1.737745e+01)*S17+(-6.566607e+00)*S18+(-6.451837e+00)*S19'
.param V36_part3='V36_part2+(-8.444583e+00)*S20+(-8.657620e+00)*S21+(-8.331814e+00)*S22+(-1.371450e+01)*S23+(-9.930775e+00)*S24+(-9.634581e+00)*S25+(-7.412848e+00)*S26+(-6.635864e+00)*S27+(-8.003487e+00)*S28+(-3.052007e+00)*S29'
.param V36_part4='V36_part3+(-8.130733e+00)*S30+(-1.127200e+02)*S31+(-1.596363e+00)*S32+(-1.352745e+01)*S33+(-4.240763e+00)*S34+(-2.998582e+00)*S35+(-4.077681e+00)*S36+(-2.539537e+00)*S37+(-1.199279e+00)*S38+(-2.020329e+00)*S39'
.param V36_part5='V36_part4+(-3.652439e+00)*S40+(-1.136232e+00)*S41+(-1.536079e+00)*S42+(-2.334108e+00)*S43+(-1.297686e+00)*S44+(-5.272152e+00)*S45+(-3.994832e+00)*S46+(-1.500660e+00)*S47+(-4.595405e+00)*S48+(-3.093060e+00)*S49'
.param V36_part6='V36_part5+(-1.412245e+00)*S50+(-3.545385e+00)*S51+(-2.254995e+00)*S52+(-8.658642e-01)*S53+(-4.757359e+00)*S54+(-1.803874e+00)*S55+(-1.507192e+00)*S56+(-2.370045e+00)*S57+(-1.577686e+00)*S58+(-9.105448e-01)*S59'
.param V36_part7='V36_part6+(-6.704987e+00)*S60+(-2.082116e+00)*S61+(-1.068505e+00)*S62+(-2.760828e+00)*S63+(-1.957327e+00)*S64+(-2.074650e+00)*S65+(-2.509288e+00)*S66+(-1.416626e+00)*S67+(-1.093298e+00)*S68+(-1.550330e+00)*S69'
.param V36_part8='V36_part7+(-1.150470e+00)*S70+(-6.625302e-01)*S71+1.360459e-01*S72+2.351769e-01*S73+(-2.412005e+00)*S74+(-2.820722e+00)*S75+(-2.622358e+00)*S76+(-6.057676e-01)*S77+(-1.905960e+00)*S78+(-2.233985e+00)*S79'
.param V36='V36_part8+(-5.754869e-01)*S80+(-3.002249e+00)*S81+(-2.476610e+00)*S82+(-5.386322e-01)*S83+(-2.285668e+00)*S84+(-1.016678e+00)*S85+(-4.747924e-01)*S86+0.000000e+00*S87+(-1.851666e+01)*S88+(-6.180828e-01)*S89'
.param V37_part1='(-3.681280e+00)*S0+(-6.372565e+01)*S1+6.751659e+01*S2+9.187097e+00*S3+(-2.804455e+00)*S4+(-1.899502e+01)*S5+(-1.451132e+01)*S6+(-3.579804e+00)*S7+(-2.600001e+00)*S8+(-5.780230e+01)*S9'
.param V37_part2='V37_part1+(-3.741972e+01)*S10+(-1.040649e+01)*S11+(-8.108483e+00)*S12+(-7.891346e+00)*S13+(-4.664554e+00)*S14+(-1.671662e+01)*S15+(-7.161239e+01)*S16+(-1.720682e+01)*S17+(-1.843662e+01)*S18+(-1.665105e+01)*S19'
.param V37_part3='V37_part2+(-1.375137e+01)*S20+(-2.238316e+01)*S21+(-9.375728e+00)*S22+(-2.143649e+01)*S23+(-2.364143e+01)*S24+(-1.097314e+01)*S25+(-1.087328e+01)*S26+(-6.552729e+00)*S27+(-1.059882e+01)*S28+(-3.138649e+00)*S29'
.param V37_part4='V37_part3+(-8.003670e+01)*S30+(-1.205978e+02)*S31+(-5.376657e+00)*S32+(-2.577592e+01)*S33+(-3.948099e+00)*S34+(-3.085413e+00)*S35+(-3.502482e+00)*S36+(-2.783334e+00)*S37+(-1.266454e+00)*S38+(-1.434556e+00)*S39'
.param V37_part5='V37_part4+(-5.124338e+00)*S40+(-7.589657e-01)*S41+(-1.111099e+00)*S42+(-3.298090e+00)*S43+(-1.562063e+00)*S44+(-1.106720e+01)*S45+(-7.899229e+00)*S46+(-1.933482e+00)*S47+(-7.645281e+00)*S48+(-4.814441e+00)*S49'
.param V37_part6='V37_part5+(-2.781350e+00)*S50+(-5.925142e+00)*S51+(-4.010358e+00)*S52+(-1.176357e+00)*S53+(-9.104218e+00)*S54+(-3.574828e+00)*S55+(-5.934272e-01)*S56+(-4.233252e+00)*S57+(-3.283641e+00)*S58+(-2.004692e+00)*S59'
.param V37_part7='V37_part6+(-2.099077e+01)*S60+(-3.883260e+00)*S61+(-2.721732e+00)*S62+(-3.188244e+00)*S63+(-3.419118e+00)*S64+(-4.945306e+00)*S65+(-3.163619e+00)*S66+(-3.324034e+00)*S67+(-2.352676e+00)*S68+(-1.850474e+00)*S69'
.param V37_part8='V37_part7+(-3.683311e+00)*S70+2.223329e+00*S71+(-5.654639e-01)*S72+(-3.676801e+00)*S73+(-4.333687e+00)*S74+(-1.167473e+01)*S75+(-5.988407e+00)*S76+(-1.431448e+00)*S77+(-3.850807e+00)*S78+(-4.150198e+00)*S79'
.param V37='V37_part8+(-1.287227e+00)*S80+(-7.316469e+00)*S81+(-6.842632e+00)*S82+(-1.178170e+00)*S83+(-5.479592e+00)*S84+(-2.710547e+00)*S85+(-1.069889e+00)*S86+0.000000e+00*S87+(-7.076659e+00)*S88+(-8.656502e-01)*S89'
.param V38_part1='8.413871e+00*S0+(-1.852330e+03)*S1+7.758973e+02*S2+6.364976e+00*S3+(-9.238584e+00)*S4+(-7.769172e+02)*S5+(-2.384693e+01)*S6+(-3.200031e+00)*S7+(-3.010571e+02)*S8+(-2.791269e+02)*S9'
.param V38_part2='V38_part1+(-9.899920e+02)*S10+(-2.675905e+02)*S11+(-8.702618e+00)*S12+(-6.304894e+00)*S13+(-3.225311e+00)*S14+(-2.978168e+00)*S15+(-1.000000e+04)*S16+(-7.810528e+00)*S17+(-3.744869e-01)*S18+(-1.076776e+01)*S19'
.param V38_part3='V38_part2+(-1.867438e+01)*S20+(-7.762823e+00)*S21+(-2.174658e+00)*S22+(-9.472033e+00)*S23+(-6.546011e+00)*S24+(-3.385433e+00)*S25+(-3.752126e+00)*S26+(-3.345378e+00)*S27+(-3.986379e+00)*S28+(-8.541392e-01)*S29'
.param V38_part4='V38_part3+6.357918e+00*S30+4.835836e+01*S31+(-1.252300e-01)*S32+(-6.894587e+00)*S33+2.993549e+00*S34+3.945103e+00*S35+2.310944e+00*S36+3.507094e+00*S37+1.454336e+00*S38+1.815631e+00*S39'
.param V38_part5='V38_part4+(-1.312437e+00)*S40+9.822377e-01*S41+1.665145e+00*S42+(-4.852589e-01)*S43+(-1.020627e-01)*S44+(-1.512592e+00)*S45+(-1.739524e+00)*S46+1.142811e-01*S47+(-9.368915e-01)*S48+(-3.585422e-01)*S49'
.param V38_part6='V38_part5+7.446399e-02*S50+(-4.856648e-01)*S51+2.225580e-01*S52+1.068151e+00*S53+(-1.784209e+00)*S54+2.208288e-01*S55+5.866599e+00*S56+(-2.626412e-01)*S57+1.025988e-01*S58+9.982056e-02*S59'
.param V38_part7='V38_part6+(-4.860128e+00)*S60+1.693019e+00*S61+2.759345e-01*S62+2.154917e+00*S63+1.604926e+00*S64+1.425104e+00*S65+1.865776e+00*S66+5.818787e-01*S67+(-2.260907e-01)*S68+1.266343e+00*S69'
.param V38_part8='V38_part7+9.953923e-01*S70+1.839564e+01*S71+4.482960e-01*S72+4.834484e-01*S73+1.922900e+00*S74+(-1.196469e+00)*S75+(-6.679196e-01)*S76+1.763636e-01*S77+4.558453e-01*S78+(-2.402843e-01)*S79'
.param V38='V38_part8+1.481443e-01*S80+(-5.162870e-01)*S81+(-2.335982e-01)*S82+1.027093e-01*S83+(-3.281300e-01)*S84+9.896801e-03*S85+8.667564e-02*S86+0.000000e+00*S87+2.763747e+03*S88+7.396498e-01*S89'
.param V39_part1='(-1.291453e-01)*S0+(-7.321987e+00)*S1+(-6.088205e+00)*S2+1.136612e-01*S3+(-1.547930e-02)*S4+1.469778e+00*S5+(-1.889483e-01)*S6+(-1.238544e-01)*S7+(-3.914639e-01)*S8+(-1.353087e+00)*S9'
.param V39_part2='V39_part1+(-2.060667e+00)*S10+(-4.205551e-01)*S11+(-1.875357e-01)*S12+(-8.432024e-02)*S13+(-6.464850e-02)*S14+(-1.840918e-01)*S15+(-4.760617e+00)*S16+(-3.404274e-01)*S17+(-1.006875e+00)*S18+(-6.979722e-01)*S19'
.param V39_part3='V39_part2+(-5.816914e-01)*S20+(-2.031340e+00)*S21+(-7.185608e-01)*S22+(-4.426705e-01)*S23+(-2.440169e+00)*S24+(-8.533836e-01)*S25+(-6.895183e-01)*S26+(-5.975489e-01)*S27+(-6.943083e-01)*S28+(-3.543164e-01)*S29'
.param V39_part4='V39_part3+(-8.395137e-02)*S30+(-2.398755e+00)*S31+(-9.214210e-02)*S32+(-1.510825e+00)*S33+(-3.161751e-01)*S34+(-2.421729e-01)*S35+(-2.372267e-01)*S36+(-2.119012e-01)*S37+(-7.475732e-02)*S38+(-1.073229e-01)*S39'
.param V39_part5='V39_part4+(-2.037830e-01)*S40+(-1.453038e-01)*S41+(-7.139531e-02)*S42+(-1.309780e-01)*S43+(-9.634533e-02)*S44+(-7.121851e-01)*S45+(-4.224750e-01)*S46+(-1.053996e-01)*S47+(-4.388533e-01)*S48+(-2.756080e-01)*S49'
.param V39_part6='V39_part5+(-3.778414e-02)*S50+(-4.014267e-01)*S51+1.146481e-02*S52+(-7.883887e-02)*S53+(-9.137472e-01)*S54+2.698855e-02*S55+2.525523e-02*S56+(-2.088341e-01)*S57+3.287101e-02*S58+(-7.258927e-04)*S59'
.param V39_part7='V39_part6+(-1.298345e+00)*S60+(-2.487434e-01)*S61+(-2.414719e-01)*S62+(-2.665367e-01)*S63+(-2.564252e-01)*S64+(-4.059400e-01)*S65+2.958576e-01*S66+(-4.085053e-01)*S67+(-1.213938e-01)*S68+(-1.735320e-01)*S69'
.param V39_part8='V39_part7+(-2.085911e-01)*S70+1.283654e-01*S71+(-2.417794e-02)*S72+(-1.212029e-01)*S73+(-2.591231e+00)*S74+(-7.205203e-01)*S75+(-3.922499e-01)*S76+(-9.494731e-02)*S77+(-2.409180e-01)*S78+(-2.829284e-01)*S79'
.param V39='V39_part8+(-8.450249e-02)*S80+(-4.569317e-01)*S81+(-1.377769e+00)*S82+(-9.021787e-02)*S83+(-3.292588e-01)*S84+(-3.135003e-01)*S85+(-8.355802e-02)*S86+0.000000e+00*S87+(-1.310032e-01)*S88+(-4.205780e-02)*S89'
.param V40_part1='9.740286e+00*S0+1.852020e+01*S1+1.101313e+01*S2+1.482448e+01*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+7.596581e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V40_part2='V40_part1+0.000000e+00*S10+0.000000e+00*S11+9.374376e+00*S12+8.266866e+00*S13+(-1.804186e+00)*S14+1.067434e+00*S15+3.999812e+00*S16+9.021492e+00*S17+8.216951e+00*S18+2.102818e+00*S19'
.param V40_part3='V40_part2+9.786325e+00*S20+8.120908e+00*S21+1.879388e+01*S22+2.451978e+01*S23+2.749580e+00*S24+1.046537e+01*S25+2.927580e+01*S26+4.354524e+01*S27+3.305758e+01*S28+1.909587e+01*S29'
.param V40_part4='V40_part3+2.555334e+01*S30+6.425821e+00*S31+(-1.092317e+01)*S32+0.000000e+00*S33+2.606824e+01*S34+0.000000e+00*S35+1.756754e+01*S36+0.000000e+00*S37+0.000000e+00*S38+4.902567e+00*S39'
.param V40_part5='V40_part4+8.577873e+00*S40+5.335639e+01*S41+2.360669e+00*S42+8.995440e+00*S43+(-6.307860e+00)*S44+7.746978e+00*S45+8.941900e+00*S46+4.918950e+01*S47+5.219352e+00*S48+8.440542e+00*S49'
.param V40_part6='V40_part5+(-2.999232e+01)*S50+6.126904e-01*S51+(-1.699874e+01)*S52+(-3.991501e+00)*S53+(-1.266623e+00)*S54+(-4.738055e+01)*S55+0.000000e+00*S56+(-4.851501e+00)*S57+(-7.841207e+01)*S58+(-8.579885e+01)*S59'
.param V40_part7='V40_part6+9.837940e+00*S60+2.064833e+01*S61+0.000000e+00*S62+(-1.031543e-01)*S63+2.568533e+01*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+(-3.298342e+01)*S68+(-1.143589e+01)*S69'
.param V40_part8='V40_part7+0.000000e+00*S70+(-3.433288e+01)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+8.390777e+00*S75+3.151309e-01*S76+3.347352e+00*S77+2.347826e+00*S78+(-2.421887e+00)*S79'
.param V40='V40_part8+1.505556e-02*S80+6.517075e+00*S81+0.000000e+00*S82+(-1.004368e-03)*S83+6.152691e+00*S84+0.000000e+00*S85+(-2.723324e-03)*S86+0.000000e+00*S87+(-2.413195e+02)*S88+0.000000e+00*S89'
.param V41_part1='(-2.749022e+01)*S0+(-1.447003e+01)*S1+7.055143e-01*S2+(-1.445360e+01)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+(-1.539330e+00)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V41_part2='V41_part1+0.000000e+00*S10+0.000000e+00*S11+(-1.938037e+00)*S12+1.405956e-01*S13+1.432085e+01*S14+3.274195e+01*S15+2.430696e+01*S16+4.376751e+00*S17+2.161537e+00*S18+6.304185e+00*S19'
.param V41_part3='V41_part2+(-2.030858e+00)*S20+8.142846e+00*S21+6.166203e+00*S22+(-1.296458e+01)*S23+1.332141e+01*S24+1.233281e+01*S25+(-4.755925e+00)*S26+(-4.221469e+00)*S27+(-5.485551e-01)*S28+1.066505e+01*S29'
.param V41_part4='V41_part3+(-5.041488e+01)*S30+(-1.148738e+00)*S31+4.825401e+01*S32+0.000000e+00*S33+(-1.479282e+01)*S34+0.000000e+00*S35+(-4.953728e+00)*S36+0.000000e+00*S37+0.000000e+00*S38+3.719027e+01*S39'
.param V41_part5='V41_part4+3.078726e+01*S40+9.588438e+00*S41+3.474668e+01*S42+2.702083e+01*S43+5.196400e+01*S44+3.721981e+01*S45+3.786036e+01*S46+2.622344e+00*S47+3.476790e+01*S48+3.719958e+01*S49'
.param V41_part6='V41_part5+6.703150e+01*S50+3.531325e+01*S51+1.980066e+01*S52+4.009603e+01*S53+2.989693e+01*S54+4.419598e+01*S55+0.000000e+00*S56+3.145055e+01*S57+6.663949e+01*S58+8.644159e+01*S59'
.param V41_part7='V41_part6+2.276803e+01*S60+(-2.480280e+00)*S61+0.000000e+00*S62+3.524448e+01*S63+(-2.337681e+01)*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+5.203201e+01*S68+2.680600e+01*S69'
.param V41_part8='V41_part7+0.000000e+00*S70+5.722138e+01*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+2.407927e+01*S75+3.435544e+01*S76+2.666528e+01*S77+2.714466e+01*S78+2.737160e+01*S79'
.param V41='V41_part8+1.873410e+01*S80+8.721884e-02*S81+0.000000e+00*S82+8.293801e+00*S83+5.824691e+00*S84+0.000000e+00*S85+1.593723e+00*S86+0.000000e+00*S87+2.682086e+02*S88+0.000000e+00*S89'
.param V42_part1='2.346181e+01*S0+(-1.139902e+01)*S1+(-1.123141e+01)*S2+(-7.669213e-01)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+(-5.752232e+00)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V42_part2='V42_part1+0.000000e+00*S10+0.000000e+00*S11+(-6.572080e+00)*S12+(-5.437262e+00)*S13+6.538575e+00*S14+4.173067e+01*S15+2.620630e+00*S16+(-4.077874e+00)*S17+4.479769e+00*S18+3.408502e+00*S19'
.param V42_part3='V42_part2+8.433058e+00*S20+1.769597e+00*S21+2.615875e+00*S22+3.953294e+00*S23+1.991758e+01*S24+1.356799e+00*S25+3.645553e+00*S26+(-3.688724e+01)*S27+(-9.951062e+00)*S28+(-2.396293e+00)*S29'
.param V42_part4='V42_part3+2.160476e+00*S30+2.165773e+01*S31+1.451342e+01*S32+0.000000e+00*S33+(-1.975815e+01)*S34+0.000000e+00*S35+3.699501e-02*S36+0.000000e+00*S37+0.000000e+00*S38+5.165538e+01*S39'
.param V42_part5='V42_part4+4.086367e+01*S40+(-3.810431e+01)*S41+6.292838e+01*S42+4.216118e+01*S43+4.070406e+01*S44+5.112153e+01*S45+4.808531e+01*S46+(-4.639523e+01)*S47+6.173184e+01*S48+5.036153e+01*S49'
.param V42_part6='V42_part5+8.793405e+01*S50+7.239147e+01*S51+8.244229e+01*S52+5.597700e+01*S53+7.321101e+01*S54+1.034563e+02*S55+0.000000e+00*S56+9.280199e+01*S57+1.158365e+02*S58+1.301801e+02*S59'
.param V42_part7='V42_part6+5.995942e+01*S60+3.553598e+01*S61+0.000000e+00*S62+9.136977e+01*S63+2.958235e-02*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+8.979727e+01*S68+4.702264e+01*S69'
.param V42_part8='V42_part7+0.000000e+00*S70+8.466318e+01*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+8.173708e+01*S75+8.947102e+01*S76+8.755849e+01*S77+9.736741e+01*S78+9.919818e+01*S79'
.param V42='V42_part8+5.055588e+01*S80+1.145760e+02*S81+0.000000e+00*S82+2.841854e+01*S83+1.076296e+02*S84+0.000000e+00*S85+6.264449e+00*S86+0.000000e+00*S87+4.798671e+02*S88+0.000000e+00*S89'
.param V43_part1='(-3.679260e+00)*S0+(-1.002926e+01)*S1+(-3.049828e-01)*S2+(-4.635369e+00)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+2.347855e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V43_part2='V43_part1+0.000000e+00*S10+0.000000e+00*S11+3.946719e+00*S12+3.487484e+00*S13+4.687988e-01*S14+(-2.630496e+00)*S15+(-2.904993e-01)*S16+2.556202e+00*S17+(-6.837667e-01)*S18+5.720384e+00*S19'
.param V43_part3='V43_part2+5.726465e+00*S20+7.546254e-01*S21+(-1.539152e+00)*S22+(-5.236616e+00)*S23+8.017221e-01*S24+4.802960e-01*S25+(-6.311251e+00)*S26+(-2.878760e+00)*S27+(-4.630305e+00)*S28+(-1.263795e+01)*S29'
.param V43_part4='V43_part3+1.498773e+00*S30+4.330077e+00*S31+8.077802e-01*S32+0.000000e+00*S33+(-6.590358e-01)*S34+0.000000e+00*S35+1.902539e+01*S36+0.000000e+00*S37+0.000000e+00*S38+(-1.463965e+01)*S39'
.param V43_part5='V43_part4+(-1.383981e+01)*S40+(-7.703378e+00)*S41+(-1.619079e+01)*S42+(-1.255679e+01)*S43+(-1.893145e+01)*S44+(-7.176363e+00)*S45+(-9.717000e+00)*S46+(-8.190509e+00)*S47+(-1.032190e+01)*S48+(-1.185789e+01)*S49'
.param V43_part6='V43_part5+(-1.785654e+01)*S50+(-1.062535e+01)*S51+(-9.150373e-01)*S52+(-1.737861e+01)*S53+(-1.196370e+01)*S54+(-2.026831e-01)*S55+0.000000e+00*S56+(-1.503258e+01)*S57+1.587828e+00*S58+(-2.321223e+01)*S59'
.param V43_part7='V43_part6+(-6.930464e+00)*S60+(-4.218031e+00)*S61+0.000000e+00*S62+(-1.184072e+01)*S63+6.188643e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+(-1.826741e+01)*S68+(-5.063422e+00)*S69'
.param V43_part8='V43_part7+0.000000e+00*S70+(-2.102214e+01)*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-9.370808e+00)*S75+(-1.316042e+01)*S76+(-2.539792e+01)*S77+(-1.224449e+01)*S78+(-1.356787e+01)*S79'
.param V43='V43_part8+(-9.713466e+00)*S80+(-7.029154e+00)*S81+0.000000e+00*S82+(-8.561558e+00)*S83+(-5.990046e+00)*S84+0.000000e+00*S85+8.119680e-01*S86+0.000000e+00*S87+(-2.701011e+01)*S88+0.000000e+00*S89'
.param V44_part1='(-1.714258e-01)*S0+1.158697e+00*S1+1.086175e-01*S2+(-3.944898e-01)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+1.197095e-01*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V44_part2='V44_part1+0.000000e+00*S10+0.000000e+00*S11+2.197804e-02*S12+1.203923e-01*S13+6.330554e-02*S14+2.076695e+00*S15+(-2.655922e+00)*S16+(-7.766382e-01)*S17+(-2.842916e+00)*S18+8.826189e-01*S19'
.param V44_part3='V44_part2+5.721147e-01*S20+(-2.516527e+00)*S21+(-4.329930e+00)*S22+(-9.426504e-01)*S23+(-3.641222e+00)*S24+(-4.383566e+00)*S25+(-4.616228e+00)*S26+(-9.251597e+00)*S27+(-5.881051e+00)*S28+2.502660e+00*S29'
.param V44_part4='V44_part3+(-3.123270e+00)*S30+4.849599e-01*S31+(-2.652046e-01)*S32+0.000000e+00*S33+(-1.008694e+00)*S34+0.000000e+00*S35+(-5.389398e-01)*S36+0.000000e+00*S37+0.000000e+00*S38+2.599984e+00*S39'
.param V44_part5='V44_part4+4.737849e+00*S40+(-9.121961e+00)*S41+3.076494e+00*S42+5.057120e+00*S43+7.188684e+00*S44+2.818345e+00*S45+3.477424e+00*S46+8.171927e-01*S47+3.492013e+00*S48+3.857669e+00*S49'
.param V44_part6='V44_part5+6.136298e+00*S50+3.786570e+00*S51+(-3.277756e+00)*S52+9.527744e+00*S53+6.722018e+00*S54+(-6.915578e-01)*S55+0.000000e+00*S56+7.008120e+00*S57+3.646169e-01*S58+1.135753e+01*S59'
.param V44_part7='V44_part6+2.777301e+00*S60+4.364670e+00*S61+0.000000e+00*S62+4.415513e+00*S63+9.820347e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+1.541319e+01*S68+1.354356e+01*S69'
.param V44_part8='V44_part7+0.000000e+00*S70+1.428954e+01*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+3.948318e+00*S75+6.720883e+00*S76+1.032684e+01*S77+8.138589e+00*S78+9.109516e+00*S79'
.param V44='V44_part8+5.673234e+00*S80+7.492588e+00*S81+0.000000e+00*S82+5.303792e+00*S83+8.490881e+00*S84+0.000000e+00*S85+3.007603e+00*S86+0.000000e+00*S87+3.507556e+01*S88+0.000000e+00*S89'
.param V45_part1='8.281826e-01*S0+(-1.955182e+00)*S1+(-5.696090e+00)*S2+(-3.736307e-01)*S3+(-2.070064e+00)*S4+(-2.396409e+00)*S5+(-7.353839e-01)*S6+(-1.948669e+00)*S7+(-3.735271e+00)*S8+(-2.021884e+00)*S9'
.param V45_part2='V45_part1+(-2.239561e+00)*S10+(-4.983876e+00)*S11+(-2.482486e+00)*S12+(-3.659086e+00)*S13+(-5.673173e+00)*S14+(-2.133049e+00)*S15+(-1.168111e+00)*S16+(-3.699797e+00)*S17+(-1.707922e+00)*S18+(-1.252979e+00)*S19'
.param V45_part3='V45_part2+(-2.649724e+00)*S20+(-2.024491e+00)*S21+(-3.311429e+00)*S22+(-9.565593e+00)*S23+(-2.532044e+00)*S24+(-4.134176e+00)*S25+(-1.628753e+01)*S26+(-6.526984e+00)*S27+(-7.798183e+00)*S28+(-2.331271e+01)*S29'
.param V45_part4='V45_part3+(-4.371309e+00)*S30+(-8.219465e-01)*S31+(-2.325988e+01)*S32+(-5.696739e+00)*S33+(-9.015669e+00)*S34+(-2.765875e+01)*S35+(-8.912371e+00)*S36+(-1.490917e+01)*S37+(-3.150774e+01)*S38+(-2.018797e+01)*S39'
.param V45_part5='V45_part4+(-1.807491e+01)*S40+(-3.672762e+01)*S41+(-2.302892e+01)*S42+(-1.857029e+01)*S43+(-3.846123e+01)*S44+(-1.216497e+01)*S45+(-1.650494e+01)*S46+(-3.051266e+01)*S47+(-2.008111e+01)*S48+(-6.528357e+00)*S49'
.param V45_part6='V45_part5+(-7.185619e+01)*S50+(-1.689177e+01)*S51+(-3.383006e+01)*S52+(-4.678338e+01)*S53+(-1.322146e+01)*S54+(-3.035999e+01)*S55+(-5.376226e+01)*S56+(-2.226547e+01)*S57+(-3.648872e+01)*S58+(-9.367113e+01)*S59'
.param V45_part7='V45_part6+(-1.199929e+01)*S60+(-3.676475e+01)*S61+2.756567e-01*S62+(-1.838407e+01)*S63+(-4.191351e+01)*S64+1.844385e+00*S65+(-9.503442e+00)*S66+0.000000e+00*S67+(-6.990442e+01)*S68+(-8.302803e+00)*S69'
.param V45_part8='V45_part7+0.000000e+00*S70+(-7.799635e+01)*S71+(-1.557244e+01)*S72+0.000000e+00*S73+0.000000e+00*S74+(-2.964843e-01)*S75+(-1.635260e+01)*S76+(-4.921501e+01)*S77+(-9.019447e+00)*S78+(-1.276161e+01)*S79'
.param V45='V45_part8+(-5.494344e+01)*S80+(-5.029572e+00)*S81+0.000000e+00*S82+(-6.012318e+01)*S83+(-8.281487e+00)*S84+0.000000e+00*S85+(-5.927307e+01)*S86+(-3.137960e+01)*S87+(-4.585701e+01)*S88+0.000000e+00*S89'
.param V46_part1='5.331371e+00*S0+5.651805e+00*S1+1.174186e+01*S2+8.927210e+00*S3+5.364225e+00*S4+6.854392e+00*S5+5.237751e+00*S6+5.012470e+00*S7+7.129355e+00*S8+5.982232e+00*S9'
.param V46_part2='V46_part1+5.909331e+00*S10+8.575903e+00*S11+5.115020e+00*S12+6.321807e+00*S13+8.856479e+00*S14+(-1.861469e-01)*S15+2.867881e+00*S16+7.481496e+00*S17+5.202933e+00*S18+4.727619e+00*S19'
.param V46_part3='V46_part2+6.219871e+00*S20+4.912873e+00*S21+4.870456e+00*S22+1.325425e+01*S23+4.928429e+00*S24+4.904268e+00*S25+1.175008e+01*S26+4.588224e+00*S27+5.542132e+00*S28+1.529986e+01*S29'
.param V46_part4='V46_part3+1.345513e+01*S30+4.193349e+00*S31+2.857265e+01*S32+1.434770e+01*S33+1.967502e+01*S34+3.887557e+01*S35+1.685005e+01*S36+2.416411e+01*S37+3.379878e+01*S38+1.778828e+01*S39'
.param V46_part5='V46_part4+7.984207e+00*S40+1.996042e+01*S41+1.357507e+01*S42+6.331635e+00*S43+3.334164e+01*S44+3.767116e+01*S45+4.381226e+01*S46+3.407019e+01*S47+1.693093e+01*S48+1.284618e+01*S49'
.param V46_part6='V46_part5+5.533700e+01*S50+8.865625e+00*S51+2.692410e+01*S52+1.860733e+01*S53+3.790495e+00*S54+1.500485e+01*S55+2.063405e+01*S56+4.703934e+00*S57+1.455059e+01*S58+4.795699e+01*S59'
.param V46_part7='V46_part6+2.794305e+01*S60+3.353662e+01*S61+7.121158e+00*S62+1.764760e+00*S63+3.079420e+01*S64+6.211283e+00*S65+(-3.358741e+00)*S66+0.000000e+00*S67+2.373255e+01*S68+(-3.643009e+00)*S69'
.param V46_part8='V46_part7+0.000000e+00*S70+2.686936e+01*S71+8.896798e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-1.474795e+01)*S75+4.513774e+00*S76+2.345369e+01*S77+(-1.060953e+01)*S78+(-1.089272e+00)*S79'
.param V46='V46_part8+6.901794e+00*S80+(-7.078729e+00)*S81+0.000000e+00*S82+9.485594e+00*S83+(-6.004057e-01)*S84+0.000000e+00*S85+1.403704e+01*S86+2.282412e+01*S87+2.371339e+01*S88+0.000000e+00*S89'
.param V47_part1='(-1.170313e+00)*S0+4.412949e+00*S1+1.015866e+01*S2+(-4.214029e-01)*S3+6.183410e+00*S4+5.287405e+00*S5+3.816478e+00*S6+5.380090e+00*S7+6.481333e+00*S8+6.769134e+00*S9'
.param V47_part2='V47_part1+6.435958e+00*S10+7.102674e+00*S11+7.299766e+00*S12+6.991744e+00*S13+1.001499e+01*S14+6.041950e+00*S15+5.855642e+00*S16+8.223955e+00*S17+5.925464e+00*S18+5.951321e+00*S19'
.param V47_part3='V47_part2+5.737922e+00*S20+6.811473e+00*S21+6.676047e+00*S22+1.185390e+01*S23+7.559101e+00*S24+1.011055e+01*S25+1.864795e+01*S26+1.792066e+01*S27+1.683406e+01*S28+2.390412e+01*S29'
.param V47_part4='V47_part3+9.350056e+00*S30+4.462999e+00*S31+4.155815e+01*S32+1.550798e+01*S33+1.798154e+01*S34+2.897159e+01*S35+1.540837e+01*S36+1.916330e+01*S37+3.540820e+01*S38+4.064376e+01*S39'
.param V47_part5='V47_part4+2.532913e+01*S40+3.374009e+01*S41+5.330074e+01*S42+2.706600e+01*S43+3.260490e+01*S44+1.851321e+01*S45+2.226154e+01*S46+3.496416e+01*S47+5.167913e+01*S48+1.704308e+01*S49'
.param V47_part6='V47_part5+8.799066e+01*S50+5.110143e+01*S51+6.814891e+01*S52+4.343072e+01*S53+3.202602e+01*S54+7.635092e+01*S55+4.731021e+01*S56+6.403888e+01*S57+8.770475e+01*S58+1.133487e+02*S59'
.param V47_part7='V47_part6+2.305587e+01*S60+7.707601e+01*S61+9.897308e+00*S62+6.662549e+01*S63+8.817498e+01*S64+1.014426e+01*S65+2.899406e+01*S66+0.000000e+00*S67+6.809937e+01*S68+2.773963e+01*S69'
.param V47_part8='V47_part7+0.000000e+00*S70+7.187658e+01*S71+9.383514e+01*S72+0.000000e+00*S73+0.000000e+00*S74+2.741147e+01*S75+3.631247e+01*S76+6.199133e+01*S77+4.794391e+01*S78+3.512842e+01*S79'
.param V47='V47_part8+6.803353e+01*S80+3.429187e+01*S81+0.000000e+00*S82+7.232999e+01*S83+2.851838e+01*S84+0.000000e+00*S85+6.649699e+01*S86+1.414202e+02*S87+1.554976e+02*S88+0.000000e+00*S89'
.param V48_part1='5.534351e-01*S0+7.856435e-01*S1+1.899189e-01*S2+6.117375e-01*S3+(-1.150088e-01)*S4+2.155574e-02*S5+(-3.214483e-01)*S6+(-1.070616e-02)*S7+(-9.823174e-02)*S8+4.315788e-01*S9'
.param V48_part2='V48_part1+2.616666e-01*S10+3.779808e-01*S11+1.095694e-01*S12+3.254326e-01*S13+(-1.653002e-01)*S14+1.351607e-02*S15+3.071329e-01*S16+(-8.730830e-02)*S17+3.616970e-01*S18+(-4.401973e-01)*S19'
.param V48_part3='V48_part2+(-1.207435e+00)*S20+8.580446e-02*S21+4.398330e-01*S22+1.386461e+00*S23+3.987518e-01*S24+4.518722e-01*S25+1.950224e+00*S26+3.012352e-01*S27+1.119472e+00*S28+2.068455e+00*S29'
.param V48_part4='V48_part3+(-9.020717e-01)*S30+(-6.613818e-01)*S31+(-1.733302e-01)*S32+(-4.258863e-01)*S33+(-1.610998e-01)*S34+(-1.220850e-01)*S35+(-1.149222e+00)*S36+(-3.174809e-01)*S37+4.627123e-01*S38+5.461224e-01*S39'
.param V48_part5='V48_part4+1.587140e-01*S40+1.312250e+00*S41+5.713867e-01*S42+9.388387e-01*S43+1.492089e+00*S44+5.494630e-01*S45+3.426059e-01*S46+2.110983e+00*S47+5.361734e-01*S48+9.977629e-01*S49'
.param V48_part6='V48_part5+3.503736e+00*S50+2.676606e-01*S51+1.197354e+00*S52+2.048885e+00*S53+(-7.534352e-02)*S54+1.349267e+00*S55+1.256109e+00*S56+4.954620e-01*S57+1.793576e+00*S58+2.774080e+00*S59'
.param V48_part7='V48_part6+3.989623e-01*S60+5.138214e-01*S61+(-2.014936e+00)*S62+1.190549e+00*S63+2.038577e-01*S64+(-2.621681e+00)*S65+7.458770e-01*S66+0.000000e+00*S67+2.414252e+00*S68+1.560528e+00*S69'
.param V48_part8='V48_part7+0.000000e+00*S70+2.109144e+00*S71+2.537204e+00*S72+0.000000e+00*S73+0.000000e+00*S74+3.639824e-01*S75+3.303080e-02*S76+(-1.270387e+00)*S77+(-9.958715e-02)*S78+1.269249e+00*S79'
.param V48='V48_part8+(-5.363264e-03)*S80+9.666198e-01*S81+0.000000e+00*S82+3.577877e-04*S83+8.626187e-01*S84+0.000000e+00*S85+1.770916e-03*S86+4.427355e+00*S87+7.629095e+00*S88+0.000000e+00*S89'
.param V49_part1='1.217362e-01*S0+(-2.944424e-02)*S1+1.427592e-01*S2+9.200014e-02*S3+3.439886e-02*S4+9.307949e-02*S5+7.102056e-02*S6+5.928521e-02*S7+1.069198e-01*S8+8.392634e-02*S9'
.param V49_part2='V49_part1+1.096958e-01*S10+1.351012e-01*S11+1.106307e-01*S12+1.175025e-01*S13+1.463122e-01*S14+1.124874e+00*S15+4.585304e-01*S16+5.380187e-01*S17+5.293451e-01*S18+2.803168e-01*S19'
.param V49_part3='V49_part2+2.632900e-01*S20+6.913231e-01*S21+8.303889e-01*S22+3.612521e-01*S23+8.499102e-01*S24+1.113301e+00*S25+3.878540e+00*S26+1.933929e+00*S27+2.274179e+00*S28+4.626795e+00*S29'
.param V49_part4='V49_part3+8.271659e-01*S30+2.609912e-01*S31+1.378813e+00*S32+3.166113e-01*S33+8.582221e-01*S34+2.293366e+00*S35+1.486876e+00*S36+1.521139e+00*S37+2.909782e+00*S38+1.566830e+00*S39'
.param V49_part5='V49_part4+7.267819e+00*S40+9.597087e+00*S41+2.372437e+00*S42+7.824163e+00*S43+6.560419e+00*S44+1.298616e-01*S45+2.076239e+00*S46+5.456466e+00*S47+2.299830e+00*S48+1.431995e+00*S49'
.param V49_part6='V49_part5+3.511972e+00*S50+2.356799e+00*S51+2.920621e+00*S52+1.503108e+01*S53+4.299618e+00*S54+2.898119e+00*S55+1.680318e+01*S56+4.305373e+00*S57+3.634638e+00*S58+3.603976e+00*S59'
.param V49_part7='V49_part6+5.590476e-01*S60+4.234110e+00*S61+(-4.183444e-01)*S62+1.135505e+00*S63+2.332063e+00*S64+(-1.076660e+00)*S65+8.612138e+00*S66+0.000000e+00*S67+2.290047e+01*S68+9.538292e+00*S69'
.param V49_part8='V49_part7+0.000000e+00*S70+2.463480e+01*S71+3.552859e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-9.935004e-01)*S75+7.110368e+00*S76+1.463297e+01*S77+4.523313e+00*S78+4.484661e+00*S79'
.param V49='V49_part8+2.261874e+01*S80+1.737552e+00*S81+0.000000e+00*S82+2.433334e+01*S83+2.323061e+00*S84+0.000000e+00*S85+2.361855e+01*S86+6.159104e+00*S87+5.589392e+00*S88+0.000000e+00*S89'
.param V50_part1='1.321355e+01*S0+6.895102e-01*S1+1.697563e+00*S2+1.149498e+01*S3+(-2.334106e-02)*S4+(-2.106419e-01)*S5+(-3.044523e-02)*S6+1.040484e-01*S7+1.078666e-02*S8+4.962937e-02*S9'
.param V50_part2='V50_part1+(-2.328877e-02)*S10+(-8.221469e-02)*S11+2.561585e-01*S12+1.558922e-01*S13+1.880129e+00*S14+1.354960e+01*S15+2.263119e-01*S16+1.002722e-01*S17+3.685687e-02*S18+5.591221e-02*S19'
.param V50_part3='V50_part2+2.654749e-01*S20+4.333665e-01*S21+2.913319e-01*S22+6.852740e-01*S23+3.504165e-01*S24+2.093231e-01*S25+8.002570e-01*S26+8.089598e-01*S27+1.009709e+00*S28+1.306901e+00*S29'
.param V50_part4='V50_part3+2.895678e+00*S30+2.597292e-01*S31+4.242286e+00*S32+3.047884e+00*S33+5.517955e+00*S34+3.391453e+00*S35+8.734862e+00*S36+4.790141e+00*S37+6.308078e+00*S38+1.408466e+01*S39'
.param V50_part5='V50_part4+3.179666e+00*S40+8.855485e+00*S41+1.276507e+01*S42+2.769001e+00*S43+3.633661e+00*S44+4.529933e+00*S45+4.195288e+00*S46+8.270096e+00*S47+4.351423e+00*S48+5.696868e+00*S49'
.param V50_part6='V50_part5+2.551592e+00*S50+3.620836e+00*S51+7.992379e+00*S52+5.899492e+00*S53+3.872279e+00*S54+1.706327e+01*S55+2.009664e+00*S56+3.642729e+00*S57+6.433491e+00*S58+(-3.890408e-01)*S59'
.param V50_part7='V50_part6+3.046946e+00*S60+8.179275e+00*S61+0.000000e+00*S62+9.721511e+00*S63+7.274966e+00*S64+0.000000e+00*S65+1.028809e+01*S66+1.422509e+01*S67+2.649726e+00*S68+1.306729e+01*S69'
.param V50_part8='V50_part7+7.681748e+00*S70+1.569370e+00*S71+7.504947e+03*S72+7.788283e+00*S73+1.761970e+00*S74+5.180822e+00*S75+3.899626e+00*S76+3.065050e+03*S77+8.659352e+03*S78+4.921354e+00*S79'
.param V50='V50_part8+2.520190e+03*S80+2.837684e+00*S81+2.887540e+00*S82+2.496890e+03*S83+2.450059e+00*S84+9.517352e+00*S85+3.027778e+02*S86+0.000000e+00*S87+1.443065e+00*S88+0.000000e+00*S89'
.param V51_part1='(-6.324910e+00)*S0+(-2.794534e-02)*S1+(-2.569418e-01)*S2+(-2.993866e+00)*S3+2.313574e-01*S4+2.690249e-01*S5+2.025620e-01*S6+1.088795e-01*S7+1.342245e-01*S8+2.055133e-01*S9'
.param V51_part2='V51_part1+1.844434e-01*S10+2.029561e-01*S11+4.384713e-02*S12+1.552401e-01*S13+(-5.743549e-01)*S14+(-1.831109e+01)*S15+2.379591e-01*S16+3.692389e-01*S17+1.004693e+00*S18+2.689442e-01*S19'
.param V51_part3='V51_part2+(-8.323223e-02)*S20+1.958077e-01*S21+1.540037e-01*S22+(-3.724085e-02)*S23+1.614517e-01*S24+1.061782e-01*S25+(-3.251523e-01)*S26+(-6.201466e-01)*S27+(-5.627771e-01)*S28+(-2.479145e-01)*S29'
.param V51_part4='V51_part3+(-1.347134e+00)*S30+(-2.483888e-01)*S31+(-2.900009e+00)*S32+(-1.120821e+00)*S33+(-1.581874e+00)*S34+(-7.230744e-01)*S35+(-2.109279e+00)*S36+(-1.305820e+00)*S37+(-1.478161e+00)*S38+(-4.520407e+00)*S39'
.param V51_part5='V51_part4+(-1.114351e+00)*S40+(-2.135811e+00)*S41+(-4.593407e+00)*S42+(-1.035775e+00)*S43+(-2.096935e-01)*S44+1.559355e+00*S45+(-6.625757e-01)*S46+(-1.581933e-01)*S47+(-1.811063e+00)*S48+(-1.960818e+00)*S49'
.param V51_part6='V51_part5+1.538614e+00*S50+(-1.557826e+00)*S51+3.165286e+00*S52+(-1.340153e+00)*S53+(-1.384583e+00)*S54+(-5.882620e-01)*S55+(-4.518778e-01)*S56+(-1.310490e+00)*S57+(-1.484289e+00)*S58+1.308384e+00*S59'
.param V51_part7='V51_part6+(-1.188731e+00)*S60+(-2.820645e+00)*S61+0.000000e+00*S62+(-4.004759e+00)*S63+(-2.540675e+00)*S64+0.000000e+00*S65+(-4.354008e+00)*S66+(-8.319429e+00)*S67+(-4.997463e-01)*S68+(-4.869238e+00)*S69'
.param V51_part8='V51_part7+(-3.343055e+00)*S70+(-2.974706e-01)*S71+(-5.662957e-01)*S72+(-4.145979e+00)*S73+(-5.388177e-01)*S74+(-3.436150e+00)*S75+(-2.067599e+00)*S76+1.718580e+03*S77+(-8.161031e+03)*S78+(-1.754133e+00)*S79'
.param V51='V51_part8+4.598876e+01*S80+(-1.528155e+00)*S81+(-9.883421e-01)*S82+3.074533e+01*S83+(-9.235198e-01)*S84+(-4.440384e+00)*S85+1.587746e+00*S86+0.000000e+00*S87+(-4.549430e-01)*S88+0.000000e+00*S89'
.param V52_part1='(-1.439578e+01)*S0+(-1.386441e-02)*S1+(-5.698856e-01)*S2+(-1.408671e+01)*S3+1.202422e-01*S4+2.447671e-01*S5+(-6.306880e-03)*S6+7.547704e-02*S7+6.384215e-02*S8+3.768418e-02*S9'
.param V52_part2='V52_part1+1.191612e-01*S10+1.546784e-01*S11+4.578553e-02*S12+4.924701e-02*S13+(-2.588542e-01)*S14+(-9.045534e+00)*S15+(-4.898649e-02)*S16+3.998950e-02*S17+3.202660e-01*S18+1.088993e-01*S19'
.param V52_part3='V52_part2+1.290403e-02*S20+(-1.909000e-01)*S21+4.267794e-01*S22+(-9.214354e-03)*S23+4.248051e-01*S24+4.399060e-01*S25+2.060251e-01*S26+1.114571e+00*S27+4.007818e-01*S28+2.480126e-01*S29'
.param V52_part4='V52_part3+4.632601e-01*S30+3.222837e-02*S31+(-7.319381e-01)*S32+(-1.561277e+00)*S33+(-2.642332e+00)*S34+(-1.363819e+00)*S35+(-6.882561e+00)*S36+(-2.511922e+00)*S37+(-2.558011e+00)*S38+(-7.833691e+00)*S39'
.param V52_part5='V52_part4+(-7.663528e-01)*S40+(-3.587449e+00)*S41+(-4.002001e+00)*S42+3.081890e-01*S43+(-3.371721e-01)*S44+(-2.997988e+00)*S45+(-2.453891e+00)*S46+3.367311e+00*S47+8.841575e-02*S48+(-1.962803e+00)*S49'
.param V52_part6='V52_part5+5.340805e+00*S50+2.709464e+00*S51+3.141414e+01*S52+(-2.656086e+00)*S53+(-1.070826e+00)*S54+3.889135e+01*S55+(-7.401995e-01)*S56+1.631034e+00*S57+1.291722e+01*S58+1.446367e+01*S59'
.param V52_part7='V52_part6+(-1.759189e+00)*S60+(-4.874621e+00)*S61+0.000000e+00*S62+(-7.298305e+00)*S63+(-3.724402e+00)*S64+0.000000e+00*S65+(-8.153777e+00)*S66+(-9.115514e+00)*S67+(-5.177891e-01)*S68+(-1.098351e+01)*S69'
.param V52_part8='V52_part7+(-3.539881e+00)*S70+(-6.146299e-01)*S71+(-4.422135e+00)*S72+(-1.874293e+00)*S73+(-6.399525e-01)*S74+(-3.142099e+00)*S75+(-1.919050e+00)*S76+(-8.308699e+02)*S77+(-4.436415e+03)*S78+(-1.899162e+00)*S79'
.param V52='V52_part8+(-2.476693e+01)*S80+8.681139e-01*S81+(-1.428473e+00)*S82+1.652222e+00*S83+1.141631e+00*S84+(-2.286448e+00)*S85+7.504312e+00*S86+0.000000e+00*S87+(-6.320294e-01)*S88+0.000000e+00*S89'
.param V53_part1='(-3.451169e+00)*S0+(-8.739576e-01)*S1+(-6.068390e-02)*S2+(-2.073105e+00)*S3+4.226630e-01*S4+1.766557e-01*S5+9.244328e-02*S6+7.309438e-01*S7+1.855340e-01*S8+4.927911e-01*S9'
.param V53_part2='V53_part1+3.525298e-01*S10+3.013516e-01*S11+8.558120e-01*S12+7.790649e-01*S13+6.706464e-01*S14+1.456438e+00*S15+5.859462e-01*S16+3.581164e-01*S17+1.470503e+00*S18+5.910492e-01*S19'
.param V53_part3='V53_part2+2.599182e-01*S20+1.006998e+00*S21+1.308728e+00*S22+5.035483e-01*S23+1.215962e+00*S24+9.455309e-01*S25+6.723787e-01*S26+1.215626e+00*S27+9.846802e-01*S28+1.432370e+00*S29'
.param V53_part4='V53_part3+(-7.880613e-01)*S30+3.839689e-01*S31+8.078806e-01*S32+9.197107e-01*S33+(-9.397802e-01)*S34+(-2.951913e-01)*S35+(-1.657455e+00)*S36+(-5.764021e-01)*S37+(-8.599416e-01)*S38+(-3.706539e+00)*S39'
.param V53_part5='V53_part4+1.442600e+00*S40+(-1.729834e+00)*S41+(-3.511378e+00)*S42+2.299141e+00*S43+2.968115e+00*S44+3.217609e+00*S45+1.740173e+00*S46+1.850604e+01*S47+3.107020e+00*S48+3.602468e+00*S49'
.param V53_part6='V53_part5+8.279986e+00*S50+4.017337e+00*S51+4.891834e+01*S52+(-6.884257e-01)*S53+1.280731e+00*S54+8.268220e+01*S55+(-3.504611e-02)*S56+3.083345e+00*S57+1.658437e+01*S58+1.645762e+01*S59'
.param V53_part7='V53_part6+1.207906e+00*S60+(-1.430350e+00)*S61+0.000000e+00*S62+(-1.637392e+00)*S63+(-1.236595e+00)*S64+0.000000e+00*S65+(-1.362690e+00)*S66+4.817374e-02*S67+1.192259e+00*S68+(-1.937589e+00)*S69'
.param V53_part8='V53_part7+(-2.233976e-01)*S70+2.375306e-02*S71+(-1.000000e+04)*S72+3.095677e-01*S73+3.830280e-02*S74+2.111214e+00*S75+1.680223e+00*S76+9.981254e+03*S77+1.000000e+04*S78+2.573894e+00*S79'
.param V53='V53_part8+1.000000e+04*S80+1.997674e+00*S81+5.952245e-01*S82+1.000000e+04*S83+2.118233e+00*S84+4.665880e+00*S85+1.191551e+03*S86+0.000000e+00*S87+2.623145e-04*S88+0.000000e+00*S89'
.param V54_part1='(-1.687272e-01)*S0+2.970230e-02*S1+(-1.869239e-02)*S2+(-2.645688e-01)*S3+1.694697e-03*S4+1.925516e-03*S5+(-2.253003e-03)*S6+(-2.348686e-03)*S7+5.270282e-03*S8+(-2.689226e-03)*S9'
.param V54_part2='V54_part1+3.968605e-03*S10+3.707987e-03*S11+6.512395e-03*S12+7.317152e-03*S13+(-1.054601e-02)*S14+1.394798e-01*S15+(-1.110343e-02)*S16+1.797613e-02*S17+(-5.816682e-02)*S18+3.582810e-02*S19'
.param V54_part3='V54_part2+9.342913e-03*S20+3.252021e-02*S21+3.990131e-02*S22+(-4.287584e-02)*S23+4.019905e-02*S24+6.546980e-02*S25+1.818420e-01*S26+1.684077e-01*S27+1.605485e-01*S28+2.943478e-01*S29'
.param V54_part4='V54_part3+(-5.525577e-02)*S30+6.199055e-03*S31+(-1.441721e-01)*S32+(-1.533986e-01)*S33+(-1.797144e-01)*S34+(-4.806587e-02)*S35+(-2.956028e-01)*S36+(-1.007261e-01)*S37+(-7.968797e-02)*S38+(-4.381613e-01)*S39'
.param V54_part5='V54_part4+1.087339e-01*S40+2.443628e-01*S41+(-2.986864e-01)*S42+3.032925e-01*S43+9.186510e-02*S44+(-3.586182e-01)*S45+(-1.526637e-01)*S46+5.306092e-01*S47+(-1.034872e-01)*S48+(-8.943835e-02)*S49'
.param V54_part6='V54_part5+(-2.060348e-01)*S50+1.106792e-01*S51+(-5.841820e-01)*S52+(-4.256545e-03)*S53+(-3.909626e-01)*S54+(-1.358415e+00)*S55+(-5.505535e-04)*S56+1.046037e-01*S57+(-6.533605e-01)*S58+(-6.120567e-01)*S59'
.param V54_part7='V54_part6+(-1.653532e-01)*S60+(-3.621153e-01)*S61+0.000000e+00*S62+(-4.533680e-01)*S63+(-2.988121e-01)*S64+0.000000e+00*S65+(-5.614103e-01)*S66+(-3.099969e-01)*S67+5.705119e-02*S68+(-1.658021e-01)*S69'
.param V54_part8='V54_part7+(-1.005445e+00)*S70+(-1.863235e-02)*S71+(-1.685454e-01)*S72+(-1.045887e+00)*S73+(-3.157734e-01)*S74+(-2.783521e-01)*S75+(-1.146206e-02)*S76+7.242557e+00*S77+(-4.399540e+01)*S78+(-9.485895e-02)*S79'
.param V54='V54_part8+2.345906e+01*S80+6.915980e-02*S81+(-2.336337e-02)*S82+3.079756e+00*S83+1.295257e-01*S84+(-5.716970e-01)*S85+3.709318e+00*S86+0.000000e+00*S87+(-1.819591e-01)*S88+0.000000e+00*S89'
.param V55_part1='(-9.161544e+00)*S0+9.979883e+00*S1+2.345225e+01*S2+(-3.532277e+01)*S3+4.345321e+02*S4+3.078154e+02*S5+4.734839e+02*S6+1.288885e+02*S7+3.113602e+02*S8+2.607249e+02*S9'
.param V55_part2='V55_part1+3.296099e+02*S10+2.829726e+02*S11+9.910303e+01*S12+9.656062e+01*S13+6.396486e+01*S14+0.000000e+00*S15+1.045468e+02*S16+8.617797e+01*S17+4.625989e+01*S18+1.115322e+02*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+2.152436e+01*S21+(-1.963359e+01)*S22+(-2.989981e+01)*S23+3.609377e+01*S24+1.022409e+01*S25+(-4.295024e+01)*S26+(-1.023166e+02)*S27+(-5.294438e+01)*S28+1.100226e+00*S29'
.param V55_part4='V55_part3+(-2.650144e+00)*S30+0.000000e+00*S31+4.492424e+01*S32+3.839129e+01*S33+(-2.414279e+01)*S34+7.995409e+01*S35+(-1.034678e+01)*S36+3.894188e+01*S37+2.359176e+01*S38+0.000000e+00*S39'
.param V55_part5='V55_part4+0.000000e+00*S40+(-5.361758e+01)*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-5.748955e+01)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V55_part6='V55_part5+0.000000e+00*S50+0.000000e+00*S51+2.036387e+01*S52+0.000000e+00*S53+0.000000e+00*S54+6.400182e+01*S55+2.406959e+01*S56+0.000000e+00*S57+9.020208e+01*S58+0.000000e+00*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+(-4.378120e+01)*S61+8.240079e+03*S62+0.000000e+00*S63+(-4.809768e+01)*S64+2.346583e+03*S65+(-2.928966e+01)*S66+4.555668e+01*S67+0.000000e+00*S68+1.652097e+01*S69'
.param V55_part8='V55_part7+2.211013e+01*S70+0.000000e+00*S71+0.000000e+00*S72+5.601111e+01*S73+(-8.589214e+02)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V55='V55_part8+(-9.751799e+00)*S80+0.000000e+00*S81+2.005137e+02*S82+(-1.104219e+01)*S83+0.000000e+00*S84+2.563902e+02*S85+(-1.353256e+01)*S86+1.000000e+04*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part1='1.537841e+02*S0+2.613355e+02*S1+2.786093e+01*S2+1.109184e+02*S3+(-3.264983e+02)*S4+(-3.182498e+01)*S5+(-3.830289e+02)*S6+1.256559e+02*S7+(-8.398389e+01)*S8+(-5.472523e+01)*S9'
.param V56_part2='V56_part1+(-8.859248e+01)*S10+(-3.519867e+01)*S11+4.127736e+01*S12+3.067423e+01*S13+1.217130e+01*S14+0.000000e+00*S15+(-1.265515e+02)*S16+(-1.979687e+01)*S17+2.526025e+01*S18+(-8.908228e+00)*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+1.353931e+00*S21+4.665280e+01*S22+9.717411e+01*S23+2.632811e+00*S24+1.342747e+01*S25+7.197510e+01*S26+8.384345e+01*S27+6.009327e+01*S28+3.643928e+01*S29'
.param V56_part4='V56_part3+2.181454e+02*S30+0.000000e+00*S31+(-1.912813e+01)*S32+4.717839e+01*S33+6.965271e+01*S34+9.703849e+00*S35+6.595956e+01*S36+4.804639e+01*S37+6.740355e+01*S38+0.000000e+00*S39'
.param V56_part5='V56_part4+0.000000e+00*S40+3.072754e+01*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+4.630589e+01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V56_part6='V56_part5+0.000000e+00*S50+0.000000e+00*S51+4.348207e+01*S52+0.000000e+00*S53+0.000000e+00*S54+(-2.609268e+00)*S55+8.950520e+01*S56+0.000000e+00*S57+(-2.894036e+01)*S58+0.000000e+00*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+9.255512e+01*S61+1.000000e+04*S62+0.000000e+00*S63+1.256419e+02*S64+8.495040e+02*S65+1.236410e+02*S66+1.119571e+02*S67+0.000000e+00*S68+1.797807e+01*S69'
.param V56_part8='V56_part7+1.586342e+02*S70+0.000000e+00*S71+0.000000e+00*S72+1.928993e+02*S73+1.133148e+03*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V56='V56_part8+1.003730e+01*S80+0.000000e+00*S81+7.242526e+01*S82+8.919689e+00*S83+0.000000e+00*S84+1.315864e+02*S85+1.260549e+01*S86+8.066762e+03*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part1='1.245911e+00*S0+7.919376e+01*S1+7.699848e+01*S2+1.062733e+02*S3+(-8.395152e+01)*S4+(-8.029087e+01)*S5+(-6.644627e+01)*S6+4.290433e+01*S7+(-6.605494e+01)*S8+(-6.920730e+01)*S9'
.param V57_part2='V57_part1+(-1.146432e+02)*S10+(-7.446386e+01)*S11+2.280287e+01*S12+3.938391e+01*S13+9.106979e+00*S14+0.000000e+00*S15+1.493058e+01*S16+5.591893e+01*S17+8.747349e+01*S18+4.775360e+01*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+1.064942e+02*S21+5.794586e+01*S22+4.405350e+01*S23+1.145051e+01*S24+6.250906e+01*S25+5.024742e+01*S26+1.771560e+02*S27+8.687826e+01*S28+5.338951e+01*S29'
.param V57_part4='V57_part3+5.153934e-01*S30+0.000000e+00*S31+4.060358e+01*S32+6.960448e+01*S33+1.323929e+02*S34+6.685147e+01*S35+7.759407e+01*S36+7.641437e+01*S37+8.134552e+01*S38+0.000000e+00*S39'
.param V57_part5='V57_part4+0.000000e+00*S40+1.527769e+02*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+1.735935e+02*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V57_part6='V57_part5+0.000000e+00*S50+0.000000e+00*S51+(-1.211286e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+(-2.934064e+01)*S55+1.025706e+02*S56+0.000000e+00*S57+(-1.484103e+01)*S58+0.000000e+00*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+9.196704e+01*S61+2.007910e+03*S62+0.000000e+00*S63+1.589287e+02*S64+1.918458e+03*S65+1.749672e+02*S66+5.827265e+01*S67+0.000000e+00*S68+5.947132e+01*S69'
.param V57_part8='V57_part7+4.904784e+00*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.397725e+02)*S73+3.680340e+02*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V57='V57_part8+8.915121e+01*S80+0.000000e+00*S81+(-9.884750e+01)*S82+1.541935e+02*S83+0.000000e+00*S84+(-1.515918e+02)*S85+2.103978e+02*S86+1.000000e+04*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part1='(-2.125753e+00)*S0+(-5.471446e+01)*S1+(-2.519400e+01)*S2+(-4.039791e+00)*S3+(-9.279233e+01)*S4+(-7.441758e+01)*S5+1.084844e+00*S6+(-1.442568e+02)*S7+(-5.925283e+01)*S8+(-8.692628e+01)*S9'
.param V58_part2='V58_part1+(-8.107637e+01)*S10+(-5.823808e+01)*S11+(-8.610686e+01)*S12+(-7.679172e+01)*S13+(-3.630273e+01)*S14+0.000000e+00*S15+(-4.361564e+01)*S16+(-5.085075e+01)*S17+(-4.430619e+01)*S18+(-8.440973e+01)*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+(-1.923125e+01)*S21+(-1.340325e+01)*S22+(-4.051353e+00)*S23+(-1.876596e+01)*S24+(-2.037718e+01)*S25+(-9.350411e+00)*S26+(-1.270766e+01)*S27+(-1.021038e+01)*S28+(-8.463246e+00)*S29'
.param V58_part4='V58_part3+(-1.849236e+01)*S30+0.000000e+00*S31+(-2.582576e+01)*S32+(-2.153211e+01)*S33+(-1.989236e+01)*S34+(-2.821084e+01)*S35+(-5.857188e+01)*S36+(-2.705954e+01)*S37+(-2.882462e+01)*S38+0.000000e+00*S39'
.param V58_part5='V58_part4+0.000000e+00*S40+(-7.028455e+00)*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+(-1.785165e+01)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V58_part6='V58_part5+0.000000e+00*S50+0.000000e+00*S51+(-2.279140e+01)*S52+0.000000e+00*S53+0.000000e+00*S54+(-2.606485e+01)*S55+(-3.938977e+01)*S56+0.000000e+00*S57+(-3.321646e+01)*S58+0.000000e+00*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+(-1.773533e+01)*S61+1.000000e+04*S62+0.000000e+00*S63+(-3.917102e+01)*S64+(-1.400477e+02)*S65+(-2.125963e+01)*S66+(-3.869918e+01)*S67+0.000000e+00*S68+(-1.060399e+01)*S69'
.param V58_part8='V58_part7+(-4.550125e+01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-6.243463e+01)*S73+(-2.246747e+02)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V58='V58_part8+(-3.451766e+01)*S80+0.000000e+00*S81+(-3.081623e+01)*S82+(-4.270491e+01)*S83+0.000000e+00*S84+(-4.599027e+01)*S85+(-6.152320e+01)*S86+1.758307e+03*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part1='2.593296e+00*S0+(-1.309705e+01)*S1+4.650449e-01*S2+3.931569e+00*S3+(-7.991368e+00)*S4+(-5.340527e-01)*S5+(-1.004982e+01)*S6+(-8.924065e-01)*S7+5.634459e-01*S8+2.554561e-01*S9'
.param V59_part2='V59_part1+(-2.629460e-01)*S10+(-8.152208e-01)*S11+(-4.848909e-02)*S12+(-5.238703e-01)*S13+6.026097e-01*S14+0.000000e+00*S15+2.134805e+01*S16+3.917943e+00*S17+2.827845e+01*S18+(-5.585587e+00)*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+1.709030e+01*S21+1.958018e+01*S22+4.714021e+00*S23+1.869659e+01*S24+2.112812e+01*S25+1.435976e+01*S26+3.356442e+01*S27+1.855548e+01*S28+(-5.480703e+00)*S29'
.param V59_part4='V59_part3+1.714983e+01*S30+0.000000e+00*S31+4.055407e+00*S32+3.652827e+00*S33+6.328839e+00*S34+(-7.599586e-01)*S35+5.074344e+00*S36+3.023360e+00*S37+2.936824e+00*S38+0.000000e+00*S39'
.param V59_part5='V59_part4+0.000000e+00*S40+4.603456e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+1.135575e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V59_part6='V59_part5+0.000000e+00*S50+0.000000e+00*S51+1.536539e+01*S52+0.000000e+00*S53+0.000000e+00*S54+1.354986e+01*S55+5.540059e+00*S56+0.000000e+00*S57+1.522160e+01*S58+0.000000e+00*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+(-4.806475e-02)*S61+6.767979e+02*S62+0.000000e+00*S63+(-1.326985e+01)*S64+(-1.201908e+03)*S65+1.607084e+01*S66+9.583252e+00*S67+0.000000e+00*S68+(-3.084353e+00)*S69'
.param V59_part8='V59_part7+4.636115e+01*S70+0.000000e+00*S71+0.000000e+00*S72+5.416055e+01*S73+4.064661e+02*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V59='V59_part8+2.333596e+01*S80+0.000000e+00*S81+(-5.953447e+01)*S82+2.862337e+01*S83+0.000000e+00*S84+(-1.086374e+02)*S85+3.940589e+01*S86+1.000000e+04*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V60_part1='5.898919e+03*S0+(-5.198265e+02)*S1+(-3.894951e+01)*S2+8.480370e+03*S3+(-2.524310e+01)*S4+2.464552e+03*S5+3.985752e+00*S6+6.836727e+03*S7+1.156183e+01*S8+(-9.687285e+02)*S9'
.param V60_part2='V60_part1+3.822885e+01*S10+(-4.932944e+02)*S11+(-1.303832e+02)*S12+1.000000e+04*S13+1.000000e+04*S14+1.501815e+02*S15+9.706318e+00*S16+1.000000e+04*S17+1.158569e+01*S18+4.904695e+01*S19'
.param V60_part3='V60_part2+9.207728e+01*S20+5.667171e+00*S21+1.350819e+01*S22+1.149379e+02*S23+4.526202e+00*S24+6.424855e+00*S25+4.134011e+00*S26+3.124195e+00*S27+4.539976e+00*S28+6.257452e+00*S29'
.param V60_part4='V60_part3+(-4.788424e+03)*S30+(-2.146717e+01)*S31+(-4.608645e+03)*S32+5.390670e+01*S33+(-4.929853e+03)*S34+(-4.922477e+03)*S35+(-4.967369e+03)*S36+(-7.468999e+00)*S37+(-6.899860e+02)*S38+(-1.963442e+03)*S39'
.param V60_part5='V60_part4+1.696382e+00*S40+1.344454e+00*S41+(-6.137218e+01)*S42+(-6.679212e-01)*S43+(-1.154765e+02)*S44+(-4.957940e+03)*S45+(-1.551785e+03)*S46+5.016135e+01*S47+(-4.997019e+03)*S48+(-4.991938e+03)*S49'
.param V60_part6='V60_part5+(-4.999008e+03)*S50+(-2.749987e+00)*S51+(-1.220210e+02)*S52+1.225455e+00*S53+(-4.424201e-01)*S54+(-4.998402e+03)*S55+(-5.520413e+02)*S56+2.182006e-01*S57+(-5.000874e+03)*S58+(-4.997714e+03)*S59'
.param V60_part7='V60_part6+(-1.472785e+01)*S60+1.662588e+00*S61+1.077133e-01*S62+(-2.192393e-02)*S63+3.012024e+00*S64+(-2.704561e-01)*S65+9.671131e+00*S66+9.753991e+00*S67+1.594038e-01*S68+5.480812e+00*S69'
.param V60_part8='V60_part7+2.639183e+01*S70+8.580358e+00*S71+0.000000e+00*S72+2.791489e+01*S73+3.497103e+02*S74+(-2.520808e+01)*S75+(-4.999179e+03)*S76+(-4.975108e-01)*S77+(-1.289742e+01)*S78+(-4.883399e+03)*S79'
.param V60='V60_part8+(-1.510957e+00)*S80+(-4.999318e+03)*S81+(-1.843194e+00)*S82+(-3.225948e+00)*S83+(-4.999441e+03)*S84+(-1.894005e+00)*S85+(-5.427819e+00)*S86+0.000000e+00*S87+0.000000e+00*S88+(-2.782887e+00)*S89'
.param V61_part1='1.000000e+04*S0+2.088512e+03*S1+1.464837e+02*S2+3.806704e+03*S3+2.091111e+02*S4+(-1.284952e+02)*S5+3.313041e+01*S6+1.414297e+03*S7+1.273907e+03*S8+1.459478e+03*S9'
.param V61_part2='V61_part1+1.555754e+00*S10+6.992410e+02*S11+(-4.859951e+00)*S12+1.000000e+04*S13+1.000000e+04*S14+(-8.925272e+01)*S15+1.855361e+00*S16+(-2.563715e+01)*S17+(-6.088653e+00)*S18+(-2.045998e+01)*S19'
.param V61_part3='V61_part2+3.880344e-01*S20+(-1.317391e+00)*S21+(-5.403109e+00)*S22+1.041770e+02*S23+(-1.391186e+00)*S24+(-9.349534e-01)*S25+(-1.879467e-01)*S26+(-5.989845e-01)*S27+(-8.683575e-01)*S28+(-1.030796e+00)*S29'
.param V61_part4='V61_part3+(-4.676744e+02)*S30+(-3.886035e+02)*S31+(-9.753061e+01)*S32+1.316528e+01*S33+(-8.980817e+01)*S34+(-3.955620e+01)*S35+(-4.400597e+01)*S36+(-2.219031e+01)*S37+(-1.679696e+01)*S38+(-1.091551e+01)*S39'
.param V61_part5='V61_part4+(-2.926744e-01)*S40+(-6.226354e-01)*S41+(-6.346573e+00)*S42+(-1.884441e-01)*S43+(-8.807497e+00)*S44+(-1.226013e+02)*S45+(-3.646503e+01)*S46+4.409058e-01*S47+(-7.060674e+00)*S48+(-2.501167e+00)*S49'
.param V61_part6='V61_part5+(-1.536090e+01)*S50+(-1.780635e+00)*S51+(-1.016542e+01)*S52+3.184450e-04*S53+1.023027e-01*S54+(-5.167559e+00)*S55+(-3.824522e+00)*S56+1.548126e+00*S57+(-2.186090e+00)*S58+(-1.131555e+01)*S59'
.param V61_part7='V61_part6+(-2.000922e+01)*S60+3.821179e+00*S61+(-4.589171e-01)*S62+4.023237e+00*S63+2.138631e+00*S64+(-2.606885e-01)*S65+3.103469e+00*S66+7.170486e-01*S67+(-3.195539e-01)*S68+1.702402e+00*S69'
.param V61_part8='V61_part7+1.526577e-01*S70+1.084593e+01*S71+0.000000e+00*S72+3.646838e+01*S73+4.808059e+01*S74+(-1.167059e+00)*S75+(-9.094301e-01)*S76+3.171145e-02*S77+(-1.546704e-01)*S78+(-4.701032e-01)*S79'
.param V61='V61_part8+8.112604e-02*S80+(-1.465812e-01)*S81+9.598448e-02*S82+(-5.411984e-03)*S83+2.081262e-01*S84+2.395876e-01*S85+(-1.230631e-02)*S86+0.000000e+00*S87+0.000000e+00*S88+3.103326e-02*S89'
.param V62_part1='(-8.427991e+03)*S0+4.512999e+02*S1+7.159580e+01*S2+(-3.408323e+03)*S3+1.197664e+02*S4+2.474833e+02*S5+1.322374e+01*S6+1.838356e+02*S7+1.000000e+04*S8+4.278687e+02*S9'
.param V62_part2='V62_part1+2.822516e+01*S10+1.765809e+02*S11+7.535696e+02*S12+1.000000e+04*S13+1.000000e+04*S14+(-2.046496e+02)*S15+(-5.280017e+00)*S16+(-1.059485e+01)*S17+(-1.181882e+01)*S18+(-4.838690e+01)*S19'
.param V62_part3='V62_part2+(-1.280666e+02)*S20+(-5.449293e+00)*S21+(-6.718977e+00)*S22+2.037703e+01*S23+(-3.672805e+00)*S24+(-2.711899e+00)*S25+(-1.115136e+00)*S26+(-3.179503e+00)*S27+(-2.274873e+00)*S28+(-3.398854e+00)*S29'
.param V62_part4='V62_part3+(-6.794209e+01)*S30+(-3.118061e+02)*S31+(-2.776779e+02)*S32+(-2.249015e+01)*S33+(-2.016530e+01)*S34+(-4.913687e+01)*S35+(-3.659602e+00)*S36+(-1.241671e+01)*S37+(-2.801388e+01)*S38+8.806016e+00*S39'
.param V62_part5='V62_part4+(-8.769437e-01)*S40+(-5.941437e-01)*S41+9.333934e+00*S42+7.200385e-01*S43+(-4.409358e+00)*S44+1.227756e+00*S45+(-1.766979e+01)*S46+1.267911e+00*S47+4.669590e+00*S48+(-1.016268e+00)*S49'
.param V62_part6='V62_part5+1.342690e+01*S50+1.434925e+00*S51+8.553546e+00*S52+(-7.548437e-01)*S53+1.228237e-01*S54+1.034199e+01*S55+1.395650e+00*S56+1.445153e+00*S57+1.099434e+01*S58+1.758534e+01*S59'
.param V62_part7='V62_part6+(-6.439483e-01)*S60+5.221587e+00*S61+5.912389e-02*S62+1.254079e+00*S63+3.684869e+00*S64+1.941893e-01*S65+(-1.657265e+01)*S66+(-1.204316e+01)*S67+2.957604e-01*S68+(-1.012688e+01)*S69'
.param V62_part8='V62_part7+(-2.611064e+01)*S70+(-1.264241e+01)*S71+0.000000e+00*S72+(-8.261287e+01)*S73+(-3.611001e+02)*S74+6.982113e-01*S75+(-9.045534e-03)*S76+(-5.577522e-01)*S77+(-3.229636e-01)*S78+(-1.433398e-01)*S79'
.param V62='V62_part8+(-6.521462e-01)*S80+(-8.562417e-01)*S81+3.360449e-01*S82+(-5.931657e-01)*S83+(-9.479830e-01)*S84+3.711317e-01*S85+(-4.756431e-01)*S86+0.000000e+00*S87+0.000000e+00*S88+(-1.950379e-02)*S89'
.param V63_part1='(-5.562457e+03)*S0+1.787916e+01*S1+1.046506e+02*S2+(-9.999813e+03)*S3+2.028226e+02*S4+9.999494e+03*S5+3.306001e+01*S6+(-1.000000e+04)*S7+3.952941e+00*S8+7.763001e+01*S9'
.param V63_part2='V63_part1+(-1.298460e+01)*S10+1.424206e+02*S11+2.510338e+01*S12+1.000000e+04*S13+1.000000e+04*S14+2.497483e+01*S15+2.124468e-01*S16+(-2.105967e+02)*S17+(-4.793539e-01)*S18+1.580069e+00*S19'
.param V63_part3='V63_part2+(-1.421001e+00)*S20+(-4.070059e-01)*S21+(-3.648585e-01)*S22+9.042069e+00*S23+(-2.842422e-01)*S24+(-3.136592e-01)*S25+(-4.097317e-01)*S26+(-1.296028e-01)*S27+(-2.544801e-01)*S28+(-1.405485e-03)*S29'
.param V63_part4='V63_part3+5.395196e+00*S30+(-2.100577e+00)*S31+(-4.797618e+00)*S32+(-6.207637e-01)*S33+(-1.807147e+00)*S34+(-9.449851e-02)*S35+3.472937e-01*S36+(-1.699626e-01)*S37+3.509302e-01*S38+5.271898e-01*S39'
.param V63_part5='V63_part4+2.301855e-02*S40+3.679931e-02*S41+8.067736e-02*S42+8.929292e-02*S43+5.846879e-01*S44+5.168154e-01*S45+2.342426e-01*S46+(-7.193228e-02)*S47+2.213091e-01*S48+2.211460e-01*S49'
.param V63_part6='V63_part5+7.550881e-02*S50+4.297676e-02*S51+1.265874e-01*S52+3.569407e-02*S53+5.635506e-02*S54+2.364247e-01*S55+2.697957e-01*S56+2.765721e-02*S57+3.053100e-01*S58+1.061937e-01*S59'
.param V63_part7='V63_part6+1.864928e-01*S60+7.697060e-02*S61+6.714751e-02*S62+(-1.488037e-01)*S63+7.209426e-02*S64+5.110996e-02*S65+(-4.031200e-01)*S66+(-1.811010e+00)*S67+2.187588e-02*S68+(-2.594163e-01)*S69'
.param V63_part8='V63_part7+(-3.875909e+00)*S70+3.042474e+00*S71+0.000000e+00*S72+(-5.145265e+00)*S73+(-1.874565e+01)*S74+9.700509e-02*S75+1.109495e-01*S76+6.169167e-02*S77+5.761051e-02*S78+7.185720e-02*S79'
.param V63='V63_part8+6.989284e-02*S80+7.341824e-02*S81+2.618156e-02*S82+4.953058e-02*S83+7.300442e-02*S84+1.863838e-02*S85+5.226157e-02*S86+0.000000e+00*S87+0.000000e+00*S88+2.271657e-02*S89'
.param V64_part1='2.476082e+01*S0+4.998414e+00*S1+(-3.970342e+00)*S2+(-2.095798e+02)*S3+(-6.691230e+00)*S4+(-3.846931e+00)*S5+(-4.784657e-01)*S6+4.650254e+01*S7+2.465127e+03*S8+(-3.052861e+00)*S9'
.param V64_part2='V64_part1+5.730442e+00*S10+1.449040e+00*S11+2.698874e+00*S12+1.000000e+04*S13+1.000000e+04*S14+9.050441e-01*S15+6.832136e+00*S16+6.196635e+02*S17+6.029667e-01*S18+1.177786e+02*S19'
.param V64_part3='V64_part2+2.391665e+02*S20+1.606063e+00*S21+5.401177e+00*S22+(-8.755809e+01)*S23+1.442724e+00*S24+2.685388e+00*S25+2.055391e+00*S26+1.015837e+00*S27+1.620094e+00*S28+8.805058e-01*S29'
.param V64_part4='V64_part3+1.000000e+04*S30+7.161902e+02*S31+1.000000e+04*S32+(-2.814098e+01)*S33+1.000000e+04*S34+1.000000e+04*S35+1.000000e+04*S36+6.337866e+01*S37+1.467214e+03*S38+3.943360e+03*S39'
.param V64_part5='V64_part4+(-9.736266e-02)*S40+7.719804e-01*S41+1.331214e+02*S42+2.056435e+00*S43+2.627883e+02*S44+1.000000e+04*S45+3.149891e+03*S46+(-3.174576e+01)*S47+1.000000e+04*S48+9.989060e+03*S49'
.param V64_part6='V64_part5+9.999994e+03*S50+8.537683e+00*S51+2.540720e+02*S52+7.324137e-02*S53+1.008918e+00*S54+1.000000e+04*S55+1.110484e+03*S56+(-8.772157e-01)*S57+1.000000e+04*S58+1.000000e+04*S59'
.param V64_part7='V64_part6+4.495315e+01*S60+(-2.530957e+00)*S61+7.315162e-01*S62+(-5.970467e-01)*S63+(-3.105391e+00)*S64+1.092478e+00*S65+(-2.041159e+00)*S66+1.925623e+00*S67+2.020641e-01*S68+(-8.654560e-01)*S69'
.param V64_part8='V64_part7+(-9.835620e-01)*S70+(-4.668280e-01)*S71+0.000000e+00*S72+1.839908e+01*S73+(-2.004042e+00)*S74+5.153158e+01*S75+1.000000e+04*S76+3.341863e+00*S77+2.690767e+01*S78+9.768140e+03*S79'
.param V64='V64_part8+5.340078e+00*S80+1.000000e+04*S81+3.554379e+00*S82+8.567433e+00*S83+9.999757e+03*S84+3.370279e+00*S85+1.257084e+01*S86+0.000000e+00*S87+0.000000e+00*S88+5.926353e+00*S89'
.param V65_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.213209e-01)*S5+(-1.405340e-02)*S6+(-9.427850e-02)*S7+(-1.295035e-01)*S8+(-1.359702e-02)*S9'
.param V65_part2='V65_part1+(-2.151386e-02)*S10+(-5.684655e-02)*S11+(-1.756878e-02)*S12+(-4.284094e-02)*S13+0.000000e+00*S14+0.000000e+00*S15+(-6.112471e-03)*S16+(-1.365337e-01)*S17+(-2.803813e-02)*S18+(-7.171802e-02)*S19'
.param V65_part3='V65_part2+(-2.208128e-01)*S20+2.429547e-01*S21+8.253029e-02*S22+(-2.557454e-01)*S23+2.931925e-01*S24+1.841370e-01*S25+2.999571e-02*S26+4.641900e-01*S27+2.576970e-01*S28+1.575187e-01*S29'
.param V65_part4='V65_part3+(-2.619435e-02)*S30+(-1.299360e-01)*S31+0.000000e+00*S32+0.000000e+00*S33+2.193542e-02*S34+(-2.499597e-01)*S35+(-1.732246e-02)*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V65_part5='V65_part4+0.000000e+00*S40+1.025741e+00*S41+0.000000e+00*S42+2.291305e+00*S43+0.000000e+00*S44+1.219976e-01*S45+0.000000e+00*S46+(-9.450744e-01)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V65_part6='V65_part5+0.000000e+00*S50+2.399200e+00*S51+2.507297e+00*S52+0.000000e+00*S53+3.971139e+00*S54+2.002457e+00*S55+2.594965e+00*S56+0.000000e+00*S57+2.574166e+00*S58+0.000000e+00*S59'
.param V65_part7='V65_part6+3.032834e-01*S60+0.000000e+00*S61+4.050680e-01*S62+0.000000e+00*S63+3.559387e+00*S64+2.073796e-01*S65+(-8.968411e-01)*S66+2.286323e+00*S67+0.000000e+00*S68+(-2.618518e+00)*S69'
.param V65_part8='V65_part7+2.892004e+00*S70+0.000000e+00*S71+0.000000e+00*S72+3.495518e+00*S73+(-1.104176e+00)*S74+0.000000e+00*S75+(-1.076196e+00)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V65='V65_part8+0.000000e+00*S80+2.885293e-01*S81+0.000000e+00*S82+(-9.030269e-01)*S83+5.316994e-01*S84+0.000000e+00*S85+(-2.467423e+00)*S86+0.000000e+00*S87+0.000000e+00*S88+(-1.969150e+00)*S89'
.param V66_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+1.596697e-01*S5+5.575473e-02*S6+1.307784e-01*S7+1.212360e-01*S8+(-1.146394e-02)*S9'
.param V66_part2='V66_part1+7.419461e-02*S10+7.086855e-02*S11+6.678080e-02*S12+6.465020e-02*S13+0.000000e+00*S14+0.000000e+00*S15+6.723669e-01*S16+4.331218e-01*S17+8.974934e-01*S18+3.343621e-01*S19'
.param V66_part3='V66_part2+4.823002e-01*S20+6.626290e-01*S21+5.483816e-01*S22+4.694609e-01*S23+7.262800e-01*S24+5.662200e-01*S25+7.261124e-01*S26+7.714492e-01*S27+6.873092e-01*S28+6.948754e-01*S29'
.param V66_part4='V66_part3+1.889783e-01*S30+6.893067e-01*S31+0.000000e+00*S32+0.000000e+00*S33+2.536745e-01*S34+5.715845e-01*S35+3.857496e-01*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V66_part5='V66_part4+0.000000e+00*S40+2.282862e+00*S41+0.000000e+00*S42+2.174760e+00*S43+0.000000e+00*S44+(-9.273747e-01)*S45+0.000000e+00*S46+2.482641e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V66_part6='V66_part5+0.000000e+00*S50+1.540079e+00*S51+2.650574e-01*S52+0.000000e+00*S53+4.709812e+00*S54+1.697788e+00*S55+6.674362e+00*S56+0.000000e+00*S57+1.871551e+00*S58+0.000000e+00*S59'
.param V66_part7='V66_part6+1.661672e+00*S60+0.000000e+00*S61+9.830311e+00*S62+0.000000e+00*S63+1.818253e+00*S64+1.016064e+01*S65+5.657467e+00*S66+6.800229e+00*S67+0.000000e+00*S68+5.553969e+00*S69'
.param V66_part8='V66_part7+6.133265e+00*S70+0.000000e+00*S71+0.000000e+00*S72+6.062676e+00*S73+6.689850e+00*S74+0.000000e+00*S75+5.470663e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V66='V66_part8+0.000000e+00*S80+1.058704e-01*S81+0.000000e+00*S82+4.131539e+00*S83+(-2.168499e-01)*S84+0.000000e+00*S85+3.222890e+00*S86+0.000000e+00*S87+0.000000e+00*S88+1.254828e+01*S89'
.param V67_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+9.349991e-02*S5+1.044271e-01*S6+5.853372e-02*S7+1.150935e-01*S8+9.266682e-02*S9'
.param V67_part2='V67_part1+4.686168e-02*S10+8.532873e-02*S11+3.927160e-03*S12+5.206234e-02*S13+0.000000e+00*S14+0.000000e+00*S15+2.317288e-01*S16+1.420388e-01*S17+5.316423e-01*S18+1.655852e-01*S19'
.param V67_part3='V67_part2+3.069910e-01*S20+4.492578e-01*S21+3.119775e-01*S22+3.512265e-01*S23+4.925989e-01*S24+3.701093e-01*S25+6.049250e-01*S26+4.735333e-01*S27+4.521275e-01*S28+6.728431e-01*S29'
.param V67_part4='V67_part3+1.313943e+00*S30+3.544932e-01*S31+0.000000e+00*S32+0.000000e+00*S33+1.105293e+00*S34+1.443318e+00*S35+2.536744e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V67_part5='V67_part4+0.000000e+00*S40+1.708245e+00*S41+0.000000e+00*S42+3.658295e-01*S43+0.000000e+00*S44+1.611289e+00*S45+0.000000e+00*S46+3.118682e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V67_part6='V67_part5+0.000000e+00*S50+(-3.747611e+00)*S51+(-2.781436e+00)*S52+0.000000e+00*S53+(-1.500673e+00)*S54+(-3.319073e+00)*S55+1.505864e+00*S56+0.000000e+00*S57+(-4.145739e+00)*S58+0.000000e+00*S59'
.param V67_part7='V67_part6+2.077018e+00*S60+0.000000e+00*S61+4.770388e+00*S62+0.000000e+00*S63+(-4.836799e+00)*S64+5.632932e+00*S65+7.809633e+00*S66+5.520110e+00*S67+0.000000e+00*S68+1.008581e+01*S69'
.param V67_part8='V67_part7+5.940207e+00*S70+0.000000e+00*S71+0.000000e+00*S72+5.694270e+00*S73+8.138619e+00*S74+0.000000e+00*S75+7.602923e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V67='V67_part8+0.000000e+00*S80+7.846243e+00*S81+0.000000e+00*S82+4.614629e+00*S83+1.050561e+01*S84+0.000000e+00*S85+1.145906e+01*S86+0.000000e+00*S87+0.000000e+00*S88+1.187720e+01*S89'
.param V68_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+3.357951e-02*S5+2.427108e-03*S6+3.298337e-02*S7+4.671309e-02*S8+1.523589e-02*S9'
.param V68_part2='V68_part1+4.138638e-02*S10+3.046430e-02*S11+4.945879e-03*S12+7.212053e-03*S13+0.000000e+00*S14+0.000000e+00*S15+2.007360e-02*S16+(-1.235728e-02)*S17+1.663517e-03*S18+9.890965e-03*S19'
.param V68_part3='V68_part2+8.508379e-03*S20+(-2.670284e-03)*S21+(-8.899632e-03)*S22+(-1.009158e-03)*S23+2.109585e-03*S24+(-1.420097e-02)*S25+(-8.340333e-03)*S26+(-1.389875e-02)*S27+(-2.256549e-03)*S28+2.175683e-02*S29'
.param V68_part4='V68_part3+(-3.040961e-02)*S30+2.930793e-02*S31+0.000000e+00*S32+0.000000e+00*S33+(-8.269378e-02)*S34+(-1.045541e-02)*S35+(-1.243160e-02)*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V68_part5='V68_part4+0.000000e+00*S40+(-3.102691e-01)*S41+0.000000e+00*S42+(-2.590411e-01)*S43+0.000000e+00*S44+(-1.662601e-01)*S45+0.000000e+00*S46+(-2.259969e-01)*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V68_part6='V68_part5+0.000000e+00*S50+(-5.095585e-02)*S51+(-1.887189e-01)*S52+0.000000e+00*S53+(-1.534357e-01)*S54+(-2.660842e-01)*S55+(-7.470423e-01)*S56+0.000000e+00*S57+(-4.000833e-01)*S58+0.000000e+00*S59'
.param V68_part7='V68_part6+1.317305e-01*S60+0.000000e+00*S61+(-5.026049e-01)*S62+0.000000e+00*S63+(-3.132614e-01)*S64+(-5.467374e-01)*S65+(-2.734508e-01)*S66+(-2.981054e-01)*S67+0.000000e+00*S68+(-3.881672e-01)*S69'
.param V68_part8='V68_part7+(-3.411394e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-3.784774e-01)*S73+(-5.026219e-01)*S74+0.000000e+00*S75+(-6.468705e-02)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V68='V68_part8+0.000000e+00*S80+(-4.943954e-02)*S81+0.000000e+00*S82+2.488885e-01*S83+2.390928e-02*S84+0.000000e+00*S85+3.134283e-01*S86+0.000000e+00*S87+0.000000e+00*S88+(-7.305121e-01)*S89'
.param V69_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+2.586709e-03*S5+4.231619e-03*S6+8.621592e-04*S7+2.214670e-03*S8+5.181270e-04*S9'
.param V69_part2='V69_part1+(-2.838610e-03)*S10+(-3.467332e-04)*S11+(-2.021931e-03)*S12+(-1.031796e-03)*S13+0.000000e+00*S14+0.000000e+00*S15+(-5.771608e-02)*S16+6.509279e-03*S17+(-1.172077e-01)*S18+(-6.537171e-03)*S19'
.param V69_part3='V69_part2+(-1.139165e-03)*S20+(-2.237999e-01)*S21+(-1.304456e-01)*S22+2.867429e-02*S23+(-2.910586e-01)*S24+(-1.956804e-01)*S25+(-2.516038e-01)*S26+(-4.019799e-01)*S27+(-2.960952e-01)*S28+(-3.708479e-01)*S29'
.param V69_part4='V69_part3+(-2.578566e-02)*S30+8.663226e-04*S31+0.000000e+00*S32+0.000000e+00*S33+(-2.286044e-02)*S34+(-3.138707e-02)*S35+(-8.774375e-02)*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V69_part5='V69_part4+0.000000e+00*S40+(-1.162210e+00)*S41+0.000000e+00*S42+(-1.555178e+00)*S43+0.000000e+00*S44+4.570808e-02*S45+0.000000e+00*S46+1.032013e-01*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V69_part6='V69_part5+0.000000e+00*S50+(-8.326510e-02)*S51+7.273106e-02*S52+0.000000e+00*S53+(-3.433259e+00)*S54+7.218861e-02*S55+(-2.659680e+00)*S56+0.000000e+00*S57+1.785889e-02*S58+0.000000e+00*S59'
.param V69_part7='V69_part6+(-2.214208e-01)*S60+0.000000e+00*S61+(-1.655240e+00)*S62+0.000000e+00*S63+4.838540e-01*S64+(-2.402458e+00)*S65+(-1.520060e+00)*S66+(-2.897736e+00)*S67+0.000000e+00*S68+(-1.055599e+00)*S69'
.param V69_part8='V69_part7+(-3.421557e+00)*S70+0.000000e+00*S71+0.000000e+00*S72+(-3.999620e+00)*S73+(-2.878830e+00)*S74+0.000000e+00*S75+(-6.102696e-01)*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V69='V69_part8+0.000000e+00*S80+2.051909e-01*S81+0.000000e+00*S82+6.768698e-01*S83+3.805332e-01*S84+0.000000e+00*S85+5.629726e-01*S86+0.000000e+00*S87+0.000000e+00*S88+(-4.934073e+00)*S89'
.param V70_part1='(-1.380102e+01)*S0+8.245952e+00*S1+6.701417e+00*S2+(-2.509239e+01)*S3+3.730496e+01*S4+1.612671e+01*S5+4.546779e+01*S6+3.035825e+01*S7+1.349524e+01*S8+2.541131e+01*S9'
.param V70_part2='V70_part1+1.747988e+01*S10+1.291418e+01*S11+2.112302e+01*S12+1.287716e+01*S13+8.488713e+00*S14+(-1.462705e+02)*S15+1.371225e+01*S16+1.206246e+01*S17+1.681616e+02*S18+1.579402e+01*S19'
.param V70_part3='V70_part2+7.683326e+00*S20+2.219613e+01*S21+9.212656e+00*S22+5.564774e+00*S23+1.761894e+01*S24+1.267394e+01*S25+5.005709e+00*S26+2.998280e+00*S27+5.083704e+00*S28+(-1.597044e+00)*S29'
.param V70_part4='V70_part3+5.587639e+00*S30+7.392424e+00*S31+9.970229e+01*S32+5.694138e+00*S33+3.313768e+00*S34+2.662685e+00*S35+2.730799e+00*S36+1.518156e+00*S37+2.423706e+00*S38+5.038087e-02*S39'
.param V70_part5='V70_part4+(-5.080431e-01)*S40+5.313320e+00*S41+1.418752e-01*S42+2.180285e-01*S43+1.434750e+00*S44+3.391710e+00*S45+1.322107e+00*S46+1.735491e+00*S47+(-1.545804e-01)*S48+8.244964e-01*S49'
.param V70_part6='V70_part5+(-6.076111e-01)*S50+6.091025e-02*S51+8.727867e-02*S52+(-2.347964e+00)*S53+1.653752e+03*S54+(-2.909063e-01)*S55+4.512206e-01*S56+(-4.151439e+00)*S57+(-2.440038e-01)*S58+(-2.966173e-01)*S59'
.param V70_part7='V70_part6+2.072333e+00*S60+2.004224e-01*S61+2.080451e+02*S62+(-1.883606e+02)*S63+6.547775e-01*S64+9.797345e+00*S65+(-1.091169e+00)*S66+(-6.915836e-01)*S67+3.631985e-01*S68+(-5.629904e+00)*S69'
.param V70_part8='V70_part7+(-7.253238e-01)*S70+9.299566e-02*S71+0.000000e+00*S72+(-7.440688e-01)*S73+3.809580e-01*S74+3.610638e+00*S75+7.519577e-01*S76+8.261035e-01*S77+3.864704e+00*S78+7.316285e-01*S79'
.param V70='V70_part8+8.186882e-01*S80+1.536989e+00*S81+4.822889e+00*S82+7.590271e-01*S83+1.589555e+00*S84+(-2.431149e+00)*S85+6.630571e-01*S86+7.253894e+03*S87+0.000000e+00*S88+6.609582e+00*S89'
.param V71_part1='5.065892e+01*S0+(-2.750304e+00)*S1+(-5.327281e+00)*S2+4.781622e+01*S3+(-3.347505e+01)*S4+(-7.382899e+00)*S5+(-1.860053e+01)*S6+(-5.070417e+00)*S7+(-6.396466e+00)*S8+(-8.366973e+00)*S9'
.param V71_part2='V71_part1+(-7.509551e+00)*S10+(-4.762346e+00)*S11+(-7.129587e+00)*S12+(-2.585299e+00)*S13+(-1.520025e+00)*S14+9.134474e+02*S15+(-1.357080e+01)*S16+(-6.679155e+00)*S17+1.368387e+02*S18+(-1.097010e+01)*S19'
.param V71_part3='V71_part2+(-2.477829e+00)*S20+(-8.791944e+00)*S21+(-2.635669e+00)*S22+(-1.412562e+00)*S23+(-6.377161e+00)*S24+(-6.219430e+00)*S25+(-1.097068e+00)*S26+(-5.277025e-01)*S27+(-1.217761e+00)*S28+1.453750e-01*S29'
.param V71_part4='V71_part3+2.399948e+00*S30+(-1.383251e+00)*S31+(-1.750247e+01)*S32+(-1.848193e+00)*S33+8.023422e-02*S34+(-4.475798e-01)*S35+(-3.733932e-01)*S36+5.220029e-01*S37+(-2.519883e-01)*S38+9.001976e-01*S39'
.param V71_part5='V71_part4+(-3.125060e+00)*S40+4.882905e-01*S41+6.166041e-01*S42+8.587024e-01*S43+1.777939e-01*S44+1.507041e-01*S45+1.101322e+00*S46+(-5.391622e-01)*S47+1.497825e+00*S48+7.926356e-01*S49'
.param V71_part6='V71_part5+6.611423e-01*S50+2.038863e+00*S51+1.010356e+00*S52+(-7.436659e-01)*S53+2.520773e+00*S54+1.283143e+00*S55+(-3.170418e-02)*S56+(-3.875700e-02)*S57+9.907876e-01*S58+3.219820e-01*S59'
.param V71_part7='V71_part6+5.563354e-01*S60+(-2.838968e+00)*S61+(-1.202240e+01)*S62+(-4.812321e-01)*S63+(-2.092186e+00)*S64+(-1.901694e+00)*S65+6.061808e-02*S66+1.804480e-02*S67+3.134543e-02*S68+9.737128e-02*S69'
.param V71_part8='V71_part7+6.321060e-02*S70+(-7.281351e-02)*S71+0.000000e+00*S72+2.646211e-02*S73+3.725916e-01*S74+2.425751e+00*S75+1.422342e+00*S76+4.615648e-01*S77+5.408467e+00*S78+1.049622e+00*S79'
.param V71='V71_part8+2.783154e-01*S80+1.979841e+00*S81+6.286740e+00*S82+6.347850e-01*S83+1.645108e+00*S84+1.100779e+01*S85+5.384608e-01*S86+4.717611e+03*S87+0.000000e+00*S88+(-7.010475e-01)*S89'
.param V72_part1='2.402105e+01*S0+(-1.196489e+00)*S1+5.252370e+00*S2+4.860738e+01*S3+4.289029e+00*S4+(-5.236532e+00)*S5+(-4.667742e+01)*S6+(-3.493517e+00)*S7+(-2.958654e+00)*S8+(-2.039295e+01)*S9'
.param V72_part2='V72_part1+(-6.319811e+00)*S10+(-3.305430e+00)*S11+(-8.139082e+00)*S12+(-6.764254e-01)*S13+8.943508e-01*S14+2.947584e+01*S15+(-7.431406e+00)*S16+(-4.158838e+00)*S17+(-5.964433e+00)*S18+(-6.879092e+00)*S19'
.param V72_part3='V72_part2+(-2.934760e+00)*S20+(-2.159365e+01)*S21+(-1.630305e+00)*S22+(-1.844554e+00)*S23+(-1.824046e+01)*S24+(-3.732028e+00)*S25+(-1.627513e+00)*S26+7.328562e+00*S27+(-3.681401e-01)*S28+5.236606e+00*S29'
.param V72_part4='V72_part3+(-1.053910e+01)*S30+(-5.100970e+00)*S31+(-3.106065e+01)*S32+(-8.979340e+00)*S33+(-2.718151e+00)*S34+(-1.410301e+00)*S35+(-3.668033e+00)*S36+(-1.316410e+00)*S37+(-1.317427e+00)*S38+1.058749e+00*S39'
.param V72_part5='V72_part4+(-1.538372e+00)*S40+(-2.643837e+00)*S41+1.375849e+00*S42+(-1.421889e-02)*S43+(-1.132749e+00)*S44+(-6.751566e+00)*S45+(-1.393094e+00)*S46+(-1.261845e+00)*S47+1.472231e+00*S48+(-9.569284e-01)*S49'
.param V72_part6='V72_part5+1.989264e+00*S50+1.165406e+00*S51+2.716201e+00*S52+2.876989e-02*S53+6.001715e-01*S54+2.587783e+00*S55+(-2.449457e-01)*S56+8.099695e-01*S57+2.232859e+00*S58+1.288583e+00*S59'
.param V72_part7='V72_part6+(-3.995790e+00)*S60+2.116098e-01*S61+(-3.946138e+01)*S62+8.542365e-01*S63+3.053852e-01*S64+(-4.388678e+00)*S65+(-1.706723e-01)*S66+1.984403e-01*S67+(-1.751641e-01)*S68+(-2.860188e-01)*S69'
.param V72_part8='V72_part7+1.341998e-01*S70+3.287791e-02*S71+0.000000e+00*S72+7.810097e-02*S73+(-3.355471e-01)*S74+(-8.804928e+00)*S75+(-1.103481e+00)*S76+(-5.357246e-01)*S77+(-1.045510e+01)*S78+(-9.955137e-01)*S79'
.param V72='V72_part8+(-6.231311e-01)*S80+(-3.857560e+00)*S81+(-9.255884e+00)*S82+(-7.823687e-01)*S83+(-4.083253e+00)*S84+(-5.918748e+00)*S85+(-7.460826e-01)*S86+7.260504e+03*S87+0.000000e+00*S88+(-3.160256e+00)*S89'
.param V73_part1='1.935463e+00*S0+7.579603e+00*S1+3.434736e-01*S2+4.392125e+00*S3+2.120795e+01*S4+7.156990e-01*S5+5.696418e+00*S6+3.273062e+01*S7+1.148459e+00*S8+3.155821e+00*S9'
.param V73_part2='V73_part1+2.007717e+00*S10+1.043025e+00*S11+6.863747e+00*S12+5.728224e+00*S13+6.034791e+00*S14+7.967399e+00*S15+(-5.794315e-02)*S16+9.187031e-01*S17+7.047295e+02*S18+1.772416e-01*S19'
.param V73_part3='V73_part2+2.013130e-01*S20+2.080599e+00*S21+1.864316e+00*S22+2.364926e-01*S23+3.859734e-01*S24+1.520792e+00*S25+3.241858e-01*S26+1.832945e+00*S27+5.434865e-01*S28+(-6.307610e-01)*S29'
.param V73_part4='V73_part3+(-1.826352e-01)*S30+(-6.991827e-01)*S31+(-2.583719e+01)*S32+2.145885e-03*S33+(-2.321950e-01)*S34+(-1.301381e-01)*S35+(-1.654030e-01)*S36+(-9.915847e-02)*S37+(-8.794843e-02)*S38+(-6.194694e-03)*S39'
.param V73_part5='V73_part4+(-1.385104e-01)*S40+(-1.908015e-01)*S41+(-2.635640e-02)*S42+1.532956e-02*S43+6.884257e-02*S44+(-2.601379e-02)*S45+3.951872e-03*S46+2.309546e-02*S47+(-9.381056e-03)*S48+1.248167e-02*S49'
.param V73_part6='V73_part5+(-5.332561e-02)*S50+(-4.503739e-02)*S51+(-1.368889e-02)*S52+8.691539e-02*S53+1.060015e-01*S54+(-3.903857e-02)*S55+1.638076e-02*S56+8.859543e-02*S57+9.332833e-03*S58+(-4.532670e-02)*S59'
.param V73_part7='V73_part6+(-6.831894e-02)*S60+5.659522e-02*S61+(-1.779821e+02)*S62+7.638915e-02*S63+2.519289e-02*S64+(-9.788957e-01)*S65+3.543986e-02*S66+2.616687e-02*S67+6.461486e-02*S68+4.156394e-02*S69'
.param V73_part8='V73_part7+1.891319e-02*S70+1.031485e-02*S71+0.000000e+00*S72+1.352728e-02*S73+1.637961e-02*S74+(-6.542963e-02)*S75+(-1.938961e-02)*S76+1.263502e-02*S77+(-2.774117e-01)*S78+(-2.105332e-02)*S79'
.param V73='V73_part8+2.228163e-04*S80+(-1.382733e-02)*S81+9.727424e-02*S82+5.866790e-05*S83+(-1.446261e-02)*S84+(-5.227909e-01)*S85+(-5.719027e-05)*S86+5.081003e+03*S87+0.000000e+00*S88+(-5.076885e-01)*S89'
.param V74_part1='(-1.647819e-01)*S0+(-5.084530e-01)*S1+1.409188e-01*S2+1.872050e+00*S3+(-1.002870e+00)*S4+(-9.477154e-02)*S5+(-4.350809e-01)*S6+(-4.976077e-01)*S7+(-6.481116e-02)*S8+(-1.967006e-01)*S9'
.param V74_part2='V74_part1+3.325565e-03*S10+(-1.698877e-02)*S11+7.594349e-02*S12+(-5.802234e-04)*S13+(-5.000877e-02)*S14+1.016788e+00*S15+1.606896e-02*S16+(-1.475325e-02)*S17+(-7.960123e+00)*S18+(-4.416404e-01)*S19'
.param V74_part3='V74_part2+(-1.346071e-01)*S20+(-7.150399e-01)*S21+(-2.427066e-02)*S22+7.512439e-02*S23+(-6.385501e-01)*S24+(-1.296017e-02)*S25+1.507243e-02*S26+1.266584e+00*S27+2.097605e-02*S28+1.822223e+00*S29'
.param V74_part4='V74_part3+2.534752e-01*S30+(-1.691439e-01)*S31+(-4.786089e+00)*S32+3.239006e-01*S33+3.712364e-02*S34+(-6.216610e-02)*S35+(-1.548154e-01)*S36+(-1.515209e-01)*S37+(-1.098239e-01)*S38+(-2.900670e-01)*S39'
.param V74_part5='V74_part4+9.121753e+00*S40+(-1.222514e+00)*S41+(-3.831816e-01)*S42+(-1.847173e-01)*S43+(-5.820719e-03)*S44+2.957544e-01*S45+6.410494e-03*S46+2.272347e-01*S47+(-2.551420e-01)*S48+(-2.981276e-02)*S49'
.param V74_part6='V74_part5+(-3.725701e-01)*S50+(-6.640824e-01)*S51+(-7.720893e-01)*S52+6.538216e+00*S53+(-1.103398e+03)*S54+(-6.891605e-01)*S55+2.922811e-02*S56+8.354286e+00*S57+(-6.547115e-01)*S58+(-2.636006e-01)*S59'
.param V74_part7='V74_part6+1.107280e-01*S60+2.361636e+00*S61+(-2.600304e+00)*S62+3.771347e+02*S63+1.578532e+00*S64+(-4.574336e-01)*S65+2.552017e+00*S66+1.356176e+00*S67+6.004198e-02*S68+1.162855e+01*S69'
.param V74_part8='V74_part7+1.397219e+00*S70+4.669721e-02*S71+0.000000e+00*S72+1.521388e+00*S73+5.922146e-01*S74+5.124790e-01*S75+7.861983e-02*S76+(-6.333882e-02)*S77+(-2.763287e-01)*S78+(-5.845020e-02)*S79'
.param V74='V74_part8+(-5.005668e-03)*S80+(-2.171287e-01)*S81+2.723001e-01*S82+(-3.909206e-03)*S83+(-2.730567e-01)*S84+1.383741e+00*S85+1.951303e-03*S86+4.492346e+03*S87+0.000000e+00*S88+(-2.185490e-01)*S89'
.param V75_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+1.047244e-01*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+1.510627e-01*S8+0.000000e+00*S9'
.param V75_part2='V75_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+3.688034e-03*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V75_part3='V75_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V75_part4='V75_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+(-2.700626e-01)*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+1.644853e+00*S37+(-5.865839e-01)*S38+6.020945e+00*S39'
.param V75_part5='V75_part4+3.261313e+00*S40+0.000000e+00*S41+6.582002e+00*S42+0.000000e+00*S43+1.639997e+00*S44+(-2.529346e-01)*S45+1.523980e+00*S46+0.000000e+00*S47+6.816616e+00*S48+(-9.946710e-01)*S49'
.param V75_part6='V75_part5+7.881160e+00*S50+0.000000e+00*S51+0.000000e+00*S52+3.606104e+00*S53+(-1.057585e+00)*S54+0.000000e+00*S55+0.000000e+00*S56+6.404265e+00*S57+0.000000e+00*S58+1.192584e+01*S59'
.param V75_part7='V75_part6+(-1.301230e+00)*S60+6.042575e+00*S61+0.000000e+00*S62+5.051186e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V75_part8='V75_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-3.090744e+00)*S75+0.000000e+00*S76+(-2.905947e+00)*S77+(-2.804158e+00)*S78+(-6.190606e+00)*S79'
.param V75='V75_part8+(-7.257219e+00)*S80+(-7.025291e+00)*S81+3.993172e+00*S82+(-9.297998e+00)*S83+(-8.890481e+00)*S84+6.140061e+00*S85+(-1.007800e+01)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V76_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+1.714819e-02*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+(-1.227478e-02)*S8+0.000000e+00*S9'
.param V76_part2='V76_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+5.992987e-01*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V76_part3='V76_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V76_part4='V76_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+4.572554e-01*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.223536e+00)*S37+1.656637e+00*S38+(-1.853280e+00)*S39'
.param V76_part5='V76_part4+4.798760e+00*S40+0.000000e+00*S41+2.924297e-02*S42+0.000000e+00*S43+(-3.231463e-01)*S44+1.014837e+00*S45+(-3.573022e+00)*S46+0.000000e+00*S47+(-5.812244e-01)*S48+3.515844e+00*S49'
.param V76_part6='V76_part5+(-3.382658e-01)*S50+0.000000e+00*S51+0.000000e+00*S52+1.228687e+01*S53+1.742458e+00*S54+0.000000e+00*S55+0.000000e+00*S56+7.210295e+00*S57+0.000000e+00*S58+3.452215e-01*S59'
.param V76_part7='V76_part6+(-7.693851e-01)*S60+1.790227e+00*S61+0.000000e+00*S62+5.609679e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V76_part8='V76_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.064970e+01*S75+0.000000e+00*S76+2.263422e+01*S77+1.048773e+01*S78+1.466750e+01*S79'
.param V76='V76_part8+3.347780e+01*S80+1.076644e+01*S81+1.556780e+01*S82+2.243936e+01*S83+1.057732e+01*S84+1.723686e+01*S85+2.011319e+01*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V77_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-1.841821e-01)*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+(-1.609023e-01)*S8+0.000000e+00*S9'
.param V77_part2='V77_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+7.109420e-02*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V77_part3='V77_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V77_part4='V77_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+3.009462e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+3.436151e+00*S37+3.086216e+00*S38+(-6.049438e+00)*S39'
.param V77_part5='V77_part4+1.237132e+00*S40+0.000000e+00*S41+(-9.714523e+00)*S42+0.000000e+00*S43+4.410880e+00*S44+2.657477e+00*S45+3.643718e+00*S46+0.000000e+00*S47+(-1.007345e+01)*S48+6.788177e+00*S49'
.param V77_part6='V77_part5+(-6.348472e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+3.465724e+00*S53+2.526832e+00*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.438754e+01)*S57+0.000000e+00*S58+(-1.020273e+01)*S59'
.param V77_part7='V77_part6+6.576621e+00*S60+(-7.237137e+00)*S61+0.000000e+00*S62+(-1.009553e+01)*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V77_part8='V77_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+1.227761e+01*S75+0.000000e+00*S76+1.476003e+01*S77+1.273011e+01*S78+2.177904e+01*S79'
.param V77='V77_part8+2.172842e+01*S80+6.064418e+00*S81+1.821312e+01*S82+2.149804e+01*S83+7.567500e+00*S84+1.807984e+01*S85+1.996125e+01*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V78_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+2.690420e-02*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+1.523475e-03*S8+0.000000e+00*S9'
.param V78_part2='V78_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+6.593358e-03*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V78_part3='V78_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V78_part4='V78_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+6.118982e-02*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-7.249797e-02)*S37+(-1.655572e-01)*S38+(-2.352721e-01)*S39'
.param V78_part5='V78_part4+(-4.350574e-01)*S40+0.000000e+00*S41+(-3.192874e-01)*S42+0.000000e+00*S43+(-2.572133e-01)*S44+3.219058e-01*S45+(-8.927118e-02)*S46+0.000000e+00*S47+(-2.554364e-01)*S48+(-2.730043e-01)*S49'
.param V78_part6='V78_part5+(-4.123872e-01)*S50+0.000000e+00*S51+0.000000e+00*S52+(-1.049866e+00)*S53+(-8.344696e-01)*S54+0.000000e+00*S55+0.000000e+00*S56+(-8.721276e-01)*S57+0.000000e+00*S58+(-9.091610e-01)*S59'
.param V78_part7='V78_part6+(-3.255371e-01)*S60+(-5.472441e-01)*S61+0.000000e+00*S62+(-5.117558e-01)*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V78_part8='V78_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+(-5.017690e-02)*S75+0.000000e+00*S76+(-7.496923e-01)*S77+(-2.903417e-01)*S78+(-4.276980e-01)*S79'
.param V78='V78_part8+(-1.583143e+00)*S80+(-2.840527e-01)*S81+(-4.339861e-01)*S82+(-1.756703e+00)*S83+(-4.226443e-01)*S84+(-2.745825e-01)*S85+(-1.729945e+00)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V79_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+7.527064e-03*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+1.240373e-03*S8+0.000000e+00*S9'
.param V79_part2='V79_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-9.033990e-02)*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V79_part3='V79_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V79_part4='V79_part3+0.000000e+00*S30+0.000000e+00*S31+0.000000e+00*S32+2.639691e-01*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.714937e-01)*S37+(-1.273432e-01)*S38+(-7.526057e-02)*S39'
.param V79_part5='V79_part4+(-2.545291e+00)*S40+0.000000e+00*S41+(-2.578333e-01)*S42+0.000000e+00*S43+(-1.122366e+00)*S44+(-1.522207e-01)*S45+(-1.604532e-01)*S46+0.000000e+00*S47+(-1.711991e-01)*S48+(-5.354113e-02)*S49'
.param V79_part6='V79_part5+3.611742e-01*S50+0.000000e+00*S51+0.000000e+00*S52+(-4.148027e+00)*S53+1.772541e+00*S54+0.000000e+00*S55+0.000000e+00*S56+(-5.349752e-01)*S57+0.000000e+00*S58+3.846892e-01*S59'
.param V79_part7='V79_part6+3.708894e-01*S60+2.002854e-01*S61+0.000000e+00*S62+1.076407e+00*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V79_part8='V79_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+4.395222e-03*S75+0.000000e+00*S76+(-1.384166e+00)*S77+(-5.933670e-01)*S78+(-3.719189e-02)*S79'
.param V79='V79_part8+(-5.803296e+00)*S80+6.424347e-01*S81+(-6.688882e+00)*S82+(-9.285713e+00)*S83+8.049835e-01*S84+(-8.291500e+00)*S85+(-1.005602e+01)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-15*_P2'
.param _P4='V5+V6*rad_+V7/w_'
.param _P5='_P4+V8*gdis_+V9*spacing_'
.param _P6='0.5*(_P5+sqrt(_P5*_P5+0.001))'
.param _P7='V10+V11*rad_+V12*w_'
.param _P8='_P7+V13*gdis_+V14*spacing_'
.param _P9='0.5*(_P8+sqrt(_P8*_P8+0.001))'
.param _P10='1e-09*_P9'
.param _P11='1e-09*_P9'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='V20+V21*rad_+V22*w_'
.param _P16='_P15+V23*gdis_+V24*spacing_'
.param _P17='0.5*(_P16+sqrt(_P16*_P16+0.001))'
.param _P18='1e-09*_P17'
.param _P19='V25+V26*rad_+V27*w_'
.param _P20='_P19+V28*gdis_+V29*spacing_'
.param _P21='0.5*(atan(2*_P20)/1.5708+1)'
.param _P22='0.7064*_P21'
.param _P23='0.7064*_P21'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='V35+V36*rad_+V37*w_'
.param _P28='_P27+V38*gdis_+V39*spacing_'
.param _P29='0.5*(_P28+sqrt(_P28*_P28+0.001))'
.param _P30='V40+V41*rad_+V42*w_'
.param _P31='_P30+V43*gdis_+V44*spacing_'
.param _P32='0.5*(_P31+sqrt(_P31*_P31+0.001))'
.param _P33='V45+V46*rad_+V47*w_'
.param _P34='_P33+V48*gdis_+V49*spacing_'
.param _P35='0.5*(_P34+sqrt(_P34*_P34+0.001))'
.param _P36='V50+V51*rad_+V52*w_'
.param _P37='_P36+V53*gdis_+V54*spacing_'
.param _P38='0.5*(_P37+sqrt(_P37*_P37+0.001))'
.param _P39='V55+V56*rad_+V57*w_'
.param _P40='_P39+V58*gdis_+V59*spacing_'
.param _P41='0.5*(_P40+sqrt(_P40*_P40+0.001))'
.param _P42='1e-14*_P26'
.param _P43='100*_P29'
.param _P44='1e-15*_P32'
.param _P45='1e-14*_P26'
.param _P46='100*_P29'
.param _P47='1e-15*_P32'
.param _P48='1e-14*_P35'
.param _P49='100*_P38'
.param _P50='1e-15*_P41'
.param _P51='V60+V61*rad_+V62*w_'
.param _P52='_P51+V63*gdis_+V64*spacing_'
.param _P53='0.5*(_P52+sqrt(_P52*_P52+0.001))'
.param _P54='V65+V66*rad_+V67*w_'
.param _P55='_P54+V68*gdis_+V69*spacing_'
.param _P56='0.5*(_P55+sqrt(_P55*_P55+0.001))'
.param _P57='100*_P53'
.param _P58='1e-13*_P56'
.param _P59='V70+V71*rad_+V72*w_'
.param _P60='_P59+V73*gdis_+V74*spacing_'
.param _P61='0.5*(_P60+sqrt(_P60*_P60+0.001))'
.param _P62='V75+V76*rad_+V77*w_'
.param _P63='_P62+V78*gdis_+V79*spacing_'
.param _P64='0.5*(_P63+sqrt(_P63*_P63+0.001))'
.param _P65='100*_P61'
.param _P66='1e-13*_P64'
.param _P67='100*_P61'
.param _P68='1e-13*_P64'
cs top bottom '_P3*c12_indfac'
rs1_1 top n1_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_1 n1_1 ni_1 '_P10* l_indfac'
rs2_1 ni_1 n2_1 '_P6*(0.0026*(temper-25)+1)*rm9_indfac'
ls2_1 n2_1 bottom '_P11* l_indfac'
rs1_2 top n1_2 '_P14*(0.0026*(temper-25)+1)*rm9_indfac'
ls1_2 n1_2 bottom '_P18* l_indfac'
k1 ls1_1 ls1_2 K=_P22
k2 ls2_1 ls1_2 K=_P23
c_1_sub top _n1_1_sub '_P42*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P43*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P44* csub_indfac'
c_2_sub bottom _n1_2_sub '_P45*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P46*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P47* csub_indfac'
c_3_sub ni_1 _n1_3_sub '_P48*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4)))/(0.0440289))* cm9_indfac'
rs_3_sub _n1_3_sub gnode '_P49*rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_3_sub _n1_3_sub gnode '_P50* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P57*rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P58* csub_indfac'
rx_1_3_sub _n1_1_sub _n1_3_sub '_P65*rsub_indfac'
cx_1_3_sub _n1_1_sub _n1_3_sub '_P66* csub_indfac'
rx_2_3_sub _n1_2_sub _n1_3_sub '_P67*rsub_indfac'
cx_2_3_sub _n1_2_sub _n1_3_sub '_P68* csub_indfac'
kzero1 ls1_1 ls2_1 K=1e-6
.ends spiral_sym_mza_a
*
.subckt spiral_sym_ct_mza_a top bottom gnode tap rad=6e-05 w=9e-06 nr=1 gdis=5e-05 spacing=3e-06 lay=8 scale='scale_ind'
.param rad_='0.0111111*(rad/1e-06*scale-0)' w_='0.0333333*(w/1e-06*scale-0)' gdis_='0.025*(gdis/1e-06*scale-20)' spacing_='0.5*(spacing/1e-06*scale-1)'
.param T132='(1-abs(sgn(nr-(1))))'
.param T133='(min(sgn(rad_-(0.3335))+1,1))'
.param T134='(min(sgn(w_-(0.4002))+1,1))'
.param T135='(min(sgn(w_-(0.3998))+1,1))'
.param T136='(min(sgn(w_+1.500000e-01*rad_-(0.708258))+1,1))'
.param T137='(min(sgn(w_+1.500000e-01*rad_-(0.707576))+1,1))'
.param T138='(min(sgn(w_-3.500000e-01*rad_-(0.540876))+1,1))'
.param T139='(min(sgn(rad_-(0.377933))+1,1))'
.param T140='(min(sgn(rad_-(0.333167))+1,1))'
.param T141='(min(sgn(rad_-(0.500167))+1,1))'
.param T142='(min(sgn(w_-3.500000e-01*rad_-(0.541624))+1,1))'
.param T143='(min(sgn(w_+1.166667e-01*rad_-(0.717884))+1,1))'
.param T144='(min(sgn(rad_-(0.377622))+1,1))'
.param T145='(min(sgn(w_+1.166667e-01*rad_-(0.717208))+1,1))'
.param T146='(min(sgn(w_-3.833333e-01*rad_-(0.467164))+1,1))'
.param T147='(min(sgn(rad_-(0.533489))+1,1))'
.param T148='(min(sgn(rad_-(0.499833))+1,1))'
.param T149='(min(sgn(rad_-(0.666833))+1,1))'
.param T150='(min(sgn(w_-3.833333e-01*rad_-(0.467929))+1,1))'
.param T151='(min(sgn(w_+8.333333e-02*rad_-(0.716771))+1,1))'
.param T152='(min(sgn(rad_-(0.533178))+1,1))'
.param T153='(min(sgn(w_+8.333333e-02*rad_-(0.7161))+1,1))'
.param T154='(min(sgn(w_-4.166667e-01*rad_-(0.382711))+1,1))'
.param T155='(min(sgn(rad_-(0.689044))+1,1))'
.param T156='(min(sgn(rad_-(0.6665))+1,1))'
.param T157='(min(sgn(rad_-(0.8335))+1,1))'
.param T158='(min(sgn(w_-4.166667e-01*rad_-(0.383493))+1,1))'
.param T159='(min(sgn(w_+5.000000e-02*rad_-(0.704918))+1,1))'
.param T160='(min(sgn(w_-4.500000e-01*rad_-(0.287516))+1,1))'
.param T161='(min(sgn(rad_-(0.8446))+1,1))'
.param T162='(min(sgn(rad_-(0.688733))+1,1))'
.param T163='(min(sgn(w_+5.000000e-02*rad_-(0.704249))+1,1))'
.param T164='(min(sgn(rad_-(0.833167))+1,1))'
.param T165='(min(sgn(w_+1.041667e-02*rad_-(0.576778))+1,1))'
.param T166='(min(sgn(w_+1.666667e-02*rad_-(0.682324))+1,1))'
.param T167='(min(sgn(w_-4.500000e-01*rad_-(0.288318))+1,1))'
.param T168='(min(sgn(w_+1.666667e-02*rad_-(0.681657))+1,1))'
.param T169='(min(sgn(w_+1.041667e-02*rad_-(0.575711))+1,1))'
.param T170='(min(sgn(rad_-(0.844289))+1,1))'
.param T171='(1-abs(sgn(nr-(2))))'
.param T172='(1-abs(sgn(nr-(3))))'
.param T173='(1-abs(sgn(nr-(4))))'
.param T174='(1-abs(sgn(nr-(5))))'
.param T175='(1-abs(sgn(nr-(6))))'
.param S0='T132*(1-T133)*(1-T134)'
.param noS0='(1-S0)'
.param S1='T132*T135*(1-T133)*(1-T136)*noS0'
.param noS1='(1-S1)*noS0'
.param S2='T132*T137*T138*(1-T139)*noS1'
.param noS2='(1-S2)*noS1'
.param S3='T132*(1-T134)*T140*(1-T141)*noS2'
.param noS3='(1-S3)*noS2'
.param S4='T132*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS3'
.param noS4='(1-S4)*noS3'
.param S5='T132*T144*T145*T146*(1-T147)*noS4'
.param noS5='(1-S5)*noS4'
.param S6='T132*(1-T134)*T148*(1-T149)*noS5'
.param noS6='(1-S6)*noS5'
.param S7='T132*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS6'
.param noS7='(1-S7)*noS6'
.param S8='T132*T152*T153*T154*(1-T155)*noS7'
.param noS8='(1-S8)*noS7'
.param S9='T132*(1-T134)*T156*(1-T157)*noS8'
.param noS9='(1-S9)*noS8'
.param S10='T132*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS9'
.param noS10='(1-S10)*noS9'
.param S11='T132*T160*(1-T161)*T162*T163*noS10'
.param noS11='(1-S11)*noS10'
.param S12='T132*(1-T134)*T164*(1-T165)*noS11'
.param noS12='(1-S12)*noS11'
.param S13='T132*T164*T135*(1-T166)*(1-T167)*noS12'
.param noS13='(1-S13)*noS12'
.param S14='T132*T168*T169*T170*noS13'
.param noS14='(1-S14)*noS13'
.param S15='T171*(1-T133)*(1-T134)*noS14'
.param noS15='(1-S15)*noS14'
.param S16='T171*T135*(1-T133)*(1-T136)*noS15'
.param noS16='(1-S16)*noS15'
.param S17='T171*T137*T138*(1-T139)*noS16'
.param noS17='(1-S17)*noS16'
.param S18='T171*(1-T134)*T140*(1-T141)*noS17'
.param noS18='(1-S18)*noS17'
.param S19='T171*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS18'
.param noS19='(1-S19)*noS18'
.param S20='T171*T144*T145*T146*(1-T147)*noS19'
.param noS20='(1-S20)*noS19'
.param S21='T171*(1-T134)*T148*(1-T149)*noS20'
.param noS21='(1-S21)*noS20'
.param S22='T171*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS21'
.param noS22='(1-S22)*noS21'
.param S23='T171*T152*T153*T154*(1-T155)*noS22'
.param noS23='(1-S23)*noS22'
.param S24='T171*(1-T134)*T156*(1-T157)*noS23'
.param noS24='(1-S24)*noS23'
.param S25='T171*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS24'
.param noS25='(1-S25)*noS24'
.param S26='T171*T160*(1-T161)*T162*T163*noS25'
.param noS26='(1-S26)*noS25'
.param S27='T171*(1-T134)*T164*(1-T165)*noS26'
.param noS27='(1-S27)*noS26'
.param S28='T171*T164*T135*(1-T166)*(1-T167)*noS27'
.param noS28='(1-S28)*noS27'
.param S29='T171*T168*T169*T170*noS28'
.param noS29='(1-S29)*noS28'
.param S30='T172*(1-T133)*(1-T134)*noS29'
.param noS30='(1-S30)*noS29'
.param S31='T172*T135*(1-T133)*(1-T136)*noS30'
.param noS31='(1-S31)*noS30'
.param S32='T172*T137*T138*(1-T139)*noS31'
.param noS32='(1-S32)*noS31'
.param S33='T172*(1-T134)*T140*(1-T141)*noS32'
.param noS33='(1-S33)*noS32'
.param S34='T172*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS33'
.param noS34='(1-S34)*noS33'
.param S35='T172*T144*T145*T146*(1-T147)*noS34'
.param noS35='(1-S35)*noS34'
.param S36='T172*(1-T134)*T148*(1-T149)*noS35'
.param noS36='(1-S36)*noS35'
.param S37='T172*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS36'
.param noS37='(1-S37)*noS36'
.param S38='T172*T152*T153*T154*(1-T155)*noS37'
.param noS38='(1-S38)*noS37'
.param S39='T172*(1-T134)*T156*(1-T157)*noS38'
.param noS39='(1-S39)*noS38'
.param S40='T172*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS39'
.param noS40='(1-S40)*noS39'
.param S41='T172*T160*(1-T161)*T162*T163*noS40'
.param noS41='(1-S41)*noS40'
.param S42='T172*(1-T134)*T164*(1-T165)*noS41'
.param noS42='(1-S42)*noS41'
.param S43='T172*T164*T135*(1-T166)*(1-T167)*noS42'
.param noS43='(1-S43)*noS42'
.param S44='T172*T168*T169*T170*noS43'
.param noS44='(1-S44)*noS43'
.param S45='T173*(1-T133)*(1-T134)*noS44'
.param noS45='(1-S45)*noS44'
.param S46='T173*T135*(1-T133)*(1-T136)*noS45'
.param noS46='(1-S46)*noS45'
.param S47='T173*T137*T138*(1-T139)*noS46'
.param noS47='(1-S47)*noS46'
.param S48='T173*(1-T134)*T140*(1-T141)*noS47'
.param noS48='(1-S48)*noS47'
.param S49='T173*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS48'
.param noS49='(1-S49)*noS48'
.param S50='T173*T144*T145*T146*(1-T147)*noS49'
.param noS50='(1-S50)*noS49'
.param S51='T173*(1-T134)*T148*(1-T149)*noS50'
.param noS51='(1-S51)*noS50'
.param S52='T173*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS51'
.param noS52='(1-S52)*noS51'
.param S53='T173*T152*T153*T154*(1-T155)*noS52'
.param noS53='(1-S53)*noS52'
.param S54='T173*(1-T134)*T156*(1-T157)*noS53'
.param noS54='(1-S54)*noS53'
.param S55='T173*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS54'
.param noS55='(1-S55)*noS54'
.param S56='T173*T160*(1-T161)*T162*T163*noS55'
.param noS56='(1-S56)*noS55'
.param S57='T173*(1-T134)*T164*(1-T165)*noS56'
.param noS57='(1-S57)*noS56'
.param S58='T173*T164*T135*(1-T166)*(1-T167)*noS57'
.param noS58='(1-S58)*noS57'
.param S59='T173*T168*T169*T170*noS58'
.param noS59='(1-S59)*noS58'
.param S60='T174*(1-T133)*(1-T134)*noS59'
.param noS60='(1-S60)*noS59'
.param S61='T174*T135*(1-T133)*(1-T136)*noS60'
.param noS61='(1-S61)*noS60'
.param S62='T174*T137*T138*(1-T139)*noS61'
.param noS62='(1-S62)*noS61'
.param S63='T174*(1-T134)*T140*(1-T141)*noS62'
.param noS63='(1-S63)*noS62'
.param S64='T174*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS63'
.param noS64='(1-S64)*noS63'
.param S65='T174*T144*T145*T146*(1-T147)*noS64'
.param noS65='(1-S65)*noS64'
.param S66='T174*(1-T134)*T148*(1-T149)*noS65'
.param noS66='(1-S66)*noS65'
.param S67='T174*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS66'
.param noS67='(1-S67)*noS66'
.param S68='T174*T152*T153*T154*(1-T155)*noS67'
.param noS68='(1-S68)*noS67'
.param S69='T174*(1-T134)*T156*(1-T157)*noS68'
.param noS69='(1-S69)*noS68'
.param S70='T174*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS69'
.param noS70='(1-S70)*noS69'
.param S71='T174*T160*(1-T161)*T162*T163*noS70'
.param noS71='(1-S71)*noS70'
.param S72='T174*(1-T134)*T164*(1-T165)*noS71'
.param noS72='(1-S72)*noS71'
.param S73='T174*T164*T135*(1-T166)*(1-T167)*noS72'
.param noS73='(1-S73)*noS72'
.param S74='T174*T168*T169*T170*noS73'
.param noS74='(1-S74)*noS73'
.param S75='T175*(1-T133)*(1-T134)*noS74'
.param noS75='(1-S75)*noS74'
.param S76='T175*T135*(1-T133)*(1-T136)*noS75'
.param noS76='(1-S76)*noS75'
.param S77='T175*T137*T138*(1-T139)*noS76'
.param noS77='(1-S77)*noS76'
.param S78='T175*(1-T134)*T140*(1-T141)*noS77'
.param noS78='(1-S78)*noS77'
.param S79='T175*T140*T135*(1-T141)*(1-T142)*(1-T143)*noS78'
.param noS79='(1-S79)*noS78'
.param S80='T175*T144*T145*T146*(1-T147)*noS79'
.param noS80='(1-S80)*noS79'
.param S81='T175*(1-T134)*T148*(1-T149)*noS80'
.param noS81='(1-S81)*noS80'
.param S82='T175*T148*T135*(1-T149)*(1-T150)*(1-T151)*noS81'
.param noS82='(1-S82)*noS81'
.param S83='T175*T152*T153*T154*(1-T155)*noS82'
.param noS83='(1-S83)*noS82'
.param S84='T175*(1-T134)*T156*(1-T157)*noS83'
.param noS84='(1-S84)*noS83'
.param S85='T175*T156*T135*(1-T157)*(1-T158)*(1-T159)*noS84'
.param noS85='(1-S85)*noS84'
.param S86='T175*T160*(1-T161)*T162*T163*noS85'
.param noS86='(1-S86)*noS85'
.param S87='T175*(1-T134)*T164*(1-T165)*noS86'
.param noS87='(1-S87)*noS86'
.param S88='T175*T164*T135*(1-T166)*(1-T167)*noS87'
.param noS88='(1-S88)*noS87'
.param S89='T175*T168*T169*T170*noS88'
.param noS89='(1-S89)*noS88'
.param V0_part1='(-4.583264e-03)*S0+4.823039e-02*S1+(-4.330614e-03)*S2+2.044747e+00*S3+1.848324e-02*S4+7.905950e-02*S5+2.489221e+00*S6+2.922939e-02*S7+3.609576e-01*S8+5.192929e-01*S9'
.param V0_part2='V0_part1+3.987634e-02*S10+1.849162e-02*S11+2.614683e-01*S12+(-2.883957e-01)*S13+(-2.044286e-01)*S14+4.098408e-01*S15+3.280417e-01*S16+3.395814e-02*S17+7.685880e-01*S18+3.739734e-01*S19'
.param V0_part3='V0_part2+4.871489e-02*S20+(-3.705854e-02)*S21+2.270394e-01*S22+2.338550e-01*S23+(-2.171859e-01)*S24+1.418254e-01*S25+8.539634e-02*S26+(-4.173818e-01)*S27+1.427345e-03*S28+3.736400e-02*S29'
.param V0_part4='V0_part3+(-7.851909e-03)*S30+(-7.601088e-01)*S31+(-5.713626e-01)*S32+2.298491e-02*S33+(-6.052482e-02)*S34+1.320052e-04*S35+8.399308e-01*S36+(-3.660910e-01)*S37+(-4.073892e-02)*S38+(-2.243012e+00)*S39'
.param V0_part5='V0_part4+(-6.103511e-01)*S40+(-3.613904e-02)*S41+1.856619e+00*S42+(-3.246291e-01)*S43+(-1.207339e-01)*S44+(-1.403226e-01)*S45+(-3.670146e-02)*S46+(-5.161693e-02)*S47+(-2.589404e-01)*S48+9.535325e-02*S49'
.param V0_part6='V0_part5+(-8.332941e-02)*S50+(-4.343627e-01)*S51+(-3.381774e-01)*S52+(-6.718159e-02)*S53+(-5.752553e-01)*S54+(-4.334502e-01)*S55+(-6.193653e-02)*S56+(-7.175259e-01)*S57+(-3.032174e-01)*S58+(-2.294972e-01)*S59'
.param V0_part7='V0_part6+(-2.843400e-01)*S60+4.924480e-01*S61+(-7.442852e-02)*S62+(-1.771926e-01)*S63+(-3.254449e-01)*S64+4.258212e-01*S65+(-3.894152e-01)*S66+(-3.725919e-01)*S67+(-2.001324e-01)*S68+(-7.237837e-01)*S69'
.param V0_part8='V0_part7+(-9.504182e-02)*S70+(-1.746043e-01)*S71+(-1.043495e+00)*S72+(-7.387047e-01)*S73+(-1.256145e-02)*S74+(-4.000927e-01)*S75+6.031792e-02*S76+(-2.908254e-01)*S77+(-2.476920e-01)*S78+(-1.744100e-01)*S79'
.param V0='V0_part8+5.225959e-01*S80+(-4.944643e-01)*S81+(-2.569496e-01)*S82+2.568833e-01*S83+(-7.035705e-01)*S84+(-8.572878e-01)*S85+7.012265e+00*S86+(-8.778253e-01)*S87+(-7.451698e-01)*S88+(-9.876382e-01)*S89'
.param V1_part1='1.711980e-01*S0+2.008182e-01*S1+7.035832e-01*S2+1.858508e+00*S3+1.838844e-01*S4+3.716456e-01*S5+5.295512e-01*S6+1.388321e-01*S7+5.377916e-01*S8+3.373778e+00*S9'
.param V1_part2='V1_part1+1.385914e-01*S10+1.095658e-01*S11+7.977377e-01*S12+8.677718e-01*S13+1.092785e+00*S14+5.581246e-01*S15+4.392490e-01*S16+5.829385e-01*S17+5.873256e-01*S18+5.534277e-01*S19'
.param V1_part3='V1_part2+1.102069e+00*S20+1.691146e+00*S21+4.678874e-01*S22+5.372732e-01*S23+1.709844e+00*S24+1.151019e+00*S25+6.220030e-01*S26+3.530101e+00*S27+1.122685e+00*S28+7.912666e-01*S29'
.param V1_part4='V1_part3+8.574170e-01*S30+9.097967e+00*S31+6.118737e+00*S32+2.128945e+00*S33+2.633660e+00*S34+1.096888e+00*S35+1.443357e+00*S36+3.533614e+00*S37+1.183338e+00*S38+8.384557e+01*S39'
.param V1_part5='V1_part4+3.817750e+00*S40+1.234173e+00*S41+3.759128e-01*S42+3.389693e+00*S43+1.423794e+00*S44+1.776909e+00*S45+1.521001e+00*S46+1.787214e+00*S47+1.923797e+00*S48+1.762649e+00*S49'
.param V1_part6='V1_part5+1.875727e+00*S50+2.162180e+00*S51+1.834584e+00*S52+1.854773e+00*S53+2.403877e+00*S54+2.092043e+00*S55+1.811331e+00*S56+2.479567e+00*S57+2.041790e+00*S58+2.008026e+00*S59'
.param V1_part7='V1_part6+6.357947e+00*S60+1.043037e+01*S61+2.413565e+00*S62+3.122720e+00*S63+2.428941e+00*S64+4.979327e+00*S65+2.783781e+00*S66+2.500471e+00*S67+2.566794e+00*S68+3.985326e+00*S69'
.param V1_part8='V1_part7+2.371391e+00*S70+2.622240e+00*S71+3.838633e+00*S72+2.795313e+00*S73+2.409342e+00*S74+6.569184e+00*S75+4.356200e+00*S76+1.402584e+01*S77+5.697370e+00*S78+4.471880e+00*S79'
.param V1='V1_part8+3.514095e+01*S80+4.458914e+00*S81+4.980937e+00*S82+4.540597e+01*S83+4.536877e+00*S84+4.503030e+00*S85+1.228001e+02*S86+4.620904e+00*S87+4.557639e+00*S88+4.263661e+00*S89'
.param V2_part1='4.653171e-02*S0+(-1.117460e-02)*S1+2.176127e-02*S2+(-2.676833e+00)*S3+(-9.701406e-03)*S4+(-7.804229e-02)*S5+2.019862e+01*S6+(-3.715370e-02)*S7+(-2.255987e-01)*S8+(-3.498187e+00)*S9'
.param V2_part2='V2_part1+(-4.926197e-02)*S10+(-1.271930e-02)*S11+(-7.510585e-01)*S12+5.149047e-02*S13+8.481326e-02*S14+(-3.580689e-01)*S15+(-1.481512e-01)*S16+1.328085e-01*S17+(-6.672188e-01)*S18+(-1.742358e-01)*S19'
.param V2_part3='V2_part2+2.588849e-03*S20+(-2.898619e-01)*S21+(-8.536284e-02)*S22+9.378605e-02*S23+(-3.284422e-01)*S24+(-8.030827e-02)*S25+(-1.402420e-02)*S26+(-9.005692e-01)*S27+(-1.541722e-01)*S28+(-7.208041e-02)*S29'
.param V2_part4='V2_part3+1.259290e-01*S30+1.627673e+00*S31+9.608812e-01*S32+1.514289e-01*S33+1.735474e-01*S34+2.106409e-01*S35+(-3.692654e-01)*S36+2.291254e-01*S37+1.505108e-01*S38+1.019150e+01*S39'
.param V2_part5='V2_part4+5.285376e-01*S40+1.240698e-01*S41+(-2.885043e-01)*S42+(-1.983734e-01)*S43+9.473221e-02*S44+3.633296e-01*S45+3.980620e-01*S46+4.306816e-01*S47+4.056273e-01*S48+4.441145e-01*S49'
.param V2_part6='V2_part5+4.075322e-01*S50+2.868650e-01*S51+5.245749e-01*S52+3.833442e-01*S53+5.512552e-01*S54+7.325268e-01*S55+3.785279e-01*S56+5.506684e-01*S57+1.204102e-01*S58+3.860289e-01*S59'
.param V2_part7='V2_part6+1.889926e+00*S60+1.711159e+00*S61+8.999561e-01*S62+5.975571e-01*S63+9.782467e-01*S64+1.889133e+00*S65+1.129379e+00*S66+1.111547e+00*S67+9.118098e-01*S68+7.336553e-01*S69'
.param V2_part8='V2_part7+8.333530e-01*S70+8.467402e-01*S71+3.838035e-01*S72+1.183237e+00*S73+7.884613e-01*S74+2.266232e+00*S75+1.319390e+00*S76+5.555523e+00*S77+1.831765e+00*S78+1.236154e+00*S79'
.param V2='V2_part8+6.880980e+00*S80+1.058931e+00*S81+1.196904e+00*S82+(-5.632017e+00)*S83+7.505277e-01*S84+1.152642e+00*S85+(-2.387113e+01)*S86+4.154705e-01*S87+7.253831e-01*S88+1.160000e+00*S89'
.param V3_part1='1.406675e-02*S0+4.611161e-02*S1+1.151049e-01*S2+1.342287e+00*S3+1.764846e-02*S4+1.895653e-02*S5+(-2.333002e+00)*S6+1.125711e-02*S7+1.649986e-01*S8+6.632701e-01*S9'
.param V3_part2='V3_part1+5.626022e-03*S10+1.295305e-02*S11+2.550375e-01*S12+8.602624e-02*S13+2.125406e-01*S14+(-4.927954e-02)*S15+(-3.744338e-02)*S16+8.335678e-02*S17+(-1.279426e-01)*S18+(-6.106845e-02)*S19'
.param V3_part3='V3_part2+(-4.718911e-02)*S20+(-1.446286e-01)*S21+6.995771e-02*S22+1.107871e-01*S23+(-3.489940e-02)*S24+(-2.998103e-02)*S25+(-3.952924e-02)*S26+(-7.061867e-02)*S27+(-3.524809e-02)*S28+(-6.512194e-02)*S29'
.param V3_part4='V3_part3+2.261376e-02*S30+1.412597e-01*S31+1.227122e-01*S32+1.606015e-02*S33+3.680186e-03*S34+7.983058e-02*S35+(-2.373059e-02)*S36+1.875727e-03*S37+8.566105e-02*S38+1.487470e+00*S39'
.param V3_part5='V3_part4+4.435742e-02*S40+1.026060e-01*S41+1.430265e-01*S42+(-2.135854e-01)*S43+1.160491e-01*S44+4.666505e-04*S45+3.503332e-02*S46+6.049557e-02*S47+(-9.074314e-03)*S48+1.011047e-01*S49'
.param V3_part6='V3_part5+8.915387e-02*S50+(-2.346694e-02)*S51+(-1.810495e-02)*S52+1.187560e-01*S53+1.723724e-03*S54+(-2.287729e-02)*S55+1.472411e-01*S56+8.268883e-03*S57+(-3.769397e-03)*S58+1.532453e-01*S59'
.param V3_part7='V3_part6+1.628032e-02*S60+(-8.675060e-02)*S61+9.593150e-02*S62+(-9.135595e-03)*S63+(-3.301231e-03)*S64+(-4.331054e-01)*S65+1.689981e-03*S66+(-9.689569e-03)*S67+1.188193e-01*S68+(-3.199349e-02)*S69'
.param V3_part8='V3_part7+(-6.112621e-02)*S70+1.326516e-01*S71+(-2.103868e-02)*S72+(-1.965543e-03)*S73+2.541442e-02*S74+3.351045e-02*S75+(-1.410131e-02)*S76+(-7.328576e-01)*S77+(-8.370415e-03)*S78+(-2.397696e-02)*S79'
.param V3='V3_part8+5.040065e-01*S80+(-4.052007e-02)*S81+6.792740e-03*S82+(-5.073925e-01)*S83+(-2.705806e-02)*S84+(-2.231129e-02)*S85+(-1.998577e+00)*S86+(-2.343766e-02)*S87+(-2.130071e-02)*S88+(-2.723453e-02)*S89'
.param V4_part1='5.161328e-03*S0+2.052850e-03*S1+1.552013e-03*S2+(-4.888983e-02)*S3+1.545770e-03*S4+3.719219e-03*S5+3.003331e-01*S6+2.091626e-03*S7+7.123137e-03*S8+4.636415e-02*S9'
.param V4_part2='V4_part1+2.321099e-03*S10+1.604363e-03*S11+1.360706e-02*S12+1.123128e-02*S13+1.759886e-04*S14+(-5.652380e-03)*S15+(-2.734160e-03)*S16+1.708827e-02*S17+5.858349e-04*S18+5.365725e-04*S19'
.param V4_part3='V4_part2+4.230333e-02*S20+2.712727e-02*S21+(-2.536955e-02)*S22+(-2.177189e-02)*S23+1.566965e-01*S24+3.448233e-02*S25+2.243743e-02*S26+4.819712e-01*S27+3.152865e-02*S28+4.077525e-02*S29'
.param V4_part4='V4_part3+2.354247e-02*S30+4.553242e-01*S31+2.867857e-01*S32+1.278635e-01*S33+1.416365e-01*S34+3.646136e-02*S35+2.545179e-01*S36+2.154669e-01*S37+3.760348e-02*S38+6.869892e+00*S39'
.param V4_part5='V4_part4+3.095926e-01*S40+3.728981e-02*S41+1.940127e-02*S42+5.850452e-04*S43+4.001541e-02*S44+2.757398e-01*S45+5.746312e-02*S46+9.160484e-02*S47+3.399162e-01*S48+6.057770e-02*S49'
.param V4_part6='V4_part5+8.486663e-02*S50+5.312151e-01*S51+3.276667e-01*S52+7.823633e-02*S53+6.281663e-01*S54+3.757193e-01*S55+9.093066e-02*S56+7.317388e-01*S57+2.266370e-01*S58+6.588089e-02*S59'
.param V4_part7='V4_part6+8.712339e-01*S60+8.459825e-01*S61+1.222954e-01*S62+4.513249e-01*S63+5.382141e-01*S64+1.266112e-01*S65+9.008678e-01*S66+7.519138e-01*S67+8.015482e-02*S68+1.177000e+00*S69'
.param V4_part8='V4_part7+7.682628e-01*S70+7.489548e-02*S71+1.561123e+00*S72+1.135793e+00*S73+(-8.147938e-03)*S74+1.174947e+00*S75+4.965146e-01*S76+3.290659e-01*S77+7.765099e-01*S78+5.916592e-01*S79'
.param V4='V4_part8+2.309177e+00*S80+9.056675e-01*S81+7.906459e-01*S82+4.057443e+00*S83+9.700547e-01*S84+6.782200e-01*S85+1.558992e+00*S86+9.334040e-01*S87+6.207814e-01*S88+2.982496e-01*S89'
.param V5_part1='(-6.124465e-02)*S0+7.661882e-01*S1+(-2.243812e+00)*S2+(-2.795490e+01)*S3+(-7.565712e-02)*S4+(-2.499306e+00)*S5+4.406977e+02*S6+(-1.066115e-01)*S7+(-1.915862e+01)*S8+(-2.079076e+02)*S9'
.param V5_part2='V5_part1+(-1.412481e-01)*S10+(-6.529894e-02)*S11+(-2.457631e+01)*S12+(-1.686048e+01)*S13+(-8.848833e+00)*S14+(-6.100484e-02)*S15+(-1.754463e-02)*S16+2.202086e+00*S17+(-3.177048e-01)*S18+(-1.167974e-01)*S19'
.param V5_part3='V5_part2+(-1.216954e-02)*S20+(-5.100484e-01)*S21+1.175777e+00*S22+1.914528e+00*S23+(-4.518713e-01)*S24+(-3.694977e-01)*S25+(-1.011092e-01)*S26+(-2.457025e-01)*S27+(-4.686696e-01)*S28+(-1.699645e-01)*S29'
.param V5_part4='V5_part3+1.463410e+00*S30+2.050623e+00*S31+3.568622e+00*S32+1.402765e+00*S33+2.019524e+00*S34+3.321246e+00*S35+9.673911e-01*S36+1.685590e+00*S37+3.020123e+00*S38+(-5.948499e-01)*S39'
.param V5_part5='V5_part4+1.805128e+00*S40+2.760019e+00*S41+4.252453e-01*S42+(-8.213874e-01)*S43+2.508508e+00*S44+1.752161e+00*S45+3.067333e+00*S46+5.211540e+00*S47+1.211819e+00*S48+3.064287e+00*S49'
.param V5_part6='V5_part5+4.876625e+00*S50+7.455943e-01*S51+1.391872e+00*S52+4.553124e+00*S53+4.131091e-01*S54+1.119188e+00*S55+4.427289e+00*S56+3.309091e-02*S57+1.095076e+00*S58+3.905004e+00*S59'
.param V5_part7='V5_part6+2.280588e+00*S60+4.069289e+00*S61+6.424767e+00*S62+2.320141e+00*S63+2.465918e+00*S64+2.317447e-01*S65+1.203309e+00*S66+2.145956e+00*S67+5.311721e+00*S68+5.484602e-01*S69'
.param V5_part8='V5_part7+1.969423e+00*S70+5.648436e+00*S71+1.818284e-01*S72+1.680996e+00*S73+4.888612e+00*S74+3.191293e+00*S75+4.344255e+00*S76+5.571825e-01*S77+3.021207e+00*S78+4.025137e+00*S79'
.param V5='V5_part8+7.147695e+00*S80+1.837987e+00*S81+3.805194e+00*S82+6.473192e+00*S83+1.109057e+00*S84+3.395135e+00*S85+6.299000e+00*S86+2.101428e-01*S87+2.893992e+00*S88+5.308102e+00*S89'
.param V6_part1='3.437339e-01*S0+2.848815e+00*S1+8.296372e+00*S2+4.370191e+00*S3+2.545442e-01*S4+5.217150e+00*S5+1.133571e+02*S6+2.420490e-01*S7+2.115101e+01*S8+2.040632e+02*S9'
.param V6_part2='V6_part1+2.383999e-01*S10+1.206789e-01*S11+3.122392e+01*S12+4.820262e+01*S13+3.578360e+01*S14+6.142019e-01*S15+4.613592e-01*S16+6.407884e-01*S17+9.276404e-01*S18+5.789292e-01*S19'
.param V6_part3='V6_part2+2.576647e-01*S20+9.645530e-01*S21+2.723330e-01*S22+1.570913e-01*S23+3.817103e+00*S24+6.830257e-01*S25+2.859176e-01*S26+3.159805e+00*S27+6.482248e-01*S28+2.956537e-01*S29'
.param V6_part4='V6_part3+1.683175e+00*S30+9.387163e-01*S31+8.401413e-01*S32+2.333261e+00*S33+1.669356e+00*S34+3.697877e-01*S35+4.626425e+00*S36+1.244199e+00*S37+6.586444e-01*S38+1.356216e+00*S39'
.param V6_part5='V6_part4+1.024014e+00*S40+8.783410e-01*S41+2.099006e+00*S42+1.084737e+00*S43+7.969508e-01*S44+1.780079e+00*S45+1.686157e+00*S46+2.760690e-01*S47+1.935796e+00*S48+1.023888e+00*S49'
.param V6_part6='V6_part5+7.789389e-01*S50+2.159345e+00*S51+1.381256e+00*S52+1.019196e+00*S53+2.394803e+00*S54+1.450519e+00*S55+4.638413e-01*S56+2.354379e+00*S57+1.609076e+00*S58+7.375380e-01*S59'
.param V6_part7='V6_part6+1.092034e+00*S60+6.347585e-01*S61+6.576863e-01*S62+2.201288e+00*S63+9.574411e-01*S64+7.778435e-01*S65+2.724906e+00*S66+1.303790e+00*S67+9.555861e-01*S68+2.913887e+00*S69'
.param V6_part8='V6_part7+1.588896e+00*S70+3.269013e-01*S71+2.675123e+00*S72+1.822936e+00*S73+4.175181e-01*S74+1.281303e+00*S75+3.964307e-01*S76+1.144454e+00*S77+2.586675e+00*S78+1.100198e+00*S79'
.param V6='V6_part8+2.498307e-01*S80+3.769928e+00*S81+1.082130e+00*S82+5.588013e-01*S83+3.724399e+00*S84+1.650625e+00*S85+2.510184e+00*S86+3.839486e+00*S87+2.224198e+00*S88+1.889779e-01*S89'
.param V7_part1='4.254948e-02*S0+1.828060e-01*S1+3.454339e+00*S2+2.265899e+01*S3+5.893567e-02*S4+3.728400e+00*S5+1.687273e+01*S6+7.189501e-02*S7+2.661444e+01*S8+6.702452e+01*S9'
.param V7_part2='V7_part1+8.914631e-02*S10+9.884190e-02*S11+1.387898e+01*S12+5.193743e-01*S13+1.916615e+01*S14+1.173001e-01*S15+1.138432e-01*S16+(-1.198485e-01)*S17+1.743740e-01*S18+1.464667e-01*S19'
.param V7_part3='V7_part2+1.548563e-01*S20+2.359576e-01*S21+5.273671e-01*S22+3.630921e-01*S23+6.291035e-01*S24+2.261283e-01*S25+2.259637e-01*S26+7.463026e-01*S27+2.850243e-01*S28+2.844971e-01*S29'
.param V7_part4='V7_part3+2.134886e-01*S30+1.448265e-01*S31+(-5.469666e-01)*S32+3.101704e-01*S33+3.215433e-01*S34+(-2.634596e-01)*S35+7.297296e-01*S36+4.819618e-01*S37+(-9.727565e-02)*S38+5.032944e-01*S39'
.param V7_part5='V7_part4+5.751103e-01*S40+(-2.759285e-02)*S41+5.439471e-01*S42+4.983385e-01*S43+3.113611e-01*S44+1.986981e-01*S45+1.397987e-01*S46+(-6.284006e-01)*S47+3.396945e-01*S48+3.809510e-01*S49'
.param V7_part6='V7_part5+(-5.494970e-01)*S50+4.123825e-01*S51+4.204259e-01*S52+(-4.511732e-01)*S53+4.124432e-01*S54+5.005551e-01*S55+(-1.568573e-01)*S56+5.048050e-01*S57+4.793159e-01*S58+3.363674e-02*S59'
.param V7_part7='V7_part6+2.487135e-01*S60+1.689844e-01*S61+(-1.074575e+00)*S62+2.301075e-01*S63+3.856961e-01*S64+4.832307e-01*S65+3.282877e-01*S66+4.265435e-01*S67+(-6.567462e-01)*S68+4.179399e-01*S69'
.param V7_part8='V7_part7+4.097632e-01*S70+(-4.810512e-01)*S71+5.485880e-01*S72+4.380560e-01*S73+5.021755e-02*S74+2.137128e-01*S75+2.464744e-01*S76+4.337831e-01*S77+1.767292e-01*S78+1.958001e-01*S79'
.param V7='V7_part8+(-6.925556e-01)*S80+2.426793e-01*S81+2.755589e-01*S82+(-4.532631e-01)*S83+3.906315e-01*S84+2.966011e-01*S85+(-2.363867e-01)*S86+5.557334e-01*S87+2.746465e-01*S88+3.766987e-01*S89'
.param V8_part1='4.909382e-02*S0+8.601146e-01*S1+9.417851e-01*S2+9.839845e+00*S3+2.881925e-02*S4+9.656431e-03*S5+(-8.557370e+01)*S6+2.898438e-02*S7+6.158256e+00*S8+4.214824e+01*S9'
.param V8_part2='V8_part1+2.915997e-02*S10+1.586401e-02*S11+1.566922e+01*S12+5.551156e+00*S13+8.549002e+00*S14+2.271979e-02*S15+2.049494e-02*S16+6.574090e-01*S17+1.516972e-02*S18+1.923815e-02*S19'
.param V8_part3='V8_part2+1.444314e-02*S20+8.517813e-03*S21+1.690374e-01*S22+5.310961e-01*S23+(-2.747564e-01)*S24+3.492731e-02*S25+9.442895e-03*S26+(-2.849180e-01)*S27+3.260239e-02*S28+8.316486e-03*S29'
.param V8_part4='V8_part3+4.016972e-01*S30+2.314170e-01*S31+4.414920e-01*S32+8.726751e-02*S33+1.876206e-01*S34+5.789327e-01*S35+(-2.213875e-02)*S36+1.604785e-01*S37+5.385561e-01*S38+(-1.396273e-01)*S39'
.param V8_part5='V8_part4+2.799916e-02*S40+5.299155e-01*S41+7.262477e-02*S42+3.786747e-02*S43+3.791127e-01*S44+4.782435e-01*S45+3.865356e-01*S46+5.844864e-01*S47+5.280732e-01*S48+3.853148e-01*S49'
.param V8_part6='V8_part5+6.367068e-01*S50+6.049400e-01*S51+6.792381e-01*S52+6.904158e-01*S53+7.415027e-01*S54+6.838652e-01*S55+6.964685e-01*S56+7.476945e-01*S57+7.880874e-01*S58+6.710819e-01*S59'
.param V8_part7='V8_part6+4.558207e-01*S60+3.752114e-01*S61+5.822160e-01*S62+5.098915e-01*S63+4.680667e-01*S64+2.364274e-03*S65+6.190442e-01*S66+5.748134e-01*S67+7.228451e-01*S68+6.519237e-01*S69'
.param V8_part8='V8_part7+6.567060e-01*S70+5.997999e-01*S71+6.929495e-01*S72+7.147818e-01*S73+5.281944e-01*S74+5.785711e-01*S75+4.851612e-01*S76+7.462912e-03*S77+6.252153e-01*S78+5.971354e-01*S79'
.param V8='V8_part8+5.573675e-01*S80+5.747338e-01*S81+6.976022e-01*S82+5.679099e-01*S83+5.841360e-01*S84+7.498747e-01*S85+1.734171e-01*S86+6.274177e-01*S87+7.599793e-01*S88+9.072058e-01*S89'
.param V9_part1='3.315628e-03*S0+3.431253e-02*S1+(-5.617963e-02)*S2+(-3.129560e-01)*S3+2.344657e-03*S4+6.228603e-02*S5+1.965508e+01*S6+2.093309e-03*S7+(-1.645100e-01)*S8+2.241716e+00*S9'
.param V9_part2='V9_part1+2.162859e-03*S10+1.046888e-03*S11+6.278899e-01*S12+5.650266e-01*S13+(-6.245297e-01)*S14+3.640810e-02*S15+2.064816e-02*S16+8.793760e-03*S17+3.719245e-02*S18+2.087154e-02*S19'
.param V9_part3='V9_part2+1.112318e-02*S20+5.245162e-02*S21+1.082145e-01*S22+(-2.454362e-02)*S23+(-4.715286e-01)*S24+2.296828e-02*S25+1.316514e-02*S26+(-6.545918e-01)*S27+1.918439e-02*S28+1.584765e-02*S29'
.param V9_part4='V9_part3+(-1.278209e-01)*S30+(-2.834214e-02)*S31+(-1.395234e-01)*S32+(-3.932823e-01)*S33+(-5.679255e-01)*S34+(-1.385138e-01)*S35+(-1.041098e+00)*S36+(-4.374574e-01)*S37+(-1.366257e-01)*S38+(-2.548079e-02)*S39'
.param V9_part5='V9_part4+(-5.859023e-01)*S40+(-1.319490e-01)*S41+(-6.044020e-01)*S42+1.210582e-01*S43+(-2.293316e-01)*S44+4.377369e-01*S45+(-2.404232e-01)*S46+(-2.942143e-01)*S47+4.255869e-01*S48+(-6.174775e-01)*S49'
.param V9_part6='V9_part5+(-2.659114e-01)*S50+4.222135e-01*S51+3.288870e-01*S52+(-2.611818e-01)*S53+3.756311e-01*S54+3.311108e-01*S55+(-1.310872e-01)*S56+3.207369e-01*S57+2.548226e-01*S58+(-1.196787e-01)*S59'
.param V9_part7='V9_part6+4.620496e-01*S60+(-4.881948e-01)*S61+(-3.941025e-01)*S62+6.100741e-02*S63+2.468377e-01*S64+8.681501e-02*S65+4.588296e-01*S66+2.766635e-01*S67+(-1.699718e-02)*S68+4.578050e-01*S69'
.param V9_part8='V9_part7+2.771197e-01*S70+(-7.611068e-02)*S71+3.858125e-01*S72+2.736464e-01*S73+7.169214e-02*S74+4.912770e-01*S75+(-1.763421e-01)*S76+1.170107e-01*S77+2.742987e-01*S78+3.537456e-02*S79'
.param V9='V9_part8+(-3.972544e-02)*S80+3.976170e-01*S81+8.883831e-02*S82+1.831134e-01*S83+3.506850e-01*S84+1.020181e-01*S85+(-1.210883e+00)*S86+3.113771e-01*S87+1.404089e-01*S88+9.409178e-02*S89'
.param V10_part1='0.000000e+00*S0+2.136434e-02*S1+1.324956e-01*S2+5.267369e-02*S3+5.349509e-02*S4+0.000000e+00*S5+5.492593e-01*S6+5.098763e-03*S7+7.781791e-01*S8+2.044664e+00*S9'
.param V10_part2='V10_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+2.425658e+01*S16+0.000000e+00*S17+0.000000e+00*S18+2.487447e+01*S19'
.param V10_part3='V10_part2+7.179614e+00*S20+0.000000e+00*S21+8.135133e-03*S22+(-4.552007e-02)*S23+(-1.051969e-02)*S24+0.000000e+00*S25+1.696357e+00*S26+(-2.846570e-02)*S27+6.352554e+00*S28+8.117984e+00*S29'
.param V10_part4='V10_part3+6.911390e-02*S30+5.114493e-02*S31+(-2.178482e-03)*S32+0.000000e+00*S33+0.000000e+00*S34+(-1.164045e-02)*S35+0.000000e+00*S36+0.000000e+00*S37+1.673879e-02*S38+0.000000e+00*S39'
.param V10_part5='V10_part4+0.000000e+00*S40+1.757883e-02*S41+0.000000e+00*S42+(-4.578674e+00)*S43+0.000000e+00*S44+0.000000e+00*S45+(-3.214750e-02)*S46+0.000000e+00*S47+0.000000e+00*S48+(-3.450560e-02)*S49'
.param V10_part6='V10_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V10_part7='V10_part6+4.175837e-02*S60+(-6.537049e-03)*S61+0.000000e+00*S62+0.000000e+00*S63+1.293627e-01*S64+0.000000e+00*S65+1.873526e-02*S66+9.818731e-02*S67+0.000000e+00*S68+(-1.539640e-02)*S69'
.param V10_part8='V10_part7+1.743974e-01*S70+0.000000e+00*S71+6.584339e-03*S72+1.905511e-01*S73+(-8.560448e-02)*S74+(-8.241091e-02)*S75+5.133208e-02*S76+2.627994e+02*S77+(-2.120359e-01)*S78+(-1.892753e-02)*S79'
.param V10='V10_part8+0.000000e+00*S80+(-9.497312e-02)*S81+0.000000e+00*S82+0.000000e+00*S83+(-1.936611e-02)*S84+(-7.350455e-02)*S85+0.000000e+00*S86+1.321071e-01*S87+(-5.161034e-02)*S88+0.000000e+00*S89'
.param V11_part1='0.000000e+00*S0+(-8.428922e-03)*S1+2.191735e-01*S2+3.677735e-01*S3+(-4.852694e-02)*S4+0.000000e+00*S5+1.904474e+00*S6+6.336505e-02*S7+(-4.853375e-01)*S8+(-3.878249e-01)*S9'
.param V11_part2='V11_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+(-2.539573e+01)*S16+0.000000e+00*S17+0.000000e+00*S18+(-8.652751e+01)*S19'
.param V11_part3='V11_part2+3.626821e-02*S20+0.000000e+00*S21+(-1.128019e-02)*S22+6.148497e-02*S23+8.990857e-02*S24+0.000000e+00*S25+4.903862e-01*S26+1.069613e-01*S27+1.489384e-01*S28+(-1.028258e+00)*S29'
.param V11_part4='V11_part3+2.161480e-02*S30+7.530008e-02*S31+1.237869e-01*S32+0.000000e+00*S33+0.000000e+00*S34+(-9.538832e-03)*S35+0.000000e+00*S36+0.000000e+00*S37+1.265342e-01*S38+0.000000e+00*S39'
.param V11_part5='V11_part4+0.000000e+00*S40+1.106496e-01*S41+0.000000e+00*S42+6.497502e-01*S43+0.000000e+00*S44+0.000000e+00*S45+7.541275e-02*S46+0.000000e+00*S47+0.000000e+00*S48+3.009730e-02*S49'
.param V11_part6='V11_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V11_part7='V11_part6+2.218067e-01*S60+(-6.076090e-02)*S61+0.000000e+00*S62+0.000000e+00*S63+(-8.432800e-03)*S64+0.000000e+00*S65+2.439751e-01*S66+1.416383e-01*S67+0.000000e+00*S68+2.660172e-01*S69'
.param V11_part8='V11_part7+3.426188e-02*S70+0.000000e+00*S71+2.578566e-01*S72+1.180054e-02*S73+2.120703e-01*S74+3.165138e-01*S75+2.080178e-01*S76+(-2.932753e+01)*S77+4.908748e-01*S78+4.464324e-03*S79'
.param V11='V11_part8+0.000000e+00*S80+1.136529e-01*S81+0.000000e+00*S82+0.000000e+00*S83+2.306172e-01*S84+7.791212e-02*S85+0.000000e+00*S86+(-7.295881e-02)*S87+3.125512e-02*S88+0.000000e+00*S89'
.param V12_part1='0.000000e+00*S0+(-1.228073e-03)*S1+(-8.829281e-02)*S2+(-1.751927e-01)*S3+(-3.865963e-02)*S4+0.000000e+00*S5+7.607021e-01*S6+(-3.460714e-02)*S7+(-4.431703e-01)*S8+(-2.717601e+00)*S9'
.param V12_part2='V12_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+7.811989e+00*S16+0.000000e+00*S17+0.000000e+00*S18+6.394129e+01*S19'
.param V12_part3='V12_part2+1.154963e+01*S20+0.000000e+00*S21+(-4.703294e-03)*S22+2.276976e-02*S23+(-3.876819e-02)*S24+0.000000e+00*S25+1.264223e+01*S26+(-3.681513e-02)*S27+8.084591e-01*S28+7.534075e+00*S29'
.param V12_part4='V12_part3+(-3.442570e-02)*S30+9.545152e-03*S31+2.890574e-02*S32+0.000000e+00*S33+0.000000e+00*S34+8.755987e-02*S35+0.000000e+00*S36+0.000000e+00*S37+5.850101e-02*S38+0.000000e+00*S39'
.param V12_part5='V12_part4+0.000000e+00*S40+5.529760e-02*S41+0.000000e+00*S42+2.447979e+01*S43+0.000000e+00*S44+0.000000e+00*S45+4.421910e-02*S46+0.000000e+00*S47+0.000000e+00*S48+4.738104e-02*S49'
.param V12_part6='V12_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V12_part7='V12_part6+1.103841e-01*S60+8.058748e-02*S61+0.000000e+00*S62+0.000000e+00*S63+7.569126e-02*S64+0.000000e+00*S65+8.992215e-02*S66+7.392291e-02*S67+0.000000e+00*S68+6.962834e-02*S69'
.param V12_part8='V12_part7+7.224936e-02*S70+0.000000e+00*S71+3.841912e-02*S72+7.556995e-02*S73+6.967972e-02*S74+1.699999e-01*S75+5.436169e-02*S76+(-1.748987e+02)*S77+1.893278e-01*S78+8.850533e-02*S79'
.param V12='V12_part8+0.000000e+00*S80+1.749736e-01*S81+0.000000e+00*S82+0.000000e+00*S83+1.534391e-01*S84+1.075273e-01*S85+0.000000e+00*S86+1.087313e-01*S87+1.086487e-01*S88+0.000000e+00*S89'
.param V13_part1='0.000000e+00*S0+4.502521e-02*S1+5.713696e-02*S2+3.855367e-02*S3+7.301655e-02*S4+0.000000e+00*S5+(-3.565022e-01)*S6+3.717992e-02*S7+3.790525e-02*S8+1.312499e-01*S9'
.param V13_part2='V13_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+3.414768e+01*S16+0.000000e+00*S17+0.000000e+00*S18+2.701305e+01*S19'
.param V13_part3='V13_part2+3.333650e+00*S20+0.000000e+00*S21+1.047398e-02*S22+1.156508e-02*S23+(-6.979665e-03)*S24+0.000000e+00*S25+1.673640e+01*S26+(-8.968131e-03)*S27+2.579782e+01*S28+2.050386e+01*S29'
.param V13_part4='V13_part3+3.785864e-02*S30+3.082263e-02*S31+5.034168e-02*S32+0.000000e+00*S33+0.000000e+00*S34+5.876326e-02*S35+0.000000e+00*S36+0.000000e+00*S37+2.466152e-02*S38+0.000000e+00*S39'
.param V13_part5='V13_part4+0.000000e+00*S40+1.457294e-02*S41+0.000000e+00*S42+2.249726e+01*S43+0.000000e+00*S44+0.000000e+00*S45+1.230266e-02*S46+0.000000e+00*S47+0.000000e+00*S48+2.085495e-02*S49'
.param V13_part6='V13_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V13_part7='V13_part6+5.502334e-02*S60+(-6.509760e-03)*S61+0.000000e+00*S62+0.000000e+00*S63+5.442506e-02*S64+0.000000e+00*S65+6.147382e-02*S66+5.783345e-02*S67+0.000000e+00*S68+6.102175e-02*S69'
.param V13_part8='V13_part7+5.969598e-02*S70+0.000000e+00*S71+6.441035e-02*S72+6.290586e-02*S73+8.032519e-02*S74+1.555908e-02*S75+1.020509e-02*S76+1.351657e+01*S77+1.330006e-02*S78+2.066087e-02*S79'
.param V13='V13_part8+0.000000e+00*S80+1.669090e-02*S81+0.000000e+00*S82+0.000000e+00*S83+1.322649e-02*S84+1.715000e-02*S85+0.000000e+00*S86+(-4.472007e-02)*S87+1.852662e-02*S88+0.000000e+00*S89'
.param V14_part1='0.000000e+00*S0+(-1.360594e-03)*S1+(-2.964799e-03)*S2+1.418281e-02*S3+(-3.455521e-04)*S4+0.000000e+00*S5+6.607746e-02*S6+(-7.810118e-04)*S7+(-7.327354e-03)*S8+2.761320e-03*S9'
.param V14_part2='V14_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+2.519436e-01*S16+0.000000e+00*S17+0.000000e+00*S18+3.494917e-02*S19'
.param V14_part3='V14_part2+(-2.044106e+00)*S20+0.000000e+00*S21+2.232080e-02*S22+1.550484e-02*S23+1.412494e-02*S24+0.000000e+00*S25+(-1.725066e+00)*S26+1.053889e-02*S27+(-3.304883e-02)*S28+(-2.452428e+00)*S29'
.param V14_part4='V14_part3+2.396577e-03*S30+1.539648e-03*S31+(-6.043110e-03)*S32+0.000000e+00*S33+0.000000e+00*S34+(-1.327306e-02)*S35+0.000000e+00*S36+0.000000e+00*S37+7.072816e-03*S38+0.000000e+00*S39'
.param V14_part5='V14_part4+0.000000e+00*S40+5.681192e-03*S41+0.000000e+00*S42+1.693917e+00*S43+0.000000e+00*S44+0.000000e+00*S45+1.689699e-02*S46+0.000000e+00*S47+0.000000e+00*S48+1.422523e-02*S49'
.param V14_part6='V14_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V14_part7='V14_part6+3.211867e-02*S60+(-1.795208e-03)*S61+0.000000e+00*S62+0.000000e+00*S63+2.076516e-02*S64+0.000000e+00*S65+4.896712e-02*S66+2.831756e-02*S67+0.000000e+00*S68+4.811504e-02*S69'
.param V14_part8='V14_part7+4.745500e-02*S70+0.000000e+00*S71+5.798436e-02*S72+5.336290e-02*S73+6.230042e-02*S74+6.888318e-02*S75+4.236300e-02*S76+(-1.266721e+01)*S77+7.218679e-02*S78+2.066679e-03*S79'
.param V14='V14_part8+0.000000e+00*S80+3.364394e-03*S81+0.000000e+00*S82+0.000000e+00*S83+4.880316e-02*S84+1.686382e-03*S85+0.000000e+00*S86+(-9.595742e-03)*S87+3.312224e-03*S88+0.000000e+00*S89'
.param V15_part1='1.425243e-02*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.049253e-02)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V15_part2='V15_part1+(-2.807520e-02)*S10+(-4.248732e-02)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+1.063203e+01*S15+0.000000e+00*S16+0.000000e+00*S17+2.050243e+01*S18+0.000000e+00*S19'
.param V15_part3='V15_part2+0.000000e+00*S20+(-6.687408e+00)*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+2.765255e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V15_part4='V15_part3+0.000000e+00*S30+0.000000e+00*S31+6.390797e-02*S32+2.969256e-02*S33+6.410522e-02*S34+0.000000e+00*S35+1.336354e-02*S36+6.031854e-02*S37+1.396421e-02*S38+9.884791e+01*S39'
.param V15_part5='V15_part4+4.101782e-02*S40+6.888386e-03*S41+1.554634e-02*S42+0.000000e+00*S43+7.438857e-02*S44+1.291050e-02*S45+5.463942e-02*S46+(-4.055950e-03)*S47+1.011997e-02*S48+0.000000e+00*S49'
.param V15_part6='V15_part5+(-3.466686e-02)*S50+(-9.790352e-03)*S51+2.740665e-02*S52+0.000000e+00*S53+(-1.764948e-02)*S54+0.000000e+00*S55+0.000000e+00*S56+(-2.851083e-02)*S57+3.746950e-03*S58+0.000000e+00*S59'
.param V15_part7='V15_part6+0.000000e+00*S60+1.399705e-01*S61+0.000000e+00*S62+1.137239e-01*S63+(-6.063028e-02)*S64+(-7.421497e+00)*S65+0.000000e+00*S66+(-5.179756e-02)*S67+0.000000e+00*S68+3.145104e-02*S69'
.param V15_part8='V15_part7+(-1.577873e-01)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.649335e-01)*S73+0.000000e+00*S74+8.134831e-02*S75+1.102792e-01*S76+0.000000e+00*S77+2.011990e-01*S78+1.116732e-01*S79'
.param V15='V15_part8+0.000000e+00*S80+6.981785e-02*S81+1.305232e-01*S82+0.000000e+00*S83+0.000000e+00*S84+1.349747e-01*S85+0.000000e+00*S86+(-1.195662e-01)*S87+1.063271e-01*S88+2.648459e-01*S89'
.param V16_part1='8.903037e-02*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-1.574526e-01)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V16_part2='V16_part1+4.693936e-02*S10+8.745154e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-1.799697e+01)*S15+0.000000e+00*S16+0.000000e+00*S17+(-1.993149e+01)*S18+0.000000e+00*S19'
.param V16_part3='V16_part2+0.000000e+00*S20+(-3.916050e+00)*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+4.296421e-01*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V16_part4='V16_part3+0.000000e+00*S30+0.000000e+00*S31+(-4.092913e-02)*S32+1.736941e-01*S33+1.511168e-01*S34+0.000000e+00*S35+2.308701e-01*S36+1.413001e-01*S37+2.552762e-02*S38+(-6.166548e+01)*S39'
.param V16_part5='V16_part4+1.592615e-01*S40+3.475847e-02*S41+1.731728e-01*S42+0.000000e+00*S43+1.281346e-01*S44+1.618000e-01*S45+9.095141e-02*S46+(-6.262746e-02)*S47+1.534303e-01*S48+0.000000e+00*S49'
.param V16_part6='V16_part5+4.749617e-04*S50+1.654324e-01*S51+1.467425e-01*S52+0.000000e+00*S53+1.658048e-01*S54+0.000000e+00*S55+0.000000e+00*S56+1.663547e-01*S57+1.604178e-01*S58+0.000000e+00*S59'
.param V16_part7='V16_part6+0.000000e+00*S60+2.368018e-01*S61+0.000000e+00*S62+2.350853e-01*S63+2.334117e-01*S64+6.710252e+01*S65+0.000000e+00*S66+1.033565e-01*S67+0.000000e+00*S68+(-4.970250e-05)*S69'
.param V16_part8='V16_part7+2.393900e-01*S70+0.000000e+00*S71+0.000000e+00*S72+2.329629e-01*S73+0.000000e+00*S74+(-1.202387e-01)*S75+(-2.237484e-02)*S76+0.000000e+00*S77+(-2.693240e-01)*S78+1.594464e-01*S79'
.param V16='V16_part8+0.000000e+00*S80+1.461325e-01*S81+(-9.397817e-03)*S82+0.000000e+00*S83+0.000000e+00*S84+1.462029e-01*S85+0.000000e+00*S86+3.122199e-01*S87+2.016194e-01*S88+1.630862e-01*S89'
.param V17_part1='(-1.120699e-03)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+1.087964e-01*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V17_part2='V17_part1+9.383193e-03*S10+(-1.309947e-03)*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+4.775870e+00*S15+0.000000e+00*S16+0.000000e+00*S17+3.305325e+00*S18+0.000000e+00*S19'
.param V17_part3='V17_part2+0.000000e+00*S20+1.182128e+01*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+(-2.234917e-01)*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V17_part4='V17_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.608140e-02)*S32+1.901332e-03*S33+(-3.614825e-03)*S34+0.000000e+00*S35+1.211031e-02*S36+2.519610e-03*S37+(-1.868612e-03)*S38+(-5.081514e+00)*S39'
.param V17_part5='V17_part4+6.136638e-03*S40+9.022806e-04*S41+9.476354e-03*S42+0.000000e+00*S43+(-6.855672e-03)*S44+(-6.375135e-03)*S45+(-8.996716e-03)*S46+9.634230e-03*S47+(-7.682935e-03)*S48+0.000000e+00*S49'
.param V17_part6='V17_part5+1.993718e-02*S50+(-6.500888e-03)*S51+(-1.286741e-02)*S52+0.000000e+00*S53+(-3.134049e-03)*S54+0.000000e+00*S55+0.000000e+00*S56+(-1.671841e-03)*S57+(-9.048056e-03)*S58+0.000000e+00*S59'
.param V17_part7='V17_part6+0.000000e+00*S60+(-1.504141e-02)*S61+0.000000e+00*S62+(-1.047129e-02)*S63+(-6.116350e-03)*S64+6.964513e+01*S65+0.000000e+00*S66+(-3.497649e-03)*S67+0.000000e+00*S68+6.415124e-04*S69'
.param V17_part8='V17_part7+(-2.714735e-03)*S70+0.000000e+00*S71+0.000000e+00*S72+(-1.886760e-05)*S73+0.000000e+00*S74+7.245375e-04*S75+(-3.983508e-02)*S76+0.000000e+00*S77+1.321897e-03*S78+(-2.005683e-02)*S79'
.param V17='V17_part8+0.000000e+00*S80+(-1.988665e-03)*S81+(-1.785305e-02)*S82+0.000000e+00*S83+0.000000e+00*S84+(-1.536049e-02)*S85+0.000000e+00*S86+(-4.558553e-03)*S87+(-1.711657e-02)*S88+(-5.174194e-02)*S89'
.param V18_part1='9.034048e-02*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+3.852307e-02*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V18_part2='V18_part1+3.910759e-02*S10+1.393408e-02*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+2.279211e+01*S15+0.000000e+00*S16+0.000000e+00*S17+3.711626e+01*S18+0.000000e+00*S19'
.param V18_part3='V18_part2+0.000000e+00*S20+1.086229e+01*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+8.690740e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V18_part4='V18_part3+0.000000e+00*S30+0.000000e+00*S31+(-1.127080e-02)*S32+3.022660e-02*S33+3.748468e-02*S34+0.000000e+00*S35+3.132725e-02*S36+3.287609e-02*S37+2.984706e-02*S38+1.910478e+01*S39'
.param V18_part5='V18_part4+3.240455e-02*S40+3.907178e-02*S41+3.538034e-02*S42+0.000000e+00*S43+4.163888e-02*S44+8.882352e-03*S45+(-3.452368e-05)*S46+2.435820e-02*S47+1.305249e-02*S48+0.000000e+00*S49'
.param V18_part6='V18_part5+4.717665e-03*S50+1.454885e-02*S51+1.525379e-02*S52+0.000000e+00*S53+1.448572e-02*S54+0.000000e+00*S55+0.000000e+00*S56+1.505636e-02*S57+1.890341e-02*S58+0.000000e+00*S59'
.param V18_part7='V18_part6+0.000000e+00*S60+5.608989e-02*S61+0.000000e+00*S62+5.712888e-02*S63+(-2.733214e-04)*S64+(-1.211902e+01)*S65+0.000000e+00*S66+1.274600e-04*S67+0.000000e+00*S68+1.632706e-03*S69'
.param V18_part8='V18_part7+(-2.561149e-04)*S70+0.000000e+00*S71+0.000000e+00*S72+(-2.461140e-04)*S73+0.000000e+00*S74+(-3.572896e-03)*S75+4.917561e-03*S76+0.000000e+00*S77+(-1.062674e-03)*S78+(-1.116380e-03)*S79'
.param V18='V18_part8+0.000000e+00*S80+(-1.416211e-03)*S81+1.623298e-02*S82+0.000000e+00*S83+0.000000e+00*S84+3.310557e-03*S85+0.000000e+00*S86+5.810493e-02*S87+3.157315e-03*S88+1.531163e-02*S89'
.param V19_part1='(-4.943221e-03)*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+(-4.759313e-03)*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V19_part2='V19_part1+(-9.309589e-04)*S10+1.001670e-03*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+3.445807e+00*S15+0.000000e+00*S16+0.000000e+00*S17+4.293050e-01*S18+0.000000e+00*S19'
.param V19_part3='V19_part2+0.000000e+00*S20+(-5.168596e+00)*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+(-1.016349e-02)*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V19_part4='V19_part3+0.000000e+00*S30+0.000000e+00*S31+6.999014e-03*S32+6.884168e-04*S33+(-1.062012e-02)*S34+0.000000e+00*S35+(-2.571730e-02)*S36+(-3.621295e-03)*S37+(-5.136977e-03)*S38+(-1.419543e+01)*S39'
.param V19_part5='V19_part4+(-1.322910e-02)*S40+(-1.130288e-03)*S41+(-1.784825e-02)*S42+0.000000e+00*S43+2.473940e-03*S44+3.706733e-02*S45+6.654479e-03*S46+1.867844e-02*S47+4.345046e-02*S48+0.000000e+00*S49'
.param V19_part6='V19_part5+3.977530e-02*S50+5.047662e-02*S51+4.303451e-02*S52+0.000000e+00*S53+4.632471e-02*S54+0.000000e+00*S55+0.000000e+00*S56+4.979135e-02*S57+4.627279e-02*S58+0.000000e+00*S59'
.param V19_part7='V19_part6+0.000000e+00*S60+1.296507e-02*S61+0.000000e+00*S62+2.121515e-02*S63+2.551884e-02*S64+(-4.956681e+00)*S65+0.000000e+00*S66+1.992705e-02*S67+0.000000e+00*S68+1.494166e-03*S69'
.param V19_part8='V19_part7+2.809260e-03*S70+0.000000e+00*S71+0.000000e+00*S72+2.721646e-03*S73+0.000000e+00*S74+(-1.790648e-02)*S75+(-9.174882e-03)*S76+0.000000e+00*S77+(-2.427354e-02)*S78+3.102798e-02*S79'
.param V19='V19_part8+0.000000e+00*S80+4.792166e-02*S81+1.594995e-02*S82+0.000000e+00*S83+0.000000e+00*S84+4.037918e-02*S85+0.000000e+00*S86+5.454618e-02*S87+3.928332e-02*S88+3.540567e-02*S89'
.param V20_part1='4.341012e-02*S0+2.483850e-02*S1+1.206314e-02*S2+2.595015e-02*S3+3.837269e-02*S4+(-1.145030e-02)*S5+2.511975e-02*S6+3.273694e+00*S7+(-1.101008e-02)*S8+5.219064e-04*S9'
.param V20_part2='V20_part1+2.339272e+01*S10+(-2.353728e-01)*S11+1.885824e-02*S12+2.067271e-02*S13+1.745460e-02*S14+5.526783e-02*S15+1.197101e-01*S16+1.928934e-01*S17+1.193903e-01*S18+1.202372e-01*S19'
.param V20_part3='V20_part2+(-7.778156e-02)*S20+(-7.194383e-03)*S21+1.516224e-01*S22+2.266885e-01*S23+1.982487e+00*S24+4.230877e-01*S25+7.202720e-02*S26+6.179153e+00*S27+1.702748e-01*S28+1.449940e-01*S29'
.param V20_part4='V20_part3+6.602247e-01*S30+6.831570e+00*S31+2.012639e+00*S32+1.797908e+01*S33+7.550498e+00*S34+2.442974e-01*S35+6.433050e+00*S36+9.361684e+00*S37+2.399898e-02*S38+2.489250e+03*S39'
.param V20_part5='V20_part4+1.541758e+00*S40+1.464313e-02*S41+4.070958e+01*S42+(-8.189288e-02)*S43+(-6.568689e-01)*S44+(-5.005859e+03)*S45+5.370375e-01*S46+1.163937e-01*S47+(-5.017415e+03)*S48+2.541898e+00*S49'
.param V20_part6='V20_part5+1.419539e-01*S50+(-5.034563e+03)*S51+(-5.036705e+03)*S52+1.536731e-02*S53+(-5.075542e+03)*S54+(-5.031585e+03)*S55+(-1.075746e-01)*S56+(-5.086040e+03)*S57+(-4.917942e+03)*S58+(-1.542684e-01)*S59'
.param V20_part7='V20_part6+(-7.161184e+02)*S60+2.059850e+02*S61+2.892499e-01*S62+7.367836e+02*S63+(-5.011749e+03)*S64+(-1.365168e-01)*S65+(-4.993064e+03)*S66+(-5.003452e+03)*S67+7.777880e-01*S68+(-5.070783e+03)*S69'
.param V20_part8='V20_part7+(-4.818886e+03)*S70+5.282042e-01*S71+(-5.101122e+03)*S72+(-5.011804e+03)*S73+(-1.304033e+00)*S74+(-1.014331e+03)*S75+1.000000e+04*S76+(-5.723722e-02)*S77+1.000000e+04*S78+1.000000e+04*S79'
.param V20='V20_part8+3.460106e+02*S80+1.000000e+04*S81+1.000000e+04*S82+2.313696e+02*S83+1.000000e+04*S84+1.000000e+04*S85+2.944638e+02*S86+1.000000e+04*S87+1.000000e+04*S88+1.000000e+04*S89'
.param V21_part1='2.984216e-01*S0+1.598302e-01*S1+8.984671e-02*S2+1.822552e-01*S3+2.397618e-01*S4+1.338030e-01*S5+1.206840e-01*S6+1.812297e+01*S7+1.242117e-01*S8+1.413526e-01*S9'
.param V21_part2='V21_part1+5.591449e+01*S10+1.025254e+00*S11+1.675294e-01*S12+1.395320e-01*S13+1.120050e-01*S14+5.566150e-01*S15+5.074060e-01*S16+3.657322e-01*S17+5.484542e-01*S18+5.340257e-01*S19'
.param V21_part3='V21_part2+1.271148e+00*S20+5.360958e-01*S21+8.639786e-01*S22+5.392044e-01*S23+2.720086e+00*S24+4.374298e-01*S25+6.103127e-01*S26+7.077336e+00*S27+6.113999e-01*S28+5.915733e-01*S29'
.param V21_part4='V21_part3+2.876862e+00*S30+1.221919e+01*S31+5.002090e+00*S32+(-1.508299e+01)*S33+(-5.813137e-01)*S34+1.358917e+00*S35+(-5.002828e+00)*S36+3.721899e+00*S37+1.767773e+00*S38+2.068574e+03*S39'
.param V21_part5='V21_part4+1.396694e+01*S40+1.958505e+00*S41+(-2.809784e+01)*S42+1.150652e+00*S43+2.880219e+00*S44+8.029045e+01*S45+3.740350e+00*S46+2.556843e+00*S47+5.243918e+01*S48+2.574215e+00*S49'
.param V21_part6='V21_part5+2.701759e+00*S50+8.376379e+01*S51+3.931286e+01*S52+3.163788e+00*S53+1.263198e+02*S54+4.341204e+01*S55+3.700534e+00*S56+1.112977e+02*S57+1.044186e-01*S58+3.889058e+00*S59'
.param V21_part7='V21_part6+3.746978e+02*S60+(-8.124804e+01)*S61+4.627188e+00*S62+8.010414e+01*S63+1.234962e+01*S64+2.502721e+00*S65+5.071761e+00*S66+(-5.759089e+00)*S67+5.846562e+00*S68+2.965140e+02*S69'
.param V21_part8='V21_part7+(-1.566451e+02)*S70+6.070573e+00*S71+2.161464e+02*S72+(-1.341741e+01)*S73+9.542851e+00*S74+4.587013e+02*S75+7.688097e+02*S76+2.912865e+00*S77+1.077735e+03*S78+5.327405e+02*S79'
.param V21='V21_part8+5.150741e+00*S80+2.139571e+02*S81+5.408649e+02*S82+3.346300e+02*S83+2.042718e+02*S84+1.994854e+02*S85+7.557485e+01*S86+1.598189e+02*S87+2.796916e+02*S88+2.041148e+02*S89'
.param V22_part1='(-6.750010e-02)*S0+(-8.495497e-04)*S1+4.585352e-03*S2+(-3.919055e-02)*S3+(-7.669032e-03)*S4+2.116373e-02*S5+(-3.081569e-02)*S6+(-1.393459e+00)*S7+6.859978e-03*S8+(-3.829516e-02)*S9'
.param V22_part2='V22_part1+2.243894e+01*S10+7.139222e-02*S11+(-6.774093e-02)*S12+(-4.340843e-02)*S13+(-1.932574e-02)*S14+3.339209e-02*S15+5.225475e-02*S16+(-2.177005e-02)*S17+(-1.612868e-02)*S18+2.764358e-02*S19'
.param V22_part3='V22_part2+1.632252e-01*S20+(-5.762051e-02)*S21+(-6.847672e-02)*S22+(-2.213399e-02)*S23+(-9.327743e-02)*S24+(-4.900927e-02)*S25+6.520390e-02*S26+(-7.405382e-01)*S27+(-6.578168e-02)*S28+3.229987e-02*S29'
.param V22_part4='V22_part3+(-1.549468e-01)*S30+(-2.833435e+00)*S31+4.996513e-02*S32+1.631326e+00*S33+(-1.802966e+00)*S34+1.865422e-01*S35+9.544305e-01*S36+(-6.251658e-01)*S37+2.017567e-01*S38+1.538427e+03*S39'
.param V22_part5='V22_part4+6.412003e-01*S40+1.480486e-01*S41+4.444713e+00*S42+5.581339e-03*S43+2.191889e-01*S44+(-1.976629e+00)*S45+1.032607e+00*S46+8.176477e-01*S47+4.127413e+01*S48+1.225627e+00*S49'
.param V22_part6='V22_part5+7.802485e-01*S50+3.081030e+01*S51+9.909375e+01*S52+7.343889e-01*S53+1.564180e+02*S54+2.099788e+02*S55+6.433753e-01*S56+2.045086e+02*S57+(-4.176267e+01)*S58+5.425967e-01*S59'
.param V22_part7='V22_part6+6.776698e+01*S60+(-8.580861e+01)*S61+1.843769e+00*S62+6.014361e+01*S63+9.253711e+01*S64+9.141924e-01*S65+1.810034e+02*S66+1.650322e+02*S67+1.511077e+00*S68+5.446407e+01*S69'
.param V22_part8='V22_part7+5.367458e+01*S70+1.503491e+00*S71+5.902913e+01*S72+2.279704e+02*S73+1.608892e+00*S74+1.011312e+02*S75+9.167911e+02*S76+1.451743e+00*S77+7.095538e+02*S78+7.585657e+02*S79'
.param V22='V22_part8+8.482645e+00*S80+2.622120e+02*S81+9.529622e+02*S82+(-1.344373e+02)*S83+2.485973e+02*S84+3.550292e+02*S85+(-1.343065e+02)*S86+1.842549e+02*S87+3.760675e+02*S88+2.968106e+02*S89'
.param V23_part1='1.109862e-02*S0+2.322068e-02*S1+1.318839e-02*S2+2.559529e-02*S3+5.664536e-02*S4+1.215999e-02*S5+7.454731e-03*S6+1.695657e+01*S7+1.150770e-02*S8+1.489779e-02*S9'
.param V23_part2='V23_part1+(-5.793786e+01)*S10+1.842470e-01*S11+2.074365e-02*S12+1.637410e-02*S13+1.176904e-02*S14+7.037819e-02*S15+9.699303e-02*S16+(-5.109444e-03)*S17+1.008690e-01*S18+1.020132e-01*S19'
.param V23_part3='V23_part2+8.020611e-02*S20+3.103311e-02*S21+(-3.658737e-02)*S22+(-2.564117e-02)*S23+6.015090e-01*S24+6.434273e-02*S25+1.057703e-01*S26+2.112477e+00*S27+7.065430e-02*S28+1.244613e-01*S29'
.param V23_part4='V23_part3+(-1.961106e-01)*S30+(-1.639599e+00)*S31+(-4.622411e-01)*S32+1.327825e-01*S33+(-6.599000e-01)*S34+(-7.254064e-02)*S35+5.411016e-02*S36+(-1.145720e+00)*S37+(-1.074984e-01)*S38+6.164162e+01*S39'
.param V23_part5='V23_part4+(-7.849028e-01)*S40+(-1.481060e-01)*S41+4.758013e-01*S42+6.659253e-02*S43+(-1.864563e-01)*S44+(-1.660642e+00)*S45+(-1.168440e-01)*S46+(-8.973745e-02)*S47+(-3.783959e+00)*S48+(-2.444566e-01)*S49'
.param V23_part6='V23_part5+(-1.617255e-01)*S50+(-5.808742e+00)*S51+(-6.907016e+00)*S52+(-2.411599e-01)*S53+5.848183e+00*S54+(-1.886689e-01)*S55+(-3.424512e-01)*S56+5.774801e+00*S57+5.779418e+00*S58+(-4.273150e-01)*S59'
.param V23_part7='V23_part6+9.327485e+00*S60+(-3.279960e+01)*S61+(-3.199654e-01)*S62+(-5.448359e+00)*S63+(-2.576787e+00)*S64+1.025196e-01*S65+5.317991e+00*S66+1.607909e+00*S67+(-5.593688e-01)*S68+5.560270e+00*S69'
.param V23_part8='V23_part7+(-1.757831e+01)*S70+(-3.783049e-01)*S71+(-2.886984e+00)*S72+6.641260e+00*S73+(-1.729147e-01)*S74+1.186930e+01*S75+(-2.097408e+00)*S76+3.614086e-02*S77+(-6.678100e+01)*S78+(-8.418903e+00)*S79'
.param V23='V23_part8+(-3.546195e+01)*S80+(-1.063058e+01)*S81+(-1.458225e+01)*S82+(-7.603757e+01)*S83+(-1.795451e+00)*S84+(-1.581424e+00)*S85+(-3.305582e+01)*S86+4.075982e-01*S87+(-1.390943e+00)*S88+5.102049e+00*S89'
.param V24_part1='9.473950e-03*S0+2.096981e-03*S1+1.905689e-03*S2+9.915711e-04*S3+1.382269e-03*S4+2.835073e-03*S5+2.243613e-03*S6+(-1.535336e-02)*S7+1.960166e-03*S8+1.307920e-03*S9'
.param V24_part2='V24_part1+2.355110e+00*S10+1.433281e-02*S11+1.416727e-03*S12+2.013247e-03*S13+1.882393e-03*S14+6.807717e-03*S15+4.414818e-03*S16+7.944183e-05*S17+(-1.039621e-03)*S18+(-5.510518e-03)*S19'
.param V24_part3='V24_part2+4.853369e-03*S20+1.252659e-02*S21+4.442571e-02*S22+9.385116e-03*S23+(-1.486208e-01)*S24+(-3.958369e-02)*S25+(-1.636223e-02)*S26+(-7.177462e-01)*S27+(-2.175972e-02)*S28+(-3.063811e-02)*S29'
.param V24_part4='V24_part3+(-2.273849e-03)*S30+1.074688e+00*S31+2.676137e-01*S32+(-1.430770e+00)*S33+(-2.707971e-01)*S34+2.216255e-02*S35+(-4.012624e-01)*S36+(-2.162267e-01)*S37+2.476154e-02*S38+(-1.860591e+03)*S39'
.param V24_part5='V24_part4+3.933371e-01*S40+2.765556e-02*S41+(-2.566766e+00)*S42+3.066049e-02*S43+3.923411e-02*S44+1.000000e+04*S45+(-1.035059e-02)*S46+1.887905e-02*S47+1.000000e+04*S48+(-3.562170e-01)*S49'
.param V24_part6='V24_part5+2.731107e-02*S50+1.000000e+04*S51+1.000000e+04*S52+2.100963e-02*S53+1.000000e+04*S54+1.000000e+04*S55+(-8.512429e-02)*S56+1.000000e+04*S57+1.000000e+04*S58+(-2.687712e-02)*S59'
.param V24_part7='V24_part6+1.527119e+03*S60+(-8.807007e+00)*S61+9.075443e-02*S62+(-4.809895e+02)*S63+1.000000e+04*S64+7.859300e-02*S65+1.000000e+04*S66+1.000000e+04*S67+(-1.454922e-02)*S68+1.000000e+04*S69'
.param V24_part8='V24_part7+1.000000e+04*S70+(-6.514910e-02)*S71+1.000000e+04*S72+1.000000e+04*S73+(-1.424305e-01)*S74+2.012183e+03*S75+(-6.875178e+03)*S76+9.743176e-02*S77+(-6.803683e+03)*S78+(-6.857916e+03)*S79'
.param V24='V24_part8+1.622560e+01*S80+(-6.676220e+03)*S81+(-6.887646e+03)*S82+4.519347e+01*S83+(-6.718335e+03)*S84+(-6.770715e+03)*S85+(-2.222946e+01)*S86+(-6.720778e+03)*S87+(-6.839281e+03)*S88+(-6.839338e+03)*S89'
.param V25_part1='(-2.025697e+00)*S0+(-2.858033e-02)*S1+(-3.821742e-03)*S2+(-1.283733e-01)*S3+5.563219e-01*S4+(-2.347273e-02)*S5+(-1.813151e-01)*S6+(-5.494504e+01)*S7+(-4.963806e-02)*S8+(-2.321195e-01)*S9'
.param V25_part2='V25_part1+1.604633e+03*S10+(-1.578344e+01)*S11+(-2.762286e-01)*S12+(-1.688826e-01)*S13+(-8.296080e-02)*S14+7.073604e-01*S15+1.211551e+00*S16+2.379604e-02*S17+4.710297e-01*S18+8.724125e-01*S19'
.param V25_part3='V25_part2+1.887518e+00*S20+5.182515e-01*S21+(-2.121133e-01)*S22+(-6.707813e-02)*S23+(-4.962037e-01)*S24+1.439085e+00*S25+1.561710e+00*S26+(-6.661512e-01)*S27+1.109081e+00*S28+1.571008e+00*S29'
.param V25_part4='V25_part3+(-1.241166e-01)*S30+(-2.206613e-02)*S31+1.158042e-01*S32+(-4.972527e-01)*S33+(-1.043840e-01)*S34+4.354801e-02*S35+(-6.124113e-01)*S36+(-3.179019e-01)*S37+(-4.505364e-02)*S38+(-9.247303e-01)*S39'
.param V25_part5='V25_part4+(-6.062580e-01)*S40+(-1.052781e-01)*S41+(-1.874400e+00)*S42+1.312265e+00*S43+(-2.306157e-01)*S44+(-3.160940e-02)*S45+5.231481e-02*S46+2.495903e-01*S47+(-6.023347e-01)*S48+(-2.174280e-01)*S49'
.param V25_part6='V25_part5+1.332833e-01*S50+(-1.134779e+00)*S51+(-2.608168e-01)*S52+3.594492e-02*S53+(-1.723409e+00)*S54+(-5.481940e-01)*S55+(-1.179187e-01)*S56+(-2.431291e+00)*S57+(-8.417700e-01)*S58+(-2.874255e-01)*S59'
.param V25_part7='V25_part6+(-2.268752e-01)*S60+8.486437e-02*S61+3.540679e-01*S62+(-1.419908e+00)*S63+(-1.303921e-01)*S64+5.587296e+00*S65+(-1.934022e+00)*S66+(-5.697908e-01)*S67+5.505347e-02*S68+(-2.789844e+00)*S69'
.param V25_part8='V25_part7+(-1.018949e+00)*S70+2.127754e-03*S71+(-3.768465e+00)*S72+(-1.505334e+00)*S73+(-3.302222e-01)*S74+(-4.192654e-01)*S75+2.012388e-01*S76+7.341277e+00*S77+(-1.880083e+00)*S78+(-3.083996e-01)*S79'
.param V25='V25_part8+4.044699e-01*S80+(-2.972928e+00)*S81+(-1.074119e+00)*S82+2.959500e-01*S83+(-4.231188e+00)*S84+(-1.682346e+00)*S85+(-4.246019e-01)*S86+(-5.269029e+00)*S87+(-2.218187e+00)*S88+(-6.422463e-03)*S89'
.param V26_part1='2.994068e+00*S0+2.367180e-01*S1+1.031089e-01*S2+3.399079e-01*S3+4.242393e+00*S4+1.171988e-01*S5+3.323230e-01*S6+8.833962e+02*S7+1.269166e-01*S8+3.303691e-01*S9'
.param V26_part2='V26_part1+2.926320e+03*S10+4.022662e+01*S11+3.222940e-01*S12+2.243792e-01*S13+1.175291e-01*S14+2.048589e+00*S15+1.488615e+00*S16+2.256863e-01*S17+1.954258e+00*S18+1.313783e+00*S19'
.param V26_part3='V26_part2+1.576373e-03*S20+1.835002e+00*S21+6.368513e-01*S22+2.963675e-01*S23+7.848766e-01*S24+7.707163e-02*S25+4.430458e-01*S26+8.276960e-01*S27+6.874068e-01*S28+4.040808e-01*S29'
.param V26_part4='V26_part3+1.209416e+00*S30+7.575075e-01*S31+4.148538e-01*S32+1.489010e+00*S33+9.441621e-01*S34+4.433422e-01*S35+1.264509e+00*S36+1.027170e+00*S37+4.761057e-01*S38+2.841158e+00*S39'
.param V26_part5='V26_part4+1.106531e+00*S40+4.538383e-01*S41+1.702169e+00*S42+1.282550e+00*S43+4.994296e-01*S44+2.117929e+00*S45+1.199565e+00*S46+5.851935e-01*S47+2.560756e+00*S48+1.473601e+00*S49'
.param V26_part6='V26_part5+6.074837e-01*S50+2.685349e+00*S51+1.770482e+00*S52+5.999367e-01*S53+2.689528e+00*S54+1.761823e+00*S55+7.045507e-01*S56+2.820928e+00*S57+1.682309e+00*S58+7.085457e-01*S59'
.param V26_part7='V26_part6+3.357406e+00*S60+1.793326e+00*S61+7.598084e-01*S62+3.672020e+00*S63+2.399593e+00*S64+1.154159e+00*S65+3.656560e+00*S66+2.499493e+00*S67+8.365746e-01*S68+3.740598e+00*S69'
.param V26_part8='V26_part7+2.441704e+00*S70+7.585874e-01*S71+4.020589e+00*S72+2.352191e+00*S73+9.081371e-01*S74+4.313675e+00*S75+2.664682e+00*S76+(-1.780095e-01)*S77+4.726523e+00*S78+3.014483e+00*S79'
.param V26='V26_part8+1.085232e+00*S80+4.579310e+00*S81+3.309375e+00*S82+1.039765e+00*S83+4.751704e+00*S84+3.170286e+00*S85+8.829789e-01*S86+4.786994e+00*S87+2.874289e+00*S88+1.537225e+00*S89'
.param V27_part1='1.220029e+00*S0+4.057062e-02*S1+4.606605e-02*S2+6.143098e-02*S3+2.222756e-01*S4+6.051524e-02*S5+7.959909e-02*S6+5.440867e+01*S7+8.039945e-02*S8+9.706409e-02*S9'
.param V27_part2='V27_part1+(-1.291649e+02)*S10+1.205882e+01*S11+1.147985e-01*S12+1.087687e-01*S13+1.180662e-01*S14+2.121995e-01*S15+1.819211e-01*S16+1.293395e-01*S17+2.493118e-01*S18+3.075875e-01*S19'
.param V27_part3='V27_part2+3.911814e-01*S20+2.533771e-01*S21+1.743631e-01*S22+1.855641e-01*S23+2.412987e-01*S24+5.382261e-01*S25+4.895461e-01*S26+2.847676e-01*S27+5.269871e-01*S28+4.802820e-01*S29'
.param V27_part4='V27_part3+2.014386e-01*S30+1.988463e-01*S31+1.769647e-01*S32+2.818582e-01*S33+2.211453e-01*S34+2.421670e-01*S35+3.098900e-01*S36+3.021920e-01*S37+3.069636e-01*S38+4.389214e-01*S39'
.param V27_part5='V27_part4+3.900712e-01*S40+3.787837e-01*S41+6.530518e-01*S42+6.203322e-01*S43+4.612840e-01*S44+2.750455e-01*S45+2.504281e-01*S46+2.382021e-01*S47+4.229814e-01*S48+3.162545e-01*S49'
.param V27_part6='V27_part5+3.356445e-01*S50+5.975408e-01*S51+4.260062e-01*S52+4.317019e-01*S53+8.295259e-01*S54+5.807667e-01*S55+5.176625e-01*S56+1.053967e+00*S57+7.449506e-01*S58+6.669003e-01*S59'
.param V27_part7='V27_part6+4.189531e-01*S60+3.383780e-01*S61+3.612585e-01*S62+7.017053e-01*S63+4.367018e-01*S64+(-7.295345e-01)*S65+9.812347e-01*S66+6.310501e-01*S67+6.487026e-01*S68+1.316679e+00*S69'
.param V27_part8='V27_part7+8.752307e-01*S70+7.505252e-01*S71+1.625761e+00*S72+1.158548e+00*S73+9.688890e-01*S74+5.863298e-01*S75+4.202962e-01*S76+(-7.688283e-01)*S77+9.627585e-01*S78+6.013229e-01*S79'
.param V27='V27_part8+5.938609e-01*S80+1.398058e+00*S81+8.906088e-01*S82+7.411635e-01*S83+1.842307e+00*S84+1.204527e+00*S85+1.162339e+00*S86+2.270968e+00*S87+1.594655e+00*S88+9.072534e-01*S89'
.param V28_part1='1.656014e-01*S0+3.025927e-02*S1+1.777579e-02*S2+4.375478e-02*S3+1.316078e+00*S4+1.737217e-02*S5+4.371400e-02*S6+7.051179e+02*S7+1.691674e-02*S8+4.198577e-02*S9'
.param V28_part2='V28_part1+(-2.513611e+03)*S10+6.689215e+00*S11+4.288792e-02*S12+2.735039e-02*S13+1.731280e-02*S14+7.641673e-01*S15+7.873326e-01*S16+1.158417e-02*S17+7.172621e-01*S18+6.878024e-01*S19'
.param V28_part3='V28_part2+4.505536e-01*S20+6.354675e-01*S21+2.704120e-02*S22+1.205510e-02*S23+8.234732e-02*S24+4.325047e-02*S25+5.567164e-01*S26+8.547755e-02*S27+7.528195e-02*S28+5.490171e-01*S29'
.param V28_part4='V28_part3+3.221072e-02*S30+3.062936e-02*S31+1.234461e-02*S32+6.345164e-02*S33+4.208321e-02*S34+8.402177e-03*S35+7.298489e-02*S36+4.556825e-02*S37+7.897815e-03*S38+6.595192e-01*S39'
.param V28_part5='V28_part4+5.784116e-02*S40+1.032978e-02*S41+1.004950e-01*S42+2.044938e-01*S43+1.117987e-02*S44+2.342533e-02*S45+3.557569e-02*S46+1.055788e-02*S47+(-1.033813e-02)*S48+2.917353e-02*S49'
.param V28_part6='V28_part5+1.311571e-02*S50+(-6.386788e-02)*S51+(-1.422419e-02)*S52+9.794518e-03*S53+(-1.561357e-01)*S54+(-4.226675e-02)*S55+8.231825e-03*S56+(-2.101679e-01)*S57+(-6.878889e-02)*S58+9.806474e-04*S59'
.param V28_part7='V28_part6+1.151133e-02*S60+3.409599e-02*S61+3.870659e-03*S62+(-2.262233e-02)*S63+2.059735e-02*S64+6.984085e-01*S65+(-1.163367e-01)*S66+(-1.401148e-02)*S67+(-4.625189e-05)*S68+(-2.082686e-01)*S69'
.param V28_part8='V28_part7+(-6.621101e-02)*S70+(-2.071087e-04)*S71+(-3.213723e-01)*S72+(-1.003846e-01)*S73+3.130759e-02*S74+(-1.555814e-02)*S75+2.807409e-02*S76+6.947785e-01*S77+(-9.069857e-02)*S78+(-7.382502e-03)*S79'
.param V28='V28_part8+3.296370e-02*S80+(-1.761403e-01)*S81+(-6.320064e-02)*S82+1.034910e-02*S83+(-3.156369e-01)*S84+(-1.223615e-01)*S85+7.327413e-02*S86+(-4.988397e-01)*S87+(-1.709608e-01)*S88+(-9.165752e-02)*S89'
.param V29_part1='1.071050e-01*S0+2.371635e-03*S1+1.350142e-03*S2+3.212894e-03*S3+6.772585e-03*S4+1.397879e-03*S5+3.308222e-03*S6+(-1.580307e+00)*S7+1.124322e-03*S8+3.128435e-03*S9'
.param V29_part2='V29_part1+1.205955e+02*S10+4.611287e-01*S11+2.976815e-03*S12+1.917749e-03*S13+8.988556e-04*S14+1.772709e-03*S15+(-8.184699e-03)*S16+8.735920e-03*S17+9.338236e-03*S18+5.187478e-02*S19'
.param V29_part3='V29_part2+(-1.349231e-02)*S20+(-1.252409e-01)*S21+2.651215e-02*S22+1.043581e-02*S23+5.221517e-02*S24+7.882145e-02*S25+(-3.017009e-03)*S26+6.384924e-02*S27+3.899800e-02*S28+1.631831e-02*S29'
.param V29_part4='V29_part3+1.135898e-01*S30+4.666160e-02*S31+2.246445e-02*S32+1.425861e-01*S33+6.503420e-02*S34+2.713443e-02*S35+1.405215e-01*S36+7.596435e-02*S37+3.081763e-02*S38+3.240181e-01*S39'
.param V29_part5='V29_part4+1.109222e-01*S40+3.145983e-02*S41+3.751825e-01*S42+(-5.173481e-01)*S43+3.298810e-02*S44+1.026399e-01*S45+1.105300e-01*S46+4.469755e-02*S47+8.231909e-02*S48+1.548696e-01*S49'
.param V29_part6='V29_part5+4.839093e-02*S50+4.634505e-02*S51+4.062669e-02*S52+5.399915e-02*S53+5.690304e-03*S54+1.139159e-02*S55+4.691051e-02*S56+4.825527e-05*S57+7.526301e-03*S58+5.221945e-02*S59'
.param V29_part7='V29_part6+1.872226e-01*S60+2.126058e-01*S61+8.548648e-02*S62+4.061007e-01*S63+1.610674e-01*S64+(-1.768577e-01)*S65+1.066181e-01*S66+1.291876e-01*S67+7.736007e-02*S68+3.894362e-02*S69'
.param V29_part8='V29_part7+9.807693e-02*S70+7.571551e-02*S71+2.327657e-02*S72+6.485149e-02*S73+5.747555e-02*S74+2.994816e-01*S75+3.473007e-01*S76+(-1.639151e-01)*S77+4.659043e-01*S78+3.422514e-01*S79'
.param V29='V29_part8+8.268920e-02*S80+4.187444e-01*S81+3.206962e-01*S82+5.453100e-02*S83+4.221455e-01*S84+3.237674e-01*S85+1.631412e-01*S86+3.976685e-01*S87+2.842414e-01*S88+7.179048e-02*S89'
.param V30_part1='1.231206e-01*S0+6.353947e-03*S1+1.963763e-02*S2+(-3.790271e-02)*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+7.083973e-02*S8+7.919088e-02*S9'
.param V30_part2='V30_part1+0.000000e+00*S10+0.000000e+00*S11+(-6.160978e-02)*S12+(-5.785702e-02)*S13+(-3.712531e-02)*S14+(-3.893979e-02)*S15+(-2.876159e-02)*S16+3.044881e+01*S17+(-1.977675e-02)*S18+(-2.401073e-03)*S19'
.param V30_part3='V30_part2+0.000000e+00*S20+0.000000e+00*S21+8.389025e+00*S22+2.106480e-01*S23+9.141600e-03*S24+0.000000e+00*S25+(-3.782032e-02)*S26+(-3.319790e-02)*S27+0.000000e+00*S28+(-4.392372e-02)*S29'
.param V30_part4='V30_part3+2.585941e+01*S30+0.000000e+00*S31+5.750026e-01*S32+3.689794e+00*S33+7.449811e-01*S34+1.153581e+00*S35+(-1.250924e-01)*S36+(-1.926452e+00)*S37+(-2.487307e+00)*S38+0.000000e+00*S39'
.param V30_part5='V30_part4+0.000000e+00*S40+(-3.325196e+00)*S41+(-2.731028e-01)*S42+0.000000e+00*S43+(-8.628798e+00)*S44+0.000000e+00*S45+2.995426e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V30_part6='V30_part5+2.530861e+01*S50+0.000000e+00*S51+(-2.224823e+02)*S52+0.000000e+00*S53+1.149949e+02*S54+(-6.732734e+01)*S55+0.000000e+00*S56+0.000000e+00*S57+(-1.491958e+02)*S58+0.000000e+00*S59'
.param V30_part7='V30_part6+4.209230e+01*S60+0.000000e+00*S61+0.000000e+00*S62+2.355309e+01*S63+(-6.267151e+02)*S64+(-3.119241e-02)*S65+6.093780e+01*S66+1.000000e+04*S67+0.000000e+00*S68+(-9.369161e+01)*S69'
.param V30_part8='V30_part7+1.086655e+03*S70+6.959138e+01*S71+(-5.855759e+02)*S72+1.000000e+04*S73+2.273603e+00*S74+0.000000e+00*S75+(-1.440437e+02)*S76+0.000000e+00*S77+3.969067e-01*S78+(-1.120916e+02)*S79'
.param V30='V30_part8+2.758887e+00*S80+0.000000e+00*S81+1.385478e+01*S82+0.000000e+00*S83+0.000000e+00*S84+(-1.607241e+03)*S85+(-1.918702e+02)*S86+0.000000e+00*S87+(-1.414488e+03)*S88+7.696302e+02*S89'
.param V31_part1='5.379954e-02*S0+1.291217e-02*S1+5.539267e-02*S2+9.083591e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+4.846884e-03*S8+3.568006e-02*S9'
.param V31_part2='V31_part1+0.000000e+00*S10+0.000000e+00*S11+1.064151e-01*S12+9.916114e-02*S13+7.867143e-02*S14+1.059519e-01*S15+7.903486e-02*S16+(-2.641441e+01)*S17+6.509350e-02*S18+2.907963e-02*S19'
.param V31_part3='V31_part2+0.000000e+00*S20+0.000000e+00*S21+3.622258e-01*S22+8.553468e-01*S23+4.599822e-02*S24+0.000000e+00*S25+5.904053e-02*S26+8.666617e-02*S27+0.000000e+00*S28+6.512861e-02*S29'
.param V31_part4='V31_part3+(-2.605866e+01)*S30+0.000000e+00*S31+(-5.248524e+00)*S32+6.415433e-01*S33+5.384735e-01*S34+9.889209e+00*S35+3.343878e-01*S36+8.296802e-01*S37+(-4.167925e-01)*S38+0.000000e+00*S39'
.param V31_part5='V31_part4+0.000000e+00*S40+(-8.551137e-01)*S41+2.087439e+00*S42+0.000000e+00*S43+7.761499e-01*S44+0.000000e+00*S45+(-2.721343e+01)*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V31_part6='V31_part5+2.870747e+01*S50+0.000000e+00*S51+(-2.336908e+00)*S52+0.000000e+00*S53+(-6.654285e+01)*S54+2.746347e-01*S55+0.000000e+00*S56+0.000000e+00*S57+(-5.938844e+01)*S58+0.000000e+00*S59'
.param V31_part7='V31_part6+2.965699e+01*S60+0.000000e+00*S61+0.000000e+00*S62+(-8.916914e-02)*S63+(-6.267151e+02)*S64+1.293957e-01*S65+(-3.296443e+01)*S66+1.000000e+04*S67+0.000000e+00*S68+1.427386e+02*S69'
.param V31_part8='V31_part7+4.846565e+02*S70+(-9.100311e-01)*S71+(-8.585563e+01)*S72+7.997288e+03*S73+(-6.348423e-02)*S74+0.000000e+00*S75+4.133428e+01*S76+0.000000e+00*S77+2.066268e+01*S78+7.681151e+01*S79'
.param V31='V31_part8+3.663980e+01*S80+0.000000e+00*S81+1.070063e+01*S82+0.000000e+00*S83+0.000000e+00*S84+4.473709e+01*S85+(-5.394536e+01)*S86+0.000000e+00*S87+(-1.320868e+02)*S88+2.291061e+01*S89'
.param V32_part1='(-2.569290e-01)*S0+1.649368e-02*S1+1.036715e-02*S2+2.584279e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+(-5.576126e-02)*S8+(-1.078801e-01)*S9'
.param V32_part2='V32_part1+0.000000e+00*S10+0.000000e+00*S11+(-7.087018e-03)*S12+6.919572e-03*S13+(-2.154748e-03)*S14+3.850320e-04*S15+6.492422e-03*S16+(-3.794901e+00)*S17+(-4.059057e-03)*S18+(-1.339657e-02)*S19'
.param V32_part3='V32_part2+0.000000e+00*S20+0.000000e+00*S21+1.010257e+00*S22+1.445155e+01*S23+6.053761e-01*S24+0.000000e+00*S25+3.049730e-02*S26+5.793114e-01*S27+0.000000e+00*S28+3.262789e-02*S29'
.param V32_part4='V32_part3+(-2.262781e+00)*S30+0.000000e+00*S31+1.522407e+01*S32+1.685109e+00*S33+6.103824e+00*S34+1.235403e+01*S35+9.769800e-01*S36+2.132971e+01*S37+2.055295e+01*S38+0.000000e+00*S39'
.param V32_part5='V32_part4+0.000000e+00*S40+2.140156e+01*S41+9.615585e+00*S42+0.000000e+00*S43+2.293615e+01*S44+0.000000e+00*S45+3.674441e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V32_part6='V32_part5+3.511051e+00*S50+0.000000e+00*S51+6.877688e+02*S52+0.000000e+00*S53+2.569682e+01*S54+1.863065e+02*S55+0.000000e+00*S56+0.000000e+00*S57+6.916644e+02*S58+0.000000e+00*S59'
.param V32_part7='V32_part6+8.223046e+01*S60+0.000000e+00*S61+0.000000e+00*S62+7.218588e+01*S63+9.277462e+03*S64+(-5.275837e-02)*S65+2.740382e+02*S66+1.000000e+04*S67+0.000000e+00*S68+6.849983e+02*S69'
.param V32_part8='V32_part7+1.000000e+04*S70+(-2.049987e+00)*S71+3.051059e+03*S72+1.000000e+04*S73+5.996789e+01*S74+0.000000e+00*S75+4.340893e+02*S76+0.000000e+00*S77+1.290515e+02*S78+3.650713e+02*S79'
.param V32='V32_part8+5.607640e+01*S80+0.000000e+00*S81+1.116147e+02*S82+0.000000e+00*S83+0.000000e+00*S84+4.261012e+03*S85+5.502225e+01*S86+0.000000e+00*S87+4.225339e+03*S88+3.180528e+03*S89'
.param V33_part1='6.306909e-02*S0+6.760134e-02*S1+5.865248e-02*S2+5.014680e-02*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+2.122431e-02*S8+3.542317e-02*S9'
.param V33_part2='V33_part1+0.000000e+00*S10+0.000000e+00*S11+1.626149e-02*S12+1.278480e-02*S13+1.654326e-02*S14+1.340443e-02*S15+1.244020e-02*S16+1.915986e+01*S17+4.188955e-03*S18+9.950397e-03*S19'
.param V33_part3='V33_part2+0.000000e+00*S20+0.000000e+00*S21+3.484896e+01*S22+1.934942e+01*S23+3.235506e-01*S24+0.000000e+00*S25+1.362119e-02*S26+3.033150e-01*S27+0.000000e+00*S28+2.044021e-03*S29'
.param V33_part4='V33_part3+1.919709e+01*S30+0.000000e+00*S31+1.495550e+01*S32+1.633025e+01*S33+2.315796e+01*S34+1.655274e+01*S35+4.850175e-01*S36+2.783125e+01*S37+2.419568e+01*S38+0.000000e+00*S39'
.param V33_part5='V33_part4+0.000000e+00*S40+2.616870e+01*S41+1.600062e+01*S42+0.000000e+00*S43+2.466459e+01*S44+0.000000e+00*S45+5.413242e+01*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V33_part6='V33_part5+1.112546e+01*S50+0.000000e+00*S51+7.582667e+01*S52+0.000000e+00*S53+9.073373e+01*S54+2.630422e+01*S55+0.000000e+00*S56+0.000000e+00*S57+1.172041e+02*S58+0.000000e+00*S59'
.param V33_part7='V33_part6+1.062562e+02*S60+0.000000e+00*S61+0.000000e+00*S62+8.127746e+01*S63+1.000000e+04*S64+3.251980e-02*S65+9.860434e+01*S66+1.000000e+04*S67+0.000000e+00*S68+3.014906e+02*S69'
.param V33_part8='V33_part7+4.446674e+02*S70+(-3.447311e+01)*S71+9.810995e+01*S72+9.949467e+03*S73+2.562555e+00*S74+0.000000e+00*S75+9.393522e+01*S76+0.000000e+00*S77+2.401872e+01*S78+1.174638e+02*S79'
.param V33='V33_part8+4.346962e+01*S80+0.000000e+00*S81+4.878708e+01*S82+0.000000e+00*S83+0.000000e+00*S84+4.080723e+02*S85+3.593792e+01*S86+0.000000e+00*S87+4.159208e+02*S88+(-2.780157e+03)*S89'
.param V34_part1='(-5.646228e-03)*S0+(-7.218940e-04)*S1+(-3.724923e-06)*S2+1.225464e-03*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+4.086253e-05*S8+(-8.164594e-05)*S9'
.param V34_part2='V34_part1+0.000000e+00*S10+0.000000e+00*S11+1.524092e-03*S12+1.250453e-03*S13+1.051723e-03*S14+1.911304e-02*S15+1.711905e-02*S16+(-9.224361e-01)*S17+1.720511e-02*S18+1.946549e-02*S19'
.param V34_part3='V34_part2+0.000000e+00*S20+0.000000e+00*S21+8.202494e-03*S22+(-4.245025e-01)*S23+8.417808e-02*S24+0.000000e+00*S25+1.275416e-02*S26+9.962247e-02*S27+0.000000e+00*S28+8.368881e-03*S29'
.param V34_part4='V34_part3+(-5.424136e-01)*S30+0.000000e+00*S31+1.452484e+00*S32+3.867506e-01*S33+5.951484e+00*S34+1.992410e-01*S35+2.043669e-01*S36+1.215523e+00*S37+8.664392e-01*S38+0.000000e+00*S39'
.param V34_part5='V34_part4+0.000000e+00*S40+1.045073e+00*S41+1.678572e+00*S42+0.000000e+00*S43+2.204637e+00*S44+0.000000e+00*S45+2.752822e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V34_part6='V34_part5+2.164437e+00*S50+0.000000e+00*S51+1.044077e+00*S52+0.000000e+00*S53+(-3.281328e-02)*S54+1.954149e-02*S55+0.000000e+00*S56+0.000000e+00*S57+(-5.276256e+00)*S58+0.000000e+00*S59'
.param V34_part7='V34_part6+(-1.102518e+01)*S60+0.000000e+00*S61+0.000000e+00*S62+2.528910e+01*S63+1.752924e+03*S64+5.850577e-02*S65+(-4.069949e+01)*S66+3.229805e+02*S67+0.000000e+00*S68+(-5.835985e+01)*S69'
.param V34_part8='V34_part7+1.743624e+01*S70+1.035258e-01*S71+(-2.304079e+01)*S72+2.877144e+02*S73+1.438083e+01*S74+0.000000e+00*S75+5.592028e+01*S76+0.000000e+00*S77+5.981556e+01*S78+4.930842e+01*S79'
.param V34='V34_part8+9.519458e+00*S80+0.000000e+00*S81+1.834054e+01*S82+0.000000e+00*S83+0.000000e+00*S84+8.367466e+01*S85+4.362544e+02*S86+0.000000e+00*S87+5.824604e+01*S88+3.840199e+01*S89'
.param V35_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+2.032616e-02*S4+1.597235e-02*S5+(-3.886738e-02)*S6+8.602934e-02*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V35_part2='V35_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-1.070213e-02)*S18+0.000000e+00*S19'
.param V35_part3='V35_part2+5.959649e-04*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+(-1.985253e-02)*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+(-1.303528e-02)*S29'
.param V35_part4='V35_part3+0.000000e+00*S30+3.047527e+01*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V35_part5='V35_part4+7.594646e+00*S40+0.000000e+00*S41+0.000000e+00*S42+4.198754e-02*S43+0.000000e+00*S44+1.796232e+01*S45+0.000000e+00*S46+3.932761e+01*S47+1.801226e+02*S48+3.933114e+01*S49'
.param V35_part6='V35_part5+0.000000e+00*S50+1.949070e+02*S51+0.000000e+00*S52+6.715046e+00*S53+0.000000e+00*S54+0.000000e+00*S55+1.026558e+01*S56+2.001188e+02*S57+0.000000e+00*S58+(-1.330972e+01)*S59'
.param V35_part7='V35_part6+0.000000e+00*S60+(-3.291151e+00)*S61+7.746439e+01*S62+0.000000e+00*S63+(-6.267151e+02)*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+(-9.364317e+01)*S68+0.000000e+00*S69'
.param V35_part8='V35_part7+6.058747e+02*S70+0.000000e+00*S71+0.000000e+00*S72+9.997502e+03*S73+0.000000e+00*S74+6.324972e+01*S75+0.000000e+00*S76+1.508090e-01*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V35='V35_part8+0.000000e+00*S80+5.430745e+02*S81+1.205773e+01*S82+1.152414e+02*S83+9.655137e+02*S84+0.000000e+00*S85+0.000000e+00*S86+1.051671e+03*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V36_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-9.751092e-02)*S4+(-2.927920e-02)*S5+1.050171e-01*S6+2.927607e-01*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V36_part2='V36_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+2.046984e-02*S18+0.000000e+00*S19'
.param V36_part3='V36_part2+1.442673e-02*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+(-2.034915e-03)*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+1.221053e-02*S29'
.param V36_part4='V36_part3+0.000000e+00*S30+(-1.686134e+01)*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V36_part5='V36_part4+8.836896e-01*S40+0.000000e+00*S41+0.000000e+00*S42+1.702158e-01*S43+0.000000e+00*S44+(-4.550437e+00)*S45+0.000000e+00*S46+(-1.085704e+01)*S47+1.062381e+00*S48+(-7.724075e+00)*S49'
.param V36_part6='V36_part5+0.000000e+00*S50+1.116500e+00*S51+0.000000e+00*S52+1.644194e+01*S53+0.000000e+00*S54+0.000000e+00*S55+(-2.075232e+00)*S56+(-5.696433e+01)*S57+0.000000e+00*S58+(-9.600426e+00)*S59'
.param V36_part7='V36_part6+0.000000e+00*S60+(-2.038667e+01)*S61+(-1.607681e+01)*S62+0.000000e+00*S63+(-6.267151e+02)*S64+0.000000e+00*S65+0.000000e+00*S66+1.000000e+04*S67+(-7.708007e+00)*S68+0.000000e+00*S69'
.param V36_part8='V36_part7+5.183580e+02*S70+0.000000e+00*S71+0.000000e+00*S72+8.553394e+03*S73+0.000000e+00*S74+6.957125e+01*S75+0.000000e+00*S76+(-1.995393e-01)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V36='V36_part8+0.000000e+00*S80+(-6.509786e+02)*S81+1.561145e+01*S82+2.162477e+01*S83+(-6.813227e+02)*S84+0.000000e+00*S85+0.000000e+00*S86+(-2.506634e+02)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V37_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+1.829957e-02*S4+2.319038e-02*S5+7.422099e-03*S6+1.079405e-01*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V37_part2='V37_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+(-2.664485e-03)*S18+0.000000e+00*S19'
.param V37_part3='V37_part2+(-2.640873e-03)*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+3.086240e-03*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+3.024771e-03*S29'
.param V37_part4='V37_part3+0.000000e+00*S30+(-5.256301e+00)*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V37_part5='V37_part4+(-1.778056e+00)*S40+0.000000e+00*S41+0.000000e+00*S42+5.292624e-03*S43+0.000000e+00*S44+1.027777e+01*S45+0.000000e+00*S46+1.134436e+01*S47+(-3.827423e+01)*S48+5.031230e+00*S49'
.param V37_part6='V37_part5+0.000000e+00*S50+(-4.148555e+01)*S51+0.000000e+00*S52+2.742751e+01*S53+0.000000e+00*S54+0.000000e+00*S55+2.649869e+01*S56+(-1.143199e+01)*S57+0.000000e+00*S58+5.655263e+01*S59'
.param V37_part7='V37_part6+0.000000e+00*S60+(-1.659667e-02)*S61+2.600881e+01*S62+0.000000e+00*S63+(-3.476950e+02)*S64+0.000000e+00*S65+0.000000e+00*S66+1.621432e+02*S67+1.573825e+02*S68+0.000000e+00*S69'
.param V37_part8='V37_part7+8.753372e+00*S70+0.000000e+00*S71+0.000000e+00*S72+1.121696e+02*S73+0.000000e+00*S74+9.426816e+00*S75+0.000000e+00*S76+(-5.281782e-02)*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V37='V37_part8+0.000000e+00*S80+1.750463e+01*S81+8.849569e-01*S82+(-4.596509e+01)*S83+(-1.502319e+01)*S84+0.000000e+00*S85+0.000000e+00*S86+(-1.948652e+02)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V38_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+6.403359e-02*S4+5.040254e-02*S5+4.744347e-02*S6+(-4.578127e-01)*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V38_part2='V38_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+9.238163e-03*S18+0.000000e+00*S19'
.param V38_part3='V38_part2+1.070230e-02*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+9.292176e-03*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+1.726326e-02*S29'
.param V38_part4='V38_part3+0.000000e+00*S30+2.679151e+01*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V38_part5='V38_part4+1.621069e+01*S40+0.000000e+00*S41+0.000000e+00*S42+4.258040e-02*S43+0.000000e+00*S44+5.179964e+01*S45+0.000000e+00*S46+7.822571e+00*S47+1.080639e+02*S48+5.614632e+01*S49'
.param V38_part6='V38_part5+0.000000e+00*S50+1.162109e+02*S51+0.000000e+00*S52+1.057689e+01*S53+0.000000e+00*S54+0.000000e+00*S55+(-6.815550e+00)*S56+1.018817e+02*S57+0.000000e+00*S58+7.514796e+00*S59'
.param V38_part7='V38_part6+0.000000e+00*S60+6.647191e+01*S61+(-3.403782e+00)*S62+0.000000e+00*S63+1.000000e+04*S64+0.000000e+00*S65+0.000000e+00*S66+8.295344e+03*S67+(-3.679735e+00)*S68+0.000000e+00*S69'
.param V38_part8='V38_part7+2.977717e+02*S70+0.000000e+00*S71+0.000000e+00*S72+6.662664e+03*S73+0.000000e+00*S74+1.169661e+02*S75+0.000000e+00*S76+5.086919e-02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V38='V38_part8+0.000000e+00*S80+3.368736e+02*S81+1.920512e+00*S82+4.973037e+01*S83+1.003009e+03*S84+0.000000e+00*S85+0.000000e+00*S86+1.815994e+02*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V39_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+(-1.729410e-03)*S4+(-1.894005e-03)*S5+1.185303e-06*S6+1.265309e-02*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V39_part2='V39_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+4.000823e-03*S18+0.000000e+00*S19'
.param V39_part3='V39_part2+1.356665e-02*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+2.479987e-02*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+1.003408e-02*S29'
.param V39_part4='V39_part3+0.000000e+00*S30+2.701813e-02*S31+0.000000e+00*S32+0.000000e+00*S33+0.000000e+00*S34+0.000000e+00*S35+0.000000e+00*S36+0.000000e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V39_part5='V39_part4+2.054493e+00*S40+0.000000e+00*S41+0.000000e+00*S42+(-8.406604e-03)*S43+0.000000e+00*S44+6.608087e-01*S45+0.000000e+00*S46+(-3.204399e+00)*S47+2.911274e-01*S48+(-2.134268e-02)*S49'
.param V39_part6='V39_part5+0.000000e+00*S50+4.044269e-01*S51+0.000000e+00*S52+(-6.120628e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+8.104116e-01*S56+(-2.442182e+01)*S57+0.000000e+00*S58+(-1.162331e+00)*S59'
.param V39_part7='V39_part6+0.000000e+00*S60+6.280121e+01*S61+(-4.125086e+01)*S62+0.000000e+00*S63+9.325310e+03*S64+0.000000e+00*S65+0.000000e+00*S66+2.404306e+03*S67+(-1.706625e+01)*S68+0.000000e+00*S69'
.param V39_part8='V39_part7+1.297975e+02*S70+0.000000e+00*S71+0.000000e+00*S72+2.141781e+03*S73+0.000000e+00*S74+8.159249e-01*S75+0.000000e+00*S76+2.368026e-02*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V39='V39_part8+0.000000e+00*S80+3.907884e+00*S81+1.997488e+00*S82+7.499023e+00*S83+2.154270e+01*S84+0.000000e+00*S85+0.000000e+00*S86+5.821867e+01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V40_part1='1.602293e+00*S0+2.202280e-01*S1+7.917592e-01*S2+2.301444e-02*S3+5.370264e-01*S4+8.906671e+00*S5+2.706537e-01*S6+9.160433e-02*S7+7.481700e+03*S8+1.708308e+00*S9'
.param V40_part2='V40_part1+3.543816e-02*S10+(-8.883132e+00)*S11+5.241824e-01*S12+3.251332e+01*S13+1.620617e+03*S14+(-3.188452e-01)*S15+(-5.030651e-01)*S16+(-2.880163e-01)*S17+(-4.035905e-01)*S18+(-4.488345e-01)*S19'
.param V40_part3='V40_part2+7.558815e-01*S20+8.785758e+00*S21+(-8.486678e-01)*S22+(-4.318741e-01)*S23+(-2.024893e-01)*S24+(-2.252548e-01)*S25+(-6.378417e+00)*S26+(-2.025340e+00)*S27+3.195032e-02*S28+(-2.053137e+00)*S29'
.param V40_part4='V40_part3+1.168730e+00*S30+(-2.565511e+00)*S31+(-1.040315e+00)*S32+(-8.820867e-01)*S33+(-7.885774e-01)*S34+(-1.849114e+00)*S35+(-1.376534e+00)*S36+(-8.151863e-01)*S37+1.254478e+01*S38+(-7.780037e+02)*S39'
.param V40_part5='V40_part4+(-5.034229e-01)*S40+6.896183e+00*S41+(-2.022752e+00)*S42+7.124709e+02*S43+5.355582e+00*S44+3.626941e+02*S45+1.912017e+00*S46+(-2.195841e+02)*S47+6.279107e+01*S48+1.075371e-01*S49'
.param V40_part6='V40_part5+1.000000e+04*S50+9.033301e+03*S51+1.456974e+02*S52+1.000000e+04*S53+3.291504e+01*S54+1.275050e+01*S55+1.000000e+04*S56+1.363302e+02*S57+1.282420e+02*S58+1.000000e+04*S59'
.param V40_part7='V40_part6+1.000000e+04*S60+(-3.069032e+00)*S61+1.000000e+04*S62+4.077884e+02*S63+1.000000e+04*S64+1.039566e+03*S65+1.000000e+04*S66+1.000000e+04*S67+1.000000e+04*S68+6.689346e+03*S69'
.param V40_part8='V40_part7+1.000000e+04*S70+1.000000e+04*S71+1.000000e+04*S72+1.000000e+04*S73+(-7.273645e+01)*S74+1.000000e+04*S75+1.000000e+04*S76+4.070979e+01*S77+1.000000e+04*S78+6.800679e+01*S79'
.param V40='V40_part8+(-5.347442e+00)*S80+1.300773e+03*S81+2.290378e+01*S82+(-4.132838e+00)*S83+1.000000e+04*S84+7.844524e+03*S85+(-1.066714e+01)*S86+1.000000e+04*S87+1.000000e+04*S88+1.000000e+04*S89'
.param V41_part1='2.425030e+00*S0+3.268251e+00*S1+5.304698e+00*S2+6.840991e-01*S3+2.547984e+00*S4+(-2.416003e-01)*S5+1.517063e+00*S6+6.424066e-01*S7+3.896235e+01*S8+8.338344e-01*S9'
.param V41_part2='V41_part1+5.776714e-01*S10+2.198015e+01*S11+1.876462e+00*S12+2.154103e+01*S13+4.554242e+02*S14+3.651268e+00*S15+3.701682e+00*S16+5.144369e+00*S17+2.608984e+00*S18+3.357710e+00*S19'
.param V41_part3='V41_part2+(-2.132908e-01)*S20+7.509010e+02*S21+3.658503e+00*S22+2.676219e+00*S23+1.900489e-01*S24+1.564720e+00*S25+1.405503e+01*S26+6.127143e-01*S27+2.354452e+00*S28+5.566829e+00*S29'
.param V41_part4='V41_part3+2.725833e+01*S30+3.895599e-01*S31+7.142676e-02*S32+1.531315e+00*S33+9.432696e-01*S34+1.291779e+01*S35+2.617551e+00*S36+4.925415e-01*S37+(-7.886707e-01)*S38+(-2.627022e+01)*S39'
.param V41_part5='V41_part4+1.279709e-01*S40+(-1.188060e+00)*S41+2.283127e+00*S42+(-5.511862e+02)*S43+(-2.259308e+00)*S44+1.000000e+04*S45+2.644005e+01*S46+1.225030e+03*S47+2.730422e+03*S48+2.329941e+00*S49'
.param V41_part6='V41_part5+1.000000e+04*S50+1.000000e+04*S51+4.158272e+00*S52+1.000000e+04*S53+9.946377e+02*S54+6.950257e-01*S55+1.000000e+04*S56+4.119671e+03*S57+2.637921e+03*S58+1.000000e+04*S59'
.param V41_part7='V41_part6+1.000000e+04*S60+1.334146e+00*S61+1.000000e+04*S62+3.904053e+02*S63+1.000000e+04*S64+1.000000e+04*S65+2.791504e+03*S66+1.000000e+04*S67+1.000000e+04*S68+1.000000e+04*S69'
.param V41_part8='V41_part7+1.000000e+04*S70+1.000000e+04*S71+1.000000e+04*S72+1.000000e+04*S73+1.107878e+02*S74+1.000000e+04*S75+1.000000e+04*S76+(-7.475615e+01)*S77+1.000000e+04*S78+1.419309e+00*S79'
.param V41='V41_part8+1.411406e-01*S80+(-4.348209e+00)*S81+(-4.600276e+00)*S82+(-2.554632e+00)*S83+1.044653e+02*S84+1.248688e+02*S85+(-1.693463e+00)*S86+1.000000e+04*S87+1.000000e+04*S88+1.000000e+04*S89'
.param V42_part1='(-1.609826e+00)*S0+5.809129e-01*S1+3.804995e-01*S2+2.271960e-01*S3+4.890369e-01*S4+(-1.186540e-01)*S5+(-5.337699e-01)*S6+5.198747e-01*S7+1.457454e+01*S8+2.430480e+00*S9'
.param V42_part2='V42_part1+3.886479e-01*S10+1.010555e+01*S11+1.523114e+00*S12+1.560620e+01*S13+3.341155e+02*S14+1.290178e+00*S15+8.954184e-01*S16+5.144241e-01*S17+6.187287e-01*S18+6.526321e-01*S19'
.param V42_part3='V42_part2+3.418197e-05*S20+1.803645e+02*S21+8.162080e-01*S22+1.920266e-01*S23+(-8.925647e-02)*S24+1.051855e-01*S25+5.206160e-01*S26+(-1.011699e-01)*S27+9.026427e-02*S28+6.670321e-01*S29'
.param V42_part4='V42_part3+2.105541e+00*S30+4.398050e-01*S31+2.846728e-01*S32+6.867569e-03*S33+4.026563e-01*S34+8.181017e-01*S35+(-2.268836e-02)*S36+1.347218e-01*S37+7.895166e-02*S38+1.000000e+04*S39'
.param V42_part5='V42_part4+(-1.656040e-01)*S40+(-4.064322e-03)*S41+(-2.255656e-01)*S42+(-1.084083e+02)*S43+(-1.893565e-01)*S44+1.937128e+03*S45+(-5.745951e-01)*S46+3.785769e+01*S47+3.353635e+02*S48+1.861583e-01*S49'
.param V42_part6='V42_part5+9.152628e+03*S50+1.000000e+04*S51+2.486101e+00*S52+1.000000e+04*S53+2.736661e+01*S54+(-1.431137e+00)*S55+1.000000e+04*S56+1.364787e+02*S57+5.202856e+01*S58+1.000000e+04*S59'
.param V42_part7='V42_part6+1.000000e+04*S60+1.706224e+00*S61+1.000000e+04*S62+9.129296e+01*S63+1.000000e+04*S64+1.000000e+04*S65+3.570604e+03*S66+1.000000e+04*S67+1.000000e+04*S68+1.000000e+04*S69'
.param V42_part8='V42_part7+2.925232e+03*S70+1.000000e+04*S71+1.000000e+04*S72+1.000000e+04*S73+(-8.876336e-01)*S74+1.000000e+04*S75+1.000000e+04*S76+7.154231e+00*S77+1.000000e+04*S78+(-1.853465e+00)*S79'
.param V42='V42_part8+1.564343e+00*S80+1.164809e+02*S81+(-7.008625e+00)*S82+2.965088e+00*S83+1.420069e+03*S84+3.628811e+02*S85+5.567981e+00*S86+1.000000e+04*S87+1.000000e+04*S88+2.385492e+03*S89'
.param V43_part1='8.221125e-01*S0+(-1.754825e-01)*S1+(-8.555959e-01)*S2+(-1.721982e-01)*S3+(-2.658099e-01)*S4+1.080722e+01*S5+2.560203e-01*S6+1.018362e-02*S7+(-1.000000e+04)*S8+(-9.108544e-01)*S9'
.param V43_part2='V43_part1+2.255717e-01*S10+(-1.213720e+01)*S11+(-9.012262e-01)*S12+(-6.515990e+01)*S13+(-2.735742e+02)*S14+(-1.470501e-01)*S15+(-6.527816e-02)*S16+(-8.146314e-02)*S17+(-1.309201e-01)*S18+(-1.036959e-01)*S19'
.param V43_part3='V43_part2+9.673928e-02*S20+(-2.838544e+00)*S21+(-6.925317e-02)*S22+6.065706e-03*S23+2.962673e-02*S24+2.667900e-02*S25+3.195894e-02*S26+(-9.386948e-03)*S27+(-1.169630e-03)*S28+1.303801e-02*S29'
.param V43_part4='V43_part3+(-7.599870e-01)*S30+2.245954e-01*S31+9.749915e-02*S32+2.405109e-02*S33+8.898248e-02*S34+(-3.060528e-01)*S35+4.000826e-02*S36+8.930666e-02*S37+3.189174e-01*S38+(-1.030955e+03)*S39'
.param V43_part5='V43_part4+5.056998e-02*S40+2.816165e-01*S41+(-5.954963e-02)*S42+(-2.981521e+00)*S43+7.187100e-04*S44+1.312653e+03*S45+(-1.240126e+00)*S46+(-9.490348e+01)*S47+6.914347e+01*S48+(-1.133880e-01)*S49'
.param V43_part6='V43_part5+2.877386e+03*S50+4.479673e+01*S51+4.575467e-01*S52+(-6.127069e+03)*S53+(-1.988531e+00)*S54+(-1.704557e+00)*S55+(-1.000000e+04)*S56+(-3.371159e-04)*S57+(-3.552034e+00)*S58+4.990724e+00*S59'
.param V43_part7='V43_part6+(-1.000000e+04)*S60+2.098366e-01*S61+6.678710e+01*S62+(-2.586350e-01)*S63+1.693061e+02*S64+3.222885e+03*S65+(-7.485856e+00)*S66+(-2.948965e+02)*S67+(-5.213486e-02)*S68+1.546641e+01*S69'
.param V43_part8='V43_part7+3.234833e+01*S70+(-1.780224e-01)*S71+(-4.498888e+03)*S72+(-3.506320e+01)*S73+1.364788e-01*S74+1.000000e+04*S75+(-4.549853e+03)*S76+3.830616e-01*S77+(-2.112236e+03)*S78+(-2.926112e-02)*S79'
.param V43='V43_part8+4.537611e-02*S80+7.976871e-01*S81+(-1.706645e-01)*S82+2.999185e-01*S83+(-1.982548e+01)*S84+(-3.972987e+01)*S85+6.019095e-01*S86+2.472698e+03*S87+6.795685e+02*S88+1.775090e+03*S89'
.param V44_part1='(-1.080514e-01)*S0+1.122747e-01*S1+1.736404e-01*S2+5.449355e-02*S3+1.702103e-01*S4+(-3.456646e-01)*S5+1.605531e-02*S6+1.517534e-02*S7+2.546570e+00*S8+1.842715e-01*S9'
.param V44_part2='V44_part1+4.942599e-03*S10+4.324725e-01*S11+1.005275e-01*S12+1.076691e+00*S13+2.247012e+02*S14+1.348884e-01*S15+1.195146e-01*S16+1.574607e-01*S17+9.306873e-02*S18+1.330452e-01*S19'
.param V44_part3='V44_part2+(-3.668234e-02)*S20+(-4.650355e+00)*S21+1.902000e-01*S22+9.213037e-02*S23+(-1.059223e-01)*S24+6.555062e-02*S25+3.842461e-01*S26+(-2.269348e-01)*S27+5.453936e-02*S28+1.891642e-01*S29'
.param V44_part4='V44_part3+9.449111e-01*S30+(-3.459345e-01)*S31+(-1.010397e-01)*S32+(-5.438518e-02)*S33+(-4.682664e-02)*S34+2.636364e-01*S35+(-1.610469e-02)*S36+(-8.368077e-02)*S37+1.402606e-01*S38+(-4.462197e+01)*S39'
.param V44_part5='V44_part4+(-1.126550e-01)*S40+7.338152e-02*S41+6.234680e-02*S42+(-4.958972e+01)*S43+(-1.067312e-01)*S44+5.751843e+02*S45+6.626299e-01*S46+4.198225e+01*S47+8.689798e+01*S48+1.644362e-01*S49'
.param V44_part6='V44_part5+5.764815e+01*S50+1.000000e+04*S51+1.461259e+01*S52+(-1.000000e+04)*S53+4.139955e+01*S54+(-2.608941e+00)*S55+5.092910e+03*S56+1.056605e+01*S57+3.650514e+02*S58+1.517298e+00*S59'
.param V44_part7='V44_part6+1.000000e+04*S60+(-1.955494e-01)*S61+1.863464e+02*S62+5.514074e+01*S63+1.000000e+04*S64+8.257682e+03*S65+3.561387e+03*S66+1.000000e+04*S67+(-8.007405e-02)*S68+1.000000e+04*S69'
.param V44_part8='V44_part7+1.303505e+03*S70+(-3.169896e-01)*S71+1.000000e+04*S72+1.000000e+04*S73+3.659070e+00*S74+1.000000e+04*S75+1.000000e+04*S76+(-4.559445e+00)*S77+1.000000e+04*S78+3.178630e+00*S79'
.param V44='V44_part8+(-3.228398e-01)*S80+(-1.509001e+00)*S81+2.763191e+00*S82+(-6.649683e-01)*S83+9.262831e+01*S84+1.132160e+02*S85+5.030646e-01*S86+1.000000e+04*S87+1.000000e+04*S88+1.000000e+04*S89'
.param V45_part1='4.564000e-02*S0+(-7.270983e-01)*S1+(-2.084187e+00)*S2+(-5.613781e-02)*S3+(-3.176992e-01)*S4+1.080659e+00*S5+(-7.186354e-01)*S6+2.264055e-01*S7+2.712414e+00*S8+3.307940e+00*S9'
.param V45_part2='V45_part1+(-3.351352e-02)*S10+3.143788e-01*S11+5.064090e-01*S12+1.311034e-01*S13+5.499208e-01*S14+(-1.198961e+03)*S15+1.000000e+04*S16+6.596864e+00*S17+(-1.866699e+02)*S18+9.668814e+03*S19'
.param V45_part3='V45_part2+6.765339e+03*S20+2.376438e+00*S21+2.613587e+01*S22+1.000000e+04*S23+8.711613e+02*S24+1.961454e+01*S25+3.127601e+01*S26+6.648368e+01*S27+7.295830e+00*S28+7.908538e+03*S29'
.param V45_part4='V45_part3+8.687700e+00*S30+3.779835e+03*S31+3.014636e+02*S32+1.000000e+04*S33+6.308135e+02*S34+1.851111e+00*S35+1.000000e+04*S36+1.000000e+04*S37+6.814722e+01*S38+(-9.288411e+01)*S39'
.param V45_part5='V45_part4+1.000000e+04*S40+1.847180e+02*S41+1.000000e+04*S42+9.369233e+02*S43+8.852151e+02*S44+2.039419e-01*S45+1.257540e+03*S46+1.831914e+00*S47+3.675086e-01*S48+3.823376e+00*S49'
.param V45_part6='V45_part5+2.096794e+00*S50+3.145233e-01*S51+5.645041e-01*S52+1.803879e+00*S53+1.174443e-01*S54+2.775726e-01*S55+1.794843e+00*S56+1.492207e-01*S57+6.009391e-01*S58+1.685710e+00*S59'
.param V45_part7='V45_part6+(-2.081972e+00)*S60+1.000000e+04*S61+6.270059e-01*S62+3.632674e-01*S63+3.229380e-01*S64+4.616296e-01*S65+(-8.344603e-02)*S66+4.692808e-02*S67+3.110506e-04*S68+(-2.964246e-01)*S69'
.param V45_part8='V45_part7+(-6.906869e-02)*S70+1.062130e-03*S71+(-9.598999e-02)*S72+1.929719e-01*S73+3.065456e-02*S74+(-1.137930e+00)*S75+(-3.981046e-02)*S76+1.306006e+00*S77+(-2.472273e-01)*S78+2.139746e-01*S79'
.param V45='V45_part8+4.360408e+01*S80+5.688397e-01*S81+(-6.539069e-03)*S82+4.118898e+01*S83+7.955270e-01*S84+9.984804e-01*S85+(-4.835894e+01)*S86+1.040938e+00*S87+8.657414e-01*S88+1.272932e+00*S89'
.param V46_part1='1.364185e+00*S0+3.560398e-01*S1+7.536433e+00*S2+1.100125e+00*S3+(-5.290156e-01)*S4+4.974262e-01*S5+3.740956e+00*S6+1.289136e+00*S7+(-9.722776e-01)*S8+3.596096e-01*S9'
.param V46_part2='V46_part1+1.608206e+00*S10+8.079322e-01*S11+2.004105e-01*S12+5.242366e-01*S13+7.846785e-01*S14+(-5.150427e+01)*S15+3.208955e+03*S16+(-1.752130e+00)*S17+(-1.825682e+01)*S18+1.708322e+03*S19'
.param V46_part3='V46_part2+(-8.725088e-03)*S20+(-1.374779e+00)*S21+(-2.521250e+01)*S22+1.000000e+04*S23+1.609883e+01*S24+(-1.175922e+01)*S25+(-2.233194e+01)*S26+1.761556e+02*S27+(-1.791449e+00)*S28+4.290685e+03*S29'
.param V46_part4='V46_part3+(-1.812542e+01)*S30+3.779835e+03*S31+2.135601e+02*S32+8.031094e+03*S33+1.000000e+04*S34+(-1.163544e+00)*S35+1.000000e+04*S36+1.000000e+04*S37+1.298309e+00*S38+2.236174e+01*S39'
.param V46_part5='V46_part4+1.000000e+04*S40+3.519160e+00*S41+1.000000e+04*S42+1.396476e+03*S43+5.029072e+01*S44+7.757177e-01*S45+(-8.603094e+02)*S46+3.583525e-01*S47+4.554244e-01*S48+1.622949e-01*S49'
.param V46_part6='V46_part5+8.911017e-01*S50+3.826727e-01*S51+3.069516e-01*S52+6.535502e-01*S53+4.037223e-01*S54+3.256817e-01*S55+4.703179e-01*S56+3.392261e-01*S57+(-1.008281e-03)*S58+5.189759e-01*S59'
.param V46_part7='V46_part6+8.622632e-01*S60+1.000000e+04*S61+1.250156e+00*S62+2.762870e-01*S63+6.649207e-01*S64+1.584930e+00*S65+8.588555e-01*S66+7.628891e-01*S67+1.164191e+00*S68+4.478507e-01*S69'
.param V46_part8='V46_part7+7.308146e-01*S70+1.254648e+00*S71+3.769420e-01*S72+4.868155e-01*S73+2.969647e+00*S74+5.998038e-01*S75+1.642554e-01*S76+6.822430e-01*S77+3.885612e-01*S78+7.457888e-02*S79'
.param V46='V46_part8+2.220618e+01*S80+2.694499e-01*S81+1.966923e-01*S82+3.595843e+01*S83+1.873626e-01*S84+(-1.527247e-01)*S85+2.967609e+02*S86+5.852469e-02*S87+(-6.434681e-02)*S88+(-4.439250e-01)*S89'
.param V47_part1='(-1.442673e+00)*S0+(-7.242889e-01)*S1+1.904730e+00*S2+1.472395e+00*S3+(-5.484193e-01)*S4+(-1.053429e+00)*S5+2.153269e+00*S6+1.151267e+00*S7+(-9.361588e-01)*S8+(-1.723525e+00)*S9'
.param V47_part2='V47_part1+1.181434e+00*S10+2.771430e-01*S11+(-1.674953e-01)*S12+2.747231e-01*S13+3.929262e-01*S14+9.523989e+03*S15+1.000000e+04*S16+(-1.291408e+00)*S17+8.838700e+02*S18+2.442982e+03*S19'
.param V47_part3='V47_part2+(-6.546368e+03)*S20+(-3.760414e-02)*S21+(-3.853999e+00)*S22+1.000000e+04*S23+(-2.973875e+02)*S24+(-5.345665e+00)*S25+(-8.100996e-01)*S26+(-1.406539e+01)*S27+(-1.053828e+00)*S28+9.982718e+02*S29'
.param V47_part4='V47_part3+(-1.845927e+00)*S30+3.779835e+03*S31+2.911846e+01*S32+2.965440e+03*S33+6.948988e+02*S34+7.138347e-01*S35+1.000000e+04*S36+1.000000e+04*S37+1.945181e+01*S38+(-1.086354e+01)*S39'
.param V47_part5='V47_part4+1.000000e+04*S40+5.272555e+01*S41+1.000000e+04*S42+2.890511e+03*S43+(-9.139093e+02)*S44+4.653314e-01*S45+9.285706e+02*S46+(-6.912650e-01)*S47+8.548166e-03*S48+1.727922e+00*S49'
.param V47_part6='V47_part5+(-1.144095e+00)*S50+(-6.940561e-03)*S51+(-2.483175e-01)*S52+(-5.187271e-01)*S53+(-4.416290e-01)*S54+(-4.470467e-01)*S55+(-3.826589e-01)*S56+(-4.956682e-01)*S57+1.539512e-02*S58+(-2.819839e-01)*S59'
.param V47_part7='V47_part6+7.016928e-01*S60+1.000000e+04*S61+(-2.341474e-01)*S62+3.669278e-01*S63+2.590746e-03*S64+(-3.607420e-01)*S65+(-2.498708e-01)*S66+(-9.018329e-02)*S67+2.557359e-01*S68+(-1.018060e-01)*S69'
.param V47_part8='V47_part7+(-5.298944e-02)*S70+1.381631e-01*S71+3.080043e-03*S72+(-3.177137e-01)*S73+1.033227e-01*S74+8.035155e-01*S75+6.729673e-01*S76+2.205052e-01*S77+2.705327e-01*S78+4.903986e-01*S79'
.param V47='V47_part8+(-1.524948e+01)*S80+2.399296e-01*S81+4.138385e-01*S82+(-2.901010e+01)*S83+1.473792e-01*S84+1.389778e-01*S85+(-2.003261e+01)*S86+1.593650e-01*S87+2.148549e-01*S88+1.581269e-01*S89'
.param V48_part1='7.113427e-02*S0+2.034942e-01*S1+7.337552e-01*S2+1.013541e-01*S3+4.339453e-01*S4+(-2.907700e-02)*S5+3.756149e-01*S6+3.229762e-01*S7+4.946262e-02*S8+(-6.047590e-01)*S9'
.param V48_part2='V48_part1+2.713267e-01*S10+(-1.616049e-04)*S11+(-1.368265e-02)*S12+(-8.529043e-02)*S13+4.510291e-03*S14+4.559160e+03*S15+1.000000e+04*S16+(-4.068021e-01)*S17+1.538522e+01*S18+1.000000e+04*S19'
.param V48_part3='V48_part2+(-2.049544e+02)*S20+3.977811e-01*S21+3.863045e-01*S22+(-6.496685e+03)*S23+(-9.523145e+02)*S24+3.593991e-01*S25+(-1.308923e+00)*S26+(-1.318299e+02)*S27+(-6.908685e-01)*S28+(-1.337410e+01)*S29'
.param V48_part4='V48_part3+6.443820e-01*S30+(-9.275054e+03)*S31+(-1.456303e+01)*S32+7.213584e+02*S33+(-7.650898e+02)*S34+3.314191e-01*S35+(-5.609121e+02)*S36+2.445162e+03*S37+(-8.157021e+00)*S38+5.837339e-01*S39'
.param V48_part5='V48_part4+(-1.000000e+04)*S40+(-5.247082e+01)*S41+(-1.000000e+04)*S42+(-9.757913e+01)*S43+(-7.765172e+00)*S44+4.041663e-02*S45+6.647749e+02*S46+1.486769e-01*S47+4.439637e-02*S48+7.549068e-01*S49'
.param V48_part6='V48_part5+(-4.729743e-02)*S50+4.786178e-02*S51+4.426062e-02*S52+(-1.182212e-02)*S53+1.295530e-02*S54+4.569588e-02*S55+2.943790e-02*S56+1.021952e-02*S57+2.089454e-02*S58+3.288443e-02*S59'
.param V48_part7='V48_part6+2.215626e-02*S60+(-1.000000e+04)*S61+(-1.281889e-01)*S62+3.800864e-02*S63+2.321846e-02*S64+(-1.781008e-03)*S65+1.580566e-02*S66+2.123493e-02*S67+(-7.524424e-03)*S68+3.575309e-02*S69'
.param V48_part8='V48_part7+4.912301e-02*S70+(-2.444272e-02)*S71+2.497096e-02*S72+1.115736e-02*S73+5.592343e-01*S74+3.487103e-03*S75+2.590553e-02*S76+3.880084e-01*S77+1.324919e-02*S78+2.504384e-02*S79'
.param V48='V48_part8+(-2.678177e+00)*S80+3.751395e-02*S81+(-6.419387e-04)*S82+(-4.102513e+00)*S83+2.127003e-02*S84+1.823691e-02*S85+(-2.311886e+01)*S86+1.992855e-02*S87+1.624852e-02*S88+1.377161e-02*S89'
.param V49_part1='(-4.806606e-02)*S0+1.481920e-04*S1+(-1.425088e-02)*S2+4.286799e-02*S3+1.705362e-02*S4+(-3.364514e-02)*S5+3.477948e-02*S6+2.034129e-02*S7+(-1.261395e-02)*S8+1.662518e-01*S9'
.param V49_part2='V49_part1+1.309073e-02*S10+1.344720e-02*S11+1.848550e-02*S12+5.565436e-03*S13+(-2.269185e-02)*S14+(-1.090411e+01)*S15+2.589156e+02*S16+(-1.352129e+00)*S17+(-4.463313e+00)*S18+4.718541e+00*S19'
.param V49_part3='V49_part2+(-1.308765e+01)*S20+(-6.141837e-01)*S21+(-2.757598e-01)*S22+9.401769e+03*S23+3.260120e+00*S24+(-8.446563e-01)*S25+(-1.760195e+00)*S26+(-3.159091e+01)*S27+(-1.325170e+00)*S28+1.338401e+03*S29'
.param V49_part4='V49_part3+8.307460e-01*S30+9.782384e+03*S31+5.421174e+00*S32+3.381685e+03*S33+2.955960e+02*S34+(-2.421459e-01)*S35+1.000000e+04*S36+1.000000e+04*S37+9.752630e+02*S38+(-2.834164e+01)*S39'
.param V49_part5='V49_part4+1.000000e+04*S40+2.643521e+03*S41+1.000000e+04*S42+5.199717e+01*S43+1.862261e+01*S44+(-4.365546e-01)*S45+(-4.149899e+01)*S46+7.666259e-02*S47+(-3.824069e-01)*S48+(-1.909662e-01)*S49'
.param V49_part6='V49_part5+2.594095e-01*S50+(-4.526802e-01)*S51+(-2.989176e-01)*S52+(-1.427639e-01)*S53+(-3.672559e-01)*S54+(-2.082180e-01)*S55+(-1.432895e-01)*S56+(-3.596537e-01)*S57+(-1.081679e-01)*S58+(-1.813384e-01)*S59'
.param V49_part7='V49_part6+(-3.904427e-01)*S60+1.000000e+04*S61+8.511930e-02*S62+(-6.833475e-01)*S63+(-3.660659e-01)*S64+2.247835e-01*S65+(-4.327834e-01)*S66+(-3.730729e-01)*S67+(-2.006441e-04)*S68+(-3.953954e-01)*S69'
.param V49_part8='V49_part7+(-3.181841e-01)*S70+(-7.770137e-04)*S71+(-4.909904e-01)*S72+(-4.130253e-01)*S73+2.878773e-01*S74+(-4.264633e-01)*S75+(-4.280010e-01)*S76+(-4.708973e-03)*S77+(-5.513866e-01)*S78+(-4.755344e-01)*S79'
.param V49='V49_part8+(-2.944971e+00)*S80+(-7.441647e-01)*S81+(-4.890778e-01)*S82+(-1.098342e+00)*S83+(-7.853281e-01)*S84+(-6.028164e-01)*S85+7.022602e-01*S86+(-8.007368e-01)*S87+(-5.342571e-01)*S88+(-3.516592e-01)*S89'
.param V50_part1='3.816348e-01*S0+1.108069e+00*S1+1.790276e-01*S2+4.872324e+00*S3+1.109411e+00*S4+1.041531e+00*S5+4.788482e+03*S6+6.415219e+02*S7+1.000000e+04*S8+2.232041e+03*S9'
.param V50_part2='V50_part1+1.000000e+04*S10+1.809884e+02*S11+5.059972e+02*S12+2.459769e+02*S13+4.063006e+01*S14+2.890119e-03*S15+(-2.895770e-02)*S16+(-1.965984e-01)*S17+(-1.031823e-02)*S18+(-4.889176e-02)*S19'
.param V50_part3='V50_part2+2.273827e-02*S20+3.825206e-02*S21+3.226916e-02*S22+5.187342e-02*S23+(-2.252764e-02)*S24+9.830292e-02*S25+7.813621e-02*S26+(-2.238100e-02)*S27+1.221850e-01*S28+1.501465e-01*S29'
.param V50_part4='V50_part3+7.302526e-03*S30+(-6.211500e-02)*S31+(-1.640243e-02)*S32+(-6.196173e-02)*S33+(-1.043518e-01)*S34+9.651443e-02*S35+(-2.182909e-01)*S36+(-1.278106e-01)*S37+2.181638e-01*S38+(-3.065745e-02)*S39'
.param V50_part5='V50_part4+(-1.117431e-01)*S40+2.645858e-01*S41+(-1.891655e-01)*S42+(-5.920360e-04)*S43+3.142902e-01*S44+2.819115e-02*S45+2.096934e-02*S46+2.281483e-01*S47+1.101922e-02*S48+(-1.043579e-01)*S49'
.param V50_part6='V50_part5+2.094553e-01*S50+2.433302e-02*S51+4.250495e-02*S52+3.157719e-01*S53+5.941178e-02*S54+3.426470e-02*S55+3.271204e-01*S56+5.700355e-02*S57+7.038145e-02*S58+4.370121e-02*S59'
.param V50_part7='V50_part6+2.449152e-02*S60+(-3.227097e-02)*S61+1.943029e-01*S62+1.206015e-01*S63+3.857371e-02*S64+6.954452e-02*S65+9.274981e-02*S66+3.369440e-02*S67+(-1.004835e-01)*S68+1.623210e-01*S69'
.param V50_part8='V50_part7+7.401585e-02*S70+(-1.432870e-01)*S71+1.455619e-01*S72+1.331580e-01*S73+1.786892e-01*S74+2.755708e-02*S75+1.092836e-01*S76+2.884734e-01*S77+1.918162e-01*S78+1.566022e-01*S79'
.param V50='V50_part8+4.702284e-02*S80+3.951649e-01*S81+1.684645e-01*S82+1.612248e-01*S83+4.820773e-01*S84+2.244925e-01*S85+(-1.362600e+00)*S86+6.113774e-01*S87+3.389271e-01*S88+1.385864e-01*S89'
.param V51_part1='7.589920e-02*S0+3.707056e-02*S1+6.225714e-01*S2+(-1.752395e+00)*S3+2.241668e-01*S4+(-4.964532e-01)*S5+1.000000e+04*S6+6.340610e+00*S7+6.847963e+02*S8+3.855512e+03*S9'
.param V51_part2='V51_part1+1.000000e+04*S10+2.812239e+02*S11+1.166169e+02*S12+2.169828e+02*S13+4.600078e+01*S14+1.648175e-01*S15+2.672429e-01*S16+4.511188e-01*S17+1.935916e-01*S18+3.322625e-01*S19'
.param V51_part3='V51_part2+2.642828e-01*S20+9.538026e-02*S21+2.720912e-01*S22+3.290449e-01*S23+1.743069e-01*S24+2.340564e-01*S25+3.224507e-01*S26+1.772412e-01*S27+2.447917e-01*S28+2.592641e-01*S29'
.param V51_part4='V51_part3+2.083001e-01*S30+5.706052e-01*S31+6.573253e-01*S32+3.744817e-01*S33+4.852598e-01*S34+4.539764e-01*S35+6.866360e-01*S36+4.979816e-01*S37+3.731227e-01*S38+1.948503e-01*S39'
.param V51_part5='V51_part4+4.522568e-01*S40+3.833066e-01*S41+5.816449e-01*S42+3.652487e-01*S43+3.114677e-01*S44+2.025961e-01*S45+4.686516e-01*S46+6.115363e-01*S47+2.572182e-01*S48+6.612104e-01*S49'
.param V51_part6='V51_part5+7.236998e-01*S50+2.666773e-01*S51+2.539970e-01*S52+5.507768e-01*S53+2.747420e-01*S54+2.673348e-01*S55+3.971813e-01*S56+3.045828e-01*S57+2.724780e-01*S58+7.243545e-01*S59'
.param V51_part7='V51_part6+2.944172e-01*S60+6.512934e-01*S61+8.286535e-01*S62+3.297597e-01*S63+3.782877e-01*S64+9.543992e-01*S65+3.658942e-01*S66+3.957651e-01*S67+9.176045e-01*S68+3.490469e-01*S69'
.param V51_part8='V51_part7+3.899180e-01*S70+1.086943e+00*S71+4.087329e-01*S72+3.573000e-01*S73+5.849075e-01*S74+4.124071e-01*S75+4.222851e-01*S76+3.883541e-01*S77+4.263026e-01*S78+4.452245e-01*S79'
.param V51='V51_part8+1.096765e+00*S80+2.916040e-01*S81+4.584150e-01*S82+1.015776e+00*S83+3.111617e-01*S84+4.552107e-01*S85+2.747688e+00*S86+2.491601e-01*S87+4.077849e-01*S88+4.509451e-01*S89'
.param V52_part1='(-6.526636e-01)*S0+(-2.272294e-01)*S1+(-2.653258e-03)*S2+(-6.233822e+00)*S3+(-2.404253e-01)*S4+2.940140e-01*S5+1.000000e+04*S6+(-1.111084e+02)*S7+1.400012e+03*S8+2.154976e+03*S9'
.param V52_part2='V52_part1+1.000000e+04*S10+1.322956e+03*S11+8.054842e-01*S12+2.557458e+02*S13+3.445180e+01*S14+9.721857e-02*S15+1.689618e-01*S16+3.822316e-01*S17+8.003850e-02*S18+1.323039e-01*S19'
.param V52_part3='V52_part2+1.649250e-01*S20+(-3.467980e-02)*S21+(-5.363520e-03)*S22+1.307256e-01*S23+(-3.067173e-02)*S24+(-8.729518e-03)*S25+8.104011e-02*S26+(-3.554561e-02)*S27+(-8.856262e-02)*S28+3.293438e-02*S29'
.param V52_part4='V52_part3+1.738184e-01*S30+3.503124e-01*S31+3.288467e-01*S32+1.486996e-01*S33+2.009344e-01*S34+2.682417e-01*S35+2.544179e-01*S36+1.774173e-01*S37+1.391286e-01*S38+2.673583e-01*S39'
.param V52_part5='V52_part4+1.910532e-01*S40+6.771672e-02*S41+2.350425e-02*S42+1.410493e-01*S43+4.434340e-02*S44+2.209138e-01*S45+4.898880e-01*S46+4.436863e-01*S47+2.277003e-01*S48+5.118838e-01*S49'
.param V52_part6='V52_part5+3.890036e-01*S50+1.900156e-01*S51+1.726059e-01*S52+3.430363e-01*S53+7.930059e-02*S54+1.626708e-01*S55+3.987293e-01*S56+5.096044e-02*S57+9.813326e-02*S58+4.438402e-01*S59'
.param V52_part7='V52_part6+4.418701e-01*S60+6.703711e-01*S61+7.555109e-01*S62+3.699025e-01*S63+4.380580e-01*S64+7.514358e-01*S65+3.272296e-01*S66+4.047729e-01*S67+8.296553e-01*S68+2.131065e-01*S69'
.param V52_part8='V52_part7+3.378335e-01*S70+7.389416e-01*S71+1.914060e-01*S72+2.617363e-01*S73+8.061092e-01*S74+7.184002e-01*S75+7.166061e-01*S76+9.946077e-01*S77+5.977401e-01*S78+6.393399e-01*S79'
.param V52='V52_part8+9.576197e-01*S80+4.453756e-01*S81+6.168124e-01*S82+9.214643e-01*S83+3.687905e-01*S84+5.531028e-01*S85+2.545332e+00*S86+3.756497e-01*S87+4.540683e-01*S88+5.685137e-01*S89'
.param V53_part1='(-2.869192e-02)*S0+4.119770e-03*S1+4.307052e-02*S2+(-5.333739e-02)*S3+(-5.990494e-01)*S4+(-1.315637e-02)*S5+3.795734e+02*S6+(-5.296225e+01)*S7+6.718060e+01*S8+3.628296e+00*S9'
.param V53_part2='V53_part1+6.087332e+03*S10+6.084186e+00*S11+6.165218e-01*S12+2.014872e+00*S13+1.290983e+01*S14+2.252816e-02*S15+3.449558e-02*S16+9.205806e-02*S17+1.825554e-02*S18+3.205899e-02*S19'
.param V53_part3='V53_part2+4.268219e-02*S20+1.135070e-02*S21+3.058091e-02*S22+5.281768e-02*S23+(-4.608704e-03)*S24+2.331107e-02*S25+6.276911e-02*S26+(-9.408067e-03)*S27+2.917936e-02*S28+5.020235e-02*S29'
.param V53_part4='V53_part3+3.326846e-03*S30+1.588232e-02*S31+2.203339e-02*S32+7.607320e-04*S33+(-8.738433e-03)*S34+5.214077e-02*S35+(-1.110258e-02)*S36+(-1.422481e-02)*S37+3.162831e-02*S38+2.966847e-02*S39'
.param V53_part5='V53_part4+(-7.982567e-03)*S40+1.707396e-02*S41+(-1.719069e-02)*S42+(-4.615821e-03)*S43+7.388675e-03*S44+(-9.791166e-03)*S45+(-1.247257e-03)*S46+4.710742e-02*S47+(-1.597738e-02)*S48+3.366945e-03*S49'
.param V53_part6='V53_part5+4.800449e-02*S50+(-2.859325e-02)*S51+(-4.124821e-02)*S52+5.036560e-02*S53+(-5.436018e-02)*S54+(-5.035875e-02)*S55+4.836556e-02*S56+(-7.271901e-02)*S57+(-6.697749e-02)*S58+1.332655e-02*S59'
.param V53_part7='V53_part6+(-1.851278e-02)*S60+(-1.569415e-02)*S61+6.451600e-02*S62+(-3.252183e-02)*S63+(-4.075516e-02)*S64+3.002743e-02*S65+(-6.287445e-02)*S66+(-6.097343e-02)*S67+1.446111e-02*S68+(-8.958629e-02)*S69'
.param V53_part8='V53_part7+(-8.286587e-02)*S70+4.795283e-04*S71+(-1.280078e-01)*S72+(-1.026190e-01)*S73+(-1.771840e-01)*S74+(-3.036965e-02)*S75+(-3.411216e-02)*S76+(-1.251348e-02)*S77+(-5.474971e-02)*S78+(-5.534338e-02)*S79'
.param V53='V53_part8+(-8.465125e-02)*S80+(-6.622378e-02)*S81+(-7.884678e-02)*S82+(-6.924819e-02)*S83+(-8.809053e-02)*S84+(-1.003759e-01)*S85+(-2.131254e-01)*S86+(-1.168039e-01)*S87+(-1.144123e-01)*S88+(-8.174412e-02)*S89'
.param V54_part1='8.651577e-03*S0+(-1.816589e-03)*S1+(-1.110636e-02)*S2+4.704672e-02*S3+(-1.014772e-02)*S4+1.361798e-02*S5+4.225299e+02*S6+4.995231e-02*S7+9.189268e+01*S8+7.546564e+02*S9'
.param V54_part2='V54_part1+1.000000e+04*S10+7.212192e+02*S11+1.289055e+01*S12+8.570563e-01*S13+1.425972e+01*S14+8.416326e-05*S15+4.122110e-05*S16+2.011344e-02*S17+(-9.114425e-04)*S18+(-1.258332e-02)*S19'
.param V54_part3='V54_part2+(-2.679587e-02)*S20+(-6.333649e-03)*S21+(-3.422164e-02)*S22+(-2.926348e-02)*S23+8.140538e-03*S24+(-4.033516e-02)*S25+(-4.515564e-02)*S26+6.160686e-03*S27+(-3.397937e-02)*S28+(-5.989908e-02)*S29'
.param V54_part4='V54_part3+4.528909e-03*S30+1.635348e-03*S31+(-5.850704e-03)*S32+1.338984e-02*S33+3.872498e-02*S34+(-4.955154e-03)*S35+4.749159e-02*S36+3.192167e-02*S37+(-4.539899e-03)*S38+(-3.772454e-02)*S39'
.param V54_part5='V54_part4+5.112076e-02*S40+(-4.367720e-03)*S41+4.158559e-02*S42+5.672866e-02*S43+1.158834e-02*S44+(-6.667194e-03)*S45+3.022130e-03*S46+3.652382e-02*S47+(-5.465445e-03)*S48+5.003662e-02*S49'
.param V54_part6='V54_part5+2.754800e-02*S50+(-3.889520e-03)*S51+(-9.572951e-03)*S52+9.545098e-03*S53+7.948455e-03*S54+(-3.789393e-03)*S55+4.022710e-02*S56+1.373763e-02*S57+(-5.574033e-03)*S58+1.001742e-04*S59'
.param V54_part7='V54_part6+5.848454e-03*S60+2.130688e-02*S61+1.495997e-02*S62+(-5.869358e-02)*S63+(-1.035214e-02)*S64+(-3.538905e-02)*S65+3.700385e-03*S66+(-1.975197e-03)*S67+(-4.600205e-02)*S68+9.005578e-03*S69'
.param V54_part8='V54_part7+(-2.550139e-03)*S70+(-3.675872e-02)*S71+2.406616e-02*S72+3.339315e-03*S73+(-8.567478e-02)*S74+1.663836e-02*S75+(-5.893896e-02)*S76+(-1.025443e-01)*S77+(-7.505853e-02)*S78+(-7.619356e-02)*S79'
.param V54='V54_part8+(-8.989116e-02)*S80+(-1.217107e-01)*S81+(-8.249589e-02)*S82+(-1.522311e-01)*S83+(-1.399830e-01)*S84+(-9.484172e-02)*S85+3.216667e-01*S86+(-1.465617e-01)*S87+(-1.100028e-01)*S88+(-9.368533e-02)*S89'
.param V55_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V55_part2='V55_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V55_part3='V55_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V55_part4='V55_part3+(-6.318505e+00)*S30+0.000000e+00*S31+(-3.886889e+01)*S32+(-9.435588e-01)*S33+(-1.026188e+00)*S34+0.000000e+00*S35+0.000000e+00*S36+(-1.256480e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V55_part5='V55_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V55_part6='V55_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V55_part7='V55_part6+0.000000e+00*S60+(-2.553743e+01)*S61+0.000000e+00*S62+1.770469e+01*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V55_part8='V55_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V55='V55_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V56_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V56_part2='V56_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V56_part3='V56_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V56_part4='V56_part3+4.043925e+01*S30+0.000000e+00*S31+4.934586e+01*S32+3.583845e+00*S33+8.598812e+00*S34+0.000000e+00*S35+0.000000e+00*S36+(-5.462217e+00)*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V56_part5='V56_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V56_part6='V56_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V56_part7='V56_part6+0.000000e+00*S60+2.442941e+01*S61+0.000000e+00*S62+1.679826e+01*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V56_part8='V56_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V56='V56_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V57_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V57_part2='V57_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V57_part3='V57_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V57_part4='V57_part3+3.539413e+01*S30+0.000000e+00*S31+5.074795e+01*S32+2.456933e+01*S33+3.202275e+01*S34+0.000000e+00*S35+0.000000e+00*S36+1.612380e+01*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V57_part5='V57_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V57_part6='V57_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V57_part7='V57_part6+0.000000e+00*S60+3.205000e+01*S61+0.000000e+00*S62+2.495871e+01*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V57_part8='V57_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V57='V57_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V58_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V58_part2='V58_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V58_part3='V58_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V58_part4='V58_part3+1.878486e+00*S30+0.000000e+00*S31+6.885580e+00*S32+2.129357e+00*S33+1.799900e+00*S34+0.000000e+00*S35+0.000000e+00*S36+1.830507e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V58_part5='V58_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V58_part6='V58_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V58_part7='V58_part6+0.000000e+00*S60+3.184301e+00*S61+0.000000e+00*S62+2.586676e-01*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V58_part8='V58_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V58='V58_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V59_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+0.000000e+00*S3+0.000000e+00*S4+0.000000e+00*S5+0.000000e+00*S6+0.000000e+00*S7+0.000000e+00*S8+0.000000e+00*S9'
.param V59_part2='V59_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+0.000000e+00*S15+0.000000e+00*S16+0.000000e+00*S17+0.000000e+00*S18+0.000000e+00*S19'
.param V59_part3='V59_part2+0.000000e+00*S20+0.000000e+00*S21+0.000000e+00*S22+0.000000e+00*S23+0.000000e+00*S24+0.000000e+00*S25+0.000000e+00*S26+0.000000e+00*S27+0.000000e+00*S28+0.000000e+00*S29'
.param V59_part4='V59_part3+(-6.723103e+00)*S30+0.000000e+00*S31+(-2.157473e+00)*S32+(-8.695287e-01)*S33+(-5.038096e+00)*S34+0.000000e+00*S35+0.000000e+00*S36+2.907078e+00*S37+0.000000e+00*S38+0.000000e+00*S39'
.param V59_part5='V59_part4+0.000000e+00*S40+0.000000e+00*S41+0.000000e+00*S42+0.000000e+00*S43+0.000000e+00*S44+0.000000e+00*S45+0.000000e+00*S46+0.000000e+00*S47+0.000000e+00*S48+0.000000e+00*S49'
.param V59_part6='V59_part5+0.000000e+00*S50+0.000000e+00*S51+0.000000e+00*S52+0.000000e+00*S53+0.000000e+00*S54+0.000000e+00*S55+0.000000e+00*S56+0.000000e+00*S57+0.000000e+00*S58+0.000000e+00*S59'
.param V59_part7='V59_part6+0.000000e+00*S60+1.816140e+01*S61+0.000000e+00*S62+(-2.036845e+01)*S63+0.000000e+00*S64+0.000000e+00*S65+0.000000e+00*S66+0.000000e+00*S67+0.000000e+00*S68+0.000000e+00*S69'
.param V59_part8='V59_part7+0.000000e+00*S70+0.000000e+00*S71+0.000000e+00*S72+0.000000e+00*S73+0.000000e+00*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V59='V59_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+0.000000e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V60_part1='2.174367e+00*S0+2.133840e+00*S1+2.121376e+00*S2+1.253247e+00*S3+(-2.053350e+00)*S4+(-4.051474e-01)*S5+6.206082e-01*S6+(-1.755908e+00)*S7+(-1.266412e+00)*S8+(-1.155141e+00)*S9'
.param V60_part2='V60_part1+(-2.125363e+00)*S10+(-6.589342e-01)*S11+(-5.686237e-01)*S12+(-1.051959e+00)*S13+(-2.245114e+00)*S14+1.015102e-01*S15+(-1.229560e+00)*S16+(-6.806013e+00)*S17+1.617772e-02*S18+(-1.703908e+00)*S19'
.param V60_part3='V60_part2+(-5.779392e+00)*S20+4.792837e-02*S21+(-1.214373e+00)*S22+(-2.991259e+00)*S23+(-6.182667e-01)*S24+(-1.225303e+00)*S25+(-4.103009e+00)*S26+(-4.099737e-01)*S27+(-1.137829e+00)*S28+(-3.740588e+00)*S29'
.param V60_part4='V60_part3+3.604615e-01*S30+(-2.614528e+00)*S31+6.393753e+00*S32+(-3.891237e-01)*S33+(-2.418394e+00)*S34+(-4.448875e+00)*S35+(-1.180192e+00)*S36+(-2.469113e+00)*S37+(-4.629950e+00)*S38+7.860251e-01*S39'
.param V60_part5='V60_part4+(-3.241756e+00)*S40+(-5.735139e+00)*S41+(-1.250452e+00)*S42+(-2.816344e+00)*S43+(-4.980889e+00)*S44+1.332698e+00*S45+(-2.206036e+00)*S46+(-5.426055e+00)*S47+1.438321e+00*S48+(-3.420089e+00)*S49'
.param V60_part6='V60_part5+(-6.385711e+00)*S50+1.730360e+00*S51+(-5.317596e-01)*S52+(-6.464235e+00)*S53+1.997566e+00*S54+(-4.738956e-01)*S55+(-8.533571e+00)*S56+2.441314e+00*S57+(-8.862905e-01)*S58+(-6.677852e+00)*S59'
.param V60_part7='V60_part6+1.567710e+00*S60+1.184645e+00*S61+(-6.782879e+00)*S62+(-2.044256e+00)*S63+(-7.902350e-01)*S64+(-7.073086e+00)*S65+2.238954e+00*S66+(-4.022924e-01)*S67+(-7.488164e+00)*S68+2.708502e+00*S69'
.param V60_part8='V60_part7+(-6.266120e-01)*S70+(-1.146938e+01)*S71+3.198531e+00*S72+(-1.285254e+00)*S73+(-6.591999e+00)*S74+2.259491e+00*S75+(-1.915453e+00)*S76+(-1.181958e+01)*S77+2.547215e+00*S78+(-1.319493e+00)*S79'
.param V60='V60_part8+(-1.374193e+01)*S80+3.289699e+00*S81+(-7.403691e-01)*S82+(-2.095087e+01)*S83+3.788325e+00*S84+(-5.263634e-01)*S85+(-2.910207e+01)*S86+4.362728e+00*S87+(-6.179980e-01)*S88+(-1.163757e+01)*S89'
.param V61_part1='(-3.643132e-02)*S0+(-3.203049e-02)*S1+1.441374e+00*S2+(-4.266155e-01)*S3+2.607995e+00*S4+2.022141e+00*S5+1.260935e+00*S6+2.176320e+00*S7+1.697713e+00*S8+2.745742e+00*S9'
.param V61_part2='V61_part1+2.928254e+00*S10+2.122846e+00*S11+1.913668e+00*S12+2.349904e+00*S13+3.387660e+00*S14+8.131339e+00*S15+8.531550e+00*S16+1.740404e+01*S17+7.280755e+00*S18+8.247607e+00*S19'
.param V61_part3='V61_part2+1.367907e+01*S20+5.092046e+00*S21+7.169554e+00*S22+9.431409e+00*S23+5.371386e+00*S24+6.855670e+00*S25+9.704334e+00*S26+4.959903e+00*S27+6.147811e+00*S28+8.747584e+00*S29'
.param V61_part4='V61_part3+3.412875e+00*S30+1.597094e+01*S31+6.544315e+00*S32+9.280514e+00*S33+9.912463e+00*S34+1.539614e+01*S35+9.964518e+00*S36+1.224479e+01*S37+1.440880e+01*S38+8.277796e+00*S39'
.param V61_part5='V61_part4+1.094653e+01*S40+1.482369e+01*S41+9.635665e+00*S42+1.027884e+01*S43+1.276699e+01*S44+1.311204e+01*S45+1.538695e+01*S46+2.299732e+01*S47+1.290571e+01*S48+1.642629e+01*S49'
.param V61_part6='V61_part5+2.219952e+01*S50+1.258304e+01*S51+1.439154e+01*S52+2.056255e+01*S53+1.225202e+01*S54+1.409860e+01*S55+2.116947e+01*S56+1.203986e+01*S57+1.408681e+01*S58+1.910959e+01*S59'
.param V61_part7='V61_part6+1.819704e+01*S60+1.892101e+01*S61+3.033471e+01*S62+1.487193e+01*S63+2.002611e+01*S64+2.799851e+01*S65+1.712267e+01*S66+1.928922e+01*S67+2.771381e+01*S68+1.668612e+01*S69'
.param V61_part8='V61_part7+1.897248e+01*S70+2.989819e+01*S71+1.682668e+01*S72+1.914436e+01*S73+2.349284e+01*S74+2.309046e+01*S75+2.704871e+01*S76+3.809749e+01*S77+2.238696e+01*S78+2.577944e+01*S79'
.param V61='V61_part8+3.546351e+01*S80+2.163803e+01*S81+2.453464e+01*S82+3.935657e+01*S83+2.099737e+01*S84+2.399025e+01*S85+3.921784e+01*S86+2.082732e+01*S87+2.331021e+01*S88+3.156635e+01*S89'
.param V62_part1='(-4.353664e-01)*S0+4.766627e-02*S1+1.109485e+00*S2+1.754198e+00*S3+6.606834e+00*S4+2.628079e+00*S5+1.557641e+00*S6+5.146948e+00*S7+3.302451e+00*S8+2.491909e+00*S9'
.param V62_part2='V62_part1+3.898366e+00*S10+2.653167e+00*S11+1.975735e+00*S12+2.721446e+00*S13+3.401628e+00*S14+3.666595e+00*S15+8.368212e+00*S16+1.394490e+01*S17+5.348994e+00*S18+8.327557e+00*S19'
.param V62_part3='V62_part2+1.246463e+01*S20+5.941948e+00*S21+8.838983e+00*S22+1.195945e+01*S23+7.003525e+00*S24+9.402501e+00*S25+1.253284e+01*S26+7.560936e+00*S27+1.030186e+01*S28+1.290299e+01*S29'
.param V62_part4='V62_part3+5.927779e+00*S30+2.130704e+01*S31+1.012867e+01*S32+8.417803e+00*S33+1.036319e+01*S34+2.237202e+01*S35+1.582243e+01*S36+1.526954e+01*S37+2.327052e+01*S38+1.600424e+01*S39'
.param V62_part5='V62_part4+2.078972e+01*S40+2.458423e+01*S41+1.898000e+01*S42+2.270952e+01*S43+2.549202e+01*S44+1.567550e+01*S45+2.599155e+01*S46+3.307629e+01*S47+1.824193e+01*S48+2.899178e+01*S49'
.param V62_part6='V62_part5+3.526119e+01*S50+2.043395e+01*S51+2.546038e+01*S52+3.698377e+01*S53+2.292620e+01*S54+2.769523e+01*S55+3.919393e+01*S56+2.488838e+01*S57+3.061028e+01*S58+4.006916e+01*S59'
.param V62_part7='V62_part6+2.566504e+01*S60+3.317904e+01*S61+4.860798e+01*S62+2.502327e+01*S63+3.613840e+01*S64+4.998349e+01*S65+3.200156e+01*S66+3.886487e+01*S67+5.109699e+01*S68+3.489633e+01*S69'
.param V62_part8='V62_part7+4.215528e+01*S70+5.496051e+01*S71+3.647042e+01*S72+4.615746e+01*S73+5.333260e+01*S74+3.610260e+01*S75+4.780616e+01*S76+6.231804e+01*S77+4.075266e+01*S78+5.099584e+01*S79'
.param V62='V62_part8+6.695828e+01*S80+4.407361e+01*S81+5.465997e+01*S82+7.365003e+01*S83+4.837190e+01*S84+5.838855e+01*S85+9.204843e+01*S86+5.109285e+01*S87+6.287278e+01*S88+7.620402e+01*S89'
.param V63_part1='(-7.576443e-01)*S0+1.602880e-01*S1+2.207802e-01*S2+3.297275e-01*S3+1.772246e-01*S4+8.674693e-01*S5+2.517376e-01*S6+4.929591e-01*S7+8.554073e-01*S8+4.618348e-01*S9'
.param V63_part2='V63_part1+3.050355e-01*S10+6.678332e-01*S11+3.028369e-01*S12+3.452389e-01*S13+2.552373e-01*S14+1.623104e-01*S15+8.152422e-02*S16+(-1.263119e-01)*S17+1.814006e-01*S18+7.559594e-02*S19'
.param V63_part3='V63_part2+4.418910e-01*S20+2.021800e-01*S21+6.202448e-01*S22+4.592184e-01*S23+3.714186e-01*S24+6.095138e-01*S25+7.005671e-01*S26+4.318742e-01*S27+5.824375e-01*S28+7.117436e-01*S29'
.param V63_part4='V63_part3+(-1.265526e-01)*S30+4.005966e-01*S31+(-1.517291e+00)*S32+(-1.409598e-01)*S33+(-4.583363e-02)*S34+3.577078e-01*S35+3.588404e-01*S36+8.606951e-03*S37+4.119405e-01*S38+3.570825e-01*S39'
.param V63_part5='V63_part4+5.059397e-01*S40+3.702314e-01*S41+4.541122e-01*S42+4.702322e-01*S43+7.305735e-01*S44+2.350227e-01*S45+3.403284e-01*S46+4.544006e-01*S47+2.858193e-01*S48+3.954822e-01*S49'
.param V63_part6='V63_part5+4.482414e-01*S50+3.341644e-01*S51+3.517360e-01*S52+3.761762e-01*S53+3.577824e-01*S54+3.676604e-01*S55+4.761996e-01*S56+3.314607e-01*S57+4.122919e-01*S58+6.585754e-01*S59'
.param V63_part7='V63_part6+2.565770e-01*S60+(-4.034593e-01)*S61+2.720030e-01*S62+1.305459e-01*S63+2.975927e-01*S64+8.450388e-02*S65+3.007914e-01*S66+3.719245e-01*S67+(-4.789536e-01)*S68+2.855087e-01*S69'
.param V63_part8='V63_part7+4.646516e-01*S70+(-1.488695e+00)*S71+2.965770e-01*S72+4.647834e-01*S73+6.249188e-01*S74+2.405109e-01*S75+3.262156e-01*S76+5.410300e-01*S77+2.910920e-01*S78+3.661382e-01*S79'
.param V63='V63_part8+5.148667e-01*S80+3.276709e-01*S81+4.551227e-01*S82+4.419200e-01*S83+4.572249e-01*S84+5.031844e-01*S85+1.444373e+00*S86+4.568321e-01*S87+5.010788e-01*S88+8.382775e-01*S89'
.param V64_part1='2.357359e-01*S0+3.538442e-02*S1+1.474953e-01*S2+1.312885e-02*S3+4.042650e-02*S4+(-1.216037e-02)*S5+(-2.621069e-02)*S6+2.252046e-02*S7+(-2.487312e-02)*S8+6.412906e-02*S9'
.param V64_part2='V64_part1+2.239807e-02*S10+1.952453e-02*S11+2.055187e-02*S12+1.004129e-02*S13+5.777102e-02*S14+(-2.973468e-01)*S15+(-3.709280e-01)*S16+(-1.161409e+00)*S17+(-9.166071e-01)*S18+(-6.698256e-01)*S19'
.param V64_part3='V64_part2+(-1.731591e+00)*S20+(-7.771780e-01)*S21+(-1.408447e+00)*S22+(-1.666632e+00)*S23+(-7.664777e-01)*S24+(-1.341506e+00)*S25+(-1.929101e+00)*S26+(-8.086825e-01)*S27+(-1.372236e+00)*S28+(-2.191407e+00)*S29'
.param V64_part4='V64_part3+4.888190e-01*S30+(-1.637387e+00)*S31+(-1.817539e+00)*S32+(-7.076077e-01)*S33+4.971696e-01*S34+(-2.399249e+00)*S35+(-9.875366e-01)*S36+(-1.751163e+00)*S37+(-2.811461e+00)*S38+(-2.428897e+00)*S39'
.param V64_part5='V64_part4+(-1.430108e+00)*S40+(-3.287892e+00)*S41+(-1.749643e+00)*S42+(-2.132620e+00)*S43+(-3.344732e+00)*S44+(-1.743882e+00)*S45+(-1.353569e+00)*S46+(-3.303308e+00)*S47+(-2.496891e+00)*S48+(-1.601937e+00)*S49'
.param V64_part6='V64_part5+(-4.166815e+00)*S50+(-3.229783e+00)*S51+(-3.623074e+00)*S52+(-5.034172e+00)*S53+(-3.942669e+00)*S54+(-4.333600e+00)*S55+(-5.588357e+00)*S56+(-4.666837e+00)*S57+(-5.012641e+00)*S58+(-6.682746e+00)*S59'
.param V64_part7='V64_part6+(-2.560417e+00)*S60+(-6.006933e+00)*S61+(-5.465917e+00)*S62+3.162079e-01*S63+(-4.261854e+00)*S64+(-6.642945e+00)*S65+(-4.572216e+00)*S66+(-5.274702e+00)*S67+(-7.847479e+00)*S68+(-5.540153e+00)*S69'
.param V64_part8='V64_part7+(-6.159085e+00)*S70+(-8.342126e+00)*S71+(-6.527454e+00)*S72+(-7.198877e+00)*S73+(-7.823577e+00)*S74+(-3.524678e+00)*S75+(-4.498377e+00)*S76+(-5.992830e+00)*S77+(-4.914817e+00)*S78+(-5.908288e+00)*S79'
.param V64='V64_part8+(-6.741976e+00)*S80+(-6.216502e+00)*S81+(-7.296973e+00)*S82+(-7.271769e+00)*S83+(-7.514366e+00)*S84+(-8.610621e+00)*S85+(-6.192570e+00)*S86+(-8.693523e+00)*S87+(-9.755307e+00)*S88+(-1.240273e+01)*S89'
.param V65_part1='1.548177e+01*S0+1.260513e+01*S1+9.882869e+00*S2+1.867508e+00*S3+4.416812e+00*S4+6.835991e+00*S5+7.102520e+00*S6+3.819030e+00*S7+6.283721e+00*S8+2.129582e+00*S9'
.param V65_part2='V65_part1+7.561351e+00*S10+3.201489e+00*S11+2.481994e+00*S12+2.620370e+00*S13+3.965412e+00*S14+7.394935e+00*S15+7.688462e+00*S16+3.749300e+00*S17+4.197036e+00*S18+3.288439e+00*S19'
.param V65_part3='V65_part2+9.206420e-01*S20+1.270013e+00*S21+1.180151e+00*S22+2.093658e+00*S23+9.731735e-01*S24+1.355385e+00*S25+1.220018e+00*S26+8.953708e-01*S27+1.398173e+00*S28+1.219190e+00*S29'
.param V65_part4='V65_part3+8.082315e-01*S30+7.089919e+00*S31+3.401417e+00*S32+3.127302e+00*S33+2.396495e+00*S34+3.398124e+00*S35+4.542788e+00*S36+3.350338e+00*S37+2.914336e+00*S38+4.387748e+00*S39'
.param V65_part5='V65_part4+3.055331e+00*S40+2.466867e+00*S41+3.988655e+00*S42+3.573601e+00*S43+2.380662e+00*S44+5.908768e+00*S45+4.682646e+00*S46+3.490809e+00*S47+4.955330e+00*S48+4.143974e+00*S49'
.param V65_part6='V65_part5+3.116898e+00*S50+4.391550e+00*S51+3.204840e+00*S52+2.471869e+00*S53+4.149587e+00*S54+3.094315e+00*S55+2.168992e+00*S56+4.464362e+00*S57+2.970042e+00*S58+1.709048e+00*S59'
.param V65_part7='V65_part6+6.067839e+00*S60+3.853831e+00*S61+2.910406e+00*S62+4.496453e+00*S63+3.743368e+00*S64+2.918960e+00*S65+5.180562e+00*S66+3.775102e+00*S67+2.060755e+00*S68+3.805304e+00*S69'
.param V65_part8='V65_part7+3.145956e+00*S70+2.084942e+00*S71+3.986442e+00*S72+3.001913e+00*S73+2.046823e+00*S74+5.798020e+00*S75+3.709766e+00*S76+1.984080e+00*S77+5.591533e+00*S78+3.670608e+00*S79'
.param V65='V65_part8+2.044531e+00*S80+4.950013e+00*S81+3.962087e+00*S82+2.223553e+00*S83+4.459662e+00*S84+3.478735e+00*S85+2.199288e+00*S86+3.656650e+00*S87+2.545050e+00*S88+2.319814e+00*S89'
.param V66_part1='1.399704e-01*S0+8.135735e+00*S1+(-4.060081e+00)*S2+5.389255e-01*S3+(-3.354105e-01)*S4+(-9.332256e-02)*S5+1.826706e+00*S6+(-2.246635e-01)*S7+(-3.569557e+00)*S8+2.262179e+00*S9'
.param V66_part2='V66_part1+(-2.788492e+00)*S10+(-6.197602e-01)*S11+2.217493e-01*S12+3.610615e-01*S13+(-1.385198e+00)*S14+(-7.947817e+00)*S15+(-7.599802e+00)*S16+(-1.555308e+00)*S17+(-1.381925e+00)*S18+(-2.466573e+00)*S19'
.param V66_part3='V66_part2+1.103100e+00*S20+6.150588e-02*S21+5.072957e-01*S22+(-2.407398e-01)*S23+2.228525e-01*S24+3.192176e-01*S25+2.218144e-01*S26+2.721092e-01*S27+1.448032e-01*S28+8.899441e-02*S29'
.param V66_part4='V66_part3+1.538498e+00*S30+(-2.618140e+00)*S31+(-6.085502e-01)*S32+1.048641e+00*S33+4.575752e-01*S34+(-3.669256e-01)*S35+1.331197e+00*S36+(-2.461102e-01)*S37+(-1.118706e-01)*S38+(-7.340374e-01)*S39'
.param V66_part5='V66_part4+(-5.331516e-02)*S40+(-8.447692e-02)*S41+7.992522e-02*S42+(-8.488119e-01)*S43+(-2.127423e-01)*S44+(-7.654116e-01)*S45+1.769310e+00*S46+2.388130e-02*S47+(-3.111838e-01)*S48+7.500952e-01*S49'
.param V66_part6='V66_part5+(-3.182019e-01)*S50+(-2.148121e-01)*S51+(-5.656218e-01)*S52+(-6.872418e-02)*S53+(-6.478384e-01)*S54+(-4.584350e-01)*S55+(-1.162742e-01)*S56+(-1.168538e+00)*S57+(-4.838351e-01)*S58+9.132653e-02*S59'
.param V66_part7='V66_part6+(-1.368601e+00)*S60+6.093655e-01*S61+(-9.439223e-02)*S62+(-2.475023e-01)*S63+(-7.277525e-01)*S64+(-4.857659e-01)*S65+(-5.108682e-01)*S66+(-6.288296e-01)*S67+(-2.707856e-01)*S68+(-3.210083e-01)*S69'
.param V66_part8='V66_part7+(-4.665801e-01)*S70+(-2.704233e-01)*S71+(-1.321660e+00)*S72+(-6.076888e-01)*S73+(-2.691545e-01)*S74+(-8.744100e-01)*S75+(-3.860292e-01)*S76+(-1.900799e-03)*S77+(-1.192153e+00)*S78+(-1.011915e-01)*S79'
.param V66='V66_part8+(-1.280571e-01)*S80+(-4.893118e-01)*S81+(-1.491544e+00)*S82+(-2.881466e-01)*S83+(-6.298866e-01)*S84+(-8.152172e-01)*S85+(-3.955150e-01)*S86+(-4.724613e-01)*S87+(-3.459116e-01)*S88+(-4.090841e-01)*S89'
.param V67_part1='4.088865e+00*S0+(-6.946953e+00)*S1+(-6.653071e-01)*S2+1.093233e+01*S3+4.308042e+00*S4+(-5.197441e-01)*S5+(-6.288416e+00)*S6+4.404329e+00*S7+(-4.585871e-01)*S8+(-7.144549e-01)*S9'
.param V67_part2='V67_part1+(-1.218088e+00)*S10+1.483164e-01*S11+(-2.169107e-02)*S12+6.984547e-02*S13+(-6.206559e-01)*S14+(-5.458814e+00)*S15+(-4.449541e+00)*S16+(-1.577172e+00)*S17+(-5.011048e+00)*S18+(-1.792078e+00)*S19'
.param V67_part3='V67_part2+8.682083e-02*S20+(-3.622996e-01)*S21+(-1.498221e-01)*S22+(-6.575748e-01)*S23+(-6.469033e-02)*S24+(-5.124845e-01)*S25+(-6.855451e-02)*S26+(-1.265443e-01)*S27+(-5.433867e-01)*S28+(-2.975039e-02)*S29'
.param V67_part4='V67_part3+5.329673e-02*S30+(-3.204636e+00)*S31+(-1.228302e+00)*S32+(-2.854507e+00)*S33+(-1.734450e+00)*S34+(-1.204899e+00)*S35+(-5.424081e+00)*S36+(-1.988283e+00)*S37+(-9.509023e-01)*S38+(-2.864316e+00)*S39'
.param V67_part5='V67_part4+(-1.698931e+00)*S40+(-7.394875e-01)*S41+(-3.199431e+00)*S42+(-1.460812e+00)*S43+(-6.678987e-01)*S44+(-6.711286e+00)*S45+(-2.290611e+00)*S46+(-1.477105e+00)*S47+(-5.457320e+00)*S48+(-2.329232e+00)*S49'
.param V67_part6='V67_part5+(-1.131624e+00)*S50+(-4.829015e+00)*S51+(-1.420358e+00)*S52+(-9.624047e-01)*S53+(-3.299872e+00)*S54+(-1.710209e+00)*S55+(-7.025193e-01)*S56+(-2.687382e+00)*S57+(-1.397871e+00)*S58+(-5.132815e-01)*S59'
.param V67_part7='V67_part6+(-5.762564e+00)*S60+(-1.466566e+00)*S61+(-1.226512e+00)*S62+(-5.402329e+00)*S63+(-1.872048e+00)*S64+(-1.174304e+00)*S65+(-6.090319e+00)*S66+(-2.438343e+00)*S67+(-6.827205e-01)*S68+(-3.133926e+00)*S69'
.param V67_part8='V67_part7+(-1.641975e+00)*S70+(-6.895741e-01)*S71+(-1.441055e+00)*S72+(-1.292504e+00)*S73+(-6.119213e-01)*S74+(-5.056995e+00)*S75+(-2.080935e+00)*S76+(-7.431672e-01)*S77+(-5.792837e+00)*S78+(-2.207554e+00)*S79'
.param V67='V67_part8+(-6.310262e-01)*S80+(-5.653499e+00)*S81+(-2.020383e+00)*S82+(-7.708715e-01)*S83+(-3.970613e+00)*S84+(-1.682556e+00)*S85+(-7.111717e-01)*S86+(-1.983949e+00)*S87+(-1.194071e+00)*S88+(-8.114308e-01)*S89'
.param V68_part1='(-5.151195e+00)*S0+9.117843e-01*S1+(-9.111833e-01)*S2+1.397979e-01*S3+1.709799e-01*S4+(-1.671884e+00)*S5+(-2.622213e+00)*S6+(-1.649287e+00)*S7+(-5.661735e-01)*S8+(-1.242079e+00)*S9'
.param V68_part2='V68_part1+(-7.017271e-01)*S10+(-5.419111e-01)*S11+(-8.334186e-01)*S12+(-1.029370e+00)*S13+1.957903e-01*S14+(-2.185631e-02)*S15+(-2.400224e-01)*S16+(-1.277756e-01)*S17+(-1.023312e-01)*S18+8.312772e-02*S19'
.param V68_part3='V68_part2+2.269596e-01*S20+5.068002e-01*S21+4.867462e-01*S22+1.140754e-01*S23+5.006409e-01*S24+2.689597e-01*S25+2.729664e-01*S26+4.544701e-01*S27+2.592608e-01*S28+3.118521e-01*S29'
.param V68_part4='V68_part3+(-3.298739e-02)*S30+(-2.112015e-01)*S31+1.227240e-01*S32+1.653420e-01*S33+1.855101e-01*S34+3.213808e-01*S35+1.537557e-01*S36+4.048104e-01*S37+3.085961e-01*S38+4.165648e-01*S39'
.param V68_part5='V68_part4+3.088364e-01*S40+3.265038e-01*S41+2.538959e-01*S42+3.450702e-01*S43+2.694567e-01*S44+1.103297e+00*S45+1.350560e-01*S46+2.374422e-01*S47+1.099325e+00*S48+2.398657e-01*S49'
.param V68_part6='V68_part5+2.372658e-01*S50+7.666740e-01*S51+5.788705e-01*S52+2.800687e-01*S53+5.591332e-01*S54+3.964945e-01*S55+2.761480e-01*S56+3.531862e-01*S57+3.949048e-01*S58+2.116477e-01*S59'
.param V68_part7='V68_part6+6.648480e-01*S60+3.728331e-01*S61+1.872942e-01*S62+4.175570e-01*S63+4.817503e-01*S64+2.116413e-01*S65+4.858334e-01*S66+4.079459e-01*S67+1.686201e-01*S68+2.903149e-01*S69'
.param V68_part8='V68_part7+3.296012e-01*S70+1.768306e-01*S71+3.179529e-01*S72+2.447940e-01*S73+1.444920e-01*S74+7.320317e-01*S75+3.835293e-01*S76+1.739079e-01*S77+5.660952e-01*S78+9.888017e-02*S79'
.param V68='V68_part8+1.559931e-01*S80+3.659532e-01*S81+1.991002e-01*S82+1.300976e-01*S83+3.773633e-01*S84+2.903561e-01*S85+1.286619e-01*S86+3.498882e-01*S87+2.053404e-01*S88+1.500775e-01*S89'
.param V69_part1='1.578456e+00*S0+4.737225e-01*S1+4.012288e-03*S2+7.833732e-02*S3+1.868535e-01*S4+6.062474e-02*S5+(-6.686577e-02)*S6+(-1.140861e-02)*S7+1.075815e-03*S8+1.610407e-01*S9'
.param V69_part2='V69_part1+(-5.099819e-02)*S10+9.815505e-03*S11+1.079068e-01*S12+2.039704e-02*S13+1.137010e-02*S14+(-6.528493e-04)*S15+6.403199e-02*S16+(-2.730618e-02)*S17+(-5.533148e-03)*S18+2.313255e-02*S19'
.param V69_part3='V69_part2+(-4.556295e-01)*S20+(-3.653773e-01)*S21+(-4.804197e-01)*S22+(-2.465259e-01)*S23+(-2.958313e-01)*S24+(-3.421845e-01)*S25+(-3.062068e-01)*S26+(-2.264590e-01)*S27+(-2.661632e-01)*S28+(-3.040129e-01)*S29'
.param V69_part4='V69_part3+(-1.954703e-01)*S30+(-1.700668e+00)*S31+(-4.715867e-01)*S32+(-9.181783e-01)*S33+(-1.651313e-01)*S34+(-4.664754e-01)*S35+(-1.207772e+00)*S36+(-4.898193e-01)*S37+(-4.321733e-01)*S38+(-9.115442e-01)*S39'
.param V69_part5='V69_part4+(-3.948315e-01)*S40+(-2.931840e-01)*S41+(-1.056010e+00)*S42+(-4.098749e-01)*S43+(-2.451666e-01)*S44+(-7.354420e-01)*S45+(-1.442011e+00)*S46+(-4.749587e-01)*S47+(-5.528933e-01)*S48+(-9.750541e-01)*S49'
.param V69_part6='V69_part5+(-3.725638e-01)*S50+(-3.780567e-01)*S51+(-2.743878e-01)*S52+(-1.335609e-01)*S53+(-4.219531e-01)*S54+(-1.176358e-01)*S55+(-9.242602e-02)*S56+(-4.704723e-01)*S57+(-1.673652e-01)*S58+(-6.290117e-02)*S59'
.param V69_part7='V69_part6+(-9.597297e-01)*S60+(-1.047242e+00)*S61+(-2.328768e-01)*S62+(-2.428951e-01)*S63+(-4.114219e-01)*S64+(-1.852988e-01)*S65+(-4.160259e-01)*S66+(-2.824341e-01)*S67+1.682811e-02*S68+(-2.753195e-01)*S69'
.param V69_part8='V69_part7+(-1.950986e-01)*S70+6.943948e-04*S71+(-3.487543e-01)*S72+(-1.209917e-01)*S73+(-1.161811e-02)*S74+(-9.394180e-01)*S75+(-3.933271e-01)*S76+(-6.921147e-04)*S77+(-5.395890e-01)*S78+(-4.369781e-01)*S79'
.param V69='V69_part8+(-9.830860e-02)*S80+(-3.941213e-01)*S81+(-1.987574e-01)*S82+(-8.618275e-02)*S83+(-4.560684e-01)*S84+(-2.981299e-01)*S85+(-4.130540e-02)*S86+(-5.437411e-01)*S87+(-6.709063e-02)*S88+(-3.833654e-02)*S89'
.param V70_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+3.004192e+01*S3+6.324650e+00*S4+0.000000e+00*S5+1.924962e+01*S6+1.526510e+01*S7+0.000000e+00*S8+1.154001e+01*S9'
.param V70_part2='V70_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+5.597537e+00*S15+1.051963e+01*S16+2.075292e+00*S17+3.936146e+01*S18+3.927687e+01*S19'
.param V70_part3='V70_part2+3.104009e+01*S20+5.643126e+01*S21+1.084848e+01*S22+6.693007e+01*S23+(-7.777923e+00)*S24+4.109228e+01*S25+4.251320e+01*S26+7.706293e+01*S27+6.453040e+01*S28+5.842178e+01*S29'
.param V70_part4='V70_part3+9.890699e+01*S30+1.004236e+01*S31+1.190179e+01*S32+3.797790e+01*S33+6.326329e+01*S34+3.655109e+01*S35+2.536643e+01*S36+3.823857e+01*S37+4.712527e+01*S38+2.151459e+01*S39'
.param V70_part5='V70_part4+2.723571e+01*S40+4.214701e+01*S41+2.598484e+01*S42+4.243209e+01*S43+7.640141e+01*S44+8.475769e+00*S45+7.134356e+00*S46+3.814533e+01*S47+1.112600e+01*S48+3.125632e+00*S49'
.param V70_part6='V70_part5+4.736255e+01*S50+1.635462e+01*S51+4.908015e+01*S52+4.869095e+01*S53+1.771897e+01*S54+2.996765e+01*S55+1.069686e+02*S56+5.215261e+01*S57+4.660248e+01*S58+0.000000e+00*S59'
.param V70_part7='V70_part6+2.762032e+01*S60+3.851561e+01*S61+4.372168e+01*S62+4.795826e+01*S63+5.242916e+01*S64+9.089984e+01*S65+1.611990e+01*S66+4.456321e+01*S67+0.000000e+00*S68+1.562103e+01*S69'
.param V70_part8='V70_part7+5.091926e+01*S70+0.000000e+00*S71+4.281201e+01*S72+(-2.865420e+01)*S73+0.000000e+00*S74+3.638661e+01*S75+2.965361e+01*S76+0.000000e+00*S77+3.694621e+01*S78+2.678765e+01*S79'
.param V70='V70_part8+0.000000e+00*S80+6.222443e+01*S81+8.765033e+01*S82+0.000000e+00*S83+(-1.941165e+01)*S84+1.403963e+01*S85+0.000000e+00*S86+1.056908e+02*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V71_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+(-2.193366e+01)*S3+(-8.916142e-01)*S4+0.000000e+00*S5+(-1.856775e+01)*S6+(-8.601838e+00)*S7+0.000000e+00*S8+(-6.082987e+00)*S9'
.param V71_part2='V71_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+7.651574e+01*S15+4.468308e+01*S16+(-7.265613e+00)*S17+4.514754e+01*S18+3.247013e+01*S19'
.param V71_part3='V71_part2+1.429236e+01*S20+(-3.675582e+01)*S21+4.814851e+01*S22+2.694980e+00*S23+4.693150e+01*S24+5.064664e+00*S25+1.153427e+01*S26+(-3.189753e+01)*S27+(-8.789599e-01)*S28+(-1.164544e+01)*S29'
.param V71_part4='V71_part3+(-1.032853e+02)*S30+3.894113e+01*S31+1.906383e+01*S32+(-1.225699e-01)*S33+(-5.818451e+00)*S34+3.343867e+01*S35+2.548163e+01*S36+1.246671e+01*S37+3.999747e+01*S38+2.525679e+01*S39'
.param V71_part5='V71_part4+3.072176e+01*S40+4.127979e+01*S41+4.154584e+01*S42+2.659613e+01*S43+(-1.132208e+01)*S44+2.191609e+01*S45+5.879879e+01*S46+2.479984e+01*S47+4.568489e+01*S48+7.399199e+01*S49'
.param V71_part6='V71_part5+4.412502e+00*S50+4.074047e+01*S51+(-1.439698e+01)*S52+1.814205e+01*S53+4.485191e+01*S54+3.267624e+01*S55+(-7.822261e+01)*S56+3.499981e-01*S57+(-5.578492e+00)*S58+0.000000e+00*S59'
.param V71_part7='V71_part6+3.040428e+01*S60+1.941532e+01*S61+5.562379e+01*S62+4.448064e+01*S63+1.486122e+01*S64+(-3.188325e+01)*S65+7.663806e+01*S66+5.553502e+01*S67+0.000000e+00*S68+5.918780e+01*S69'
.param V71_part8='V71_part7+1.747687e+01*S70+0.000000e+00*S71+1.981476e+01*S72+7.828509e+01*S73+0.000000e+00*S74+3.384603e+01*S75+9.873081e+00*S76+0.000000e+00*S77+7.456042e+01*S78+1.012749e+02*S79'
.param V71='V71_part8+0.000000e+00*S80+5.384391e+01*S81+(-7.549417e+01)*S82+0.000000e+00*S83+1.111785e+02*S84+8.312362e+01*S85+0.000000e+00*S86+(-1.758850e+01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V72_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+(-3.570851e+01)*S3+6.051465e-01*S4+0.000000e+00*S5+(-3.300808e+00)*S6+(-1.343357e+01)*S7+0.000000e+00*S8+(-4.901894e+00)*S9'
.param V72_part2='V72_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-1.430841e-01)*S15+2.216793e-01*S16+5.990144e+01*S17+5.969097e-01*S18+4.755243e+00*S19'
.param V72_part3='V72_part2+2.222708e+01*S20+4.712337e+01*S21+1.003492e+01*S22+(-5.870985e+00)*S23+4.256067e+01*S24+3.128176e+01*S25+9.096768e+00*S26+(-1.461658e+01)*S27+(-5.649487e-01)*S28+1.690939e+01*S29'
.param V72_part4='V72_part3+(-6.300410e+01)*S30+3.559665e+01*S31+4.016829e+01*S32+1.100149e+01*S33+(-3.332624e+01)*S34+1.632874e+01*S35+1.414927e+01*S36+9.291142e+00*S37+4.808939e+00*S38+1.523000e+01*S39'
.param V72_part5='V72_part4+5.633306e+00*S40+3.779618e+00*S41+(-1.413900e+01)*S42+(-1.486573e+01)*S43+1.514869e+01*S44+4.086361e+01*S45+6.261454e+01*S46+2.929788e+01*S47+(-2.329957e+00)*S48+5.424672e+01*S49'
.param V72_part6='V72_part5+2.651896e+01*S50+(-1.321526e+01)*S51+1.214565e+00*S52+1.113906e+01*S53+(-1.553164e+01)*S54+(-2.256385e+01)*S55+1.193499e+01*S56+2.846468e+00*S57+(-1.146543e+01)*S58+0.000000e+00*S59'
.param V72_part7='V72_part6+3.236010e-01*S60+3.083936e+01*S61+2.478431e+01*S62+(-9.666050e+01)*S63+3.321418e+00*S64+1.331724e+01*S65+(-4.179696e+01)*S66+(-3.306145e+01)*S67+0.000000e+00*S68+(-6.516484e+00)*S69'
.param V72_part8='V72_part7+(-3.670964e+01)*S70+0.000000e+00*S71+5.027715e+01*S72+3.454205e+01*S73+0.000000e+00*S74+1.958463e+01*S75+7.336861e+01*S76+0.000000e+00*S77+(-3.149506e+01)*S78+8.497747e+00*S79'
.param V72='V72_part8+0.000000e+00*S80+(-9.760083e+01)*S81+4.640813e+01*S82+0.000000e+00*S83+5.550876e+01*S84+3.467373e+01*S85+0.000000e+00*S86+6.730584e+01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V73_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+(-3.344593e-02)*S3+(-1.605226e+00)*S4+0.000000e+00*S5+5.112992e+00*S6+3.153802e+00*S7+0.000000e+00*S8+5.570356e+00*S9'
.param V73_part2='V73_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-3.555665e+00)*S15+(-7.388657e-01)*S16+(-2.032687e+01)*S17+7.736251e-01*S18+(-1.191007e+00)*S19'
.param V73_part3='V73_part2+(-2.042292e+01)*S20+3.752118e+00*S21+(-3.254334e+00)*S22+(-2.464623e+01)*S23+1.234207e+01*S24+(-1.608522e+01)*S25+(-9.298138e+00)*S26+9.478312e+00*S27+(-1.966993e+01)*S28+(-4.856491e+00)*S29'
.param V73_part4='V73_part3+(-1.489786e+01)*S30+(-4.166387e+00)*S31+(-1.001499e+01)*S32+(-6.547677e+00)*S33+(-5.564828e+00)*S34+(-1.209486e+01)*S35+(-7.069004e+00)*S36+(-6.157261e+00)*S37+(-1.561785e+01)*S38+(-5.775533e+00)*S39'
.param V73_part5='V73_part4+(-1.097758e+01)*S40+(-1.551423e+01)*S41+(-7.811662e+00)*S42+(-1.126853e+01)*S43+(-1.325352e+01)*S44+(-1.812661e+00)*S45+(-1.462197e+01)*S46+(-9.340586e+00)*S47+(-8.875908e-01)*S48+(-1.635717e+01)*S49'
.param V73_part6='V73_part5+(-1.010168e+01)*S50+(-5.966845e-01)*S51+(-1.568157e+00)*S52+(-1.068293e+01)*S53+(-2.950793e+00)*S54+1.299425e+00*S55+6.105712e+00*S56+(-3.953729e+00)*S57+8.562885e+00*S58+0.000000e+00*S59'
.param V73_part7='V73_part6+(-8.721846e+00)*S60+(-1.273644e+01)*S61+(-1.206150e+01)*S62+(-7.664283e+00)*S63+(-6.495605e+00)*S64+(-1.001659e+01)*S65+6.543061e-01*S66+(-1.780241e+00)*S67+0.000000e+00*S68+(-4.879015e+00)*S69'
.param V73_part8='V73_part7+3.577171e+00*S70+0.000000e+00*S71+(-1.461431e+01)*S72+8.002071e+00*S73+0.000000e+00*S74+(-1.544037e+01)*S75+(-1.591221e+01)*S76+0.000000e+00*S77+(-8.893475e+00)*S78+(-3.932168e+01)*S79'
.param V73='V73_part8+0.000000e+00*S80+(-1.399081e+01)*S81+(-9.634927e+00)*S82+0.000000e+00*S83+(-1.126853e+01)*S84+(-1.017332e+01)*S85+0.000000e+00*S86+1.373083e+01*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V74_part1='0.000000e+00*S0+0.000000e+00*S1+0.000000e+00*S2+(-1.136736e-03)*S3+(-1.472296e-02)*S4+0.000000e+00*S5+(-6.213440e-01)*S6+(-2.460200e-01)*S7+0.000000e+00*S8+(-5.572519e-02)*S9'
.param V74_part2='V74_part1+0.000000e+00*S10+0.000000e+00*S11+0.000000e+00*S12+0.000000e+00*S13+0.000000e+00*S14+(-5.189387e+00)*S15+(-6.329181e+00)*S16+1.440172e+01*S17+(-2.577817e+01)*S18+(-1.696659e+01)*S19'
.param V74_part3='V74_part2+4.918545e+00*S20+(-1.436769e+01)*S21+6.977675e-01*S22+2.802457e+00*S23+(-1.154813e+01)*S24+(-6.288953e+00)*S25+(-1.212532e+00)*S26+(-1.155693e+01)*S27+(-9.016606e+00)*S28+(-1.011214e+01)*S29'
.param V74_part4='V74_part3+2.846410e+00*S30+4.371845e+00*S31+6.900029e+00*S32+3.743222e+00*S33+3.801264e-01*S34+(-3.090479e+00)*S35+5.379941e-01*S36+(-2.275155e+00)*S37+(-1.245024e+01)*S38+2.091436e+00*S39'
.param V74_part5='V74_part4+(-1.878508e+00)*S40+(-1.412193e+01)*S41+(-1.039431e+01)*S42+(-8.625932e+00)*S43+(-1.924418e+01)*S44+5.738439e+00*S45+(-8.079776e+00)*S46+(-1.209445e+01)*S47+5.488658e+00*S48+(-1.148144e+01)*S49'
.param V74_part6='V74_part5+(-1.381768e+01)*S50+2.278396e+00*S51+(-4.059789e-01)*S52+(-1.286201e+01)*S53+(-3.945934e+00)*S54+(-4.154229e+00)*S55+(-1.611833e+01)*S56+(-1.145202e+01)*S57+(-6.431964e+00)*S58+0.000000e+00*S59'
.param V74_part7='V74_part6+3.697578e+00*S60+(-1.141427e+01)*S61+(-1.448760e+01)*S62+1.540763e+00*S63+(-1.035757e+01)*S64+(-2.896242e+01)*S65+(-3.442293e-01)*S66+(-1.343105e+01)*S67+0.000000e+00*S68+(-6.084471e+00)*S69'
.param V74_part8='V74_part7+(-5.825194e+00)*S70+0.000000e+00*S71+(-2.040874e+01)*S72+(-2.378743e+01)*S73+0.000000e+00*S74+(-6.185461e+00)*S75+(-1.315224e+01)*S76+0.000000e+00*S77+(-7.676221e+00)*S78+(-1.926407e+01)*S79'
.param V74='V74_part8+0.000000e+00*S80+(-7.625667e+00)*S81+(-1.629128e+01)*S82+0.000000e+00*S83+(-1.825257e+01)*S84+(-4.020993e+01)*S85+0.000000e+00*S86+(-4.877468e+01)*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V75_part1='8.941800e+01*S0+9.190865e+01*S1+1.580512e+02*S2+(-2.528178e+02)*S3+3.974745e+02*S4+5.924705e+03*S5+5.622569e+03*S6+1.000000e+04*S7+1.000000e+04*S8+3.439281e+02*S9'
.param V75_part2='V75_part1+4.654620e+03*S10+1.000000e+04*S11+1.450854e+03*S12+8.090859e+03*S13+6.909364e+01*S14+7.426417e+03*S15+7.420696e+03*S16+(-1.930511e+03)*S17+7.509194e+03*S18+7.558829e+03*S19'
.param V75_part3='V75_part2+2.107934e+01*S20+1.391976e+00*S21+1.145259e+01*S22+2.020606e+01*S23+(-8.246980e-01)*S24+4.837368e+00*S25+1.006625e+01*S26+(-1.162606e+00)*S27+4.015474e+00*S28+7.540143e+00*S29'
.param V75_part4='V75_part3+(-1.326121e+00)*S30+9.579210e+00*S31+7.498130e+00*S32+(-1.468580e+00)*S33+(-2.149582e+00)*S34+1.903845e+00*S35+(-9.166289e-01)*S36+(-8.393114e-01)*S37+1.500476e+00*S38+(-1.192412e-01)*S39'
.param V75_part5='V75_part4+(-4.554596e-01)*S40+1.250270e+00*S41+(-7.595253e-01)*S42+(-3.778541e-02)*S43+9.413931e-01*S44+(-1.147454e-01)*S45+4.770832e-01*S46+1.407449e+00*S47+(-1.157229e-01)*S48+(-2.498920e-01)*S49'
.param V75_part6='V75_part5+1.041818e+00*S50+(-8.758209e-02)*S51+(-6.727976e-02)*S52+8.047097e-01*S53+(-6.152008e-02)*S54+(-5.115357e-02)*S55+4.792000e-01*S56+(-5.443407e-02)*S57+(-1.584630e-02)*S58+3.990420e-01*S59'
.param V75_part7='V75_part6+(-6.733095e-02)*S60+(-4.886829e-01)*S61+8.675894e-01*S62+7.793478e-02*S63+(-2.736725e-02)*S64+4.233040e-01*S65+(-6.059543e-03)*S66+(-1.473955e-02)*S67+2.007114e-01*S68+(-8.455969e-04)*S69'
.param V75_part8='V75_part7+5.190521e-03*S70+1.714518e-01*S71+(-9.063535e-03)*S72+3.159655e-02*S73+1.403020e-01*S74+(-1.582541e-02)*S75+4.874755e-02*S76+1.617600e-01*S77+2.550419e-02*S78+5.385769e-02*S79'
.param V75='V75_part8+1.215203e-01*S80+3.634239e-02*S81+2.796687e-02*S82+1.953590e-01*S83+3.545250e-02*S84+4.096425e-02*S85+(-3.178263e-02)*S86+3.311673e-02*S87+5.779147e-02*S88+8.759006e-03*S89'
.param V76_part1='1.270294e+00*S0+2.097881e+02*S1+3.872521e+02*S2+1.496370e+03*S3+3.167449e+02*S4+1.611401e+02*S5+5.623172e+03*S6+1.000000e+04*S7+1.000000e+04*S8+6.308262e+01*S9'
.param V76_part2='V76_part1+(-1.000000e+04)*S10+1.000000e+04*S11+5.419071e+02*S12+3.984642e+02*S13+4.661392e+01*S14+9.392945e+01*S15+2.157815e+02*S16+(-1.221463e+02)*S17+1.582178e+01*S18+(-6.921384e+01)*S19'
.param V76_part3='V76_part2+(-4.170215e+00)*S20+(-1.935602e+00)*S21+(-8.668299e+00)*S22+(-6.871742e+00)*S23+1.311146e-01*S24+(-4.445612e+00)*S25+(-2.220921e+00)*S26+2.900981e-01*S27+(-3.111143e+00)*S28+(-1.308033e+00)*S29'
.param V76_part4='V76_part3+(-1.297265e+01)*S30+(-5.661296e+00)*S31+(-9.921290e-01)*S32+3.691114e-01*S33+5.185997e-01*S34+(-9.300416e-01)*S35+2.478306e-01*S36+2.877222e-01*S37+(-5.999039e-01)*S38+(-1.030751e-02)*S39'
.param V76_part5='V76_part4+8.862280e-02*S40+(-4.140897e-01)*S41+9.436234e-02*S42+(-2.035388e-01)*S43+(-3.761556e-01)*S44+1.369289e-01*S45+(-1.595052e+00)*S46+(-8.229005e-01)*S47+1.108121e-01*S48+(-2.331815e-01)*S49'
.param V76_part6='V76_part5+(-5.014559e-01)*S50+5.492660e-02*S51+4.770662e-02*S52+(-4.047492e-01)*S53+2.812767e-02*S54+2.646511e-02*S55+(-1.807771e-01)*S56+2.083428e-02*S57+5.607465e-03*S58+(-1.153735e-01)*S59'
.param V76_part7='V76_part6+1.993320e-03*S60+(-1.969816e-02)*S61+(-4.896282e-01)*S62+(-3.168006e-02)*S63+(-1.626741e-02)*S64+(-2.614388e-01)*S65+(-3.980313e-02)*S66+(-2.327212e-02)*S67+(-8.515903e-02)*S68+(-2.887723e-02)*S69'
.param V76_part8='V76_part7+(-1.839747e-02)*S70+(-3.103805e-03)*S71+(-2.250303e-02)*S72+(-2.378022e-02)*S73+(-3.605499e-02)*S74+(-1.159592e-01)*S75+(-1.320626e-01)*S76+(-2.224731e-01)*S77+(-7.936372e-02)*S78+(-9.682479e-02)*S79'
.param V76='V76_part8+(-7.615428e-02)*S80+(-6.791005e-02)*S81+(-2.672843e-02)*S82+(-1.369047e-01)*S83+(-4.513801e-02)*S84+(-3.403096e-02)*S85+(-2.493291e-01)*S86+(-2.835006e-02)*S87+(-3.770405e-02)*S88+(-8.716276e-03)*S89'
.param V77_part1='(-6.156827e+01)*S0+1.573674e+02*S1+3.228634e+02*S2+7.579618e+01*S3+1.005609e+03*S4+5.090977e+03*S5+5.623172e+03*S6+1.000000e+04*S7+1.000000e+04*S8+3.104500e+02*S9'
.param V77_part2='V77_part1+9.998815e+03*S10+2.289490e+03*S11+8.642009e+02*S12+4.040107e+01*S13+(-1.065554e+01)*S14+2.366505e+02*S15+1.647509e+02*S16+(-1.904815e+02)*S17+1.958129e+01*S18+(-1.077727e+01)*S19'
.param V77_part3='V77_part2+(-1.735669e+01)*S20+(-6.098769e-01)*S21+(-1.015602e+01)*S22+(-1.426996e+01)*S23+5.892183e-01*S24+(-5.279300e+00)*S25+(-6.891315e+00)*S26+8.400932e-01*S27+(-2.394705e+00)*S28+(-5.069227e+00)*S29'
.param V77_part4='V77_part3+1.636025e+00*S30+(-1.050465e+01)*S31+(-6.173699e+00)*S32+6.719436e-01*S33+1.367556e+00*S34+(-1.060931e+00)*S35+3.330417e-01*S36+5.184030e-01*S37+(-8.272206e-01)*S38+7.924283e-01*S39'
.param V77_part5='V77_part4+2.592340e-01*S40+(-6.525208e-01)*S41+4.465951e-01*S42+1.770402e-01*S43+(-3.965653e-01)*S44+4.233657e-01*S45+(-2.516676e-01)*S46+(-9.118187e-01)*S47+4.032543e-01*S48+2.048816e-01*S49'
.param V77_part6='V77_part5+(-5.975602e-01)*S50+3.602620e-01*S51+2.573740e-01*S52+(-3.499622e-01)*S53+3.079783e-01*S54+2.323657e-01*S55+(-1.438551e-01)*S56+2.904244e-01*S57+1.854875e-01*S58+(-9.351419e-02)*S59'
.param V77_part7='V77_part6+4.141583e-01*S60+3.949043e-01*S61+(-4.911702e-01)*S62+4.467421e-01*S63+2.516116e-01*S64+(-9.224846e-02)*S65+2.808128e-01*S66+2.138114e-01*S67+4.161439e-02*S68+2.458691e-01*S69'
.param V77_part8='V77_part7+1.662912e-01*S70+1.400091e-03*S71+2.627088e-01*S72+1.171773e-01*S73+6.353194e-02*S74+3.864835e-01*S75+2.128265e-01*S76+1.234577e-01*S77+2.844552e-01*S78+1.738131e-01*S79'
.param V77='V77_part8+1.031598e-01*S80+2.479349e-01*S81+1.468385e-01*S82+5.462763e-02*S83+2.063212e-01*S84+1.207776e-01*S85+4.680857e-02*S86+1.877737e-01*S87+8.704346e-02*S88+8.592369e-02*S89'
.param V78_part1='1.056144e+02*S0+5.266225e+02*S1+3.989618e+01*S2+(-9.651814e-01)*S3+4.256323e+00*S4+3.090645e+01*S5+1.000000e+04*S6+1.000000e+04*S7+4.945636e+01*S8+2.267123e+02*S9'
.param V78_part2='V78_part1+2.558037e+00*S10+1.000000e+04*S11+4.645989e+00*S12+1.725802e+02*S13+2.745629e+02*S14+(-1.000000e+04)*S15+(-1.000000e+04)*S16+5.407674e+00*S17+(-1.000000e+04)*S18+(-1.000000e+04)*S19'
.param V78_part3='V78_part2+(-2.249627e-01)*S20+(-1.350065e-01)*S21+1.589510e-02*S22+(-9.939329e-01)*S23+3.843473e-02*S24+3.289504e-01*S25+(-2.820897e-01)*S26+4.051798e-02*S27+1.522260e-01*S28+(-3.503411e-01)*S29'
.param V78_part4='V78_part3+2.765997e-01*S30+(-1.996503e-01)*S31+2.391018e-01*S32+9.053516e-02*S33+1.859940e-01*S34+1.785403e-02*S35+4.248571e-02*S36+1.020757e-01*S37+1.873354e-02*S38+8.258492e-02*S39'
.param V78_part5='V78_part4+8.333154e-02*S40+1.144688e-02*S41+5.355774e-02*S42+6.741884e-02*S43+6.462550e-02*S44+1.137117e-02*S45+3.581889e-02*S46+2.836214e-02*S47+1.396701e-02*S48+5.211104e-02*S49'
.param V78_part6='V78_part5+2.839587e-02*S50+1.519901e-02*S51+1.179829e-02*S52+2.932288e-02*S53+1.352549e-02*S54+1.403115e-02*S55+3.722130e-02*S56+1.655200e-02*S57+1.190914e-02*S58+2.787558e-02*S59'
.param V78_part7='V78_part6+1.578698e-02*S60+4.232413e-02*S61+8.584943e-03*S62+3.131204e-02*S63+1.570568e-02*S64+8.978977e-03*S65+1.568657e-02*S66+1.162175e-02*S67+1.183934e-02*S68+1.789421e-02*S69'
.param V78_part8='V78_part7+9.471785e-03*S70+4.098007e-04*S71+1.752466e-02*S72+1.038363e-02*S73+6.393569e-03*S74+1.295150e-02*S75+1.168170e-02*S76+1.499781e-02*S77+1.141139e-02*S78+1.036146e-02*S79'
.param V78='V78_part8+1.438833e-02*S80+1.299214e-02*S81+7.906187e-03*S82+1.583055e-02*S83+1.046630e-02*S84+7.652145e-03*S85+3.137627e-02*S86+9.535005e-03*S87+7.768066e-03*S88+3.618464e-03*S89'
.param V79_part1='3.753775e-01*S0+2.250114e-02*S1+2.101281e+02*S2+2.061644e+00*S3+3.721015e+02*S4+2.099741e+03*S5+5.623172e+03*S6+1.000000e+04*S7+9.257751e+03*S8+5.271912e+01*S9'
.param V79_part2='V79_part1+1.874813e+03*S10+1.000000e+04*S11+4.923913e+02*S12+2.600665e+02*S13+(-1.427190e+00)*S14+1.646923e+01*S15+1.195372e+01*S16+4.401711e+03*S17+5.287834e+00*S18+7.656840e+00*S19'
.param V79_part3='V79_part2+4.878699e+00*S20+1.103429e+00*S21+4.857908e+00*S22+6.703421e+00*S23+1.463516e+00*S24+9.189771e+00*S25+2.430151e+00*S26+1.713047e+00*S27+4.701335e+00*S28+1.813697e+00*S29'
.param V79_part4='V79_part3+1.117846e+01*S30+3.450001e+00*S31+4.525691e+00*S32+2.582685e+00*S33+3.445405e+00*S34+4.499845e-01*S35+1.620510e+00*S36+1.388768e+00*S37+4.006909e-01*S38+1.123006e-01*S39'
.param V79_part5='V79_part4+1.063379e+00*S40+3.571421e-01*S41+1.491170e+00*S42+8.767566e-01*S43+3.921473e-01*S44+5.328750e-02*S45+7.780576e-01*S46+3.529964e-01*S47+6.850353e-02*S48+9.507019e-01*S49'
.param V79_part6='V79_part5+2.683683e-01*S50+8.078999e-02*S51+9.230110e-02*S52+1.943185e-01*S53+9.017550e-02*S54+9.755365e-02*S55+1.648924e-01*S56+9.328049e-02*S57+9.647249e-02*S58+1.399042e-01*S59'
.param V79_part7='V79_part6+6.277491e-02*S60+1.065768e+00*S61+1.744078e-01*S62+(-2.513345e-02)*S63+7.818930e-02*S64+8.951065e-02*S65+7.101349e-02*S66+8.002310e-02*S67+5.914862e-02*S68+7.104848e-02*S69'
.param V79_part8='V79_part7+7.543564e-02*S70+7.010058e-02*S71+7.035515e-02*S72+7.186670e-02*S73+4.517911e-02*S74+5.954129e-02*S75+5.337349e-02*S76+2.704297e-02*S77+4.381806e-02*S78+4.941173e-02*S79'
.param V79='V79_part8+2.634343e-02*S80+4.079134e-02*S81+4.779755e-02*S82+2.193338e-02*S83+4.182704e-02*S84+4.657502e-02*S85+8.626771e-01*S86+3.784809e-02*S87+4.588632e-02*S88+3.712035e-02*S89'
.param V80_part1='0.000000e+00*S0+0.000000e+00*S1+4.000252e-02*S2+(-3.083413e-02)*S3+(-6.389475e-02)*S4+2.964618e-03*S5+(-5.002362e-02)*S6+(-7.247869e-02)*S7+(-5.859042e-02)*S8+(-1.044009e-02)*S9'
.param V80_part2='V80_part1+(-8.340192e-02)*S10+1.116881e-01*S11+7.888578e-02*S12+7.359054e-02*S13+(-5.925215e-02)*S14+(-1.479432e-01)*S15+(-1.791056e-01)*S16+(-4.064666e-01)*S17+(-2.201243e-01)*S18+(-3.509858e-01)*S19'
.param V80_part3='V80_part2+3.467772e-02*S20+1.008534e+00*S21+5.591589e-01*S22+(-2.228093e-01)*S23+2.389224e+00*S24+5.596419e-01*S25+2.164787e-01*S26+2.115236e+00*S27+5.448234e-01*S28+2.406125e-01*S29'
.param V80_part4='V80_part3+5.522084e-01*S30+(-4.598158e-02)*S31+1.046474e+00*S32+1.551162e+00*S33+1.023745e+00*S34+7.509481e-01*S35+2.957433e+00*S36+2.223150e+00*S37+1.318232e+00*S38+6.919022e+00*S39'
.param V80_part5='V80_part4+2.975992e+00*S40+1.933975e+00*S41+3.280051e+00*S42+2.788713e+00*S43+2.797010e+00*S44+0.000000e+00*S45+2.080568e+00*S46+1.087153e+00*S47+0.000000e+00*S48+3.379753e+00*S49'
.param V80_part6='V80_part5+2.218938e+00*S50+0.000000e+00*S51+0.000000e+00*S52+4.301309e+00*S53+0.000000e+00*S54+0.000000e+00*S55+4.662582e+00*S56+0.000000e+00*S57+0.000000e+00*S58+6.673599e+00*S59'
.param V80_part7='V80_part6+0.000000e+00*S60+3.915061e+00*S61+3.165683e+00*S62+0.000000e+00*S63+0.000000e+00*S64+9.105664e+00*S65+0.000000e+00*S66+0.000000e+00*S67+1.578594e+01*S68+0.000000e+00*S69'
.param V80_part8='V80_part7+0.000000e+00*S70+7.336776e+00*S71+0.000000e+00*S72+0.000000e+00*S73+2.830437e+01*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V80='V80_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+2.646424e+00*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V81_part1='0.000000e+00*S0+0.000000e+00*S1+1.135356e-01*S2+9.633741e-02*S3+1.207361e-01*S4+5.610362e-03*S5+7.492729e-02*S6+1.143016e-01*S7+1.314784e-01*S8+8.817526e-02*S9'
.param V81_part2='V81_part1+1.345306e-01*S10+2.573738e-02*S11+6.221163e-02*S12+5.868430e-02*S13+1.913623e-01*S14+9.002701e-01*S15+8.087779e-01*S16+1.371042e+00*S17+7.716197e-01*S18+1.232429e+00*S19'
.param V81_part3='V81_part2+3.644480e-01*S20+1.783676e+00*S21+4.295400e-01*S22+6.439114e-01*S23+4.747719e-01*S24+4.910605e-01*S25+5.075416e-01*S26+6.140540e-01*S27+6.089456e-01*S28+6.402917e-01*S29'
.param V81_part4='V81_part3+6.298908e-01*S30+1.753170e+00*S31+3.551000e-01*S32+1.182648e+00*S33+8.719997e-01*S34+2.254101e+00*S35+1.130391e+00*S36+1.670399e+00*S37+2.018058e+00*S38+4.109514e-01*S39'
.param V81_part5='V81_part4+1.550598e+00*S40+1.959037e+00*S41+1.596552e+00*S42+2.018603e+00*S43+1.852449e+00*S44+0.000000e+00*S45+4.630645e+00*S46+5.187885e+00*S47+0.000000e+00*S48+3.568908e+00*S49'
.param V81_part6='V81_part5+5.165889e+00*S50+0.000000e+00*S51+0.000000e+00*S52+4.429630e+00*S53+0.000000e+00*S54+0.000000e+00*S55+5.574344e+00*S56+0.000000e+00*S57+0.000000e+00*S58+5.015244e+00*S59'
.param V81_part7='V81_part6+0.000000e+00*S60+4.541532e+00*S61+9.415793e+00*S62+0.000000e+00*S63+0.000000e+00*S64+6.165134e+00*S65+0.000000e+00*S66+0.000000e+00*S67+5.723945e+00*S68+0.000000e+00*S69'
.param V81_part8='V81_part7+0.000000e+00*S70+1.619382e+01*S71+0.000000e+00*S72+0.000000e+00*S73+(-6.294041e-01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V81='V81_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+1.748534e+01*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V82_part1='0.000000e+00*S0+0.000000e+00*S1+(-6.427606e-02)*S2+7.461561e-03*S3+6.283581e-02*S4+3.443734e-02*S5+9.747789e-02*S6+7.915463e-02*S7+7.926445e-02*S8+6.081078e-02*S9'
.param V82_part2='V82_part1+9.012790e-02*S10+1.250383e-02*S11+(-2.277153e-02)*S12+6.578040e-03*S13+1.233349e-01*S14+1.210507e-01*S15+2.527231e-01*S16+4.610425e-01*S17+6.780906e-01*S18+4.930479e-01*S19'
.param V82_part3='V82_part2+7.119025e-01*S20+(-4.448362e-01)*S21+4.861708e-01*S22+8.533749e-01*S23+(-1.071143e+00)*S24+2.642695e-01*S25+7.099240e-01*S26+(-1.006556e+00)*S27+4.102527e-01*S28+6.602011e-01*S29'
.param V82_part4='V82_part3+(-2.245728e-01)*S30+1.233943e+00*S31+(-8.817916e-02)*S32+(-3.418304e-01)*S33+(-4.958053e-02)*S34+1.748990e+00*S35+4.367469e-01*S36+(-9.417712e-02)*S37+1.608772e+00*S38+(-5.883228e+00)*S39'
.param V82_part5='V82_part4+3.052182e-01*S40+1.285154e+00*S41+(-3.717089e-02)*S42+4.834159e-01*S43+5.495113e-01*S44+0.000000e+00*S45+1.256186e+00*S46+2.489976e+00*S47+0.000000e+00*S48+8.738152e-01*S49'
.param V82_part6='V82_part5+2.020412e+00*S50+0.000000e+00*S51+0.000000e+00*S52+8.700319e-01*S53+0.000000e+00*S54+0.000000e+00*S55+3.081046e-02*S56+0.000000e+00*S57+0.000000e+00*S58+(-3.962546e-01)*S59'
.param V82_part7='V82_part6+0.000000e+00*S60+1.552153e+00*S61+2.736807e+00*S62+0.000000e+00*S63+0.000000e+00*S64+(-1.851950e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-7.171068e+00)*S68+0.000000e+00*S69'
.param V82_part8='V82_part7+0.000000e+00*S70+(-5.219917e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+(-2.128833e+01)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V82='V82_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+1.083855e+01*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V83_part1='0.000000e+00*S0+0.000000e+00*S1+4.535504e-02*S2+2.917817e-02*S3+3.355284e-02*S4+7.138276e-02*S5+5.555506e-02*S6+4.957195e-02*S7+7.494013e-02*S8+6.298282e-02*S9'
.param V83_part2='V83_part1+3.939701e-02*S10+9.087246e-02*S11+7.959489e-02*S12+9.544604e-02*S13+(-1.169494e-02)*S14+5.526319e-02*S15+4.092076e-02*S16+8.759223e-02*S17+4.258814e-02*S18+(-3.359517e-02)*S19'
.param V83_part3='V83_part2+(-1.440455e-02)*S20+(-2.331963e-01)*S21+(-1.795579e-01)*S22+5.794048e-02*S23+(-2.871150e-01)*S24+(-5.112299e-02)*S25+(-8.958309e-02)*S26+(-2.368601e-01)*S27+(-4.376908e-02)*S28+(-1.289650e-01)*S29'
.param V83_part4='V83_part3+(-5.017492e-02)*S30+(-2.963200e-03)*S31+(-2.197628e-01)*S32+(-2.389705e-01)*S33+(-1.678981e-01)*S34+(-2.057237e-01)*S35+(-1.846764e-01)*S36+(-2.960934e-01)*S37+(-2.401937e-01)*S38+(-7.013860e-01)*S39'
.param V83_part5='V83_part4+(-2.484819e-01)*S40+(-3.213716e-01)*S41+(-2.644937e-01)*S42+(-3.202341e-01)*S43+(-3.353013e-01)*S44+0.000000e+00*S45+(-1.402105e-01)*S46+(-3.346601e-01)*S47+0.000000e+00*S48+(-2.438923e-01)*S49'
.param V83_part6='V83_part5+(-4.966107e-01)*S50+0.000000e+00*S51+0.000000e+00*S52+(-7.298660e-01)*S53+0.000000e+00*S54+0.000000e+00*S55+(-9.267098e-01)*S56+0.000000e+00*S57+0.000000e+00*S58+(-9.320796e-01)*S59'
.param V83_part7='V83_part6+0.000000e+00*S60+(-4.185434e-01)*S61+(-8.007615e-01)*S62+0.000000e+00*S63+0.000000e+00*S64+(-1.416275e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-3.351072e+00)*S68+0.000000e+00*S69'
.param V83_part8='V83_part7+0.000000e+00*S70+(-6.417435e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+(-1.693850e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V83='V83_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+(-9.584985e-01)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param V84_part1='0.000000e+00*S0+0.000000e+00*S1+3.569739e-03*S2+(-6.566264e-04)*S3+(-6.311844e-04)*S4+5.793599e-04*S5+3.671086e-03*S6+2.281177e-03*S7+(-1.816719e-03)*S8+(-1.012485e-03)*S9'
.param V84_part2='V84_part1+1.474986e-03*S10+(-5.169650e-05)*S11+(-3.868318e-03)*S12+(-1.541387e-03)*S13+2.562318e-03*S14+1.458440e-02*S15+1.884963e-02*S16+(-1.800690e-01)*S17+(-1.177435e-02)*S18+1.147754e-03*S19'
.param V84_part3='V84_part2+(-1.280402e-01)*S20+(-5.973056e-01)*S21+(-2.477728e-01)*S22+(-1.946368e-01)*S23+(-8.375777e-01)*S24+(-2.640151e-01)*S25+(-2.514087e-01)*S26+(-7.916527e-01)*S27+(-3.529177e-01)*S28+(-2.669635e-01)*S29'
.param V84_part4='V84_part3+(-1.106610e-01)*S30+(-2.205395e-01)*S31+(-2.713515e-01)*S32+(-7.239354e-01)*S33+(-3.989781e-01)*S34+(-8.743098e-01)*S35+(-1.467193e+00)*S36+(-1.223548e+00)*S37+(-1.086530e+00)*S38+(-1.755432e+00)*S39'
.param V84_part5='V84_part4+(-1.502240e+00)*S40+(-1.309531e+00)*S41+(-1.724467e+00)*S42+(-1.647984e+00)*S43+(-1.416447e+00)*S44+0.000000e+00*S45+(-1.159404e+00)*S46+(-1.204711e+00)*S47+0.000000e+00*S48+(-1.795716e+00)*S49'
.param V84_part6='V84_part5+(-1.749649e+00)*S50+0.000000e+00*S51+0.000000e+00*S52+(-2.343544e+00)*S53+0.000000e+00*S54+0.000000e+00*S55+(-2.818510e+00)*S56+0.000000e+00*S57+0.000000e+00*S58+(-3.957675e+00)*S59'
.param V84_part7='V84_part6+0.000000e+00*S60+(-2.658341e+00)*S61+(-2.098080e+00)*S62+0.000000e+00*S63+0.000000e+00*S64+(-3.225157e+00)*S65+0.000000e+00*S66+0.000000e+00*S67+(-6.029332e+00)*S68+0.000000e+00*S69'
.param V84_part8='V84_part7+0.000000e+00*S70+(-5.970028e+00)*S71+0.000000e+00*S72+0.000000e+00*S73+(-3.785219e+00)*S74+0.000000e+00*S75+0.000000e+00*S76+0.000000e+00*S77+0.000000e+00*S78+0.000000e+00*S79'
.param V84='V84_part8+0.000000e+00*S80+0.000000e+00*S81+0.000000e+00*S82+0.000000e+00*S83+0.000000e+00*S84+0.000000e+00*S85+(-7.235006e+00)*S86+0.000000e+00*S87+0.000000e+00*S88+0.000000e+00*S89'
.param _P0='V0+V1*rad_+V2*w_'
.param _P1='_P0+V3*gdis_+V4*spacing_'
.param _P2='0.5*(_P1+sqrt(_P1*_P1+0.001))'
.param _P3='1e-09*_P2'
.param _P4='1e-09*_P2'
.param _P5='V5+V6*rad_+V7/w_'
.param _P6='_P5+V8*gdis_+V9*spacing_'
.param _P7='0.5*(_P6+sqrt(_P6*_P6+0.001))'
.param _P8='V10+V11*rad_+V12*w_'
.param _P9='_P8+V13*gdis_+V14*spacing_'
.param _P10='0.5*(_P9+sqrt(_P9*_P9+0.001))'
.param _P11='1e-09*_P10'
.param _P12='V15+V16*rad_+V17/w_'
.param _P13='_P12+V18*gdis_+V19*spacing_'
.param _P14='0.5*(_P13+sqrt(_P13*_P13+0.001))'
.param _P15='1e-09*_P14'
.param _P16='V20+V21*rad_+V22*w_'
.param _P17='_P16+V23*gdis_+V24*spacing_'
.param _P18='0.5*(_P17+sqrt(_P17*_P17+0.001))'
.param _P19='1e-09*_P18'
.param _P20='1e-09*_P18'
.param _P21='V25+V26*rad_+V27/w_'
.param _P22='_P21+V28*gdis_+V29*spacing_'
.param _P23='0.5*(_P22+sqrt(_P22*_P22+0.001))'
.param _P24='V30+V31*rad_+V32*w_'
.param _P25='_P24+V33*gdis_+V34*spacing_'
.param _P26='0.5*(_P25+sqrt(_P25*_P25+0.001))'
.param _P27='1e-09*_P26'
.param _P28='V35+V36*rad_+V37/w_'
.param _P29='_P28+V38*gdis_+V39*spacing_'
.param _P30='0.5*(_P29+sqrt(_P29*_P29+0.001))'
.param _P31='1e-09*_P30'
.param _P32='V40+V41*rad_+V42*w_'
.param _P33='_P32+V43*gdis_+V44*spacing_'
.param _P34='atan(_P33-0.5)/1.5708'
.param _P35='V45+V46*rad_+V47*w_'
.param _P36='_P35+V48*gdis_+V49*spacing_'
.param _P37='atan(_P36-0.5)/1.5708'
.param _P38='0.5*_P34+0.5*_P37'
.param _P39='0.5*_P34-0.5*_P37'
.param _P40='V50+V51*rad_+V52*w_'
.param _P41='_P40+V53*gdis_+V54*spacing_'
.param _P42='0.5*(_P41+sqrt(_P41*_P41+0.001))'
.param _P43='1e-09*_P42'
.param _P44='1e-09*_P42'
.param _P45='1e-06'
.param _P46='V55+V56*rad_+V57*w_'
.param _P47='_P46+V58*gdis_+V59*spacing_'
.param _P48='0.5*(_P47+sqrt(_P47*_P47+0.001))'
.param _P49='1e-15*_P48'
.param _P50='V60+V61*rad_+V62*w_'
.param _P51='_P50+V63*gdis_+V64*spacing_'
.param _P52='0.5*(_P51+sqrt(_P51*_P51+0.001))'
.param _P53='V65+V66*rad_+V67*w_'
.param _P54='_P53+V68*gdis_+V69*spacing_'
.param _P55='0.5*(_P54+sqrt(_P54*_P54+0.001))'
.param _P56='V70+V71*rad_+V72*w_'
.param _P57='_P56+V73*gdis_+V74*spacing_'
.param _P58='0.5*(_P57+sqrt(_P57*_P57+0.001))'
.param _P59='1e-14*_P52'
.param _P60='100*_P55'
.param _P61='1e-15*_P58'
.param _P62='1e-14*_P52'
.param _P63='100*_P55'
.param _P64='1e-15*_P58'
.param _P65='V75+V76*rad_+V77*w_'
.param _P66='_P65+V78*gdis_+V79*spacing_'
.param _P67='0.5*(_P66+sqrt(_P66*_P66+0.001))'
.param _P68='V80+V81*rad_+V82*w_'
.param _P69='_P68+V83*gdis_+V84*spacing_'
.param _P70='0.5*(_P69+sqrt(_P69*_P69+0.001))'
.param _P71='100*_P67'
.param _P72='1e-13*_P70'
l1_sect1 top _n1i_sect1 '_P3* l_indfac'
l2_sect1 _n2i_sect1 bottom '_P4* l_indfac'
r1_sect1 _n1i_sect1 _n_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect1 _n_sect1 _n2i_sect1 '_P7*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect1 _nc_sect1 tap '_P11* l_indfac'
rc_sect1 _n_sect1 _nc_sect1 '(_P15+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
l1_sect2 top _n1i_sect2 '_P19* l_indfac'
l2_sect2 _n2i_sect2 bottom '_P20* l_indfac'
r1_sect2 _n1i_sect2 _n_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
r2_sect2 _n_sect2 _n2i_sect2 '_P23*(0.0026*(temper-25)+1)*rm9_indfac'
lc_sect2 _nc_sect2 tap '_P27* l_indfac'
rc_sect2 _n_sect2 _nc_sect2 '(_P31+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
k12_sect1 l1_sect1 l2_sect1 K=_P38
k12_sect2 l1_sect2 l2_sect2 K=_P38
ks1s2_1 l1_sect1 l1_sect2 K=_P39
ks1s2_2 l2_sect1 l2_sect2 K=_P39
lx1 _n1i_sect1 _nx1 '_P43* l_indfac'
lx2 _n2i_sect1 _nx2 '_P44* l_indfac'
rx1 _nx1 _n1i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
rx2 _nx2 _n2i_sect2 '(_P45+1.2e-5)*(0.0026*(temper-25)+1)*rm9_indfac'
c12 top bottom '_P49*c12_indfac'
c_1_sub top _n1_1_sub '_P59*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4*3)))/(0.0440289))* cm9_indfac'
rs_1_sub _n1_1_sub gnode '_P60* rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_1_sub _n1_1_sub gnode '_P61* csub_indfac'
c_2_sub bottom _n1_2_sub '_P62*((1/(12.503905+(1.7014125)*(lay-2-(lay-8)/4*3)))/(0.0440289))* cm9_indfac'
rs_2_sub _n1_2_sub gnode '_P63* rsub_indfac*(-0.0000114365*(temper-25)*(temper-25)+0.0045985091*(temper-25)+1)'
cs_2_sub _n1_2_sub gnode '_P64* csub_indfac'
rx_1_2_sub _n1_1_sub _n1_2_sub '_P71* rsub_indfac'
cx_1_2_sub _n1_1_sub _n1_2_sub '_P72* csub_indfac'
kzero1 l1_sect1 l2_sect2 K=1e-6
kzero2 l1_sect2 l2_sect1 K=1e-6
.ends spiral_sym_ct_mza_a

.ENDL RF_IND




***************************************************************************
* RF MOS VARACTOR MODEL : 
*
*  
*     ## library files:
*     
*           
*      Model name	        wr (um)         lr (um)            gr             br  
*                           low   high      low     high       low    high    low    high
*      -------------------------------------------------------------------------
*       moscap_rf	    0.4    3.2      0.2      3.2        1      16      2      64 
*       moscap_rf_nw	    0.4    3.2      0.2      3.2        1      16      2      64
*       pmoscap_rf	    0.4    3.2      0.2      3.2        1      16      2      64
*       moscap_rf_hvt	    0.4    3.2      0.2      3.2        1      16      2      64 
*       moscap_rf_hvt_nw    0.4    3.2      0.2      3.2        1      16      2      64
*       moscap_rf25	    0.4    3.2      0.4      3.2        1      16      2      64 
*       moscap_rf25_nw	    0.4    3.2      0.4      3.2        1      16      2      64 
*       pmoscap_rf25	    0.4    3.2      0.4      3.2        1      16      2      64  
*      -------------------------------------------------------------------------
*	End Model
***************************************************************************


.LIB scale_option_caprf
.param scale_caprf=1
.ENDL scale_option_caprf

.LIB scale_option_caprfhvt
.param scale_caprfhvt=1
.ENDL scale_option_caprfhvt

.LIB scale_option_caprf25
.param scale_caprf25=1
.ENDL scale_option_caprf25

********************************************************
************* 1.2V MOS Varactor Corner Parameters ***********
********************************************************
.lib MC_RFMVAR
.lib 'crn65lp_v1d5.l' scale_option_caprf
.param
+parmvarrf=AGAUSS(0,1,1)
+A1_varrf='-par1*2.2203e+000*3/3' 
+A2_varrf='-par2*2.6509e-001*3/3' 
+Cgmin_Varrf       = '1.0000e+000+(4.4963e-002)*A1_varrf+(2.1870e-002)*A2_varrf'
+dCg_Varrf         = '1.0000e+000+(1.7086e-002)*A1_varrf+(8.3107e-003)*A2_varrf'
+dxL_Varrf         = '0.0000e+000+(-3.3722e-009)*A1_varrf+(-1.6403e-009)*A2_varrf'
+dxW_Varrf         = '0.0000e+000+(5.3956e-009)*A1_varrf+(2.6244e-009)*A2_varrf'
+fac_varrf         = '1.0000e+000+(6.8651e-001)*A1_varrf+(-1.4114e+000)*A2_varrf'
+ l_mvfacrf = 1
+ rm_mvfacrf = 1
+ rsub_mvfacrf = 1
+ csub_mvfacrf  = 1
.lib 'crn65lp_v1d5.l' RF_MVAR
.endl MC_RFMVAR


.LIB TT_RFMVAR
.lib 'crn65lp_v1d5.l' scale_option_caprf
.param
+parmvarrf=AGAUSS(0,1,1) 
+ l_mvfacrf = 1
+ rm_mvfacrf = 1
+ rsub_mvfacrf = 1
+ csub_mvfacrf  = 1
+ Cgmin_Varrf= 1        dCg_Varrf= 1         dxL_Varrf= 0            dxW_Varrf= 0
+ fac_varrf= 1
.lib 'crn65lp_v1d5.l' RF_MVAR
.ENDL TT_RFMVAR

.LIB FF_RFMVAR 
.lib 'crn65lp_v1d5.l' scale_option_caprf
.param
+parmvarrf=AGAUSS(0,1,1)
+ l_mvfacrf = 1.0235
+ rm_mvfacrf = 1.1
+ rsub_mvfacrf = 0.8
+ csub_mvfacrf  = 1.25
+ Cgmin_Varrf= 1.1      dCg_Varrf= 1.038    dxL_Varrf= -7.5E-09     dxW_Varrf= 12.0E-09
+ fac_varrf= 3.3
.lib 'crn65lp_v1d5.l' RF_MVAR
.ENDL FF_RFMVAR

.LIB SS_RFMVAR 
.lib 'crn65lp_v1d5.l' scale_option_caprf
.param 
+parmvarrf=AGAUSS(0,1,1)
+ l_mvfacrf = 0.9762
+ rm_mvfacrf = 0.9
+ rsub_mvfacrf = 1.2
+ csub_mvfacrf  = 0.833
+ Cgmin_Varrf= 0.9      dCg_Varrf= 0.962     dxL_Varrf= 7.5E-09      dxW_Varrf= -12.0E-09
+ fac_varrf= 0.3
.lib 'crn65lp_v1d5.l' RF_MVAR
.ENDL SS_RFMVAR

********************************************************
************* 1.2V HVT MOS Varactor Corner Parameters ***********
********************************************************
.lib MC_RFMVAR_HVT
.lib 'crn65lp_v1d5.l' scale_option_caprfhvt
.param
+parmvarrf_hvt=AGAUSS(0,1,1)
+A1_varrf_hvt='-par1*2.2203e+000*3/3' 
+A2_varrf_hvt='-par2*2.6509e-001*3/3' 
+Cgmin_Varrf_hvt       = '1.0000e+000+(4.4963e-002)*A1_varrf_hvt+(2.1870e-002)*A2_varrf_hvt'
+dCg_Varrf_hvt         = '1.0000e+000+(1.7086e-002)*A1_varrf_hvt+(8.3107e-003)*A2_varrf_hvt'
+dxL_Varrf_hvt         = '0.0000e+000+(-3.3722e-009)*A1_varrf_hvt+(-1.6403e-009)*A2_varrf_hvt'
+dxW_Varrf_hvt        = '0.0000e+000+(5.3956e-009)*A1_varrf_hvt+(2.6244e-009)*A2_varrf_hvt'
+fac_varrf_hvt        = '1.0000e+000+(6.8651e-001)*A1_varrf_hvt+(-1.4114e+000)*A2_varrf_hvt'
+ l_mvfacrf_hvt = 1
+ rm_mvfacrf_hvt = 1
+ rsub_mvfacrf_hvt = 1
+ csub_mvfacrf_hvt = 1
.lib 'crn65lp_v1d5.l' RF_MVAR_HVT
.endl MC_RFMVAR_HVT


.LIB TT_RFMVAR_HVT
.lib 'crn65lp_v1d5.l' scale_option_caprfhvt
.param
+parmvarrf_hvt=AGAUSS(0,1,1)
+ l_mvfacrf_hvt = 1
+ rm_mvfacrf_hvt = 1
+ rsub_mvfacrf_hvt = 1
+ csub_mvfacrf_hvt  = 1
+ Cgmin_Varrf_hvt= 1        dCg_Varrf_hvt= 1         dxL_Varrf_hvt= 0            dxW_Varrf_hvt= 0
+ fac_varrf_hvt= 1
.lib 'crn65lp_v1d5.l' RF_MVAR_HVT
.ENDL TT_RFMVAR_HVT

.LIB FF_RFMVAR_HVT 
.lib 'crn65lp_v1d5.l' scale_option_caprfhvt
.param
+parmvarrf_hvt=AGAUSS(0,1,1)
+ l_mvfacrf_hvt = 1.0235
+ rm_mvfacrf_hvt = 1.1
+ rsub_mvfacrf_hvt = 0.8
+ csub_mvfacrf_hvt  = 1.25
+ Cgmin_Varrf_hvt= 1.1      dCg_Varrf_hvt= 1.038    dxL_Varrf_hvt= -7.5E-09     dxW_Varrf_hvt= 12.0E-09
+ fac_varrf_hvt= 3.3
.lib 'crn65lp_v1d5.l' RF_MVAR_HVT
.ENDL FF_RFMVAR_HVT

.LIB SS_RFMVAR_HVT 
.lib 'crn65lp_v1d5.l' scale_option_caprfhvt
.param 
+parmvarrf_hvt=AGAUSS(0,1,1)
+ l_mvfacrf_hvt = 0.9762
+ rm_mvfacrf_hvt = 0.9
+ rsub_mvfacrf_hvt = 1.2
+ csub_mvfacrf_hvt  = 0.833
+ Cgmin_Varrf_hvt= 0.9      dCg_Varrf_hvt= 0.962     dxL_Varrf_hvt= 7.5E-09      dxW_Varrf_hvt= -12.0E-09
+ fac_varrf_hvt= 0.3
.lib 'crn65lp_v1d5.l' RF_MVAR_HVT
.ENDL SS_RFMVAR_HVT
********************************************************
************* 2.5V MOS Varactor Corner Parameters ***********
********************************************************
.lib MC_RFMVAR_25
.lib 'crn65lp_v1d5.l' scale_option_caprf25
.param
+parmvar_25rf=AGAUSS(0,1,1)
+A1_var_25rf='-par1*2.0000e+000*3/2.9' 
+Cgmin_Varrf25     = '1.0000e+000+(-5.0000e-002)*A1_var_25rf'
+dCg_Varrf25       = '1.0000e+000+(-2.6800e-002)*A1_var_25rf'
+dxL_Varrf25       = '0.0000e+000+(5.0000e-009)*A1_var_25rf'
+dxW_Varrf25       = '0.0000e+000+(-6.0000e-009)*A1_var_25rf'
+ l_mvfacrf25 = 1
+ rm_mvfacrf25 = 1
+ rsub_mvfacrf25 = 1
+ csub_mvfacrf25  = 1
.lib 'crn65lp_v1d5.l' RF_MVAR_25
.endl MC_RFMVAR_25

.LIB TT_RFMVAR_25  
.lib 'crn65lp_v1d5.l' scale_option_caprf25
.param 
+parmvar_25rf=AGAUSS(0,1,1)
+ l_mvfacrf25 = 1
+ rm_mvfacrf25 = 1
+ rsub_mvfacrf25 = 1
+ csub_mvfacrf25  = 1
+ Cgmin_Varrf25= 1     dCg_Varrf25= 1     dxL_Varrf25= 0     dxW_Varrf25= 0
.lib 'crn65lp_v1d5.l' RF_MVAR_25
.ENDL TT_RFMVAR_25


.LIB FF_RFMVAR_25 
.lib 'crn65lp_v1d5.l' scale_option_caprf25
.param
+parmvar_25rf=AGAUSS(0,1,1)
+ l_mvfacrf25 = 1.0235
+ rm_mvfacrf25 = 1.1
+ rsub_mvfacrf25 = 0.8
+ csub_mvfacrf25  = 1.25
+ Cgmin_Varrf25= 1.1     dCg_Varrf25= 1.0536     dxL_Varrf25= -1.0E-08     dxW_Varrf25= 1.2E-08
.lib 'crn65lp_v1d5.l' RF_MVAR_25
.ENDL FF_RFMVAR_25


.LIB SS_RFMVAR_25 
.lib 'crn65lp_v1d5.l' scale_option_caprf25
.param
+parmvar_25rf=AGAUSS(0,1,1)
+ l_mvfacrf25 = 0.9762
+ rm_mvfacrf25 = 0.9
+ rsub_mvfacrf25 = 1.2
+ csub_mvfacrf25  = 0.833
+ Cgmin_Varrf25= 0.9     dCg_Varrf25= 0.9464     dxL_Varrf25= 1.0E-08     dxW_Varrf25= -1.2E-08
.lib 'crn65lp_v1d5.l' RF_MVAR_25
.ENDL SS_RFMVAR_25



.LIB RF_MVAR

.subckt moscap_rf gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf mismatchflag=0
.param XLrf=3.46E-08
.param XWrf=-1.60E-08
.param leffrf='(lr*scale-XLrf+dxL_Varrf)*(gr*br)'
.param weffrf='(wr*scale-XWrf+dxW_Varrf)*(gr*br)'
.param arearf='leffrf*weffrf/(gr*br)'
.param Cgminrf='3.09E-10*Cgmin_Varrf*2*weffrf+2.19E-10*Cgmin_Varrf*2*leffrf+1.61E-03*Cgmin_Varrf*arearf'
.param dCgrf='60E-12*dCg_Varrf*2*weffrf-5E-12*dCg_Varrf*2*leffrf+5.704E-03*dCg_Varrf*arearf'
.param dt='temper-25'
.param dVgsrf='-0.09-1.0E-04*dt'
.param Vgnormrf='0.39+6.0E-04*dt'
.param for_effrf='110'
.param gtmprf='2.0E-12'
.param varbfrf='3'
.param rev_effrf='4.3'
.param varbrrf='-0.6'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='320*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'
.param rgm11='0.188*wr*scale/1.3E-7'
.param rpo='15.75*(wr*scale/2)/(2*1.3E-7)'
.param rrrg='1.44615+(gr+1-1)*(2*(gr+1)-1)/(6*(gr+1))*rgm11+(rpo/2+22)/(gr+1)'
.param avrrrg='rrrg/(int(abs((lr*scale-0.03e-6)/0.22e-6)+1.00001))'
.param rgviaarray='0.75*3/((2*1.2E-6+(br-1)*4.2e-7+br*1.55E-7)/2.3E-7/br*2)'
.param rrg='avrrrg+rgviaarray'
.param rgm1='0.188*(lr*scale+4.2e-7)/1E-06'
.param rgm2='0.163*(lr*scale+4.2e-7)/2.8E-06'
.param rgmhead='1/(1/rgm1+1/rgm2)'
.param rgg='(rgmhead/2+(br/2-1)*(br-1)/(6*(br/2))*rgmhead+rrg/(br/2))/2'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*3.6e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='605*3e-6/ll'
.param rwod='320*ww/6/ll'
.param rlsti='605*3e-6/ww'
.param rlod='320*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
Rgate 1 2 'rm_mvfacrf*(rgg+14.63998/(wr*scale*1e6)/(lr*scale*1e6)/br/gr+0.095455*(wr*scale*1e6)*(lr*scale*1e6)+32.57847/br/gr+0.381158/(wr*scale*1e6)-0.00268/(lr*scale*1e6)-0.0783/gr-7.75987/br-0.47412)*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf*(1+0.01*geo_fac*parmvarrf*mismatchflag*(0.092+0.151*(1-tanh((v(2,3)-0.09)/0.39))))+dCgrf*(1.0+tanh((v(2,3)-dVgsrf)/Vgnormrf))*(1+0.00092*geo_fac*parmvarrf*mismatchflag)'
GDF1  2 3 Cur='fac_varrf*(for_effrf*arearf*pwr((abs(v(2,3))+v(2,3))/2,varbfrf+2)+gtmprf*(abs(v(2,3))+v(2,3))-rev_effrf*arearf*pwr((abs(v(2,3))-v(2,3))/2,varbrrf+2))'
Rsd 3 4 'rm_mvfacrf*(rd)*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
DIO 5 3 MVDNWPSUB AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf*rsub'
C_sub 5 gnode 'csub_mvfacrf*165f/rsub' 
.ends moscap_rf

.subckt moscap_rf_nw gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf mismatchflag=0
.param XLrf=3.46E-08
.param XWrf=-1.60E-08
.param leffrf='(lr*scale-XLrf+dxL_Varrf)*(gr*br)'
.param weffrf='(wr*scale-XWrf+dxW_Varrf)*(gr*br)'
.param arearf='leffrf*weffrf/(gr*br)'
.param Cgminrf='3.09E-10*Cgmin_Varrf*2*weffrf+2.19E-10*Cgmin_Varrf*2*leffrf+1.61E-03*Cgmin_Varrf*arearf'
.param dCgrf='60E-12*dCg_Varrf*2*weffrf-5E-12*dCg_Varrf*2*leffrf+5.704E-03*dCg_Varrf*arearf'
.param dt='temper-25'
.param dVgsrf='-0.09-1.0E-04*dt'
.param Vgnormrf='0.39+6.0E-04*dt'
.param for_effrf='110'
.param gtmprf='2.0E-12'
.param varbfrf='3'
.param rev_effrf='4.3'
.param varbrrf='-0.6'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='320*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'
.param rgm11='0.188*wr*scale/1.3E-7'
.param rpo='15.75*(wr*scale/2)/(2*1.3E-7)'
.param rrrg='1.44615+(gr+1-1)*(2*(gr+1)-1)/(6*(gr+1))*rgm11+(rpo/2+22)/(gr+1)'
.param avrrrg='rrrg/(int(abs((lr*scale-0.03e-6)/0.22e-6)+1.00001))'
.param rgviaarray='0.75*3/((2*1.2E-6+(br-1)*4.2e-7+br*1.55E-7)/2.3E-7/br*2)'
.param rrg='avrrrg+rgviaarray'
.param rgm1='0.188*(lr*scale+4.2e-7)/1E-06'
.param rgm2='0.163*(lr*scale+4.2e-7)/2.8E-06'
.param rgmhead='1/(1/rgm1+1/rgm2)'
.param rgg='(rgmhead/2+(br/2-1)*(br-1)/(6*(br/2))*rgmhead+rrg/(br/2))/2'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*1.8e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='605*3e-6/ll'
.param rwod='320*ww/6/ll'
.param rlsti='605*3e-6/ww'
.param rlod='320*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
Rgate 1 2 'rm_mvfacrf*(rgg+14.63998/(wr*scale*1e6)/(lr*scale*1e6)/br/gr+0.095455*(wr*scale*1e6)*(lr*scale*1e6)+32.57847/br/gr+0.381158/(wr*scale*1e6)-0.00268/(lr*scale*1e6)-0.0783/gr-7.75987/br-0.47412)*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf*(1+0.01*geo_fac*parmvarrf*mismatchflag*(0.092+0.151*(1-tanh((v(2,3)-0.09)/0.39))))+dCgrf*(1.0+tanh((v(2,3)-dVgsrf)/Vgnormrf))*(1+0.00092*geo_fac*parmvarrf*mismatchflag)'
GDF1  2 3 Cur='fac_varrf*(for_effrf*arearf*pwr((abs(v(2,3))+v(2,3))/2,varbfrf+2)+gtmprf*(abs(v(2,3))+v(2,3))-rev_effrf*arearf*pwr((abs(v(2,3))-v(2,3))/2,varbrrf+2))'
Rsd 3 4 'rm_mvfacrf*(rd)*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
DIO 5 3 MVNWDIO AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf*rsub'
C_sub 5 gnode 'csub_mvfacrf*165f/rsub' 
.ends moscap_rf_nw

.subckt pmoscap_rf gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf 
.param Cmin_p=1E-15
.param XLrf=4.92E-08
.param XWrf=1.20E-08
.param leffrf='(lr*scale-XLrf+dxL_Varrf)*(gr*br)'
.param weffrf='(wr*scale-XWrf+dxW_Varrf)*(gr*br)'
.param arearf='leffrf*weffrf/(gr*br)'
.param Cgminrf='4E-10*Cgmin_Varrf*2*weffrf+1.85E-10*Cgmin_Varrf*2*leffrf+1.8E-03*Cgmin_Varrf*arearf+Cmin_p'
.param dCgrf='4E-12*dCg_Varrf*2*weffrf-5E-12*dCg_Varrf*2*leffrf+5.45E-03*dCg_Varrf*arearf'
.param dt='temper-25'
.param dVgsrf='0.05-1.0E-04*dt'
.param Vgnormrf='0.41+6.0E-04*dt'
.param for_effrf='0.7'
.param gtmprf='2.0E-12'
.param varbfrf='-0.01'
.param rev_effrf='15'
.param varbrrf='2'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='625*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'
.param rgm11='0.188*wr*scale/1.3E-7'
.param rpo='15.75*(wr*scale/2)/(2*1.3E-7)'
.param rrrg='1.44615+(gr+1-1)*(2*(gr+1)-1)/(6*(gr+1))*rgm11+(rpo/2+22)/(gr+1)'
.param avrrrg='rrrg/(int(abs((lr*scale-0.03e-6)/0.22e-6)+1.00001))'
.param rgviaarray='0.75*3/((2*1.2E-6+(br-1)*4.2e-7+br*1.55E-7)/2.3E-7/br*2)'
.param rrg='avrrrg+rgviaarray'
.param rgm1='0.188*(lr*scale+4.2e-7)/1E-06'
.param rgm2='0.163*(lr*scale+4.2e-7)/2.8E-06'
.param rgmhead='1/(1/rgm1+1/rgm2)'
.param rgg='(rgmhead/2+(br/2-1)*(br-1)/(6*(br/2))*rgmhead+rrg/(br/2))/2'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*3.6e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='800*3e-6/ll'
.param rwod='625*ww/6/ll'
.param rlsti='800*3e-6/ww'
.param rlod='625*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'


Lgate gate 1 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
Rgate 1 2 'rm_mvfacrf*(rgg+14.63998/(wr*scale*1e6)/(lr*scale*1e6)/br/gr+0.095455*(wr*scale*1e6)*(lr*scale*1e6)+32.57847/br/gr+0.381158/(wr*scale*1e6)-0.00268/(lr*scale*1e6)-0.0783/gr-7.75987/br-0.47412)*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 '(Cgminrf+dCgrf*(1.0-tanh((v(2,3)-dVgsrf)/Vgnormrf)))'
GDF1  2 3 Cur='fac_varrf*(for_effrf*arearf*pwr((abs(v(2,3))+v(2,3))/2,varbfrf+2)+gtmprf*(abs(v(2,3))+v(2,3))-rev_effrf*arearf*pwr((abs(v(2,3))-v(2,3))/2,varbrrf+2))'
Rsd 3 4 'rm_mvfacrf*(rd)*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
DIO 3 5 MVDNWPW AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf*rsub'
C_sub 5 gnode 'csub_mvfacrf*245f/rsub' 
.ends pmoscap_rf

.lib 'crn65lp_v1d5.l' DIO_MVDNWPW
.lib 'crn65lp_v1d5.l' DIO_MVDNWPSUB
.lib 'crn65lp_v1d5.l' DIO_MVNWDIO
.ENDL RF_MVAR

.lib DIO_MVDNWPW
.MODEL MVDNWPW D      ( 
+ LEVEL = 3                  
+ IS     = 3.6E-06               IKR    = 1E10                 RS     = 1.0E-10
+ N      = 1.02                  BV     = 12.31                IBV    = 0.03
+ JSW    = 1.3E-13               CJ     = 7.31E-04             PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = 6.46E-10
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04              TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0      )
.ENDL DIO_MVDNWPW

.LIB DIO_MVDNWPSUB
.MODEL MVDNWPSUB D      ( 
+ LEVEL = 3                  
+ IS     = 3.68E-6          RS     = 100E-12         N     = 1.02          
+ BV     = 11.92            IBV    = 0.03            IK    = 1E20               
+ IKR    = 1E10             JSW    = 8.80E-12        AREA  = 3.1161E-8             
+ PJ     = 7.24E-4          CJ     = 1.15E-4         PB    = 0.64      
+ MJ     = 0.36             CJSW   = 1.33E-9         PHP   = 0.77      
+ MJSW   = 0.355            TLEV   = 1               EG    = 1.17               
+ XTI    = 3                TCV    = -9.50E-4        TRS   = 2.5E-3           
+ TLEVC  = 1                CTA    = 2.2E-3          CTP   = 1.2E-3     
+ TPB    = 3.5E-3           TPHP   = 2.6E-3          TREF  = 25                
+ FC     = 0                FCS    = 0      )
.ENDL DIO_MVDNWPSUB



.LIB DIO_MVNWDIO
.MODEL MVNWDIO D     (
+LEVEL  = 3               
+IS    = 3.41e-6        RS     = 1.00E-10         N      = 1.02         
+BV    = 12             IBV    = 0.03             IK     = 1E+20         
+IKR   = 1E+10          JSW    = 1.05e-12         CJ     = 0.000137     
+PB    = 0.5            MJ     = 0.33             CJSW   = 7.25E-10      
+PHP   = 0.65           MJSW   = 0.35             TLEV   = 1             
+EG    = 1.17           XTI    = 3                TCV    = -9.5E-4     
+TRS   = 0.0025         TLEVC  = 1                CTA    = 0.0023      
+CTP   = 0.00116        TPB    = 0.0026           TPHP   = 0.0019      
+TREF  = 25             FC     = 0                FCS    = 0             
+AREA  = 3.1161e-08     PJ     = 0.000724          )

.ENDL DIO_MVNWDIO



.LIB RF_MVAR_HVT

.subckt moscap_rf_hvt gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprfhvt mismatchflag=0
.param XLrf=3.46E-08
.param XWrf=-1.60E-08
.param leffrf='(lr*scale-XLrf+dxL_Varrf_hvt)*(gr*br)'
.param weffrf='(wr*scale-XWrf+dxW_Varrf_hvt)*(gr*br)'
.param arearf='leffrf*weffrf/(gr*br)'
.param Cgminrf='3.69E-10*Cgmin_Varrf_hvt*2*weffrf+2.59E-10*Cgmin_Varrf_hvt*2*leffrf+2.45E-03*Cgmin_Varrf_hvt*arearf'
.param dCgrf='60E-12*dCg_Varrf_hvt*2*weffrf-5E-12*dCg_Varrf_hvt*2*leffrf+5.154E-03*dCg_Varrf_hvt*arearf'
.param dt='temper-25'
.param dVgsrf='-0.09-1.0E-04*dt'
.param Vgnormrf='0.39+6.0E-04*dt'
.param for_effrf='110'
.param gtmprf='2.0E-12'
.param varbfrf='3'
.param rev_effrf='4.3'
.param varbrrf='-0.6'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='320*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'
.param rgm11='0.188*wr*scale/1.3E-7'
.param rpo='15.75*(wr*scale/2)/(2*1.3E-7)'
.param rrrg='1.44615+(gr+1-1)*(2*(gr+1)-1)/(6*(gr+1))*rgm11+(rpo/2+22)/(gr+1)'
.param avrrrg='rrrg/(int(abs((lr*scale-0.03e-6)/0.22e-6)+1.00001))'
.param rgviaarray='0.75*3/((2*1.2E-6+(br-1)*4.2e-7+br*1.55E-7)/2.3E-7/br*2)'
.param rrg='avrrrg+rgviaarray'
.param rgm1='0.188*(lr*scale+4.2e-7)/1E-06'
.param rgm2='0.163*(lr*scale+4.2e-7)/2.8E-06'
.param rgmhead='1/(1/rgm1+1/rgm2)'
.param rgg='(rgmhead/2+(br/2-1)*(br-1)/(6*(br/2))*rgmhead+rrg/(br/2))/2'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*3.6e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='605*3e-6/ll'
.param rwod='320*ww/6/ll'
.param rlsti='605*3e-6/ww'
.param rlod='320*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf_hvt*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
Rgate 1 2 'rm_mvfacrf_hvt*(rgg+14.63998/(wr*scale*1e6)/(lr*scale*1e6)/br/gr+0.095455*(wr*scale*1e6)*(lr*scale*1e6)+32.57847/br/gr+0.381158/(wr*scale*1e6)-0.00268/(lr*scale*1e6)-0.0783/gr-7.75987/br-0.47412)*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf*(1+0.01*geo_fac*parmvarrf_hvt*mismatchflag*(0.089+0.0755*(1-tanh((v(2,3)-0.01)/0.39))))+dCgrf*(1.0+tanh((v(2,3)-dVgsrf)/Vgnormrf))*(1+0.00089*geo_fac*parmvarrf_hvt*mismatchflag)'
GDF1  2 3 Cur='fac_varrf_hvt*(for_effrf*arearf*pwr((abs(v(2,3))+v(2,3))/2,varbfrf+2)+gtmprf*(abs(v(2,3))+v(2,3))-rev_effrf*arearf*pwr((abs(v(2,3))-v(2,3))/2,varbrrf+2))'
Rsd 3 4 'rm_mvfacrf_hvt*(rd)*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf_hvt*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
DIO 5 3 MVDNWPSUB_HVT AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf_hvt*rsub'
C_sub 5 gnode 'csub_mvfacrf_hvt*165f/rsub' 
.ends moscap_rf_hvt

.subckt moscap_rf_hvt_nw gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprfhvt mismatchflag=0
.param XLrf=3.46E-08
.param XWrf=-1.60E-08
.param leffrf='(lr*scale-XLrf+dxL_Varrf_hvt)*(gr*br)'
.param weffrf='(wr*scale-XWrf+dxW_Varrf_hvt)*(gr*br)'
.param arearf='leffrf*weffrf/(gr*br)'
.param Cgminrf='3.69E-10*Cgmin_Varrf_hvt*2*weffrf+2.59E-10*Cgmin_Varrf_hvt*2*leffrf+2.45E-03*Cgmin_Varrf_hvt*arearf'
.param dCgrf='60E-12*dCg_Varrf_hvt*2*weffrf-5E-12*dCg_Varrf_hvt*2*leffrf+5.154E-03*dCg_Varrf_hvt*arearf'
.param dt='temper-25'
.param dVgsrf='-0.09-1.0E-04*dt'
.param Vgnormrf='0.39+6.0E-04*dt'
.param for_effrf='110'
.param gtmprf='2.0E-12'
.param varbfrf='3'
.param rev_effrf='4.3'
.param varbrrf='-0.6'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='320*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'
.param rgm11='0.188*wr*scale/1.3E-7'
.param rpo='15.75*(wr*scale/2)/(2*1.3E-7)'
.param rrrg='1.44615+(gr+1-1)*(2*(gr+1)-1)/(6*(gr+1))*rgm11+(rpo/2+22)/(gr+1)'
.param avrrrg='rrrg/(int(abs((lr*scale-0.03e-6)/0.22e-6)+1.00001))'
.param rgviaarray='0.75*3/((2*1.2E-6+(br-1)*4.2e-7+br*1.55E-7)/2.3E-7/br*2)'
.param rrg='avrrrg+rgviaarray'
.param rgm1='0.188*(lr*scale+4.2e-7)/1E-06'
.param rgm2='0.163*(lr*scale+4.2e-7)/2.8E-06'
.param rgmhead='1/(1/rgm1+1/rgm2)'
.param rgg='(rgmhead/2+(br/2-1)*(br-1)/(6*(br/2))*rgmhead+rrg/(br/2))/2'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*1.8e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='605*3e-6/ll'
.param rwod='320*ww/6/ll'
.param rlsti='605*3e-6/ww'
.param rlod='320*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf_hvt*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
Rgate 1 2 'rm_mvfacrf_hvt*(rgg+14.63998/(wr*scale*1e6)/(lr*scale*1e6)/br/gr+0.095455*(wr*scale*1e6)*(lr*scale*1e6)+32.57847/br/gr+0.381158/(wr*scale*1e6)-0.00268/(lr*scale*1e6)-0.0783/gr-7.75987/br-0.47412)*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf*(1+0.01*geo_fac*parmvarrf_hvt*mismatchflag*(0.089+0.0755*(1-tanh((v(2,3)-0.01)/0.39))))+dCgrf*(1.0+tanh((v(2,3)-dVgsrf)/Vgnormrf))*(1+0.00089*geo_fac*parmvarrf_hvt*mismatchflag)'
GDF1  2 3 Cur='fac_varrf_hvt*(for_effrf*arearf*pwr((abs(v(2,3))+v(2,3))/2,varbfrf+2)+gtmprf*(abs(v(2,3))+v(2,3))-rev_effrf*arearf*pwr((abs(v(2,3))-v(2,3))/2,varbrrf+2))'
Rsd 3 4 'rm_mvfacrf_hvt*(rd)*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf_hvt*(2.96951*((wr*scale*1e6)**3.105522)*((lr*scale*1e6)**(-6.93053))*(gr**(-2.14551))*(br**(-9.30307))+0.596551*(wr*scale/(lr*scale))+1.114765*(gr/br)-0.59986*(wr*scale*1e6)-0.43278/(lr*scale*1e6)-0.07311*gr+1.105405/br+1.463448)*1e-12'
DIO 5 3 MVNWDIO_HVT AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf_hvt*rsub'
C_sub 5 gnode 'csub_mvfacrf_hvt*165f/rsub' 
.ends moscap_rf_hvt_nw
.lib 'crn65lp_v1d5.l' DIO_MVDNWPSUB_HVT
.lib 'crn65lp_v1d5.l' DIO_MVNWDIO_HVT
.ENDL RF_MVAR_HVT



.LIB DIO_MVDNWPSUB_HVT
.MODEL MVDNWPSUB_HVT D      ( 
+ LEVEL = 3                  
+ IS     = 3.68E-6          RS     = 100E-12         N     = 1.02          
+ BV     = 11.92            IBV    = 0.03            IK    = 1E20               
+ IKR    = 1E10             JSW    = 8.80E-12        AREA  = 3.1161E-8             
+ PJ     = 7.24E-4          CJ     = 1.15E-4         PB    = 0.64      
+ MJ     = 0.36             CJSW   = 1.33E-9         PHP   = 0.77      
+ MJSW   = 0.355            TLEV   = 1               EG    = 1.17               
+ XTI    = 3                TCV    = -9.50E-4        TRS   = 2.5E-3           
+ TLEVC  = 1                CTA    = 2.2E-3          CTP   = 1.2E-3     
+ TPB    = 3.5E-3           TPHP   = 2.6E-3          TREF  = 25                
+ FC     = 0                FCS    = 0      )
.ENDL DIO_MVDNWPSUB_HVT



.LIB DIO_MVNWDIO_HVT
.MODEL MVNWDIO_HVT D     (
+LEVEL  = 3               
+IS    = 3.41e-6        RS     = 1.00E-10         N      = 1.02         
+BV    = 12             IBV    = 0.03             IK     = 1E+20         
+IKR   = 1E+10          JSW    = 1.05e-12         CJ     = 0.000137     
+PB    = 0.5            MJ     = 0.33             CJSW   = 7.25E-10      
+PHP   = 0.65           MJSW   = 0.35             TLEV   = 1             
+EG    = 1.17           XTI    = 3                TCV    = -9.5E-4     
+TRS   = 0.0025         TLEVC  = 1                CTA    = 0.0023      
+CTP   = 0.00116        TPB    = 0.0026           TPHP   = 0.0019      
+TREF  = 25             FC     = 0                FCS    = 0             
+AREA  = 3.1161e-08     PJ     = 0.000724          )

.ENDL DIO_MVNWDIO_HVT



.LIB RF_MVAR_25
.subckt moscap_rf25 gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf25 mismatchflag=0
.param XLrf25=1.5E-08
.param XWrf25=-7.0E-09
.param leffrf25='(lr*scale-XLrf25+dxL_Varrf25)*(gr*br)'
.param weffrf25='(wr*scale-XWrf25+dxW_Varrf25)*(gr*br)'
.param arearf25='leffrf25*weffrf25/(gr*br)'
.param Cgminrf25='3.2E-10*Cgmin_Varrf25*2*weffrf25+1.8E-10*Cgmin_Varrf25*2*leffrf25+0.96E-03*Cgmin_Varrf25*arearf25'
.param dCgrf25='-1.0E-11*dCg_Varrf25*2*weffrf25-1.0E-11*dCg_Varrf25*2*leffrf25+2.285E-03*dCg_Varrf25*arearf25'
.param dt='temper-25'
.param dVgsrf25='-0.16-2.000E-04*dt'
.param Vgnormrf25='0.55+1.0E-03*dt'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='315*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'

.param lm1g='1.4e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1g='lr*scale-0.09e-6*int((lr*scale-0.2e-6)/0.2e-6)'
.param rgm='0.16*lm1g/(3*wm1g*br)'
.param rgp='17.0*wr*scale/(12*lr*scale*gr*br)'
.param rgch='((lr*scale*1e6)**(-0.038119))/(12*0.002072)/((wr*scale*1e6)**0.656366)/(gr**0.818013)/(br**1.066443)'
.param rg='rgm+rgp+rgch'

.param lm1s='(1.2-0.015)*1e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1s=0.13E-6
.param rsm='0.16*lm1s/(3*wm1s*(br+1))'

.param lgm='1e-9*2*lm1g*(log(2*lm1g/(wm1g+0.18e-6))+0.5+(wm1g+0.18e-6)/(3*lm1g))/br'
.param lsm='1e-9*2*lm1s*(log(2*lm1s/(wm1s+0.18e-6))+0.5+(wm1s+0.18e-6)/(3*lm1s))/(br+1)'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*3.6e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='554*3e-6/ll'
.param rwod='315*ww/6/ll'
.param rlsti='554*3e-6/ww'
.param rlod='315*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf25*lgm'
Rgate 1 2 'rm_mvfacrf25*rg*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf25*(1+0.01*geo_fac*parmvar_25rf*mismatchflag*(0.081+0.351*(1-tanh((v(2,3)-0.16)/0.55))))+dCgrf25*(1.0+tanh((v(2,3)-dVgsrf25)/Vgnormrf25))*(1+0.00081*geo_fac*parmvar_25rf*mismatchflag)'
Rsd 3 4 'rm_mvfacrf25*rd*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf25*lsm'
DIO 5 3 MVDNWPSUB25 AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf25*rsub'
C_sub 5 gnode 'csub_mvfacrf25*165f/rsub'
.ends moscap_rf25

.subckt moscap_rf25_nw gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf25 mismatchflag=0
.param XLrf25=1.5E-08
.param XWrf25=-7.0E-09
.param leffrf25='(lr*scale-XLrf25+dxL_Varrf25)*(gr*br)'
.param weffrf25='(wr*scale-XWrf25+dxW_Varrf25)*(gr*br)'
.param arearf25='leffrf25*weffrf25/(gr*br)'
.param Cgminrf25='3.2E-10*Cgmin_Varrf25*2*weffrf25+1.8E-10*Cgmin_Varrf25*2*leffrf25+0.96E-03*Cgmin_Varrf25*arearf25'
.param dCgrf25='-1.0E-11*dCg_Varrf25*2*weffrf25-1.0E-11*dCg_Varrf25*2*leffrf25+2.285E-03*dCg_Varrf25*arearf25'
.param dt='temper-25'
.param dVgsrf25='-0.16-2.000E-04*dt'
.param Vgnormrf25='0.55+1.0E-03*dt'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='315*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'

.param lm1g='1.4e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1g='lr*scale-0.09e-6*int((lr*scale-0.2e-6)/0.2e-6)'
.param rgm='0.16*lm1g/(3*wm1g*br)'
.param rgp='17.0*wr*scale/(12*lr*scale*gr*br)'
.param rgch='((lr*scale*1e6)**(-0.038119))/(12*0.002072)/((wr*scale*1e6)**0.656366)/(gr**0.818013)/(br**1.066443)'
.param rg='rgm+rgp+rgch'

.param lm1s='(1.2-0.015)*1e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1s=0.13E-6
.param rsm='0.16*lm1s/(3*wm1s*(br+1))'

.param lgm='1e-9*2*lm1g*(log(2*lm1g/(wm1g+0.18e-6))+0.5+(wm1g+0.18e-6)/(3*lm1g))/br'
.param lsm='1e-9*2*lm1s*(log(2*lm1s/(wm1s+0.18e-6))+0.5+(wm1s+0.18e-6)/(3*lm1s))/(br+1)'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*1.8e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='554*3e-6/ll'
.param rwod='315*ww/6/ll'
.param rlsti='554*3e-6/ww'
.param rlod='315*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'
.param geo_fac='sqrt(2)/sqrt(lr*scale*wr*scale*gr*br*1e12)'

Lgate gate 1 'l_mvfacrf25*lgm'
Rgate 1 2 'rm_mvfacrf25*rg*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 'Cgminrf25*(1+0.01*geo_fac*parmvar_25rf*mismatchflag*(0.081+0.351*(1-tanh((v(2,3)-0.16)/0.55))))+dCgrf25*(1.0+tanh((v(2,3)-dVgsrf25)/Vgnormrf25))*(1+0.00081*geo_fac*parmvar_25rf*mismatchflag)'
Rsd 3 4 'rm_mvfacrf25*rd*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf25*lsm'
DIO 5 3 MVNWDIO25 AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf25*rsub'
C_sub 5 gnode 'csub_mvfacrf25*165f/rsub'
.ends moscap_rf25_nw

.subckt pmoscap_rf25 gate bulk gnode wr=2u lr=0.4u gr=2 br=32 scale=scale_caprf25 
.param Cmin_p25=1E-15
.param XLrf25=4.92E-08
.param XWrf25=1.2E-08
.param leffrf25='(lr*scale-XLrf25+dxL_Varrf25)*(gr*br)'
.param weffrf25='(wr*scale-XWrf25+dxW_Varrf25)*(gr*br)'
.param arearf25='leffrf25*weffrf25/(gr*br)'
.param Cgminrf25='3.5E-10*Cgmin_Varrf25*2*weffrf25+1.5E-10*Cgmin_Varrf25*2*leffrf25+1.1E-03*Cgmin_Varrf25*arearf25+Cmin_p25'
.param dCgrf25='4.0E-12*dCg_Varrf25*2*weffrf25-5.0E-12*dCg_Varrf25*2*leffrf25+2.2E-03*dCg_Varrf25*arearf25'
.param dt='temper-25'
.param dVgsrf25='0.18-2.000E-04*dt'
.param Vgnormrf25='0.61+1.0E-03*dt'

.param ld2d='lr*scale+2*9.0E-8'
.param rdm11='0.188*(wr*scale+2.30E-07)/1.30E-7'
.param rdcont='30/int(abs((wr*scale-0.3e-6)/0.34e-6+1.00001))'
.param rwell='750*(lr*scale/4+9.00E-8+1.30E-7/2)/(wr*scale)'
.param rrrd='1.735+(gr-1)*(2*gr-1)/(6*gr)*rdm11+(rwell/2+rdcont)/gr'
.param rdvia_array='0.75*3/((2*9.8E-7+br*ld2d+(br+1)*1.3E-7)/2.3E-7/(br+1)*2)'
.param rrd='rrrd+rdvia_array'
.param rdm1='0.188*(1.3E-7+ld2d)/1E-06'
.param rdm2='0.163*(1.3E-7+ld2d)/2.8E-06'		
.param rdmhead='1/(1/rdm1+1/rdm2)'
.param rd='(rdmhead/2+((br+1)/2-1)*br/(6*((br+1)/2))*rdmhead+rrd/((br+1)/2))/2'

.param lm1g='1.4e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1g='lr*scale-0.09e-6*int((lr*scale-0.2e-6)/0.2e-6)'
.param rgm='0.2*lm1g/(3*wm1g*br)'
.param rgp='80.0*wr*scale/(12*lr*scale*gr*br)'
.param rgch='((lr*scale*1e6)**(-0.038119))/(12*0.002072)/((wr*scale*1e6)**0.656366)/(gr**0.818013)/(br**1.066443)'
.param rg='rgm+rgp+rgch'

.param lm1s='(1.2-0.015)*1e-6+wr*scale*gr+0.23e-6*(gr-1)'
.param wm1s=0.13E-6
.param rsm='0.16*lm1s/(3*wm1s*(br+1))'

.param lgm='1e-9*2*lm1g*(log(2*lm1g/(wm1g+0.18e-6))+0.5+(wm1g+0.18e-6)/(3*lm1g))/br'
.param lsm='1e-9*2*lm1s*(log(2*lm1s/(wm1s+0.18e-6))+0.5+(wm1s+0.18e-6)/(3*lm1s))/(br+1)'

.param ww='wr*scale*gr+2.30E-07*(gr-1)'
.param ll='lr*scale*br+(br-1)*3.10e-7+2*2.30e-7'
.param wtub='ww+2*3.6e-7'
.param ltub='ll+2*3.6e-7'
.param area_dio='wtub*ltub/scale/scale'
.param pj_dio='2*(wtub+ltub)/scale'
.param rwsti='800*3e-6/ll'
.param rwod='750*ww/6/ll'
.param rlsti='800*3e-6/ww'
.param rlod='750*ll/6/ww'
.param rrsub='1/(2/(rwsti+rwod)+2/(rlsti+rlod))'
.param rsub='rrsub*(1+3.74m*dt+9.1u*dt*dt)'


Lgate gate 1 'l_mvfacrf25*lgm'
Rgate 1 2 'rm_mvfacrf25*rg*(1+2.6m*dt+8.94u*dt*dt)'
Cgate 2 3 '(Cgminrf25+dCgrf25*(1.0-tanh((v(2,3)-dVgsrf25)/Vgnormrf25)))'
Rsd 3 4 'rm_mvfacrf25*rd*(1+2.93m*dt)'
Lsd 4 bulk 'l_mvfacrf25*lsm'
DIO 3 5 MVDNWPW25 AREA='area_dio'  PJ='pj_dio'
R_sub 5 gnode 'rsub_mvfacrf25*rsub'
C_sub 5 gnode 'csub_mvfacrf25*245f/rsub'
.ends pmoscap_rf25

.lib 'crn65lp_v1d5.l' DIO_MVDNWPW25
.lib 'crn65lp_v1d5.l' DIO_MVDNWPSUB25
.lib 'crn65lp_v1d5.l' DIO_MVNWDIO25
.ENDL RF_MVAR_25

.lib DIO_MVDNWPW25
.MODEL MVDNWPW25 D            (
+ LEVEL = 3                  
+ IS     = 3.6E-06               IKR    = 1E10                 RS     = 1.0E-10
+ N      = 1.02                  BV     = 12.31                IBV    = 0.03
+ JSW    = 1.3E-13               CJ     = 7.31E-04             PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = 6.46E-10
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04              TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0      )
.ENDL DIO_MVDNWPW25

.LIB DIO_MVDNWPSUB25
.MODEL MVDNWPSUB25 D            (
+ LEVEL = 3                  
+ IS     = 3.68E-6          RS     = 100E-12         N     = 1.02          
+ BV     = 11.92            IBV    = 0.03            IK    = 1E20               
+ IKR    = 1E10             JSW    = 8.80E-12        AREA  = 3.1161E-8             
+ PJ     = 7.24E-4          CJ     = 1.15E-4         PB    = 0.64      
+ MJ     = 0.36             CJSW   = 1.33E-9         PHP   = 0.77      
+ MJSW   = 0.355            TLEV   = 1               EG    = 1.17               
+ XTI    = 3                TCV    = -9.50E-4        TRS   = 2.5E-3           
+ TLEVC  = 1                CTA    = 2.2E-3          CTP   = 1.2E-3     
+ TPB    = 3.5E-3           TPHP   = 2.6E-3          TREF  = 25                
+ FC     = 0                FCS    = 0     )
.ENDL DIO_MVDNWPSUB25



.LIB DIO_MVNWDIO25
.MODEL MVNWDIO25 D   (
+LEVEL  = 3               
+IS    = 3.41e-6        RS     = 1.00E-10         N      = 1.02         
+BV    = 12             IBV    = 0.03             IK     = 1E+20         
+IKR   = 1E+10          JSW    = 1.05e-12         CJ     = 0.000137     
+PB    = 0.5            MJ     = 0.33             CJSW   = 7.25E-10      
+PHP   = 0.65           MJSW   = 0.35             TLEV   = 1             
+EG    = 1.17           XTI    = 3                TCV    = -9.5E-4     
+TRS   = 0.0025         TLEVC  = 1                CTA    = 0.0023      
+CTP   = 0.00116        TPB    = 0.0026           TPHP   = 0.0019      
+TREF  = 25             FC     = 0                FCS    = 0             
+AREA  = 3.1161e-08     PJ     = 0.000724          )

.ENDL DIO_MVNWDIO25




***************************************************************************
* RF JUNCTION VARACTOR MODEL : 
*     ## library files:
*     
*           
*      Model name      L(um)         W(um)         Finger(nr)  
*                    low   high     low   high    low   high
*      ---------------------------------------------------
*       xjvar        0.15   1       10    60      1     64  
*       xjvar_nw     0.15   1       10    60      1     64     
*      ---------------------------------------------------
*	End Model
***************************************************************************

.LIB scale_option_rfjvar
.param scale_rfjvar=1
.ENDL scale_option_rfjvar



.LIB MC_RFJVAR
.lib 'crn65lp_v1d5.l' scale_option_rfjvar
.param
+par1MC_RFJVAR=AGAUSS(0,1,3) 
+ A1MC_RFJVAR='par1MC_RFJVAR*2.8264e+000*3/3' 
+ CJ_fac          = '1.0000e+000+(2.4764e-002)*A1MC_RFJVAR'
+ CJSW_fac        = '1.0000e+000+(2.4764e-002)*A1MC_RFJVAR'
+ L_fac           = '1.0000e+000+(8.3664e-003)*A1MC_RFJVAR'
+ Rm_fac          = '1.0000e+000+(3.5378e-002)*A1MC_RFJVAR'
+ Rsub_fac        = '1.0000e+000+(-7.0755e-002)*A1MC_RFJVAR'
+ Csub_fac        = '1.0000e+000+(7.3822e-002)*A1MC_RFJVAR'
+ Rwell_fac       = '1.0000e+000+(5.3067e-002)*A1MC_RFJVAR'
+ Csti_fac        = '1.0000e+000+(1.7689e-002)*A1MC_RFJVAR'
.lib 'crn65lp_v1d5.l' RF_JVAR
.ENDL MC_RFJVAR

.LIB TT_RFJVAR
.lib 'crn65lp_v1d5.l' scale_option_rfjvar
.param
+CJ_fac= 1          CJSW_fac= 1         L_fac= 1         Rm_fac= 1                  
+Rsub_fac= 1        Csub_fac= 1         Rwell_fac= 1     Csti_fac= 1
.lib 'crn65lp_v1d5.l' RF_JVAR
.ENDL TT_RFJVAR

.LIB FF_RFJVAR
.lib 'crn65lp_v1d5.l' scale_option_rfjvar
.param
+CJ_fac= 0.93          CJSW_fac= 0.93         L_fac= 0.9762         Rm_fac= 0.9                  
+Rsub_fac= 1.2         Csub_fac= 0.83333      Rwell_fac= 0.85       Csti_fac= 0.95
.lib 'crn65lp_v1d5.l' RF_JVAR
.ENDL FF_RFJVAR

.LIB SS_RFJVAR
.lib 'crn65lp_v1d5.l' scale_option_rfjvar
.param
+CJ_fac= 1.07         CJSW_fac= 1.07        L_fac= 1.0235          Rm_fac= 1.1                  
+Rsub_fac= 0.8        Csub_fac= 1.25        Rwell_fac= 1.15        Csti_fac= 1.05
.lib 'crn65lp_v1d5.l' RF_JVAR
.ENDL SS_RFJVAR


.LIB RF_JVAR

.subckt xjvar_nw anode cathode gnode l=0.3u w=15u nr=1 scale=scale_rfjvar 
.param Nconp='int((w*scale-0.28u)/0.23u+0.1m)+1'
.param Nconn='int((w*scale-0.2u)/0.2u+0.1m)+1'
.param Nstrip='int(abs(l*scale-0.27u)/0.23u+0.1m)+1'
.param area_d1='nr*l*scale*w*scale/scale/scale'      
.param peri_d1='2*nr*(l*scale+w*scale)/scale' 
.param area_d2='((l*scale+0.45u)*nr+2.39u)*(w*scale+2.24u)/scale/scale'
.param peri_d2='2*(((l*scale+0.45u)*nr+2.39u)+(w*scale+2.82u))/scale'
.param M1_S_sd='l*scale+0.45u'
.param RR_pnsd='(0.188*M1_S_sd/1u)*(0.163*M1_S_sd/3u)/((0.188*M1_S_sd/1u)+(0.163*M1_S_sd/3u))'
.param R_1str_p='(1.5416+((Nconp-1)*(2*Nconp-1)/6/Nconp*0.2162)+30/Nconp)/Nstrip'
.param R_1str_n='(1.504+((Nconn-1)*(2*Nconn-1)/6/Nconn*0.188)+30/Nconn)'
.param dt='temper-25'
Rpsd anode 1 '(-0.4498*(l*scale*1e6) + 1.0484)*(1-(w*scale*1e6)/10*0.02)*((RR_pnsd/2+((nr/2-1)*(nr-1)/3/nr*RR_pnsd)+R_1str_p/nr*2)/2)*(1+2.69e-3*dt-3e-7*dt*dt)*Rm_fac'
L1 1 2     '(0.0105*w*scale*1e6 + 0.3755)*(w*scale*1e6/40)*(1.27e-11*(30/(w*scale*1e6))*(0.7382*(1/nr)+0.2675))*L_fac'
D1 2 3     PDIO_XJ area=area_d1 pj=peri_d1
Rwell 3 4     '0.92*(20/(w*scale*1e6))*(1.8526*(l*scale*1e6)*(l*scale*1e6) - 3.2111*(l*scale*1e6) + 2.3984)*(-0.086*nr + 7.9461)*((554*0.15u/(w*scale)+315*(l*scale+0.15u)/2/(w*scale))/2/nr)*(1+2.95e-3*dt+8.42e-6*dt*dt)*Rwell_fac'
L2 4 5     '(0.0105*w*scale*1e6 + 0.3755)*(w*scale*1e6/40)*(1.27e-11*(30/(w*scale*1e6))*(0.7382*(1/nr)+0.2675))*L_fac'
Rnsd 5 cathode '(-0.4498*(l*scale*1e6) + 1.0484)*(1-(w*scale*1e6)/10*0.02)*((RR_pnsd/2+(((nr+1)/2-1)*(nr+1-1)/3/(nr+1)*RR_pnsd)+R_1str_n/(nr+1)*2)/2)*(1+2.69e-3*dt-3e-7*dt*dt)*Rm_fac'
Csti 2 4  '0.2385*w*scale*nr*1e-9*(l*scale*1e6+0.02)/(l*scale*1e6)'
D2 30 3 NWPSUB_XJ area=area_d2 pj=peri_d2
Rsub 30 gnode '(1.872/nr + 0.2225)*(30/(w*scale*1e6))*(1/((1/(315*w*scale/6/((l*scale+0.45u)*nr+0.15u)+554*3u/((l*scale+0.45u)*nr+0.15u)))+1/((315*w*scale/6/((l*scale+0.45u)*nr+0.15u))+554*3u/((l*scale+0.45u)*nr+0.15u))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))))*(1+2.95e-3*dt+8.42e-6*dt*dt)*Rsub_fac'
Csub 30 gnode '(1.65e-13/((1.872/nr + 0.2225)*(30/(w*scale*1e6))*(1/((1/(315*w*scale/6/((l*scale+0.45u)*nr+0.15u)+554*3u/((l*scale+0.45u)*nr+0.15u)))+1/((315*w*scale/6/((l*scale+0.45u)*nr+0.15u))+554*3u/((l*scale+0.45u)*nr+0.15u))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale)))))*(1+2.95e-3*dt+8.42e-6*dt*dt))*Csub_fac'
.ends xjvar_nw

.subckt xjvar anode cathode gnode l=0.3u w=15u nr=1 scale=scale_rfjvar
.param Nconp='int((w*scale-0.28u)/0.23u+0.1m)+1'
.param Nconn='int((w*scale-0.2u)/0.2u+0.1m)+1'
.param Nstrip='int(abs(l*scale-0.27u)/0.23u+0.1m)+1'
.param area_d1='nr*l*scale*w*scale/scale/scale'      
.param peri_d1='2*nr*(l*scale+w*scale)/scale' 
.param area_d2='((l*scale+0.45u)*nr+2.39u)*(w*scale+2.24u)/scale/scale'
.param peri_d2='2*(((l*scale+0.45u)*nr+2.39u)+(w*scale+2.82u))/scale'
.param M1_S_sd='l*scale+0.45u'
.param RR_pnsd='(0.188*M1_S_sd/1u)*(0.163*M1_S_sd/3u)/((0.188*M1_S_sd/1u)+(0.163*M1_S_sd/3u))'
.param R_1str_p='(1.5416+((Nconp-1)*(2*Nconp-1)/6/Nconp*0.2162)+30/Nconp)/Nstrip'
.param R_1str_n='(1.504+((Nconn-1)*(2*Nconn-1)/6/Nconn*0.188)+30/Nconn)'
.param dt='temper-25'
Rpsd anode 1 '(-0.4498*(l*scale*1e6) + 1.0484)*(1-(w*scale*1e6)/10*0.02)*((RR_pnsd/2+((nr/2-1)*(nr-1)/3/nr*RR_pnsd)+R_1str_p/nr*2)/2)*(1+2.69e-3*dt-3e-7*dt*dt)*Rm_fac'
L1 1 2     '(0.0105*w*scale*1e6 + 0.3755)*(w*scale*1e6/40)*(1.27e-11*(30/(w*scale*1e6))*(0.7382*(1/nr)+0.2675))*L_fac'
D1 2 3     PDIO_XJ area=area_d1 pj=peri_d1
Rwell 3 4     '0.64*(20/(w*scale*1e6))*(1.8526*(l*scale*1e6)*(l*scale*1e6) - 3.2111*(l*scale*1e6) + 2.3984)*(-0.086*nr + 7.9461)*((554*0.15u/(w*scale)+315*(l*scale+0.15u)/2/(w*scale))/2/nr)*(1+10.95e-3*dt+8.42e-6*dt*dt)*Rwell_fac'
L2 4 5     '(0.0105*w*scale*1e6 + 0.3755)*(w*scale*1e6/40)*(1.27e-11*(30/(w*scale*1e6))*(0.7382*(1/nr)+0.2675))*L_fac'
Rnsd 5 cathode '(-0.4498*(l*scale*1e6) + 1.0484)*(1-(w*scale*1e6)/10*0.02)*((RR_pnsd/2+(((nr+1)/2-1)*(nr+1-1)/3/(nr+1)*RR_pnsd)+R_1str_n/(nr+1)*2)/2)*(1+2.69e-3*dt-3e-7*dt*dt)*Rm_fac'
Csti 2 4  '0.225*w*scale*nr*1e-9*(l*scale*1e6+0.02)/(l*scale*1e6)'
D2 30 3 DNWPSUB_XJ area=area_d2 pj=peri_d2
Rsub 30 gnode '(1.872/nr + 0.2225)*(30/(w*scale*1e6))*(1/((1/(315*w*scale/6/((l*scale+0.45u)*nr+0.15u)+554*3u/((l*scale+0.45u)*nr+0.15u)))+1/((315*w*scale/6/((l*scale+0.45u)*nr+0.15u))+554*3u/((l*scale+0.45u)*nr+0.15u))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))))*(1+2.95e-3*dt+8.42e-6*dt*dt)*Rsub_fac'
Csub 30 gnode '(1.65e-13/((1.872/nr + 0.2225)*(30/(w*scale*1e6))*(1/((1/(315*w*scale/6/((l*scale+0.45u)*nr+0.15u)+554*3u/((l*scale+0.45u)*nr+0.15u)))+1/((315*w*scale/6/((l*scale+0.45u)*nr+0.15u))+554*3u/((l*scale+0.45u)*nr+0.15u))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale))+1/(315*((l*scale+0.45u)*nr+0.15u)/6/(w*scale)+554*3u/(w*scale)))))*(1+2.95e-3*dt+8.42e-6*dt*dt))*Csub_fac'
.ends xjvar

.lib 'crn65lp_v1d5.l' DIO_PDIO_XJ
.lib 'crn65lp_v1d5.l' DIO_NWPSUB_XJ
.lib 'crn65lp_v1d5.l' DIO_DNWPSUB_XJ

.ENDL RF_JVAR



.LIB DIO_PDIO_XJ
.MODEL PDIO_XJ D (                                          LEVEL  = 3
+ IS     = 1.82E-07            IKR    = 1E10                RS     = 1.0E-10
+ N      = 1.00                   BV     = 9.4                    IBV    = 0.03
+ JSW    = 2.71E-13         CJ     = '1.077E-03*CJ_fac'         PJ     = 7.2E-4
+ MJ     = 0.41              FC     = 0                  CJSW   = '6.4E-11*CJSW_fac'
+ AREA   = 3.08E-8           MJSW   = 0.035              TLEVC  = 1
+ CTA    = 8.72E-04          CTP    = 1.96E-04           TRS    = 2.5E-3
+ TCV    = -8.5E-04         TLEV   = 1                   XTI    = 3
+ EG     = 1.17              PHP    = 0.49               PB     = 1.02
+ IK     = 1E20              TPB    = 2.3E-3               TREF   = 25
+ TPHP   = 1.80E-03          FCS    = 0                  )

.ENDL DIO_PDIO_XJ


.LIB DIO_DNWPSUB_XJ
.MODEL DNWPSUB_XJ D (                                            LEVEL  = 3
+ IS     = 3.68E-06                        IKR    = 1E10                RS     = 1E-10
+ N      = 1.02        BV     = 11.92               IBV    = 0.03
+ JSW    = 8.80E-12  CJ     = 1.15E-04 PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = 1.33E-09
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )
.ENDL DIO_DNWPSUB_XJ


.LIB DIO_NWPSUB_XJ
.MODEL NWPSUB_XJ D (                                         LEVEL  = 3
+ IS     = 3.41E-06   IKR    = 1E10               RS     = 0
+ N      = 1.02        BV     = 12                 IBV    = 0.03
+ JSW    = 1.05E-12 CJ     = 1.37E-04    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = 7.25E-10
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )
.ENDL DIO_NWPSUB_XJ




**************************************************************************************************
*  RF RESISTOR MODEL 
*	
*      	Model name          W(um)           L(um)              sqr
*                        low   high      low     high       low    high  
* ----------------------------------------------------------------------
* rppolyl_rf             2       10     0.3     150         1     150
* rppolys_rf             0.15     2     0.3     150         1     150
* rppolywo_rf	         0.4     10     0.8      25         1      20
* ----------------------------------------------------------------------
*  End Model
*
* Note: W&L are in drawn size.
* rppolyl_rf: P+Poly w/i silicide (W>2um)
* rppolys_rf: P+Poly w/i silicide (W<2um)
* rppolywo_rf: P+Poly w/o silicide  
**************************************************************************************************

.LIB scale_option_rfres_sa
.param scale_rfres_sa=1
.ENDL scale_option_rfres_sa

.LIB scale_option_rfres_rpo
.param scale_rfres_rpo=1
.param rnoiseflag_rfresrpo=0
.ENDL scale_option_rfres_rpo


********************************************************
***************    RES Corner Parameters  **************
********************************************************

.lib MC_RFRES_SA
.lib 'crn65lp_v1d5.l' scale_option_rfres_sa
.Param
+ par_rfres_sa=AGAUSS(0,1,1)
+A1_rfres_sal='par1_res*3.4218e+000*3/3.1' 
+A2_rfres_sal='par2_res*5.3941e-001*3/3.1' 

+rppolylrf       = '1.4926e+001+(1.3027e+000)*A1_rfres_sal+(-7.8588e-001)*A2_rfres_sal'
+rppolysrf       = '1.4926e+001+(1.6180e+000)*A1_rfres_sal+(-1.0884e+000)*A2_rfres_sal'
+dxw_rppolysrf     = '0.0000e+000+(4.2404e-009)*A1_rfres_sal+(5.7744e-009)*A2_rfres_sal'
+ sal_fac = 1
+ sarsub_fac = 1
+ sacsub_fac = 1      
+ ca_pofoxrf=10.77e-17  cf_polfoxrf=5.35e-17 cf_posfoxrf=4.28e-17


.lib 'crn65lp_v1d5.l' RF_RES_SA
.endl MC_RFRES_SA


.LIB TT_RFRES_SA
.lib 'crn65lp_v1d5.l' scale_option_rfres_sa
.param
+ par_rfres_sa=AGAUSS(0,1,1)
+ rppolylrf  = 14.9255297
+ rppolysrf  = 14.9255297
+ sal_fac = 1
+ sarsub_fac = 1
+ sacsub_fac = 1      
+ dxw_rppolysrf =0 
+ ca_pofoxrf=10.77e-17  cf_polfoxrf=5.35e-17 cf_posfoxrf=4.28e-17
.lib 'crn65lp_v1d5.l' RF_RES_SA
.ENDL TT_RFRES_SA


.LIB FF_RFRES_SA
.lib 'crn65lp_v1d5.l' scale_option_rfres_sa
.param
+ par_rfres_sa=AGAUSS(0,1,1)
+ rppolylrf  = '14.9255297 * 0.70'
+ rppolysrf  = '14.9255297 * 0.634'
+ sal_fac = 0.9762
+ sarsub_fac = 0.8
+ sacsub_fac = 1.25
+ dxw_rppolysrf = '0 - 0.0219u'
+ ca_pofoxrf=9.93e-17  cf_polfoxrf=5.17e-17 cf_posfoxrf=4.12e-17
.lib 'crn65lp_v1d5.l' RF_RES_SA
.ENDL FF_RFRES_SA


.LIB SS_RFRES_SA
.lib 'crn65lp_v1d5.l' scale_option_rfres_sa
.param
+ par_rfres_sa=AGAUSS(0,1,1)
+ rppolylrf  = '14.9255297 * 1.3'
+ rppolysrf  = '14.9255297 * 1.38'
+ sal_fac = 1.0235
+ sarsub_fac = 1.2
+ sacsub_fac = 0.833
+ dxw_rppolysrf = '0 + 0.0064u'
+ ca_pofoxrf=11.84e-17  cf_polfoxrf=5.51e-17 cf_posfoxrf=4.43e-17
.lib 'crn65lp_v1d5.l' RF_RES_SA
.ENDL SS_RFRES_SA


********************************************************

.lib MC_RFRES_RPO
.lib 'crn65lp_v1d5.l' scale_option_rfres_rpo
.Param
+ par_rfres_rpo=AGAUSS(0,1,1)
+A1_rfres_rpo='par3_res*3.4546e+000*3/3.2' 

+rppolyworf      = '6.9002e+002+(2.4734e+001)*A1_rfres_rpo'
+rend_rppolyworf   = '1.0400e-006+(1.5035e-007)*A1_rfres_rpo'
+ rpol_fac = 1
+ rporsub_fac = 1
+ rpocsub_fac = 1
+dxw_rppolyworf    = '0.0000e+000+(3.6342e-009)*A1_rfres_rpo'
+dxl_rppolyworf    = '0.0000e+000'
+ ca_pofoxrf_rpo=10.77e-17  cf_polfoxrf_rpo=5.35e-17 cf_posfoxrf_rpo=4.28e-17

.lib 'crn65lp_v1d5.l' RF_RES_RPO
.endl MC_RFRES_RPO


.LIB TT_RFRES_RPO
.lib 'crn65lp_v1d5.l' scale_option_rfres_rpo
.param
+ par_rfres_rpo=AGAUSS(0,1,1)
+ rppolyworf = 690.0226806
+ rend_rppolyworf  = 1.04E-06   
+ rpol_fac = 1
+ rporsub_fac = 1
+ rpocsub_fac = 1
+ dxl_rppolyworf  = 0            
+ dxw_rppolyworf  = 0
+ ca_pofoxrf_rpo=10.77e-17  cf_polfoxrf_rpo=5.35e-17 cf_posfoxrf_rpo=4.28e-17

.lib 'crn65lp_v1d5.l' RF_RES_RPO
.ENDL TT_RFRES_RPO


.LIB FF_RFRES_RPO
.lib 'crn65lp_v1d5.l' scale_option_rfres_rpo
.param
+ par_rfres_rpo=AGAUSS(0,1,1)
+ rppolyworf = '690.0226806 * 0.877'
+ rend_rppolyworf  = '1.04E-06 * 0.50'   
+ rpol_fac = 0.9762
+ rporsub_fac = 0.8
+ rpocsub_fac = 1.25
+ dxl_rppolyworf    = '0.0u + 0.0u'   
+ dxw_rppolyworf    = '0 - 0.015u'
+ ca_pofoxrf_rpo=9.93e-17  cf_polfoxrf_rpo=5.17e-17 cf_posfoxrf_rpo=4.12e-17

.lib 'crn65lp_v1d5.l' RF_RES_RPO
.ENDL FF_RFRES_RPO


.LIB SS_RFRES_RPO
.lib 'crn65lp_v1d5.l' scale_option_rfres_rpo
.param
+ par_rfres_rpo=AGAUSS(0,1,1)
+ rppolyworf = '690.0226806 * 1.125'
+ rend_rppolyworf  = '1.04E-06 * 1.5'   
+ rpol_fac = 1.0235
+ rporsub_fac = 1.2
+ rpocsub_fac = 0.833
+ dxl_rppolyworf  = '0.0u + 0.0u'
+ dxw_rppolyworf  = '0 + 0.01u'
+ ca_pofoxrf_rpo=11.84e-17  cf_polfoxrf_rpo=5.51e-17 cf_posfoxrf_rpo=4.43e-17

.lib 'crn65lp_v1d5.l' RF_RES_RPO
.ENDL SS_RFRES_RPO



.LIB RF_RES_SA
.subckt rppolyl_rf hi lo gnode l=20u w=5u scale='scale_rfres_sa' mismatchflag=0
.param geo_fac ='1/sqrt(l*scale*w*scale*1e12)'
.param factmis='0.0143*geo_fac*par_rfres_sa*mismatchflag'
.param rsh='rppolylrf*(1+factmis)' dw = -0.023u pvc1 = 8.25E-07   pvc2 = 1.38E-11   ptc1 = 0.002250708   ptc2 = -9.32E-07 pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param rsubtfac='1.0+3.74m*(pt-25.0)+9.1u*(pt-25.0)*(pt-25.0)'
.param rsubx='277/((1/(0.5u+(l*scale+0.24u)/6)*(w*scale-dw))+(1/(3u+(w*scale-dw)/6)*(l*scale+0.24u)))*rsubtfac'
.param Ca='ca_pofoxrf' Cf='cf_polfoxrf'
Rend1 hi 1   '22/(int(abs((w*scale-0.016u)/0.22u)+1))'
Ls1   1  12  '0.02*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R1    12 2   '1/6*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls2   2  23  '0.04*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R2    23 3   '1/3*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls3   3  34  '0.04*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R3    34 4   '1/3*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
R4    4  45  '1/6*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls4   45 5   '0.02*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
Rend2 5  lo  '22/(int(abs((w*scale-0.016u)/0.22u)+1))'
Cox1  2  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Cox2  3  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Cox3  4  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Rsub  6  gnode 'rsubx*sarsub_fac'
Csub  6  gnode '85f/rsubx*sacsub_fac'
.ends rppolyl_rf

.subckt rppolys_rf hi lo gnode l=20u w=1u scale='scale_rfres_sa' mismatchflag=0
.param geo_fac ='1/sqrt(l*scale*w*scale*1e12)'
.param factmis='0.0143*geo_fac*par_rfres_sa*mismatchflag'
.param rsh='rppolysrf*(1+factmis)' dw='-0.023u+dxw_rppolysrf' pvc1 = 8.54E-08   pvc2 = 4.18E-12   ptc1 = 0.002371857   ptc2 = -6.16E-07   pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param rsubtfac='1.0+3.74m*(pt-25.0)+9.1u*(pt-25.0)*(pt-25.0)'
.param rsubx='277/((1/(0.5u+(l*scale+0.24u)/6)*(w*scale-dw))+(1/(3u+(w*scale-dw)/6)*(l*scale+0.24u)))*rsubtfac'
.param Ca='ca_pofoxrf' Cf='cf_posfoxrf'
Rend1 hi 1   '22/(int(abs((w*scale-0.016u)/0.22u)+1))'
Ls1   1  12  '0.02*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R1    12 2   '1/6*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls2   2  23  '0.04*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R2    23 3   '1/3*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls3   3  34  '0.04*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
R3    34 4   '1/3*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
R4    4  45  '1/6*rsh*l*scale/(w*scale-dw)*(1+pvc1*abs(v(5,1)/(l*scale))+pvc2*v(5,1)/(l*scale)*v(5,1)/(l*scale))*tfac'
Ls4   45 5   '0.02*l*scale*1e+6*(log((l*scale)/(w*scale))+0.022*(w*scale)/(l*scale)+1.19)*1e-12*sal_fac'
Rend2 5  lo  '22/(int(abs((w*scale-0.016u)/0.22u)+1))'
Cox1  2  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Cox2  3  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Cox3  4  6   '1/3*(Ca*w*scale*(l*scale+0.24u)*1e+12+Cf*2*(w*scale+l*scale+0.24u)*1e+6)'
Rsub  6  gnode 'rsubx*sarsub_fac'
Csub  6  gnode '85f/rsubx*sacsub_fac'
.ends rppolys_rf
.ENDL RF_RES_SA


.LIB RF_RES_RPO
.subckt rppolywo_rf hi lo gnode l=10u w=5u scale='scale_rfres_rpo' mismatchflag=0
.param geo_fac ='1/sqrt(l*scale*w*scale*1e12)'
.param factmis='0.006*geo_fac*par_rfres_rpo*mismatchflag'
.param rsh='rppolyworf*(1+factmis)' 
.param rendsh = 'rend_rppolyworf*2*1e6*(1+factmis)'
.param dw = '(0.03685u + dxw_rppolyworf)*1e6' dwend = '(0.03685u + dxw_rppolyworf)*1e6' dl = '(0u + dxl_rppolyworf)*1e6'
.param weff= 'w*scale - dw/1e6 '
.param leff= 'l*scale- dl/1e6'
.param wendeff= 'w*scale - dwend/1e6'
.param Jc1_0 = 0.0695053510675811  Jc1_w=0.0269845671346735  Jc1_n=0.000714977117664719
.param Jc1end_0 = 27.900361735252  Jc1end_w=0
.param Tc1_0 = -0.000326161317630646  Tc1_w=3.10855059871834E-06
.param Tc2_0 = 8.05172629127237E-07  Tc2_w=-2.79415787596679E-08
.param Tc1end_0 = -0.00141906402431781  Tc1end_w=1.51517802655145E-05
.param Tc2end_0 = 1.19263050938459E-06  Tc2end_w=5.77755688915007E-07
.param Jct_0 = -0.00425159480565355  Jct_w=2.26507523320411E-05
.param Jctend_0 = -0.00141455931220154  Jctend_w=0.000920093941015092
.param Delta_T = 'temper - 25'
.param lum = 'l*scale*1e6'   wum = 'w*scale*1e6'   nsqr= '(l*scale)/(w*scale)'
.param Tc1 = 'Tc1_0 + Tc1_w * wum'   Tc2 = 'Tc2_0 + Tc2_w * wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w * wum'   Tc2end = 'Tc2end_0 + Tc2end_w * wum'
.param Jct = 'Jct_0 + Jct_w * wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh*(lum-Dl)/(wum-Dw)*Tfac'
.param rsubtfac='1.0+3.74m*(Delta_T)+9.1u*(Delta_T)*(Delta_T)'
.param rsubx='277/((1/(0.5u+(leff+0.68u)/6)*(weff))+(1/(3u+(weff)/6)*(leff+0.68u)))*rsubtfac'
.param Ca='ca_pofoxrf_rpo' Cf='cf_polfoxrf_rpo'

.param a1_rfresrpo=6.3E-23 
.param b1_rfresrpo=-2.35E-23 
.param c1_rfresrpo=7.5E-23 
.param KF_rppolywo_rf='a1_rfresrpo*(abs(rnoiseflag_rfresrpo)+rnoiseflag_rfresrpo)+b1_rfresrpo*(abs(rnoiseflag_rfresrpo)-rnoiseflag_rfresrpo)+c1_rfresrpo'

Rend1 hi 1   '1/2*max(min(Rendo/2*(3-1/(1+Jc1end*v(hi,1)*v(hi,1))), Rendo*1.5), Rendo/2)+22/(int(abs((wendeff-0.016u)/0.22u)+1))'
Ls1   1  12  '0.02*leff*1e+6*(log(leff/weff)+0.022*weff/leff+1.19)*1e-12*rpol_fac'
R1    12 2   Rppoly1 '1/6*max(min(Ro/2*(1+1/(1+Jc1*v(1,5)*v(1,5))), Ro*1.5), Ro/2)'
Ls2   2  23  '0.04*leff*1e+6*(log(leff/weff)+0.022*weff/leff+1.19)*1e-12*rpol_fac'
R2    23 3   Rppoly2 '1/3*max(min(Ro/2*(1+1/(1+Jc1*v(1,5)*v(1,5))), Ro*1.5), Ro/2)'
Ls3   3  34  '0.04*leff*1e+6*(log(leff/weff)+0.022*weff/leff+1.19)*1e-12*rpol_fac'
R3    34 4   Rppoly2 '1/3*max(min(Ro/2*(1+1/(1+Jc1*v(1,5)*v(1,5))), Ro*1.5), Ro/2)'
R4    4  45  Rppoly1 '1/6*max(min(Ro/2*(1+1/(1+Jc1*v(1,5)*v(1,5))), Ro*1.5), Ro/2)'
Ls4   45 5   '0.02*leff*1e+6*(log(leff/weff)+0.022*weff/leff+1.19)*1e-12*rpol_fac'
Rend2 5  lo  '1/2*max(min(Rendo/2*(3-1/(1+Jc1end*v(5,lo)*v(5,lo))), Rendo*1.5), Rendo/2)+22/(int(abs((wendeff-0.016u)/0.22u)+1))'
Cox1  2  6   '1/3*(Ca*weff*(leff+0.68u)*1e+12+Cf*2*(weff+leff+0.68u)*1e+6)'
Cox2  3  6   '1/3*(Ca*weff*(leff+0.68u)*1e+12+Cf*2*(weff+leff+0.68u)*1e+6)'
Cox3  4  6   '1/3*(Ca*weff*(leff+0.68u)*1e+12+Cf*2*(weff+leff+0.68u)*1e+6)'
Rsub  6  gnode 'rsubx*rporsub_fac'
Csub  6  gnode '85f/rsubx*rpocsub_fac'
.model Rppoly1 r L='(leff)/6' W='(weff)' KF='KF_rppolywo_rf' AF=2 EF=0.9 WF=1 LF=1
.model Rppoly2 r L='(leff)/3' W='(weff)' KF='KF_rppolywo_rf' AF=2 EF=0.9 WF=1 LF=1

.ends rppolywo_rf
.ENDL RF_RES_RPO




***********************************************************************
*             	              RFRTMOM                                 *
***********************************************************************
*****************************************************************************************************************
*														*
*    N65LP RF RTMOM											        *
*														*
*    Model name	     nv               nh            w(um)         s(um)          stm           spm		*
*                low    high     low    high    low    high    low    high    low    high   low    high		*
* --------------------------------------------------------------------------------------------------------------*
*    crtmom_rf     6     288      6      288    0.1    0.16    0.1   0.16      1      5      3       7		*
* --------------------------------------------------------------------------------------------------------------*
*	End Model												*
*                                                                                                               *
*           parameter range: nv : 6~288, nh : 6~288                                                             *
*                            nv and nh should be even fingers                                                   *
*                            w(width):0.1u ~0.16u (drawn size)                                                  *
*                            s(spacing):0.1u ~0.16u (drawn size)                                                *
*                            stm(start metal layer):M1,Mx (Mx is inter metal)                                   *
*                            spm(stop metal layer):Mx (Mx is inter metal)                                       *
*                            Total metal is at least 3 layers stacked with ploy shield                          *
*                            for example 1P6M                                                                   *
*                            stm(start metal layer):M1,M2,M3                                                    *
*                            spm(stop metal layer):M3,M4,M5                                                     *
*                                                                                                               *
*****************************************************************************************************************

.LIB scale_option_rfrtmom
.param scale_rfrtmom=1
.ENDL scale_option_rfrtmom


************* Library of MC corner ************************************
.LIB MC_RFRTMOM
.lib 'crn65lp_v1d5.l' scale_option_rfrtmom

.param 
+ A1_rfmom='par1_mom*1.4142/3' 
+ RTMOM_momfac1='1+(0.10607)*A1_rfmom'
+ RTMOM_momfac2='1+(0.28284)*A1_rfmom'
+ l_momfac=1.0
+ r_momfac=1.0
+ par_rfmom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RFRTMOM
.ENDL MC_RFRTMOM


************* Library of typical corner *******************************
.LIB TT_RFRTMOM
.lib 'crn65lp_v1d5.l' scale_option_rfrtmom

.param
+ RTMOM_momfac1= 1 	
+ RTMOM_momfac2= 1 
+ l_momfac=1
+ r_momfac=1
+ par_rfmom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RFRTMOM
.ENDL TT_RFRTMOM


************* Library of slow corner **********************************
.LIB SS_RFRTMOM
.lib 'crn65lp_v1d5.l' scale_option_rfrtmom

.param
+ RTMOM_momfac1= 1.15	
+ RTMOM_momfac2= 1.4	
+ l_momfac=1.0235
+ r_momfac=1.3
+ par_rfmom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RFRTMOM
.ENDL SS_RFRTMOM


************* Library of fast corner **********************************
.LIB FF_RFRTMOM
.lib 'crn65lp_v1d5.l' scale_option_rfrtmom

.param
+ RTMOM_momfac1= 0.85 	
+ RTMOM_momfac2= 0.6 
+ l_momfac=0.9762
+ r_momfac=0.7
+ par_rfmom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RFRTMOM
.ENDL FF_RFRTMOM


.LIB RFRTMOM

.subckt crtmom_rf a b p nv=48 nh=48 w=0.1u s=0.1u stm=1 spm=5 scale='scale_rfrtmom' mismatchflag=0
.param 
+ layno   = 'spm-stm+1'
+ laym1   = 'INT(layno/spm)'
+ layodd  = 'INT((layno+j1+j3+j5)/2)-laym1'
+ layeven = 'INT((layno+j2+j4)/2)'
+ r   = '0.92'
+ dw  = '((0.228495016028492)*(w*scale*1e6)+(0.864862940554024)*(s*scale*1e6)+(-4.46733713068237)*(s*scale*1e6)*(w*scale*1e6)+(-6.35923905319406E-02))*(1e-6)'
+ ww  = 'w*scale+dw'
+ ss  = 's*scale-dw'
+ wb  = '0.18u+dw'
+ sb  = '0.2u-dw'
+ lnv = 'nh*(ww+ss)-ss'
+ lnh = 'nv*(ww+ss)-ss'
+ tcc1  = '-12.4*1e-6'
+ tcc2  = '0.0133*1e-6'
+ vcc1  = '-0.1*1e-6'
+ vcc2  = '0.8*1e-6'
+ j1 = '(stm-2)*(stm-3)*(stm-4)*(stm-5)/(1-2)/(1-3)/(1-4)/(1-5)'
+ j2 = '(stm-1)*(stm-3)*(stm-4)*(stm-5)/(2-1)/(2-3)/(2-4)/(2-5)'
+ j3 = '(stm-1)*(stm-2)*(stm-4)*(stm-5)/(3-1)/(3-2)/(3-4)/(3-5)'
+ j4 = '(stm-1)*(stm-2)*(stm-3)*(stm-5)/(4-1)/(4-2)/(4-3)/(4-5)'
+ j5 = '(stm-1)*(stm-2)*(stm-3)*(stm-4)/(5-1)/(5-2)/(5-3)/(5-4)'
*
+ Edg ='((layodd+r*laym1)*(nv-1)*lnv+layeven*(nh-1)*lnh)'
+ AREA='nv*nh/2*ww*(layno-1)'
+ FRI1='(2*nh*nv*ww)*(layno-1)'
+ FRI2='(layodd+r*laym1)*lnv*2+layeven*(lnh+sb)*2+((layodd+r*laym1)*nv*ww+layeven*nh*ww)+layno*wb*2'
+ Abm ='((lnh+(wb+sb)*2)+(lnv+sb))*wb/ww*(1.7*j1+8*j2+8*(j3+j4+j5))'
+ Afm ='(j1+j3+j5)*(nv*(lnv+sb))/2+(j2+j4)*(nh*(lnh+sb))/2'
+ Pf  ='(j1+j3+j5)*nv*(lnv+sb)+(j2+j4)*nh*(lnh+sb)+2*(lnv+lnh)+6*wb+6*sb'
+ Pfb ='j1*(lnv+2*wb+sb)*1'
*
+ Cc1 ='((3.31778571428518E-03)/(w*scale*1e6)+(4.58367293233029E-03)/(s*scale*1e6)+(3.33151365255902E-05)/(s*scale*1e6)/(w*scale*1e6)+(3.18642857143291E-03))*1.0005'
+ Cc2 ='(0.0471)*1.49'
+ Cf  ='((0.217378960485214)*(w*scale*1e6)+(0.152520469919126)*(s*scale*1e6)+(-0.787958348173258)*(s*scale*1e6)*(w*scale*1e6)+(-1.11529681382862E-02))*0.7'
+ Ca  ='(((-7.4178977970751E-03)*(w*scale*1e6)+(1.64193663145724E-02)*(s*scale*1e6)+(0.22479975089191)*(s*scale*1e6)*(w*scale*1e6)+(5.00430980214061E-03))*0.5)'
*
+ ca_p_a='(j1*(0.228499695208201)*0.6308+j2*(9.21578947359392E-02)*0.4976+j3*(4.63684210684769E-02)*0.4055+j4*(2.64537201083299E-02)*0.4055+j5*(2.00000889208476E-02)*0.4055)'
+ ca_p_b='(j1*(9.07506717796861E-02)*0.6308+j2*(5.95789473675215E-02)*0.4976+j3*(3.06315789633253E-02)*0.4055+j4*(2.07273050345198E-02)*0.4055+j5*(1.56699002205504E-02)*0.4055)'
+ ca_p_c='(j1*(-0.377728701830403)*0.6308+j2*(-0.354986149577421)*0.4976+j3*(-0.176869806250642)*0.4055+j4*(-0.105731576687923)*0.4055+j5*(-7.99127797182435E-02)*0.4055)'
+ ca_p_d='(j1*(-8.09567284527284E-03)*0.6308+j2*(-6.66999999988505E-03)*0.4976+j3*(-3.22000000149291E-03)*0.4055+j4*(-1.82074224563325E-03)*0.4055+j5*(-1.36635723238263E-03)*0.4055)'
*
+ cf_p_a='(j1*(3.92322184993517E-03)*0.6308+j2*(9.73684223713357E-04)*0.4976+j3*(0.008631579009041)*0.4055+j4*(-1.35697747026833E-03)*0.4055+j5*(-1.38305409476152E-04)*0.4055)'
+ cf_p_b='(j1*(5.26195109392581E-02)*0.6308+j2*(6.47368422147126E-03)*0.4976+j3*(8.02631583671123E-03)*0.4055+j4*(2.91660738192766E-03)*0.4055+j5*(3.3899964647692E-03)*0.4055)'
+ cf_p_c='(j1*(0.095762967753077)*0.6308+j2*(0.121952908482245)*0.4976+j3*(4.46675895930827E-02)*0.4055+j4*(0.055633676966577)*0.4055+j5*(4.34229260807518E-02)*0.4055)'
+ cf_p_d='(j1*(8.54632956062667E-03)*0.6308+j2*(5.82999999863725E-03)*0.4976+j3*(4.2199999931874E-03)*0.4055+j4*(5.05353060446388E-03)*0.4055+j5*(4.65741277617021E-03)*0.4055)'
*
+ Ca_p ='(ca_p_a*(w*scale*1e6)+ca_p_b*(s*scale*1e6)+ca_p_c*(s*scale*1e6)*(w*scale*1e6)+ca_p_d)*1'
+ Cf_p ='(cf_p_a*(w*scale*1e6)+cf_p_b*(s*scale*1e6)+cf_p_c*(s*scale*1e6)*(w*scale*1e6)+cf_p_d)*1'
+ Cc_p ='(0.017)*4'
*
+ geo_fac ='1/sqrt((Cc1*Edg*1e-9+Cf*1e-9*FRI1+Ca*1e-9*AREA+Cc2*1e-9*FRI2)*1e15)'
+ mis='0.32*(((geo_fac-0.027)**2+0.000000000000000001)**0.5+geo_fac)+2.4*(((geo_fac-0.027)**2+0.000000000000000001)**0.5-geo_fac)+0.084'
+ factmis='mis/1.414/100*par_rfmom*mismatchflag'
*
+ length_nv='nh*((w*scale)+(s*scale))-(s*scale)'
+ res_nv='length_nv/(w*scale)*0.14+0.2*1e-6/(w*scale)*0.14'
+ latres_nv='((w*scale)+2*(s*scale))/(0.18*1e-6)*0.14'
+ fin_nv='nv/2'
+ totres_nv='(latres_nv/2+(fin_nv/2-1)*(fin_nv-1)/(6*fin_nv/2)*latres_nv+res_nv/(fin_nv/2))/2'
+ allres_nv='totres_nv/(layodd+laym1)'
+ length_nh='nv*((w*scale)+(s*scale))-(s*scale)'
+ res_nh='length_nh/(w*scale)*0.14+0.2*1e-6/(w*scale)*0.14'
+ latres_nh='((w*scale)+2*(s*scale))/(0.18*1e-6)*0.14'
+ fin_nh='nh/2'
+ rend_nh='(0.2*1e-6+(w*scale)+(s*scale)+length_nh/2+0.2*1e-6)/(0.18*1e-6)*0.14'
+ totres_nh='rend_nh+(fin_nh-1)*(2*fin_nh-1)/(6*fin_nh)*latres_nh+res_nh/fin_nh'
+ allres_nh='totres_nh/layeven'
+ total_res='1/(1/allres_nv+1/allres_nh)*(((-0.00712873084974587*nh/nv+3.35551710606971/nh)+(-0.00895910254712926*nv/nh+2.01477796505834/nv)+6.5884069072713E-07*nv*nh)*(-35.140406193376*((w*scale)*1e6)-68.3803850278667*((s*scale)*1e6)+0.108753331486981/((w*scale)*1e6)/((s*scale)*1e6)+1023.24230850048*((w*scale)*1e6)*((s*scale)*1e6))+0.478099155984093)+0.103399478730698'
*
+ l_nvnh='((0.2*(length_nv*1e6)*(log((length_nv*1e6)/(length_nh*1e6+0.22))+1.19+0.022*(length_nh*1e6+0.22)/(length_nv*1e6))+1.5))'
+ total_nvnh='(0.1+(layno-1)*(2*layno-1)/(6*layno)*0.1+l_nvnh/layno)'
+ total_l='((0.229289757299351*total_nvnh**2+0.365863332205633*total_nvnh-0.242677462368036)*(0.205246455834331*(((w*scale)*1e6)+((s*scale)*1e6))**(-0.30997693758166))*((0.139488733019201*nv*nh+0.268982725644102*nv/nh-4.97906032421557*nh/nv)**(0.0850436841380641))*(0.138127474751232*(layno)**(1.55674090087571))+4.25301938990689)*1e-12'
*
*
la a n1 'total_l*l_momfac'
ra n1 a1 'total_res*(0.0036*(temper-25)+1)*r_momfac'
Cab a1 b1 '(1+factmis)*(Cc1*Edg+Cf*FRI1+Ca*AREA+Cc2*FRI2)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a1,b1)+vcc2*v(a1,b1)*v(a1,b1))*RTMOM_momfac1'
Cpa a1 p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a1,p)+vcc2*v(a1,p)*v(a1,p))*RTMOM_momfac2'
Cpb b1 p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(b1,p)+vcc2*v(b1,p)*v(b1,p))*RTMOM_momfac2'
rb b1 n2 'total_res*(0.0036*(temper-25)+1)*r_momfac'
lb n2 b 'total_l*l_momfac'

.ends crtmom_rf


.ENDL RFRTMOM



***************************************************************************
* RF IO ESD Low-Capacitance Pad Model: 
*
*  
*     ## library files:
*     
*           
*      Model name	        wt (um)        lt (um)              lay 
*                           low   high      low     high         low    high
*      ---------------------------------------------------------------------------------
*       lowcpad_d15	    47     80        47     80            6      9
*       lowcpad_d23	    47     80        47     80            6      9
*      ---------------------------------------------------------------------------------
*	End Model
*  Note:"lowcpad_d15" means 15% float metal density and "lowcpad_d23" means 23% float metal density.
***************************************************************************

.LIB scale_option_pad
.param scale_pad=1
.ENDL scale_option_pad
**************************************************************************
************* RF IO ESD Low-Capacitance Pad Corner Parameters ************
**************************************************************************
.lib tt_lowcpad
.lib 'crn65lp_v1d5.l' scale_option_pad
.param lowcpad_fac=1
.lib 'crn65lp_v1d5.l' lowc_pad
.endl tt_lowcpad

.lib ff_lowcpad
.lib 'crn65lp_v1d5.l' scale_option_pad
.param lowcpad_fac=0.85
.lib 'crn65lp_v1d5.l' lowc_pad
.endl ff_lowcpad

.lib ss_lowcpad
.lib 'crn65lp_v1d5.l' scale_option_pad
.param lowcpad_fac=1.15
.lib 'crn65lp_v1d5.l' lowc_pad
.endl ss_lowcpad


.lib lowc_pad
.subckt lowcpad_d15 APAD AVSS lt=50u wt=50u lay=6 scale=scale_pad
cpad APAD AVSS '(0.0186*lt*scale*wt*scale*1e12+2.4107)*(0.0171*lay**2-0.3719*lay+2.6155)*1e-15*lowcpad_fac'
.ends lowcpad_d15

.subckt lowcpad_d23 APAD AVSS lt=50u wt=50u lay=6 scale=scale_pad
cpad APAD AVSS '(0.0197*lt*scale*wt*scale*1e12+1.42)*(0.0164*lay**2-0.3622*lay+2.5815)*1e-15*lowcpad_fac'
.ends lowcpad_d23
.endl lowc_pad





***************************************************************************
* High-Current Diode RF Model :
*
*  
*     ## library files:
*           
*      Model name        aw(um)           al(um)          fn
*                      low   high       low   high    low   high
*      -------------------------------------------------------------
*       ndio_hia_rf    0.6/0.8/1.6        5   40         1   3  
*       pdio_hia_rf    0.6/0.8/1.6        5   40         1   3    
*      -------------------------------------------------------------
*      End Model
*     Note: 1. Only discrete width[aw] can be used in this model;
*              length[al] should be used with at least 1um integer step.
*           2. "anode" means P+ region of P+/NW diode and N+ region of N+/PSUB diode
*           3. aw & al are width & length of "anode" region.
*           4. hiaflag=0 for reverse RF simulation; 
*              hiaflag=1 for forward ESD high-current simulation.
***************************************************************************

.LIB scale_option_esd
.param scale_esd=1
.ENDL scale_option_esd

*************************************************************
***************     CORNER_LIB OF TYPICAL High-Current Diode MODEL     ***************
.lib tt_dio_hia_rf
.lib 'crn65lp_v1d5.l' scale_option_esd
.param
+L_fac_hia= 1             Rm_fac_hia= 1                  
+Rsub_fac_hia= 1          Csub_fac_hia= 1           Rwell_fac_hia= 1          Csti_fac_hia= 1
.param
+is_esd_macro_hia = 1                   jsw_esd_macro_hia  = 1                   n_esd_macro_hia= 1         rs_esd_macro_hia= 0
+cj_esd_macro_hia = 1                   cjsw_esd_macro_hia = 1 
+dpvc0_nd_hia     = '4.18E+04*0'        dpvc1_nd_hia       = '0.105*0'
+dpvc0_pd_hia     = '6.91E+04*0'        dpvc1_pd_hia       = '0.157*0'

.lib 'crn65lp_v1d5.l' dio_hia_rf
.endl tt_dio_hia_rf

***************     CORNER_LIB OF SLOW High-Current Diode MODEL     ***************
.lib ss_dio_hia_rf
.lib 'crn65lp_v1d5.l' scale_option_esd
.param
+L_fac_hia= 1.0235         Rm_fac_hia= 1.1                  
+Rsub_fac_hia= 0.8        Csub_fac_hia= 1.25        Rwell_fac_hia= 1.15       Csti_fac_hia= 1.05
.param
+is_esd_macro_hia = 0.7                 jsw_esd_macro_hia  = -1                  n_esd_macro_hia= 0.9975         rs_esd_macro_hia= 0
+cj_esd_macro_hia = 1.07                cjsw_esd_macro_hia = 1.07
+dpvc0_nd_hia     = '4.18E+04*(-0.30)'  dpvc1_nd_hia       = '0.105*(-0.00)'
+dpvc0_pd_hia     = '6.91E+04*(-0.30)'  dpvc1_pd_hia       = '0.157*(-0.00)'

.lib 'crn65lp_v1d5.l' dio_hia_rf
.endl ss_dio_hia_rf

***************     CORNER_LIB OF FAST High-Current Diode MODEL     ***************
.lib ff_dio_hia_rf
.lib 'crn65lp_v1d5.l' scale_option_esd
.param
+L_fac_hia= 0.9762         Rm_fac_hia= 0.9                  
+Rsub_fac_hia= 1.2         Csub_fac_hia= 0.83333    Rwell_fac_hia= 0.85       Csti_fac_hia= 0.95
.param
+is_esd_macro_hia = 1.3                 jsw_esd_macro_hia  = +1                  n_esd_macro_hia= 1.0025         rs_esd_macro_hia= 0
+cj_esd_macro_hia = 0.93                cjsw_esd_macro_hia = 0.93
+dpvc0_nd_hia     = '4.18E+04*0.30'     dpvc1_nd_hia       = '0.105*0.00'
+dpvc0_pd_hia     = '6.91E+04*0.30'     dpvc1_pd_hia       = '0.157*0.00'

.lib 'crn65lp_v1d5.l' dio_hia_rf
.endl ff_dio_hia_rf

***************     STATISTCAL MODEL OF High-Current Diode     ***************
.lib mc_dio_hia_rf
.lib 'crn65lp_v1d5.l' scale_option_esd
.param
+par1_RFHIA=AGAUSS(0,1,3)
+A1_RFHIA='par1_RFHIA' 

.param
+L_fac_hia= '1 + (+0.0235)*A1_RFHIA'
+Rm_fac_hia= '1 + (+0.1000)*A1_RFHIA'
+Rsub_fac_hia= '1 + (-0.2000)*A1_RFHIA'
+Csub_fac_hia= '1 + (+0.2500)*A1_RFHIA'
+Rwell_fac_hia= '1 + (+0.1500)*A1_RFHIA'
+Csti_fac_hia= '1 + (+0.0500)*A1_RFHIA'
.param
+is_esd_macro_hia = '1 + (-0.3000)*A1_RFHIA'
+jsw_esd_macro_hia  = '0 + (-1.0000)*A1_RFHIA'
+n_esd_macro_hia= '1 + (-0.0025)*A1_RFHIA'
+rs_esd_macro_hia= '0'
+cj_esd_macro_hia = '1 + (+0.0700)*A1_RFHIA'
+cjsw_esd_macro_hia = '1 + (+0.0700)*A1_RFHIA'
+dpvc0_nd_hia     = '4.18E+04 * (0 + (-0.3000)*A1_RFHIA)'
+dpvc1_nd_hia       = '0.105 * 0'
+dpvc0_pd_hia     = '6.91E+04 * (0 + (-0.3000)*A1_RFHIA)'
+dpvc1_pd_hia       = '0.157 * 0'

.lib 'crn65lp_v1d5.l' dio_hia_rf
.endl mc_dio_hia_rf




.lib dio_hia_rf
***************************************************************
*            2-Terminal N+/PW High-Current Diode              *
***************************************************************
.subckt ndio_hia_rf cathode anode aw=0.8u al=20u fn=1 scale=scale_esd hiaflag=0
.param area_d1='fn*al*scale*aw*scale/scale/scale'      
.param peri_d1='2*fn*(al+aw)*scale/scale'
.param width_d2='(2*fn+1)*aw*scale+fn*2*0.2u+0.16u*2'
.param length_d2='al*scale+0.4u*2+aw*scale*2+0.16u*2'
.param area_d2='(width_d2*length_d2)/scale/scale'
.param peri_d2='2*(width_d2+length_d2)/scale'

.param awum='aw*scale*1e6'
.param alum='al*scale*1e6'

.param w06_R_anode='3.6465/alum+0.3417/fn+5.7505/alum/fn+0.2167'
.param w06_R_cathode='2.5455/alum+0.2546/fn+2.075/alum/fn+0.0981'
.param w06_L_1='(12.6851/alum+1.1415/fn+45.4551/alum/fn+0.3185)*1e-12'
.param w06_L_2='(5.6378/alum+0.5073/fn+20.2023/alum/fn+0.1416)*1e-12'
.param w06_R_well='12.7272/alum+4.1952/fn+415.6479/alum/fn+(-0.7573)'
.param w06_C_well='(0)*1e-15'
.param w06_C_sti='(0.0545*alum+0.7587*fn+0.0569*alum*fn+(-0.3551))*1e-15'

.param w08_R_anode='3.0388/alum+0.2848/fn+4.7923/alum/fn+0.1806'
.param w08_R_cathode='2.1213/alum+0.2122/fn+1.7292/alum/fn+0.0818'
.param w08_L_1='(10.5709/alum+0.9512/fn+37.8792/alum/fn+0.2655)*1e-12'
.param w08_L_2='(4.6982/alum+0.4228/fn+16.8352/alum/fn+0.1180)*1e-12'
.param w08_R_well='71.8865/alum+7.4975/fn+327.6971/alum/fn+(-3.4546)'
.param w08_C_well='(0)*1e-15'
.param w08_C_sti='(0.4182*alum+(-0.6346)/fn+(-0.1119)*alum/fn+1.3712)*1e-15'

.param w16_R_anode='3.1195/alum+0.312/fn+2.5429/alum/fn+0.1203'
.param w16_R_cathode='1.7677/alum+0.1768/fn+1.4410/alum/fn+0.0681'
.param w16_L_1='(8.8091/alum+0.7927/fn+31.5660/alum/fn+0.2212)*1e-12'
.param w16_L_2='(3.9152/alum+0.3523/fn+14.0293/alum/fn+0.0983)*1e-12'
.param w16_R_well='(-15.8842)/alum+(-2.7405)/fn+454.7319/alum/fn+2.0321'
.param w16_C_well='(0)*1e-15'
.param w16_C_sti='(0.2158*alum+0.6722/fn+0.2657*alum/fn+2.8537)*1e-15'

.param dt='temper-25'
.param rfflag=abs(hiaflag-1)

Ranode anode 3 'rfflag*Rm_fac_hia*(1+2.69e-3*dt-3e-7*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_anode+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_anode+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_anode)'
L1 3 4 'L_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_L_1+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_L_1+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_L_1)'
XD1 5 4 ndioesd_m_hia w='aw' l='al' scale=scale_esd multi='fn'
Rwell1 5 6 'rfflag*Rwell_fac_hia*(1+2.95e-3*dt+8.42e-6*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_well+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_well+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_well)'
L2 6 7 'L_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_L_2+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_L_2+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_L_2)'
Rcathode 7 cathode 'rfflag*Rm_fac_hia*(1+2.69e-3*dt-3e-7*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_cathode+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_cathode+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_cathode)'
Csti 4 6 'Csti_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_C_sti+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_C_sti+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_C_sti)'

.ends ndio_hia_rf
*
*
***************************************************************
*            3-Terminal P+/NW High-Current Diode              *
***************************************************************
.subckt pdio_hia_rf anode cathode gnode aw=0.8u al=20u fn=1 scale=scale_esd hiaflag=0
.param area_d1='fn*al*scale*aw*scale/scale/scale'      
.param peri_d1='2*fn*(al+aw)*scale/scale'
.param width_d2='(2*fn+1)*aw*scale+fn*2*0.2u+0.16u*2'
.param length_d2='al*scale+0.4u*2+aw*scale*2+0.16u*2'
.param area_d2='(width_d2*length_d2)/scale/scale'
.param peri_d2='2*(width_d2+length_d2)/scale'

.param awum='aw*scale*1e6'
.param alum='al*scale*1e6'

.param w06_R_anode='3.6465/alum+0.3417/fn+5.7505/alum/fn+0.2167'
.param w06_R_cathode='2.5455/alum+0.2546/fn+2.075/alum/fn+0.0981'
.param w06_L_1='(12.6851/alum+1.1415/fn+45.4551/alum/fn+0.3185)*1e-12'
.param w06_L_2='(5.6378/alum+0.5073/fn+20.2023/alum/fn+0.1416)*1e-12'
.param w06_R_well='43.0288/alum+3.2096/fn+76.6191/alum/fn+427.7024/alum**2/fn+0.7853'
.param w06_C_sti='(0.8476*alum+0.8046*fn+0.1292*alum*fn+42.2159/alum+(-0.0119)*alum**2+(-11.7169))*1e-15'
.param w06_R_sub='144.5886/alum+(-13.2710)/fn+941.8115/alum/fn+(-2990.3884)/alum**2/fn+14.3679'
.param w06_C_sub='(0.0617*alum+0.1472*fn+0.0395*alum*fn+1.3679)*1e-15'
.param w06_C_para2='((-0.2610)*alum+(-0.8528)/fn+1.0363*alum/fn+17.5241)*1e-15'

.param w08_R_anode='3.0388/alum+0.2848/fn+4.7923/alum/fn+0.1806'
.param w08_R_cathode='2.1213/alum+0.2122/fn+1.7292/alum/fn+0.0818'
.param w08_L_1='(10.5709/alum+0.9512/fn+37.8792/alum/fn+0.2655)*1e-12'
.param w08_L_2='(4.6982/alum+0.4228/fn+16.8352/alum/fn+0.1180)*1e-12'
.param w08_R_well='(-1.8381)/alum+(-2.8355)/fn+280.9525/alum/fn+1.2589'
.param w08_C_sti='(0.3902*alum+7.2693*fn+0.0563*alum*fn+(-1.4898)*fn**2+(-5.5305)+(-0.4))*1e-15'
.param w08_R_sub='26.0201/alum+(-4.9064)/fn+438.1806/alum/fn+15.9548'
.param w08_C_sub='(0.1303*alum+0.4563*fn+0.0412*alum*fn+0.7345)*1e-15'
.param w08_C_para2='((-0.0532)*alum+5.5284/fn+0.7605*alum/fn+14.7352)*1e-15'

.param w16_R_anode='3.1195/alum+0.312/fn+2.5429/alum/fn+0.1203'
.param w16_R_cathode='1.7677/alum+0.1768/fn+1.4410/alum/fn+0.0681'
.param w16_L_1='(8.8091/alum+0.7927/fn+31.5660/alum/fn+0.2212)*1e-12'
.param w16_L_2='(3.9152/alum+0.3523/fn+14.0293/alum/fn+0.0983)*1e-12'
.param w16_R_well='(-47.6746)/alum+(-4.9952)/fn+389.5682/alum/fn+261.8807/alum**2+(-898.099)/alum**2/fn+2.1823'
.param w16_C_sti='(0.4944*alum+2.3518/fn+0.0367*alum/fn+(-79.1111)/alum+345.3968/alum**2+6.3183)*1e-15'
.param w16_R_sub='(-56.5217)/alum+(-4.0635)/fn+303.6522/alum/fn+9.1355'
.param w16_C_sub='(0.3199*alum+3.1005*fn+0.0255*alum*fn+(-1.0751))*1e-15'
.param w16_C_para2='((-0.7265)*alum+11.5936/fn+1.0232*alum/fn+19.2701)*1e-15'

.param dt='temper-25'
.param rfflag=abs(hiaflag-1)

Ranode anode 4 'rfflag*Rm_fac_hia*(1+2.69e-3*dt-3e-7*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_anode+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_anode+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_anode)'
L1 4 5 'L_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_L_1+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_L_1+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_L_1)'
XD1 5 6 pdioesd_m_hia w='aw' l='al' scale=scale_esd multi='fn'
Rwell1 6 7 'rfflag*Rwell_fac_hia*(1+2.95e-3*dt+8.42e-6*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_well/2+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_well/2+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_well/2)'
Rwell2 7 8 'rfflag*Rwell_fac_hia*(1+2.95e-3*dt+8.42e-6*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_well/2+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_well/2+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_well/2)'
L2 8 9 'L_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_L_2+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_L_2+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_L_2)'
Rcathode 9 cathode 'rfflag*Rm_fac_hia*(1+2.69e-3*dt-3e-7*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_cathode+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_cathode+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_cathode)'
Csti 5 8 'Csti_fac_hia*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_C_sti+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_C_sti+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_C_sti)'
D2 10 7 NWPSUB_HIA area='area_d2' pj='peri_d2'
Rsub 10 gnode 'rfflag*Rsub_fac_hia*(1+2.95e-3*dt+8.42e-6*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_R_sub+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_R_sub+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_R_sub)'
Csub 10 gnode 'Csub_fac_hia*(1+2.95e-3*dt+8.42e-6*dt*dt)*((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_C_sub+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_C_sub+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_C_sub)'
Cpara2 8 gnode '((aw*scale-0.8u)*(aw*scale-1.6u)/(0.6u-0.8u)/(0.6u-1.6u)*w06_C_para2+(aw*scale-0.6u)*(aw*scale-1.6u)/(0.8u-0.6u)/(0.8u-1.6u)*w08_C_para2+(aw*scale-0.6u)*(aw*scale-0.8u)/(1.6u-0.6u)/(1.6u-0.8u)*w16_C_para2)'

.ends pdio_hia_rf
*
*
.lib 'crn65lp_v1d5.l' DIO_NWPSUB_HIA
.lib 'crn65lp_v1d5.l' DIO_MAC_HIA
.lib 'crn65lp_v1d5.l' DIO_MDL_HIA
*
*
.endl dio_hia_rf


*************************************************************
.LIB DIO_NWPSUB_HIA
.MODEL NWPSUB_HIA D (                                    LEVEL  = 3
+ IS     = 3.41E-06          IKR    = 1E10               RS     = 0
+ N      = 1.02              BV     = 12                 IBV    = 0.03
+ JSW    = 1.05E-12          CJ     = 1.37E-04           PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = 7.25E-10
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )
.ENDL DIO_NWPSUB_HIA
*************************************************************



.LIB DIO_MDL_HIA
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
***************************************************************
.MODEL NDIOESD_HIA D (                                                            LEVEL  = 3
+ IS     = '1.8421E-07*is_esd_macro_hia'   IKR    = 1E10                          RS     = '1E-10*rs_esd_macro_hia'
+ N      = '1.02*n_esd_macro_hia'          BV     = 9.10                          IBV    = 0.03
+ JSW    = '1.4539E-13*pwr(2,jsw_esd_macro_hia)'  CJ     = '1.12E-03*cj_esd_macro_hia'   PJ     = 7.2E-4
+ MJ     = 0.36                            FC     = 0                             CJSW   = '2.530E-10*cjsw_esd_macro_hia'
+ AREA   = 3.08E-8                         MJSW   = 0.07                          TLEVC  = 1
+ CTA    = 7.00E-04                        CTP    = 5.00E-04                      TRS    = 2.5E-3
+ TCV    = -5.0E-04                        TLEV   = 1                             XTI    = 3
+ EG     = 1.17                            PHP    = 0.95                          PB     = 0.75
+ IK     = 1E+06                           TPB    = 2.0E-3                        TREF   = 25
+ TPHP   = 4E-04                           FCS    = 0                  )
***************************************************************
*                      MODEL OF P+/NW DIODE                   *
***************************************************************
.MODEL PDIOESD_HIA D (                     LEVEL  = 3
+ IS     = '1.6457E-07*is_esd_macro_hia'   IKR    = 1E10                          RS     = '1.0E-10*rs_esd_macro_hia'
+ N      = '1.02*n_esd_macro_hia'          BV     = 9.4                           IBV    = 0.03
+ JSW    = '1.1584E-13*pwr(2,jsw_esd_macro_hia)'  CJ     = '9.57E-04*cj_esd_macro_hia'   PJ     = 7.2E-4
+ MJ     = 0.38                            FC     = 0                             CJSW   = '2.22E-10*cjsw_esd_macro_hia'
+ AREA   = 3.08E-8                         MJSW   = 0.062                         TLEVC  = 1
+ CTA    = 1.05E-03                        CTP    = 2E-04                         TRS    = 2.5E-3
+ TCV    = -5.0E-04                        TLEV   = 1                             XTI    = 3
+ EG     = 1.17                            PHP    = 1                             PB     = 0.78
+ IK     = 1E+06                           TPB    = 3E-3                          TREF   = 25
+ TPHP   = 2E-03                           FCS    = 0                  )
*
.ENDL DIO_MDL_HIA



.LIB DIO_MAC_HIA
********************************* N-Type Diode ******************************
.subckt ndioesd_m_hia n2 n1 l=20u w=0.8u scale=1 multi=1
.param dw = 0
.param ptc1 = 2.02E-03   ptc2 = 9.94E-06
.param pvc0_nd = '3.03e+4+dpvc0_nd_hia'   pvc1_nd = '0.0225+dpvc1_nd_hia'    pvc2_nd = '0.0'
.param pvc3_nd =00.0E-03                  pvc4_nd = '0'                      pvc5_nd = '0.018'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
d1 n2 nx ndioesd_hia area='multi*(w-dw)*scale*l*scale/scale/scale' pj='2*multi*((w-dw)*scale+l*scale)/scale'
r1 nx n1 '1E-5+v(nx,n1)/(1e-12+(2*((multi-1)*0.9+1)*(6.3024e-1*(w*scale-dw+l*scale-0.8e-6)/(20*1e-6))*tanh((pvc1_nd*v(nx,n1)+pvc3_nd*v(nx,n1)**3+pvc4_nd*v(nx,n1)**5)/(pvc5_nd+pvc2_nd*abs(v(nx,n1))))))*tfac'
.ends ndioesd_m_hia
********************************* P-Type Diode ******************************
.subckt pdioesd_m_hia n2 n1 l=20u w=0.8u scale=1 multi=1
.param dw = 0
.param ptc1 = 2.02E-03   ptc2 = 9.94E-06
.param pvc0_pd = '19.91E+04+dpvc0_pd_hia'   pvc1_pd = '0.159+dpvc1_pd_hia'    pvc2_pd = '0.04'
.param pvc3_pd = '1.7E-03'                  pvc4_pd = 0                       pvc5_pd = '1' 
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
d1 n2 nx pdioesd_hia area='multi*(w-dw)*scale*l*scale/scale/scale' pj='2*multi*((w-dw)*scale+l*scale)/scale'
r1 nx n1 '1E-5+v(nx,n1)/(1e-12+(2*((multi-1)*0.3+1)*pvc0_pd*(w*scale-dw+l*scale)*tanh((pvc1_pd*v(nx,n1)+pvc3_pd*v(nx,n1)**3+pvc4_pd*v(nx,n1)**5)/(pvc5_pd+pvc2_pd*abs(v(nx,n1))))))*tfac'
.ends pdioesd_m_hia

.ENDL DIO_MAC_HIA



*****************************************************************************
*   
* CMOS 65nm Schottky Barrier Diode (SBD) Scalable Model
*
* HSPICE LEVEL 49:
*  
*     ## library files:
*        Model Name       l(um)            w(um)             nf
*                       low   high       low   high        low   high
*        --------------------------------------------------------------------
*        sbd_rf         0.4   4          1   16             1   16
*        sbd_rf_nw      0.4   4          1   16             1   16
*        --------------------------------------------------------------------
*        End Model
*****************************************************************************

.LIB scale_option_sbd
.param scale_sbd=1
.ENDL scale_option_sbd
*************************************************************************
************* Schottky Barrier Diode Model Corner Parameters ************
*************************************************************************
.LIB TT_RFSBD
.lib 'crn65lp_v1d5.l' scale_option_sbd
.param
+factor_isf_wi= 1       factor_re_wi=1        factor_isr_wi= 1        factor_cjf_wi= 1
+factor_isf_wo= 1       factor_re_wo=1        factor_isr_wo= 1        factor_cjf_wo= 1
+factor_l= 1            factor_rm= 1
+factor_rsub= 1         factor_csub= 1        factor_rnwell= 1        factor_csti= 1
+factor_is_d = 1        factor_jsw_d = 1      factor_n_d = 1          factor_rs_d = 1
+factor_cj_d = 1        factor_cjsw_d = 1
.lib 'crn65lp_v1d5.l' RF_SBD
.ENDL TT_RFSBD


.LIB SS_RFSBD
.lib 'crn65lp_v1d5.l' scale_option_sbd
.param
+factor_isf_wi= 0.1     factor_re_wi=1.3      factor_isr_wi= '1/25'   factor_cjf_wi= 1.05
+factor_isf_wo= 0.05    factor_re_wo=1.3      factor_isr_wo= '1/15'   factor_cjf_wo= 1.05
+factor_l= 1.0235       factor_rm= 1.1
+factor_rsub= 0.8       factor_csub= 1.25     factor_rnwell= 1.15     factor_csti= 1.05
+factor_is_d = 0.7      factor_jsw_d  = 0.5   factor_n_d = 1.0025     factor_rs_d = 1.2
+factor_cj_d = 1.07     factor_cjsw_d = 1.07
.lib 'crn65lp_v1d5.l' RF_SBD
.ENDL SS_RFSBD


.LIB FF_RFSBD
.lib 'crn65lp_v1d5.l' scale_option_sbd
.param
+factor_isf_wi= 1.9     factor_re_wi=0.7      factor_isr_wi= 25       factor_cjf_wi= 0.95
+factor_isf_wo= 1.95    factor_re_wo=0.7      factor_isr_wo= 15       factor_cjf_wo= 0.95
+factor_l= 0.9765       factor_rm= 0.9
+factor_rsub= 1.2       factor_csub= 0.75     factor_rnwell= 0.85     factor_csti= 0.95
+factor_is_d = 1.3      factor_jsw_d  = 2     factor_n_d = 0.9975     factor_rs_d = 0.8
+factor_cj_d = 0.93     factor_cjsw_d = 0.93
.lib 'crn65lp_v1d5.l' RF_SBD
.ENDL FF_RFSBD


*************************************************************************
************* Schottky Barrier Diode Model Statistical Model ************
*************************************************************************
.lib mc_RFSBD
.lib 'crn65lp_v1d5.l' scale_option_sbd
.param
+par1_RFSBD=AGAUSS(0,1,3)
+A1_RFSBD='par1_RFSBD*4.1231e+000*3/3' 

+factor_isf_wi   = '1.0000e+000+(-2.1828e-001)*A1_RFSBD'
+factor_re_wi    = '1.0000e+000+(7.2761e-002)*A1_RFSBD'
+factor_isr_wi   = '10**(par1_RFSBD*(-1)*(log(25)/3))'
+factor_cjf_wi   = '1.0000e+000+(1.21267978e-002)*A1_RFSBD'
+factor_isf_wo   = '1.0000e+000+(-2.3041e-001)*A1_RFSBD'
+factor_re_wo    = '1.0000e+000+(7.2761e-002)*A1_RFSBD'
+factor_isr_wo   = '10**(par1_RFSBD*(-1)*(log(15)/3))'
+factor_cjf_wo   = '1.0000e+000+(1.21267978e-002)*A1_RFSBD'
+factor_l        = '1.0000e+000+(5.6996e-003)*A1_RFSBD'
+factor_rm       = '1.0000e+000+(2.42535956e-002)*A1_RFSBD'
+factor_rsub     = '1.0000e+000+(-4.8507e-002)*A1_RFSBD'
+factor_csub     = '1.0000e+000+(6.0634e-002)*A1_RFSBD'
+factor_rnwell   = '1.0000e+000+(3.6380e-002)*A1_RFSBD'
+factor_csti     = '1.0000e+000+(1.2127e-002)*A1_RFSBD'
+factor_is_d     = '1.0000e+000+(-7.2761e-002)*A1_RFSBD'
+factor_jsw_d    = '10**(par1_RFSBD*(-1)*(log(2)/3))'
+factor_n_d      = '1.0000e+000+(6.0634e-004)*A1_RFSBD'
+factor_rs_d     = '1.0000e+000+(4.8507e-002)*A1_RFSBD'
+factor_cj_d     = '1.0000e+000+(1.6977e-002)*A1_RFSBD'
+factor_cjsw_d   = '1.0000e+000+(1.6977e-002)*A1_RFSBD'

.lib 'crn65lp_v1d5.l' RF_SBD
.endl mc_RFSBD



.LIB RF_SBD

*****************************************************************************
*****                 Schottky Diode with Deep N-Well                   *****
*****************************************************************************
.subckt sbd_rf 1 2 3 l=2e-006 w=4e-006 nf=1 scale=scale_sbd
.param lum = 'l*scale*1e6'
.param wum = 'w*scale*1e6'

.param num_strip = 'int(6+(lum-2)*2.8)'
.param r_strip = '(1.16*0.09/0.16)+(int((wum-0.08*2+0.18)/0.34)-1)*(2*int((wum-0.08*2+0.18)/0.34)-1)/6/int((wum-0.08*2+0.18)/0.34)*(0.36/0.16*0.09)+0.68/int((wum-0.08*2+0.18)/0.34)'
.param leng_strip = 'r_strip*0.16/0.09'
.param lph_end = '(0.36*int(6+(lum-2)*2.8)+0.4)*1.8'
.param num_sidebranch = '(-1)*(int((nf+1)/2-int(nf/2))-1)*nf/2+(int((nf+1)/2-int(nf/2)))*1'
.param lph_sidex1 = 'lph_end+(num_sidebranch-1)*(2*num_sidebranch-1)/6/num_sidebranch*lph_end+r_strip*0.16/0.09/num_sidebranch-int((nf+1)/2-int(nf/2))*lph_end/2'
.param lph_sidex2 = 'lph_sidex1/2'
.param lph_center = 'leng_strip*1.8'


.param a1_eff = '(l*scale-0.18u)*(w*scale-0.18u)*nf/scale/scale'
.param p1_eff = '((l*scale-0.18u)+(w*scale-0.18u))*2*nf/scale'
.param a2_eff = 'l*scale*w*scale*nf/scale/scale-a1_eff'
.param p2_eff = '(l+w)*scale*2*nf/scale+p1_eff'

.param ldnw_eff = '0.15u*(nf+1)+(0.15u*2+l*scale)*nf+1.32u*2'
.param wdnw_eff = 'w*scale+1.32u*2'
.param adnw_eff = 'ldnw_eff*wdnw_eff/scale/scale'
.param pdnw_eff = '(ldnw_eff+wdnw_eff)*2/scale'

.param r_s1 = '(0.502561)/nf+(0.063063)*lum+(0.315745)/wum+(0.17721)*lum/wum/nf+(-0.192448)*lum/wum+(0.922859)*lum/nf+(4.138226)/wum/nf+0.4578998'
.param r_s2 = '(0.502561)/nf+(0.063063)*lum+(0.315745)/wum+(0.17721)*lum/wum/nf+(-0.192448)*lum/wum+(0.922859)*lum/nf+(4.138226)/wum/nf+0.4578998'
.param r_1 = 'r_strip/num_strip/nf'
.param l_1 = 'leng_strip*2/num_strip/nf*1e-12'
.param r_2 = 'r_strip/(nf+1)/0.46*0.16'
.param l_2 = '(lph_sidex2*lph_center/(lph_sidex2+lph_center)*(1-int((nf+1)/2-int(nf/2)))+lph_sidex2*int((nf+1)/2-int(nf/2)))*1e-12'

.param r_nwell = '(36.572788)/nf+(-0.032945)/lum+(22.084013)/wum+(353.86901)/lum/wum/nf+(-36.420887)/lum/wum+(-56.032173)/lum/nf+(-102.884385)/wum/nf+(-0.675401)*lum+(6.426042)*lum/nf/wum+71.880211*1/sqrt(lum*wum*nf)+3.6544606'
.param r_sub = '(-18.69063)/nf+(-4.110373)/lum+(-2.898886)/wum+(-200.415451)/lum/wum/nf+(-19.420086)/lum/wum+(-61.579568)/lum/nf+(74.942507)/wum/nf+7.757009*lum+(31.716724)*lum/nf/wum+563.309377*1/sqrt(lum*wum*nf)+(-0.707531)'
.param c_sub = '((0.510625)*nf+(0.121115)*lum+(-0.43987)*wum+(0.0022525)*lum*wum*nf+(0.0131018)*lum*wum+(-0.130591)*lum*nf+(0.128858)*wum*nf+(2.555541)*sqrt(lum*wum)+(-0.16933)*sqrt(lum*wum)*nf+1.480559)*1e-15'
.param c_sti = '((-0.160573)*nf+(0.252906)*lum+(0.320262)*wum+(0.086901)*lum*wum*nf+(0.189157)*lum*wum+(-0.06223)*lum*nf+(0.153927)*wum*nf+(-2.198457)*sqrt(lum*wum)+(0.133938)*sqrt(lum*wum)*nf+2.146732)*1e-15'
.param c_pp = '((0.107974)*nf+(-0.021841)*lum+(0.064216)*wum+(0.012852)*lum*wum*nf+(0.004053)*lum*wum+(0.22495)*lum*nf+(-0.005763)*wum*nf+(-0.204881)*sqrt(lum*wum)+(-0.038639)*sqrt(lum*wum)*nf+0.24632)*1e-15'

.param is_fdiode1_wi = '((-0.039135)*lum+(-0.01639)*wum+(0.336731)/nf+(-0.022858)*lum*wum+(0.023842)*lum/nf+(0.012557)*wum/nf+(0.018385)*lum*wum/nf+(-0.213709)*sqrt(wum*lum)/nf+0.270956*sqrt(wum*lum)+(-0.014951))*factor_isf_wi*(1+(temper-25)*1.8309+(temper-25)*(temper-25)*0.028)'
.param n_fdiode1_wi = '(0.088201)/lum+(0.028120)/wum+(-0.027211)/lum/wum+(0.007037)*lum+(-0.000642)*wum+0.884969'
.param cj_fdiode1_wi = '((-0.0002415141)/lum+(-0.00023467898)/wum+(0.00011923785869)/lum/wum+(0.000024816751)*lum+(-0.00000653812)*wum+(0.001792321))*factor_cjf_wi'
.param mj_fdiode1_wi = '(0.082786)/lum+(-0.059715)/wum+(0.040969)/lum/wum+(0.030802)*lum+(0.00014552)*wum+0.65635399'

.param is_rdiode_wi = '((20.85103)*lum+(5.467119)*wum+(69.116692)/nf+(2.900199)*lum*wum+(-32.740413)*lum/nf+(-8.5295896)*wum/nf+(-0.059975)*lum*wum/nf+(24.8596698)*sqrt(wum*lum)/nf+(-49.295898)*sqrt(wum*lum)+(63.861724))*factor_isr_wi*(1+(temper-25)*1.8309+(temper-25)*(temper-25)*0.028)'
.param n_rdiode_wi = '(6.695345)/lum+(1.707535)/wum+(0.1154301)/lum/wum+(2.733127)*lum+(0.103745)*wum+(-0.357563)*lum/wum+(-0.132907)*wum/lum+132.319113'

*=====================
r1 1 4 'r_1*factor_rm*(1+(temper-25)*2.93e-3)'
l1 4 5 'l_1*factor_l'
csti 5 8 'c_sti*factor_csti'
*--- Schottky diode
df1 5 11 f_diode1_wi area = 'a1_eff' pj = 'p1_eff'
rs1 11 6 'r_s1*factor_re_wi'
dr 11 5 r_diode_wi area = 'a1_eff' pj = 'p1_eff'
*--- PN junction diode
df2 5 21 f_diode2_wi area = 'a2_eff' pj = 'p2_eff'
rs2 21 6 'r_s2*factor_re_wi'
cpp 5 3 'c_pp'
*--- Substrate network
ddnw 31 7 dio_dnwpsub area = 'adnw_eff' pj='pdnw_eff'
rsub 31 3 'r_sub*factor_rsub*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
csub 31 3 'c_sub*factor_csub*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
rnwell1 6 7 'r_nwell/2*factor_rnwell*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
rnwell2 7 8 'r_nwell/2*factor_rnwell*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'

r2 8 9 'r_2*factor_rm*(1+(temper-25)*2.93e-3)'
l2 9 2 'l_2*factor_l'

*-- Forward diode No. 1 ---
.MODEL f_diode1_wi  		 D (
+ LEVEL = 3         		 IS = 'is_fdiode1_wi'		 RS = 1E-010        		 N = 'n_fdiode1_wi' 		
+ BV = 1e4          		 IBV = 'is_fdiode1_wi'		 IK = 3E+005        		 IKR = 1E+010       		
+ JSW = 3.5E-014    		 CJ = 'cj_fdiode1_wi'		 PB = 0.8756        		 MJ = 'mj_fdiode1_wi'		
+ CJSW = 0          		 PHP = 0.8956       		 MJSW = 0.6823      		 TLEV = 1           		
+ EG = 1.17         		 XTI = 3            		 TCV = -0.000888    		 TRS = 0.00277      		
+ TLEVC = 1         		 CTA = 0.0009067    		 CTP = 0.0002781    		 TPB = 0.001427      		
+ TPHP = 0.001427   		 TREF = 25          		 FC = 0             		 FCS = 0 )

*-- Reverse diode to model leakage current ---
.MODEL r_diode_wi   		 D (
+ LEVEL = 3         		 IS = 'is_rdiode_wi'		 RS = 1E-010        		 N = 'n_rdiode_wi'  		
+ BV = 1e4            		 IBV = 'is_rdiode_wi'		 IK = 6E+004        		 IKR = 5E+005       		
+ JSW = 1.55E-013   		 CJ = 0             		 PB = 0.2006        		 MJ = 0.4528        		
+ CJSW = 0          		 PHP = 0.7956       		 MJSW = 0.2323      		 TLEV = 1           		
+ EG = 1.37         		 XTI = 3            		 TCV = -0.000888    		 TRS = 0.00277      		
+ TLEVC = 1         		 CTA = 0.0009067    		 CTP = 0.0002781    		 TPB = 0.001427     		
+ TPHP = 0.001427   		 TREF = 25          		 FC = 0             		 FCS = 0 )

*-- Forward diode No. 2, P+/NW STI Diode ---
.MODEL f_diode2_wi  		 D (
+ LEVEL = 3         		 IS = '1.82E-007*factor_is_d'    RS = '1E-010*factor_rs_d'       N = '1.00*factor_n_d'		
+ BV = 9.4         		 IBV = 0.03         		 IK = 1E+020        		 IKR = 1E+010       		
+ JSW = '2.71E-013*factor_jsw_d' CJ = '0.001077*factor_cj_d'	 PB = 1           	         MJ = 0.4        		
+ CJSW = '6.4E-11*factor_cjsw_d' PHP = 1          	         MJSW = 0.062      		 TLEV = 1           		
+ EG = 1.17         		 XTI = 3            		 TCV = -0.00085    		 TRS = 2.5E-3      		
+ TLEVC = 1         		 CTA = 1.05E-3     		 CTP = 2.0E-4    		 TPB = 0.003     		
+ TPHP = 0.002   		 TREF = 25          		 FC = 0             		 FCS = 0            		
+ AREA = 3.08E-008  		 PJ = 7.2E-004 )

*-- DNW/PSUB diode ---
.MODEL dio_dnwpsub  		 D (
+ LEVEL = 3         		 IS = 3.68E-006     		 RS = 1.0E-010        		 N = 1.02           		
+ BV = 11.92         		 IBV = 0.03         		 IK = 1E+020        		 IKR = 1E+010       		
+ JSW = 8.8E-012   		 AREA = 3.1161E-008   		 PJ = 7.24E-004       		 CJ = 0.000115     		
+ PB = 0.64       		 MJ = 0.36        		 CJSW = 1.33E-009  		 PHP = 0.77       		
+ MJSW = 0.355     		 TLEV = 1           		 EG = 1.17          		 XTI = 3            		
+ TCV = -0.00095    		 TRS = 2.5E-3      		 TLEVC = 1          		 CTA = 0.0022     		
+ CTP = 0.0012    		 TPB = 0.0035     		 TPHP = 0.0026    		 TREF = 25          		
+ FC = 0            		 FCS=0 )

.ends sbd_rf
*
*
*
*
*
*****************************************************************************
*****               Schottky Diode with only N-Well                     *****
*****************************************************************************
.subckt sbd_rf_nw 1 2 3 l=2e-006 w=4e-006 nf=1 scale=scale_sbd
.param lum = 'l*scale*1e6'
.param wum = 'w*scale*1e6'

.param num_strip = 'int(6+(lum-2)*2.8)'
.param r_strip = '(1.16*0.09/0.16)+(int((wum-0.08*2+0.18)/0.34)-1)*(2*int((wum-0.08*2+0.18)/0.34)-1)/6/int((wum-0.08*2+0.18)/0.34)*(0.36/0.16*0.09)+0.68/int((wum-0.08*2+0.18)/0.34)'
.param leng_strip = 'r_strip*0.16/0.09'
.param lph_end = '(0.36*int(6+(lum-2)*2.8)+0.4)*1.8'
.param num_sidebranch = '(-1)*(int((nf+1)/2-int(nf/2))-1)*nf/2+(int((nf+1)/2-int(nf/2)))*1'
.param lph_sidex1 = 'lph_end+(num_sidebranch-1)*(2*num_sidebranch-1)/6/num_sidebranch*lph_end+r_strip*0.16/0.09/num_sidebranch-int((nf+1)/2-int(nf/2))*lph_end/2'
.param lph_sidex2 = 'lph_sidex1/2'
.param lph_center = 'leng_strip*1.8'


.param a1_eff = '(l*scale-0.18u)*(w*scale-0.18u)*nf/scale/scale'
.param p1_eff = '((l*scale-0.18u)+(w*scale-0.18u))*2*nf/scale'
.param a2_eff = 'l*scale*w*scale*nf/scale/scale-a1_eff'
.param p2_eff = '(l+w)*scale*2*nf/scale+p1_eff'

.param lnw_eff='0.15u*(nf+1)+(0.15u*2+l*scale)*nf+0.52u*2'
.param wnw_eff='w*scale+0.52u*2'
.param anw_eff='lnw_eff*wnw_eff/scale/scale'
.param pnw_eff='(lnw_eff+wnw_eff)*2/scale'

.param r_s1 = '(0.502561)/nf+(0.063063)*lum+(0.315745)/wum+(0.17721)*lum/wum/nf+(-0.192448)*lum/wum+(0.922859)*lum/nf+(4.138226)/wum/nf+0.4578998'
.param r_s2 = '(0.502561)/nf+(0.063063)*lum+(0.315745)/wum+(0.17721)*lum/wum/nf+(-0.192448)*lum/wum+(0.922859)*lum/nf+(4.138226)/wum/nf+0.4578998'
.param r_1 = 'r_strip/num_strip/nf'
.param l_1 = 'leng_strip*2/num_strip/nf*1e-12'
.param r_2 = 'r_strip/(nf+1)/0.46*0.16'
.param l_2 = '(lph_sidex2*lph_center/(lph_sidex2+lph_center)*(1-int((nf+1)/2-int(nf/2)))+lph_sidex2*int((nf+1)/2-int(nf/2)))*1e-12'

.param r_nwell = '(18.931278)/nf+(-1.343653)/lum+(-3.513022)/wum+(-18.217372)/lum/wum/nf+(-3.660468)/lum/wum+(-36.997148)/lum/nf+(93.143816)/wum/nf+3.305505*lum+(27.547453)*lum/nf/wum+154.031451*1/sqrt(lum*wum*nf)+(-9.837494)'
.param r_sub = '(-28.295812)/nf+(2.776671)/lum+(1.671799)/wum+(-92.904497)/lum/wum/nf+(-27.274966)/lum/wum+(-25.416789)/lum/nf+(-37.204636)/wum/nf+7.982986*lum+(34.660705)*lum/nf/wum+478.158232*1/sqrt(lum*wum*nf)+(12.431468)'
.param c_sub = '((0.510625)*nf+(0.121115)*lum+(-0.43987)*wum+(0.0022525)*lum*wum*nf+(0.0131018)*lum*wum+(-0.130591)*lum*nf+(0.128858)*wum*nf+(2.555541)*sqrt(lum*wum)+(-0.16933)*sqrt(lum*wum)*nf+1.480559)*1e-15'
.param c_sti = '((-0.160573)*nf+(0.252906)*lum+(0.320262)*wum+(0.086901)*lum*wum*nf+(0.189157)*lum*wum+(-0.06223)*lum*nf+(0.153927)*wum*nf+(-2.198457)*sqrt(lum*wum)+(0.133938)*sqrt(lum*wum)*nf+2.146732)*1e-15'
.param c_pp = '((0.107974)*nf+(-0.021841)*lum+(0.064216)*wum+(0.012852)*lum*wum*nf+(0.004053)*lum*wum+(0.22495)*lum*nf+(-0.005763)*wum*nf+(-0.204881)*sqrt(lum*wum)+(-0.038639)*sqrt(lum*wum)*nf+0.24632)*1e-15'

.param is_fdiode1_wo = '((-0.039135)*lum+(-0.01639)*wum+(0.336731)/nf+(-0.022858)*lum*wum+(0.023842)*lum/nf+(0.012557)*wum/nf+(0.018385)*lum*wum/nf+(-0.213709)*sqrt(wum*lum)/nf+0.270956*sqrt(wum*lum)+(-0.014951))*factor_isf_wo*(1+(temper-25)*1.8309+(temper-25)*(temper-25)*0.028)'
.param n_fdiode1_wo = '(0.088201)/lum+(0.028120)/wum+(-0.027211)/lum/wum+(0.007037)*lum+(-0.000642)*wum+0.884969'
.param cj_fdiode1_wo = '((-0.0002415141)/lum+(-0.00023467898)/wum+(0.00011923785869)/lum/wum+(0.000024816751)*lum+(-0.00000653812)*wum+(0.001792321))*factor_cjf_wo'
.param mj_fdiode1_wo = '(0.082786)/lum+(-0.059715)/wum+(0.040969)/lum/wum+(0.030802)*lum+(0.00014552)*wum+0.65635399'

.param is_rdiode_wo = '((20.85103)*lum+(5.467119)*wum+(69.116692)/nf+(2.900199)*lum*wum+(-32.740413)*lum/nf+(-8.5295896)*wum/nf+(-0.059975)*lum*wum/nf+(24.8596698)*sqrt(wum*lum)/nf+(-49.295898)*sqrt(wum*lum)+(63.861724))*factor_isr_wo*(1+(temper-25)*1.8309+(temper-25)*(temper-25)*0.028)'
.param n_rdiode_wo = '(6.695345)/lum+(1.707535)/wum+(0.1154301)/lum/wum+(2.733127)*lum+(0.103745)*wum+(-0.357563)*lum/wum+(-0.132907)*wum/lum+132.319113'
*=====================
r1 1 4 'r_1*factor_rm*(1+(temper-25)*2.93e-3)'
l1 4 5 'l_1*factor_l'
csti 5 8 'c_sti*factor_csti'
*--- Schottky diode
df1 5 11 f_diode1_wo area = 'a1_eff' pj = 'p1_eff'
rs1 11 6 'r_s1*factor_re_wo'
dr 11 5 r_diode_wo area = 'a1_eff' pj = 'p1_eff'
*--- PN junction diode
df2 5 21 f_diode2_wo area = 'a2_eff' pj = 'p2_eff'
rs2 21 6 'r_s2*factor_re_wo'
cpp 5 3 'c_pp'
*--- Substrate network
dnw 31 7 dio_nwpsub area = 'anw_eff' pj='pnw_eff'
rsub 31 3 'r_sub*factor_rsub*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
csub 31 3 'c_sub*factor_csub*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
rnwell1 6 7 'r_nwell/2*factor_rnwell*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'
rnwell2 7 8 'r_nwell/2*factor_rnwell*(1+(temper-25)*3.74e-3+(temper-25)*(temper-25)*9.1e-6)'

r2 8 9 'r_2*factor_rm*(1+(temper-25)*2.93e-3)'
l2 9 2 'l_2*factor_l'

*-- Forward diode No. 1 ---
.MODEL f_diode1_wo  		 D (
+ LEVEL = 3         		 IS = 'is_fdiode1_wo'		 RS = 1E-010        		 N = 'n_fdiode1_wo' 		
+ BV = 1e4          		 IBV = 'is_fdiode1_wo'		 IK = 3E+005        		 IKR = 1E+010       		
+ JSW = 3.5E-014    		 CJ = 'cj_fdiode1_wo'		 PB = 0.8756        		 MJ = 'mj_fdiode1_wo'		
+ CJSW = 0          		 PHP = 0.8956       		 MJSW = 0.6823      		 TLEV = 1           		
+ EG = 1.17         		 XTI = 3            		 TCV = -0.000888    		 TRS = 0.00277      		
+ TLEVC = 1         		 CTA = 0.0009067    		 CTP = 0.0002781    		 TPB = 0.001427      		
+ TPHP = 0.001427   		 TREF = 25          		 FC = 0             		 FCS = 0 )

*-- Reverse diode to model leakage current ---
.MODEL r_diode_wo   		 D (
+ LEVEL = 3         		 IS = 'is_rdiode_wo'		 RS = 1E-010        		 N = 'n_rdiode_wo'  		
+ BV = 1e4            		 IBV = 'is_rdiode_wo'		 IK = 6E+004        		 IKR = 5E+005       		
+ JSW = 1.55E-013   		 CJ = 0             		 PB = 0.2006        		 MJ = 0.4528        		
+ CJSW = 0          		 PHP = 0.7956       		 MJSW = 0.2323      		 TLEV = 1           		
+ EG = 1.37          		 XTI = 3            		 TCV = -0.000888    		 TRS = 0.00277      		
+ TLEVC = 1         		 CTA = 0.0009067    		 CTP = 0.0002781    		 TPB = 0.001427     		
+ TPHP = 0.001427   		 TREF = 25          		 FC = 0             		 FCS = 0 )

*-- Forward diode No. 2, P+/NW STI Diode ---
.MODEL f_diode2_wo   		 D (
+ LEVEL = 3         		 IS = '1.82E-007*factor_is_d'	 RS = '1E-010*factor_rs_d' 	 N = '1.00*factor_n_d'     		
+ BV = 9.4         		 IBV = 0.03         		 IK = 1E+020        		 IKR = 1E+010       		
+ JSW = '2.71E-013*factor_jsw_d' CJ = '0.001077*factor_cj_d'	 PB = 1           	         MJ = 0.4        		
+ CJSW = '6.4E-11*factor_cjsw_d' PHP = 1          	         MJSW = 0.062      		 TLEV = 1           		
+ EG = 1.17         		 XTI = 3            		 TCV = -0.00085    		 TRS = 2.5E-3      		
+ TLEVC = 1         		 CTA = 1.05E-3     		 CTP = 2.0E-4     		 TPB = 0.003     		
+ TPHP = 0.002   		 TREF = 25          		 FC = 0             		 FCS = 0            		
+ AREA = 3.08E-008  		 PJ = 7.2E-004 )

*-- NW/PSUB diode ---
.MODEL dio_nwpsub   		 D (
+ LEVEL = 3         		 IS = 3.41E-006      		 RS = 1.0E-010        		 N = 1.02           		
+ BV = 12         		 IBV = 0.03         		 IK = 1E+020        		 IKR = 1E+010       		
+ JSW = 1.05E-012   		 CJ = 0.000137     		 PB = 0.5        		 MJ = 0.33        		
+ CJSW = 7.25E-010  	         PHP = 0.65       		 MJSW = 0.35      		 TLEV = 1           		
+ EG = 1.17         		 XTI = 3            		 TCV = -0.00095     		 TRS = 2.5E-3      		
+ TLEVC = 1         		 CTA = 0.0023     		 CTP = 1.16E-03     		 TPB = 0.0026     		
+ TPHP = 1.90E-03   		 TREF = 25          		 FC = 0             		 FCS = 0            		
+ AREA = 3.1161E-008  		 PJ = 7.24E-4 )

.ends sbd_rf_nw
*
*
*
.ENDL RF_SBD




*  **********************************************
*  *             TSMC SPICE MODEL               *
*  **********************************************
*
*    PROCESS :  0.065um MIXED-SIGNAL SALICIDE Low-K IMD (1.2V) (CMN65LP 1P9M+AL_RDL)
*    MODEL   :  BSIM4 ( V4.5 )
*    DOC. NO.:  T-N65-CM-SP-002
*    VERSION :  1.3
*    DATE    :  May 06, 2009
*    HSPICE VERSION : A-2008.03
*
******************************************************************************
*     Release Note:							     *
*									     *
*    V0.1P1 (01/20)                                                          *
*    1. V0.1 Statistical model card 		        		     *
*	Newly created							     *
*									     *	
*    V0.2P1 (03/31)							     *	
*    1. Logic model is based on V1.1. 					     *	
*    2. Updated mismatch model based on V1.0 mismatch data quality.          *
*    3. Updated statistical model as following:                              *
*     a.  Removed IO and core device correlation                             *
*     b.  Fine tuned multiple Vt correlation                                 *
* 									     *	
* 									     *	
*    V0.2 (05/15)						             *
*    1. Fixed nonlinear issues on principle components. That impacts the     *
*       corner percentage of SVT, HVT and mLVT (nothing to do with TT case). *
*       The offset of final Idsat corner is within 1%.			     *
*    2. Added passive mismatch models.					     *	
*    3. Improved LOD model accuracy for SVT PMOS.			     *
*       This impact on idsat with LOD effect is less than 0.3%.		     *	
* 									     *
*    V1.0P1 (07/05)						             *
*    1. Added passive statistical models.                                    *
*									     *
*    V1.1P1 (01/15)							     *
*    1. Newly created SVT/HVT/LVT/IO/native core/native IO MOS,BJT,RES       *
*       mismatch models based on "TSMC 65NM CMOS LOGIC LOW POWER 1P9M+AL_RDL *
*       SALICIDE Cu_Lowk 1.2V/2.5V SPICE MODELS (CLN65LP)",                  *
*       Ver1.2 (T-N65-CL-SP-009).                                            *
*    2. Added flicker noise corner and thermal noise.                        *  
*    3. Copied base band models from                                         *
*	"TSMC 65NM CMOS LOGIC LOW POWER 1P9M+AL_RDL SALICIDE Cu_LowK	     *
*	1.2V/2.5V SPICE MODELS (CLN65LP)", Ver1.2 (T-N65-CL-SP-009).	     *
*    4. Statistical model is not included                                    * 
* 									     *
*    V1.1 (04/15)							     *
*    1. Added SVT/HVT/mLVT/LVT/native/IO ans passive devices statistical     *
*       models								     *	
*                                                                            *
*    V1.2P1 (01/09)                                                          * 
*    1.Updated multi-finger mismatch macro model equation.		     * 
*    2.Add inter metal resistor My in resistor model.                        *
*    3.Modified the RPO_Resistor VCR and TCR model equations.                * 
*                                                                            *
*    V1.2P2 (01/31/2008)                                                     * 
*    1.Added 3T resistor statistial model.                                   *
*    2.Added/updated mismatch and thermal noise parameters in the            *
*      RPO_Resistor models.						     *
*                                                                            *
*    V1.2P3 (10/17/2008)                                                     * 
*    1. Added native IO 2.5V over-drive 3.3V NMOS device model.		     *
*    2. Added NDIO_na25od33 model copied from NDIO_na25.                     *
*    3. Correct Dwend in Rend equation of RPO-resistor models.		     *
*    4. Minor change A2_disres_sal in the lib of mc_disres.                  *
*    5. Updated par_res=AGAUSS(0,1,1) as par_res=0 dev/gauss='1/1' and       *
*       par_res_m=AGAUSS(0,1,1) as par_res_m=0 dev/gauss='1/1' for 2T and 3T *
*       resistor model in eldo model card.                                   *
*    6. 1/f noise corner MC model of mos.                                    *
*    7. Revise the mismatch parameters for all devices to improve the Id     *
*       mismatch fitting in sub-vt region.                                   *
*    8. Modified HVT NMOS flicker noise model from new data.                 *
*    9. scale1 instead of scale for mos mismatch model in the eldo model *
*        card .                                                              *
*    10. Added 'mf' into metal resistor model.                               *
*    11. Added 2T and 3T UTM direct contact MIMCAP.                          *
*    12. Updated RTMOM corner from +/-20% to +/-15% and Ca1b1/Cpa1/Cpb1      *
*        equations.                                                          *
*                                                                            *
*    V1.2 (11/12/2008)                                                       * 
*    1. Added metal resistor Rmap, Rmr, and Rmap_ut in resistor model.	     *
*    2. Modified par_res=0 dev/gauss='1/1' as AGAUSS(0,1,1) for 2T           *
*       resistor model and par_res_m=0 dev/gauss='1/1' as AGAUSS(0,1,1)      *
*       for 3T resistor model in eldo model card.                            *
*    3. Added stat_mis_mim, stat_mis_rtmom, stat_mis_mvar, and               *
*       stat_mis_mvar_25 in spectre model card.                              *
*    4. Corrected Cjsw for ndio_mlvt and pdio_mlvt.                          *
*    5. Updated BVS and BVD for nch/pch/nch_mlvt/pch_mlvt/pch_lvt/nch_na to  *
*       align the diode's BV.                                                *
*    6. Updated CTA of ndio_lvt.                                             *
*    7. Updated Cje for NPN10.                                               *
*                                                                            *
*    V1.3 (2009/05/06)						             *
*    1. Add 10x10, 5x5, 2x2 NPN & PNP small BJT model.		             *
*    2. Add 2.5V HVMOS devices models.                                       *
*    3. Updated RTMOM models.                                                *
******************************************************************************
*                                                                            *
*       THIS MODEL LIB CONTAINS :                                            *
*                                                                            *
*       1.LIB stat                                                           *
*   ( Common statistical library )                                           *
*                                                                            *
*       2.LIB stat_bip_dio                                                   *
*   ( Common BJT and diode statistical library )                             *
*                                                                            *
*       3.LIB stat_res                                                       *
*   ( Common resistor statistical library )                                  *
*                                                                            *
*       4.LIB MC                                                             *
*   ( 1.2V Standard-Vt statistical models with different device geometries)  *
*                                                                            *
*       5.LIB MC_hvt                                                         *
*   ( 1.2V High-Vt statistical models with different device geometries)      *
*                                                                            *
*       6.LIB MC_mlvt                                                        *
*   ( 1.2V mLow-Vt statistical models with different device geometries)      *
*                                                                            *
*       7.LIB MC_lvt                                                         *
*   ( 1.2V Low-Vt statistical models with different device geometries)       *
*                                                                            *
*       8.LIB MC_18                                                          *
*   ( 1.8V under-drive I/O statistical models with different device          *
*     geometries)                                                            *
*                                                                            *
*       9.LIB MC_25                                                          *
*   ( 2.5V I/O statistical models with different device geometries)          *
*                                                                            *
*       10.LIB MC_33                                                         *
*   ( 3.3V over-drive I/O statistical models with different device           *
*     geometries)                                                            *
*                                                                            *
*       11.LIB MC_na                                                         *
*   ( 1.2V Native statistical models with different device geometries)       *
*                                                                            *
*       12.LIB MC_na25                                                       *
*   ( 2.5V Native I/O statistical models with different device geometries)   *
*                                                                            *
*       13.LIB mc_hv25_snw_spw                                               *
*   ( 2.5V HVMOS statistical models for standard NW_HVNMOS and PW_HVPMOS     *
*     with different device geometries)                                      *
*                                                                            *
*                                                                            *
*      14.LIB TT                                                             *
*             SS                                                             *
*             FF                                                             *
*             SF                                                             *
*             FS                                                             *
*   ( 1.2V Standard-Vt devices with different geometric and corner models)   *
*									     *
*      15.LIB TT_hvt                                                         *
*             SS_hvt                                                         *
*             FF_hvt                                                         *
*             SF_hvt                                                         *
*             FS_hvt                                                         *
*   ( 1.2V High-Vt devices with different geometric and corner models)       *			
*									     *
*      16.LIB TT_mlvt                                                        *
*             SS_mlvt                                                        *
*             FF_mlvt                                                        *
*             SF_mlvt                                                        *
*             FS_mlvt                                                        *
*   ( 1.2V mLow-Vt devices with different geometric and corner models)       *
*                                                                            *                                                                       *
*      17.LIB TT_lvt                                                         *
*             SS_lvt                                                         *
*             FF_lvt                                                         *
*             SF_lvt                                                         *
*             FS_lvt                                                         *
*   ( 1.2V Low-Vt devices with different geometric and corner models)        *
*                                                                            *                                                                       *
*      18.LIB TT_18                                                          *
*             SS_18                                                          *
*             FF_18                                                          *
*             SF_18                                                          *
*             FS_18                                                          *
* ( 1.8V under-drive devices with different geometric and corner models)*
*									     *
*      19.LIB TT_25                                                          *
*             SS_25                                                          *
*             FF_25                                                          *
*             SF_25                                                          *
*             FS_25                                                          *
*   ( 2.5V devices with different geometric and corner models)               *
*									     *
*      20.LIB TT_33                                                          *
*             SS_33                                                          *
*             FF_33                                                          *
*             SF_33                                                          *
*             FS_33                                                          *
*									     *
*   ( 3.3V over-drive devices with different geometric and corner models)    *
*									     *
*      21.LIB TT_na                                                          *
*             SS_na                                                          *
*             FF_na                                                          *
*             SF_na                                                          *
*             FS_na                                                          *
*   ( 1.2V native devices with different geometric and corner models)        *
*                                                                            *
*      22.LIB TT_na25                                                        *
*             SS_na25                                                        *
*             FF_na25                                                        *
*             SF_na25                                                        *
*             FS_na25                                                        *
*   ( 2.5V native devices with different geometric and corner models)        *
*                                                                            *
*      23.LIB TT_na25od33                                                    *
*             SS_na25od33                                                    *
*             FF_na25od33                                                    *
*             SF_na25od33                                                    *
*             FS_na25od33                                                    *
*   ( 2.5V over-drive 3.3V native devices with different geometric and       *
*    corner models)                                                          *
*                                                                            *
*      24.LIB TT_hv25_snw_spw                                                *
*             SS_hv25_snw_spw                                                *
*             FF_hv25_snw_spw                                                *
*             SF_hv25_snw_spw                                                *
*             FS_hv25_snw_spw                                                *
*   ( 2.5V HVMOS devices for standard NW_HVNMOS and PW_HVPMOS with different *
*     geometry and corner models)                                            *
*									     *
*       25.LIB mc_bip                                                        *
*   ( 1.2V P+/NW/PSUB 10x10, 5x5, and 2x2 vertical PNP bipolar statistical   *
*     model)                                                                 *
*                                                                            *
*       26.LIB TT_BIP                                                        *
*              SS_BIP                                                        *
*              FF_BIP                                                        *
*   ( 1.2V P+/NW/PSUB 10x10, 5x5, and 2x2 vertical PNP bipolar )             *
*		                                                             *
*       27.LIB mc_bip_npn                                                    *
*   ( 1.2V N+/PW/PSUB 10x10, 5x5, and 2x2 vertical NPN bipolar statistical   *
*     model)                                                                 *
*		                                                             *
*       28.LIB TT_BIP_NPN                                                    *
*              SS_BIP_NPN                                                    *
*              FF_BIP_NPN                                                    *
*		                                                             *
*   ( 1.2V N+/PW/PSUB 10x10, 5x5, and 2x2 vertical NPN bipolar )             *
*                                                                            *
*       29.LIB MC_BIP_S                                                      *
*   ( 1.2V P+/NW/PSUB 10x10, 5x5, and 2x2 vertical PNP small bipolar         *
*     statistical model)                                                     *
*                                                                            *
*       30.LIB TT_BIP_S                                                      *
*              SS_BIP_S                                                      *
*              FF_BIP_S                                                      *
*   ( 1.2V P+/NW/PSUB 10x10, 5x5, and 2x2 vertical PNP small bipolar )       *
*		                                                             *
*       31.LIB MC_BIP_NPN_S                                                  *
*   ( 1.2V N+/PW/PSUB 10x10, 5x5, and 2x2 vertical NPN small bipolar         *
*     statistical model)                                                     *
*		                                                             *
*       32.LIB TT_BIP_NPN_S                                                  *
*              SS_BIP_NPN_S                                                  *
*              FF_BIP_NPN_S                                                  *
*   ( 1.2V N+/PW/PSUB 10x10, 5x5, and 2x2 vertical NPN small bipolar )       *
*                                                                            *
*       33.LIB mc_dio                                                        *
*   ( 1.2V Standard-Vt P+/NW, N+/PW, and NW/PSUB diode statistical model)    *
*                                                                            *
*       34.LIB TT_DIO                                                        *
*              SS_DIO                                                        *
*              FF_DIO                                                        *
*   ( 1.2V Standard-Vt P+/NW, N+/PW, and NW/PSUB diode )                     *
*                                                                            *
*       35.LIB mc_dio_hvt                                                    *
*   ( 1.2V High-Vt P+/NW, and N+/PW diode statistical model)                 *
*                                                                            *
*       36.LIB TT_DIO_hvt                                                    *
*              SS_DIO_hvt                                                    *
*              FF_DIO_hvt                                                    *
*   ( 1.2V High-Vt P+/NW, and N+/PW diode )                                  *                                                                           *
*                                                                            *
*       37.LIB mc_dio_mlvt                                                   *
*   ( 1.2V mLow-Vt P+/NW, and N+/PW diode statistical model)                 *
*                                                                            *
*       38.LIB TT_DIO_mlvt                                                   *
*              SS_DIO_mlvt                                                   *
*              FF_DIO_mlvt                                                   *
*   ( 1.2V mLow-Vt P+/NW, and N+/PW diode )                                  *
*                                                                            *
*       39.LIB mc_dio_lvt                                                    *
*   ( 1.2V Low-Vt P+/NW, and N+/PW diode statistical model)                  *
*                                                                            *
*       40.LIB TT_DIO_lvt                                                    *
*              SS_DIO_lvt                                                    *
*              FF_DIO_lvt                                                    *
*   ( 1.2V Low-Vt P+/NW, and N+/PW diode )                                   *
*                                                                            *
*       41.LIB mc_dio_18                                                     *
*   ( 2.5V under-drive P+/NW, and N+/PW diode statistical model)             *
*                                                                            *
*       42.LIB TT_DIO_18                                                     *
*              SS_DIO_18                                                     *
*              FF_DIO_18                                                     *
*   ( 2.5V under-drive P+/NW, and N+/PW diode )                              *
*                                                                            *
*       43.LIB mc_dio_25                                                     *
*   ( 2.5V P+/NW, and N+/PW diode statistical model)                         *
*                                                                            *
*       44.LIB TT_DIO_25                                                     *
*              SS_DIO_25                                                     *
*              FF_DIO_25                                                     *
*   ( 2.5V P+/NW, and N+/PW diode )                                          *
*                                                                            *
*       45.LIB mc_dio_33                                                     *
*   ( 2.5V over-drive P+/NW, and N+/PW diode statistical model)              *
*                                                                            *
*       46.LIB TT_DIO_33                                                     *
*              SS_DIO_33                                                     *
*              FF_DIO_33                                                     *
*   ( 2.5V over-drive P+/NW, and N+/PW diode )                               *
*                                                                            *
*       47.LIB mc_dio_NA                                                     *
*   ( 1.2V native N+/PW diode statistical model)                             *
*                                                                            *
*       48.LIB TT_DIO_na                                                     *
*              SS_DIO_na                                                     *
*              FF_DIO_na                                                     *
*    ( 1.2V native N+/PW diode )                                             *
*                                                                            *
*       49.LIB mc_dio_NA25                                                   *
*   ( 2.5V native N+/PW diode statistical model)                             *
*                                                                            *
*       50.LIB TT_DIO_na25                                                   *
*              SS_DIO_na25                                                   *
*              FF_DIO_na25                                                   *
*    ( 2.5V native N+/PW diode )                                             *
*                                                                            *
*       51.LIB TT_DIO_na25od33                                               *
*              SS_DIO_na25od33                                               *
*              FF_DIO_na25od33                                               *
*    ( 2.5V over-drive 3.3V native P+/NW, and N+/PW diode )                  *
*                                                                            *
*       52.LIB mc_dio_DNW                                                    *
*   ( PW/DNW and DNW/PSUB diode statistical model)                           *
*                                                                            *
*       53.LIB TT_DIO_DNW                                                    *
*              SS_DIO_DNW                                                    *
*              FF_DIO_DNW                                                    *
*    (  PW/DNW and DNW/PSUB diode  )                                         *
*                                                                            *
*       54.LIB mc_dio_ESD                                                    *
*   ( ESD diode statistical model)                                           *
*                                                                            *
*       55.LIB TT_DIO_ESD                                                    *
*              SS_DIO_ESD                                                    *
*              FF_DIO_ESD                                                    *
*    (  ESD diode  )                                                         *
*                                                                            *
*       56.LIB mc_mos_cap                                                    *
*   ( core varactor statistical model)                                       *
*                                                                            *
*       57.LIB TT_MOS_CAP                                                    *
*              SS_MOS_CAP                                                    *
*              FF_MOS_CAP                                                    *
*    ( 1.2V Standard-Vt NMOS in N-Well varactor )                            *
*                                                                            *
*       58.LIB mc_mos_cap_25                                                 *
*   ( IO varactor statistical model)                                         *
*                                                                            *
*       59.LIB TT_MOS_CAP_25                                                 *
*              SS_MOS_CAP_25                                                 *
*              FF_MOS_CAP_25                                                 *
*    ( 2.5V IO NMOS in N-Well varactor )                                     *
*                                                                            *
*       60.LIB mc_res                                                        *
*   ( Front-end resistors statistical model)                                 *
*                                                                            *
*       61.LIB TT_RES							     *
*              SS_RES							     *
*              FF_RES							     *
*    ( Front-end and metal resistance corner and mismatch model)             *
*                                                                            *
*       62.LIB mc_disres                                                     *
*   ( Front-end 3T resistors statistical model)                              *
*                                                                            *
*       63.LIB TT_DISRES						     *
*              SS_DISRES						     *
*              FF_DISRES						     *
*    ( Front-end 3T resistance corner and mismatch model)                    *
*                                                                            *
*       64.LIB TT_MIM                                                        *
*              SS_MIM                                                        *
*              FF_MIM                                                        *
*              MC_MIM                                                        *
*        ( MIM capactiance corner, mismatch and statistical model)           *
*                                                                            *
*       65.LIB TT_RTMOM                                                      *
*              SS_RTMOM                                                      *
*              FF_RTMOM                                                      *
*              MC_RTMOM                                                      *
*        ( RTMOM capactiance corner, mismatch and statistical model)         * 
*                                                                            *
************************    Pre-layout simulation    *************************
*
* NOTE:
*  1. All parasitics capacitances are removed from intrinsic model. The model only
*     covers the intrinsic MOSFET. All parasitic components will be handled by LPE.
*
*  2. Best approximation for gate resistance extraction is 1/3 of Rg, DC gate resistance.
*     Current LPE tools extract gate resistors from gate edge to center of gate.
*     Error of 1/2 Rg methodology is less than 5% when W/L < 30.  It is recommended to
*     split wide gate transistor to meet W/L < 30 for high precision designs.For pre-layout 
*     simulation, Rg effect can be simulated by setting rgflag=1.
*
*  3. The WPE (well proximity effect) is modeled in Bsim4.5. A new LPE deck is needed.
*
***********************************************************************************
*



***************************     LIBRARY OF STATISTICAL CASE     ***************************





***************************     COMMON STATISTICAL LIBRARY      ***************************




.LIB stat
.param
+random1=AGAUSS(0,1,3) random2=AGAUSS(0,1,3) random3=AGAUSS(0,1,3) random4=AGAUSS(0,1,3)  random5=AGAUSS(0,1,3)
+par1=random1 par2=random2 par3=random3 par4=random4  par5=random5
+random6=AGAUSS(0,1,3) random7=AGAUSS(0,1,3) random8=AGAUSS(0,1,3) random9=AGAUSS(0,1,3)  random10=AGAUSS(0,1,3)
+par6=random6 par7=random7 par8=random8 par9=random9  par10=random10
+parl1 =AGAUSS(0,1,3) parl2 =AGAUSS(0,1,3) parl3 =AGAUSS(0,1,3) parl4 =AGAUSS(0,1,3) parl5 =AGAUSS(0,1,3)

.ENDL stat







***************************     COMMON STATISTICAL LIBRARY      ***************************
.LIB stat_bip_dio
.param
+random1_bip_dio=AGAUSS(0,1,3)
+par1_bip_dio=random1_bip_dio 
.ENDL stat_bip_dio







.LIB stat_res
.param
+random1_res=AGAUSS(0,1,3) random2_res=AGAUSS(0,1,3) random3_res=AGAUSS(0,1,3) random4_res=AGAUSS(0,1,3)
+par1_res=random1_res par2_res=random2_res par3_res=random3_res par4_res=random4_res
.ENDL stat_res


.lib stat_mim
.param
+par1_mim=AGAUSS(0,1,3) 
.endl stat_mim







.lib stat_mom
.param
+random1_mom=AGAUSS(0,1,1)   
+par1_mom=random1_mom 
.endl stat_mom



.LIB noiseflag
.param noiseflagn=0
.param noiseflagp=0
.param noiseflagn_mc=0
.param noiseflagp_mc=0
.param noiseflagn_mc_mis=0
.param noiseflagp_mc_mis=0
.param sigma_factor_flicker=1
.param par2fn_mc=AGAUSS(0,1,3)
.param par2fp_mc=AGAUSS(0,1,3)
.ENDL noiseflag

.LIB noiseflag_hvt
.param noiseflagn_hvt=0
.param noiseflagp_hvt=0
.param noiseflagn_hvt_mc=0
.param noiseflagp_hvt_mc=0
.param noiseflagn_hvt_mc_mis=0
.param noiseflagp_hvt_mc_mis=0
.param sigma_factor_flicker_hvt=1
.param par2fn_hvt_mc=AGAUSS(0,1,3)
.param par2fp_hvt_mc=AGAUSS(0,1,3)
.ENDL noiseflag_hvt

.LIB noiseflag_lvt
.param noiseflagn_lvt=0
.param noiseflagp_lvt=0
.param noiseflagn_lvt_mc=0
.param noiseflagp_lvt_mc=0
.param noiseflagn_lvt_mc_mis=0
.param noiseflagp_lvt_mc_mis=0
.param sigma_factor_flicker_lvt=1
.param par2fn_lvt_mc=AGAUSS(0,1,3)
.param par2fp_lvt_mc=AGAUSS(0,1,3)
.ENDL noiseflag_lvt

.LIB noiseflag_mlvt
.param noiseflagn_mlvt=0
.param noiseflagp_mlvt=0
.param noiseflagn_mlvt_mc=0
.param noiseflagp_mlvt_mc=0
.param noiseflagn_mlvt_mc_mis=0
.param noiseflagp_mlvt_mc_mis=0
.param sigma_factor_flicker_mlvt=1
.param par2fn_mlvt_mc=AGAUSS(0,1,3)
.param par2fp_mlvt_mc=AGAUSS(0,1,3)
.ENDL noiseflag_mlvt

.LIB noiseflag_18
.param noiseflagn_18=0
.param noiseflagp_18=0
.param noiseflagn_18_mc=0
.param noiseflagp_18_mc=0
.param noiseflagn_18_mc_mis=0
.param noiseflagp_18_mc_mis=0
.param sigma_factor_flicker_18=1
.param par2fn_18_mc=AGAUSS(0,1,3)
.param par2fp_18_mc=AGAUSS(0,1,3)
.ENDL noiseflag_18

.LIB noiseflag_25
.param noiseflagn_25=0
.param noiseflagp_25=0
.param noiseflagn_25_mc=0
.param noiseflagp_25_mc=0
.param noiseflagn_25_mc_mis=0
.param noiseflagp_25_mc_mis=0
.param sigma_factor_flicker_25=1
.param par2fn_25_mc=AGAUSS(0,1,3)
.param par2fp_25_mc=AGAUSS(0,1,3)
.ENDL noiseflag_25

.LIB noiseflag_33
.param noiseflagn_33=0
.param noiseflagp_33=0
.param noiseflagn_33_mc=0
.param noiseflagp_33_mc=0
.param noiseflagn_33_mc_mis=0
.param noiseflagp_33_mc_mis=0
.param sigma_factor_flicker_33=1
.param par2fn_33_mc=AGAUSS(0,1,3)
.param par2fp_33_mc=AGAUSS(0,1,3)
.ENDL noiseflag_33

.LIB noiseflag_na
.param noiseflagn_na=0
.param noiseflagn_na_mc=0
.param noiseflagn_na_mc_mis=0
.param sigma_factor_flicker_na=1
.param par2fn_na_mc=AGAUSS(0,1,3)
.ENDL noiseflag_na

.LIB noiseflag_na25
.param noiseflagn_na25=0
.param noiseflagn_na25_mc=0
.param noiseflagn_na25_mc_mis=0
.param sigma_factor_flicker_na25=1
.param par2fn_na25_mc=AGAUSS(0,1,3)
.ENDL noiseflag_na25

.LIB noiseflag_na25od33
.param noiseflagn_na25od33=0
.param noiseflagn_na25od33_mc=0
.param noiseflagn_na25od33_mc_mis=0
.param sigma_factor_flicker_na25od33=1
.param par2fn_na25od33_mc=AGAUSS(0,1,3)
.ENDL noiseflag_na25od33


.LIB noiseflag_res
.param rnoiseflag_res=0    
.ENDL noiseflag_res








.LIB noiseflag_disres
.param rnoiseflag_disres=0    
.ENDL noiseflag_disres







.LIB post_simu
.param ccoflag=0
.param rgflag=0
.ENDL post_simu








.LIB post_simu_hvt
.param ccoflag_hvt=0
.param rgflag_hvt=0
.ENDL post_simu_hvt








.LIB post_simu_mlvt
.param ccoflag_mlvt=0
.param rgflag_mlvt=0
.ENDL post_simu_mlvt







.LIB post_simu_lvt
.param ccoflag_lvt=0
.param rgflag_lvt=0
.ENDL post_simu_lvt








.LIB post_simu_18
.param ccoflag_18=0
.param rgflag_18=0
.ENDL post_simu_18








.LIB post_simu_25
.param ccoflag_25=0
.param rgflag_25=0
.ENDL post_simu_25








.LIB post_simu_33
.param ccoflag_33=0
.param rgflag_33=0
.ENDL post_simu_33








.LIB post_simu_na
.param ccoflag_na=0
.param rgflag_na=0
.ENDL post_simu_na








.LIB POST_SIMU_na25
.param ccoflag_na25=0
.param rgflag_na25=0
.ENDL POST_SIMU_na25


.LIB POST_SIMU_na25od33
.param ccoflag_na25od33=0
.param rgflag_na25od33=0
.ENDL POST_SIMU_na25od33


.LIB post_simu_hv25_snw_spw
.param ccoflag_hv25_snw_spw=0
.param rgflag_hv25_snw_spw=0
.param sigma_factor_hv25_snw_spw=1
.ENDL post_simu_hv25_snw_spw


***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+A1='par1*5.7353*3/2.1'
+A2='par2*4.3947*3/2.1'
+A3='par3*3.8969*3/2.1'
+A4='par4*2.1385*3/2.1'
+A5='par5*1.017*3/2.1'
+toxn           ='2.6e-09+(4.0971e-012)*A1+(-3.6618e-012)*A2+(-1.1634e-011)*A3+(-5.2349e-012)*A4+(9.0461e-013)*A5'
+dxln           ='0+(2.2463e-010)*A1+(-3.3035e-010)*A2+(-1.202e-009)*A3+(-5.4657e-010)*A4+(1.0098e-010)*A5'
+dxwn           ='0+(-2.1836e-010)*A1+(1.5263e-009)*A2+(1.6182e-009)*A3+(9.7014e-010)*A4+(-1.894e-010)*A5'
+dvthn          ='0+(0.0022015)*A1+(-0.0027641)*A2+(0.0013134)*A3+(0.00013438)*A4+(-8.7415e-005)*A5'
+dlvthn         ='0+(1.4358e-010)*A1+(-1.8027e-010)*A2+(8.5658e-011)*A3+(8.7637e-012)*A4+(-5.701e-012)*A5'
+dwvthn         ='0+(2.7348e-010)*A1+(-3.5411e-010)*A2+(1.8146e-010)*A3+(-1.3311e-011)*A4+(-1.1259e-011)*A5'
+dpvthn         ='0+(2.6778e-017)*A1+(-3.1326e-017)*A2+(2.0129e-017)*A3+(-7.9316e-018)*A4+(-1.3078e-018)*A5'
+cjn            ='0.001251+(8.3819e-006)*A1+(-1.0525e-005)*A2+(5.0002e-006)*A3+(5.1126e-007)*A4+(-3.3274e-007)*A5'
+cjswn          ='7.9e-11+(5.2652e-013)*A1+(-6.6363e-013)*A2+(3.17e-013)*A3+(3.2782e-014)*A4+(-2.1021e-014)*A5'
+cjswgn         ='2.04e-10+(1.3669e-012)*A1+(-1.7161e-012)*A2+(8.1547e-013)*A3+(8.343e-014)*A4+(-5.4274e-014)*A5'
+cgon           ='8.28670e-11+(-3.5472e-013)*A1+(3.1703e-013)*A2+(1.0072e-012)*A3+(4.5323e-013)*A4+(-7.8319e-014)*A5'
+cgln           ='9.96116e-12+(-4.266e-014)*A1+(3.812e-014)*A2+(1.2109e-013)*A3+(5.4425e-014)*A4+(-9.4143e-015)*A5'
+cfn            ='1.200000e-010+(-5.1367e-013)*A1+(4.5909e-013)*A2+(1.4586e-012)*A3+(6.5632e-013)*A4+(-1.1341e-013)*A5+5.4e-11*ccoflag'
+ntoxn          ='1+(-0.043827)*A1+(0.035889)*A2+(0.10819)*A3+(0.028624)*A4+(-0.0078852)*A5'
+du0n           ='0+(2.8716e-005)*A1+(-3.6053e-005)*A2+(1.7132e-005)*A3+(1.7527e-006)*A4+(-1.1402e-006)*A5'
+dlu0n          ='0+(2.2787e-012)*A1+(-1.0714e-012)*A2+(-1.6898e-012)*A3+(5.1397e-012)*A4+(-2.3755e-014)*A5'
+dwu0n          ='0+(7.2475e-012)*A1+(-1.0173e-011)*A2+(6.1534e-012)*A3+(-2.558e-012)*A4+(-3.2781e-013)*A5'
+dpu0n          ='0+(-9.5719e-019)*A1+(1.2018e-018)*A2+(-5.7106e-019)*A3+(-5.8424e-020)*A4+(3.8007e-020)*A5'
+dleta0n        ='0+(-3.7373e-011)*A1+(3.2607e-011)*A2+(2.0973e-012)*A3+(-4.2286e-011)*A4+(9.5018e-013)*A5'
+dweta0n        ='max(-10.0e-9,0+(-4.7409e-010)*A1+(8.9946e-010)*A2+(-8.0122e-010)*A3+(8.2116e-010)*A4+(3.0168e-011)*A5)'
+dpeta0n        ='0+(1.294e-017)*A1+(-3.8281e-017)*A2+(4.204e-017)*A3+(-5.4391e-017)*A4+(-1.2033e-018)*A5'
+dvsatn         ='max(-26000,0+(352.63)*A1+(2494.3)*A2+(-762.23)*A3+(239.08)*A4+(-69.558)*A5)'
+dlvsatn        ='0+(1.6967e-005)*A1+(-0.00018169)*A2+(6.5693e-005)*A3+(-1.5713e-005)*A4+(2.2596e-006)*A5'
+dpvsatn        ='0+(2.6099e-012)*A1+(-9.2175e-013)*A2+(2.8583e-013)*A3+(1.3074e-012)*A4+(-1.2806e-013)*A5'
+dk2n           ='0+(0.00042845)*A1+(-0.00050214)*A2+(0.00019463)*A3+(0.00012616)*A4+(-1.5678e-005)*A5'
+dlcitn         ='0+(-1.267e-012)*A1+(-3.5649e-013)*A2+(-2.9996e-012)*A3+(-2.5869e-012)*A4+(3.3949e-013)*A5'
+dwcitn         ='0+(-2.7345e-012)*A1+(1.2857e-012)*A2+(2.0278e-012)*A3+(-6.1676e-012)*A4+(2.8506e-014)*A5'
+dlvoffn        ='0+(-4.7859e-011)*A1+(6.0089e-011)*A2+(-2.8553e-011)*A3+(-2.9212e-012)*A4+(1.9003e-012)*A5'
+dpvoffn        ='0+(1.285e-018)*A1+(2.0405e-020)*A2+(1.2082e-018)*A3+(-1.7478e-018)*A4+(-1.2216e-019)*A5'
+dlnfactorn     ='max(-6e-9,0+(-6.2903e-010)*A1+(8.9714e-010)*A2+(-5.5823e-010)*A3+(2.6164e-010)*A4+(2.898e-011)*A5)'
+dpnfactorn     ='0+(7.0527e-017)*A1+(4.9885e-016)*A2+(-1.5245e-016)*A3+(4.7816e-017)*A4+(-1.3912e-017)*A5'
+dla0n          ='0+(9.5719e-009)*A1+(-1.2018e-008)*A2+(5.7106e-009)*A3+(5.8424e-010)*A4+(-3.8007e-010)*A5'
+ss_flag        ='max(-0.10,0+(0.045574)*A1+(-0.021428)*A2+(-0.033796)*A3+(0.10279)*A4+(-0.0004751)*A5)'
+ff_flag        ='0+(-0.048025)*A1+(0.010395)*A2+(0.0063398)*A3+(0.11857)*A4+(-0.00058697)*A5'
+sf_flag        ='0+(-0.0086543)*A1+(-0.060646)*A2+(0.023442)*A3+(-0.051073)*A4+(-0.21784)*A5'
+fs_flag        ='0+(0.0089773)*A1+(0.064067)*A2+(-0.014669)*A3+(-0.039119)*A4+(-0.22132)*A5'
+toxp           ='2.8e-09+(4.0971e-012)*A1+(-3.6618e-012)*A2+(-1.1634e-011)*A3+(-5.2349e-012)*A4+(9.0461e-013)*A5'
+dxlp           ='0+(2.2463e-010)*A1+(-3.3035e-010)*A2+(-1.202e-009)*A3+(-5.4657e-010)*A4+(1.0098e-010)*A5'
+dxwp           ='0+(-5.0047e-010)*A1+(-4.6914e-010)*A2+(2.228e-009)*A3+(7.7887e-010)*A4+(-1.3375e-010)*A5'
+dvthp          ='0+(-0.0029743)*A1+(-0.0019047)*A2+(9.2954e-005)*A3+(-0.00059925)*A4+(0.00022477)*A5'
+dlvthp         ='0+(-4.3016e-011)*A1+(-7.3011e-012)*A2+(1.4293e-011)*A3+(-4.6111e-011)*A4+(2.0631e-012)*A5'
+dwvthp         ='0+(-4.5014e-010)*A1+(-3.3888e-010)*A2+(-1.8304e-011)*A3+(2.9186e-012)*A4+(3.6986e-011)*A5'
+dpvthp         ='0+(-2.3675e-017)*A1+(-1.3642e-017)*A2+(1.711e-018)*A3+(-7.5782e-018)*A4+(1.7e-018)*A5'
+cjp            ='0.001077+(9.3432e-006)*A1+(5.983e-006)*A2+(-2.9125e-007)*A3+(1.8827e-006)*A4+(-7.0611e-007)*A5'
+cjswp          ='6.4e-11+(5.5708e-013)*A1+(3.5491e-013)*A2+(-1.8154e-014)*A3+(1.1154e-013)*A4+(-4.1954e-014)*A5'
+cjswgp         ='2.2e-10+(1.9085e-012)*A1+(1.2222e-012)*A2+(-5.9645e-014)*A3+(3.8452e-013)*A4+(-1.4423e-013)*A5'
+cgop           ='7.70111e-11+(-3.2965e-013)*A1+(2.9463e-013)*A2+(9.3606e-013)*A3+(4.212e-013)*A4+(-7.2784e-014)*A5'
+cglp           ='2.69027e-11+(-1.1516e-013)*A1+(1.0293e-013)*A2+(3.27e-013)*A3+(1.4715e-013)*A4+(-2.5426e-014)*A5'
+cfp            ='1.200000e-010+(-5.1367e-013)*A1+(4.5909e-013)*A2+(1.4586e-012)*A3+(6.5632e-013)*A4+(-1.1341e-013)*A5+5.6e-11*ccoflag'
+drdswp         ='0+(-2.4786)*A1+(-1.5872)*A2+(0.077461)*A3+(-0.49937)*A4+(0.18731)*A5'
+ntoxp          ='1+(-0.13098)*A1+(0.094482)*A2+(0.26006)*A3+(-0.021039)*A4+(-0.016591)*A5'
+du0p           ='0+(4.9572e-005)*A1+(3.1745e-005)*A2+(-1.5492e-006)*A3+(9.9875e-006)*A4+(-3.7461e-006)*A5'
+dlu0p          ='0+(-3.8116e-012)*A1+(-5.4352e-012)*A2+(1.1107e-012)*A3+(-9.8974e-013)*A4+(3.4468e-013)*A5'
+dwu0p          ='0+(-7.8355e-013)*A1+(-1.0079e-012)*A2+(-2.9923e-013)*A3+(7.7825e-013)*A4+(8.8902e-014)*A5'
+dpu0p          ='0+(1.2393e-018)*A1+(7.9362e-019)*A2+(-3.8731e-020)*A3+(2.4969e-019)*A4+(-9.3653e-020)*A5'
+dleta0p        ='0+(-1.3105e-010)*A1+(-4.849e-011)*A2+(2.6756e-011)*A3+(-9.193e-011)*A4+(7.8248e-012)*A5'
+dpeta0p        ='0+(-3.0063e-018)*A1+(-5.4681e-018)*A2+(-2.1721e-018)*A3+(5.9471e-018)*A4+(4.3501e-019)*A5'
+dlvsatp        ='0+(0.0002106)*A1+(8.6782e-005*0.30)*A2+(-3.7335e-005)*A3+(0.00013136)*A4+(-1.3095e-005)*A5'
+dwvsatp        ='max(-0.0031,0+(-0.00014887)*A1+(-0.0001915)*A2+(-5.6853e-005)*A3+(0.00014787)*A4+(1.6891e-005)*A5)'
+dpvsatp        ='0+(7.8355e-014)*A1+(1.0079e-013)*A2+(2.9923e-014)*A3+(-7.7825e-014)*A4+(-8.8902e-015)*A5'
+dk2p           ='0+(0.00099144)*A1+(0.0006349)*A2+(-3.0985e-005)*A3+(0.00019975)*A4+(-7.4923e-005)*A5'
+dlcitp         ='0+(-1.6224e-012)*A1+(-1.1415e-012)*A2+(-6.6752e-012)*A3+(-3.118e-012)*A4+(6.6949e-013)*A5'
+dlvoffp        ='0+(3.9178e-011)*A1+(5.0395e-011)*A2+(1.4961e-011)*A3+(-3.8912e-011)*A4+(-4.4451e-012)*A5'
+dnfactorp      ='0+(-0.0054849)*A1+(-0.0070553)*A2+(-0.0020946)*A3+(0.0054477)*A4+(0.00062232)*A5'
+dlnfactorp     ='0+(-1.0527e-009)*A1+(1.8265e-010)*A2+(-2.9996e-010)*A3+(-5.1262e-011)*A4+(6.5355e-011)*A5'
+dpnfactorp     ='max(-4.0e-15,0+(-3.9835e-016)*A1+(-6.3254e-018)*A2+(-3.7456e-016)*A3+(5.4181e-016)*A4+(3.7869e-017)*A5)'
+dlk2p          ='0+(-4.5574e-012)*A1+(2.1428e-012)*A2+(3.3796e-012)*A3+(-1.0279e-011)*A4+(4.751e-014)*A5'
+dwk2p          ='0+(1.1154e-010)*A1+(7.1426e-011)*A2+(-3.4858e-012)*A3+(2.2472e-011)*A4+(-8.4288e-012)*A5'
+dpk2p          ='0+(2.8064e-018)*A1+(2.8094e-018)*A2+(5.5973e-019)*A3+(-1.3068e-018)*A4+(-2.7146e-019)*A5'
+dpdiblc2p      ='max(-0.00032,0+(-5.14e-005)*A1+(-8.1618e-007)*A2+(-4.833e-005)*A3+(6.991e-005)*A4+(4.8863e-006)*A5)'
+datp           ='0+(-460.44)*A1+(-165.92)*A2+(386.31)*A3+(-706.07)*A4+(1243.7)*A5'
+dlatp          ='0+(-0.00028469)*A1+(-0.00019815)*A2+(-0.00016663)*A3+(0.00018612)*A4+(-0.00067267)*A5'
+dpatp          ='0+(2.1352e-011)*A1+(1.4861e-011)*A2+(1.2497e-011)*A3+(-1.3959e-011)*A4+(5.045e-011)*A5'
+ddlcn          =7.27377e-09
+drdswn         =0
+deta0n         =0
+dwvsatn        =0
+dwvoffn        =0
+dnfactorn      =0
+dwnfactorn     =0
+dpdiblc2n      =0
+ddlcp          =8.26573e-09
+deta0p         =0
+dweta0p        =0
+dvsatp         =0
+dwcitp         =0
+dpcitp         =0
+dwvoffp        =0
+dpvoffp        =0
+dwnfactorp     =0
+dlpclmp        =0
+dppclmp        =0
+dwatp          =0

+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' mos
.ENDL mc








.LIB TT
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+toxn           = 2.6e-09       dxln           = 0             dxwn           = 0
+dvthn          = 0             dlvthn         = 0             dwvthn         = 0
+dpvthn         = 0             cjn            = 0.001251      cjswn          = 7.9e-11
+cjswgn         = 2.04e-10
+cgon           = 8.28670e-11
+cgln           = 9.96116e-12
+ddlcn          = 7.27377e-09
+cfn            = '1.20e-10 + 5.4e-11*ccoflag' drdswn         = 0
+ntoxn          = 1             du0n           = 0             dlu0n          = 0
+dwu0n          = 0             dpu0n          = 0             deta0n         = 0
+dleta0n        = 0             dweta0n        = 0             dpeta0n        = 0
+dvsatn         = 0             dlvsatn        = 0             dwvsatn        = 0
+dpvsatn        = 0             dk2n           = 0             dlcitn         = 0
+dwcitn         = 0             dlvoffn        = 0             dwvoffn        = 0
+dpvoffn        = 0             dnfactorn      = 0             dwnfactorn     = 0
+dlnfactorn     = 0             dpnfactorn     = 0             dpdiblc2n      = 0
+dla0n          = 0             ss_flag        = 0             ff_flag        = 0
+sf_flag        = 0             fs_flag        = 0
+toxp           = 2.8e-09       dxlp           = 0             dxwp           = 0
+dvthp          = 0             dlvthp         = 0             dwvthp         = 0
+dpvthp         = 0             cjp            = 0.001077      cjswp          = 6.4e-11
+cjswgp         = 2.2e-10       cgop           = 7.70111e-11   cglp           = 2.69027e-11
+ddlcp          = 8.26573e-09   cfp            = '1.20e-10 + 5.6e-11*ccoflag' drdswp         = 0
+ntoxp          = 1             du0p           = 0             dlu0p          = 0
+dwu0p          = 0             dpu0p          = 0             deta0p         = 0
+dleta0p        = 0             dweta0p        = 0             dpeta0p        = 0
+dvsatp         = 0             dlvsatp        = 0             dwvsatp        = 0
+dpvsatp        = 0             dk2p           = 0             dlcitp         = 0
+dwcitp         = 0             dpcitp         = 0             dlvoffp        = 0
+dwvoffp        = 0             dpvoffp        = 0             dnfactorp      = 0
+dlnfactorp     = 0             dwnfactorp     = 0             dpnfactorp     = 0
+dlk2p          = 0             dwk2p          = 0             dpk2p          = 0
+dpdiblc2p      = 0
+dlpclmp        = 0             dppclmp         = 0
+datp           = 0
+dlatp          = 0
+dwatp          = 0
+dpatp          = 0
     
+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' MAC
.lib 'crn65lp_v1d5.l' MOS
.ENDL TT








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+toxn           = 2.667e-09     dxln           = 5e-09         dxwn           = -8e-09
+dvthn          = 0.023         dlvthn         = 1.5e-09       dwvthn         = 2.7e-09
+dpvthn         = 2.2e-16       cjn            = 0.00133857    cjswn          = 8.45e-11
+cjswgn         = 2.1828e-10    cgon           = 7.70663e-11   cgln           = 9.26338e-12
+ddlcn          = 7.27377e-09   cfn            = '1.1160e-10 + 5.4e-11*ccoflag' drdswn         = 0
+ntoxn          = 0.24          du0n           = 3.0e-04       dlu0n          = 5.0e-011
+dwu0n          = 0.6e-10       dpu0n          = -1.0e-17      deta0n         = 0
+dleta0n        = -0.6e-09      dweta0n        = -5.0e-10      dpeta0n        = -1.5e-16
+dvsatn         = -0.0e04       dlvsatn        = 0.35e-03      dwvsatn        = 0
+dpvsatn        = 3.0e-11       dk2n           = 0.005         dlcitn         = -1e-11
+dwcitn         = -6e-11        dlvoffn        = -5.0e-10      dwvoffn        = 0
+dpvoffn        = 0             dnfactorn      = -0.0e-2       dwnfactorn     = 0
+dlnfactorn     = -0.5e-08      dpnfactorn     = -0.0e-15      dpdiblc2n      = 0
+dla0n          = 10e-08        ss_flag        = 1             ff_flag        = 0
+sf_flag        = 0             fs_flag        = 0
+toxp           = 2.867e-09     dxlp           = 5e-09         dxwp           = -8e-09
+dvthp          = -0.024        dlvthp         = -6e-10        dwvthp         = -3.0e-09
+dpvthp         = -2.1e-16      cjp            = 0.00115239    cjswp          = 6.85e-11
+cjswgp         = 2.354e-10     cgop           = 7.16203e-11   cglp           = 2.50195e-11
+ddlcp          = 8.26573e-09   cfp            = '1.1160e-10 + 5.6e-11*ccoflag' drdswp         = -20
+ntoxp          = -1.44         du0p           = 0.0004        dlu0p          = -2.7e-11
+dwu0p          = 0             dpu0p          = 1e-17         deta0p         = 0
+dleta0p        = -1.5e-9       dweta0p        = 0             dpeta0p        = 2e-17
+dvsatp         = 0             dlvsatp        = 0.0023        dwvsatp        = -0.000
+dpvsatp        = -0e-12        dk2p           = 0.008         dlcitp         = 0
+dwcitp         = 0             dpcitp         = 0             dlvoffp        = 0
+dwvoffp        = 0             dpvoffp        = 0             dnfactorp      = 0
+dlnfactorp     = -9e-09        dwnfactorp     = 0             dpnfactorp     = 0
+dlk2p          = -1.0e-10      dwk2p          = 9e-10         dpk2p          = 1e-17
+dpdiblc2p      = 0
+dlpclmp        = 0e-7          dppclmp        = 0
+datp           = -9000
+dlatp          = 0
+dwatp          = 0
+dpatp          = 0

+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' MAC
.lib 'crn65lp_v1d5.l' MOS
.ENDL SS








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+toxn           = 2.533e-09     dxln           = -5e-09        dxwn           = 8e-09
+dvthn          = -0.023        dlvthn         = -1.5e-09      dwvthn         = -3.0e-09
+dpvthn         = -3.2e-16      cjn            = 0.00116343    cjswn          = 7.35e-11
+cjswgn         = 1.8972e-10    cgon           = 8.86677e-11   cgln           = 1.06584e-11
+ddlcn          = 7.27377e-09   cfn            = '1.2840e-10 + 5.4e-11*ccoflag' drdswn         = 0
+ntoxn          = 1.59          du0n           = -3.0e-04      dlu0n          = -0.0e-011
+dwu0n          = -0.9e-10      dpu0n          = 1.0e-17       deta0n         = 0
+dleta0n        = 0.2e-9        dweta0n        = 9.0e-09       dpeta0n        = -4.0e-16
+dvsatn         = 0.0e4         dlvsatn        = -0.4e-03     dwvsatn        = 0.0e-03
+dpvsatn        = -2.0e-11      dk2n           = -0.004        dlcitn         = 0
+dwcitn         = 0             dlvoffn        = 5.0e-10       dwvoffn        = 0
+dpvoffn        = -0.2e-16       dnfactorn      = 0             dwnfactorn     = 0e-08
+dlnfactorn     = 0.8e-08       dpnfactorn     = 0.0e-14       dpdiblc2n      = 0
+dla0n          = -10e-08       ss_flag        = 0             ff_flag        = 1
+sf_flag        = 0             fs_flag        = 0
+toxp           = 2.733e-09     dxlp           = -5e-09        dxwp           = 8e-09
+dvthp          = 0.024         dlvthp         = 2e-10         dwvthp         = 4e-09
+dpvthp         = 1.8e-16       cjp            = 0.00100161    cjswp          = 5.95e-11
+cjswgp         = 2.046e-10     cgop           = 8.24019e-11   cglp           = 2.878599e-11
+ddlcp          = 8.26573e-09   cfp            = '1.2840e-10 + 5.6e-11*ccoflag' drdswp         = 20
+ntoxp          = 2.27          du0p           = -0.0004       dlu0p          = 2.7e-11
+dwu0p          = 1e-11         dpu0p          = -1e-17        deta0p         = 0
+dleta0p        = 8e-10         dweta0p        = 0             dpeta0p        = 5e-17
+dvsatp         = 0             dlvsatp        = -0.00135      dwvsatp        = 0.0019
+dpvsatp        = -1e-12        dk2p           = -0.008        dlcitp         = 0
+dwcitp         = 0             dpcitp         = 0             dlvoffp        = -5e-10
+dwvoffp        = 0             dpvoffp        = 0             dnfactorp      = 0.07
+dlnfactorp     = 1.0e-8        dwnfactorp     = 0             dpnfactorp     = 6.2e-15
+dlk2p          = 0             dwk2p          = -9e-10        dpk2p          = -3e-17
+dpdiblc2p      = 0.0008
+dlpclmp        = 0             dppclmp        = 0
+datp           = 9000
+dlatp          = 0
+dwatp          = 0
+dpatp          = 0

+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' MAC
.lib 'crn65lp_v1d5.l' MOS
.ENDL FF








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+A1N=0.8 A1P=-0.8 A2N=0 A2P=0 A3N=-1 A3P=1 A4NP=0
+toxn = '2.6e-09 + 6.7000e-011*A4NP'     dxln = '5e-009*A2N'                     dxwn = '8e-009*A3N'
+dvthn = '0.023*A1N'                     dlvthn = '1.5e-009*A1N'                 dwvthn = '3e-009*A1N'
+dpvthn = '2.7e-016*A1N'                 cjn = '0.001251 * (1+0.070*A1N)'        cjswn = '7.9e-11 * (1+0.070*A1N)'
+cjswgn = '2.04e-10 * (1+0.070*A1N)'     cgon = '8.28670e-11 * (1-0.070*A4NP)'     cgln = '9.96116e-12 * (1-0.070*A4NP)'
+ddlcn = 7.27377e-09
+cfn = '1.20e-10*(1-0.070*A4NP)+5.4e-11*ccoflag'
+drdswn = 0                              ntoxn = '1 + -5.9000e-001*A4NP'         du0n = '0.0003*A1N'
+dlu0n = '0*A1N'                         dwu0n = '9e-011*A1N'                    dpu0n = '-1e-017*A1N'
+deta0n = 0                              dleta0n = '-2e-010*A1N'                 dweta0n = '-9e-009*A1N'
+dpeta0n = '4.2e-016*A1N'                dvsatn = '-25000*A1N'                   dlvsatn = '0.00175*A1N'
+dwvsatn = '0*A1N'                       dpvsatn = '3e-012*A1N'                  dk2n = '0.004*A1N'
+dlcitn = 0                              dwcitn = 0                              dlvoffn = '-5e-010*A1N'
+dwvoffn = 0                             dpvoffn = 0                             dnfactorn = 0
+dwnfactorn = '0*A1N'                    dlnfactorn = '-8e-009*A1N'              dpnfactorn = '-5e-015*A1N'
+dpdiblc2n = 0                           dla0n = '1e-007*A1N'                    ss_flag = 0
+ff_flag = 0                             sf_flag = 1                             fs_flag = 0
+toxp = '2.8e-09 + 6.7000e-11*A4NP'      dxlp = '5e-09*A2P'                      dxwp = '8e-09*A3P'
+dvthp = '-0.024*A1P'                    dlvthp = '-2e-10*A1P'                   dwvthp = '-4e-09*A1P'
+dpvthp = '-1.8e-16*A1P'                 cjp = '0.001077 * (1+0.070*A1P)'        cjswp = '6.4e-11 * (1+0.070*A1P)'
+cjswgp = '2.2e-10 * (1+0.070*A1P)'      cgop = '7.70111e-11 * (1-0.070*A4NP)'   cglp = '2.69027e-11 * (1-0.070*A4NP)'
+ddlcp = 8.26573e-09
+cfp = '1.20e-10*(1-0.070*A4NP)+5.6e-11*ccoflag'
+drdswp = '-20*A1P'                      ntoxp = '1 + -1.2700e+00*A4NP'          du0p = '0.0004*A1P'
+dlu0p = '-6e-11*A1P'                    dwu0p = '-1e-11*A1P'                    dpu0p = '1e-17*A1P'
+deta0p = 0                              dleta0p = '-8e-10*A1P'                  dweta0p = 0
+dpeta0p = '-5e-17*A1P'                  dvsatp = 0                              dlvsatp = '0.00135*A1P'
+dwvsatp = '-0.0019*A1P'                 dpvsatp = '1e-12*A1P'                   dk2p = '0.008*A1P'
+dlcitp = 0                              dwcitp = 0                              dpcitp = 0
+dlvoffp = '5e-10*A1P'                   dwvoffp = 0                             dpvoffp = 0
+dnfactorp = '-0.07*A1P'                 dlnfactorp = '-1e-08*A1P*0'             dwnfactorp = 0
+dpnfactorp = '-6.2e-15*A1P*0'           dlk2p = 0                               dwk2p = '9e-10*A1P'
+dpk2p = '3e-17*A1P'                     dpdiblc2p = '-0.0008*A1P*0'             dlpclmp = 0
+dppclmp = 0                             datp = '-7000*A1P'                      dlatp = 0
+dwatp              = 0                  dpatp              = 0

+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' MAC
.lib 'crn65lp_v1d5.l' MOS
.ENDL SF








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS
.lib 'crn65lp_v1d5.l' noiseflag
.lib 'crn65lp_v1d5.l' post_simu
.param
+parn1=AGAUSS(0,1,1)
+parn2=AGAUSS(0,1,1)
+parp1=AGAUSS(0,1,1)
+parp2=AGAUSS(0,1,1)
+A1N=-0.8 A1P=0.8 A2N=0 A2P=0 A3N=1 A3P=-1 A4NP=0
+toxn = '2.6e-09 + 6.7000e-011*A4NP'     dxln = '5e-009*A2N'                     dxwn = '8e-009*A3N'
+dvthn = '0.023*A1N'                     dlvthn = '1.5e-009*A1N'                 dwvthn = '3e-009*A1N'
+dpvthn = '2.7e-016*A1N'                 cjn = '0.001251 * (1+0.070*A1N)'        cjswn = '7.9e-11 * (1+0.070*A1N)'
+cjswgn = '2.04e-10 * (1+0.070*A1N)'     cgon = '8.28670e-11 * (1-0.070*A4NP)'     cgln = '9.96116e-12 * (1-0.070*A4NP)'
+ddlcn = 7.27377e-09
+cfn = '1.20e-10*(1-0.070*A4NP)+5.4e-11*ccoflag'
+drdswn = 0                              ntoxn = '1 + -5.9000e-001*A4NP'         du0n = '0.0003*A1N'
+dlu0n = '0*A1N'                         dwu0n = '9e-011*A1N'                    dpu0n = '-1e-017*A1N'
+deta0n = 0                              dleta0n = '-2e-010*A1N'                 dweta0n = '-9e-009*A1N'
+dpeta0n = '4.2e-016*A1N'                dvsatn = '-25000*A1N'                   dlvsatn = '0.00175*A1N'
+dwvsatn = '0*A1N'                       dpvsatn = '3e-012*A1N'                  dk2n = '0.004*A1N'
+dlcitn = 0                              dwcitn = 0                              dlvoffn = '-5e-010*A1N'
+dwvoffn = 0                             dpvoffn = 0                             dnfactorn = 0
+dwnfactorn = '0*A1N'                    dlnfactorn = '-8e-009*A1N'              dpnfactorn = '-5e-015*A1N'
+dpdiblc2n = 0                           dla0n = '1e-007*A1N'                    ss_flag = 0
+ff_flag = 0                             sf_flag = 0                             fs_flag = 1
+toxp = '2.8e-09 + 6.7000e-11*A4NP'      dxlp = '5e-09*A2P'                      dxwp = '8e-09*A3P'
+dvthp = '-0.024*A1P'                    dlvthp = '-2e-10*A1P'                   dwvthp = '-4e-09*A1P'
+dpvthp = '-1.8e-16*A1P'                 cjp = '0.001077 * (1+0.070*A1P)'        cjswp = '6.4e-11 * (1+0.070*A1P)'
+cjswgp = '2.2e-10 * (1+0.070*A1P)'      cgop = '7.70111e-11 * (1-0.070*A4NP)'   cglp = '2.69027e-11 * (1-0.070*A4NP)'
+ddlcp = 8.26573e-09
+cfp = '1.20e-10*(1-0.070*A4NP)+5.6e-11*ccoflag'
+drdswp = '-20*A1P'                      ntoxp = '1 + -1.2700e+00*A4NP'          du0p = '0.0004*A1P'
+dlu0p = '-6e-11*A1P'                    dwu0p = '-1e-11*A1P'                    dpu0p = '1e-17*A1P'
+deta0p = 0                              dleta0p = '-8e-10*A1P'                  dweta0p = 0
+dpeta0p = '-5e-17*A1P'                  dvsatp = 0                              dlvsatp = '0.00135*A1P'
+dwvsatp = '-0.0019*A1P'                 dpvsatp = '1e-12*A1P'                   dk2p = '0.008*A1P'
+dlcitp = 0                              dwcitp = 0                              dpcitp = 0
+dlvoffp = '5e-10*A1P'                   dwvoffp = 0                             dpvoffp = 0
+dnfactorp = '-0.07*A1P'                 dlnfactorp = '-1e-08*A1P*0'             dwnfactorp = 0
+dpnfactorp = '-6.2e-15*A1P*0'           dlk2p = 0                               dwk2p = '9e-10*A1P'
+dpk2p = '3e-17*A1P'                     dpdiblc2p = '-0.0008*A1P*0'             dlpclmp = 0
+dppclmp = 0                             datp = '-7000*A1P'                      dlatp = 0
+dwatp              = 0                  dpatp              = 0

+ c1fn=8.00E+41           c2fn=5.00E+22           c3fn=1.00E+7               
+ c1fp=9.50E+41           c2fp=1.55E+24           c3fp=1.00E+10       
+ fn_dice_svtn='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
+ arearation='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian='c1fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noibn='c2fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ noicn='c3fn*2.718**((fn_dice_svtn+(1-fn_dice_svtn)*noiseflagn)*arearation)'
+ fn_dice_svtp='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
+ arearatiop='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap='c1fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noibp='c2fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'
+ noicp='c3fp*2.718**((noiseflagp_mc*par1fn_mc+(1-noiseflagp_mc)*noiseflagp)*arearatiop)'

.lib 'crn65lp_v1d5.l' MAC
.lib 'crn65lp_v1d5.l' MOS
.ENDL FS







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+A1_hvt='-par1*5.4189e+000*3/2.1'
+A2_hvt='-par2*4.3704e+000*3/2.1'
+A3_hvt='-par3*3.1178e+000*3/2.1'
+A4_hvt='-par4*1.9530e+000*3/2.1'
+toxn_hvt        = '2.6000e-009+(-7.4904e-012)*A1_hvt+(-1.8124e-012)*A2_hvt+(-1.1128e-011)*A3_hvt+(4.5387e-012)*A4_hvt'
+dxln_hvt        = '0.0000e+000+(-5.7247e-010)*A1_hvt+(-2.0717e-010)*A2_hvt+(-1.2667e-009)*A3_hvt+(5.2275e-010)*A4_hvt'
+dxwn_hvt        = 'max(-20e-9,0.0000e+000+(9.1309e-010)*A1_hvt+(-6.8212e-010)*A2_hvt+(2.4039e-009)*A3_hvt+(-5.4317e-010)*A4_hvt)'
+dvthn_hvt       = '0.0000e+000+(-2.1429e-003)*A1_hvt+(2.2248e-003)*A2_hvt+(4.4850e-004)*A3_hvt+(-1.2686e-003)*A4_hvt'
+dlvthn_hvt      = '0.0000e+000+(-9.3533e-011)*A1_hvt+(9.9323e-011)*A2_hvt+(2.0387e-011)*A3_hvt+(-5.2212e-011)*A4_hvt'
+dwvthn_hvt      = '0.0000e+000+(-3.9482e-010)*A1_hvt+(6.5874e-010)*A2_hvt+(1.7377e-010)*A3_hvt+(1.2165e-010)*A4_hvt'
+dpvthn_hvt      = '0.0000e+000+(-1.4592e-017)*A1_hvt+(-1.2112e-018)*A2_hvt+(-2.1770e-017)*A3_hvt+(-1.7468e-017)*A4_hvt'
+cjn_hvt         = '1.4720e-003+(-1.0768e-005)*A1_hvt+(1.1510e-005)*A2_hvt+(2.3747e-006)*A3_hvt+(-5.9026e-006)*A4_hvt'
+cjswn_hvt       = '9.5000e-011+(-6.9492e-013)*A1_hvt+(7.4282e-013)*A2_hvt+(1.5326e-013)*A3_hvt+(-3.8094e-013)*A4_hvt'
+cjswgn_hvt      = '2.5900e-010+(-1.8946e-012)*A1_hvt+(2.0252e-012)*A2_hvt+(4.1783e-013)*A3_hvt+(-1.0386e-012)*A4_hvt'
+cgon_hvt        = '7.8989e-011+(6.1815e-013)*A1_hvt+(1.4957e-013)*A2_hvt+(9.1836e-013)*A3_hvt+(-3.7456e-013)*A4_hvt'
+cgln_hvt        = '1.5523e-012+(1.2148e-014)*A1_hvt+(2.9393e-015)*A2_hvt+(1.8047e-014)*A3_hvt+(-7.3606e-015)*A4_hvt'
+dlcitn_hvt      = '0.0000e+000+(-6.1772e-012)*A1_hvt+(7.4696e-012)*A2_hvt+(6.0819e-012)*A3_hvt+(-5.5477e-012)*A4_hvt'
+dwcitn_hvt      = '0.0000e+000+(1.5548e-011)*A1_hvt+(-2.9770e-011)*A2_hvt+(-8.2456e-012)*A3_hvt+(-1.0259e-011)*A4_hvt'
+dpcitn_hvt      = '0.0000e+000+(-2.6527e-018)*A1_hvt+(4.0848e-018)*A2_hvt+(1.0426e-018)*A3_hvt+(3.3017e-019)*A4_hvt'
+ntoxn_hvt       = '1.0000e+000+(8.7883e-002)*A1_hvt+(2.0085e-002)*A2_hvt+(1.0874e-001)*A3_hvt+(-2.1196e-003)*A4_hvt'
+dlu0n_hvt       = '0.0000e+000+(-3.3384e-012)*A1_hvt+(1.4317e-012)*A2_hvt+(-4.6449e-014)*A3_hvt+(-4.8822e-012)*A4_hvt'
+dwu0n_hvt       = '0.0000e+000+(-9.5069e-012)*A1_hvt+(1.0425e-011)*A2_hvt+(2.1930e-012)*A3_hvt+(-4.8359e-012)*A4_hvt'
+dpu0n_hvt       = '0.0000e+000+(5.5020e-019)*A1_hvt+(-4.2375e-019)*A2_hvt+(-6.1133e-020)*A3_hvt+(5.3639e-019)*A4_hvt'
+dlvsatn_hvt     = '0.0000e+000+(-1.5485e-005)*A1_hvt+(3.6278e-005)*A2_hvt+(1.0640e-005)*A3_hvt+(1.9685e-005)*A4_hvt'
+dwvsatn_hvt     = 'max(-0.7e-3,0.0000e+000+(-1.1508e-004)*A1_hvt+(1.0986e-004)*A2_hvt+(2.0562e-005)*A3_hvt+(-8.1865e-005)*A4_hvt)'
+dpvsatn_hvt     = '0.0000e+000+(-3.2131e-013)*A1_hvt+(-5.9028e-012)*A2_hvt+(-2.2170e-012)*A3_hvt+(-9.0979e-012)*A4_hvt'
+deta0n_hvt      = '0.0000e+000+(-3.7017e-004)*A1_hvt+(-6.4558e-005)*A2_hvt+(-8.6943e-005)*A3_hvt+(-8.6031e-004)*A4_hvt'
+dleta0n_hvt     = '0.0000e+000+(-4.6456e-011)*A1_hvt+(1.0883e-010)*A2_hvt+(3.1920e-011)*A3_hvt+(5.9055e-011)*A4_hvt'
+dweta0n_hvt     = '0.0000e+000+(4.1294e-011)*A1_hvt+(-9.6740e-011)*A2_hvt+(-2.8373e-011)*A3_hvt+(-5.2494e-011)*A4_hvt'
+dpeta0n_hvt     = '0.0000e+000+(2.5809e-018)*A1_hvt+(-6.0463e-018)*A2_hvt+(-1.7733e-018)*A3_hvt+(-3.2808e-018)*A4_hvt'
+dk2n_hvt        = '0.0000e+000+(-3.1350e-004)*A1_hvt+(3.3511e-004)*A2_hvt+(6.9138e-005)*A3_hvt+(-1.7185e-004)*A4_hvt'
+dwk2n_hvt       = '0.0000e+000+(-3.6511e-010)*A1_hvt+(4.5603e-010)*A2_hvt+(1.0461e-010)*A3_hvt+(-1.0624e-010)*A4_hvt'
+dpclmn_hvt      = '0.0000e+000+(1.0323e-003)*A1_hvt+(-2.4185e-003)*A2_hvt+(-7.0933e-004)*A3_hvt+(-1.3123e-003)*A4_hvt'
+da0n_hvt        = '0.0000e+000+(3.2235e-003)*A1_hvt+(5.7593e-003)*A2_hvt+(2.6607e-003)*A3_hvt+(1.4915e-002)*A4_hvt'
+dla0n_hvt       = '0.0000e+000+(-1.6518e-009)*A1_hvt+(3.8696e-009)*A2_hvt+(1.1349e-009)*A3_hvt+(2.0997e-009)*A4_hvt'
+dwa0n_hvt       = '0.0000e+000+(5.1617e-009)*A1_hvt+(-1.2093e-008)*A2_hvt+(-3.5467e-009)*A3_hvt+(-6.5617e-009)*A4_hvt'
+cfn_hvt         = '1.2000e-010+(9.3910e-013)*A1_hvt+(2.2723e-013)*A2_hvt+(1.3952e-012)*A3_hvt+(-5.6903e-013)*A4_hvt+5e-11*ccoflag_hvt'
+ss_flag_hvt     = '0.0000e+000+(-5.2882e-002)*A1_hvt+(-9.2226e-003)*A2_hvt+(-1.2420e-002)*A3_hvt+(-1.2290e-001)*A4_hvt'
+ff_flag_hvt     = 'max(-0.4,0.0000e+000+(5.3522e-002)*A1_hvt+(-1.0937e-002)*A2_hvt+(-2.0828e-002)*A3_hvt+(-1.1703e-001)*A4_hvt)'
+toxp_hvt        = '2.8000e-009+(-7.4904e-012)*A1_hvt+(-1.8124e-012)*A2_hvt+(-1.1128e-011)*A3_hvt+(4.5387e-012)*A4_hvt'
+dxlp_hvt        = '0.0000e+000+(-5.4550e-010)*A1_hvt+(-6.3340e-011)*A2_hvt+(-3.9422e-010)*A3_hvt+(1.5466e-010)*A4_hvt'
+dxwp_hvt        = 'max(-22e-9,0.0000e+000+(9.1882e-010)*A1_hvt+(1.3451e-009)*A2_hvt+(1.6496e-009)*A3_hvt+(-1.1296e-009)*A4_hvt)'
+dvthp_hvt       = '0.0000e+000+(2.1122e-003)*A1_hvt+(1.8778e-003)*A2_hvt+(-1.6204e-003)*A3_hvt+(-1.7446e-004)*A4_hvt'
+dlvthp_hvt      = '0.0000e+000+(9.5050e-011)*A1_hvt+(8.4501e-011)*A2_hvt+(-7.2917e-011)*A3_hvt+(-7.8507e-012)*A4_hvt'
+dwvthp_hvt      = '0.0000e+000+(2.2184e-010)*A1_hvt+(1.6699e-010)*A2_hvt+(-1.2779e-010)*A3_hvt+(8.3492e-011)*A4_hvt'
+dpvthp_hvt      = '0.0000e+000+(2.9039e-017)*A1_hvt+(2.7706e-017)*A2_hvt+(-2.4927e-017)*A3_hvt+(-8.7620e-018)*A4_hvt'
+cjp_hvt         = '1.0910e-003+(-8.0655e-006)*A1_hvt+(-7.1704e-006)*A2_hvt+(6.1874e-006)*A3_hvt+(6.6618e-007)*A4_hvt'
+cjswp_hvt       = '6.4000e-011+(-4.7314e-013)*A1_hvt+(-4.2063e-013)*A2_hvt+(3.6296e-013)*A3_hvt+(3.9079e-014)*A4_hvt'
+cjswgp_hvt      = '2.9000e-010+(-2.1439e-012)*A1_hvt+(-1.9060e-012)*A2_hvt+(1.6447e-012)*A3_hvt+(1.7708e-013)*A4_hvt'
+cgop_hvt        = '4.7923e-011+(3.7504e-013)*A1_hvt+(9.0744e-014)*A2_hvt+(5.5718e-013)*A3_hvt+(-2.2725e-013)*A4_hvt'
+cglp_hvt        = '5.2044e-011+(4.0729e-013)*A1_hvt+(9.8549e-014)*A2_hvt+(6.0510e-013)*A3_hvt+(-2.4679e-013)*A4_hvt'
+dlcitp_hvt      = '0.0000e+000+(-5.5921e-012)*A1_hvt+(-4.3906e-012)*A2_hvt+(1.1965e-011)*A3_hvt+(-1.1923e-012)*A4_hvt'
+dwcitp_hvt      = '0.0000e+000+(2.3744e-012)*A1_hvt+(3.0556e-012)*A2_hvt+(-3.1462e-012)*A3_hvt+(-3.3779e-012)*A4_hvt'
+dpcitp_hvt      = '0.0000e+000+(-6.3367e-019)*A1_hvt+(-5.6334e-019)*A2_hvt+(4.8611e-019)*A3_hvt+(5.2338e-020)*A4_hvt'
+ntoxp_hvt       = '1.0000e+000+(2.1738e-001)*A1_hvt+(4.7881e-002)*A2_hvt+(2.3564e-001)*A3_hvt+(7.2812e-002)*A4_hvt'
+dlu0p_hvt       = '0.0000e+000+(-4.3163e-012)*A1_hvt+(-2.8812e-012)*A2_hvt+(8.7626e-012)*A3_hvt+(-2.6214e-012)*A4_hvt'
+dwu0p_hvt       = '0.0000e+000+(2.1122e-012)*A1_hvt+(1.8778e-012)*A2_hvt+(-1.6204e-012)*A3_hvt+(-1.7446e-013)*A4_hvt'
+dpu0p_hvt       = '0.0000e+000+(1.1603e-018)*A1_hvt+(1.4506e-018)*A2_hvt+(5.5986e-019)*A3_hvt+(-1.4346e-018)*A4_hvt'
+dlvsatp_hvt     = '0.0000e+000+(-1.0035e-004)*A1_hvt+(-7.7879e-005)*A2_hvt+(6.1089e-005)*A3_hvt+(-2.9892e-005)*A4_hvt'
+dpvsatp_hvt     = '0.0000e+000+(4.7457e-013)*A1_hvt+(7.6201e-013)*A2_hvt+(-8.4095e-013)*A3_hvt+(-1.1846e-012)*A4_hvt'
+dk2p_hvt        = '0.0000e+000+(-3.1683e-004)*A1_hvt+(-2.8167e-004)*A2_hvt+(2.4306e-004)*A3_hvt+(2.6169e-005)*A4_hvt'
+dwk2p_hvt       = '0.0000e+000+(-3.6956e-010)*A1_hvt+(-3.6634e-010)*A2_hvt+(3.3649e-010)*A3_hvt+(1.5779e-010)*A4_hvt'
+dla0p_hvt       = '0.0000e+000+(-5.2806e-009)*A1_hvt+(-4.6945e-009)*A2_hvt+(4.0509e-009)*A3_hvt+(4.3615e-010)*A4_hvt'
+dlubp_hvt       = '0.0000e+000+(8.9793e-028)*A1_hvt+(6.8490e-028)*A2_hvt+(-5.2987e-028)*A3_hvt+(3.0764e-028)*A4_hvt'
+dpubp_hvt       = '0.0000e+000+(6.3276e-035)*A1_hvt+(1.0160e-034)*A2_hvt+(-1.1213e-034)*A3_hvt+(-1.5795e-034)*A4_hvt'
+cfp_hvt         = '1.2000e-010+(9.3910e-013)*A1_hvt+(2.2723e-013)*A2_hvt+(1.3952e-012)*A3_hvt+(-5.6903e-013)*A4_hvt+5e-11*ccoflag_hvt'
+ddlcn_hvt       = '6.6302e-009'
+dcitn_hvt       = '0.0000e+000'
+dnfactorn_hvt   = '0.0000e+000'
+dlnfactorn_hvt  = '0.0000e+000'
+dwnfactorn_hvt  = '0.0000e+000'
+dpnfactorn_hvt  = '0.0000e+000'
+du0n_hvt        = '0.0000e+000'
+dvsatn_hvt      = '0.0000e+000'
+dlk2n_hvt       = '0.0000e+000'
+dpk2n_hvt       = '0.0000e+000'
+drdswn_hvt      = '0.0000e+000'
+dpdiblc2n_hvt   = '0.0000e+000'
+dlpdiblc2n_hvt  = '0.0000e+000'
+dpa0n_hvt       = '0.0000e+000'
+dvoffn_hvt      = '0.0000e+000'
+dlvoffn_hvt     = '0.0000e+000'
+dwvoffn_hvt     = '0.0000e+000'
+dpvoffn_hvt     = '0.0000e+000'
+datn_hvt        = '0.0000e+000'
+sf_flag_hvt     = '0.0000e+000'
+fs_flag_hvt     = '0.0000e+000'
+ddlcp_hvt       = '7.3569e-009'
+dcitp_hvt       = '0.0000e+000'
+dnfactorp_hvt   = '0.0000e+000'
+dlnfactorp_hvt  = '0.0000e+000'
+dwnfactorp_hvt  = '0.0000e+000'
+dpnfactorp_hvt  = '0.0000e+000'
+du0p_hvt        = '0.0000e+000'
+dvsatp_hvt      = '0.0000e+000'
+dwvsatp_hvt     = '0.0000e+000'
+deta0p_hvt      = '0.0000e+000'
+dleta0p_hvt     = '0.0000e+000'
+dweta0p_hvt     = '0.0000e+000'
+dpeta0p_hvt     = '0.0000e+000'
+dlk2p_hvt       = '0.0000e+000'
+dpk2p_hvt       = '0.0000e+000'
+drdswp_hvt      = '0.0000e+000'
+dpclmp_hvt      = '0.0000e+000'
+dlpclmp_hvt     = '0.0000e+000'
+dwpclmp_hvt     = '0.0000e+000'
+dppclmp_hvt     = '0.0000e+000'
+dpdiblc2p_hvt   = '0.0000e+000'
+da0p_hvt        = '0.0000e+000'
+dwa0p_hvt       = '0.0000e+000'
+dpa0p_hvt       = '0.0000e+000'
+dvoffp_hvt      = '0.0000e+000'
+dlvoffp_hvt     = '0.0000e+000'
+dwvoffp_hvt     = '0.0000e+000'
+dpvoffp_hvt     = '0.0000e+000'
+datp_hvt        = '0.0000e+000'
+dubp_hvt        = '0.0000e+000'
+dwubp_hvt       = '0.0000e+000'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL mc_hvt








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+toxn_hvt       = 2.6e-09       dxln_hvt       = 0             dxwn_hvt       = 0
+dvthn_hvt      = 0             dlvthn_hvt     = 0             dwvthn_hvt     = 0
+dpvthn_hvt     = 0             cjn_hvt        = 0.001472      cjswn_hvt      = 9.5e-11
+cjswgn_hvt     = 2.59e-10      cgon_hvt       = 7.89886e-11   cgln_hvt       = 1.55225e-12
+ddlcn_hvt      = 6.6302e-09    dcitn_hvt      = 0             dlcitn_hvt     = 0
+dwcitn_hvt     = 0             dpcitn_hvt     = 0             ntoxn_hvt      = 1
+dnfactorn_hvt  = 0             dlnfactorn_hvt = 0             dwnfactorn_hvt = 0
+dpnfactorn_hvt = 0             du0n_hvt       = 0             dlu0n_hvt      = 0
+dwu0n_hvt      = 0             dpu0n_hvt      = 0             dvsatn_hvt     = 0
+dlvsatn_hvt    = 0             dwvsatn_hvt    = 0             dpvsatn_hvt    = 0
+deta0n_hvt     = 0             dleta0n_hvt    = 0             dweta0n_hvt    = 0
+dpeta0n_hvt    = 0             dk2n_hvt       = 0             dlk2n_hvt      = 0
+dwk2n_hvt      = 0             dpk2n_hvt      = 0             drdswn_hvt     = 0
+dpclmn_hvt     = 0             dpdiblc2n_hvt  = 0             dlpdiblc2n_hvt = 0
+da0n_hvt       = 0             dla0n_hvt      = 0             dwa0n_hvt      = 0
+dpa0n_hvt      = 0             dvoffn_hvt     = 0             dlvoffn_hvt    = 0
+dwvoffn_hvt    = 0             dpvoffn_hvt    = 0             datn_hvt       = 0
+cfn_hvt        = '1.20e-10 + 5.4e-11*ccoflag_hvt' ss_flag_hvt    = 0             ff_flag_hvt    = 0
+sf_flag_hvt    = 0             fs_flag_hvt    = 0
+toxp_hvt       = 2.8e-09       dxlp_hvt       = 0             dxwp_hvt       = 0
+dvthp_hvt      = 0             dlvthp_hvt     = 0             dwvthp_hvt     = 0
+dpvthp_hvt     = 0             cjp_hvt        = 0.001091      cjswp_hvt      = 6.4e-11
+cjswgp_hvt     = 2.9e-10       cgop_hvt       = 4.79229e-11   cglp_hvt       = 5.20444e-11
+ddlcp_hvt      = 7.35688e-09   dcitp_hvt      = 0             dlcitp_hvt     = 0
+dwcitp_hvt     = 0             dpcitp_hvt     = 0             ntoxp_hvt      = 1
+dnfactorp_hvt  = 0             dlnfactorp_hvt = 0             dwnfactorp_hvt = 0
+dpnfactorp_hvt = 0             du0p_hvt       = 0             dlu0p_hvt      = 0
+dwu0p_hvt      = 0             dpu0p_hvt      = 0             dvsatp_hvt     = 0
+dlvsatp_hvt    = 0             dwvsatp_hvt    = 0             dpvsatp_hvt    = 0
+deta0p_hvt     = 0             dleta0p_hvt    = 0             dweta0p_hvt    = 0
+dpeta0p_hvt    = 0             dk2p_hvt       = 0             dlk2p_hvt      = 0
+dwk2p_hvt      = 0             dpk2p_hvt      = 0             drdswp_hvt     = 0
+dpclmp_hvt     = 0             dlpclmp_hvt    = 0             dwpclmp_hvt    = 0
+dppclmp_hvt    = 0             dpdiblc2p_hvt  = 0             da0p_hvt       = 0
+dla0p_hvt      = 0             dwa0p_hvt      = 0             dpa0p_hvt      = 0
+dvoffp_hvt     = 0             dlvoffp_hvt    = 0             dwvoffp_hvt    = 0
+dpvoffp_hvt    = 0             datp_hvt       = 0             dubp_hvt       = 0
+dlubp_hvt      = 0             dwubp_hvt      = 0             dpubp_hvt      = 0
+cfp_hvt            = '1.20e-10 + 5.6e-11*ccoflag_hvt'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MAC_hvt
.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL TT_hvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+toxn_hvt       = 2.667e-09     dxln_hvt       = 5e-09         dxwn_hvt       = -8e-09
+dvthn_hvt      = 0.021         dlvthn_hvt     = 9e-10         dwvthn_hvt     = 2e-09
+dpvthn_hvt     = 2.3e-16       cjn_hvt        = 0.00157504    cjswn_hvt      = 1.0165e-10
+cjswgn_hvt     = 2.7713e-10    cgon_hvt       = 7.3459398e-11 cgln_hvt       = 1.4435925e-12
+ddlcn_hvt      = 6.6302e-09    dcitn_hvt      = 0             dlcitn_hvt     = 6.1e-11
+dwcitn_hvt     = -5e-11        dpcitn_hvt     = 1.6e-17       ntoxn_hvt      = 0.04
+dnfactorn_hvt  = 0             dlnfactorn_hvt = 0             dwnfactorn_hvt = 0
+dpnfactorn_hvt = 0             du0n_hvt       = 0             dlu0n_hvt      = 4.8e-11
+dwu0n_hvt      = 8.9e-11       dpu0n_hvt      = -6.5e-18      dvsatn_hvt     = 0
+dlvsatn_hvt    = 0             dwvsatn_hvt    = 1.2e-3        dpvsatn_hvt    = 0.5e-10
+deta0n_hvt     = 0.007         dleta0n_hvt    = 0             dweta0n_hvt    = 0
+dpeta0n_hvt    = 0             dk2n_hvt       = 0.003         dlk2n_hvt      = 0
+dwk2n_hvt      = 3e-09         dpk2n_hvt      = 0             drdswn_hvt     = 0
+dpclmn_hvt     = 0             dpdiblc2n_hvt  = 0             dlpdiblc2n_hvt = 0
+da0n_hvt       = -0.1          dla0n_hvt      = 0             dwa0n_hvt      = 0
+dpa0n_hvt      = 0             dvoffn_hvt     = 0             dlvoffn_hvt    = 0
+dwvoffn_hvt    = 0             dpvoffn_hvt    = 0             datn_hvt       = 0
+cfn_hvt        = '1.116e-10 + 5.4e-11*ccoflag_hvt' ss_flag_hvt    = 1             ff_flag_hvt    = 0
+sf_flag_hvt    = 0             fs_flag_hvt    = 0
+toxp_hvt       = 2.867e-09     dxlp_hvt       = 5e-09         dxwp_hvt       = -8e-09
+dvthp_hvt      = -0.02         dlvthp_hvt     = -0.9e-9       dwvthp_hvt     = -2.5e-09
+dpvthp_hvt     = -2.5e-16      cjp_hvt        = 0.00116737    cjswp_hvt      = 6.848e-11
+cjswgp_hvt     = 3.103e-10     cgop_hvt       = 4.4568297e-11 cglp_hvt       = 4.8401292e-11
+ddlcp_hvt      = 7.35688e-09   dcitp_hvt      = 0             dlcitp_hvt     = 5e-11
+dwcitp_hvt     = -1e-11        dpcitp_hvt     = 6e-18         ntoxp_hvt      = -1.64
+dnfactorp_hvt  = 0             dlnfactorp_hvt = 0             dwnfactorp_hvt = 0
+dpnfactorp_hvt = 0             du0p_hvt       = 0             dlu0p_hvt      = 4.5e-11
+dwu0p_hvt      = -2e-11        dpu0p_hvt      = -8e-18        dvsatp_hvt     = 0
+dlvsatp_hvt    = 0.0011        dwvsatp_hvt    = 0             dpvsatp_hvt    = 0
+deta0p_hvt     = 0             dleta0p_hvt    = 0             dweta0p_hvt    = 0
+dpeta0p_hvt    = 0             dk2p_hvt       = 0.003         dlk2p_hvt      = 0
+dwk2p_hvt      = 3e-09         dpk2p_hvt      = 0             drdswp_hvt     = 0
+dpclmp_hvt     = 0             dlpclmp_hvt    = 0             dwpclmp_hvt    = 0
+dppclmp_hvt    = 0             dpdiblc2p_hvt  = 0             da0p_hvt       = 0
+dla0p_hvt      = 0.5e-7        dwa0p_hvt      = 0             dpa0p_hvt      = 0
+dvoffp_hvt     = 0             dlvoffp_hvt    = 0             dwvoffp_hvt    = 0
+dpvoffp_hvt    = 0             datp_hvt       = 0             dubp_hvt       = 0
+dlubp_hvt      = -1.0e-26      dwubp_hvt      = 0             dpubp_hvt      = 0
+cfp_hvt            = '1.116e-10 + 5.6e-11*ccoflag_hvt'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MAC_hvt
.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL SS_hvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+toxn_hvt       = 2.533e-09     dxln_hvt       = -5e-09        dxwn_hvt       = 8e-09
+dvthn_hvt      = -0.02         dlvthn_hvt     = -8.9e-10      dwvthn_hvt     = -5.6e-09
+dpvthn_hvt     = -0.35e-16     cjn_hvt        = 0.00136896    cjswn_hvt      = 8.835e-11
+cjswgn_hvt     = 2.4087e-10    cgon_hvt       = 8.4517802e-11 cgln_hvt       = 1.6609075e-12
+ddlcn_hvt      = 6.6302e-09    dcitn_hvt      = 0             dlcitn_hvt     = -0.6e-10
+dwcitn_hvt     = 25e-11        dpcitn_hvt     = -3.5e-17      ntoxn_hvt      = 1.63
+dnfactorn_hvt  = 0             dlnfactorn_hvt = 0             dwnfactorn_hvt = 0
+dpnfactorn_hvt = 0             du0n_hvt       = 0             dlu0n_hvt      = -1.55e-11
+dwu0n_hvt      = -9.3e-11      dpu0n_hvt      = 4.0e-18       dvsatn_hvt     = 0
+dlvsatn_hvt    = -3.0e-4       dwvsatn_hvt    = -1e-3         dpvsatn_hvt    = 4.5e-11
+deta0n_hvt     = 0             dleta0n_hvt    = -9e-10        dweta0n_hvt    = 8e-10
+dpeta0n_hvt    = 5e-17         dk2n_hvt       = -0.003        dlk2n_hvt      = 0
+dwk2n_hvt      = -4e-09        dpk2n_hvt      = 0             drdswn_hvt     = 0
+dpclmn_hvt     = 0.02          dpdiblc2n_hvt  = 0             dlpdiblc2n_hvt = 0
+da0n_hvt       = -0.04         dla0n_hvt      = -3.2e-8       dwa0n_hvt      = 1e-7
+dpa0n_hvt      = 0             dvoffn_hvt     = 0             dlvoffn_hvt    = 0
+dwvoffn_hvt    = 0             dpvoffn_hvt    = 0             datn_hvt       = 0
+cfn_hvt        = '1.284e-10 + 5.4e-11*ccoflag_hvt' ss_flag_hvt    = 0             ff_flag_hvt    = 1
+sf_flag_hvt    = 0             fs_flag_hvt    = 0
+toxp_hvt       = 2.733e-09     dxlp_hvt       = -5e-09        dxwp_hvt       = 8e-09
+dvthp_hvt      = 0.02          dlvthp_hvt     = 0.9e-9        dwvthp_hvt     = 1.7e-09
+dpvthp_hvt     = 3e-16         cjp_hvt        = 0.00101463    cjswp_hvt      = 5.952e-11
+cjswgp_hvt     = 2.697e-10     cgop_hvt       = 5.1277503e-11 cglp_hvt       = 5.5687508e-11
+ddlcp_hvt      = 7.35688e-09   dcitp_hvt      = 0             dlcitp_hvt     = -0.6e-10
+dwcitp_hvt     = 3.5e-11       dpcitp_hvt     = -6e-18        ntoxp_hvt      = 2.32
+dnfactorp_hvt  = 0             dlnfactorp_hvt = 0             dwnfactorp_hvt = 0
+dpnfactorp_hvt = 0             du0p_hvt       = 0             dlu0p_hvt      = -4.0e-11
+dwu0p_hvt      = 2e-11         dpu0p_hvt      = 1.3e-17       dvsatp_hvt     = 0
+dlvsatp_hvt    = -0.0008       dwvsatp_hvt    = 0             dpvsatp_hvt    = 0.9e-11
+deta0p_hvt     = 0             dleta0p_hvt    = 0             dweta0p_hvt    = 0
+dpeta0p_hvt    = 0             dk2p_hvt       = -0.003        dlk2p_hvt      = 0
+dwk2p_hvt      = -4e-09        dpk2p_hvt      = 0             drdswp_hvt     = 0
+dpclmp_hvt     = 0             dlpclmp_hvt    = 0             dwpclmp_hvt    = 0
+dppclmp_hvt    = 0             dpdiblc2p_hvt  = 0             da0p_hvt       = 0
+dla0p_hvt      = -0.5e-7       dwa0p_hvt      = 0             dpa0p_hvt      = 0
+dvoffp_hvt     = 0             dlvoffp_hvt    = 0             dwvoffp_hvt    = 0
+dpvoffp_hvt    = 0             datp_hvt       = 0             dubp_hvt       = 0
+dlubp_hvt      = 0.7e-26       dwubp_hvt      = 0             dpubp_hvt      = 1.2e-33
+cfp_hvt            = '1.284e-10 + 5.6e-11*ccoflag_hvt'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MAC_hvt
.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL FF_hvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+A1N_hvt=0.8 A1P_hvt=-0.8 A2N_hvt=0 A2P_hvt=0 A3N_hvt=-1 A3P_hvt=1 A4NP_hvt=0
+toxn_hvt = '2.6e-09 + 6.7000e-011*A4NP_hvt'     dxln_hvt = '5e-009*A2N_hvt'                     dxwn_hvt = '8e-009*A3N_hvt'
+dvthn_hvt = '0.02*A1N_hvt'                      dlvthn_hvt = '8.9e-010*A1N_hvt'                 dwvthn_hvt = '5.6e-009*A1N_hvt'
+dpvthn_hvt = '3.5e-017*A1N_hvt'                 cjn_hvt = '0.001472 * (1+0.070*A1N_hvt)'        cjswn_hvt = '9.5e-11 * (1+0.070*A1N_hvt)'
+cjswgn_hvt = '2.59e-10 * (1+0.070*A1N_hvt)'     cgon_hvt = '7.89886e-11 * (1-0.070*A4NP_hvt)'   cgln_hvt = '1.55225e-12 * (1-0.070*A4NP_hvt)'
+ddlcn_hvt = 6.6302e-09                          dcitn_hvt = 0                                   dlcitn_hvt = '6e-011*A1N_hvt'
+dwcitn_hvt = '-2.5e-010*A1N_hvt'                dpcitn_hvt = '3.5e-017*A1N_hvt'                 ntoxn_hvt = '1 + -6.3000e-001*A4NP_hvt'
+dnfactorn_hvt = 0                               dlnfactorn_hvt = 0                              dwnfactorn_hvt = 0
+dpnfactorn_hvt = 0                              du0n_hvt = 0                                    dlu0n_hvt = '1.55e-011*A1N_hvt'
+dwu0n_hvt = '9.3e-011*A1N_hvt'                  dpu0n_hvt = '-4e-018*A1N_hvt'                   dvsatn_hvt = 0
+dlvsatn_hvt = '0.0003*A1N_hvt'                  dwvsatn_hvt = '0.001*A1N_hvt'                   dpvsatn_hvt = '-4.5e-011*A1N_hvt'
+deta0n_hvt = 0                                  dleta0n_hvt = '9e-010*A1N_hvt'                  dweta0n_hvt = '-8e-010*A1N_hvt'
+dpeta0n_hvt = '-5e-017*A1N_hvt'                 dk2n_hvt = '0.003*A1N_hvt'                      dlk2n_hvt = 0
+dwk2n_hvt = '4e-009*A1N_hvt'                    dpk2n_hvt = 0                                   drdswn_hvt = 0
+dpclmn_hvt = '-0.02*A1N_hvt'                    dpdiblc2n_hvt = 0                               dlpdiblc2n_hvt = 0
+da0n_hvt = '0.04*A1N_hvt'                       dla0n_hvt = '3.2e-008*A1N_hvt'                  dwa0n_hvt = '-1e-007*A1N_hvt'
+dpa0n_hvt = 0                                   dvoffn_hvt = 0                                  dlvoffn_hvt = 0
+dwvoffn_hvt = 0                                 dpvoffn_hvt = 0                                 datn_hvt = 0
+cfn_hvt = '1.20e-10*(1-0.070*A4NP_hvt)+5.4e-11*ccoflag_hvt'
+ss_flag_hvt = 0                                 ff_flag_hvt = 0                                 sf_flag_hvt = 0
+fs_flag_hvt = 0
+toxp_hvt = '2.8e-09 + 6.7000e-011*A4NP_hvt'     dxlp_hvt = '5e-009*A2P_hvt'                     dxwp_hvt = '8e-009*A3P_hvt'
+dvthp_hvt = '-0.02*A1P_hvt'                     dlvthp_hvt = '-9e-010*A1P_hvt'                  dwvthp_hvt = '-1.7e-009*A1P_hvt'
+dpvthp_hvt = '-3e-016*A1P_hvt'                  cjp_hvt = '0.001091 * (1+0.070*A1P_hvt)'        cjswp_hvt = '6.4e-11 * (1+0.070*A1P_hvt)'
+cjswgp_hvt = '2.9e-10 * (1+0.070*A1P_hvt)'      cgop_hvt = '4.79229e-11 * (1-0.070*A4NP_hvt)'   cglp_hvt = '5.20444e-11 * (1-0.070*A4NP_hvt)'
+ddlcp_hvt = 7.35688e-09                         dcitp_hvt = 0                                   dlcitp_hvt = '6e-011*A1P_hvt'
+dwcitp_hvt = '-3.5e-011*A1P_hvt'                dpcitp_hvt = '6e-018*A1P_hvt'                   ntoxp_hvt = '1 + -1.3200e+000*A4NP_hvt'
+dnfactorp_hvt = 0                               dlnfactorp_hvt = 0                              dwnfactorp_hvt = 0
+dpnfactorp_hvt = 0                              du0p_hvt = 0                                    dlu0p_hvt = '4e-011*A1P_hvt'
+dwu0p_hvt = '-2e-011*A1P_hvt'                   dpu0p_hvt = '-1.3e-017*A1P_hvt'                 dvsatp_hvt = 0
+dlvsatp_hvt = '0.0008*A1P_hvt'                  dwvsatp_hvt = 0                                 dpvsatp_hvt = '-9e-012*A1P_hvt'
+deta0p_hvt = 0                                  dleta0p_hvt = 0                                 dweta0p_hvt = 0
+dpeta0p_hvt = 0                                 dk2p_hvt = '0.003*A1P_hvt'                      dlk2p_hvt = 0
+dwk2p_hvt = '4e-009*A1P_hvt'                    dpk2p_hvt = 0                                   drdswp_hvt = 0
+dpclmp_hvt = 0                                  dlpclmp_hvt = 0                                 dwpclmp_hvt = 0
+dppclmp_hvt = 0                                 dpdiblc2p_hvt = 0                               da0p_hvt = 0
+dla0p_hvt = '5e-008*A1P_hvt'                    dwa0p_hvt = 0                                   dpa0p_hvt = 0
+dvoffp_hvt = 0                                  dlvoffp_hvt = 0                                 dwvoffp_hvt = 0
+dpvoffp_hvt = 0                                 datp_hvt = 0                                    dubp_hvt = 0
+dlubp_hvt = '-7e-027*A1P_hvt'                   dwubp_hvt = 0                                   dpubp_hvt = '-1.2e-033*A1P_hvt'
+cfp_hvt = '1.20e-10*(1-0.070*A4NP_hvt)+5.6e-11*ccoflag_hvt'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MAC_hvt
.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL SF_hvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_hvt
.lib 'crn65lp_v1d5.l' noiseflag_hvt
.lib 'crn65lp_v1d5.l' post_simu_hvt
.param
+parn1_hvt=AGAUSS(0,1,1)
+parn2_hvt=AGAUSS(0,1,1)
+parp1_hvt=AGAUSS(0,1,1)
+parp2_hvt=AGAUSS(0,1,1)
+A1N_hvt=-0.8 A1P_hvt=0.8 A2N_hvt=0 A2P_hvt=0 A3N_hvt=1 A3P_hvt=-1 A4NP_hvt=0
+toxn_hvt = '2.6e-09 + 6.7000e-011*A4NP_hvt'     dxln_hvt = '5e-009*A2N_hvt'                     dxwn_hvt = '8e-009*A3N_hvt'
+dvthn_hvt = '0.02*A1N_hvt'                      dlvthn_hvt = '8.9e-010*A1N_hvt'                 dwvthn_hvt = '5.6e-009*A1N_hvt'
+dpvthn_hvt = '3.5e-017*A1N_hvt'                 cjn_hvt = '0.001472 * (1+0.070*A1N_hvt)'        cjswn_hvt = '9.5e-11 * (1+0.070*A1N_hvt)'
+cjswgn_hvt = '2.59e-10 * (1+0.070*A1N_hvt)'     cgon_hvt = '7.89886e-11 * (1-0.070*A4NP_hvt)'   cgln_hvt = '1.55225e-12 * (1-0.070*A4NP_hvt)'
+ddlcn_hvt = 6.6302e-09                          dcitn_hvt = 0                                   dlcitn_hvt = '6e-011*A1N_hvt'
+dwcitn_hvt = '-2.5e-010*A1N_hvt'                dpcitn_hvt = '3.5e-017*A1N_hvt'                 ntoxn_hvt = '1 + -6.3000e-001*A4NP_hvt'
+dnfactorn_hvt = 0                               dlnfactorn_hvt = 0                              dwnfactorn_hvt = 0
+dpnfactorn_hvt = 0                              du0n_hvt = 0                                    dlu0n_hvt = '1.55e-011*A1N_hvt'
+dwu0n_hvt = '9.3e-011*A1N_hvt'                  dpu0n_hvt = '-4e-018*A1N_hvt'                   dvsatn_hvt = 0
+dlvsatn_hvt = '0.0003*A1N_hvt'                  dwvsatn_hvt = '0.001*A1N_hvt'                   dpvsatn_hvt = '-4.5e-011*A1N_hvt'
+deta0n_hvt = 0                                  dleta0n_hvt = '9e-010*A1N_hvt'                  dweta0n_hvt = '-8e-010*A1N_hvt'
+dpeta0n_hvt = '-5e-017*A1N_hvt'                 dk2n_hvt = '0.003*A1N_hvt'                      dlk2n_hvt = 0
+dwk2n_hvt = '4e-009*A1N_hvt'                    dpk2n_hvt = 0                                   drdswn_hvt = 0
+dpclmn_hvt = '-0.02*A1N_hvt'                    dpdiblc2n_hvt = 0                               dlpdiblc2n_hvt = 0
+da0n_hvt = '0.04*A1N_hvt'                       dla0n_hvt = '3.2e-008*A1N_hvt'                  dwa0n_hvt = '-1e-007*A1N_hvt'
+dpa0n_hvt = 0                                   dvoffn_hvt = 0                                  dlvoffn_hvt = 0
+dwvoffn_hvt = 0                                 dpvoffn_hvt = 0                                 datn_hvt = 0
+cfn_hvt = '1.20e-10*(1-0.070*A4NP_hvt)+5.4e-11*ccoflag_hvt'
+ss_flag_hvt = 0                                 ff_flag_hvt = 0                                 sf_flag_hvt = 0
+fs_flag_hvt = 0
+toxp_hvt = '2.8e-09 + 6.7000e-011*A4NP_hvt'     dxlp_hvt = '5e-009*A2P_hvt'                     dxwp_hvt = '8e-009*A3P_hvt'
+dvthp_hvt = '-0.02*A1P_hvt'                     dlvthp_hvt = '-9e-010*A1P_hvt'                  dwvthp_hvt = '-1.7e-009*A1P_hvt'
+dpvthp_hvt = '-3e-016*A1P_hvt'                  cjp_hvt = '0.001091 * (1+0.070*A1P_hvt)'        cjswp_hvt = '6.4e-11 * (1+0.070*A1P_hvt)'
+cjswgp_hvt = '2.9e-10 * (1+0.070*A1P_hvt)'      cgop_hvt = '4.79229e-11 * (1-0.070*A4NP_hvt)'   cglp_hvt = '5.20444e-11 * (1-0.070*A4NP_hvt)'
+ddlcp_hvt = 7.35688e-09                         dcitp_hvt = 0                                   dlcitp_hvt = '6e-011*A1P_hvt'
+dwcitp_hvt = '-3.5e-011*A1P_hvt'                dpcitp_hvt = '6e-018*A1P_hvt'                   ntoxp_hvt = '1 + -1.3200e+000*A4NP_hvt'
+dnfactorp_hvt = 0                               dlnfactorp_hvt = 0                              dwnfactorp_hvt = 0
+dpnfactorp_hvt = 0                              du0p_hvt = 0                                    dlu0p_hvt = '4e-011*A1P_hvt'
+dwu0p_hvt = '-2e-011*A1P_hvt'                   dpu0p_hvt = '-1.3e-017*A1P_hvt'                 dvsatp_hvt = 0
+dlvsatp_hvt = '0.0008*A1P_hvt'                  dwvsatp_hvt = 0                                 dpvsatp_hvt = '-9e-012*A1P_hvt'
+deta0p_hvt = 0                                  dleta0p_hvt = 0                                 dweta0p_hvt = 0
+dpeta0p_hvt = 0                                 dk2p_hvt = '0.003*A1P_hvt'                      dlk2p_hvt = 0
+dwk2p_hvt = '4e-009*A1P_hvt'                    dpk2p_hvt = 0                                   drdswp_hvt = 0
+dpclmp_hvt = 0                                  dlpclmp_hvt = 0                                 dwpclmp_hvt = 0
+dppclmp_hvt = 0                                 dpdiblc2p_hvt = 0                               da0p_hvt = 0
+dla0p_hvt = '5e-008*A1P_hvt'                    dwa0p_hvt = 0                                   dpa0p_hvt = 0
+dvoffp_hvt = 0                                  dlvoffp_hvt = 0                                 dwvoffp_hvt = 0
+dpvoffp_hvt = 0                                 datp_hvt = 0                                    dubp_hvt = 0
+dlubp_hvt = '-7e-027*A1P_hvt'                   dwubp_hvt = 0                                   dpubp_hvt = '-1.2e-033*A1P_hvt'
+cfp_hvt = '1.20e-10*(1-0.070*A4NP_hvt)+5.6e-11*ccoflag_hvt'

+ c1fn_hvt=3.0E+42           c2fn_hvt=1.00E+23           c3fn_hvt=1.00E+7                     
+ c1fp_hvt=2.10E+42           c2fp_hvt=1.55E+24           c3fp_hvt=1.00E+10    
+ fn_dice_hvtn='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
+ arearation_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(7.5E-6*1E-6*1))**0.5)))'
+ noian_hvt='c1fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noibn_hvt='c2fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ noicn_hvt='c3fn_hvt*2.718**((fn_dice_hvtn+(1-fn_dice_hvtn)*noiseflagn_hvt)*arearation_hvt)'
+ fn_dice_hvtp='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
+ arearatiop_hvt='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_hvt='c1fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noibp_hvt='c2fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'
+ noicp_hvt='c3fp_hvt*2.718**((fn_dice_hvtp+(1-fn_dice_hvtp)*noiseflagp_hvt)*arearatiop_hvt)'

.lib 'crn65lp_v1d5.l' MAC_hvt
.lib 'crn65lp_v1d5.l' MOS_hvt
.ENDL FS_hvt







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+A1_mlvt='par1*5.6347*3/1.99'
+A2_mlvt='par2*4.0042*3/1.99'
+A3_mlvt='par3*3.6874*3/1.99'
+A4_mlvt='par4*2.1364*3/1.99'
+A5_mlvt='par5*1.0272*3/1.99'
+toxn_mlvt      ='2.6e-09+(4.6487e-012)*A1_mlvt+(-1.0377e-011)*A2_mlvt+(-5.6685e-012)*A3_mlvt+(-5.5834e-012)*A4_mlvt+(9.2037e-013)*A5_mlvt'
+dxln_mlvt      ='-6.000000e-009+(3.2055e-010)*A1_mlvt+(-8.797e-010)*A2_mlvt+(-5.1527e-010)*A3_mlvt+(-4.7864e-010)*A4_mlvt+(8.2509e-011)*A5_mlvt'
+dxwn_mlvt      ='0+(-2.4818e-010)*A1_mlvt+(2.2966e-009)*A2_mlvt+(4.7596e-011)*A3_mlvt+(9.4536e-010)*A4_mlvt+(-1.8637e-010)*A5_mlvt'
+dvthn_mlvt     ='0+(0.0022197)*A1_mlvt+(-0.0015133)*A2_mlvt+(0.0038396)*A3_mlvt+(0.00016367)*A4_mlvt+(-0.00012209)*A5_mlvt'
+dlvthn_mlvt    ='0+(1.5982e-010)*A1_mlvt+(-1.0896e-010)*A2_mlvt+(2.7645e-010)*A3_mlvt+(1.1785e-011)*A4_mlvt+(-8.7906e-012)*A5_mlvt'
+dwvthn_mlvt    ='0+(2.5185e-010)*A1_mlvt+(-1.7035e-010)*A2_mlvt+(4.6206e-010)*A3_mlvt+(-1.0387e-011)*A4_mlvt+(-1.4659e-011)*A5_mlvt'
+dpvthn_mlvt    ='0+(2.115e-017)*A1_mlvt+(-1.4238e-017)*A2_mlvt+(4.0107e-017)*A3_mlvt+(-2.3015e-018)*A4_mlvt+(-1.2708e-018)*A5_mlvt'
+cjn_mlvt       ='0.001251+(7.7749e-006)*A1_mlvt+(-5.3018e-006)*A2_mlvt+(1.3449e-005)*A3_mlvt+(5.7299e-007)*A4_mlvt+(-4.2758e-007)*A5_mlvt'
+cjswn_mlvt     ='9.5e-11+(5.9044e-013)*A1_mlvt+(-4.0255e-013)*A2_mlvt+(1.0213e-012)*A3_mlvt+(4.3537e-014)*A4_mlvt+(-3.2476e-014)*A5_mlvt'
+cjswgn_mlvt    ='2.04e-10+(1.2679e-012)*A1_mlvt+(-8.6443e-013)*A2_mlvt+(2.1932e-012)*A3_mlvt+(9.349e-014)*A4_mlvt+(-6.9739e-014)*A5_mlvt'
+cgon_mlvt      ='8.28670e-11+(-4.0247e-013)*A1_mlvt+(8.9839e-013)*A2_mlvt+(4.9077e-013)*A3_mlvt+(4.834e-013)*A4_mlvt+(-7.9683e-014)*A5_mlvt'
+cgln_mlvt      ='9.96116e-12+(-4.8378e-014)*A1_mlvt+(1.0799e-013)*A2_mlvt+(5.8994e-014)*A3_mlvt+(5.8102e-014)*A4_mlvt+(-9.5786e-015)*A5_mlvt'
+cfn_mlvt       ='1.200000e-010+(-5.8282e-013)*A1_mlvt+(1.301e-012)*A2_mlvt+(7.1068e-013)*A3_mlvt+(7.0001e-013)*A4_mlvt+(-1.1539e-013)*A5_mlvt+4.5e-11*ccoflag_mlvt'
+ntoxn_mlvt     ='1+(-0.049161)*A1_mlvt+(0.097754)*A2_mlvt+(0.050659)*A3_mlvt+(0.032151)*A4_mlvt+(-0.0081093)*A5_mlvt'
+du0n_mlvt      ='0+(2.6636e-005)*A1_mlvt+(-1.816e-005)*A2_mlvt+(4.6076e-005)*A3_mlvt+(1.9641e-006)*A4_mlvt+(-1.4651e-006)*A5_mlvt'
+dlu0n_mlvt     ='0+(4.4394e-012)*A1_mlvt+(-3.0267e-012)*A2_mlvt+(7.6793e-012)*A3_mlvt+(3.2735e-013)*A4_mlvt+(-2.4418e-013)*A5_mlvt'
+dleta0n_mlvt   ='0+(-1.4514e-011)*A1_mlvt+(1.1253e-011)*A2_mlvt+(1.3087e-012)*A3_mlvt+(-3.0028e-011)*A4_mlvt+(-8.0882e-015)*A5_mlvt'
+dpeta0n_mlvt   ='0+(-2.0204e-018)*A1_mlvt+(1.1512e-018)*A2_mlvt+(-7.8974e-018)*A3_mlvt+(4.6773e-018)*A4_mlvt+(2.4553e-019)*A5_mlvt'
+dlvsatn_mlvt   ='0+(2.3721e-005)*A1_mlvt+(-8.8143e-007)*A2_mlvt+(1.0578e-005*0.84)*A3_mlvt+(5.929e-006)*A4_mlvt+(-1.3991e-006)*A5_mlvt'
+dpvsatn_mlvt   ='0+(-3.2327e-013)*A1_mlvt+(1.8419e-013)*A2_mlvt+(-1.2636e-012)*A3_mlvt+(7.4836e-013)*A4_mlvt+(3.9285e-014)*A5_mlvt'
+dk2n_mlvt      ='0+(0.00040353)*A1_mlvt+(-0.00027965)*A2_mlvt+(0.00060998)*A3_mlvt+(0.00012628)*A4_mlvt+(-1.9508e-005)*A5_mlvt'
+dlcitn_mlvt    ='0+(-1.3182e-012)*A1_mlvt+(-5.2657e-012)*A2_mlvt+(-4.6123e-012)*A3_mlvt+(-3.0987e-012)*A4_mlvt+(6.9126e-013)*A5_mlvt'
+dwcitn_mlvt    ='0+(-2.9027e-012)*A1_mlvt+(2.2506e-012)*A2_mlvt+(2.6174e-013)*A3_mlvt+(-6.0055e-012)*A4_mlvt+(-1.6176e-015)*A5_mlvt'
+dlvoffn_mlvt   ='0+(-4.4394e-011)*A1_mlvt+(3.0267e-011)*A2_mlvt+(-7.6793e-011)*A3_mlvt+(-3.2735e-012)*A4_mlvt+(2.4418e-012)*A5_mlvt'
+dpvoffn_mlvt   ='0+(8.4858e-018)*A1_mlvt+(-4.8351e-018)*A2_mlvt+(3.3169e-017)*A3_mlvt+(-1.9645e-017)*A4_mlvt+(-1.0312e-018)*A5_mlvt'
+dla0n_mlvt     ='0+(4.8379e-009)*A1_mlvt+(-3.751e-009)*A2_mlvt+(-4.3623e-010)*A3_mlvt+(1.0009e-008)*A4_mlvt+(2.6961e-012)*A5_mlvt'
+ss_flag_mlvt   ='0+(0.048379)*A1_mlvt+(-0.03751)*A2_mlvt+(-0.0043623)*A3_mlvt+(0.10009)*A4_mlvt+(2.6961e-005)*A5_mlvt'
+ff_flag_mlvt   ='0+(-0.047369)*A1_mlvt+(0.012053)*A2_mlvt+(-0.012002)*A3_mlvt+(0.12145)*A4_mlvt+(0.00011527)*A5_mlvt'
+sf_flag_mlvt   ='0+(-0.013094)*A1_mlvt+(-0.035826)*A2_mlvt+(0.065008)*A3_mlvt+(-0.0468)*A4_mlvt+(-0.21631)*A5_mlvt'
+fs_flag_mlvt   ='0+(0.012084)*A1_mlvt+(0.04371)*A2_mlvt+(-0.05977)*A3_mlvt+(-0.04295)*A4_mlvt+(-0.21896)*A5_mlvt'
+toxp_mlvt      ='2.8e-09+(4.6487e-012)*A1_mlvt+(-1.0377e-011)*A2_mlvt+(-5.6685e-012)*A3_mlvt+(-5.5834e-012)*A4_mlvt+(9.2037e-013)*A5_mlvt'
+dxlp_mlvt      ='max(-16e-9,-6.000000e-009+(3.2055e-010)*A1_mlvt+(-8.797e-010)*A2_mlvt+(-5.1527e-010)*A3_mlvt+(-4.7864e-010)*A4_mlvt+(8.2509e-011)*A5_mlvt)'
+dxwp_mlvt      ='0+(-6.5104e-010)*A1_mlvt+(1.024e-009)*A2_mlvt+(2.044e-009)*A3_mlvt+(8.8377e-010)*A4_mlvt+(-1.4402e-010)*A5_mlvt'
+dvthp_mlvt     ='0+(-0.0030978)*A1_mlvt+(-0.0016014)*A2_mlvt+(0.0011054)*A3_mlvt+(-0.00030495)*A4_mlvt+(0.00021883)*A5_mlvt'
+dlvthp_mlvt    ='0+(-9.2761e-011)*A1_mlvt+(-1.9819e-011)*A2_mlvt+(2.7296e-011)*A3_mlvt+(-5.203e-011)*A4_mlvt+(5.0028e-012)*A5_mlvt'
+dwvthp_mlvt    ='0+(-4.6791e-010)*A1_mlvt+(-3.044e-010)*A2_mlvt+(1.7988e-010)*A3_mlvt+(4.9267e-011)*A4_mlvt+(3.6499e-011)*A5_mlvt'
+dpvthp_mlvt    ='max(-2.4e-16,0+(-3.5336e-017)*A1_mlvt+(-2.2643e-017)*A2_mlvt+(1.3513e-017)*A3_mlvt+(3.1945e-018)*A4_mlvt+(2.7373e-018)*A5_mlvt)'
+cjp_mlvt       ='0.001077+(9.7309e-006)*A1_mlvt+(5.0307e-006)*A2_mlvt+(-3.4717e-006)*A3_mlvt+(9.5824e-007)*A4_mlvt+(-6.8748e-007)*A5_mlvt'
+cjswp_mlvt     ='7.5e-11+(6.7764e-013)*A1_mlvt+(3.503e-013)*A2_mlvt+(-2.4181e-013)*A3_mlvt+(6.6709e-014)*A4_mlvt+(-4.787e-014)*A5_mlvt'
+cjswgp_mlvt    ='2.2e-10+(1.9877e-012)*A1_mlvt+(1.0275e-012)*A2_mlvt+(-7.0932e-013)*A3_mlvt+(1.9568e-013)*A4_mlvt+(-1.4042e-013)*A5_mlvt'
+cgop_mlvt      ='7.70111e-11+(-3.7403e-013)*A1_mlvt+(8.3491e-013)*A2_mlvt+(4.5609e-013)*A3_mlvt+(4.4924e-013)*A4_mlvt+(-7.4052e-014)*A5_mlvt'
+cglp_mlvt      ='2.69027e-11+(-1.3066e-013)*A1_mlvt+(2.9166e-013)*A2_mlvt+(1.5933e-013)*A3_mlvt+(1.5693e-013)*A4_mlvt+(-2.5869e-014)*A5_mlvt'
+cfp_mlvt       ='1.200000e-010+(-5.8282e-013)*A1_mlvt+(1.301e-012)*A2_mlvt+(7.1068e-013)*A3_mlvt+(7.0001e-013)*A4_mlvt+(-1.1539e-013)*A5_mlvt+5.6e-11*ccoflag_mlvt'
+drdswp_mlvt    ='0+(-2.5815)*A1_mlvt+(-1.3345)*A2_mlvt+(0.9212)*A3_mlvt+(-0.25413)*A4_mlvt+(0.18236)*A5_mlvt'
+ntoxp_mlvt     ='1+(-0.14472)*A1_mlvt+(0.24058)*A2_mlvt+(0.11255)*A3_mlvt+(-0.011274)*A4_mlvt+(-0.017477)*A5_mlvt'
+du0p_mlvt      ='0+(5.1629e-005)*A1_mlvt+(2.6689e-005)*A2_mlvt+(-1.8424e-005)*A3_mlvt+(5.0826e-006)*A4_mlvt+(-3.6472e-006)*A5_mlvt'
+dlu0p_mlvt     ='0+(-4.1497e-012)*A1_mlvt+(-3.9013e-012)*A2_mlvt+(4.5378e-012)*A3_mlvt+(-4.447e-013)*A4_mlvt+(3.1606e-013)*A5_mlvt'
+dwu0p_mlvt     ='0+(-8.0694e-013)*A1_mlvt+(-1.0423e-012)*A2_mlvt+(4.1697e-013)*A3_mlvt+(8.7386e-013)*A4_mlvt+(9.1451e-014)*A5_mlvt'
+dpu0p_mlvt     ='0+(1.2907e-018)*A1_mlvt+(6.6724e-019)*A2_mlvt+(-4.606e-019)*A3_mlvt+(1.2706e-019)*A4_mlvt+(-9.1181e-020)*A5_mlvt'
+dleta0p_mlvt   ='0+(-4.356e-011)*A1_mlvt+(-1.6266e-011)*A2_mlvt+(1.4254e-011)*A3_mlvt+(-1.3821e-011)*A4_mlvt+(2.7327e-012)*A5_mlvt'
+dpeta0p_mlvt   ='0+(-8.3888e-018)*A1_mlvt+(-1.8358e-018)*A2_mlvt+(2.4775e-018)*A3_mlvt+(-4.639e-018)*A4_mlvt+(4.5483e-019)*A5_mlvt'
+dlvsatp_mlvt   ='max(-0.002,0+(0.00022021)*A1_mlvt+(5.4443e-005)*A2_mlvt+(-6.6325e-005)*A3_mlvt+(0.00011224)*A4_mlvt+(-1.2284e-005)*A5_mlvt)'
+dwvsatp_mlvt   ='max(-0.0030,0+(-0.00015332)*A1_mlvt+(-0.00019804*0.3)*A2_mlvt+(7.9225e-005)*A3_mlvt+(0.00016603)*A4_mlvt+(1.7376e-005)*A5_mlvt)'
+dpvsatp_mlvt   ='0+(7.3376e-012)*A1_mlvt+(-5.5223e-012)*A2_mlvt+(-6.9604e-013)*A3_mlvt+(1.4926e-011)*A4_mlvt+(-5.101e-015)*A5_mlvt'
+dk2p_mlvt      ='0+(0.0010326)*A1_mlvt+(0.00053379)*A2_mlvt+(-0.00036848)*A3_mlvt+(0.00010165)*A4_mlvt+(-7.2945e-005)*A5_mlvt'
+dlcitp_mlvt    ='0+(1.3182e-012)*A1_mlvt+(5.2657e-012)*A2_mlvt+(4.6123e-012)*A3_mlvt+(3.0987e-012)*A4_mlvt+(-6.9126e-013)*A5_mlvt'
+dlvoffp_mlvt   ='0+(4.0347e-011)*A1_mlvt+(5.2117e-011)*A2_mlvt+(-2.0849e-011)*A3_mlvt+(-4.3693e-011)*A4_mlvt+(-4.5725e-012)*A5_mlvt'
+dnfactorp_mlvt ='0+(-0.0056486)*A1_mlvt+(-0.0072963)*A2_mlvt+(0.0029188)*A3_mlvt+(0.006117)*A4_mlvt+(0.00064015)*A5_mlvt'
+dlnfactorp_mlvt='max(-0.68e-8,0+(-1.969e-009)*A1_mlvt+(-1.192e-009)*A2_mlvt+(-2.4126e-010)*A3_mlvt+(1.0586e-009)*A4_mlvt+(1.7554e-010)*A5_mlvt)'
+dpnfactorp_mlvt='max(-2e-15,0+(-3.7542e-016)*A1_mlvt+(-2.5175e-016)*A2_mlvt+(-3.6037e-016)*A3_mlvt+(5.6089e-016)*A4_mlvt+(4.3573e-017)*A5_mlvt)'
+dlk2p_mlvt     ='0+(-4.8379e-012)*A1_mlvt+(3.751e-012)*A2_mlvt+(4.3623e-013)*A3_mlvt+(-1.0009e-011)*A4_mlvt+(-2.6961e-015)*A5_mlvt'
+dwk2p_mlvt     ='0+(1.1617e-010)*A1_mlvt+(6.0051e-011)*A2_mlvt+(-4.1454e-011)*A3_mlvt+(1.1436e-011)*A4_mlvt+(-8.2063e-012)*A5_mlvt'
+dpk2p_mlvt     ='0+(2.9046e-018)*A1_mlvt+(2.7519e-018)*A2_mlvt+(-1.2945e-018)*A3_mlvt+(-1.6207e-018)*A4_mlvt+(-2.7408e-019)*A5_mlvt'
+dpdiblc2p_mlvt ='max(-0.0003,0+(-4.8441e-005)*A1_mlvt+(-3.2484e-005)*A2_mlvt+(-4.65e-005)*A3_mlvt+(7.2372e-005)*A4_mlvt+(5.6223e-006)*A5_mlvt)'
+datp_mlvt      ='0+(-1562.4)*A1_mlvt+(192.29)*A2_mlvt+(1267.6)*A3_mlvt+(-1927.9)*A4_mlvt+(4203.3)*A5_mlvt'
+dlatp_mlvt     ='0+(-0.00028411)*A1_mlvt+(-0.00027706)*A2_mlvt+(-2.4475e-005)*A3_mlvt+(0.0002121)*A4_mlvt+(-0.00066409)*A5_mlvt'
+dpatp_mlvt     ='0+(2.1308e-011)*A1_mlvt+(2.078e-011)*A2_mlvt+(1.8356e-012)*A3_mlvt+(-1.5908e-011)*A4_mlvt+(4.9807e-011)*A5_mlvt'
+ddlcn_mlvt     =7.27377e-09
+drdswn_mlvt    =0
+dwu0n_mlvt     =0
+dpu0n_mlvt     =0
+deta0n_mlvt    =0
+dweta0n_mlvt   =0
+dvsatn_mlvt    =0
+dwvsatn_mlvt   =0
+dwvoffn_mlvt   =0
+dnfactorn_mlvt =0
+dwnfactorn_mlvt=0
+dlnfactorn_mlvt=0
+dpnfactorn_mlvt=0
+dpdiblc2n_mlvt =0
+ddlcp_mlvt     =8.26573e-09
+deta0p_mlvt    =0
+dweta0p_mlvt   =0
+dvsatp_mlvt    =0
+dwcitp_mlvt    =0
+dpcitp_mlvt    =0
+dwvoffp_mlvt   =0
+dpvoffp_mlvt   =0
+dwnfactorp_mlvt=0
+dlpclmp_mlvt   =0
+dppclmp_mlvt   =0
+dwatp_mlvt     =0
         
+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' mos_mlvt
.ENDL mc_mlvt








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+toxn_mlvt           = 2.6e-09       dxln_mlvt           = '0-6e-09'             dxwn_mlvt           = 0
+dvthn_mlvt          = 0             dlvthn_mlvt         = 0             dwvthn_mlvt         = 0
+dpvthn_mlvt         = 0             cjn_mlvt            = 0.001251      cjswn_mlvt          = 9.5e-11
+cjswgn_mlvt         = 2.04e-10      cgon_mlvt           = 8.28670e-11   cgln_mlvt           = 9.96116e-12
+ddlcn_mlvt          = 7.27377e-09   cfn_mlvt            = '1.20e-10 + 4.5e-11*ccoflag_mlvt' drdswn_mlvt         = 0
+ntoxn_mlvt          = 1             du0n_mlvt           = 0             dlu0n_mlvt          = 0
+dwu0n_mlvt          = 0             dpu0n_mlvt          = 0             deta0n_mlvt         = 0
+dleta0n_mlvt        = 0             dweta0n_mlvt        = 0             dpeta0n_mlvt        = 0
+dvsatn_mlvt         = 0             dlvsatn_mlvt        = 0             dwvsatn_mlvt        = 0
+dpvsatn_mlvt        = 0             dk2n_mlvt           = 0             dlcitn_mlvt         = 0
+dwcitn_mlvt         = 0             dlvoffn_mlvt         = 0             dwvoffn_mlvt         = 0
+dpvoffn_mlvt         = 0             dnfactorn_mlvt      = 0             dwnfactorn_mlvt     = 0
+dlnfactorn_mlvt     = 0             dpnfactorn_mlvt     = 0             dpdiblc2n_mlvt      = 0
+dla0n_mlvt          = 0             ss_flag_mlvt        = 0             ff_flag_mlvt        = 0
+sf_flag_mlvt        = 0             fs_flag_mlvt        = 0
+toxp_mlvt           = 2.8e-09       dxlp_mlvt           = '0-6e-9'             dxwp_mlvt           = 0
+dvthp_mlvt          = 0             dlvthp_mlvt         = 0             dwvthp_mlvt         = 0
+dpvthp_mlvt         = 0             cjp_mlvt            = 0.001077      cjswp_mlvt          = 7.5e-11
+cjswgp_mlvt         = 2.2e-10       cgop_mlvt           = 7.70111e-11   cglp_mlvt           = 2.69027e-11
+ddlcp_mlvt          = 8.26573e-09   cfp_mlvt            = '1.20e-10 + 5.6e-11*ccoflag_mlvt' drdswp_mlvt         = 0
+ntoxp_mlvt          = 1             du0p_mlvt           = 0             dlu0p_mlvt          = 0
+dwu0p_mlvt          = 0             dpu0p_mlvt          = 0             deta0p_mlvt         = 0
+dleta0p_mlvt        = 0             dweta0p_mlvt        = 0             dpeta0p_mlvt        = 0
+dvsatp_mlvt         = 0             dlvsatp_mlvt        = 0             dwvsatp_mlvt        = 0
+dpvsatp_mlvt        = 0             dk2p_mlvt           = 0             dlcitp_mlvt         = 0
+dwcitp_mlvt         = 0             dpcitp_mlvt         = 0             dlvoffp_mlvt        = 0
+dwvoffp_mlvt        = 0             dpvoffp_mlvt        = 0             dnfactorp_mlvt      = 0
+dlnfactorp_mlvt     = 0             dwnfactorp_mlvt     = 0             dpnfactorp_mlvt     = 0
+dlk2p_mlvt          = 0             dwk2p_mlvt          = 0             dpk2p_mlvt          = 0
+dpdiblc2p_mlvt      = 0
+dlpclmp_mlvt        = 0             dppclmp_mlvt         = 0
+datp_mlvt           = 0
+dlatp_mlvt          = 0
+dwatp_mlvt          = 0
+dpatp_mlvt          = 0

+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' MAC_mlvt
.lib 'crn65lp_v1d5.l' MOS_mlvt
.ENDL TT_mlvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+toxn_mlvt           = 2.667e-09     dxln_mlvt           = '5e-09-6e-09'         dxwn_mlvt           = -8e-09
+dvthn_mlvt          = 0.025         dlvthn_mlvt         = 1.8e-09       dwvthn_mlvt         = 2.7e-09
+dpvthn_mlvt         = 2.2e-16       cjn_mlvt            = 0.00133857    cjswn_mlvt          = 1.0165e-10
+cjswgn_mlvt         = 2.1828e-10    cgon_mlvt           = 7.70663e-11   cgln_mlvt           = 9.26388e-12
+ddlcn_mlvt          = 7.27377e-09   cfn_mlvt            = '1.1160e-10 + 4.5e-11*ccoflag_mlvt' drdswn_mlvt         = 0
+ntoxn_mlvt          = 0.24          du0n_mlvt           = 3.0e-04       dlu0n_mlvt          = 5.0e-011
+dwu0n_mlvt          = 0.0e-10       dpu0n_mlvt          = -0.0e-17      deta0n_mlvt         = 0
+dleta0n_mlvt        = -0.3e-09      dweta0n_mlvt        = -0.0e-10      dpeta0n_mlvt        = -0.0e-16
+dvsatn_mlvt         = -0.0e04       dlvsatn_mlvt        = 0.24e-03       dwvsatn_mlvt        = 0
+dpvsatn_mlvt        = 0.0e-11       dk2n_mlvt           = 0.005         dlcitn_mlvt         = -0e-11
+dwcitn_mlvt         = -6e-11        dlvoffn_mlvt         = -5.0e-10      dwvoffn_mlvt         = 0
+dpvoffn_mlvt         = 0             dnfactorn_mlvt      = -0.0e-2       dwnfactorn_mlvt     = 0
+dlnfactorn_mlvt     = -0.0e-08      dpnfactorn_mlvt     = -0.0e-15      dpdiblc2n_mlvt      = 0
+dla0n_mlvt          = 10e-08             ss_flag_mlvt        = 1             ff_flag_mlvt        = 0
+sf_flag_mlvt        = 0             fs_flag_mlvt        = 0
+toxp_mlvt           = 2.867e-09     dxlp_mlvt           = '5e-09-6e-9'  dxwp_mlvt           = -8e-09
+dvthp_mlvt          = -0.024        dlvthp_mlvt         = -10e-10       dwvthp_mlvt         = -3.0e-09
+dpvthp_mlvt         = -2.3e-16      cjp_mlvt            = 0.00115239    cjswp_mlvt          = 8.025e-11
+cjswgp_mlvt         = 2.354e-10     cgop_mlvt           = 7.16203e-11   cglp_mlvt           = 2.50195e-11
+ddlcp_mlvt          = 8.26573e-09   cfp_mlvt            = '1.1160e-10 + 5.6e-11*ccoflag_mlvt' drdswp_mlvt         = -20
+ntoxp_mlvt          = -1.44         du0p_mlvt           = 0.0004        dlu0p_mlvt          = -2.7e-11
+dwu0p_mlvt          = 0             dpu0p_mlvt          = 1e-17         deta0p_mlvt         = 0
+dleta0p_mlvt        = -0.4e-9       dweta0p_mlvt        = 0             dpeta0p_mlvt        = -9e-17
+dvsatp_mlvt         = 0             dlvsatp_mlvt        = 0.0023        dwvsatp_mlvt        = -0.000
+dpvsatp_mlvt        = 15e-11        dk2p_mlvt           = 0.008         dlcitp_mlvt         = 0
+dwcitp_mlvt         = 0             dpcitp_mlvt         = 0             dlvoffp_mlvt        = 0
+dwvoffp_mlvt        = 0             dpvoffp_mlvt        = 0             dnfactorp_mlvt      = 0
+dlnfactorp_mlvt     = -9e-09        dwnfactorp_mlvt     = 0             dpnfactorp_mlvt     = 0
+dlk2p_mlvt          = -1.0e-10      dwk2p_mlvt          = 9e-10         dpk2p_mlvt          = 1e-17
+dpdiblc2p_mlvt      = 0
+dlpclmp_mlvt        = 0e-7          dppclmp_mlvt        = 0
+datp_mlvt           = -27500
+dlatp_mlvt          = 0
+dwatp_mlvt          = 0
+dpatp_mlvt          = 0

+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' MAC_mlvt
.lib 'crn65lp_v1d5.l' MOS_mlvt
.ENDL SS_mlvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+toxn_mlvt           = 2.533e-09     dxln_mlvt           = '-5e-09-6e-09'        dxwn_mlvt           = 8e-09
+dvthn_mlvt          = -0.025        dlvthn_mlvt         = -1.8e-09      dwvthn_mlvt         = -3.0e-09
+dpvthn_mlvt         = -2.6e-16      cjn_mlvt            = 0.00116343    cjswn_mlvt          = 8.835e-11
+cjswgn_mlvt         = 1.8972e-10    cgon_mlvt           = 8.86677e-11   cgln_mlvt           = 1.06584e-11
+ddlcn_mlvt          = 7.27377e-09   cfn_mlvt            = '1.2840e-10 + 4.5e-11*ccoflag_mlvt' drdswn_mlvt         = 0
+ntoxn_mlvt          = 1.59          du0n_mlvt           = -3.0e-04      dlu0n_mlvt          = -5.0e-011
+dwu0n_mlvt          = -0.0e-10      dpu0n_mlvt          = 0.0e-17       deta0n_mlvt         = 0
+dleta0n_mlvt        = -0.0e-9       dweta0n_mlvt        = 0.0e-09       dpeta0n_mlvt        = 0.5e-16
+dvsatn_mlvt         = 0.0e4         dlvsatn_mlvt        = -0.2e-03      dwvsatn_mlvt        = 0.0e-03
+dpvsatn_mlvt        = 0.8e-11       dk2n_mlvt           = -0.004        dlcitn_mlvt         = 0
+dwcitn_mlvt         = 0             dlvoffn_mlvt         = 5.0e-10      dwvoffn_mlvt         = 0
+dpvoffn_mlvt         = -2.1e-16             dnfactorn_mlvt      = 0             dwnfactorn_mlvt     = 0e-08
+dlnfactorn_mlvt     = 0.0e-08       dpnfactorn_mlvt     = 0.0e-14       dpdiblc2n_mlvt      = 0
+dla0n_mlvt          = -0e-08        ss_flag_mlvt        = 0             ff_flag_mlvt        = 1
+sf_flag_mlvt        = 0             fs_flag_mlvt        = 0
+toxp_mlvt           = 2.733e-09     dxlp_mlvt           = '-5e-09-6e-9' dxwp_mlvt           = 8e-09
+dvthp_mlvt          = 0.024         dlvthp_mlvt         = 5.5e-10       dwvthp_mlvt         = 4e-09
+dpvthp_mlvt         = 3e-16         cjp_mlvt            = 0.00100161    cjswp_mlvt          = 6.975e-11
+cjswgp_mlvt         = 2.046e-10     cgop_mlvt           = 8.24019e-11   cglp_mlvt           = 2.87859e-11
+ddlcp_mlvt          = 8.26573e-09   cfp_mlvt            = '1.2840e-10 + 5.6e-11*ccoflag_mlvt' drdswp_mlvt         = 20
+ntoxp_mlvt          = 2.27          du0p_mlvt           = -0.0004       dlu0p_mlvt          = 2.7e-11
+dwu0p_mlvt          = 1e-11         dpu0p_mlvt          = -1e-17        deta0p_mlvt         = 0
+dleta0p_mlvt        = 3e-10         dweta0p_mlvt        = 0             dpeta0p_mlvt        = 5e-17
+dvsatp_mlvt         = 0             dlvsatp_mlvt        = -0.00135      dwvsatp_mlvt        = 0.0019
+dpvsatp_mlvt        = -1e-12        dk2p_mlvt           = -0.008        dlcitp_mlvt         = 0
+dwcitp_mlvt         = 0             dpcitp_mlvt         = 0             dlvoffp_mlvt        = -5e-10
+dwvoffp_mlvt        = 0             dpvoffp_mlvt        = 0             dnfactorp_mlvt      = 0.07
+dlnfactorp_mlvt     = 2.2e-8        dwnfactorp_mlvt     = 0             dpnfactorp_mlvt     = 6.2e-15
+dlk2p_mlvt          = 0             dwk2p_mlvt          = -9e-10        dpk2p_mlvt          = -3e-17
+dpdiblc2p_mlvt      = 0.0008
+dlpclmp_mlvt        = 0             dppclmp_mlvt        = 0
+datp_mlvt           = 27500
+dlatp_mlvt          = 0
+dwatp_mlvt          = 0
+dpatp_mlvt          = 0

+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' MAC_mlvt
.lib 'crn65lp_v1d5.l' MOS_mlvt
.ENDL FF_mlvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+A1N_mlvt=0.8 A1P_mlvt=-0.8 A2N_mlvt=0 A2P_mlvt=0 A3N_mlvt=-1 A3P_mlvt=1 A4NP_mlvt=0
+toxn_mlvt = '2.6e-09 + 6.7000e-011*A4NP_mlvt'     dxln_mlvt = '(-5e-009*A2N_mlvt)-6e-09'                     dxwn_mlvt = '8e-009*A3N_mlvt'
+dvthn_mlvt = '0.025*A1N_mlvt'                     dlvthn_mlvt = '1.8e-009*A1N_mlvt'                 dwvthn_mlvt = '3e-009*A1N_mlvt'
+dpvthn_mlvt = '2.6e-016*A1N_mlvt'                 cjn_mlvt = '0.001251 * (1+0.070*A1N_mlvt)'        cjswn_mlvt = '9.5e-11 * (1+0.070*A1N_mlvt)'
+cjswgn_mlvt = '2.04e-10 * (1+0.070*A1N_mlvt)'     cgon_mlvt = '8.28670e-11 * (1-0.070*A4NP_mlvt)'   cgln_mlvt = '9.96116e-12 * (1-0.070*A4NP_mlvt)'
+ddlcn_mlvt = 7.27377e-09
+cfn_mlvt = '1.20e-10*(1-0.070*A4NP_mlvt)+4.5e-11*ccoflag_mlvt'
+drdswn_mlvt = 0                              ntoxn_mlvt = '1 + -5.9000e-001*A4NP_mlvt'         du0n_mlvt = '0.0003*A1N_mlvt'
+dlu0n_mlvt = '5e-011*A1N_mlvt'                    dwu0n_mlvt = '0.0e-011*A1N_mlvt'                  dpu0n_mlvt = '0.0e-017*A1N_mlvt'
+deta0n_mlvt = 0                              dleta0n_mlvt = '-0e-010*A1N_mlvt'                 dweta0n_mlvt = '-0e-009*A1N_mlvt'
+dpeta0n_mlvt = '-0.5e-016*A1N_mlvt'               dvsatn_mlvt = '-0.0e4*A1N_mlvt'                   dlvsatn_mlvt = '0.000*A1N_mlvt'
+dwvsatn_mlvt = '0*A1N_mlvt'                       dpvsatn_mlvt = '-8e-012*A1N_mlvt'                 dk2n_mlvt = '0.004*A1N_mlvt'
+dlcitn_mlvt = 0                              dwcitn_mlvt = 0                              dlvoffn_mlvt = '-5e-010*A1N_mlvt'
+dwvoffn_mlvt = 0                             dpvoffn_mlvt = '2.1e-016*A1N_mlvt'                dnfactorn_mlvt = 0
+dwnfactorn_mlvt = '0*A1N_mlvt'                    dlnfactorn_mlvt = '-0.0e-008*A1N_mlvt'            dpnfactorn_mlvt = '-0e-014*A1N_mlvt'
+dpdiblc2n_mlvt = 0                           dla0n_mlvt = 0                               ss_flag_mlvt = 0
+ff_flag_mlvt = 0                             sf_flag_mlvt = 1                             fs_flag_mlvt = 0
+A1N_mlvt_mlvt=0.8 A1P_mlvt_mlvt=-0.8 A2N_mlvt_mlvt=0 A2P_mlvt_mlvt=0 A3N_mlvt_mlvt=-1 A3P_mlvt_mlvt=1 A4NP_mlvt_mlvt=0
+toxp_mlvt = '2.8e-09 + 6.7000e-11*A4NP_mlvt_mlvt'      dxlp_mlvt = '5e-09*A2P_mlvt_mlvt-6e-9'                 dxwp_mlvt = '8e-09*A3P_mlvt_mlvt'
+dvthp_mlvt = '-0.024*A1P_mlvt_mlvt'                    dlvthp_mlvt = '-5.5e-10*A1P_mlvt_mlvt'                 dwvthp_mlvt = '-4e-09*A1P_mlvt_mlvt'
+dpvthp_mlvt = '-3e-16*A1P_mlvt_mlvt'                   cjp_mlvt = '0.001077 * (1+0.070*A1P_mlvt_mlvt)'        cjswp_mlvt = '7.5e-11 * (1+0.070*A1P_mlvt_mlvt)'
+cjswgp_mlvt = '2.2e-10 * (1+0.070*A1P_mlvt_mlvt)'      cgop_mlvt = '7.70111e-11 * (1-0.070*A4NP_mlvt_mlvt)'   cglp_mlvt = '2.69027e-11 * (1-0.070*A4NP_mlvt_mlvt)'
+ddlcp_mlvt = 8.26573e-09
+cfp_mlvt = '1.20e-10*(1-0.070*A4NP_mlvt_mlvt)+5.6e-11*ccoflag_mlvt'
+drdswp_mlvt = '-20*A1P_mlvt_mlvt'                      ntoxp_mlvt = '1 + -1.2700e+00*A4NP_mlvt_mlvt'          du0p_mlvt = '0.0004*A1P_mlvt_mlvt'
+dlu0p_mlvt = '-6.0e-11*A1P_mlvt_mlvt'                  dwu0p_mlvt = '-1e-11*A1P_mlvt_mlvt'                    dpu0p_mlvt = '1e-17*A1P_mlvt_mlvt'
+deta0p_mlvt = 0                                   dleta0p_mlvt = '-3e-10*A1P_mlvt_mlvt'                  dweta0p_mlvt = 0
+dpeta0p_mlvt = '-5e-17*A1P_mlvt_mlvt'                  dvsatp_mlvt = 0                                   dlvsatp_mlvt = '0.00135*A1P_mlvt_mlvt'
+dwvsatp_mlvt = '-0.0019*A1P_mlvt_mlvt'                 dpvsatp_mlvt = '1e-12*A1P_mlvt_mlvt'                   dk2p_mlvt = '0.008*A1P_mlvt_mlvt'
+dlcitp_mlvt = 0                                   dwcitp_mlvt = 0                                   dpcitp_mlvt = 0
+dlvoffp_mlvt = '5e-10*A1P_mlvt_mlvt'                   dwvoffp_mlvt = 0                                  dpvoffp_mlvt = 0
+dnfactorp_mlvt = '-0.07*A1P_mlvt_mlvt'                 dlnfactorp_mlvt = '-1.0e-08*A1P_mlvt_mlvt'             dwnfactorp_mlvt = 0
+dpnfactorp_mlvt = '-6.2e-15*A1P_mlvt_mlvt*0'             dlk2p_mlvt = 0                                    dwk2p_mlvt = '9e-10*A1P_mlvt_mlvt'
+dpk2p_mlvt = '3e-17*A1P_mlvt_mlvt'                     dpdiblc2p_mlvt = '-0.0008*A1P_mlvt_mlvt*0'               dlpclmp_mlvt = 0
+dppclmp_mlvt = 0                                  datp_mlvt = '-24000*A1P_mlvt_mlvt'                     dlatp_mlvt = 0
+dwatp_mlvt         = 0                  dpatp_mlvt         = 0

+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' MAC_mlvt
.lib 'crn65lp_v1d5.l' MOS_mlvt
.ENDL SF_mlvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_mlvt
.lib 'crn65lp_v1d5.l' noiseflag_mlvt
.lib 'crn65lp_v1d5.l' post_simu_mlvt
.param
+parn1_mlvt=AGAUSS(0,1,1)
+parn2_mlvt=AGAUSS(0,1,1)
+parp1_mlvt=AGAUSS(0,1,1)
+parp2_mlvt=AGAUSS(0,1,1)
+A1N_mlvt=-0.8 A1P_mlvt=0.8 A2N_mlvt=0 A2P_mlvt=0 A3N_mlvt=1 A3P_mlvt=-1 A4NP_mlvt=0
+toxn_mlvt = '2.6e-09 + 6.7000e-011*A4NP_mlvt'     dxln_mlvt = '(-5e-009*A2N_mlvt)-6e-09'                     dxwn_mlvt = '8e-009*A3N_mlvt'
+dvthn_mlvt = '0.025*A1N_mlvt'                     dlvthn_mlvt = '1.8e-009*A1N_mlvt'                 dwvthn_mlvt = '3e-009*A1N_mlvt'
+dpvthn_mlvt = '2.6e-016*A1N_mlvt'                 cjn_mlvt = '0.001251 * (1+0.070*A1N_mlvt)'        cjswn_mlvt = '9.5e-11 * (1+0.070*A1N_mlvt)'
+cjswgn_mlvt = '2.04e-10 * (1+0.070*A1N_mlvt)'     cgon_mlvt = '8.28670e-11 * (1-0.070*A4NP_mlvt)'   cgln_mlvt = '9.96116e-12 * (1-0.070*A4NP_mlvt)'
+ddlcn_mlvt = 7.27377e-09
+cfn_mlvt = '1.20e-10*(1-0.070*A4NP_mlvt)+4.5e-11*ccoflag_mlvt'
+drdswn_mlvt = 0                              ntoxn_mlvt = '1 + -5.9000e-001*A4NP_mlvt'         du0n_mlvt = '0.0003*A1N_mlvt'
+dlu0n_mlvt = '5e-011*A1N_mlvt'                    dwu0n_mlvt = '0.0e-011*A1N_mlvt'                  dpu0n_mlvt = '0.0e-017*A1N_mlvt'
+deta0n_mlvt = 0                              dleta0n_mlvt = '-0e-010*A1N_mlvt'                 dweta0n_mlvt = '-0e-009*A1N_mlvt'
+dpeta0n_mlvt = '-0.5e-016*A1N_mlvt'               dvsatn_mlvt = '-0.0e4*A1N_mlvt'                   dlvsatn_mlvt = '0.000*A1N_mlvt'
+dwvsatn_mlvt = '0*A1N_mlvt'                       dpvsatn_mlvt = '-8e-012*A1N_mlvt'                 dk2n_mlvt = '0.004*A1N_mlvt'
+dlcitn_mlvt = 0                              dwcitn_mlvt = 0                              dlvoffn_mlvt = '-5e-010*A1N_mlvt'
+dwvoffn_mlvt = 0                             dpvoffn_mlvt = '2.1e-016*A1N_mlvt'                dnfactorn_mlvt = 0
+dwnfactorn_mlvt = '0*A1N_mlvt'                    dlnfactorn_mlvt = '-0.0e-008*A1N_mlvt'            dpnfactorn_mlvt = '-0e-014*A1N_mlvt'
+dpdiblc2n_mlvt = 0                           dla0n_mlvt = 0                               ss_flag_mlvt = 0
+ff_flag_mlvt = 0                             sf_flag_mlvt = 0                             fs_flag_mlvt = 1
+A1N_mlvt_mlvt=-0.8 A1P_mlvt_mlvt=0.8 A2N_mlvt_mlvt=0 A2P_mlvt_mlvt=0 A3N_mlvt_mlvt=1 A3P_mlvt_mlvt=-1 A4NP_mlvt_mlvt=0
+toxp_mlvt = '2.8e-09 + 6.7000e-11*A4NP_mlvt_mlvt'      dxlp_mlvt = '5e-09*A2P_mlvt_mlvt-6e-9'                 dxwp_mlvt = '8e-09*A3P_mlvt_mlvt'
+dvthp_mlvt = '-0.024*A1P_mlvt_mlvt'                    dlvthp_mlvt = '-5.5e-10*A1P_mlvt_mlvt'                 dwvthp_mlvt = '-4e-09*A1P_mlvt_mlvt'
+dpvthp_mlvt = '-3e-16*A1P_mlvt_mlvt'                   cjp_mlvt = '0.001077 * (1+0.070*A1P_mlvt_mlvt)'        cjswp_mlvt = '7.5e-11 * (1+0.070*A1P_mlvt_mlvt)'
+cjswgp_mlvt = '2.2e-10 * (1+0.070*A1P_mlvt_mlvt)'      cgop_mlvt = '7.70111e-11 * (1-0.070*A4NP_mlvt_mlvt)'   cglp_mlvt = '2.69027e-11 * (1-0.070*A4NP_mlvt_mlvt)'
+ddlcp_mlvt = 8.26573e-09
+cfp_mlvt = '1.20e-10*(1-0.070*A4NP_mlvt_mlvt)+5.6e-11*ccoflag_mlvt'
+drdswp_mlvt = '-20*A1P_mlvt_mlvt'                      ntoxp_mlvt = '1 + -1.2700e+00*A4NP_mlvt_mlvt'          du0p_mlvt = '0.0004*A1P_mlvt_mlvt'
+dlu0p_mlvt = '-6.0e-11*A1P_mlvt_mlvt'                  dwu0p_mlvt = '-1e-11*A1P_mlvt_mlvt'                    dpu0p_mlvt = '1e-17*A1P_mlvt_mlvt'
+deta0p_mlvt = 0                                   dleta0p_mlvt = '-3e-10*A1P_mlvt_mlvt'                  dweta0p_mlvt = 0
+dpeta0p_mlvt = '-5e-17*A1P_mlvt_mlvt'                  dvsatp_mlvt = 0                                   dlvsatp_mlvt = '0.00135*A1P_mlvt_mlvt'
+dwvsatp_mlvt = '-0.0019*A1P_mlvt_mlvt'                 dpvsatp_mlvt = '1e-12*A1P_mlvt_mlvt'                   dk2p_mlvt = '0.008*A1P_mlvt_mlvt'
+dlcitp_mlvt = 0                                   dwcitp_mlvt = 0                                   dpcitp_mlvt = 0
+dlvoffp_mlvt = '5e-10*A1P_mlvt_mlvt'                   dwvoffp_mlvt = 0                                  dpvoffp_mlvt = 0
+dnfactorp_mlvt = '-0.07*A1P_mlvt_mlvt'                 dlnfactorp_mlvt = '-1.0e-08*A1P_mlvt_mlvt'             dwnfactorp_mlvt = 0
+dpnfactorp_mlvt = '-6.2e-15*A1P_mlvt_mlvt*0'             dlk2p_mlvt = 0                                    dwk2p_mlvt = '9e-10*A1P_mlvt_mlvt'
+dpk2p_mlvt = '3e-17*A1P_mlvt_mlvt'                     dpdiblc2p_mlvt = '-0.0008*A1P_mlvt_mlvt*0'               dlpclmp_mlvt = 0
+dppclmp_mlvt = 0                                  datp_mlvt = '-24000*A1P_mlvt_mlvt'                     dlatp_mlvt = 0
+dwatp_mlvt         = 0                  dpatp_mlvt         = 0

+ c1fn_mlvt=8.00E+41           c2fn_mlvt=5.00E+22           c3fn_mlvt=1.00E+7            
+ c1fp_mlvt=9.50E+41           c2fp_mlvt=1.55E+24           c3fp_mlvt=1.00E+10          
+ fn_dice_mlvtn='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
+ arearation_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_mlvt='c1fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noibn_mlvt='c2fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ noicn_mlvt='c3fn_mlvt*2.718**((fn_dice_mlvtn+(1-fn_dice_mlvtn)*noiseflagn_mlvt)*arearation_mlvt)'
+ fn_dice_mlvtp='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
+ arearatiop_mlvt='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((1e-6*0.06e-6*1)/(10.3E-6*1E-6*1))**0.5)))'
+ noiap_mlvt='c1fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noibp_mlvt='c2fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'
+ noicp_mlvt='c3fp_mlvt*2.718**((fn_dice_mlvtp+(1-fn_dice_mlvtp)*noiseflagp_mlvt)*arearation_mlvt)'

.lib 'crn65lp_v1d5.l' MAC_mlvt
.lib 'crn65lp_v1d5.l' MOS_mlvt
.ENDL FS_mlvt







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+A1_lvt='par1*4.9161*3/2.1'
+A2_lvt='par2*4.0383*3/2.1'
+A3_lvt='par3*3.5526*3/2.1'
+A4_lvt='par4*2.0284*3/2.1'
+A5_lvt='par5*0.88801*3/2.1'
+toxn_lvt       ='2.6e-09+(6.8083e-012)*A1_lvt+(2.4563e-012)*A2_lvt+(-1.1379e-011)*A3_lvt+(-5.8103e-012)*A4_lvt+(1.0545e-012)*A5_lvt'
+dxln_lvt       ='0+(4.7435e-010)*A1_lvt+(2.1417e-010)*A2_lvt+(-1.2376e-009)*A3_lvt+(-6.1477e-010)*A4_lvt+(1.1334e-010)*A5_lvt'
+dxwn_lvt       ='0+(-9.0939e-010)*A1_lvt+(7.7991e-010)*A2_lvt+(2.1156e-009)*A3_lvt+(1.0165e-009)*A4_lvt+(-1.6813e-010)*A5_lvt'
+dvthn_lvt      ='0+(0.0041068)*A1_lvt+(-0.0028236)*A2_lvt+(0.0014907)*A3_lvt+(0.00056075)*A4_lvt+(-0.00019114)*A5_lvt'
+dlvthn_lvt     ='0+(2.0652e-010)*A1_lvt+(-1.3342e-010)*A2_lvt+(6.7549e-011)*A3_lvt+(4.421e-011)*A4_lvt+(-1.4339e-011)*A5_lvt'
+dwvthn_lvt     ='0+(4.1068e-010)*A1_lvt+(-2.8236e-010)*A2_lvt+(1.4907e-010)*A3_lvt+(5.6075e-011)*A4_lvt+(-1.9114e-011)*A5_lvt'
+dpvthn_lvt     ='0+(3.2462e-017)*A1_lvt+(-2.7674e-017)*A2_lvt+(1.6414e-017)*A3_lvt+(-5.575e-018)*A4_lvt+(1.4437e-018)*A5_lvt'
+cjn_lvt        ='1.185e-03+(1.1361e-005)*A1_lvt+(-7.806e-006)*A2_lvt+(4.1202e-006)*A3_lvt+(1.5494e-006)*A4_lvt+(-5.2835e-007)*A5_lvt'
+cjswn_lvt      ='9.400e-11+(9.0193e-013)*A1_lvt+(-6.1904e-013)*A2_lvt+(3.2645e-013)*A3_lvt+(1.2515e-013)*A4_lvt+(-4.2569e-014)*A5_lvt'
+cjswgn_lvt     ='1.600e-10+(1.5332e-012)*A1_lvt+(-1.0541e-012)*A2_lvt+(5.5651e-013)*A3_lvt+(2.0935e-013)*A4_lvt+(-7.136e-014)*A5_lvt'
+cgon_lvt       ='8.918e-11+(-6.3461e-013)*A1_lvt+(-2.289e-013)*A2_lvt+(1.0601e-012)*A3_lvt+(5.4255e-013)*A4_lvt+(-9.8583e-014)*A5_lvt'
+cgln_lvt       ='2.295e-11+(-1.6308e-013)*A1_lvt+(-5.8869e-014)*A2_lvt+(2.73e-013)*A3_lvt+(1.3814e-013)*A4_lvt+(-2.4948e-014)*A5_lvt'
+cfn_lvt        ='1.200000e-010+(-8.5357e-013)*A1_lvt+(-3.0795e-013)*A2_lvt+(1.4266e-012)*A3_lvt+(7.2845e-013)*A4_lvt+(-1.322e-013)*A5_lvt+5.4e-11*ccoflag_lvt'
+dlvoffn_lvt    ='0+(3.1284e-011)*A1_lvt+(-4.2931e-011)*A2_lvt+(2.9881e-011)*A3_lvt+(-3.5758e-011)*A4_lvt+(1.0362e-011)*A5_lvt'
+dpvoffn_lvt    ='0+(-3.1284e-018)*A1_lvt+(4.2931e-018)*A2_lvt+(-2.9881e-018)*A3_lvt+(3.5758e-018)*A4_lvt+(-1.0362e-018)*A5_lvt'
+ntoxn_lvt      ='1+(-0.05686)*A1_lvt+(-0.019224)*A2_lvt+(0.083196)*A3_lvt+(0.022902)*A4_lvt+(-0.0021051)*A5_lvt'
+du0n_lvt       ='0+(3.0085e-006)*A1_lvt+(-2.2452e-005)*A2_lvt+(-2.7072e-006)*A3_lvt+(-6.5707e-007)*A4_lvt+(-2.6423e-007)*A5_lvt'
+dlu0n_lvt      ='0+(-1.2034e-012)*A1_lvt+(8.9807e-012)*A2_lvt+(1.0829e-012)*A3_lvt+(2.6283e-013)*A4_lvt+(1.0569e-013)*A5_lvt'
+dpu0n_lvt      ='0+(7.4285e-020)*A1_lvt+(-5.6172e-019)*A2_lvt+(-5.519e-020)*A3_lvt+(-1.1173e-019)*A4_lvt+(-3.8519e-019)*A5_lvt'
+deta0n_lvt     ='0+(0.0023463)*A1_lvt+(-0.0032198)*A2_lvt+(0.002241)*A3_lvt+(-0.0026818)*A4_lvt+(0.00077716)*A5_lvt'
+dleta0n_lvt    ='0+(-3.7557e-010)*A1_lvt+(2.5665e-010)*A2_lvt+(-1.0521e-010)*A3_lvt+(-1.2378e-010)*A4_lvt+(-6.2248e-011)*A5_lvt'
+dpeta0n_lvt    ='0+(-1.1737e-017)*A1_lvt+(-2.6417e-018)*A2_lvt+(5.0026e-018)*A3_lvt+(-2.1617e-017)*A4_lvt+(6.4553e-018)*A5_lvt'
+dweta0n_lvt    ='0+(-4.6926e-010)*A1_lvt+(6.4397e-010)*A2_lvt+(-4.4821e-010)*A3_lvt+(5.3637e-010)*A4_lvt+(-1.5543e-010)*A5_lvt'
+dlvsatn_lvt    ='0+(3.0313e-005)*A1_lvt+(-1.8164e-005)*A2_lvt+(8.6871e-006)*A3_lvt+(9.1426e-006)*A4_lvt+(-2.8881e-006)*A5_lvt'
+dpvsatn_lvt    ='0+(-1.9558e-012)*A1_lvt+(8.0911e-013)*A2_lvt+(-2.4676e-013)*A3_lvt+(-1.2678e-012)*A4_lvt+(3.8648e-013)*A5_lvt'
+dlk2n_lvt      ='0+(4.1068e-011)*A1_lvt+(-2.8236e-011)*A2_lvt+(1.4907e-011)*A3_lvt+(5.6075e-012)*A4_lvt+(-1.9114e-012)*A5_lvt'
+dwk2n_lvt      ='0+(6.8447e-011)*A1_lvt+(-4.706e-011)*A2_lvt+(2.4844e-011)*A3_lvt+(9.3458e-012)*A4_lvt+(-3.1857e-012)*A5_lvt'
+ss_flag_lvt    ='0+(0.058683)*A1_lvt+(0.013208)*A2_lvt+(-0.025013)*A3_lvt+(0.10809)*A4_lvt+(-0.032277)*A5_lvt'
+ff_flag_lvt    ='max(-0.5,0+(-0.056423)*A1_lvt+(-0.011104)*A2_lvt+(-0.01055)*A3_lvt+(0.12234)*A4_lvt+(-0.034156)*A5_lvt)'
+sf_flag_lvt    ='max(-0.3,0+(0.0088222)*A1_lvt+(-0.07043)*A2_lvt+(-0.00065409)*A3_lvt+(-0.061618)*A4_lvt+(-0.23744)*A5_lvt)'
+fs_flag_lvt    ='0+(-0.0099807)*A1_lvt+(0.069892)*A2_lvt+(0.016266)*A3_lvt+(-0.057511)*A4_lvt+(-0.23579)*A5_lvt'
+toxp_lvt       ='2.8e-09+(6.8083e-012)*A1_lvt+(2.4563e-012)*A2_lvt+(-1.1379e-011)*A3_lvt+(-5.8103e-012)*A4_lvt+(1.0545e-012)*A5_lvt'
+dxlp_lvt       ='0+(4.7435e-010)*A1_lvt+(2.1417e-010)*A2_lvt+(-1.2376e-009)*A3_lvt+(-6.1477e-010)*A4_lvt+(1.1334e-010)*A5_lvt'
+dxwp_lvt       ='0+(-6.0854e-010)*A1_lvt+(-1.4653e-009)*A2_lvt+(1.8448e-009)*A3_lvt+(9.5077e-010)*A4_lvt+(-1.9455e-010)*A5_lvt'
+dvthp_lvt      ='0+(-0.0028838)*A1_lvt+(-0.0035207)*A2_lvt+(-0.0020725)*A3_lvt+(-0.00068208)*A4_lvt+(0.00010069)*A5_lvt'
+dlvthp_lvt     ='0+(-1.9226e-010)*A1_lvt+(-1.9828e-010)*A2_lvt+(-1.5301e-010)*A3_lvt+(-4.249e-011)*A4_lvt+(-1.9731e-010)*A5_lvt'
+dwvthp_lvt     ='0+(-3.7383e-010)*A1_lvt+(-4.5639e-010)*A2_lvt+(-2.6866e-010)*A3_lvt+(-8.8418e-011)*A4_lvt+(1.3052e-011)*A5_lvt'
+dpvthp_lvt     ='0+(-1.5493e-017)*A1_lvt+(-2.4759e-017)*A2_lvt+(-1.7853e-017)*A3_lvt+(5.7562e-018)*A4_lvt+(-2.4818e-018)*A5_lvt'
+cjp_lvt        ='1.068e-03+(7.9957e-006)*A1_lvt+(9.7512e-006)*A2_lvt+(5.732e-006)*A3_lvt+(1.9219e-006)*A4_lvt+(-2.8858e-007)*A5_lvt'
+cjswp_lvt      ='7.600e-11+(5.6822e-013)*A1_lvt+(6.9371e-013)*A2_lvt+(4.0837e-013)*A3_lvt+(1.344e-013)*A4_lvt+(-1.9839e-014)*A5_lvt'
+cjswgp_lvt     ='1.500e-10+(1.1215e-012)*A1_lvt+(1.3692e-012)*A2_lvt+(8.0598e-013)*A3_lvt+(2.6525e-013)*A4_lvt+(-3.9155e-014)*A5_lvt'
+cgop_lvt       ='7.490e-11+(-5.3243e-013)*A1_lvt+(-1.9214e-013)*A2_lvt+(8.9041e-013)*A3_lvt+(4.5463e-013)*A4_lvt+(-8.2509e-014)*A5_lvt'
+cglp_lvt       ='6.169e-11+(-4.3844e-013)*A1_lvt+(-1.5824e-013)*A2_lvt+(7.3354e-013)*A3_lvt+(3.7329e-013)*A4_lvt+(-6.7623e-014)*A5_lvt'
+du0p_lvt       ='0+(-6.3168e-006)*A1_lvt+(-4.9302e-007)*A2_lvt+(-8.8237e-006)*A3_lvt+(8.6109e-006)*A4_lvt+(-2.7226e-006)*A5_lvt'
+dlu0p_lvt      ='0+(1.7957e-012)*A1_lvt+(1.8416e-012)*A2_lvt+(3.0266e-012)*A3_lvt+(-2.7062e-012)*A4_lvt+(8.9106e-013)*A5_lvt'
+dpu0p_lvt      ='0+(1.6078e-020)*A1_lvt+(1.1451e-019)*A2_lvt+(6.3899e-020)*A3_lvt+(-8.7421e-020)*A4_lvt+(-1.7436e-019)*A5_lvt'
+deta0p_lvt     ='0+(0.00094014)*A1_lvt+(-0.0070161)*A2_lvt+(-0.00084599)*A3_lvt+(-0.00020534)*A4_lvt+(-8.2573e-005)*A5_lvt'
+dweta0p_lvt    ='0+(-5.8683e-010)*A1_lvt+(-1.3208e-010)*A2_lvt+(2.5013e-010)*A3_lvt+(-1.0809e-009)*A4_lvt+(3.2277e-010)*A5_lvt'
+ntoxp_lvt      ='1+(-0.084214)*A1_lvt+(-0.026401)*A2_lvt+(0.10422)*A3_lvt+(-0.007214)*A4_lvt+(0.0076397)*A5_lvt'
+dlk2p_lvt      ='0+(5.0703e-011)*A1_lvt+(3.2683e-011)*A2_lvt+(2.8457e-012)*A3_lvt+(5.9096e-011)*A4_lvt+(-1.6884e-011)*A5_lvt'
+dwk2p_lvt      ='0+(4.2723e-011)*A1_lvt+(5.2159e-011)*A2_lvt+(3.0704e-011)*A3_lvt+(1.0105e-011)*A4_lvt+(-1.4916e-012)*A5_lvt'
+dlcitp_lvt     ='0+(-2.9342e-012)*A1_lvt+(-6.6041e-013)*A2_lvt+(1.2506e-012)*A3_lvt+(-5.4043e-012)*A4_lvt+(1.6138e-012)*A5_lvt'
+cfp_lvt        ='1.200000e-010+(-8.5357e-013)*A1_lvt+(-3.0795e-013)*A2_lvt+(1.4266e-012)*A3_lvt+(7.2845e-013)*A4_lvt+(-1.322e-013)*A5_lvt+5.6e-11*ccoflag_lvt'
+dlvoffp_lvt    ='0+(3.3688e-011)*A1_lvt+(8.2032e-011)*A2_lvt+(7.1241e-011)*A3_lvt+(-5.7977e-011)*A4_lvt+(1.9983e-011)*A5_lvt'
+dpvoffp_lvt    ='0+(-5.8683e-019)*A1_lvt+(-1.3208e-019)*A2_lvt+(2.5013e-019)*A3_lvt+(-1.0809e-018)*A4_lvt+(3.2277e-019)*A5_lvt'
+dnfactorp_lvt  ='max(0,0+(-0.025267)*A1_lvt+(-0.0019721)*A2_lvt+(-0.035295)*A3_lvt+(0.034444)*A4_lvt+(-0.010891)*A5_lvt)'
+dagsp_lvt      ='0+(0.0024063)*A1_lvt+(0.0058594)*A2_lvt+(0.0050887)*A3_lvt+(-0.0041412)*A4_lvt+(0.0014274)*A5_lvt'
+dvsatp_lvt     ='max(-10000,0+(630.29)*A1_lvt+(886.36)*A2_lvt+(587.35)*A3_lvt+(-39.337)*A4_lvt+(38.45)*A5_lvt)'
+ddlcn_lvt      =8.441e-09
+drdswn_lvt     =0
+dcitn_lvt      =0
+dlcitn_lvt     =0
+dwcitn_lvt     =0
+dpcitn_lvt     =0
+dvoffn_lvt     =0
+dwvoffn_lvt    =0
+dnfactorn_lvt  =0
+dwnfactorn_lvt =0
+dlnfactorn_lvt =0
+dpnfactorn_lvt =0
+dwu0n_lvt      =0
+duan_lvt       =0
+dluan_lvt      =0
+dwuan_lvt      =0
+dpuan_lvt      =0
+dubn_lvt       =0
+dlubn_lvt      =0
+dwubn_lvt      =0
+dpubn_lvt      =0
+dua1n_lvt      =0
+dlua1n_lvt     =0
+dwua1n_lvt     =0
+dpua1n_lvt     =0
+dub1n_lvt      =0
+dlub1n_lvt     =0
+dwub1n_lvt     =0
+dpub1n_lvt     =0
+dkt1n_lvt      =0
+dlkt1n_lvt     =0
+dwkt1n_lvt     =0
+dpkt1n_lvt     =0
+dcdscdn_lvt    =0
+dk2n_lvt       =0
+dvsatn_lvt     =0
+dwvsatn_lvt    =0
+dpk2n_lvt      =0
+tt_flag_lvt    =0
+ddlcp_lvt      =1.054e-08
+dwu0p_lvt      =0
+duap_lvt       =0
+dluap_lvt      =0
+dwuap_lvt      =0
+dpuap_lvt      =0
+dubp_lvt       =0
+dlubp_lvt      =0
+dwubp_lvt      =0
+dpubp_lvt      =0
+dub1p_lvt      =0
+dlub1p_lvt     =0
+dwub1p_lvt     =0
+dpub1p_lvt     =0
+dua1p_lvt      =0
+dlua1p_lvt     =0
+dwua1p_lvt     =0
+dpua1p_lvt     =0
+datp_lvt       =0
+dlatp_lvt      =0
+dwatp_lvt      =0
+dpatp_lvt      =0
+dutep_lvt      =0
+dlutep_lvt     =0
+dwutep_lvt     =0
+dputep_lvt     =0
+dpclmp_lvt     =0
+dlpclmp_lvt    =0
+dwpclmp_lvt    =0
+dppclmp_lvt    =0
+dleta0p_lvt    =0
+dpeta0p_lvt    =0
+dk2p_lvt       =0
+dpk2p_lvt      =0
+dcitp_lvt      =0
+dwcitp_lvt     =0
+dpcitp_lvt     =0
+dvoffp_lvt     =0
+dwvoffp_lvt    =0
+dlnfactorp_lvt =0
+dwnfactorp_lvt =0
+dpnfactorp_lvt =0
+da0p_lvt       =0
+dla0p_lvt      =0
+dwa0p_lvt      =0
+dpa0p_lvt      =0
+dlagsp_lvt     =0
+dwagsp_lvt     =0
+dpagsp_lvt     =0
+dlvsatp_lvt    =0
+dwvsatp_lvt    =0
+dpvsatp_lvt    =0
+dpdiblc2p_lvt  =0
+dlpdiblc2p_lvt =0
+dwpdiblc2p_lvt =0
+dppdiblc2p_lvt =0
       
+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' mos_lvt
.ENDL mc_lvt







***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+toxn_lvt       = 2.6e-09       dxln_lvt       = 0             dxwn_lvt       = 0
+dvthn_lvt      = 0             dlvthn_lvt     = 0             dwvthn_lvt     = 0
+dpvthn_lvt     = 0             cjn_lvt        = 1.185E-03     cjswn_lvt      = 9.400E-11
+cjswgn_lvt     = 1.600E-10
+cgon_lvt       = 8.918E-11
+cgln_lvt       = 2.295E-11
+ddlcn_lvt      = 8.441E-09
+cfn_lvt        = '1.20e-10 + 5.4e-11*ccoflag_lvt' drdswn_lvt     = 0
+dcitn_lvt      = 0             dlcitn_lvt     = 0             dwcitn_lvt     = 0
+dpcitn_lvt     = 0             dvoffn_lvt     = 0             dlvoffn_lvt    = 0
+dwvoffn_lvt    = 0             dpvoffn_lvt    = 0             ntoxn_lvt      = 1
+dnfactorn_lvt  = 0             dwnfactorn_lvt = 0             dlnfactorn_lvt = 0
+dpnfactorn_lvt = 0             du0n_lvt       = 0             dlu0n_lvt      = 0
+dwu0n_lvt      = 0             dpu0n_lvt      = 0             duan_lvt       = 0
+dluan_lvt      = 0             dwuan_lvt      = 0             dpuan_lvt      = 0
+dubn_lvt       = 0             dlubn_lvt      = 0             dwubn_lvt      = 0
+dpubn_lvt      = 0             dua1n_lvt      = 0             dlua1n_lvt     = 0
+dwua1n_lvt     = 0             dpua1n_lvt     = 0             dub1n_lvt      = 0
+dlub1n_lvt     = 0             dwub1n_lvt     = 0             dpub1n_lvt     = 0
+dkt1n_lvt      = 0             dlkt1n_lvt     = 0             dwkt1n_lvt     = 0
+dpkt1n_lvt     = 0             deta0n_lvt     = 0             dleta0n_lvt    = 0
+dpeta0n_lvt    = 0             dweta0n_lvt    = 0             dcdscdn_lvt    = 0
+dk2n_lvt       = 0             dvsatn_lvt     = 0             dlvsatn_lvt    = 0
+dwvsatn_lvt    = 0             dpvsatn_lvt    = 0             dlk2n_lvt      = 0
+dwk2n_lvt      = 0             dpk2n_lvt      = 0
+tt_flag_lvt    = 0             ss_flag_lvt    = 0             ff_flag_lvt    = 0
+sf_flag_lvt    = 0             fs_flag_lvt    = 0
+toxp_lvt       = 2.8e-09       dxlp_lvt       = 0             dxwp_lvt       = 0
+dvthp_lvt      = 0             dlvthp_lvt     = 0             dwvthp_lvt     = 0
+dpvthp_lvt     = 0             cjp_lvt        = 1.068E-03     cjswp_lvt      = 7.600E-11
+cjswgp_lvt     = 1.500E-10
+cgop_lvt       = 7.490E-11
+cglp_lvt       = 6.169E-11
+ddlcp_lvt      = 1.054E-08
+du0p_lvt       = 0             dlu0p_lvt      = 0
+dwu0p_lvt      = 0             dpu0p_lvt      = 0             duap_lvt       = 0
+dluap_lvt      = 0             dwuap_lvt      = 0             dpuap_lvt      = 0
+dubp_lvt       = 0             dlubp_lvt      = 0             dwubp_lvt      = 0
+dpubp_lvt      = 0             dub1p_lvt      = 0             dlub1p_lvt     = 0
+dwub1p_lvt     = 0             dpub1p_lvt     = 0             dua1p_lvt      = 0
+dlua1p_lvt     = 0             dwua1p_lvt     = 0             dpua1p_lvt     = 0
+datp_lvt       = 0             dlatp_lvt      = 0             dwatp_lvt      = 0
+dpatp_lvt      = 0             dutep_lvt      = 0             dlutep_lvt     = 0
+dwutep_lvt     = 0             dputep_lvt     = 0             dpclmp_lvt     = 0
+dlpclmp_lvt    = 0             dwpclmp_lvt    = 0             dppclmp_lvt    = 0
+deta0p_lvt     = 0             dleta0p_lvt    = 0             dweta0p_lvt    = 0
+dpeta0p_lvt    = 0             ntoxp_lvt      = 1             dk2p_lvt       = 0
+dlk2p_lvt      = 0             dwk2p_lvt      = 0             dpk2p_lvt      = 0
+dcitp_lvt      = 0             dlcitp_lvt     = 0             dwcitp_lvt     = 0
+dpcitp_lvt     = 0             cfp_lvt        = '1.200E-10 + 5.6e-11*ccoflag_lvt' dvoffp_lvt     = 0
+dlvoffp_lvt    = 0             dwvoffp_lvt    = 0             dpvoffp_lvt    = 0
+dnfactorp_lvt  = 0             dlnfactorp_lvt = 0             dwnfactorp_lvt = 0
+dpnfactorp_lvt = 0             da0p_lvt       = 0             dla0p_lvt      = 0
+dwa0p_lvt      = 0             dpa0p_lvt      = 0             dagsp_lvt      = 0
+dlagsp_lvt     = 0             dwagsp_lvt     = 0             dpagsp_lvt     = 0
+dvsatp_lvt     = 0             dlvsatp_lvt    = 0             dwvsatp_lvt    = 0
+dpvsatp_lvt    = 0             dpdiblc2p_lvt  = 0             dlpdiblc2p_lvt = 0
+dwpdiblc2p_lvt = 0             dppdiblc2p_lvt = 0

+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' MAC_lvt
.lib 'crn65lp_v1d5.l' MOS_lvt
.ENDL TT_lvt








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+toxn_lvt       = 2.667e-09     dxln_lvt       = 5e-09         dxwn_lvt       = -8e-09
+dvthn_lvt      = 0.03          dlvthn_lvt     = 1.6e-09      dwvthn_lvt     = 3e-09
+dpvthn_lvt     = 1.8e-16       cjn_lvt        = 1.268E-03     cjswn_lvt      = 1.006E-10
+cjswgn_lvt     = 1.712E-10     cgon_lvt       = 8.294E-11     cgln_lvt       = 2.134E-11
+ddlcn_lvt      = 8.441E-09     cfn_lvt        = '1.116e-10 + 5.4e-11*ccoflag_lvt' drdswn_lvt     = 0
+dcitn_lvt      = 0             dlcitn_lvt     = 0             dwcitn_lvt     = 0
+dpcitn_lvt     = 0             dvoffn_lvt     = 0             dlvoffn_lvt    = 0e-11
+dwvoffn_lvt    = 0             dpvoffn_lvt    = -0e-17        ntoxn_lvt      = 0.372
+dnfactorn_lvt  = 0             dwnfactorn_lvt = 0             dlnfactorn_lvt = 0
+dpnfactorn_lvt = 0             du0n_lvt       = 0             dlu0n_lvt      = 0
+dwu0n_lvt      = 0             dpu0n_lvt      = 0             duan_lvt       = 0
+dluan_lvt      = 0             dwuan_lvt      = 0             dpuan_lvt      = 0
+dubn_lvt       = 0             dlubn_lvt      = 0             dwubn_lvt      = 0
+dpubn_lvt      = 0             dua1n_lvt      = 0             dlua1n_lvt     = 0
+dwua1n_lvt     = 0             dpua1n_lvt     = 0             dub1n_lvt      = 0
+dlub1n_lvt     = 0             dwub1n_lvt     = 0             dpub1n_lvt     = 0
+dkt1n_lvt      = 0             dlkt1n_lvt     = 0             dwkt1n_lvt     = 0
+dpkt1n_lvt     = 0             deta0n_lvt     = 0             dleta0n_lvt    = -3.0e-09
+dpeta0n_lvt    = -0.2e-15       dweta0n_lvt    = 0             dcdscdn_lvt    = 0
+dk2n_lvt       = 0             dvsatn_lvt     = 0             dlvsatn_lvt    = 2.5e-04
+dwvsatn_lvt    = 0             dpvsatn_lvt    = -2.0e-11      dlk2n_lvt      = 3e-10
+dwk2n_lvt      = 5e-10         dpk2n_lvt      = 0
+tt_flag_lvt    = 0             ss_flag_lvt    = 1             ff_flag_lvt    = 0
+sf_flag_lvt    = 0             fs_flag_lvt    = 0
+toxp_lvt       = 2.867e-09     dxlp_lvt       = 5e-09         dxwp_lvt       = -8e-09
+dvthp_lvt      = -0.027         dlvthp_lvt     = -1.5e-09      dwvthp_lvt     = -3.5e-09
+dpvthp_lvt     = -1e-16        cjp_lvt        = 1.143E-03     cjswp_lvt      = 8.132E-11
+cjswgp_lvt     = 1.605E-10     cgop_lvt       = 6.966E-11     cglp_lvt       = 5.737E-11
+ddlcp_lvt      = 1.054E-08     du0p_lvt       = -0.0000       dlu0p_lvt      = 0e-11
+dwu0p_lvt      = 0e-10         dpu0p_lvt      = 0e-19         duap_lvt       = 0
+dluap_lvt      = 0             dwuap_lvt      = 0             dpuap_lvt      = 0
+dubp_lvt       = 0             dlubp_lvt      = 0e-27             dwubp_lvt      = 0e-27
+dpubp_lvt      = 0             dub1p_lvt      = 0             dlub1p_lvt     = 0
+dwub1p_lvt     = 0             dpub1p_lvt     = 0             dua1p_lvt      = 0
+dlua1p_lvt     = 0             dwua1p_lvt     = 0             dpua1p_lvt     = 0
+datp_lvt       = 0             dlatp_lvt      = 0             dwatp_lvt      = 0
+dpatp_lvt      = 0             dutep_lvt      = 0             dlutep_lvt     = 0
+dwutep_lvt     = 0             dputep_lvt     = 0             dpclmp_lvt     = 0
+dlpclmp_lvt    = 0             dwpclmp_lvt    = 0             dppclmp_lvt    = 0
+deta0p_lvt     = 0             dleta0p_lvt    = 0e-9             dweta0p_lvt    = -1e-08
+dpeta0p_lvt    = 0             ntoxp_lvt      = -0.04         dk2p_lvt       = 0
+dlk2p_lvt      = 0.7e-9         dwk2p_lvt      = 4e-10         dpk2p_lvt      = 0
+dcitp_lvt      = 0             dlcitp_lvt     = -5e-11             dwcitp_lvt     = 0
+dpcitp_lvt     = 0             cfp_lvt        = '1.116E-10 + 5.6e-11*ccoflag_lvt' dvoffp_lvt     = 0
+dlvoffp_lvt    = -0e-10      dwvoffp_lvt    = 0             dpvoffp_lvt    = -1e-17
+dnfactorp_lvt  = 0             dlnfactorp_lvt = -0e-8             dwnfactorp_lvt = 0
+dpnfactorp_lvt = 0             da0p_lvt       = 0             dla0p_lvt      = 0
+dwa0p_lvt      = 0             dpa0p_lvt      = 0             dagsp_lvt      = 0
+dlagsp_lvt     = 0             dwagsp_lvt     = 0             dpagsp_lvt     = 0e20
+dvsatp_lvt     = 5000             dlvsatp_lvt    = 0             dwvsatp_lvt    = 0
+dpvsatp_lvt    = 0             dpdiblc2p_lvt  = 0             dlpdiblc2p_lvt = 0
+dwpdiblc2p_lvt = 0             dppdiblc2p_lvt = 0

+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' MAC_lvt
.lib 'crn65lp_v1d5.l' MOS_lvt
.ENDL SS_lvt








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+toxn_lvt       = 2.533e-09     dxln_lvt       = -5e-09        dxwn_lvt       = 8e-09
+dvthn_lvt      = -0.03         dlvthn_lvt     = -14.4e-10      dwvthn_lvt     = -3e-09
+dpvthn_lvt     = -2.8e-16      cjn_lvt        = 1.102E-03     cjswn_lvt      = 8.742E-11
+cjswgn_lvt     = 1.488E-10     cgon_lvt       = 9.543E-11     cgln_lvt       = 2.455E-11
+ddlcn_lvt      = 8.441E-09     cfn_lvt        = '1.284e-10 + 5.4e-11*ccoflag_lvt' drdswn_lvt     = 0
+dcitn_lvt      = 0             dlcitn_lvt     = 0             dwcitn_lvt     = 0
+dpcitn_lvt     = 0             dvoffn_lvt     = 0             dlvoffn_lvt    = -0.4e-09
+dwvoffn_lvt    = 0             dpvoffn_lvt    = 0.4e-16       ntoxn_lvt      = 1.466
+dnfactorn_lvt  = 0             dwnfactorn_lvt = 0             dlnfactorn_lvt = 0
+dpnfactorn_lvt = 0             du0n_lvt       = 0             dlu0n_lvt      = 0
+dwu0n_lvt      = 0             dpu0n_lvt      = 0             duan_lvt       = 0
+dluan_lvt      = 0             dwuan_lvt      = 0             dpuan_lvt      = 0
+dubn_lvt       = 0             dlubn_lvt      = 0             dwubn_lvt      = 0
+dpubn_lvt      = 0             dua1n_lvt      = 0             dlua1n_lvt     = 0
+dwua1n_lvt     = 0             dpua1n_lvt     = 0             dub1n_lvt      = 0
+dlub1n_lvt     = 0             dwub1n_lvt     = 0             dpub1n_lvt     = 0
+dkt1n_lvt      = 0             dlkt1n_lvt     = 0             dwkt1n_lvt     = 0
+dpkt1n_lvt     = 0             deta0n_lvt     = -0.03         dleta0n_lvt    = 2.5e-09
+dpeta0n_lvt    = -0.0e-15      dweta0n_lvt    = 0.6e-08       dcdscdn_lvt    = 0
+dk2n_lvt       = 0             dvsatn_lvt     = 0             dlvsatn_lvt    = -2.0e-04
+dwvsatn_lvt    = 0             dpvsatn_lvt    = 1.0e-11       dlk2n_lvt      = -3e-10
+dwk2n_lvt      = -5e-10        dpk2n_lvt      = 0
+tt_flag_lvt    = 0             ss_flag_lvt    = 0             ff_flag_lvt    = 1
+sf_flag_lvt    = 0             fs_flag_lvt    = 0
+toxp_lvt       = 2.733e-09     dxlp_lvt       = -5e-09        dxwp_lvt       = 8e-09
+dvthp_lvt      = 0.027          dlvthp_lvt     = 2e-09         dwvthp_lvt     = 3.5e-09
+dpvthp_lvt     = 2e-16         cjp_lvt        = 9.933E-04     cjswp_lvt      = 7.068E-11
+cjswgp_lvt     = 1.395E-10     cgop_lvt       = 8.014E-11     cglp_lvt       = 6.600E-11
+ddlcp_lvt      = 1.054E-08     du0p_lvt       = 0.0001        dlu0p_lvt      = -3.2e-11
+dwu0p_lvt      = -0e-10        dpu0p_lvt      = -0.5e-18        duap_lvt       = 0
+dluap_lvt      = 0e-18             dwuap_lvt      = 0             dpuap_lvt      = 0
+dubp_lvt       = 0             dlubp_lvt      = -0e-27             dwubp_lvt      = 0
+dpubp_lvt      = 0             dub1p_lvt      = 0             dlub1p_lvt     = 0
+dwub1p_lvt     = 0             dpub1p_lvt     = 0             dua1p_lvt      = 0
+dlua1p_lvt     = 0             dwua1p_lvt     = 0             dpua1p_lvt     = 0
+datp_lvt       = 0             dlatp_lvt      = 0             dwatp_lvt      = 0
+dpatp_lvt      = 0             dutep_lvt      = 0             dlutep_lvt     = 0
+dwutep_lvt     = 0             dputep_lvt     = 0             dpclmp_lvt     = 0
+dlpclmp_lvt    = 0             dwpclmp_lvt    = 0             dppclmp_lvt    = 0
+deta0p_lvt     = 0             dleta0p_lvt    = 0e-9             dweta0p_lvt    = 0e-08
+dpeta0p_lvt    = 0             ntoxp_lvt      = 1.54          dk2p_lvt       = 0
+dlk2p_lvt      = -0.2e-9        dwk2p_lvt      = -4e-10        dpk2p_lvt      = 0
+dcitp_lvt      = 0e-4             dlcitp_lvt     = 0e-11             dwcitp_lvt     = 0
+dpcitp_lvt     = 0             cfp_lvt        = '1.284E-10 + 5.6e-11*ccoflag_lvt' dvoffp_lvt     = 0
+dlvoffp_lvt    = -7e-10       dwvoffp_lvt    = 0             dpvoffp_lvt    = -0e-17
+dnfactorp_lvt  = 0.4             dlnfactorp_lvt = 0e-8             dwnfactorp_lvt = 0
+dpnfactorp_lvt = 0             da0p_lvt       = 0             dla0p_lvt      = 0
+dwa0p_lvt      = 0             dpa0p_lvt      = 0             dagsp_lvt      = -0.05
+dlagsp_lvt     = 0             dwagsp_lvt     = 0             dpagsp_lvt     = -0e20
+dvsatp_lvt     = -7000             dlvsatp_lvt    = 0             dwvsatp_lvt    = 0
+dpvsatp_lvt    = 0             dpdiblc2p_lvt  = 0             dlpdiblc2p_lvt = 0
+dwpdiblc2p_lvt = 0             dppdiblc2p_lvt = 0

+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' MAC_lvt
.lib 'crn65lp_v1d5.l' MOS_lvt
.ENDL FF_lvt








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+A1N_lvt=0.8 A1P_lvt=-0.8 A2N_lvt=0 A2P_lvt=0 A3N_lvt=-1 A3P_lvt=1 A4NP_lvt=0
+toxn_lvt = '2.6e-09 + 6.7000e-011*A4NP_lvt'    dxln_lvt = '5e-009*A2N_lvt'                    dxwn_lvt = '8e-009*A3N_lvt'
+dvthn_lvt = '0.03*A1N_lvt'                     dlvthn_lvt = '14.4e-010*A1N_lvt'               dwvthn_lvt = '3e-009*A1N_lvt'
+dpvthn_lvt = '2.8e-016*A1N_lvt'                cjn_lvt = '1.185E-03 * (1+0.070*A1N_lvt)'      cjswn_lvt = '9.400E-11 * (1+0.070*A1N_lvt)'
+cjswgn_lvt = '1.600E-10 * (1+0.070*A1N_lvt)'   cgon_lvt = '8.918E-11 * (1-0.070*A4NP_lvt)'    cgln_lvt = '2.295E-11 * (1-0.070*A4NP_lvt)'
+ddlcn_lvt = 8.441E-09
+cfn_lvt = '1.20e-10*(1-0.070*A4NP_lvt)+5.4e-11*ccoflag_lvt'
+drdswn_lvt = 0                                 dcitn_lvt = 0                                  dlcitn_lvt = 0
+dwcitn_lvt = 0                                 dpcitn_lvt = 0                                 dvoffn_lvt = 0
+dlvoffn_lvt = '0.4e-09*A1N_lvt'                dwvoffn_lvt = 0                                dpvoffn_lvt = '-0.4e-16*A1N_lvt'
+ntoxn_lvt = '1 + -4.6600e-001*A4NP_lvt'        dnfactorn_lvt = 0                              dwnfactorn_lvt = 0
+dlnfactorn_lvt = 0                             dpnfactorn_lvt = 0                             du0n_lvt = '2.0e-4*A1N_lvt'
+dlu0n_lvt = '-0.8e-10*A1N_lvt'                 dwu0n_lvt = 0                                  dpu0n_lvt = '6.0e-18*A1N_lvt'
+duan_lvt = 0                                   dluan_lvt = 0                                  dwuan_lvt = 0
+dpuan_lvt = 0                                  dubn_lvt = 0                                   dlubn_lvt = 0
+dwubn_lvt = 0                                  dpubn_lvt = 0                                  dua1n_lvt = 0
+dlua1n_lvt = 0                                 dwua1n_lvt = 0                                 dpua1n_lvt = 0
+dub1n_lvt = 0                                  dlub1n_lvt = 0                                 dwub1n_lvt = 0
+dpub1n_lvt = 0                                 dkt1n_lvt = 0                                  dlkt1n_lvt = 0
+dwkt1n_lvt = 0                                 dpkt1n_lvt = 0                                 deta0n_lvt = '0.03*A1N_lvt'
+dleta0n_lvt = '-2.5e-09*A1N_lvt'               dpeta0n_lvt = '0.0e-15*A1N_lvt'                dweta0n_lvt = '-0.6e-08*A1N_lvt'
+dcdscdn_lvt = 0                                dk2n_lvt = 0                                   dvsatn_lvt = 0
+dlvsatn_lvt = '2.0e-04*A1N_lvt'                dwvsatn_lvt = 0                                dpvsatn_lvt = '-1.0e-11*A1N_lvt'
+dlk2n_lvt = '3e-010*A1N_lvt'                   dwk2n_lvt = '5e-010*A1N_lvt'                   dpk2n_lvt = 0
+tt_flag_lvt    = 0                             ss_flag_lvt    = 0                             ff_flag_lvt    = 0
+sf_flag_lvt    = 1                             fs_flag_lvt    = 0
+toxp_lvt = '2.8e-09 + 6.7000e-11*A4NP_lvt'     dxlp_lvt = '5e-09*A2P_lvt'                     dxwp_lvt = '8e-09*A3P_lvt'
+dvthp_lvt = '-0.027*A1P_lvt'                   dlvthp_lvt = '-2e-09*A1P_lvt'                  dwvthp_lvt = '-3.5e-09*A1P_lvt'
+dpvthp_lvt = '-2e-16*A1P_lvt'                  cjp_lvt = '1.068E-03 * (1+0.070*A1P_lvt)'      cjswp_lvt = '7.600E-11 * (1+0.070*A1P_lvt)'
+cjswgp_lvt = '1.500E-10 * (1+0.070*A1P_lvt)'   cgop_lvt = '7.490E-11 * (1-0.070*A4NP_lvt)'    cglp_lvt = '6.169E-11 * (1-0.070*A4NP_lvt)'
+ddlcp_lvt = 1.054E-08                          du0p_lvt = '0.0000*A1P_lvt'                   dlu0p_lvt = '1.5e-11*A1P_lvt'
+dwu0p_lvt = '0*A1P_lvt'                        dpu0p_lvt = '5e-19*A1P_lvt'                    duap_lvt = 0
+dluap_lvt = '0*A1P_lvt'                        dwuap_lvt = 0                                  dpuap_lvt = 0
+dubp_lvt = 0                                   dlubp_lvt = '0*A1P_lvt'                        dwubp_lvt = 0
+dpubp_lvt = 0                                  dub1p_lvt = 0                                  dlub1p_lvt = 0
+dwub1p_lvt = 0                                 dpub1p_lvt = 0                                 dua1p_lvt = 0
+dlua1p_lvt = 0                                 dwua1p_lvt = 0                                 dpua1p_lvt = 0
+datp_lvt = 0                                   dlatp_lvt = 0                                  dwatp_lvt = 0
+dpatp_lvt = 0                                  dutep_lvt = 0                                  dlutep_lvt = 0
+dwutep_lvt = 0                                 dputep_lvt = 0                                 dpclmp_lvt = 0
+dlpclmp_lvt = 0                                dwpclmp_lvt = 0                                dppclmp_lvt = 0
+deta0p_lvt = 0.05                                 dleta0p_lvt = '0*A1P_lvt'                      dweta0p_lvt = '0*A1P_lvt'
+dpeta0p_lvt = 0                                ntoxp_lvt = '1 + -5.4000e-01*A4NP_lvt'         dk2p_lvt = 0
+dlk2p_lvt = '2e-10*A1P_lvt'                    dwk2p_lvt = '4e-10*A1P_lvt'                    dpk2p_lvt = 0
+dcitp_lvt = '0*A1P_lvt'                        dlcitp_lvt = '0*A1P_lvt'                       dwcitp_lvt = 0
+dpcitp_lvt = 0
+cfp_lvt = '1.200E-10*(1-0.070*A4NP_lvt)+5.6e-11*ccoflag_lvt'
+dvoffp_lvt = 0                                 dlvoffp_lvt = '7e-10*A1P_lvt'                  dwvoffp_lvt = 0
+dpvoffp_lvt = '0*A1P_lvt'                      dnfactorp_lvt = '-0.0*A1P_lvt'                 dlnfactorp_lvt = '0*A1P_lvt'
+dwnfactorp_lvt = 0                             dpnfactorp_lvt = 0                             da0p_lvt = 0
+dla0p_lvt = 0                                  dwa0p_lvt = 0                                  dpa0p_lvt = 0
+dagsp_lvt = '0.05*A1P_lvt'                     dlagsp_lvt = 0                                 dwagsp_lvt = 0
+dpagsp_lvt = '0*A1P_lvt'                       dvsatp_lvt = '7000*A1P_lvt'                    dlvsatp_lvt = 0
+dwvsatp_lvt = 0                                dpvsatp_lvt = 0                                dpdiblc2p_lvt = 0
+dlpdiblc2p_lvt = 0                             dwpdiblc2p_lvt = 0                             dppdiblc2p_lvt = 0

+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' MAC_lvt
.lib 'crn65lp_v1d5.l' MOS_lvt
.ENDL SF_lvt








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_lvt
.lib 'crn65lp_v1d5.l' noiseflag_lvt
.lib 'crn65lp_v1d5.l' post_simu_lvt
.param
+parn1_lvt=AGAUSS(0,1,1)
+parn2_lvt=AGAUSS(0,1,1)
+parp1_lvt=AGAUSS(0,1,1)
+parp2_lvt=AGAUSS(0,1,1)
+A1N_lvt=-0.8 A1P_lvt=0.8 A2N_lvt=0 A2P_lvt=0 A3N_lvt=1 A3P_lvt=-1 A4NP_lvt=0
+toxn_lvt = '2.6e-09 + 6.7000e-011*A4NP_lvt'    dxln_lvt = '5e-009*A2N_lvt'                    dxwn_lvt = '8e-009*A3N_lvt'
+dvthn_lvt = '0.03*A1N_lvt'                     dlvthn_lvt = '14.4e-010*A1N_lvt'               dwvthn_lvt = '3e-009*A1N_lvt'
+dpvthn_lvt = '2.8e-016*A1N_lvt'                cjn_lvt = '1.185E-03 * (1+0.070*A1N_lvt)'      cjswn_lvt = '9.400E-11 * (1+0.070*A1N_lvt)'
+cjswgn_lvt = '1.600E-10 * (1+0.070*A1N_lvt)'   cgon_lvt = '8.918E-11 * (1-0.070*A4NP_lvt)'    cgln_lvt = '2.295E-11 * (1-0.070*A4NP_lvt)'
+ddlcn_lvt = 8.441E-09
+cfn_lvt = '1.20e-10*(1-0.070*A4NP_lvt)+5.4e-11*ccoflag_lvt'
+drdswn_lvt = 0                                 dcitn_lvt = 0                                  dlcitn_lvt = 0
+dwcitn_lvt = 0                                 dpcitn_lvt = 0                                 dvoffn_lvt = 0
+dlvoffn_lvt = '0.4e-09*A1N_lvt'                dwvoffn_lvt = 0                                dpvoffn_lvt = '-0.4e-16*A1N_lvt'
+ntoxn_lvt = '1 + -4.6600e-001*A4NP_lvt'        dnfactorn_lvt = 0                              dwnfactorn_lvt = 0
+dlnfactorn_lvt = 0                             dpnfactorn_lvt = 0                             du0n_lvt = '2.0e-4*A1N_lvt'
+dlu0n_lvt = '-0.8e-10*A1N_lvt'                 dwu0n_lvt = 0                                  dpu0n_lvt = '4.0e-18*A1N_lvt'
+duan_lvt = 0                                   dluan_lvt = 0                                  dwuan_lvt = 0
+dpuan_lvt = 0                                  dubn_lvt = 0                                   dlubn_lvt = 0
+dwubn_lvt = 0                                  dpubn_lvt = 0                                  dua1n_lvt = 0
+dlua1n_lvt = 0                                 dwua1n_lvt = 0                                 dpua1n_lvt = 0
+dub1n_lvt = 0                                  dlub1n_lvt = 0                                 dwub1n_lvt = 0
+dpub1n_lvt = 0                                 dkt1n_lvt = 0                                  dlkt1n_lvt = 0
+dwkt1n_lvt = 0                                 dpkt1n_lvt = 0                                 deta0n_lvt = '0.03*A1N_lvt'
+dleta0n_lvt = '-3.0e-09*A1N_lvt'               dpeta0n_lvt = '0.0e-15*A1N_lvt'                dweta0n_lvt = '-0.6e-08*A1N_lvt'
+dcdscdn_lvt = 0                                dk2n_lvt = 0                                   dvsatn_lvt = 0
+dlvsatn_lvt = '2.0e-04*A1N_lvt'                dwvsatn_lvt = 0                                dpvsatn_lvt = '-1.0e-11*A1N_lvt'
+dlk2n_lvt = '3e-010*A1N_lvt'                   dwk2n_lvt = '5e-010*A1N_lvt'                   dpk2n_lvt = 0
+tt_flag_lvt    = 0                             ss_flag_lvt    = 0                             ff_flag_lvt    = 0
+sf_flag_lvt    = 0                             fs_flag_lvt    = 1
+toxp_lvt = '2.8e-09 + 6.7000e-11*A4NP_lvt'     dxlp_lvt = '5e-09*A2P_lvt'                     dxwp_lvt = '8e-09*A3P_lvt'
+dvthp_lvt = '-0.027*A1P_lvt'                   dlvthp_lvt = '-1e-09*A1P_lvt'                  dwvthp_lvt = '-3.5e-09*A1P_lvt'
+dpvthp_lvt = '-2e-16*A1P_lvt'                  cjp_lvt = '1.068E-03 * (1+0.070*A1P_lvt)'      cjswp_lvt = '7.600E-11 * (1+0.070*A1P_lvt)'
+cjswgp_lvt = '1.500E-10 * (1+0.070*A1P_lvt)'   cgop_lvt = '7.490E-11 * (1-0.070*A4NP_lvt)'    cglp_lvt = '6.169E-11 * (1-0.070*A4NP_lvt)'
+ddlcp_lvt = 1.054E-08                          du0p_lvt = '0.0000*A1P_lvt'                   dlu0p_lvt = '1.5e-11*A1P_lvt'
+dwu0p_lvt = '0*A1P_lvt'                        dpu0p_lvt = '1.5e-18*A1P_lvt'                    duap_lvt = 0
+dluap_lvt = '0*A1P_lvt'                        dwuap_lvt = 0                                  dpuap_lvt = 0
+dubp_lvt = 0                                   dlubp_lvt = '0*A1P_lvt'                        dwubp_lvt = 0
+dpubp_lvt = 0                                  dub1p_lvt = 0                                  dlub1p_lvt = 0
+dwub1p_lvt = 0                                 dpub1p_lvt = 0                                 dua1p_lvt = 0
+dlua1p_lvt = 0                                 dwua1p_lvt = 0                                 dpua1p_lvt = 0
+datp_lvt = 0                                   dlatp_lvt = 0                                  dwatp_lvt = 0
+dpatp_lvt = 0                                  dutep_lvt = 0                                  dlutep_lvt = 0
+dwutep_lvt = 0                                 dputep_lvt = 0                                 dpclmp_lvt = 0
+dlpclmp_lvt = 0                                dwpclmp_lvt = 0                                dppclmp_lvt = 0
+deta0p_lvt = -0.05                                 dleta0p_lvt = '0*A1P_lvt'                      dweta0p_lvt = '0*A1P_lvt'
+dpeta0p_lvt = 0                                ntoxp_lvt = '1 + -5.4000e-01*A4NP_lvt'         dk2p_lvt = 0
+dlk2p_lvt = '2e-10*A1P_lvt'                    dwk2p_lvt = '4e-10*A1P_lvt'                    dpk2p_lvt = 0
+dcitp_lvt = '0*A1P_lvt'                        dlcitp_lvt = '0*A1P_lvt'                       dwcitp_lvt = 0
+dpcitp_lvt = 0
+cfp_lvt = '1.200E-10*(1-0.070*A4NP_lvt)+5.6e-11*ccoflag_lvt'
+dvoffp_lvt = 0                                 dlvoffp_lvt = '7e-10*A1P_lvt'                  dwvoffp_lvt = 0
+dpvoffp_lvt = '0*A1P_lvt'                      dnfactorp_lvt = '-0.0*A1P_lvt'                 dlnfactorp_lvt = '0*A1P_lvt'
+dwnfactorp_lvt = 0                             dpnfactorp_lvt = 0                             da0p_lvt = 0
+dla0p_lvt = 0                                  dwa0p_lvt = 0                                  dpa0p_lvt = 0
+dagsp_lvt = '0.05*A1P_lvt'                     dlagsp_lvt = 0                                 dwagsp_lvt = 0
+dpagsp_lvt = '0*A1P_lvt'                       dvsatp_lvt = '7000*A1P_lvt'                    dlvsatp_lvt = 0
+dwvsatp_lvt = 0                                dpvsatp_lvt = 0                                dpdiblc2p_lvt = 0
+dlpdiblc2p_lvt = 0                             dwpdiblc2p_lvt = 0                             dppdiblc2p_lvt = 0

+ c1fn_lvt=7.05E+41           c2fn_lvt=1.00E+23           c3fn_lvt=1.00E+7                
+ c1fp_lvt=5.00E+42           c2fp_lvt=1.55E+24           c3fp_lvt=1.00E+10           
+ fn_dice_lvtn='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
+ arearation_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((1e-6*0.06e-6*1)/(15.2E-6*1E-6*1))**0.5)))'
+ noian_lvt='c1fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noibn_lvt='c2fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ noicn_lvt='c3fn_lvt*2.718**((fn_dice_lvtn+(1-fn_dice_lvtn)*noiseflagn_lvt)*arearation_lvt)'
+ fn_dice_lvtp='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
+ arearatiop_lvt='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((1e-6*0.06e-6*1)/(2.3E-6*1E-6*1))**0.5)))'
+ noiap_lvt='c1fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noibp_lvt='c2fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'
+ noicp_lvt='c3fp_lvt*2.718**((fn_dice_lvtp+(1-fn_dice_lvtp)*noiseflagp_lvt)*arearatiop_lvt)'

.lib 'crn65lp_v1d5.l' MAC_lvt
.lib 'crn65lp_v1d5.l' MOS_lvt
.ENDL FS_lvt







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+A1_18='par6*4.8844*3/2.2'
+A2_18='par7*3.6211*3/2.2'
+A3_18='par8*3.1765*3/2.2'
+A4_18='par9*1.3928*3/2.2'
+toxn_18        ='5.6e-09+(-2.9051e-011)*A1_18+(1.0524e-011)*A2_18+(-6.11e-011)*A3_18+(1.9574e-011)*A4_18'
+dxln_18        ='0+(-8.7742e-010)*A1_18+(4.0539e-010)*A2_18+(-2.9313e-009)*A3_18+(7.5636e-010)*A4_18'
+dxwn_18        ='0+(1.2502e-009)*A1_18+(1.4002e-009)*A2_18+(3.7127e-009)*A3_18+(-9.9453e-010)*A4_18'
+cjn_18         ='1.1950e-03+(-1.1483e-005)*A1_18+(-8.9571e-006)*A2_18+(4.3258e-006)*A3_18+(3.3359e-006)*A4_18'
+cjswn_18       ='1.6500e-10+(-1.5855e-012)*A1_18+(-1.2368e-012)*A2_18+(5.9728e-013)*A3_18+(4.6052e-013)*A4_18'
+cjswgn_18      ='2.0800e-10+(-1.9987e-012)*A1_18+(-1.5591e-012)*A2_18+(7.5294e-013)*A3_18+(5.8053e-013)*A4_18'
+cgon_18        ='9.95494e-11+(6.7482e-013)*A1_18+(-2.4444e-013)*A2_18+(1.4192e-012)*A3_18+(-4.5469e-013)*A4_18'
+cgln_18        ='2.67995e-10+(1.8167e-012)*A1_18+(-6.5807e-013)*A2_18+(3.8207e-012)*A3_18+(-1.224e-012)*A4_18'
+dvthn_18       ='0+(-0.0019918)*A1_18+(-0.003373)*A2_18+(0.00046738)*A3_18+(0.00060958)*A4_18'
+dlvthn_18      ='0+(-4.0919e-010)*A1_18+(-4.1802e-010)*A2_18+(1.4887e-010)*A3_18+(1.5429e-010)*A4_18'
+dwvthn_18      ='0+(-1.3431e-010)*A1_18+(-1.3975e-010)*A2_18+(5.0205e-011)*A3_18+(5.6487e-011)*A4_18'
+dpvthn_18      ='0+(-2.983e-016)*A1_18+(-3.235e-016)*A2_18+(1.1844e-016)*A3_18+(1.5571e-016)*A4_18'
+dcitn_18       ='0+(-1.2806e-005)*A1_18+(-1.4097e-005)*A2_18+(5.1948e-006)*A3_18+(7.1655e-006)*A4_18'
+dlcitn_18      ='0+(-2.9669e-012)*A1_18+(-4.4006e-012)*A2_18+(1.8026e-012)*A3_18+(4.2731e-012)*A4_18'
+dwu0n_18       ='0+(1.4056e-011)*A1_18+(1.3852e-011)*A2_18+(-4.8461e-012)*A3_18+(-4.132e-012)*A4_18'
+dpu0n_18       ='0+(1.0153e-017)*A1_18+(6.3139e-018)*A2_18+(-1.5511e-018)*A3_18+(5.5177e-018)*A4_18'
+da0n_18        ='0+(-0.0062062)*A1_18+(0.00093485)*A2_18+(0.0032361)*A3_18+(0.0017039)*A4_18'
+dla0n_18       ='0+(-1.2412e-009)*A1_18+(1.8697e-010)*A2_18+(6.4721e-010)*A3_18+(3.4078e-010)*A4_18'
+dlvsatn_18     ='0+(-8.6887e-005)*A1_18+(1.3088e-005)*A2_18+(4.5305e-005)*A3_18+(2.3855e-005)*A4_18'
+dpvsatn_18     ='0+(-3.125e-012)*A1_18+(6.1228e-013)*A2_18+(-8.7195e-013)*A3_18+(-7.5837e-012)*A4_18'
+dpclmn_18      ='max(-0.18,0+(0.014056)*A1_18+(0.013852)*A2_18+(-0.0048461)*A3_18+(-0.004132)*A4_18)'
+dppclmn_18     ='0+(7.5001e-016)*A1_18+(-1.4695e-016)*A2_18+(2.0927e-016)*A3_18+(1.8201e-015)*A4_18'
+dleta0n_18     ='0+(3.9835e-010)*A1_18+(1.7105e-010)*A2_18+(-2.0374e-011)*A3_18+(3.9304e-010)*A4_18'
+dpeta0n_18     ='0+(5.7782e-016)*A1_18+(7.171e-016)*A2_18+(-2.7718e-016)*A3_18+(-5.0995e-016)*A4_18'
+dk2n_18        ='0+(-0.00098395)*A1_18+(-0.00096966)*A2_18+(0.00033922)*A3_18+(0.00028924)*A4_18'
+dlk2n_18       ='0+(-9.8395e-011)*A1_18+(-9.6966e-011)*A2_18+(3.3922e-011)*A3_18+(2.8924e-011)*A4_18'
+cfn_18         ='9.000000e-011+(6.1008e-013)*A1_18+(-2.2099e-013)*A2_18+(1.2831e-012)*A3_18+(-4.1105e-013)*A4_18+2.4e-11*ccoflag_18'
+toxp_18        ='5.9e-09+(-2.9051e-011)*A1_18+(1.0524e-011)*A2_18+(-6.11e-011)*A3_18+(1.9574e-011)*A4_18'
+dxlp_18        ='0+(-8.7742e-010)*A1_18+(4.0539e-010)*A2_18+(-2.9313e-009)*A3_18+(7.5636e-010)*A4_18'
+dxwp_18        ='max(-3.1e-8,0+(8.5562e-010)*A1_18+(-2.3731e-009)*A2_18+(3.3224e-009)*A3_18+(-8.2073e-010)*A4_18)'
+cjp_18         ='0.001111+(-8.6302e-006)*A1_18+(1.1236e-005)*A2_18+(6.0451e-006)*A3_18+(2.2003e-006)*A4_18'
+cjswp_18       ='9.7000e-11+(-7.535e-013)*A1_18+(9.8097e-013)*A2_18+(5.2778e-013)*A3_18+(1.9205e-013)*A4_18'
+cjswgp_18      ='1.6800e-10+(-1.305e-012)*A1_18+(1.699e-012)*A2_18+(9.141e-013)*A3_18+(3.3263e-013)*A4_18'
+cgop_18        ='1.19935e-10+(8.1294e-013)*A1_18+(-2.9449e-013)*A2_18+(1.7099e-012)*A3_18+(-5.4775e-013)*A4_18'
+cglp_18        ='2.49822e-10+(1.6935e-012)*A1_18+(-6.1344e-013)*A2_18+(3.5616e-012)*A3_18+(-1.141e-012)*A4_18'
+dvthp_18       ='0+(0.0012355)*A1_18+(-0.0038591)*A2_18+(-0.0012154)*A3_18+(-0.00027645)*A4_18'
+dlvthp_18      ='0+(1.3028e-010)*A1_18+(-2.5775e-010)*A2_18+(-1.3019e-010)*A3_18+(-1.1609e-010)*A4_18'
+dwvthp_18      ='0+(1.0768e-010)*A1_18+(-1.7592e-010)*A2_18+(-8.0982e-011)*A3_18+(-2.6836e-011)*A4_18'
+dpvthp_18      ='0+(3.7968e-016)*A1_18+(-6.4722e-016)*A2_18+(-3.0486e-016)*A3_18+(-1.448e-016)*A4_18'
+du0p_18        ='0+(-4.9737e-006)*A1_18+(8.0582e-007)*A2_18+(1.5929e-006)*A3_18+(-2.0111e-006)*A4_18'
+dpu0p_18       ='0+(-3.125e-019)*A1_18+(6.1228e-020)*A2_18+(-8.7195e-020)*A3_18+(-7.5837e-019)*A4_18'
+dlvsatp_18     ='0+(6.2501e-006)*A1_18+(-1.2246e-006)*A2_18+(1.7439e-006)*A3_18+(1.5167e-005)*A4_18'
+dpvsatp_18     ='0+(-7.086e-011)*A1_18+(1.0677e-010)*A2_18+(4.6845e-011)*A3_18+(9.3422e-013)*A4_18'
+dla0p_18       ='0+(-7.2592e-009)*A1_18+(9.1632e-009)*A2_18+(3.5259e-009)*A3_18+(-3.2084e-009)*A4_18'
+dpa0p_18       ='0+(-4.5183e-016)*A1_18+(1.6367e-015)*A2_18+(9.8421e-016)*A3_18+(1.7851e-015)*A4_18'
+dagsp_18       ='0+(-4.5183e-005)*A1_18+(0.00016367)*A2_18+(9.8421e-005)*A3_18+(0.00017851)*A4_18'
+dpeta0p_18     ='0+(3.8555e-016)*A1_18+(-5.4e-016)*A2_18+(-2.2551e-016)*A3_18+(7.1166e-017)*A4_18'
+dlk2p_18       ='0+(-7.5379e-011)*A1_18+(1.2314e-010)*A2_18+(5.6687e-011)*A3_18+(1.8785e-011)*A4_18'
+cfp_18         ='9.000000e-011+(6.1008e-013)*A1_18+(-2.2099e-013)*A2_18+(1.2831e-012)*A3_18+(-4.1105e-013)*A4_18+2.4e-11*ccoflag_18'
+dlcn_18        =6.03005e-08
+dwcitn_18      =0
+dpcitn_18      =0
+du0n_18        =0
+dlu0n_18       =0
+dwa0n_18       =0
+dpa0n_18       =0
+dagsn_18       =0
+dlagsn_18      =0
+dwagsn_18      =0
+dpagsn_18      =0
+dvsatn_18      =0
+dwvsatn_18     =0
+dlpclmn_18     =0
+dwpclmn_18     =0
+deta0n_18      =0
+dweta0n_18     =0
+dwk2n_18       =0
+dpk2n_18       =0
+dlcp_18        =6.40638e-08
+dlu0p_18       =0
+dwu0p_18       =0
+dnfactorp_18   =0
+dlnfactorp_18  =0
+dwnfactorp_18  =0
+dpnfactorp_18  =0
+dvoffp_18      =0
+dlvoffp_18     =0
+dwvoffp_18     =0
+dpvoffp_18     =0
+dcitp_18       =0
+dlcitp_18      =0
+dwcitp_18      =0
+dpcitp_18      =0
+dvsatp_18      =0
+dwvsatp_18     =0
+da0p_18        =0
+dwa0p_18       =0
+dlagsp_18      =0
+dwagsp_18      =0
+dpagsp_18      =0
+dpclmp_18      =0
+dlpclmp_18     =0
+dwpclmp_18     =0
+dppclmp_18     =0
+deta0p_18      =0
+dleta0p_18     =0
+dweta0p_18     =0
+dk2p_18        =0
+dwk2p_18       =0
+dpk2p_18       =0


+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' mos_18
.ENDL mc_18








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+toxn_18        = 5.6e-09       dxln_18        = 0             dxwn_18        = 0
+cjn_18         = 1.1950E-03    cjswn_18       = 1.6500E-10    cjswgn_18      = 2.0800E-10
+cgon_18        = 9.95494E-11   cgln_18        = 2.67995E-10   dlcn_18        = 6.03005E-08
+dvthn_18       = 0             dlvthn_18      = 0             dwvthn_18      = 0
+dpvthn_18      = 0             dcitn_18       = 0             dlcitn_18      = 0
+dwcitn_18      = 0             dpcitn_18      = 0             du0n_18        = 0
+dlu0n_18       = 0             dwu0n_18       = 0             dpu0n_18       = 0
+da0n_18        = 0             dla0n_18       = 0             dwa0n_18       = 0
+dpa0n_18       = 0             dagsn_18       = 0             dlagsn_18      = 0
+dwagsn_18      = 0             dpagsn_18      = 0             dvsatn_18      = 0
+dlvsatn_18     = 0             dwvsatn_18     = 0             dpvsatn_18     = 0
+dpclmn_18      = 0             dlpclmn_18     = 0             dwpclmn_18     = 0
+dppclmn_18     = 0             deta0n_18      = 0             dleta0n_18     = 0
+dweta0n_18     = 0             dpeta0n_18     = 0             dk2n_18        = 0
+dlk2n_18       = 0             dwk2n_18       = 0             dpk2n_18       = 0
+cfn_18         = '9e-11 + 2.4e-11*ccoflag_18'
+toxp_18        = 5.9e-09       dxlp_18        = 0             dxwp_18        = 0
+cjp_18         = 0.001111      cjswp_18       = 9.7000E-11    cjswgp_18      = 1.6800E-10
+cgop_18        = 1.19935E-10   cglp_18        = 2.49822E-10   dlcp_18        = 6.40638E-08
+dvthp_18       = 0             dlvthp_18      = 0             dwvthp_18      = 0
+dpvthp_18      = 0             du0p_18        = 0             dlu0p_18       = 0
+dwu0p_18       = 0             dpu0p_18       = 0             dnfactorp_18   = 0
+dlnfactorp_18  = 0             dwnfactorp_18  = 0             dpnfactorp_18  = 0
+dvoffp_18      = 0             dlvoffp_18     = 0             dwvoffp_18     = 0
+dpvoffp_18     = 0             dcitp_18       = 0             dlcitp_18      = 0
+dwcitp_18      = 0             dpcitp_18      = 0             dvsatp_18      = 0
+dlvsatp_18     = 0             dwvsatp_18     = 0             dpvsatp_18     = 0
+da0p_18        = 0             dla0p_18       = 0             dwa0p_18       = 0
+dpa0p_18       = 0             dagsp_18       = 0             dlagsp_18      = 0
+dwagsp_18      = 0             dpagsp_18      = 0             dpclmp_18      = 0
+dlpclmp_18     = 0             dwpclmp_18     = 0             dppclmp_18     = 0
+deta0p_18      = 0             dleta0p_18     = 0             dweta0p_18     = 0
+dpeta0p_18     = 0             dk2p_18        = 0             dlk2p_18       = 0
+dwk2p_18       = 0             dpk2p_18       = 0             cfp_18         = '9e-11 + 2.4e-11*ccoflag_18'

+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' MAC_18
.lib 'crn65lp_v1d5.l' MOS_18
.ENDL TT_18








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+toxn_18        = 5.9e-09       dxln_18        = 1e-08         dxwn_18        = -1.2e-08
+cjn_18         = 0.00127865    cjswn_18       = 1.7655E-10    cjswgn_18      = 2.2256E-10
+cgon_18        = 9.25809E-11   cgln_18        = 2.49235E-10   dlcn_18        = 6.03005E-08
+dvthn_18       = 0.013         dlvthn_18      = 2.8e-9        dwvthn_18      = 0.9e-9
+dpvthn_18      = 1.9e-15       dcitn_18       = 0.8e-4        dlcitn_18      = 1e-11
+dwcitn_18      = 0             dpcitn_18      = 0             du0n_18        = 0
+dlu0n_18       = 0             dwu0n_18       = -1e-10        dpu0n_18       = -1e-16
+da0n_18        = 0.05          dla0n_18       = 1e-8          dwa0n_18       = 0
+dpa0n_18       = 0             dagsn_18       = 0             dlagsn_18      = 0
+dwagsn_18      = 0             dpagsn_18      = 0             dvsatn_18      = 0
+dlvsatn_18     = 7e-4          dwvsatn_18     = 0             dpvsatn_18     = 0.5e-10
+dpclmn_18      = -0.1          dlpclmn_18     = 0             dwpclmn_18     = 0
+dppclmn_18     = -1.2e-14      deta0n_18      = 0             dleta0n_18     = -4.5e-9
+dweta0n_18     = 0             dpeta0n_18     = -3e-15        dk2n_18        = 0.007
+dlk2n_18       = 7e-10         dwk2n_18       = 0             dpk2n_18       = 0
+cfn_18         = '8.37e-11 + 2.4e-11*ccoflag_18'
+toxp_18        = 6.2e-09       dxlp_18        = 1e-08         dxwp_18        = -1.2e-08
+cjp_18         = 0.00118877    cjswp_18       = 1.0379E-10    cjswgp_18      = 1.7976E-10
+cgop_18        = 1.11540E-10   cglp_18        = 2.32334E-10   dlcp_18        = 6.40638E-08
+dvthp_18       = -0.013        dlvthp_18      = -1e-9         dwvthp_18      = -1e-9
+dpvthp_18      = -3.4e-15      du0p_18        = 0.5e-4        dlu0p_18       = 0
+dwu0p_18       = 0             dpu0p_18       = 0.5e-17       dnfactorp_18   = 0
+dlnfactorp_18  = 0             dwnfactorp_18  = 0             dpnfactorp_18  = 0
+dvoffp_18      = 0             dlvoffp_18     = 0             dwvoffp_18     = 0
+dpvoffp_18     = 0             dcitp_18       = 0             dlcitp_18      = 0
+dwcitp_18      = 0             dpcitp_18      = 0             dvsatp_18      = 0
+dlvsatp_18     = -1e-4         dwvsatp_18     = 0             dpvsatp_18     = 7e-10
+da0p_18        = 0             dla0p_18       = 8e-8          dwa0p_18       = 0
+dpa0p_18       = 0             dagsp_18       = 0             dlagsp_18      = 0
+dwagsp_18      = 0             dpagsp_18      = 0             dpclmp_18      = 0
+dlpclmp_18     = 0             dwpclmp_18     = 0             dppclmp_18     = 0
+deta0p_18      = 0             dleta0p_18     = 0             dweta0p_18     = 0
+dpeta0p_18     = -4e-15        dk2p_18        = 0             dlk2p_18       = 7e-10
+dwk2p_18       = 0             dpk2p_18       = 0             cfp_18         = '8.37e-11 + 2.4e-11*ccoflag_18'

+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' MAC_18
.lib 'crn65lp_v1d5.l' MOS_18
.ENDL SS_18








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+toxn_18        = 5.3e-09       dxln_18        = -1e-08        dxwn_18        = 1.2e-08
+cjn_18         = 0.00111135    cjswn_18       = 1.5345E-10    cjswgn_18      = 1.9344E-10
+cgon_18        = 1.06518E-10   cgln_18        = 2.86755E-10   dlcn_18        = 6.03005E-08
+dvthn_18       = -0.013        dlvthn_18      = -3.0e-9       dwvthn_18      = -1e-9
+dpvthn_18      = -2.3e-15      dcitn_18       = -1e-4         dlcitn_18      = -3e-11
+dwcitn_18      = 0             dpcitn_18      = 0             du0n_18        = 0
+dlu0n_18       = 0             dwu0n_18       = 1e-10         dpu0n_18       = 0.5e-16
+da0n_18        = -0.05         dla0n_18       = -1e-8         dwa0n_18       = 0
+dpa0n_18       = 0             dagsn_18       = 0             dlagsn_18      = 0
+dwagsn_18      = 0             dpagsn_18      = 0             dvsatn_18      = 0
+dlvsatn_18     = -7e-4         dwvsatn_18     = 0             dpvsatn_18     = 0
+dpclmn_18      = 0.1           dlpclmn_18     = 0             dwpclmn_18     = 0
+dppclmn_18     = 0             deta0n_18      = 0             dleta0n_18     = 1.5e-9
+dweta0n_18     = 0             dpeta0n_18     = 5e-15         dk2n_18        = -0.007
+dlk2n_18       = -7e-10        dwk2n_18       = 0             dpk2n_18       = 0
+cfn_18         = '9.63e-11 + 2.4e-11*ccoflag_18'
+toxp_18        = 5.6e-09       dxlp_18        = -1e-08        dxwp_18        = 1.2e-08
+cjp_18         = 0.00103323    cjswp_18       = 9.0210E-11    cjswgp_18      = 1.5624E-10
+cgop_18        = 1.28330E-10   cglp_18        = 2.67310E-10   dlcp_18        = 6.40638E-08
+dvthp_18       = 0.013         dlvthp_18      = 1.5e-9        dwvthp_18      = 1e-9
+dpvthp_18      = 3.7e-15       du0p_18        = -0.3e-4       dlu0p_18       = 0
+dwu0p_18       = 0             dpu0p_18       = 0             dnfactorp_18   = 0
+dlnfactorp_18  = 0             dwnfactorp_18  = 0             dpnfactorp_18  = 0
+dvoffp_18      = 0             dlvoffp_18     = 0             dwvoffp_18     = 0
+dpvoffp_18     = 0             dcitp_18       = 0             dlcitp_18      = 0
+dwcitp_18      = 0             dpcitp_18      = 0             dvsatp_18      = 0
+dlvsatp_18     = 0             dwvsatp_18     = 0             dpvsatp_18     = -6e-10
+da0p_18        = 0             dla0p_18       = -5e-8         dwa0p_18       = 0
+dpa0p_18       = -1e-14        dagsp_18       = -0.001        dlagsp_18      = 0
+dwagsp_18      = 0             dpagsp_18      = 0             dpclmp_18      = 0
+dlpclmp_18     = 0             dwpclmp_18     = 0             dppclmp_18     = 0
+deta0p_18      = 0             dleta0p_18     = 0             dweta0p_18     = 0
+dpeta0p_18     = 3e-15         dk2p_18        = 0             dlk2p_18       = -7e-10
+dwk2p_18       = 0             dpk2p_18       = 0             cfp_18         = '9.63e-11 + 2.4e-11*ccoflag_18'

+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' MAC_18
.lib 'crn65lp_v1d5.l' MOS_18
.ENDL FF_18








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+A1N_18=1 A1P_18=-1 A2N_18=0 A2P_18=0 A3N_18=-1 A3P_18=1 A4NP_18=0
+toxn_18 = '5.6e-09 + 3.0000e-010*A4NP_18'     dxln_18 = '1e-008*A2N_18'                     dxwn_18 = '1.2e-008*A3N_18'
+cjn_18 = '1.1950E-03 * (1+0.070*0.8)'      cjswn_18 = '1.6500E-10 * (1+0.070*0.8)'    cjswgn_18 = '2.0800E-10 * (1+0.070*0.8)'
+cgon_18 = '9.95494E-11 * (1-0.070*A4NP_18)'   cgln_18 = '2.67995E-10 * (1-0.070*A4NP_18)'   dlcn_18 = 6.03005E-08
+dvthn_18 = '0.023*A1N_18'                     dlvthn_18 = '3e-009*A1N_18'                   dwvthn_18 = '1e-009*A1N_18'
+dpvthn_18 = '2.3e-015*A1N_18'                 dcitn_18 = '0.0001*A1N_18'                    dlcitn_18 = '3e-011*A1N_18'
+dwcitn_18 = 0                                 dpcitn_18 = 0                                 du0n_18 = 0
+dlu0n_18 = 0                                  dwu0n_18 = '-1e-010*A1N_18'                   dpu0n_18 = '-5e-017*A1N_18'
+da0n_18 = '0.00*A1N_18'                       dla0n_18 = '0e-008*A1N_18'                    dwa0n_18 = 0
+dpa0n_18 = 0                                  dagsn_18 = 0                                  dlagsn_18 = 0
+dwagsn_18 = 0                                 dpagsn_18 = 0                                 dvsatn_18 = 0
+dlvsatn_18 = '0.0000*A1N_18'                  dwvsatn_18 = 0                                dpvsatn_18 = 0
+dpclmn_18 = '-0.1*A1N_18'                     dlpclmn_18 = 0                                dwpclmn_18 = 0
+dppclmn_18 = 0                                deta0n_18 = 0                                 dleta0n_18 = '-1.5e-009*A1N_18'
+dweta0n_18 = 0                                dpeta0n_18 = '-5e-015*A1N_18'                 dk2n_18 = '0.007*A1N_18'
+dlk2n_18 = '7e-010*A1N_18'                    dwk2n_18 = 0                                  dpk2n_18 = 0
+cfn_18 = '9e-11*(1-0.070*A4NP_18)+2.4e-11*ccoflag_18'
+toxp_18 = '5.9e-09 + 3.0000e-010*A4NP_18'     dxlp_18 = '1e-008*A2P_18'                     dxwp_18 = '1.2e-008*A3P_18'
+cjp_18 = '0.001111 * (1+0.070*-0.8)'        cjswp_18 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgp_18 = '1.6800E-10 * (1+0.070*-0.8)'
+cgop_18 = '1.19935E-10 * (1-0.070*A4NP_18)'   cglp_18 = '2.49822E-10 * (1-0.070*A4NP_18)'   dlcp_18 = 6.40638E-08
+dvthp_18 = '-0.023*A1P_18'                    dlvthp_18 = '-1.5e-009*A1P_18'                dwvthp_18 = '-1e-009*A1P_18'
+dpvthp_18 = '-3.7e-015*A1P_18'                du0p_18 = '0e-005*A1P_18'                     dlu0p_18 = 0
+dwu0p_18 = 0                                  dpu0p_18 = 0                                  dnfactorp_18 = 0
+dlnfactorp_18 = 0                             dwnfactorp_18 = 0                             dpnfactorp_18 = 0
+dvoffp_18 = 0                                 dlvoffp_18 = 0                                dwvoffp_18 = 0
+dpvoffp_18 = 0                                dcitp_18 = 0                                  dlcitp_18 = 0
+dwcitp_18 = 0                                 dpcitp_18 = 0                                 dvsatp_18 = 0
+dlvsatp_18 = 0                                dwvsatp_18 = 0                                dpvsatp_18 = '6e-010*A1P_18'
+da0p_18 = 0                                   dla0p_18 = '5e-008*A1P_18'                    dwa0p_18 = 0
+dpa0p_18 = '1e-014*A1P_18'                    dagsp_18 = '0.001*A1P_18'                     dlagsp_18 = 0
+dwagsp_18 = 0                                 dpagsp_18 = 0                                 dpclmp_18 = 0
+dlpclmp_18 = 0                                dwpclmp_18 = 0                                dppclmp_18 = 0
+deta0p_18 = 0                                 dleta0p_18 = 0                                dweta0p_18 = 0
+dpeta0p_18 = '-3e-015*A1P_18'                 dk2p_18 = 0                                   dlk2p_18 = '7e-010*A1P_18'
+dwk2p_18 = 0                                  dpk2p_18 = 0
+cfp_18 = '9e-11*(1-0.070*A4NP_18)+2.4e-11*ccoflag_18'

+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' MAC_18
.lib 'crn65lp_v1d5.l' MOS_18
.ENDL SF_18








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_18
.lib 'crn65lp_v1d5.l' noiseflag_18
.lib 'crn65lp_v1d5.l' post_simu_18
.param
+parn1_18=AGAUSS(0,1,1)
+parn2_18=AGAUSS(0,1,1)
+parp1_18=AGAUSS(0,1,1)
+parp2_18=AGAUSS(0,1,1)
+A1N_18=-1 A1P_18=1 A2N_18=0 A2P_18=0 A3N_18=1 A3P_18=-1 A4NP_18=0
+toxn_18 = '5.6e-09 + 3.0000e-010*A4NP_18'     dxln_18 = '1e-008*A2N_18'                     dxwn_18 = '1.2e-008*A3N_18'
+cjn_18 = '1.1950E-03 * (1+0.070*-0.8)'      cjswn_18 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgn_18 = '2.0800E-10 * (1+0.070*-0.8)'
+cgon_18 = '9.95494E-11 * (1-0.070*A4NP_18)'   cgln_18 = '2.67995E-10 * (1-0.070*A4NP_18)'   dlcn_18 = 6.03005E-08
+dvthn_18 = '0.023*A1N_18'                     dlvthn_18 = '3e-009*A1N_18'                   dwvthn_18 = '1e-009*A1N_18'
+dpvthn_18 = '2.3e-015*A1N_18'                 dcitn_18 = '0.0001*A1N_18'                    dlcitn_18 = '3e-011*A1N_18'
+dwcitn_18 = 0                                 dpcitn_18 = 0                                 du0n_18 = 0
+dlu0n_18 = 0                                  dwu0n_18 = '-1e-010*A1N_18'                   dpu0n_18 = '-5e-017*A1N_18'
+da0n_18 = '0.00*A1N_18'                       dla0n_18 = '0e-008*A1N_18'                    dwa0n_18 = 0
+dpa0n_18 = 0                                  dagsn_18 = 0                                  dlagsn_18 = 0
+dwagsn_18 = 0                                 dpagsn_18 = 0                                 dvsatn_18 = 0
+dlvsatn_18 = '0.0000*A1N_18'                  dwvsatn_18 = 0                                dpvsatn_18 = 0
+dpclmn_18 = '-0.1*A1N_18'                     dlpclmn_18 = 0                                dwpclmn_18 = 0
+dppclmn_18 = 0                                deta0n_18 = 0                                 dleta0n_18 = '-1.5e-009*A1N_18'
+dweta0n_18 = 0                                dpeta0n_18 = '-5e-015*A1N_18'                 dk2n_18 = '0.007*A1N_18'
+dlk2n_18 = '7e-010*A1N_18'                    dwk2n_18 = 0                                  dpk2n_18 = 0
+cfn_18 = '9e-11*(1-0.070*A4NP_18)+2.4e-11*ccoflag_18'
+toxp_18 = '5.9e-09 + 3.0000e-010*A4NP_18'     dxlp_18 = '1e-008*A2P_18'                     dxwp_18 = '1.2e-008*A3P_18'
+cjp_18 = '0.001111 * (1+0.070*0.8)'        cjswp_18 = '9.7000E-11 * (1+0.070*0.8)'    cjswgp_18 = '1.6800E-10 * (1+0.070*0.8)'
+cgop_18 = '1.19935E-10 * (1-0.070*A4NP_18)'   cglp_18 = '2.49822E-10 * (1-0.070*A4NP_18)'   dlcp_18 = 6.40638E-08
+dvthp_18 = '-0.023*A1P_18'                    dlvthp_18 = '-1.5e-009*A1P_18'                dwvthp_18 = '-1e-009*A1P_18'
+dpvthp_18 = '-3.7e-015*A1P_18'                du0p_18 = '0e-005*A1P_18'                     dlu0p_18 = 0
+dwu0p_18 = 0                                  dpu0p_18 = 0                                  dnfactorp_18 = 0
+dlnfactorp_18 = 0                             dwnfactorp_18 = 0                             dpnfactorp_18 = 0
+dvoffp_18 = 0                                 dlvoffp_18 = 0                                dwvoffp_18 = 0
+dpvoffp_18 = 0                                dcitp_18 = 0                                  dlcitp_18 = 0
+dwcitp_18 = 0                                 dpcitp_18 = 0                                 dvsatp_18 = 0
+dlvsatp_18 = 0                                dwvsatp_18 = 0                                dpvsatp_18 = '6e-010*A1P_18'
+da0p_18 = 0                                   dla0p_18 = '5e-008*A1P_18'                    dwa0p_18 = 0
+dpa0p_18 = '1e-014*A1P_18'                    dagsp_18 = '0.001*A1P_18'                     dlagsp_18 = 0
+dwagsp_18 = 0                                 dpagsp_18 = 0                                 dpclmp_18 = 0
+dlpclmp_18 = 0                                dwpclmp_18 = 0                                dppclmp_18 = 0
+deta0p_18 = 0                                 dleta0p_18 = 0                                dweta0p_18 = 0
+dpeta0p_18 = '-3e-015*A1P_18'                 dk2p_18 = 0                                   dlk2p_18 = '7e-010*A1P_18'
+dwk2p_18 = 0                                  dpk2p_18 = 0
+cfp_18 = '9e-11*(1-0.070*A4NP_18)+2.4e-11*ccoflag_18'

+ c1fn_18=8.00E+41           c2fn_18=5.55E+24           c3fn_18=7.75E+6                     
+ c1fp_18=2.40E+41           c2fp_18=9.00E+21           c3fp_18=2.00E+09           
+ fn_dice_18n='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
+ arearation_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_18='c1fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noibn_18='c2fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ noicn_18='c3fn_18*2.718**((fn_dice_18n+(1-fn_dice_18n)*noiseflagn_18)*arearation_18)'
+ fn_dice_18p='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
+ arearatiop_18='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_18='c1fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noibp_18='c2fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'
+ noicp_18='c3fp_18*2.718**((fn_dice_18p+(1-fn_dice_18p)*noiseflagp_18)*arearatiop_18)'

.lib 'crn65lp_v1d5.l' MAC_18
.lib 'crn65lp_v1d5.l' MOS_18
.ENDL FS_18







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+A1_25='par6*4.8844*3/2.2'
+A2_25='par7*3.6211*3/2.2'
+A3_25='par8*3.1765*3/2.2'
+A4_25='par9*1.3928*3/2.2'
+toxn_25        ='5.6e-09+(-2.9051e-011)*A1_25+(1.0524e-011)*A2_25+(-6.11e-011)*A3_25+(1.9574e-011)*A4_25'
+dxln_25        ='0+(-8.7742e-010)*A1_25+(4.0539e-010)*A2_25+(-2.9313e-009)*A3_25+(7.5636e-010)*A4_25'
+dxwn_25        ='0+(1.2502e-009)*A1_25+(1.4002e-009)*A2_25+(3.7127e-009)*A3_25+(-9.9453e-010)*A4_25'
+cjn_25         ='1.1950e-03+(-1.1483e-005)*A1_25+(-8.9571e-006)*A2_25+(4.3258e-006)*A3_25+(3.3359e-006)*A4_25'
+cjswn_25       ='1.6500e-10+(-1.5855e-012)*A1_25+(-1.2368e-012)*A2_25+(5.9728e-013)*A3_25+(4.6052e-013)*A4_25'
+cjswgn_25      ='2.0800e-10+(-1.9987e-012)*A1_25+(-1.5591e-012)*A2_25+(7.5294e-013)*A3_25+(5.8053e-013)*A4_25'
+cgon_25        ='9.95494e-11+(6.7482e-013)*A1_25+(-2.4444e-013)*A2_25+(1.4192e-012)*A3_25+(-4.5469e-013)*A4_25'
+cgln_25        ='2.67995e-10+(1.8167e-012)*A1_25+(-6.5807e-013)*A2_25+(3.8207e-012)*A3_25+(-1.224e-012)*A4_25'
+dvthn_25       ='0+(-0.0019918)*A1_25+(-0.003373)*A2_25+(0.00046738)*A3_25+(0.00060958)*A4_25'
+dlvthn_25      ='0+(-4.0919e-010)*A1_25+(-4.1802e-010)*A2_25+(1.4887e-010)*A3_25+(1.5429e-010)*A4_25'
+dwvthn_25      ='0+(-1.3431e-010)*A1_25+(-1.3975e-010)*A2_25+(5.0205e-011)*A3_25+(5.6487e-011)*A4_25'
+dpvthn_25      ='0+(-2.983e-016)*A1_25+(-3.235e-016)*A2_25+(1.1844e-016)*A3_25+(1.5571e-016)*A4_25'
+dcitn_25       ='0+(-1.2806e-005)*A1_25+(-1.4097e-005)*A2_25+(5.1948e-006)*A3_25+(7.1655e-006)*A4_25'
+dlcitn_25      ='0+(-2.9669e-012)*A1_25+(-4.4006e-012)*A2_25+(1.8026e-012)*A3_25+(4.2731e-012)*A4_25'
+dwu0n_25       ='0+(1.4056e-011)*A1_25+(1.3852e-011)*A2_25+(-4.8461e-012)*A3_25+(-4.132e-012)*A4_25'
+dpu0n_25       ='0+(1.0153e-017)*A1_25+(6.3139e-018)*A2_25+(-1.5511e-018)*A3_25+(5.5177e-018)*A4_25'
+da0n_25        ='0+(-0.0062062)*A1_25+(0.00093485)*A2_25+(0.0032361)*A3_25+(0.0017039)*A4_25'
+dla0n_25       ='0+(-1.2412e-009)*A1_25+(1.8697e-010)*A2_25+(6.4721e-010)*A3_25+(3.4078e-010)*A4_25'
+dlvsatn_25     ='0+(-8.6887e-005)*A1_25+(1.3088e-005)*A2_25+(4.5305e-005)*A3_25+(2.3855e-005)*A4_25'
+dpvsatn_25     ='0+(-3.125e-012)*A1_25+(6.1228e-013)*A2_25+(-8.7195e-013)*A3_25+(-7.5837e-012)*A4_25'
+dpclmn_25      ='max(-0.18,0+(0.014056)*A1_25+(0.013852)*A2_25+(-0.0048461)*A3_25+(-0.004132)*A4_25)'
+dppclmn_25     ='0+(7.5001e-016)*A1_25+(-1.4695e-016)*A2_25+(2.0927e-016)*A3_25+(1.8201e-015)*A4_25'
+dleta0n_25     ='0+(3.9835e-010)*A1_25+(1.7105e-010)*A2_25+(-2.0374e-011)*A3_25+(3.9304e-010)*A4_25'
+dpeta0n_25     ='0+(5.7782e-016)*A1_25+(7.171e-016)*A2_25+(-2.7718e-016)*A3_25+(-5.0995e-016)*A4_25'
+dk2n_25        ='0+(-0.00098395)*A1_25+(-0.00096966)*A2_25+(0.00033922)*A3_25+(0.00028924)*A4_25'
+dlk2n_25       ='0+(-9.8395e-011)*A1_25+(-9.6966e-011)*A2_25+(3.3922e-011)*A3_25+(2.8924e-011)*A4_25'
+cfn_25         ='9.000000e-011+(6.1008e-013)*A1_25+(-2.2099e-013)*A2_25+(1.2831e-012)*A3_25+(-4.1105e-013)*A4_25+2.4e-11*ccoflag_25'
+toxp_25        ='5.9e-09+(-2.9051e-011)*A1_25+(1.0524e-011)*A2_25+(-6.11e-011)*A3_25+(1.9574e-011)*A4_25'
+dxlp_25        ='0+(-8.7742e-010)*A1_25+(4.0539e-010)*A2_25+(-2.9313e-009)*A3_25+(7.5636e-010)*A4_25'
+dxwp_25        ='max(-3.1e-8,0+(8.5562e-010)*A1_25+(-2.3731e-009)*A2_25+(3.3224e-009)*A3_25+(-8.2073e-010)*A4_25)'
+cjp_25         ='0.001111+(-8.6302e-006)*A1_25+(1.1236e-005)*A2_25+(6.0451e-006)*A3_25+(2.2003e-006)*A4_25'
+cjswp_25       ='9.7000e-11+(-7.535e-013)*A1_25+(9.8097e-013)*A2_25+(5.2778e-013)*A3_25+(1.9205e-013)*A4_25'
+cjswgp_25      ='1.6800e-10+(-1.305e-012)*A1_25+(1.699e-012)*A2_25+(9.141e-013)*A3_25+(3.3263e-013)*A4_25'
+cgop_25        ='1.19935e-10+(8.1294e-013)*A1_25+(-2.9449e-013)*A2_25+(1.7099e-012)*A3_25+(-5.4775e-013)*A4_25'
+cglp_25        ='2.49822e-10+(1.6935e-012)*A1_25+(-6.1344e-013)*A2_25+(3.5616e-012)*A3_25+(-1.141e-012)*A4_25'
+dvthp_25       ='0+(0.0012355)*A1_25+(-0.0038591)*A2_25+(-0.0012154)*A3_25+(-0.00027645)*A4_25'
+dlvthp_25      ='0+(1.3028e-010)*A1_25+(-2.5775e-010)*A2_25+(-1.3019e-010)*A3_25+(-1.1609e-010)*A4_25'
+dwvthp_25      ='0+(1.0768e-010)*A1_25+(-1.7592e-010)*A2_25+(-8.0982e-011)*A3_25+(-2.6836e-011)*A4_25'
+dpvthp_25      ='0+(3.7968e-016)*A1_25+(-6.4722e-016)*A2_25+(-3.0486e-016)*A3_25+(-1.448e-016)*A4_25'
+du0p_25        ='0+(-4.9737e-006)*A1_25+(8.0582e-007)*A2_25+(1.5929e-006)*A3_25+(-2.0111e-006)*A4_25'
+dpu0p_25       ='0+(-3.125e-019)*A1_25+(6.1228e-020)*A2_25+(-8.7195e-020)*A3_25+(-7.5837e-019)*A4_25'
+dlvsatp_25     ='0+(6.2501e-006)*A1_25+(-1.2246e-006)*A2_25+(1.7439e-006)*A3_25+(1.5167e-005)*A4_25'
+dpvsatp_25     ='0+(-7.086e-011)*A1_25+(1.0677e-010)*A2_25+(4.6845e-011)*A3_25+(9.3422e-013)*A4_25'
+dla0p_25       ='0+(-7.2592e-009)*A1_25+(9.1632e-009)*A2_25+(3.5259e-009)*A3_25+(-3.2084e-009)*A4_25'
+dpa0p_25       ='0+(-4.5183e-016)*A1_25+(1.6367e-015)*A2_25+(9.8421e-016)*A3_25+(1.7851e-015)*A4_25'
+dagsp_25       ='0+(-4.5183e-005)*A1_25+(0.00016367)*A2_25+(9.8421e-005)*A3_25+(0.00017851)*A4_25'
+dpeta0p_25     ='0+(3.8555e-016)*A1_25+(-5.4e-016)*A2_25+(-2.2551e-016)*A3_25+(7.1166e-017)*A4_25'
+dlk2p_25       ='0+(-7.5379e-011)*A1_25+(1.2314e-010)*A2_25+(5.6687e-011)*A3_25+(1.8785e-011)*A4_25'
+cfp_25         ='9.000000e-011+(6.1008e-013)*A1_25+(-2.2099e-013)*A2_25+(1.2831e-012)*A3_25+(-4.1105e-013)*A4_25+2.4e-11*ccoflag_25'
+dlcn_25        =6.03005e-08
+dwcitn_25      =0
+dpcitn_25      =0
+du0n_25        =0
+dlu0n_25       =0
+dwa0n_25       =0
+dpa0n_25       =0
+dagsn_25       =0
+dlagsn_25      =0
+dwagsn_25      =0
+dpagsn_25      =0
+dvsatn_25      =0
+dwvsatn_25     =0
+dlpclmn_25     =0
+dwpclmn_25     =0
+deta0n_25      =0
+dweta0n_25     =0
+dwk2n_25       =0
+dpk2n_25       =0
+dlcp_25        =6.40638e-08
+dlu0p_25       =0
+dwu0p_25       =0
+dnfactorp_25   =0
+dlnfactorp_25  =0
+dwnfactorp_25  =0
+dpnfactorp_25  =0
+dvoffp_25      =0
+dlvoffp_25     =0
+dwvoffp_25     =0
+dpvoffp_25     =0
+dcitp_25       =0
+dlcitp_25      =0
+dwcitp_25      =0
+dpcitp_25      =0
+dvsatp_25      =0
+dwvsatp_25     =0
+da0p_25        =0
+dwa0p_25       =0
+dlagsp_25      =0
+dwagsp_25      =0
+dpagsp_25      =0
+dpclmp_25      =0
+dlpclmp_25     =0
+dwpclmp_25     =0
+dppclmp_25     =0
+deta0p_25      =0
+dleta0p_25     =0
+dweta0p_25     =0
+dk2p_25        =0
+dwk2p_25       =0
+dpk2p_25       =0
   
+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'


.lib 'crn65lp_v1d5.l' mos_25
.ENDL mc_25








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+toxn_25        = 5.6e-09       dxln_25        = 0             dxwn_25        = 0
+cjn_25         = 1.1950E-03    cjswn_25       = 1.6500E-10    cjswgn_25      = 2.0800E-10
+cgon_25        = 9.95494E-11   cgln_25        = 2.67995E-10   dlcn_25        = 6.03005E-08
+dvthn_25       = 0             dlvthn_25      = 0             dwvthn_25      = 0
+dpvthn_25      = 0             dcitn_25       = 0             dlcitn_25      = 0
+dwcitn_25      = 0             dpcitn_25      = 0             du0n_25        = 0
+dlu0n_25       = 0             dwu0n_25       = 0             dpu0n_25       = 0
+da0n_25        = 0             dla0n_25       = 0             dwa0n_25       = 0
+dpa0n_25       = 0             dagsn_25       = 0             dlagsn_25      = 0
+dwagsn_25      = 0             dpagsn_25      = 0             dvsatn_25      = 0
+dlvsatn_25     = 0             dwvsatn_25     = 0             dpvsatn_25     = 0
+dpclmn_25      = 0             dlpclmn_25     = 0             dwpclmn_25     = 0
+dppclmn_25     = 0             deta0n_25      = 0             dleta0n_25     = 0
+dweta0n_25     = 0             dpeta0n_25     = 0             dk2n_25        = 0
+dlk2n_25       = 0             dwk2n_25       = 0             dpk2n_25       = 0
+cfn_25         = '9e-11 + 2.4e-11*ccoflag_25'
+toxp_25        = 5.9e-09       dxlp_25        = 0             dxwp_25        = 0
+cjp_25         = 0.001111      cjswp_25       = 9.7000E-11    cjswgp_25      = 1.6800E-10
+cgop_25        = 1.19935E-10   cglp_25        = 2.49822E-10   dlcp_25        = 6.40638E-08
+dvthp_25       = 0             dlvthp_25      = 0             dwvthp_25      = 0
+dpvthp_25      = 0             du0p_25        = 0             dlu0p_25       = 0
+dwu0p_25       = 0             dpu0p_25       = 0             dnfactorp_25   = 0
+dlnfactorp_25  = 0             dwnfactorp_25  = 0             dpnfactorp_25  = 0
+dvoffp_25      = 0             dlvoffp_25     = 0             dwvoffp_25     = 0
+dpvoffp_25     = 0             dcitp_25       = 0             dlcitp_25      = 0
+dwcitp_25      = 0             dpcitp_25      = 0             dvsatp_25      = 0
+dlvsatp_25     = 0             dwvsatp_25     = 0             dpvsatp_25     = 0
+da0p_25        = 0             dla0p_25       = 0             dwa0p_25       = 0
+dpa0p_25       = 0             dagsp_25       = 0             dlagsp_25      = 0
+dwagsp_25      = 0             dpagsp_25      = 0             dpclmp_25      = 0
+dlpclmp_25     = 0             dwpclmp_25     = 0             dppclmp_25     = 0
+deta0p_25      = 0             dleta0p_25     = 0             dweta0p_25     = 0
+dpeta0p_25     = 0             dk2p_25        = 0             dlk2p_25       = 0
+dwk2p_25       = 0             dpk2p_25       = 0             cfp_25         = '9e-11 + 2.4e-11*ccoflag_25'

+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'

.lib 'crn65lp_v1d5.l' MAC_25
.lib 'crn65lp_v1d5.l' MOS_25
.ENDL TT_25








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+toxn_25        = 5.9e-09       dxln_25        = 1e-08         dxwn_25        = -1.2e-08
+cjn_25         = 0.00127865    cjswn_25       = 1.7655E-10    cjswgn_25      = 2.2256E-10
+cgon_25        = 9.25809E-11   cgln_25        = 2.49235E-10   dlcn_25        = 6.03005E-08
+dvthn_25       = 0.013         dlvthn_25      = 2.8e-9        dwvthn_25      = 0.9e-9
+dpvthn_25      = 1.9e-15       dcitn_25       = 0.8e-4        dlcitn_25      = 1e-11
+dwcitn_25      = 0             dpcitn_25      = 0             du0n_25        = 0
+dlu0n_25       = 0             dwu0n_25       = -1e-10        dpu0n_25       = -1e-16
+da0n_25        = 0.05          dla0n_25       = 1e-8          dwa0n_25       = 0
+dpa0n_25       = 0             dagsn_25       = 0             dlagsn_25      = 0
+dwagsn_25      = 0             dpagsn_25      = 0             dvsatn_25      = 0
+dlvsatn_25     = 7e-4          dwvsatn_25     = 0             dpvsatn_25     = 0.5e-10
+dpclmn_25      = -0.1          dlpclmn_25     = 0             dwpclmn_25     = 0
+dppclmn_25     = -1.2e-14      deta0n_25      = 0             dleta0n_25     = -4.5e-9
+dweta0n_25     = 0             dpeta0n_25     = -3e-15        dk2n_25        = 0.007
+dlk2n_25       = 7e-10         dwk2n_25       = 0             dpk2n_25       = 0
+cfn_25         = '8.37e-11 + 2.4e-11*ccoflag_25'
+toxp_25        = 6.2e-09       dxlp_25        = 1e-08         dxwp_25        = -1.2e-08
+cjp_25         = 0.00118877    cjswp_25       = 1.0379E-10    cjswgp_25      = 1.7976E-10
+cgop_25        = 1.11540E-10   cglp_25        = 2.32334E-10   dlcp_25        = 6.40638E-08
+dvthp_25       = -0.013        dlvthp_25      = -1e-9         dwvthp_25      = -1e-9
+dpvthp_25      = -3.4e-15      du0p_25        = 0.5e-4        dlu0p_25       = 0
+dwu0p_25       = 0             dpu0p_25       = 0.5e-17       dnfactorp_25   = 0
+dlnfactorp_25  = 0             dwnfactorp_25  = 0             dpnfactorp_25  = 0
+dvoffp_25      = 0             dlvoffp_25     = 0             dwvoffp_25     = 0
+dpvoffp_25     = 0             dcitp_25       = 0             dlcitp_25      = 0
+dwcitp_25      = 0             dpcitp_25      = 0             dvsatp_25      = 0
+dlvsatp_25     = -1e-4         dwvsatp_25     = 0             dpvsatp_25     = 7e-10
+da0p_25        = 0             dla0p_25       = 8e-8          dwa0p_25       = 0
+dpa0p_25       = 0             dagsp_25       = 0             dlagsp_25      = 0
+dwagsp_25      = 0             dpagsp_25      = 0             dpclmp_25      = 0
+dlpclmp_25     = 0             dwpclmp_25     = 0             dppclmp_25     = 0
+deta0p_25      = 0             dleta0p_25     = 0             dweta0p_25     = 0
+dpeta0p_25     = -4e-15        dk2p_25        = 0             dlk2p_25       = 7e-10
+dwk2p_25       = 0             dpk2p_25       = 0             cfp_25         = '8.37e-11 + 2.4e-11*ccoflag_25'

+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'

.lib 'crn65lp_v1d5.l' MAC_25
.lib 'crn65lp_v1d5.l' MOS_25
.ENDL SS_25








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+toxn_25        = 5.3e-09       dxln_25        = -1e-08        dxwn_25        = 1.2e-08
+cjn_25         = 0.00111135    cjswn_25       = 1.5345E-10    cjswgn_25      = 1.9344E-10
+cgon_25        = 1.06518E-10   cgln_25        = 2.86755E-10   dlcn_25        = 6.03005E-08
+dvthn_25       = -0.013        dlvthn_25      = -3.0e-9       dwvthn_25      = -1e-9
+dpvthn_25      = -2.3e-15      dcitn_25       = -1e-4         dlcitn_25      = -3e-11
+dwcitn_25      = 0             dpcitn_25      = 0             du0n_25        = 0
+dlu0n_25       = 0             dwu0n_25       = 1e-10         dpu0n_25       = 0.5e-16
+da0n_25        = -0.05         dla0n_25       = -1e-8         dwa0n_25       = 0
+dpa0n_25       = 0             dagsn_25       = 0             dlagsn_25      = 0
+dwagsn_25      = 0             dpagsn_25      = 0             dvsatn_25      = 0
+dlvsatn_25     = -7e-4         dwvsatn_25     = 0             dpvsatn_25     = 0
+dpclmn_25      = 0.1           dlpclmn_25     = 0             dwpclmn_25     = 0
+dppclmn_25     = 0             deta0n_25      = 0             dleta0n_25     = 1.5e-9
+dweta0n_25     = 0             dpeta0n_25     = 5e-15         dk2n_25        = -0.007
+dlk2n_25       = -7e-10        dwk2n_25       = 0             dpk2n_25       = 0
+cfn_25         = '9.63e-11 + 2.4e-11*ccoflag_25'
+toxp_25        = 5.6e-09       dxlp_25        = -1e-08        dxwp_25        = 1.2e-08
+cjp_25         = 0.00103323    cjswp_25       = 9.0210E-11    cjswgp_25      = 1.5624E-10
+cgop_25        = 1.28330E-10   cglp_25        = 2.67310E-10   dlcp_25        = 6.40638E-08
+dvthp_25       = 0.013         dlvthp_25      = 1.5e-9        dwvthp_25      = 1e-9
+dpvthp_25      = 3.7e-15       du0p_25        = -0.3e-4       dlu0p_25       = 0
+dwu0p_25       = 0             dpu0p_25       = 0             dnfactorp_25   = 0
+dlnfactorp_25  = 0             dwnfactorp_25  = 0             dpnfactorp_25  = 0
+dvoffp_25      = 0             dlvoffp_25     = 0             dwvoffp_25     = 0
+dpvoffp_25     = 0             dcitp_25       = 0             dlcitp_25      = 0
+dwcitp_25      = 0             dpcitp_25      = 0             dvsatp_25      = 0
+dlvsatp_25     = 0             dwvsatp_25     = 0             dpvsatp_25     = -6e-10
+da0p_25        = 0             dla0p_25       = -5e-8         dwa0p_25       = 0
+dpa0p_25       = -1e-14        dagsp_25       = -0.001        dlagsp_25      = 0
+dwagsp_25      = 0             dpagsp_25      = 0             dpclmp_25      = 0
+dlpclmp_25     = 0             dwpclmp_25     = 0             dppclmp_25     = 0
+deta0p_25      = 0             dleta0p_25     = 0             dweta0p_25     = 0
+dpeta0p_25     = 3e-15         dk2p_25        = 0             dlk2p_25       = -7e-10
+dwk2p_25       = 0             dpk2p_25       = 0             cfp_25         = '9.63e-11 + 2.4e-11*ccoflag_25'

+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'

.lib 'crn65lp_v1d5.l' MAC_25
.lib 'crn65lp_v1d5.l' MOS_25
.ENDL FF_25








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+A1N_25=1 A1P_25=-1 A2N_25=0 A2P_25=0 A3N_25=-1 A3P_25=1 A4NP_25=0
+toxn_25 = '5.6e-09 + 3.0000e-010*A4NP_25'     dxln_25 = '1e-008*A2N_25'                     dxwn_25 = '1.2e-008*A3N_25'
+cjn_25 = '1.1950E-03 * (1+0.070*0.8)'      cjswn_25 = '1.6500E-10 * (1+0.070*0.8)'    cjswgn_25 = '2.0800E-10 * (1+0.070*0.8)'
+cgon_25 = '9.95494E-11 * (1-0.070*A4NP_25)'   cgln_25 = '2.67995E-10 * (1-0.070*A4NP_25)'   dlcn_25 = 6.03005E-08
+dvthn_25 = '0.023*A1N_25'                     dlvthn_25 = '3e-009*A1N_25'                   dwvthn_25 = '1e-009*A1N_25'
+dpvthn_25 = '2.3e-015*A1N_25'                 dcitn_25 = '0.0001*A1N_25'                    dlcitn_25 = '3e-011*A1N_25'
+dwcitn_25 = 0                                 dpcitn_25 = 0                                 du0n_25 = 0
+dlu0n_25 = 0                                  dwu0n_25 = '-1e-010*A1N_25'                   dpu0n_25 = '-5e-017*A1N_25'
+da0n_25 = '0.00*A1N_25'                       dla0n_25 = '0e-008*A1N_25'                    dwa0n_25 = 0
+dpa0n_25 = 0                                  dagsn_25 = 0                                  dlagsn_25 = 0
+dwagsn_25 = 0                                 dpagsn_25 = 0                                 dvsatn_25 = 0
+dlvsatn_25 = '0.0000*A1N_25'                  dwvsatn_25 = 0                                dpvsatn_25 = 0
+dpclmn_25 = '-0.1*A1N_25'                     dlpclmn_25 = 0                                dwpclmn_25 = 0
+dppclmn_25 = 0                                deta0n_25 = 0                                 dleta0n_25 = '-1.5e-009*A1N_25'
+dweta0n_25 = 0                                dpeta0n_25 = '-5e-015*A1N_25'                 dk2n_25 = '0.007*A1N_25'
+dlk2n_25 = '7e-010*A1N_25'                    dwk2n_25 = 0                                  dpk2n_25 = 0
+cfn_25 = '9e-11*(1-0.070*A4NP_25)+2.4e-11*ccoflag_25'
+toxp_25 = '5.9e-09 + 3.0000e-010*A4NP_25'     dxlp_25 = '1e-008*A2P_25'                     dxwp_25 = '1.2e-008*A3P_25'
+cjp_25 = '0.001111 * (1+0.070*-0.8)'        cjswp_25 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgp_25 = '1.6800E-10 * (1+0.070*-0.8)'
+cgop_25 = '1.19935E-10 * (1-0.070*A4NP_25)'   cglp_25 = '2.49822E-10 * (1-0.070*A4NP_25)'   dlcp_25 = 6.40638E-08
+dvthp_25 = '-0.023*A1P_25'                    dlvthp_25 = '-1.5e-009*A1P_25'                dwvthp_25 = '-1e-009*A1P_25'
+dpvthp_25 = '-3.7e-015*A1P_25'                du0p_25 = '0e-005*A1P_25'                     dlu0p_25 = 0
+dwu0p_25 = 0                                  dpu0p_25 = 0                                  dnfactorp_25 = 0
+dlnfactorp_25 = 0                             dwnfactorp_25 = 0                             dpnfactorp_25 = 0
+dvoffp_25 = 0                                 dlvoffp_25 = 0                                dwvoffp_25 = 0
+dpvoffp_25 = 0                                dcitp_25 = 0                                  dlcitp_25 = 0
+dwcitp_25 = 0                                 dpcitp_25 = 0                                 dvsatp_25 = 0
+dlvsatp_25 = 0                                dwvsatp_25 = 0                                dpvsatp_25 = '6e-010*A1P_25'
+da0p_25 = 0                                   dla0p_25 = '5e-008*A1P_25'                    dwa0p_25 = 0
+dpa0p_25 = '1e-014*A1P_25'                    dagsp_25 = '0.001*A1P_25'                     dlagsp_25 = 0
+dwagsp_25 = 0                                 dpagsp_25 = 0                                 dpclmp_25 = 0
+dlpclmp_25 = 0                                dwpclmp_25 = 0                                dppclmp_25 = 0
+deta0p_25 = 0                                 dleta0p_25 = 0                                dweta0p_25 = 0
+dpeta0p_25 = '-3e-015*A1P_25'                 dk2p_25 = 0                                   dlk2p_25 = '7e-010*A1P_25'
+dwk2p_25 = 0                                  dpk2p_25 = 0
+cfp_25 = '9e-11*(1-0.070*A4NP_25)+2.4e-11*ccoflag_25'

+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'

.lib 'crn65lp_v1d5.l' MAC_25
.lib 'crn65lp_v1d5.l' MOS_25
.ENDL SF_25








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_25
.lib 'crn65lp_v1d5.l' noiseflag_25
.lib 'crn65lp_v1d5.l' post_simu_25
.param
+parn1_25=AGAUSS(0,1,1)
+parn2_25=AGAUSS(0,1,1)
+parp1_25=AGAUSS(0,1,1)
+parp2_25=AGAUSS(0,1,1)
+A1N_25=-1 A1P_25=1 A2N_25=0 A2P_25=0 A3N_25=1 A3P_25=-1 A4NP_25=0
+toxn_25 = '5.6e-09 + 3.0000e-010*A4NP_25'     dxln_25 = '1e-008*A2N_25'                     dxwn_25 = '1.2e-008*A3N_25'
+cjn_25 = '1.1950E-03 * (1+0.070*-0.8)'      cjswn_25 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgn_25 = '2.0800E-10 * (1+0.070*-0.8)'
+cgon_25 = '9.95494E-11 * (1-0.070*A4NP_25)'   cgln_25 = '2.67995E-10 * (1-0.070*A4NP_25)'   dlcn_25 = 6.03005E-08
+dvthn_25 = '0.023*A1N_25'                     dlvthn_25 = '3e-009*A1N_25'                   dwvthn_25 = '1e-009*A1N_25'
+dpvthn_25 = '2.3e-015*A1N_25'                 dcitn_25 = '0.0001*A1N_25'                    dlcitn_25 = '3e-011*A1N_25'
+dwcitn_25 = 0                                 dpcitn_25 = 0                                 du0n_25 = 0
+dlu0n_25 = 0                                  dwu0n_25 = '-1e-010*A1N_25'                   dpu0n_25 = '-5e-017*A1N_25'
+da0n_25 = '0.00*A1N_25'                       dla0n_25 = '0e-008*A1N_25'                    dwa0n_25 = 0
+dpa0n_25 = 0                                  dagsn_25 = 0                                  dlagsn_25 = 0
+dwagsn_25 = 0                                 dpagsn_25 = 0                                 dvsatn_25 = 0
+dlvsatn_25 = '0.0000*A1N_25'                  dwvsatn_25 = 0                                dpvsatn_25 = 0
+dpclmn_25 = '-0.1*A1N_25'                     dlpclmn_25 = 0                                dwpclmn_25 = 0
+dppclmn_25 = 0                                deta0n_25 = 0                                 dleta0n_25 = '-1.5e-009*A1N_25'
+dweta0n_25 = 0                                dpeta0n_25 = '-5e-015*A1N_25'                 dk2n_25 = '0.007*A1N_25'
+dlk2n_25 = '7e-010*A1N_25'                    dwk2n_25 = 0                                  dpk2n_25 = 0
+cfn_25 = '9e-11*(1-0.070*A4NP_25)+2.4e-11*ccoflag_25'
+toxp_25 = '5.9e-09 + 3.0000e-010*A4NP_25'     dxlp_25 = '1e-008*A2P_25'                     dxwp_25 = '1.2e-008*A3P_25'
+cjp_25 = '0.001111 * (1+0.070*0.8)'        cjswp_25 = '9.7000E-11 * (1+0.070*0.8)'    cjswgp_25 = '1.6800E-10 * (1+0.070*0.8)'
+cgop_25 = '1.19935E-10 * (1-0.070*A4NP_25)'   cglp_25 = '2.49822E-10 * (1-0.070*A4NP_25)'   dlcp_25 = 6.40638E-08
+dvthp_25 = '-0.023*A1P_25'                    dlvthp_25 = '-1.5e-009*A1P_25'                dwvthp_25 = '-1e-009*A1P_25'
+dpvthp_25 = '-3.7e-015*A1P_25'                du0p_25 = '0e-005*A1P_25'                     dlu0p_25 = 0
+dwu0p_25 = 0                                  dpu0p_25 = 0                                  dnfactorp_25 = 0
+dlnfactorp_25 = 0                             dwnfactorp_25 = 0                             dpnfactorp_25 = 0
+dvoffp_25 = 0                                 dlvoffp_25 = 0                                dwvoffp_25 = 0
+dpvoffp_25 = 0                                dcitp_25 = 0                                  dlcitp_25 = 0
+dwcitp_25 = 0                                 dpcitp_25 = 0                                 dvsatp_25 = 0
+dlvsatp_25 = 0                                dwvsatp_25 = 0                                dpvsatp_25 = '6e-010*A1P_25'
+da0p_25 = 0                                   dla0p_25 = '5e-008*A1P_25'                    dwa0p_25 = 0
+dpa0p_25 = '1e-014*A1P_25'                    dagsp_25 = '0.001*A1P_25'                     dlagsp_25 = 0
+dwagsp_25 = 0                                 dpagsp_25 = 0                                 dpclmp_25 = 0
+dlpclmp_25 = 0                                dwpclmp_25 = 0                                dppclmp_25 = 0
+deta0p_25 = 0                                 dleta0p_25 = 0                                dweta0p_25 = 0
+dpeta0p_25 = '-3e-015*A1P_25'                 dk2p_25 = 0                                   dlk2p_25 = '7e-010*A1P_25'
+dwk2p_25 = 0                                  dpk2p_25 = 0
+cfp_25 = '9e-11*(1-0.070*A4NP_25)+2.4e-11*ccoflag_25'

+ c1fn_25=8.00E+41           c2fn_25=5.55E+24           c3fn_25=7.75E+6                     
+ c1fp_25=2.40E+41           c2fp_25=9.00E+21           c3fp_25=2.00E+09           
+ fn_dice_25n='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
+ arearation_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_25='c1fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noibn_25='c2fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ noicn_25='c3fn_25*2.718**((fn_dice_25n+(1-fn_dice_25n)*noiseflagn_25)*arearation_25)'
+ fn_dice_25p='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
+ arearatiop_25='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_25='c1fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noibp_25='c2fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'
+ noicp_25='c3fp_25*2.718**((fn_dice_25p+(1-fn_dice_25p)*noiseflagp_25)*arearatiop_25)'

.lib 'crn65lp_v1d5.l' MAC_25
.lib 'crn65lp_v1d5.l' MOS_25
.ENDL FS_25







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+A1_33='par6*4.8844*3/2.2'
+A2_33='par7*3.6211*3/2.2'
+A3_33='par8*3.1765*3/2.2'
+A4_33='par9*1.3928*3/2.2'
+toxn_33        ='5.6e-09+(-2.9051e-011)*A1_33+(1.0524e-011)*A2_33+(-6.11e-011)*A3_33+(1.9574e-011)*A4_33'
+dxln_33        ='0+(-8.7742e-010)*A1_33+(4.0539e-010)*A2_33+(-2.9313e-009)*A3_33+(7.5636e-010)*A4_33'
+dxwn_33        ='0+(1.2502e-009)*A1_33+(1.4002e-009)*A2_33+(3.7127e-009)*A3_33+(-9.9453e-010)*A4_33'
+cjn_33         ='1.1950e-03+(-1.1483e-005)*A1_33+(-8.9571e-006)*A2_33+(4.3258e-006)*A3_33+(3.3359e-006)*A4_33'
+cjswn_33       ='1.6500e-10+(-1.5855e-012)*A1_33+(-1.2368e-012)*A2_33+(5.9728e-013)*A3_33+(4.6052e-013)*A4_33'
+cjswgn_33      ='2.0800e-10+(-1.9987e-012)*A1_33+(-1.5591e-012)*A2_33+(7.5294e-013)*A3_33+(5.8053e-013)*A4_33'
+cgon_33        ='9.95494e-11+(6.7482e-013)*A1_33+(-2.4444e-013)*A2_33+(1.4192e-012)*A3_33+(-4.5469e-013)*A4_33'
+cgln_33        ='2.67995e-10+(1.8167e-012)*A1_33+(-6.5807e-013)*A2_33+(3.8207e-012)*A3_33+(-1.224e-012)*A4_33'
+dvthn_33       ='0+(-0.0019918)*A1_33+(-0.003373)*A2_33+(0.00046738)*A3_33+(0.00060958)*A4_33'
+dlvthn_33      ='0+(-4.0919e-010)*A1_33+(-4.1802e-010)*A2_33+(1.4887e-010)*A3_33+(1.5429e-010)*A4_33'
+dwvthn_33      ='0+(-1.3431e-010)*A1_33+(-1.3975e-010)*A2_33+(5.0205e-011)*A3_33+(5.6487e-011)*A4_33'
+dpvthn_33      ='0+(-2.983e-016)*A1_33+(-3.235e-016)*A2_33+(1.1844e-016)*A3_33+(1.5571e-016)*A4_33'
+dcitn_33       ='0+(-1.2806e-005)*A1_33+(-1.4097e-005)*A2_33+(5.1948e-006)*A3_33+(7.1655e-006)*A4_33'
+dlcitn_33      ='0+(-2.9669e-012)*A1_33+(-4.4006e-012)*A2_33+(1.8026e-012)*A3_33+(4.2731e-012)*A4_33'
+dwu0n_33       ='0+(1.4056e-011)*A1_33+(1.3852e-011)*A2_33+(-4.8461e-012)*A3_33+(-4.132e-012)*A4_33'
+dpu0n_33       ='0+(1.0153e-017)*A1_33+(6.3139e-018)*A2_33+(-1.5511e-018)*A3_33+(5.5177e-018)*A4_33'
+da0n_33        ='0+(-0.0062062)*A1_33+(0.00093485)*A2_33+(0.0032361)*A3_33+(0.0017039)*A4_33'
+dla0n_33       ='0+(-1.2412e-009)*A1_33+(1.8697e-010)*A2_33+(6.4721e-010)*A3_33+(3.4078e-010)*A4_33'
+dlvsatn_33     ='0+(-8.6887e-005)*A1_33+(1.3088e-005)*A2_33+(4.5305e-005)*A3_33+(2.3855e-005)*A4_33'
+dpvsatn_33     ='0+(-3.125e-012)*A1_33+(6.1228e-013)*A2_33+(-8.7195e-013)*A3_33+(-7.5837e-012)*A4_33'
+dpclmn_33      ='max(-0.18,0+(0.014056)*A1_33+(0.013852)*A2_33+(-0.0048461)*A3_33+(-0.004132)*A4_33)'
+dppclmn_33     ='0+(7.5001e-016)*A1_33+(-1.4695e-016)*A2_33+(2.0927e-016)*A3_33+(1.8201e-015)*A4_33'
+dleta0n_33     ='0+(3.9835e-010)*A1_33+(1.7105e-010)*A2_33+(-2.0374e-011)*A3_33+(3.9304e-010)*A4_33'
+dpeta0n_33     ='0+(5.7782e-016)*A1_33+(7.171e-016)*A2_33+(-2.7718e-016)*A3_33+(-5.0995e-016)*A4_33'
+dk2n_33        ='0+(-0.00098395)*A1_33+(-0.00096966)*A2_33+(0.00033922)*A3_33+(0.00028924)*A4_33'
+dlk2n_33       ='0+(-9.8395e-011)*A1_33+(-9.6966e-011)*A2_33+(3.3922e-011)*A3_33+(2.8924e-011)*A4_33'
+cfn_33         ='9.000000e-011+(6.1008e-013)*A1_33+(-2.2099e-013)*A2_33+(1.2831e-012)*A3_33+(-4.1105e-013)*A4_33+2.4e-11*ccoflag_33'
+toxp_33        ='5.9e-09+(-2.9051e-011)*A1_33+(1.0524e-011)*A2_33+(-6.11e-011)*A3_33+(1.9574e-011)*A4_33'
+dxlp_33        ='0+(-8.7742e-010)*A1_33+(4.0539e-010)*A2_33+(-2.9313e-009)*A3_33+(7.5636e-010)*A4_33'
+dxwp_33        ='max(-3.1e-8,0+(8.5562e-010)*A1_33+(-2.3731e-009)*A2_33+(3.3224e-009)*A3_33+(-8.2073e-010)*A4_33)'
+cjp_33         ='0.001111+(-8.6302e-006)*A1_33+(1.1236e-005)*A2_33+(6.0451e-006)*A3_33+(2.2003e-006)*A4_33'
+cjswp_33       ='9.7000e-11+(-7.535e-013)*A1_33+(9.8097e-013)*A2_33+(5.2778e-013)*A3_33+(1.9205e-013)*A4_33'
+cjswgp_33      ='1.6800e-10+(-1.305e-012)*A1_33+(1.699e-012)*A2_33+(9.141e-013)*A3_33+(3.3263e-013)*A4_33'
+cgop_33        ='1.19935e-10+(8.1294e-013)*A1_33+(-2.9449e-013)*A2_33+(1.7099e-012)*A3_33+(-5.4775e-013)*A4_33'
+cglp_33        ='2.49822e-10+(1.6935e-012)*A1_33+(-6.1344e-013)*A2_33+(3.5616e-012)*A3_33+(-1.141e-012)*A4_33'
+dvthp_33       ='0+(0.0012355)*A1_33+(-0.0038591)*A2_33+(-0.0012154)*A3_33+(-0.00027645)*A4_33'
+dlvthp_33      ='0+(1.3028e-010)*A1_33+(-2.5775e-010)*A2_33+(-1.3019e-010)*A3_33+(-1.1609e-010)*A4_33'
+dwvthp_33      ='0+(1.0768e-010)*A1_33+(-1.7592e-010)*A2_33+(-8.0982e-011)*A3_33+(-2.6836e-011)*A4_33'
+dpvthp_33      ='0+(3.7968e-016)*A1_33+(-6.4722e-016)*A2_33+(-3.0486e-016)*A3_33+(-1.448e-016)*A4_33'
+du0p_33        ='0+(-4.9737e-006)*A1_33+(8.0582e-007)*A2_33+(1.5929e-006)*A3_33+(-2.0111e-006)*A4_33'
+dpu0p_33       ='0+(-3.125e-019)*A1_33+(6.1228e-020)*A2_33+(-8.7195e-020)*A3_33+(-7.5837e-019)*A4_33'
+dlvsatp_33     ='0+(6.2501e-006)*A1_33+(-1.2246e-006)*A2_33+(1.7439e-006)*A3_33+(1.5167e-005)*A4_33'
+dpvsatp_33     ='0+(-7.086e-011)*A1_33+(1.0677e-010)*A2_33+(4.6845e-011)*A3_33+(9.3422e-013)*A4_33'
+dla0p_33       ='0+(-7.2592e-009)*A1_33+(9.1632e-009)*A2_33+(3.5259e-009)*A3_33+(-3.2084e-009)*A4_33'
+dpa0p_33       ='0+(-4.5183e-016)*A1_33+(1.6367e-015)*A2_33+(9.8421e-016)*A3_33+(1.7851e-015)*A4_33'
+dagsp_33       ='0+(-4.5183e-005)*A1_33+(0.00016367)*A2_33+(9.8421e-005)*A3_33+(0.00017851)*A4_33'
+dpeta0p_33     ='0+(3.8555e-016)*A1_33+(-5.4e-016)*A2_33+(-2.2551e-016)*A3_33+(7.1166e-017)*A4_33'
+dlk2p_33       ='0+(-7.5379e-011)*A1_33+(1.2314e-010)*A2_33+(5.6687e-011)*A3_33+(1.8785e-011)*A4_33'
+cfp_33         ='9.000000e-011+(6.1008e-013)*A1_33+(-2.2099e-013)*A2_33+(1.2831e-012)*A3_33+(-4.1105e-013)*A4_33+2.4e-11*ccoflag_33'
+dlcn_33        =6.03005e-08
+dwcitn_33      =0
+dpcitn_33      =0
+du0n_33        =0
+dlu0n_33       =0
+dwa0n_33       =0
+dpa0n_33       =0
+dagsn_33       =0
+dlagsn_33      =0
+dwagsn_33      =0
+dpagsn_33      =0
+dvsatn_33      =0
+dwvsatn_33     =0
+dlpclmn_33     =0
+dwpclmn_33     =0
+deta0n_33      =0
+dweta0n_33     =0
+dwk2n_33       =0
+dpk2n_33       =0
+dlcp_33        =6.40638e-08
+dlu0p_33       =0
+dwu0p_33       =0
+dnfactorp_33   =0
+dlnfactorp_33  =0
+dwnfactorp_33  =0
+dpnfactorp_33  =0
+dvoffp_33      =0
+dlvoffp_33     =0
+dwvoffp_33     =0
+dpvoffp_33     =0
+dcitp_33       =0
+dlcitp_33      =0
+dwcitp_33      =0
+dpcitp_33      =0
+dvsatp_33      =0
+dwvsatp_33     =0
+da0p_33        =0
+dwa0p_33       =0
+dlagsp_33      =0
+dwagsp_33      =0
+dpagsp_33      =0
+dpclmp_33      =0
+dlpclmp_33     =0
+dwpclmp_33     =0
+dppclmp_33     =0
+deta0p_33      =0
+dleta0p_33     =0
+dweta0p_33     =0
+dk2p_33        =0
+dwk2p_33       =0
+dpk2p_33       =0

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' mos_33
.ENDL mc_33








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+toxn_33        = 5.6e-09       dxln_33        = 0             dxwn_33        = 0
+cjn_33         = 1.1950E-03    cjswn_33       = 1.6500E-10    cjswgn_33      = 2.0800E-10
+cgon_33        = 9.95494E-11   cgln_33        = 2.67995E-10   dlcn_33        = 6.03005E-08
+dvthn_33       = 0             dlvthn_33      = 0             dwvthn_33      = 0
+dpvthn_33      = 0             dcitn_33       = 0             dlcitn_33      = 0
+dwcitn_33      = 0             dpcitn_33      = 0             du0n_33        = 0
+dlu0n_33       = 0             dwu0n_33       = 0             dpu0n_33       = 0
+da0n_33        = 0             dla0n_33       = 0             dwa0n_33       = 0
+dpa0n_33       = 0             dagsn_33       = 0             dlagsn_33      = 0
+dwagsn_33      = 0             dpagsn_33      = 0             dvsatn_33      = 0
+dlvsatn_33     = 0             dwvsatn_33     = 0             dpvsatn_33     = 0
+dpclmn_33      = 0             dlpclmn_33     = 0             dwpclmn_33     = 0
+dppclmn_33     = 0             deta0n_33      = 0             dleta0n_33     = 0
+dweta0n_33     = 0             dpeta0n_33     = 0             dk2n_33        = 0
+dlk2n_33       = 0             dwk2n_33       = 0             dpk2n_33       = 0
+cfn_33         = '9e-11 + 2.4e-11*ccoflag_33'
+toxp_33        = 5.9e-09       dxlp_33        = 0             dxwp_33        = 0
+cjp_33         = 0.001111      cjswp_33       = 9.7000E-11    cjswgp_33      = 1.6800E-10
+cgop_33        = 1.19935E-10   cglp_33        = 2.49822E-10   dlcp_33        = 6.40638E-08
+dvthp_33       = 0             dlvthp_33      = 0             dwvthp_33      = 0
+dpvthp_33      = 0             du0p_33        = 0             dlu0p_33       = 0
+dwu0p_33       = 0             dpu0p_33       = 0             dnfactorp_33   = 0
+dlnfactorp_33  = 0             dwnfactorp_33  = 0             dpnfactorp_33  = 0
+dvoffp_33      = 0             dlvoffp_33     = 0             dwvoffp_33     = 0
+dpvoffp_33     = 0             dcitp_33       = 0             dlcitp_33      = 0
+dwcitp_33      = 0             dpcitp_33      = 0             dvsatp_33      = 0
+dlvsatp_33     = 0             dwvsatp_33     = 0             dpvsatp_33     = 0
+da0p_33        = 0             dla0p_33       = 0             dwa0p_33       = 0
+dpa0p_33       = 0             dagsp_33       = 0             dlagsp_33      = 0
+dwagsp_33      = 0             dpagsp_33      = 0             dpclmp_33      = 0
+dlpclmp_33     = 0             dwpclmp_33     = 0             dppclmp_33     = 0
+deta0p_33      = 0             dleta0p_33     = 0             dweta0p_33     = 0
+dpeta0p_33     = 0             dk2p_33        = 0             dlk2p_33       = 0
+dwk2p_33       = 0             dpk2p_33       = 0             cfp_33         = '9e-11 + 2.4e-11*ccoflag_33'

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' MAC_33
.lib 'crn65lp_v1d5.l' MOS_33
.ENDL TT_33








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+toxn_33        = 5.9e-09       dxln_33        = 1e-08         dxwn_33        = -1.2e-08
+cjn_33         = 0.00127865    cjswn_33       = 1.7655E-10    cjswgn_33      = 2.2256E-10
+cgon_33        = 9.25809E-11   cgln_33        = 2.49235E-10   dlcn_33        = 6.03005E-08
+dvthn_33       = 0.013         dlvthn_33      = 2.8e-9        dwvthn_33      = 0.9e-9
+dpvthn_33      = 1.9e-15       dcitn_33       = 0.8e-4        dlcitn_33      = 1e-11
+dwcitn_33      = 0             dpcitn_33      = 0             du0n_33        = 0
+dlu0n_33       = 0             dwu0n_33       = -1e-10        dpu0n_33       = -1e-16
+da0n_33        = 0.05          dla0n_33       = 1e-8          dwa0n_33       = 0
+dpa0n_33       = 0             dagsn_33       = 0             dlagsn_33      = 0
+dwagsn_33      = 0             dpagsn_33      = 0             dvsatn_33      = 0
+dlvsatn_33     = 7e-4          dwvsatn_33     = 0             dpvsatn_33     = 0.5e-10
+dpclmn_33      = -0.1          dlpclmn_33     = 0             dwpclmn_33     = 0
+dppclmn_33     = -1.2e-14      deta0n_33      = 0             dleta0n_33     = -4.5e-9
+dweta0n_33     = 0             dpeta0n_33     = -3e-15        dk2n_33        = 0.007
+dlk2n_33       = 7e-10         dwk2n_33       = 0             dpk2n_33       = 0
+cfn_33         = '8.37e-11 + 2.4e-11*ccoflag_33'
+toxp_33        = 6.2e-09       dxlp_33        = 1e-08         dxwp_33        = -1.2e-08
+cjp_33         = 0.00118877    cjswp_33       = 1.0379E-10    cjswgp_33      = 1.7976E-10
+cgop_33        = 1.11540E-10   cglp_33        = 2.32334E-10   dlcp_33        = 6.40638E-08
+dvthp_33       = -0.013        dlvthp_33      = -1e-9         dwvthp_33      = -1e-9
+dpvthp_33      = -3.4e-15      du0p_33        = 0.5e-4        dlu0p_33       = 0
+dwu0p_33       = 0             dpu0p_33       = 0.5e-17       dnfactorp_33   = 0
+dlnfactorp_33  = 0             dwnfactorp_33  = 0             dpnfactorp_33  = 0
+dvoffp_33      = 0             dlvoffp_33     = 0             dwvoffp_33     = 0
+dpvoffp_33     = 0             dcitp_33       = 0             dlcitp_33      = 0
+dwcitp_33      = 0             dpcitp_33      = 0             dvsatp_33      = 0
+dlvsatp_33     = -1e-4         dwvsatp_33     = 0             dpvsatp_33     = 7e-10
+da0p_33        = 0             dla0p_33       = 8e-8          dwa0p_33       = 0
+dpa0p_33       = 0             dagsp_33       = 0             dlagsp_33      = 0
+dwagsp_33      = 0             dpagsp_33      = 0             dpclmp_33      = 0
+dlpclmp_33     = 0             dwpclmp_33     = 0             dppclmp_33     = 0
+deta0p_33      = 0             dleta0p_33     = 0             dweta0p_33     = 0
+dpeta0p_33     = -4e-15        dk2p_33        = 0             dlk2p_33       = 7e-10
+dwk2p_33       = 0             dpk2p_33       = 0             cfp_33         = '8.37e-11 + 2.4e-11*ccoflag_33'

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' MAC_33
.lib 'crn65lp_v1d5.l' MOS_33
.ENDL SS_33








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+toxn_33        = 5.3e-09       dxln_33        = -1e-08        dxwn_33        = 1.2e-08
+cjn_33         = 0.00111135    cjswn_33       = 1.5345E-10    cjswgn_33      = 1.9344E-10
+cgon_33        = 1.06518E-10   cgln_33        = 2.86755E-10   dlcn_33        = 6.03005E-08
+dvthn_33       = -0.013        dlvthn_33      = -3.0e-9       dwvthn_33      = -1e-9
+dpvthn_33      = -2.3e-15      dcitn_33       = -1e-4         dlcitn_33      = -3e-11
+dwcitn_33      = 0             dpcitn_33      = 0             du0n_33        = 0
+dlu0n_33       = 0             dwu0n_33       = 1e-10         dpu0n_33       = 0.5e-16
+da0n_33        = -0.05         dla0n_33       = -1e-8         dwa0n_33       = 0
+dpa0n_33       = 0             dagsn_33       = 0             dlagsn_33      = 0
+dwagsn_33      = 0             dpagsn_33      = 0             dvsatn_33      = 0
+dlvsatn_33     = -7e-4         dwvsatn_33     = 0             dpvsatn_33     = 0
+dpclmn_33      = 0.1           dlpclmn_33     = 0             dwpclmn_33     = 0
+dppclmn_33     = 0             deta0n_33      = 0             dleta0n_33     = 1.5e-9
+dweta0n_33     = 0             dpeta0n_33     = 5e-15         dk2n_33        = -0.007
+dlk2n_33       = -7e-10        dwk2n_33       = 0             dpk2n_33       = 0
+cfn_33         = '9.63e-11 + 2.4e-11*ccoflag_33'
+toxp_33        = 5.6e-09       dxlp_33        = -1e-08        dxwp_33        = 1.2e-08
+cjp_33         = 0.00103323    cjswp_33       = 9.0210E-11    cjswgp_33      = 1.5624E-10
+cgop_33        = 1.28330E-10   cglp_33        = 2.67310E-10   dlcp_33        = 6.40638E-08
+dvthp_33       = 0.013         dlvthp_33      = 1.5e-9        dwvthp_33      = 1e-9
+dpvthp_33      = 3.7e-15       du0p_33        = -0.3e-4       dlu0p_33       = 0
+dwu0p_33       = 0             dpu0p_33       = 0             dnfactorp_33   = 0
+dlnfactorp_33  = 0             dwnfactorp_33  = 0             dpnfactorp_33  = 0
+dvoffp_33      = 0             dlvoffp_33     = 0             dwvoffp_33     = 0
+dpvoffp_33     = 0             dcitp_33       = 0             dlcitp_33      = 0
+dwcitp_33      = 0             dpcitp_33      = 0             dvsatp_33      = 0
+dlvsatp_33     = 0             dwvsatp_33     = 0             dpvsatp_33     = -6e-10
+da0p_33        = 0             dla0p_33       = -5e-8         dwa0p_33       = 0
+dpa0p_33       = -1e-14        dagsp_33       = -0.001        dlagsp_33      = 0
+dwagsp_33      = 0             dpagsp_33      = 0             dpclmp_33      = 0
+dlpclmp_33     = 0             dwpclmp_33     = 0             dppclmp_33     = 0
+deta0p_33      = 0             dleta0p_33     = 0             dweta0p_33     = 0
+dpeta0p_33     = 3e-15         dk2p_33        = 0             dlk2p_33       = -7e-10
+dwk2p_33       = 0             dpk2p_33       = 0             cfp_33         = '9.63e-11 + 2.4e-11*ccoflag_33'

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' MAC_33
.lib 'crn65lp_v1d5.l' MOS_33
.ENDL FF_33








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+A1N_33=1 A1P_33=-1 A2N_33=0 A2P_33=0 A3N_33=-1 A3P_33=1 A4NP_33=0
+toxn_33 = '5.6e-09 + 3.0000e-010*A4NP_33'     dxln_33 = '1e-008*A2N_33'                     dxwn_33 = '1.2e-008*A3N_33'
+cjn_33 = '1.1950E-03 * (1+0.070*0.8)'      cjswn_33 = '1.6500E-10 * (1+0.070*0.8)'    cjswgn_33 = '2.0800E-10 * (1+0.070*0.8)'
+cgon_33 = '9.95494E-11 * (1-0.070*A4NP_33)'   cgln_33 = '2.67995E-10 * (1-0.070*A4NP_33)'   dlcn_33 = 6.03005E-08
+dvthn_33 = '0.023*A1N_33'                     dlvthn_33 = '3e-009*A1N_33'                   dwvthn_33 = '1e-009*A1N_33'
+dpvthn_33 = '2.3e-015*A1N_33'                 dcitn_33 = '0.0001*A1N_33'                    dlcitn_33 = '3e-011*A1N_33'
+dwcitn_33 = 0                                 dpcitn_33 = 0                                 du0n_33 = 0
+dlu0n_33 = 0                                  dwu0n_33 = '-1e-010*A1N_33'                   dpu0n_33 = '-5e-017*A1N_33'
+da0n_33 = '0.00*A1N_33'                       dla0n_33 = '0e-008*A1N_33'                    dwa0n_33 = 0
+dpa0n_33 = 0                                  dagsn_33 = 0                                  dlagsn_33 = 0
+dwagsn_33 = 0                                 dpagsn_33 = 0                                 dvsatn_33 = 0
+dlvsatn_33 = '0.0000*A1N_33'                  dwvsatn_33 = 0                                dpvsatn_33 = 0
+dpclmn_33 = '-0.1*A1N_33'                     dlpclmn_33 = 0                                dwpclmn_33 = 0
+dppclmn_33 = 0                                deta0n_33 = 0                                 dleta0n_33 = '-1.5e-009*A1N_33'
+dweta0n_33 = 0                                dpeta0n_33 = '-5e-015*A1N_33'                 dk2n_33 = '0.007*A1N_33'
+dlk2n_33 = '7e-010*A1N_33'                    dwk2n_33 = 0                                  dpk2n_33 = 0
+cfn_33 = '9e-11*(1-0.070*A4NP_33)+2.4e-11*ccoflag_33'
+toxp_33 = '5.9e-09 + 3.0000e-010*A4NP_33'     dxlp_33 = '1e-008*A2P_33'                     dxwp_33 = '1.2e-008*A3P_33'
+cjp_33 = '0.001111 * (1+0.070*-0.8)'        cjswp_33 = '9.7000E-11 * (1+0.070*-0.8)'    cjswgp_33 = '1.6800E-10 * (1+0.070*-0.8)'
+cgop_33 = '1.19935E-10 * (1-0.070*A4NP_33)'   cglp_33 = '2.49822E-10 * (1-0.070*A4NP_33)'   dlcp_33 = 6.40638E-08
+dvthp_33 = '-0.023*A1P_33'                    dlvthp_33 = '-1.5e-009*A1P_33'                dwvthp_33 = '-1e-009*A1P_33'
+dpvthp_33 = '-3.7e-015*A1P_33'                du0p_33 = '0e-005*A1P_33'                     dlu0p_33 = 0
+dwu0p_33 = 0                                  dpu0p_33 = 0                                  dnfactorp_33 = 0
+dlnfactorp_33 = 0                             dwnfactorp_33 = 0                             dpnfactorp_33 = 0
+dvoffp_33 = 0                                 dlvoffp_33 = 0                                dwvoffp_33 = 0
+dpvoffp_33 = 0                                dcitp_33 = 0                                  dlcitp_33 = 0
+dwcitp_33 = 0                                 dpcitp_33 = 0                                 dvsatp_33 = 0
+dlvsatp_33 = 0                                dwvsatp_33 = 0                                dpvsatp_33 = '6e-010*A1P_33'
+da0p_33 = 0                                   dla0p_33 = '5e-008*A1P_33'                    dwa0p_33 = 0
+dpa0p_33 = '1e-014*A1P_33'                    dagsp_33 = '0.001*A1P_33'                     dlagsp_33 = 0
+dwagsp_33 = 0                                 dpagsp_33 = 0                                 dpclmp_33 = 0
+dlpclmp_33 = 0                                dwpclmp_33 = 0                                dppclmp_33 = 0
+deta0p_33 = 0                                 dleta0p_33 = 0                                dweta0p_33 = 0
+dpeta0p_33 = '-3e-015*A1P_33'                 dk2p_33 = 0                                   dlk2p_33 = '7e-010*A1P_33'
+dwk2p_33 = 0                                  dpk2p_33 = 0
+cfp_33 = '9e-11*(1-0.070*A4NP_33)+2.4e-11*ccoflag_33'

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' MAC_33
.lib 'crn65lp_v1d5.l' MOS_33
.ENDL SF_33








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_33
.lib 'crn65lp_v1d5.l' noiseflag_33
.lib 'crn65lp_v1d5.l' post_simu_33
.param
+parn1_33=AGAUSS(0,1,1)
+parn2_33=AGAUSS(0,1,1)
+parp1_33=AGAUSS(0,1,1)
+parp2_33=AGAUSS(0,1,1)
+A1N_33=-1 A1P_33=1 A2N_33=0 A2P_33=0 A3N_33=1 A3P_33=-1 A4NP_33=0
+toxn_33 = '5.6e-09 + 3.0000e-010*A4NP_33'     dxln_33 = '1e-008*A2N_33'                     dxwn_33 = '1.2e-008*A3N_33'
+cjn_33 = '1.1950E-03 * (1+0.070*-0.8)'      cjswn_33 = '1.6500E-10 * (1+0.070*-0.8)'    cjswgn_33 = '2.0800E-10 * (1+0.070*-0.8)'
+cgon_33 = '9.95494E-11 * (1-0.070*A4NP_33)'   cgln_33 = '2.67995E-10 * (1-0.070*A4NP_33)'   dlcn_33 = 6.03005E-08
+dvthn_33 = '0.023*A1N_33'                     dlvthn_33 = '3e-009*A1N_33'                   dwvthn_33 = '1e-009*A1N_33'
+dpvthn_33 = '2.3e-015*A1N_33'                 dcitn_33 = '0.0001*A1N_33'                    dlcitn_33 = '3e-011*A1N_33'
+dwcitn_33 = 0                                 dpcitn_33 = 0                                 du0n_33 = 0
+dlu0n_33 = 0                                  dwu0n_33 = '-1e-010*A1N_33'                   dpu0n_33 = '-5e-017*A1N_33'
+da0n_33 = '0.00*A1N_33'                       dla0n_33 = '0e-008*A1N_33'                    dwa0n_33 = 0
+dpa0n_33 = 0                                  dagsn_33 = 0                                  dlagsn_33 = 0
+dwagsn_33 = 0                                 dpagsn_33 = 0                                 dvsatn_33 = 0
+dlvsatn_33 = '0.0000*A1N_33'                  dwvsatn_33 = 0                                dpvsatn_33 = 0
+dpclmn_33 = '-0.1*A1N_33'                     dlpclmn_33 = 0                                dwpclmn_33 = 0
+dppclmn_33 = 0                                deta0n_33 = 0                                 dleta0n_33 = '-1.5e-009*A1N_33'
+dweta0n_33 = 0                                dpeta0n_33 = '-5e-015*A1N_33'                 dk2n_33 = '0.007*A1N_33'
+dlk2n_33 = '7e-010*A1N_33'                    dwk2n_33 = 0                                  dpk2n_33 = 0
+cfn_33 = '9e-11*(1-0.070*A4NP_33)+2.4e-11*ccoflag_33'
+toxp_33 = '5.9e-09 + 3.0000e-010*A4NP_33'     dxlp_33 = '1e-008*A2P_33'                     dxwp_33 = '1.2e-008*A3P_33'
+cjp_33 = '0.001111 * (1+0.070*0.8)'        cjswp_33 = '9.7000E-11 * (1+0.070*0.8)'    cjswgp_33 = '1.6800E-10 * (1+0.070*0.8)'
+cgop_33 = '1.19935E-10 * (1-0.070*A4NP_33)'   cglp_33 = '2.49822E-10 * (1-0.070*A4NP_33)'   dlcp_33 = 6.40638E-08
+dvthp_33 = '-0.023*A1P_33'                    dlvthp_33 = '-1.5e-009*A1P_33'                dwvthp_33 = '-1e-009*A1P_33'
+dpvthp_33 = '-3.7e-015*A1P_33'                du0p_33 = '0e-005*A1P_33'                     dlu0p_33 = 0
+dwu0p_33 = 0                                  dpu0p_33 = 0                                  dnfactorp_33 = 0
+dlnfactorp_33 = 0                             dwnfactorp_33 = 0                             dpnfactorp_33 = 0
+dvoffp_33 = 0                                 dlvoffp_33 = 0                                dwvoffp_33 = 0
+dpvoffp_33 = 0                                dcitp_33 = 0                                  dlcitp_33 = 0
+dwcitp_33 = 0                                 dpcitp_33 = 0                                 dvsatp_33 = 0
+dlvsatp_33 = 0                                dwvsatp_33 = 0                                dpvsatp_33 = '6e-010*A1P_33'
+da0p_33 = 0                                   dla0p_33 = '5e-008*A1P_33'                    dwa0p_33 = 0
+dpa0p_33 = '1e-014*A1P_33'                    dagsp_33 = '0.001*A1P_33'                     dlagsp_33 = 0
+dwagsp_33 = 0                                 dpagsp_33 = 0                                 dpclmp_33 = 0
+dlpclmp_33 = 0                                dwpclmp_33 = 0                                dppclmp_33 = 0
+deta0p_33 = 0                                 dleta0p_33 = 0                                dweta0p_33 = 0
+dpeta0p_33 = '-3e-015*A1P_33'                 dk2p_33 = 0                                   dlk2p_33 = '7e-010*A1P_33'
+dwk2p_33 = 0                                  dpk2p_33 = 0
+cfp_33 = '9e-11*(1-0.070*A4NP_33)+2.4e-11*ccoflag_33'

+ c1fn_33=8.00E+41           c2fn_33=5.55E+24           c3fn_33=7.75E+6                     
+ c1fp_33=2.40E+41           c2fp_33=9.00E+21           c3fp_33=2.00E+09           
+ fn_dice_33n='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
+ arearation_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_33='c1fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noibn_33='c2fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ noicn_33='c3fn_33*2.718**((fn_dice_33n+(1-fn_dice_33n)*noiseflagn_33)*arearation_33)'
+ fn_dice_33p='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
+ arearatiop_33='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noiap_33='c1fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noibp_33='c2fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'
+ noicp_33='c3fp_33*2.718**((fn_dice_33p+(1-fn_dice_33p)*noiseflagp_33)*arearatiop_33)'

.lib 'crn65lp_v1d5.l' MAC_33
.lib 'crn65lp_v1d5.l' MOS_33
.ENDL FS_33







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+A1_na='-par1*3.2887*3/2.3'
+A2_na='-par2*2.3913*3/2.3'
+A3_na='-par3*0.58018*3/2.3'
+toxn_na        ='2.6e-09+(-1.021e-011)*A1_na+(-1.7974e-011)*A2_na+(-4.6513e-012)*A3_na'
+dxln_na        ='0+(-7.6734e-010)*A1_na+(-1.8997e-009)*A2_na+(4.8058e-010)*A3_na'
+dxwn_na        ='max(0,0+(1.9544e-009)*A1_na+(2.4031e-009)*A2_na+(-5.9391e-009)*A3_na)'
+dvthn_na       ='0+(-0.0087932)*A1_na+(0.0056567)*A2_na+(0.0009701)*A3_na'
+dlvthn_na      ='0+(-1.0775e-009)*A1_na+(5.8171e-011)*A2_na+(9.163e-011)*A3_na'
+dwvthn_na      ='0+(-2.9632e-010)*A1_na+(1.0441e-010)*A2_na+(-4.8172e-010)*A3_na'
+dpvthn_na      ='0+(-1.178e-016)*A1_na+(1.2505e-016)*A2_na+(3.0695e-016)*A3_na'
+cjn_na         ='0.000155+(-2.4064e-006)*A1_na+(1.4144e-006)*A2_na+(-5.3186e-007)*A3_na'
+cjswn_na       ='1.82e-10+(-2.8256e-012)*A1_na+(1.6607e-012)*A2_na+(-6.2451e-013)*A3_na'
+cjswgn_na      ='1.43e-10+(-2.2201e-012)*A1_na+(1.3049e-012)*A2_na+(-4.9068e-013)*A3_na'
+cgon_na        ='1.58659e-10+(1.6924e-012)*A1_na+(2.9794e-012)*A2_na+(7.7097e-013)*A3_na'
+cgln_na        ='3.27874e-10+(3.4973e-012)*A1_na+(6.1571e-012)*A2_na+(1.5932e-012)*A3_na'
+cfn_na         ='1.200000e-010+(1.28e-012)*A1_na+(2.2535e-012)*A2_na+(5.8315e-013)*A3_na+5.4e-11*ccoflag_na'
+dleta0n_na     ='0+(2.5124e-009)*A1_na+(-1.6162e-009)*A2_na+(-2.7717e-010)*A3_na'
+dlvsatn_na     ='min(0,0+(-0.00017743)*A1_na+(0.00010429)*A2_na+(-3.9215e-005)*A3_na)'
+dpvsatn_na     ='min(0,0+(-1.7743e-010)*A1_na+(1.0429e-010)*A2_na+(-3.9215e-011)*A3_na)'
+ntoxn_na       ='1+(0.045715)*A1_na+(0.080481)*A2_na+(0.020827)*A3_na'
+ddlcn_na       =3.47595e-08
+deta0n_na      =0
+dweta0n_na     =0
+dpeta0n_na     =0
+dk2n_na        =0
+dlk2n_na       =0
+dwk2n_na       =0
+dpk2n_na       =0
+dvsatn_na      =0
+dwvsatn_na     =0

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' mos_na
.ENDL mc_na








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+toxn_na        = 2.6e-09       dxln_na        = 0             dxwn_na        = 0
+dvthn_na       = 0             dlvthn_na      = 0             dwvthn_na      = 0
+dpvthn_na      = 0             cjn_na         = 0.000155      cjswn_na       = 1.82e-10
+cjswgn_na      = 1.43e-10      cgon_na        = 1.58659E-10   cgln_na        = 3.27874E-10
+ddlcn_na       = 3.47595e-08   cfn_na         = '1.20e-10 + 5.4e-11*ccoflag_na' deta0n_na      = 0
+dleta0n_na     = 0             dweta0n_na     = 0             dpeta0n_na     = 0
+dk2n_na        = 0             dlk2n_na       = 0             dwk2n_na       = 0
+dpk2n_na       = 0             dvsatn_na      = 0             dlvsatn_na     = 0
+dwvsatn_na     = 0             dpvsatn_na     = 0             ntoxn_na       = 1

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' MAC_na
.lib 'crn65lp_v1d5.l' MOS_na
.ENDL TT_na








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+toxn_na        = 2.667e-09     dxln_na        = 5e-09         dxwn_na        = -8e-09
+dvthn_na       = 0.035         dlvthn_na      = 5.5e-09       dwvthn_na      = 2e-09
+dpvthn_na      = 0             cjn_na         = 0.00016585    cjswn_na       = 1.9474e-10
+cjswgn_na      = 1.5301e-10    cgon_na        = 1.47553E-10   cgln_na        = 3.04923E-10
+ddlcn_na       = 3.47595e-08   cfn_na         = '1.1160e-10 + 5.4e-11*ccoflag_na' deta0n_na      = 0
+dleta0n_na     = -1e-08        dweta0n_na     = 0             dpeta0n_na     = 0
+dk2n_na        = 0             dlk2n_na       = 0             dwk2n_na       = 0
+dpk2n_na       = 0             dvsatn_na      = 0             dlvsatn_na     = 0.0008
+dwvsatn_na     = 0             dpvsatn_na     = 8e-10         ntoxn_na       = 0.7

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' MAC_na
.lib 'crn65lp_v1d5.l' MOS_na
.ENDL SS_na








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+toxn_na        = 2.533e-09     dxln_na        = -5e-09        dxwn_na        = 8e-09
+dvthn_na       = -0.042        dlvthn_na      = -4.5e-09      dwvthn_na      = -1e-09
+dpvthn_na      = -8e-16        cjn_na         = 0.00014415    cjswn_na       = 1.6926e-10
+cjswgn_na      = 1.3299e-10    cgon_na        = 1.69765E-10   cgln_na        = 3.50825E-10
+ddlcn_na       = 3.47595e-08   cfn_na         = '1.2840e-10 + 5.4e-11*ccoflag_na' deta0n_na      = 0
+dleta0n_na     = 1.2e-08       dweta0n_na     = 0             dpeta0n_na     = 0
+dk2n_na        = 0             dlk2n_na       = 0             dwk2n_na       = 0
+dpk2n_na       = 0             dvsatn_na      = 0             dlvsatn_na     = -0.0008
+dwvsatn_na     = 0             dpvsatn_na     = -8e-10        ntoxn_na       = 1.3

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' MAC_na
.lib 'crn65lp_v1d5.l' MOS_na
.ENDL FF_na








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+A1N_na=0.8 A1P_na=-0.8 A2N_na=0 A2P_na=0 A3N_na=-1 A3P_na=1 A4NP_na=0
+toxn_na = '2.6e-09 + 6.7000e-011*A4NP_na'     dxln_na = '5e-009*A2N_na'                     dxwn_na = '8e-009*A3N_na'
+dvthn_na = '0.042*A1N_na'                     dlvthn_na = '4.5e-009*A1N_na'                 dwvthn_na = '1e-009*A1N_na'
+dpvthn_na = '8e-016*A1N_na'                   cjn_na = '0.000155 * (1+0.070*A1N_na)'        cjswn_na = '1.82e-10 * (1+0.070*A1N_na)'
+cjswgn_na = '1.43e-10 * (1+0.070*A1N_na)'     cgon_na = '1.58659E-10 * (1-0.070*A4NP_na)'   cgln_na = '3.27874E-10 * (1-0.070*A4NP_na)'
+ddlcn_na = 3.47595e-08
+cfn_na = '1.20e-10*(1-0.072*A4NP_na)+5.4e-11*ccoflag_na'
+deta0n_na = 0                                 dleta0n_na = '-1.2e-008*A1N_na'               dweta0n_na = 0
+dpeta0n_na = 0                                dk2n_na = 0                                   dlk2n_na = 0
+dwk2n_na = 0                                  dpk2n_na = 0                                  dvsatn_na = 0
+dlvsatn_na = '0.0008*A1N_na'                  dwvsatn_na = 0                                dpvsatn_na = '8e-010*A1N_na'
+ntoxn_na = '1 + -3.0000e-001*A4NP_na'

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' MAC_na
.lib 'crn65lp_v1d5.l' MOS_na
.ENDL SF_na








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_na
.lib 'crn65lp_v1d5.l' noiseflag_na
.lib 'crn65lp_v1d5.l' post_simu_na
.param
+parn1_na=AGAUSS(0,1,1)
+parn2_na=AGAUSS(0,1,1)
+A1N_na=-0.8 A1P_na=0.8 A2N_na=0 A2P_na=0 A3N_na=1 A3P_na=-1 A4NP_na=0
+toxn_na = '2.6e-09 + 6.7000e-011*A4NP_na'     dxln_na = '5e-009*A2N_na'                     dxwn_na = '8e-009*A3N_na'
+dvthn_na = '0.042*A1N_na'                     dlvthn_na = '4.5e-009*A1N_na'                 dwvthn_na = '1e-009*A1N_na'
+dpvthn_na = '8e-016*A1N_na'                   cjn_na = '0.000155 * (1+0.070*A1N_na)'        cjswn_na = '1.82e-10 * (1+0.070*A1N_na)'
+cjswgn_na = '1.43e-10 * (1+0.070*A1N_na)'     cgon_na = '1.58659E-10 * (1-0.070*A4NP_na)'   cgln_na = '3.27874E-10 * (1-0.070*A4NP_na)'
+ddlcn_na = 3.47595e-08
+cfn_na = '1.20e-10*(1-0.072*A4NP_na)+5.4e-11*ccoflag_na'
+deta0n_na = 0                                 dleta0n_na = '-1.2e-008*A1N_na'               dweta0n_na = 0
+dpeta0n_na = 0                                dk2n_na = 0                                   dlk2n_na = 0
+dwk2n_na = 0                                  dpk2n_na = 0                                  dvsatn_na = 0
+dlvsatn_na = '0.0008*A1N_na'                  dwvsatn_na = 0                                dpvsatn_na = '8e-010*A1N_na'
+ntoxn_na = '1 + -3.0000e-001*A4NP_na'

+ c1fn_na=1.00E+42           c2fn_na=3.56E+21           c3fn_na=5.100E+7    
+ fn_dice_na='noiseflagn_na_mc*par1fn_mc+noiseflagn_na_mc_mis*par2fn_na_mc'
+ arearation_na='sigma_factor_flicker_na*(log(3.873)-min(0,0.555*log(((1e-6*0.06e-6*1)/(12.7E-6*1E-6*1))**0.5)))'
+ noian_na='c1fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noibn_na='c2fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'
+ noicn_na='c3fn_na*2.718**((fn_dice_na+(1-fn_dice_na)*noiseflagn_na)*arearation_na)'

.lib 'crn65lp_v1d5.l' MAC_na
.lib 'crn65lp_v1d5.l' MOS_na
.ENDL FS_na







***************************     LIBRARY OF STATISTICAL CASE     ***************************
.LIB mc_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+A1_na25='par6*3.0821e+000/2.15*3' A2_na25='par7*2.3340e+000/2.15*3' A3_na25='par8*1.0192e+000/2.15*3' A4_na25='par9*1.2047e-001/2.15*3'
+toxn_na25       = '5.6000e-009+(-4.3997e-011)*A1_na25+(-8.6813e-011)*A2_na25+(-2.2516e-011)*A3_na25+(4.4952e-011)*A4_na25'
+dxln_na25       = '0.0000e+000+(-1.4387e-009)*A1_na25+(-3.9925e-009)*A2_na25+(-7.1539e-010)*A3_na25+(-9.4769e-009)*A4_na25'
+ori_dxwn_na25       = '0.0000e+000+(1.7599e-009)*A1_na25+(3.4725e-009)*A2_na25+(9.0065e-010)*A3_na25+(-1.7981e-009)*A4_na25'
+dxwn_na25       = '((ori_dxwn_na25+1.4e-8)+sqrt((ori_dxwn_na25+1.4e-8)*(ori_dxwn_na25+1.4e-8)+1e-26)-1.4e-8-sqrt(1.4e-8*1.4e-8+1e-26))*0.5'
*+dxwn_na25       = '0.0000e+000+(1.7599e-009)*A1_na25+(3.4725e-009)*A2_na25+(9.0065e-010)*A3_na25+(-1.7981e-009)*A4_na25'
+cjn_na25        = '1.4516e-004+(-2.6802e-006)*A1_na25+(1.1611e-006)*A2_na25+(5.1817e-007)*A3_na25+(-1.2118e-007)*A4_na25'
+cjswn_na25      = '1.9352e-010+(-3.5731e-012)*A1_na25+(1.5479e-012)*A2_na25+(6.9080e-013)*A3_na25+(-1.6168e-013)*A4_na25'
+cjswgn_na25     = '1.1776e-010+(-2.1744e-012)*A1_na25+(9.4199e-013)*A2_na25+(4.2013e-013)*A3_na25+(-9.9029e-014)*A4_na25'
+cgon_na25       = '5.4786e-011+(5.6243e-013)*A1_na25+(1.1098e-012)*A2_na25+(2.8783e-013)*A3_na25+(-5.7461e-013)*A4_na25'
+cgln_na25       = '7.5784e-010+(7.7800e-012)*A1_na25+(1.5351e-011)*A2_na25+(3.9816e-012)*A3_na25+(-7.9499e-012)*A4_na25'
+dvthn_na25      = '0.0000e+000+(-1.2738e-002)*A1_na25+(5.9117e-003)*A2_na25+(8.5692e-004)*A3_na25+(-6.2110e-004)*A4_na25'
+dlvthn_na25     = '0.0000e+000+(-8.9650e-009)*A1_na25+(3.7627e-009)*A2_na25+(2.2273e-009)*A3_na25+(-3.9208e-010)*A4_na25'
+dwvthn_na25     = '0.0000e+000+(-2.9013e-011)*A1_na25+(-1.2967e-010)*A2_na25+(5.8615e-010)*A3_na25+(1.4787e-011)*A4_na25'
+dpvthn_na25     = '0.0000e+000+(1.7145e-016)*A1_na25+(-7.4275e-017)*A2_na25+(-3.3148e-017)*A3_na25+(7.7605e-018)*A4_na25'
+du0n_na25       = '0.0000e+000+(4.8748e-004)*A1_na25+(-1.9302e-004)*A2_na25+(-1.6836e-004)*A3_na25+(2.0009e-005)*A4_na25'
+dpu0n_na25      = '0.0000e+000+(2.6377e-017)*A1_na25+(-1.1427e-017)*A2_na25+(-5.0996e-018)*A3_na25+(1.1939e-018)*A4_na25'
+dcitn_na25      = '0.0000e+000+(4.0072e-004)*A1_na25+(-3.5517e-004)*A2_na25+(6.6365e-004)*A3_na25+(3.8691e-005)*A4_na25'
+cfn_na25        = '9.0000e-011+(9.2394e-013)*A1_na25+(1.8231e-012)*A2_na25+(4.7284e-013)*A3_na25+(-9.4399e-013)*A4_na25+4.5e-11*ccoflag_na25'
+ddlcn_na25      = '1.3015e-007'
+dlu0n_na25      = '0.0000e+000'
+dwu0n_na25      = '0.0000e+000'
+dlcitn_na25     = '0.0000e+000'
+dwcitn_na25     = '0.0000e+000'
+dpcitn_na25     = '0.0000e+000'
+dnfactorn_na25  = '0.0000e+000'
+dlnfactorn_na25 = '0.0000e+000'
+dwnfactorn_na25 = '0.0000e+000'
+dpnfactorn_na25 = '0.0000e+000'
+dvsatn_na25     = '0.0000e+000'
+dlvsatn_na25    = '0.0000e+000'
+dwvsatn_na25    = '0.0000e+000'
+dpvsatn_na25    = '0.0000e+000'
+deta0n_na25     = '0.0000e+000'
+dleta0n_na25    = '0.0000e+000'
+dweta0n_na25    = '0.0000e+000'
+dpeta0n_na25    = '0.0000e+000'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL mc_na25








***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+toxn_na25        = 5.6e-09       dxln_na25        = 0             dxwn_na25        = 0
+cjn_na25         = 0.000145159   cjswn_na25       = 1.93515E-10   cjswgn_na25      = 1.17763E-10
+cgon_na25        = 5.47859E-11   cgln_na25        = 7.57836E-10   ddlcn_na25       = 1.30153E-07
+dvthn_na25       = 0             dlvthn_na25      = 0             dwvthn_na25      = 0
+dpvthn_na25      = 0             du0n_na25        = 0             dlu0n_na25       = 0
+dwu0n_na25       = 0             dpu0n_na25       = 0             dcitn_na25       = 0
+dlcitn_na25      = 0             dwcitn_na25      = 0             dpcitn_na25      = 0
+dnfactorn_na25   = 0             dlnfactorn_na25  = 0             dwnfactorn_na25  = 0
+dpnfactorn_na25  = 0             dvsatn_na25      = 0             dlvsatn_na25     = 0
+dwvsatn_na25     = 0             dpvsatn_na25     = 0             deta0n_na25      = 0
+dleta0n_na25     = 0             dweta0n_na25     = 0             dpeta0n_na25     = 0
+cfn_na25         = '9e-11 + 2.4e-11*ccoflag_na25'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MAC_na25
.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL TT_na25








***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+toxn_na25        = 5.9e-09       dxln_na25        = 1e-08         dxwn_na25        = -1.2e-08
+cjn_na25         = 0.00015532    cjswn_na25       = 2.07061E-10   cjswgn_na25      = 1.26006E-10
+cgon_na25        = 5.09509E-11   cgln_na25        = 7.04787E-10   ddlcn_na25       = 1.30153E-07
+dvthn_na25       = 0.045         dlvthn_na25      = 3.5e-08       dwvthn_na25      = 1.3e-09
+dpvthn_na25      = -6.5e-16      du0n_na25        = -0.002        dlu0n_na25       = 0
+dwu0n_na25       = 0             dpu0n_na25       = -1e-16        dcitn_na25       = 0
+dlcitn_na25      = 0             dwcitn_na25      = 0             dpcitn_na25      = 0
+dnfactorn_na25   = 0             dlnfactorn_na25  = 0             dwnfactorn_na25  = 0
+dpnfactorn_na25  = 0             dvsatn_na25      = 0             dlvsatn_na25     = 0
+dwvsatn_na25     = 0             dpvsatn_na25     = 0             deta0n_na25      = 0
+dleta0n_na25     = 0             dweta0n_na25     = 0             dpeta0n_na25     = 0
+cfn_na25         = '8.37e-11 + 2.4e-11*ccoflag_na25'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MAC_na25
.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL SS_na25








***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+toxn_na25        = 5.3e-09       dxln_na25        = -1e-08        dxwn_na25        = 1.2e-08
+cjn_na25         = 0.000134998   cjswn_na25       = 1.79969E-10   cjswgn_na25      = 1.09519E-10
+cgon_na25        = 5.86209E-11   cgln_na25        = 8.10885E-10   ddlcn_na25       = 1.30153E-07
+dvthn_na25       = -0.0515       dlvthn_na25      = -3.3e-08      dwvthn_na25      = 1.05e-09
+dpvthn_na25      = 6.5e-16       du0n_na25        = 0.0017        dlu0n_na25       = 0
+dwu0n_na25       = 0             dpu0n_na25       = 1e-16         dcitn_na25       = 0.003
+dlcitn_na25      = 0             dwcitn_na25      = 0             dpcitn_na25      = 0
+dnfactorn_na25   = 0             dlnfactorn_na25  = 0             dwnfactorn_na25  = 0
+dpnfactorn_na25  = 0             dvsatn_na25      = 0             dlvsatn_na25     = 0
+dwvsatn_na25     = 0             dpvsatn_na25     = 0             deta0n_na25      = 0
+dleta0n_na25     = 0             dweta0n_na25     = 0             dpeta0n_na25     = 0
+cfn_na25         = '9.63e-11 + 2.4e-11*ccoflag_na25'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MAC_na25
.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL FF_na25








***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+toxn_na25        = 5.6e-09       dxln_na25        = 0             dxwn_na25        = 0
+cjn_na25         = 0.00015532    cjswn_na25       = 2.07061E-10   cjswgn_na25      = 1.26006E-10
+cgon_na25        = 5.47859E-11   cgln_na25        = 7.57836E-10   ddlcn_na25       = 1.30153E-07
+dvthn_na25       = 0.045         dlvthn_na25      = 3.5e-08       dwvthn_na25      = 1.3e-09
+dpvthn_na25      = -6.5e-16      du0n_na25        = -0.002        dlu0n_na25       = 0
+dwu0n_na25       = 0             dpu0n_na25       = -1e-16        dcitn_na25       = 0
+dlcitn_na25      = 0             dwcitn_na25      = 0             dpcitn_na25      = 0
+dnfactorn_na25   = 0             dlnfactorn_na25  = 0             dwnfactorn_na25  = 0
+dpnfactorn_na25  = 0             dvsatn_na25      = 0             dlvsatn_na25     = 0
+dwvsatn_na25     = 0             dpvsatn_na25     = 0             deta0n_na25      = 0
+dleta0n_na25     = 0             dweta0n_na25     = 0             dpeta0n_na25     = 0
+cfn_na25         = '9e-11 + 2.4e-11*ccoflag_na25'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MAC_na25
.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL SF_na25








***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_na25
.lib 'crn65lp_v1d5.l' noiseflag_na25
.lib 'crn65lp_v1d5.l' post_simu_na25
.param
+parn1_na25=AGAUSS(0,1,1)
+parn2_na25=AGAUSS(0,1,1)
+toxn_na25        = 5.6e-09       dxln_na25        = 0             dxwn_na25        = 0
+cjn_na25         = 0.000134998   cjswn_na25       = 1.79969E-10   cjswgn_na25      = 1.09519E-10
+cgon_na25        = 5.47859E-11   cgln_na25        = 7.57836E-10   ddlcn_na25       = 1.30153E-07
+dvthn_na25       = -0.0515       dlvthn_na25      = -3.3e-08      dwvthn_na25      = 1.05e-09
+dpvthn_na25      = 6.5e-16       du0n_na25        = 0.0017        dlu0n_na25       = 0
+dwu0n_na25       = 0             dpu0n_na25       = 1e-16         dcitn_na25       = 0.003
+dlcitn_na25      = 0             dwcitn_na25      = 0             dpcitn_na25      = 0
+dnfactorn_na25   = 0             dlnfactorn_na25  = 0             dwnfactorn_na25  = 0
+dpnfactorn_na25  = 0             dvsatn_na25      = 0             dlvsatn_na25     = 0
+dwvsatn_na25     = 0             dpvsatn_na25     = 0             deta0n_na25      = 0
+dleta0n_na25     = 0             dweta0n_na25     = 0             dpeta0n_na25     = 0
+cfn_na25         = '9e-11 + 2.4e-11*ccoflag_na25'

+ c1fn_na25=2.00E+41           c2fn_na25=5.55E+24           c3fn_na25=5.75E+6        
+ fn_dice_na25='noiseflagn_na25_mc*par1fn_mc+noiseflagn_na25_mc_mis*par2fn_na25_mc'
+ arearation_na25='sigma_factor_flicker_na25*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25='c1fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noibn_na25='c2fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'
+ noicn_na25='c3fn_na25*2.718**((fn_dice_na25+(1-fn_dice_na25)*noiseflagn_na25)*arearation_na25)'

.lib 'crn65lp_v1d5.l' MAC_na25
.lib 'crn65lp_v1d5.l' MOS_na25
.ENDL FS_na25


**********************************************************************************************
.LIB TT_na25od33
.lib 'crn65lp_v1d5.l' post_simu_na25od33
.lib 'crn65lp_v1d5.l' noiseflag_na25od33
.param
+toxn_na25od33        = 5.6e-09       dxln_na25od33        = 0             dxwn_na25od33        = 0
+cjn_na25od33         = 0.000145159   cjswn_na25od33       = 1.93515E-10   cjswgn_na25od33      = 1.17763E-10
+cgon_na25od33        = 5.47859E-11   cgln_na25od33        = 7.57836E-10   ddlcn_na25od33       = 1.30153E-07
+dvthn_na25od33       = 0             dlvthn_na25od33      = 0             dwvthn_na25od33      = 0
+dpvthn_na25od33      = 0             du0n_na25od33        = 0             dlu0n_na25od33       = 0
+dwu0n_na25od33       = 0             dpu0n_na25od33       = 0             dcitn_na25od33       = 0
+dlcitn_na25od33      = 0             dwcitn_na25od33      = 0             dpcitn_na25od33      = 0
+dnfactorn_na25od33   = 0             dlnfactorn_na25od33  = 0             dwnfactorn_na25od33  = 0
+dpnfactorn_na25od33  = 0             dvsatn_na25od33      = 0             dlvsatn_na25od33     = 0
+dwvsatn_na25od33     = 0             dpvsatn_na25od33     = 0             deta0n_na25od33      = 0
+dleta0n_na25od33     = 0             dweta0n_na25od33     = 0             dpeta0n_na25od33     = 0
+cfn_na25od33         = '9e-11 + 2.4e-11*ccoflag_na25od33'
+dvoffn_na25od33      = 0		  dlvoffn_na25od33     = 0		   dwvoffn_na25od33     = 0
+dpvoffn_na25od33     = 0		  dagsn_na25od33	   = 0		  dwagsn_na25od33	   = 0
    
+ c1fn_na25od33=2.00E+41           c2fn_na25od33=5.55E+24           c3fn_na25od33=5.75E+6        
+ fn_dice_na25od33='noiseflagn_na25od33_mc*par1fn_mc+noiseflagn_na25od33_mc_mis*par2fn_na25od33_mc'
+ arearation_na25od33='sigma_factor_flicker_na25od33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25od33='c1fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noibn_na25od33='c2fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noicn_na25od33='c3fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'

.lib 'crn65lp_v1d5.l' MOS_na25od33
.ENDL TT_na25od33

***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_na25od33
.lib 'crn65lp_v1d5.l' post_simu_na25od33
.lib 'crn65lp_v1d5.l' noiseflag_na25od33
.param
+toxn_na25od33        = 5.9e-09       dxln_na25od33        = 1e-08         dxwn_na25od33        = -1.2e-08
+cjn_na25od33         = 0.00015532    cjswn_na25od33       = 2.07061E-10   cjswgn_na25od33      = 1.26006E-10
+cgon_na25od33        = 5.09509E-11   cgln_na25od33        = 7.04787E-10   ddlcn_na25od33       = 1.30153E-07
+dvthn_na25od33       = 0.045         dlvthn_na25od33      = 3.5e-08       dwvthn_na25od33      = 1.3e-09
+dpvthn_na25od33      = -6.5e-16      du0n_na25od33        = -0.0017        dlu0n_na25od33       = 4e-10
+dwu0n_na25od33       = 0             dpu0n_na25od33       = -5e-16        dcitn_na25od33       = 0
+dlcitn_na25od33      = 0             dwcitn_na25od33      = 0             dpcitn_na25od33      = 0
+dnfactorn_na25od33   = 0             dlnfactorn_na25od33  = 0             dwnfactorn_na25od33  = 0
+dpnfactorn_na25od33  = 0             dvsatn_na25od33      = 0             dlvsatn_na25od33     = 1e-2
+dwvsatn_na25od33     = 0             dpvsatn_na25od33     = -1e-9             deta0n_na25od33      = 0
+dleta0n_na25od33     = 0             dweta0n_na25od33     = 0             dpeta0n_na25od33     = 0
+cfn_na25od33         = '8.37e-11 + 2.4e-11*ccoflag_na25od33'
+dvoffn_na25od33      = 0		  dlvoffn_na25od33     = 0		   dwvoffn_na25od33     = 0
+dpvoffn_na25od33     = 0		  dagsn_na25od33	   = 0		  dwagsn_na25od33	   = 0

+ c1fn_na25od33=2.00E+41           c2fn_na25od33=5.55E+24           c3fn_na25od33=5.75E+6        
+ fn_dice_na25od33='noiseflagn_na25od33_mc*par1fn_mc+noiseflagn_na25od33_mc_mis*par2fn_na25od33_mc'
+ arearation_na25od33='sigma_factor_flicker_na25od33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25od33='c1fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noibn_na25od33='c2fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noicn_na25od33='c3fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'

.lib 'crn65lp_v1d5.l' MOS_na25od33
.ENDL SS_na25od33

***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_na25od33
.lib 'crn65lp_v1d5.l' post_simu_na25od33
.lib 'crn65lp_v1d5.l' noiseflag_na25od33
.param
+toxn_na25od33        = 5.3e-09       dxln_na25od33        = -1e-08        dxwn_na25od33        = 1.2e-08
+cjn_na25od33         = 0.000134998   cjswn_na25od33       = 1.79969E-10   cjswgn_na25od33      = 1.09519E-10
+cgon_na25od33        = 5.86209E-11   cgln_na25od33        = 8.10885E-10   ddlcn_na25od33       = 1.30153E-07
+dvthn_na25od33       = -0.0775       dlvthn_na25od33      = -3.5e-08      dwvthn_na25od33      = 1.05e-09
+dpvthn_na25od33      = 65.8e-16       du0n_na25od33        = 0.00025        dlu0n_na25od33       = 0
+dwu0n_na25od33       = 0             dpu0n_na25od33       = 6.5e-16         dcitn_na25od33       = 0.003
+dlcitn_na25od33      = 0             dwcitn_na25od33      = 0             dpcitn_na25od33      = 0
+dnfactorn_na25od33   = 0             dlnfactorn_na25od33  = 0             dwnfactorn_na25od33  = 0
+dpnfactorn_na25od33  = 0             dvsatn_na25od33      = 0             dlvsatn_na25od33     = -1.4e-2
+dwvsatn_na25od33     = 0             dpvsatn_na25od33     = 1e-9             deta0n_na25od33      = 0
+dleta0n_na25od33     = 0             dweta0n_na25od33     = 0             dpeta0n_na25od33     = 0
+cfn_na25od33         = '9.63e-11 + 2.4e-11*ccoflag_na25od33'
+dvoffn_na25od33      = 0.02		  dlvoffn_na25od33     = 0		   dwvoffn_na25od33     = 0
+dpvoffn_na25od33     = 0		  dagsn_na25od33	   = 0		  dwagsn_na25od33	   = -1.3e-8

+ c1fn_na25od33=2.00E+41           c2fn_na25od33=5.55E+24           c3fn_na25od33=5.75E+6        
+ fn_dice_na25od33='noiseflagn_na25od33_mc*par1fn_mc+noiseflagn_na25od33_mc_mis*par2fn_na25od33_mc'
+ arearation_na25od33='sigma_factor_flicker_na25od33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25od33='c1fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noibn_na25od33='c2fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noicn_na25od33='c3fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'

.lib 'crn65lp_v1d5.l' MOS_na25od33
.ENDL FF_na25od33

***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_na25od33
.lib 'crn65lp_v1d5.l' post_simu_na25od33
.lib 'crn65lp_v1d5.l' noiseflag_na25od33
.param
+toxn_na25od33        = 5.6e-09       dxln_na25od33        = 0             dxwn_na25od33        = 0
+cjn_na25od33         = 0.00015532    cjswn_na25od33       = 2.07061E-10   cjswgn_na25od33      = 1.26006E-10
+cgon_na25od33        = 5.47859E-11   cgln_na25od33        = 7.57836E-10   ddlcn_na25od33       = 1.30153E-07
+dvthn_na25od33       = 0.045         dlvthn_na25od33      = 3.5e-08       dwvthn_na25od33      = 1.3e-09
+dpvthn_na25od33      = -6.5e-16      du0n_na25od33        = -0.002        dlu0n_na25od33       = 0
+dwu0n_na25od33       = 0             dpu0n_na25od33       = -1e-16        dcitn_na25od33       = 0
+dlcitn_na25od33      = 0             dwcitn_na25od33      = 0             dpcitn_na25od33      = 0
+dnfactorn_na25od33   = 0             dlnfactorn_na25od33  = 0             dwnfactorn_na25od33  = 0
+dpnfactorn_na25od33  = 0             dvsatn_na25od33      = 0             dlvsatn_na25od33     = 0.5e-2
+dwvsatn_na25od33     = 0             dpvsatn_na25od33     = -0.8e-9             deta0n_na25od33      = 0
+dleta0n_na25od33     = 0             dweta0n_na25od33     = 0             dpeta0n_na25od33     = 0
+cfn_na25od33         = '9e-11 + 2.4e-11*ccoflag_na25od33'
+dvoffn_na25od33      = 0		  dlvoffn_na25od33     = 0		   dwvoffn_na25od33     = 0
+dpvoffn_na25od33     = 0		  dagsn_na25od33	   = 0		  dwagsn_na25od33	   = 0

+ c1fn_na25od33=2.00E+41           c2fn_na25od33=5.55E+24           c3fn_na25od33=5.75E+6        
+ fn_dice_na25od33='noiseflagn_na25od33_mc*par1fn_mc+noiseflagn_na25od33_mc_mis*par2fn_na25od33_mc'
+ arearation_na25od33='sigma_factor_flicker_na25od33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25od33='c1fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noibn_na25od33='c2fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noicn_na25od33='c3fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'

.lib 'crn65lp_v1d5.l' MOS_na25od33
.ENDL SF_na25od33

***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_na25od33
.lib 'crn65lp_v1d5.l' post_simu_na25od33
.lib 'crn65lp_v1d5.l' noiseflag_na25od33
.param
+toxn_na25od33        = 5.6e-09       dxln_na25od33        = 0             dxwn_na25od33        = 0
+cjn_na25od33         = 0.000134998   cjswn_na25od33       = 1.79969E-10   cjswgn_na25od33      = 1.09519E-10
+cgon_na25od33        = 5.47859E-11   cgln_na25od33        = 7.57836E-10   ddlcn_na25od33       = 1.30153E-07
+dvthn_na25od33       = -0.0515       dlvthn_na25od33      = -3.3e-08      dwvthn_na25od33      = 1.05e-09
+dpvthn_na25od33      = 6.5e-16       du0n_na25od33        = 0.0017        dlu0n_na25od33       = 0
+dwu0n_na25od33       = 0             dpu0n_na25od33       = 1e-16         dcitn_na25od33       = 0.003
+dlcitn_na25od33      = 0             dwcitn_na25od33      = 0             dpcitn_na25od33      = 0
+dnfactorn_na25od33   = 0             dlnfactorn_na25od33  = 0             dwnfactorn_na25od33  = 0
+dpnfactorn_na25od33  = 0             dvsatn_na25od33      = 0             dlvsatn_na25od33     = -0.5e-2
+dwvsatn_na25od33     = 0             dpvsatn_na25od33     = 0.8e-9             deta0n_na25od33      = 0
+dleta0n_na25od33     = 0             dweta0n_na25od33     = 0             dpeta0n_na25od33     = 0
+cfn_na25od33         = '9e-11 + 2.4e-11*ccoflag_na25od33'
+dvoffn_na25od33      = 0		  dlvoffn_na25od33     = 0		   dwvoffn_na25od33     = 0
+dpvoffn_na25od33     = 0		  dagsn_na25od33	   = 0		  dwagsn_na25od33	   = 0

+ c1fn_na25od33=2.00E+41           c2fn_na25od33=5.55E+24           c3fn_na25od33=5.75E+6        
+ fn_dice_na25od33='noiseflagn_na25od33_mc*par1fn_mc+noiseflagn_na25od33_mc_mis*par2fn_na25od33_mc'
+ arearation_na25od33='sigma_factor_flicker_na25od33*(log(3.873)-min(0,0.36*log(((10e-6*0.28e-6*1)/(28E-6*1E-6*1))**0.5)))'
+ noian_na25od33='c1fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noibn_na25od33='c2fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'
+ noicn_na25od33='c3fn_na25od33*2.718**((fn_dice_na25od33+(1-fn_dice_na25od33)*noiseflagn_na25od33)*arearation_na25od33)'

.lib 'crn65lp_v1d5.l' MOS_na25od33
.ENDL FS_na25od33


.lib mc_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+A1_hv25_snw_spw='-par6*5.8239*3/2.13'
+A2_hv25_snw_spw='-par7*4.3582*3/2.13'
+A3_hv25_snw_spw='-par8*3.9704*3/2.13'
+A4_hv25_snw_spw='-par9*1.6923*3/2.13'
+toxp_hv25_spw  ='5.9e-09+(2.0239e-011)*A1_hv25_snw_spw+(-4.3302e-011)*A2_hv25_snw_spw+(-2.4876e-011)*A3_hv25_snw_spw+(-1.6014e-011)*A4_hv25_snw_spw'
+dxlp_hv25_spw  ='0+(5.4471e-010)*A1_hv25_snw_spw+(-1.9454e-009)*A2_hv25_snw_spw+(-1.2508e-009)*A3_hv25_snw_spw+(-7.7503e-010)*A4_hv25_snw_spw'
*+dxlp_hv25_spw  =max(-1.4e-8,0+(5.4471e-010)*A1_hv25_snw_spw+(-1.9454e-009)*A2_hv25_snw_spw+(-1.2508e-009)*A3_hv25_snw_spw+(-7.7503e-010)*A4_hv25_snw_spw)
+dxwp_hv25_spw  ='0+(-4.1482e-010)*A1_hv25_snw_spw+(3.1992e-009)*A2_hv25_snw_spw+(8.1914e-011)*A3_hv25_snw_spw+(1.1299e-009)*A4_hv25_snw_spw'
+cjdp_hv25_spw  ='0.000575+(3.6436e-006)*A1_hv25_snw_spw+(-2.0683e-006)*A2_hv25_snw_spw+(5.5618e-006)*A3_hv25_snw_spw+(2.2785e-007)*A4_hv25_snw_spw'
+cjswdp_hv25_spw='5.21e-10+(3.3014e-012)*A1_hv25_snw_spw+(-1.8741e-012)*A2_hv25_snw_spw+(5.0395e-012)*A3_hv25_snw_spw+(2.0645e-013)*A4_hv25_snw_spw'
+cjswgdp_hv25_spw='2.39e-10+(1.5145e-012)*A1_hv25_snw_spw+(-8.5969e-013)*A2_hv25_snw_spw+(2.3118e-012)*A3_hv25_snw_spw+(9.4705e-014)*A4_hv25_snw_spw'
+cjsp_hv25_spw  ='0.001111+(7.0401e-006)*A1_hv25_snw_spw+(-3.9966e-006)*A2_hv25_snw_spw+(1.0747e-005)*A3_hv25_snw_spw+(4.3941e-007)*A4_hv25_snw_spw'
+cjswsp_hv25_spw='9.7e-11+(6.1466e-013)*A1_hv25_snw_spw+(-3.4891e-013)*A2_hv25_snw_spw+(9.3825e-013)*A3_hv25_snw_spw+(3.8437e-014)*A4_hv25_snw_spw'
+cjswgsp_hv25_spw='1.68e-10+(1.0646e-012)*A1_hv25_snw_spw+(-6.043e-013)*A2_hv25_snw_spw+(1.625e-012)*A3_hv25_snw_spw+(6.6571e-014)*A4_hv25_snw_spw'
+cgdop_hv25_spw ='3.00907e-13+(-1.421e-015)*A1_hv25_snw_spw+(3.0403e-015)*A2_hv25_snw_spw+(1.7466e-015)*A3_hv25_snw_spw+(1.1244e-015)*A4_hv25_snw_spw'
+cgdlp_hv25_spw ='1.5319e-09+(-7.2345e-012)*A1_hv25_snw_spw+(1.5478e-011)*A2_hv25_snw_spw+(8.8917e-012)*A3_hv25_snw_spw+(5.7242e-012)*A4_hv25_snw_spw'
+cgsop_hv25_spw ='1.19935e-10+(-5.664e-013)*A1_hv25_snw_spw+(1.2118e-012)*A2_hv25_snw_spw+(6.9615e-013)*A3_hv25_snw_spw+(4.4817e-013)*A4_hv25_snw_spw'
+cgslp_hv25_spw ='2.49822e-10+(-1.1798e-012)*A1_hv25_snw_spw+(2.5241e-012)*A2_hv25_snw_spw+(1.4501e-012)*A3_hv25_snw_spw+(9.335e-013)*A4_hv25_snw_spw'
+dvthp_hv25_spw ='0+(-0.00021885)*A1_hv25_snw_spw+(-0.0031011)*A2_hv25_snw_spw+(-0.0071214)*A3_hv25_snw_spw+(-0.0018102)*A4_hv25_snw_spw'
+dlvthp_hv25_spw='0+(-5.3633e-010)*A1_hv25_snw_spw+(6.5866e-010)*A2_hv25_snw_spw+(-6.5375e-010)*A3_hv25_snw_spw+(2.8376e-011)*A4_hv25_snw_spw'
+dwvthp_hv25_spw='0+(-2.5545e-010)*A1_hv25_snw_spw+(7.5878e-011)*A2_hv25_snw_spw+(-3.2098e-010)*A3_hv25_snw_spw+(6.4071e-011)*A4_hv25_snw_spw'
+dpvthp_hv25_spw='0+(-2.1345e-016)*A1_hv25_snw_spw+(2.7668e-016)*A2_hv25_snw_spw+(-3.4537e-016)*A3_hv25_snw_spw+(2.7473e-017)*A4_hv25_snw_spw'
+du0p_hv25_spw  ='0+(6.2954e-006)*A1_hv25_snw_spw+(8.1745e-006)*A2_hv25_snw_spw+(-9.6207e-006)*A3_hv25_snw_spw+(-5.134e-007)*A4_hv25_snw_spw'
+dlu0p_hv25_spw ='0+(-1.074e-011)*A1_hv25_snw_spw+(7.528e-012)*A2_hv25_snw_spw+(-1.6774e-011)*A3_hv25_snw_spw+(-4.12e-012)*A4_hv25_snw_spw'
+dwu0p_hv25_spw ='0+(-8.0765e-012)*A1_hv25_snw_spw+(4.7172e-012)*A2_hv25_snw_spw+(-9.6157e-012)*A3_hv25_snw_spw+(-5.5196e-012)*A4_hv25_snw_spw'
+dpu0p_hv25_spw ='0+(3.6057e-018)*A1_hv25_snw_spw+(5.0816e-018)*A2_hv25_snw_spw+(-7.3623e-018)*A3_hv25_snw_spw+(1.8086e-018)*A4_hv25_snw_spw'
*+dwvsatp_hv25_spw='0+(0.00028359)*A1_hv25_snw_spw+(-0.00031127)*A2_hv25_snw_spw+(0.00031727)*A3_hv25_snw_spw+(0.00058829)*A4_hv25_snw_spw'
+dwvsatp_hv25_spw='max(-0.001,0+(0.00028359)*A1_hv25_snw_spw+(-0.00031127)*A2_hv25_snw_spw+(0.00031727)*A3_hv25_snw_spw+(0.00058829)*A4_hv25_snw_spw)'
+dpa0p_hv25_spw ='0+(-4.6185e-015)*A1_hv25_snw_spw+(-5.345e-016)*A2_hv25_snw_spw+(-8.0009e-015)*A3_hv25_snw_spw+(9.141e-015)*A4_hv25_snw_spw'
+dagsp_hv25_spw ='0+(-0.00097494)*A1_hv25_snw_spw+(0.0012377)*A2_hv25_snw_spw+(-0.0023204)*A3_hv25_snw_spw+(-0.00059749)*A4_hv25_snw_spw'
+dlagsp_hv25_spw='0+(2.1481e-009)*A1_hv25_snw_spw+(2.486e-010)*A2_hv25_snw_spw+(3.7214e-009)*A3_hv25_snw_spw+(-4.2516e-009)*A4_hv25_snw_spw'
+dwagsp_hv25_spw='0+(4.2839e-010)*A1_hv25_snw_spw+(-2.5404e-010)*A2_hv25_snw_spw+(1.9149e-009)*A3_hv25_snw_spw+(-2.0969e-009)*A4_hv25_snw_spw'
+dpagsp_hv25_spw='0+(7.783e-015)*A1_hv25_snw_spw+(-5.0111e-015)*A2_hv25_snw_spw+(-2.5473e-016)*A3_hv25_snw_spw+(2.292e-014)*A4_hv25_snw_spw'
+dlpclmp_hv25_spw='0+(-6.7707e-010)*A1_hv25_snw_spw+(4.2388e-010)*A2_hv25_snw_spw+(-6.6944e-010)*A3_hv25_snw_spw+(-7.7763e-010)*A4_hv25_snw_spw'
*+deta0p_hv25_spw='0+(0.00040892)*A1_hv25_snw_spw+(-0.00024259)*A2_hv25_snw_spw+(0.00041005)*A3_hv25_snw_spw+(0.00042146)*A4_hv25_snw_spw'
+deta0p_hv25_spw='max(-0.003,0+(0.00040892)*A1_hv25_snw_spw+(-0.00024259)*A2_hv25_snw_spw+(0.00041005)*A3_hv25_snw_spw+(0.00042146)*A4_hv25_snw_spw)'
+dweta0p_hv25_spw='0+(3.2048e-011)*A1_hv25_snw_spw+(-2.0634e-011)*A2_hv25_snw_spw+(-1.0489e-012)*A3_hv25_snw_spw+(9.4377e-011)*A4_hv25_snw_spw'
+dlk2p_hv25_spw ='0+(6.3367e-011)*A1_hv25_snw_spw+(-3.597e-011)*A2_hv25_snw_spw+(9.6727e-011)*A3_hv25_snw_spw+(3.9625e-012)*A4_hv25_snw_spw'
+cfp_hv25_spw   ='9.000000e-011+(-4.2503e-013)*A1_hv25_snw_spw+(9.0933e-013)*A2_hv25_snw_spw+(5.2239e-013)*A3_hv25_snw_spw+(3.363e-013)*A4_hv25_snw_spw+2.4e-11*ccoflag_hv25_snw_spw'
*+dagidlp_hv25_spw='0+(-1.5381e-008)*A1_hv25_snw_spw+(6.2442e-009)*A2_hv25_snw_spw+(-2.3948e-008)*A3_hv25_snw_spw+(1.7851e-008)*A4_hv25_snw_spw'
+dagidlp_hv25_spw='max(-4.7e-008,0+(-1.5381e-008)*A1_hv25_snw_spw+(6.2442e-009)*A2_hv25_snw_spw+(-2.3948e-008)*A3_hv25_snw_spw+(1.7851e-008)*A4_hv25_snw_spw)'
+dlketap_hv25_spw='0+(-4.8532e-011)*A1_hv25_snw_spw+(-2.8591e-011)*A2_hv25_snw_spw+(-3.6058e-011)*A3_hv25_snw_spw+(9.2672e-011)*A4_hv25_snw_spw'
+toxn_hv25_snw  ='5.6e-09+(2.0239e-011)*A1_hv25_snw_spw+(-4.3302e-011)*A2_hv25_snw_spw+(-2.4876e-011)*A3_hv25_snw_spw+(-1.6014e-011)*A4_hv25_snw_spw'
+dxln_hv25_snw  ='0+(5.4471e-010)*A1_hv25_snw_spw+(-1.9454e-009)*A2_hv25_snw_spw+(-1.2508e-009)*A3_hv25_snw_spw+(-7.7503e-010)*A4_hv25_snw_spw'
*+dxln_hv25_snw  =min(1.4e-8,0+(5.4471e-010)*A1_hv25_snw_spw+(-1.9454e-009)*A2_hv25_snw_spw+(-1.2508e-009)*A3_hv25_snw_spw+(-7.7503e-010)*A4_hv25_snw_spw)
+dxwn_hv25_snw  ='0+(-8.9248e-010)*A1_hv25_snw_spw+(1.4698e-009)*A2_hv25_snw_spw+(2.9201e-009)*A3_hv25_snw_spw+(7.3017e-010)*A4_hv25_snw_spw'
+cjdn_hv25_snw  ='0.000141+(1.2078e-006)*A1_hv25_snw_spw+(6.3078e-007)*A2_hv25_snw_spw+(-5.0369e-007)*A3_hv25_snw_spw+(3.189e-007)*A4_hv25_snw_spw'
+cjswdn_hv25_snw='6.64e-10+(5.6877e-012)*A1_hv25_snw_spw+(2.9705e-012)*A2_hv25_snw_spw+(-2.372e-012)*A3_hv25_snw_spw+(1.5018e-012)*A4_hv25_snw_spw'
+cjswgdn_hv25_snw='9.14e-10+(7.8292e-012)*A1_hv25_snw_spw+(4.0889e-012)*A2_hv25_snw_spw+(-3.265e-012)*A3_hv25_snw_spw+(2.0672e-012)*A4_hv25_snw_spw'
+cjsn_hv25_snw  ='0.001195+(1.0236e-005)*A1_hv25_snw_spw+(5.346e-006)*A2_hv25_snw_spw+(-4.2688e-006)*A3_hv25_snw_spw+(2.702e-006)*A4_hv25_snw_spw'
+cjswsn_hv25_snw='1.65e-10+(1.4134e-012)*A1_hv25_snw_spw+(7.3814e-013)*A2_hv25_snw_spw+(-5.8942e-013)*A3_hv25_snw_spw+(3.7318e-013)*A4_hv25_snw_spw'
+cjswgsn_hv25_snw='2.08e-10+(1.7817e-012)*A1_hv25_snw_spw+(9.3051e-013)*A2_hv25_snw_spw+(-7.4303e-013)*A3_hv25_snw_spw+(4.7044e-013)*A4_hv25_snw_spw'
+cgdon_hv25_snw ='1.75494e-13+(-8.2878e-016)*A1_hv25_snw_spw+(1.7731e-015)*A2_hv25_snw_spw+(1.0186e-015)*A3_hv25_snw_spw+(6.5577e-016)*A4_hv25_snw_spw'
+cgdln_hv25_snw ='2.33505e-09+(-1.1027e-011)*A1_hv25_snw_spw+(2.3593e-011)*A2_hv25_snw_spw+(1.3554e-011)*A3_hv25_snw_spw+(8.7254e-012)*A4_hv25_snw_spw'
+cgson_hv25_snw ='9.95494e-11+(-4.7013e-013)*A1_hv25_snw_spw+(1.0058e-012)*A2_hv25_snw_spw+(5.7782e-013)*A3_hv25_snw_spw+(3.7199e-013)*A4_hv25_snw_spw'
+cgsln_hv25_snw ='2.67995e-10+(-1.2656e-012)*A1_hv25_snw_spw+(2.7077e-012)*A2_hv25_snw_spw+(1.5555e-012)*A3_hv25_snw_spw+(1.0014e-012)*A4_hv25_snw_spw'
+dvthn_hv25_snw ='0+(0.0010907)*A1_hv25_snw_spw+(0.0069288)*A2_hv25_snw_spw+(0.00097057)*A3_hv25_snw_spw+(0.0026166)*A4_hv25_snw_spw'
+dlvthn_hv25_snw='0+(1.6006e-009)*A1_hv25_snw_spw+(9.4615e-010)*A2_hv25_snw_spw+(-1.2164e-009)*A3_hv25_snw_spw+(4.9382e-010)*A4_hv25_snw_spw'
+dwvthn_hv25_snw='0+(2.9677e-010)*A1_hv25_snw_spw+(1.6567e-010)*A2_hv25_snw_spw+(-1.2728e-010)*A3_hv25_snw_spw+(5.381e-011)*A4_hv25_snw_spw'
+dpvthn_hv25_snw='0+(8.8933e-016)*A1_hv25_snw_spw+(1.6155e-016)*A2_hv25_snw_spw+(-8.3072e-016)*A3_hv25_snw_spw+(7.7495e-017)*A4_hv25_snw_spw'
+dcitn_hv25_snw ='0+(1.1321e-005)*A1_hv25_snw_spw+(6.9804e-006)*A2_hv25_snw_spw+(-5.0733e-006)*A3_hv25_snw_spw+(5.3451e-007)*A4_hv25_snw_spw'
+dlcitn_hv25_snw='0+(2.7554e-012)*A1_hv25_snw_spw+(2.5068e-012)*A2_hv25_snw_spw+(-1.501e-012)*A3_hv25_snw_spw+(-1.7272e-012)*A4_hv25_snw_spw'
+du0n_hv25_snw  ='0+(-7.8385e-005)*A1_hv25_snw_spw+(-2.0015e-005)*A2_hv25_snw_spw+(-7.3793e-007)*A3_hv25_snw_spw+(-2.3459e-005)*A4_hv25_snw_spw'
+dlu0n_hv25_snw ='0+(-4.0359e-010)*A1_hv25_snw_spw+(-2.1559e-010)*A2_hv25_snw_spw+(1.7922e-010)*A3_hv25_snw_spw+(-1.1143e-010)*A4_hv25_snw_spw'
+dwu0n_hv25_snw ='0+(2.5856e-011)*A1_hv25_snw_spw+(1.6173e-011)*A2_hv25_snw_spw+(-1.1662e-011)*A3_hv25_snw_spw+(6.9007e-013)*A4_hv25_snw_spw'
+dpu0n_hv25_snw ='0+(9.8886e-017)*A1_hv25_snw_spw+(6.4747e-017)*A2_hv25_snw_spw+(-4.5423e-017)*A3_hv25_snw_spw+(-1.385e-018)*A4_hv25_snw_spw'
+da0n_hv25_snw  ='0+(0.0061184)*A1_hv25_snw_spw+(0.0031954)*A2_hv25_snw_spw+(-0.0025516)*A3_hv25_snw_spw+(0.0016155)*A4_hv25_snw_spw'
+dla0n_hv25_snw ='0+(1.2237e-009)*A1_hv25_snw_spw+(6.3908e-010)*A2_hv25_snw_spw+(-5.1032e-010)*A3_hv25_snw_spw+(3.231e-010)*A4_hv25_snw_spw'
+dagsn_hv25_snw ='0+(0.0041674)*A1_hv25_snw_spw+(0.0084709)*A2_hv25_snw_spw+(0.002918)*A3_hv25_snw_spw+(-0.0031504)*A4_hv25_snw_spw'
+dlagsn_hv25_snw='0+(-2.8202e-008)*A1_hv25_snw_spw+(-3.1349e-008)*A2_hv25_snw_spw+(1.1509e-008)*A3_hv25_snw_spw+(4.0696e-008)*A4_hv25_snw_spw'
+dwagsn_hv25_snw='0+(7.9058e-010)*A1_hv25_snw_spw+(-3.8574e-009)*A2_hv25_snw_spw+(-3.5898e-009)*A3_hv25_snw_spw+(-1.6826e-009)*A4_hv25_snw_spw'
*+dvsatn_hv25_snw='0+(1017.2)*A1_hv25_snw_spw+(-226.85)*A2_hv25_snw_spw+(-174.37)*A3_hv25_snw_spw+(2011.4)*A4_hv25_snw_spw'
+dvsatn_hv25_snw='max(-6300,0+(1017.2)*A1_hv25_snw_spw+(-226.85)*A2_hv25_snw_spw+(-174.37)*A3_hv25_snw_spw+(2011.4)*A4_hv25_snw_spw)'
+dwvsatn_hv25_snw='0+(-0.00046009)*A1_hv25_snw_spw+(-5.3027e-005)*A2_hv25_snw_spw+(0.00013733)*A3_hv25_snw_spw+(-0.00056425)*A4_hv25_snw_spw'
*+dwvsatn_hv25_snw=max(0.002,0+(-0.00046009)*A1_hv25_snw_spw+(-5.3027e-005)*A2_hv25_snw_spw+(0.00013733)*A3_hv25_snw_spw+(-0.00056425)*A4_hv25_snw_spw)
*+deta0n_hv25_snw='0+(-1.3925e-005)*A1_hv25_snw_spw+(-1.2772e-005)*A2_hv25_snw_spw+(3.1448e-007)*A3_hv25_snw_spw+(1.8593e-005)*A4_hv25_snw_spw'
+deta0n_hv25_snw='max(0.00015,0+(-1.3925e-005)*A1_hv25_snw_spw+(-1.2772e-005)*A2_hv25_snw_spw+(3.1448e-007)*A3_hv25_snw_spw+(1.8593e-005)*A4_hv25_snw_spw)'
+dk2n_hv25_snw  ='0+(0.00085658)*A1_hv25_snw_spw+(0.00044736)*A2_hv25_snw_spw+(-0.00035723)*A3_hv25_snw_spw+(0.00022617)*A4_hv25_snw_spw'
+dlk2n_hv25_snw ='0+(8.5658e-011)*A1_hv25_snw_spw+(4.4736e-011)*A2_hv25_snw_spw+(-3.5723e-011)*A3_hv25_snw_spw+(2.2617e-011)*A4_hv25_snw_spw'
+cfn_hv25_snw   ='9.000000e-011+(-4.2503e-013)*A1_hv25_snw_spw+(9.0933e-013)*A2_hv25_snw_spw+(5.2239e-013)*A3_hv25_snw_spw+(3.363e-013)*A4_hv25_snw_spw+2.4e-11*ccoflag_hv25_snw_spw'
*+dagidln_hv25_snw='0+(-3.0833e-009)*A1_hv25_snw_spw+(-1.8819e-009)*A2_hv25_snw_spw+(1.0549e-009)*A3_hv25_snw_spw+(2.1e-009)*A4_hv25_snw_spw'
+dagidln_hv25_snw='max(-6.8e-009,0+(-3.0833e-009)*A1_hv25_snw_spw+(-1.8819e-009)*A2_hv25_snw_spw+(1.0549e-009)*A3_hv25_snw_spw+(2.1e-009)*A4_hv25_snw_spw)'
+dlketan_hv25_snw='0+(-3.0706e-009)*A1_hv25_snw_spw+(-2.5228e-009)*A2_hv25_snw_spw+(-6.1569e-010)*A3_hv25_snw_spw+(4.6138e-009)*A4_hv25_snw_spw'
+duc1n_hv25_snw ='0+(-1.763e-012)*A1_hv25_snw_spw+(-1.6669e-012)*A2_hv25_snw_spw+(1.5592e-013)*A3_hv25_snw_spw+(2.267e-012)*A4_hv25_snw_spw'
+dluc1n_hv25_snw='0+(3.2573e-018)*A1_hv25_snw_spw+(2.49e-018)*A2_hv25_snw_spw+(1.0875e-018)*A3_hv25_snw_spw+(-5.2202e-018)*A4_hv25_snw_spw'
+dlcp_hv25_spw  =1.63188e-07
+dnfactorp_hv25_spw=0
+dlnfactorp_hv25_spw=0
+dwnfactorp_hv25_spw=0
+dpnfactorp_hv25_spw=0
+dvoffp_hv25_spw=0
+dlvoffp_hv25_spw=0
+dwvoffp_hv25_spw=0
+dpvoffp_hv25_spw=0
+dcitp_hv25_spw =0
+dlcitp_hv25_spw=0
+dwcitp_hv25_spw=0
+dpcitp_hv25_spw=0
+dvsatp_hv25_spw=0
+dlvsatp_hv25_spw=0
+dpvsatp_hv25_spw=0
+da0p_hv25_spw  =0
+dla0p_hv25_spw =0
+dwa0p_hv25_spw =0
+dpclmp_hv25_spw=0
+dwpclmp_hv25_spw=0
+dppclmp_hv25_spw=0
+dleta0p_hv25_spw=0
+dpeta0p_hv25_spw=0
+dk2p_hv25_spw  =0
+dwk2p_hv25_spw =0
+dpk2p_hv25_spw =0
+dlagidlp_hv25_spw=0
+dwagidlp_hv25_spw=0
+dpagidlp_hv25_spw=0
+dketap_hv25_spw=0
+dwketap_hv25_spw=0
+dpketap_hv25_spw=0
+dlcn_hv25_snw  =2.18800e-07
+dwcitn_hv25_snw=0
+dpcitn_hv25_snw=0
+dwa0n_hv25_snw =0
+dpa0n_hv25_snw =0
+dpagsn_hv25_snw=0
+dlvsatn_hv25_snw=0
+dpvsatn_hv25_snw=0
+dpclmn_hv25_snw=0
+dlpclmn_hv25_snw=0
+dwpclmn_hv25_snw=0
+dppclmn_hv25_snw=0
+dleta0n_hv25_snw=0
+dweta0n_hv25_snw=0
+dpeta0n_hv25_snw=0
+dwk2n_hv25_snw =0
+dpk2n_hv25_snw =0
+dlagidln_hv25_snw=0
+dwagidln_hv25_snw=0
+dpagidln_hv25_snw=0
+dpdiblc2n_hv25_snw=0
+dlpdiblc2n_hv25_snw=0
+dwpdiblc2n_hv25_snw=0
+dppdiblc2n_hv25_snw=0
+dketan_hv25_snw=0
+dwketan_hv25_snw=0
+dpketan_hv25_snw=0
+ducn_hv25_snw  =0
+dlucn_hv25_snw =0
+dwucn_hv25_snw =0
+dpucn_hv25_snw =0
+dwuc1n_hv25_snw=0
+dpuc1n_hv25_snw=0
.lib 'crn65lp_v1d5.l' mos_hv25_snw_spw
.endl mc_hv25_snw_spw


***************************     LIBRARY OF TYPICAL CASE     ***************************
.LIB TT_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+parn1_hv25_snw_spw=AGAUSS(0,1,1)
+parn2_hv25_snw_spw=AGAUSS(0,1,1)
+parp1_hv25_snw_spw=AGAUSS(0,1,1)
+parp2_hv25_snw_spw=AGAUSS(0,1,1)
+toxp_hv25_spw        = 5.9e-09       dxlp_hv25_spw        = 0             dxwp_hv25_spw        = 0
+cjdp_hv25_spw        = 0.000575      cjswdp_hv25_spw      = 5.21e-10      cjswgdp_hv25_spw     = 2.39e-10
+cjsp_hv25_spw        = 0.001111      cjswsp_hv25_spw      = 9.7e-11       cjswgsp_hv25_spw     = 1.68e-10
+cgdop_hv25_spw       = 3.00907e-13   cgdlp_hv25_spw       = 1.5319e-09    dlcp_hv25_spw        = 1.63188e-07
+cgsop_hv25_spw       = 1.19935e-10   cgslp_hv25_spw       = 2.49822e-10   dvthp_hv25_spw       = 0
+dlvthp_hv25_spw      = 0             dwvthp_hv25_spw      = 0             dpvthp_hv25_spw      = 0
+du0p_hv25_spw        = 0             dlu0p_hv25_spw       = 0             dwu0p_hv25_spw       = 0
+dpu0p_hv25_spw       = 0             dnfactorp_hv25_spw   = 0             dlnfactorp_hv25_spw  = 0
+dwnfactorp_hv25_spw  = 0             dpnfactorp_hv25_spw  = 0             dvoffp_hv25_spw      = 0
+dlvoffp_hv25_spw     = 0             dwvoffp_hv25_spw     = 0             dpvoffp_hv25_spw     = 0
+dcitp_hv25_spw       = 0             dlcitp_hv25_spw      = 0             dwcitp_hv25_spw      = 0
+dpcitp_hv25_spw      = 0             dvsatp_hv25_spw      = 0             dlvsatp_hv25_spw     = 0
+dwvsatp_hv25_spw     = 0             dpvsatp_hv25_spw     = 0             da0p_hv25_spw        = 0
+dla0p_hv25_spw       = 0             dwa0p_hv25_spw       = 0             dpa0p_hv25_spw       = 0
+dagsp_hv25_spw       = 0             dlagsp_hv25_spw      = 0             dwagsp_hv25_spw      = 0
+dpagsp_hv25_spw      = 0             dpclmp_hv25_spw      = 0             dlpclmp_hv25_spw     = 0
+dwpclmp_hv25_spw     = 0             dppclmp_hv25_spw     = 0             deta0p_hv25_spw      = 0
+dleta0p_hv25_spw     = 0             dweta0p_hv25_spw     = 0             dpeta0p_hv25_spw     = 0
+dk2p_hv25_spw        = 0             dlk2p_hv25_spw       = 0             dwk2p_hv25_spw       = 0
+dpk2p_hv25_spw       = 0             cfp_hv25_spw         = '9e-11 + 2.4e-11*ccoflag_hv25_snw_spw' dagidlp_hv25_spw     = 0
+dlagidlp_hv25_spw    = 0             dwagidlp_hv25_spw    = 0             dpagidlp_hv25_spw    = 0
+dketap_hv25_spw      = 0             dlketap_hv25_spw     = 0             dwketap_hv25_spw     = 0
+dpketap_hv25_spw     = 0
.param
+toxn_hv25_snw        = 5.6e-09       dxln_hv25_snw        = 0             dxwn_hv25_snw        = 0
+cjdn_hv25_snw        = 0.000141      cjswdn_hv25_snw      = 6.64e-10      cjswgdn_hv25_snw     = 9.14e-10
+cjsn_hv25_snw        = 0.001195      cjswsn_hv25_snw      = 1.65e-10      cjswgsn_hv25_snw     = 2.08e-10
+cgdon_hv25_snw       = 1.75494e-13   cgdln_hv25_snw       = 2.33505e-09   dlcn_hv25_snw        = 2.18800e-07
+cgson_hv25_snw       = 9.95494e-11   cgsln_hv25_snw       = 2.67995e-10   dvthn_hv25_snw       = 0
+dlvthn_hv25_snw      = 0             dwvthn_hv25_snw      = 0             dpvthn_hv25_snw      = 0
+dcitn_hv25_snw       = 0             dlcitn_hv25_snw      = 0             dwcitn_hv25_snw      = 0
+dpcitn_hv25_snw      = 0             du0n_hv25_snw        = 0             dlu0n_hv25_snw       = 0
+dwu0n_hv25_snw       = 0             dpu0n_hv25_snw       = 0             da0n_hv25_snw        = 0
+dla0n_hv25_snw       = 0             dwa0n_hv25_snw       = 0             dpa0n_hv25_snw       = 0
+dagsn_hv25_snw       = 0             dlagsn_hv25_snw      = 0             dwagsn_hv25_snw      = 0
+dpagsn_hv25_snw      = 0             dvsatn_hv25_snw      = 0             dlvsatn_hv25_snw     = 0
+dwvsatn_hv25_snw     = 0             dpvsatn_hv25_snw     = 0             dpclmn_hv25_snw      = 0
+dlpclmn_hv25_snw     = 0             dwpclmn_hv25_snw     = 0             dppclmn_hv25_snw     = 0
+deta0n_hv25_snw      = 0             dleta0n_hv25_snw     = 0             dweta0n_hv25_snw     = 0
+dpeta0n_hv25_snw     = 0             dk2n_hv25_snw        = 0             dlk2n_hv25_snw       = 0
+dwk2n_hv25_snw       = 0             dpk2n_hv25_snw       = 0             cfn_hv25_snw         = '9e-11 + 2.4e-11*ccoflag_hv25_snw_spw'
+dagidln_hv25_snw     = 0             dlagidln_hv25_snw    = 0             dwagidln_hv25_snw    = 0
+dpagidln_hv25_snw    = 0             dpdiblc2n_hv25_snw   = 0             dlpdiblc2n_hv25_snw  = 0
+dwpdiblc2n_hv25_snw  = 0             dppdiblc2n_hv25_snw  = 0             dketan_hv25_snw      = 0
+dlketan_hv25_snw     = 0             dwketan_hv25_snw     = 0             dpketan_hv25_snw     = 0
+ducn_hv25_snw        = 0             dlucn_hv25_snw       = 0             dwucn_hv25_snw       = 0
+dpucn_hv25_snw       = 0             duc1n_hv25_snw       = 0             dluc1n_hv25_snw      = 0
+dwuc1n_hv25_snw      = 0             dpuc1n_hv25_snw      = 0
.lib 'crn65lp_v1d5.l' MOS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' MAC_hv25_snw_spw
.ENDL TT_hv25_snw_spw


***************************     LIBRARY OF SNSP CORNER CASE     ***************************
.LIB SS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+parn1_hv25_snw_spw=AGAUSS(0,1,1)
+parn2_hv25_snw_spw=AGAUSS(0,1,1)
+parp1_hv25_snw_spw=AGAUSS(0,1,1)
+parp2_hv25_snw_spw=AGAUSS(0,1,1)
+A1N_hv25_snw='-1*sigma_factor_hv25_snw_spw' A1P_hv25_spw='-1*sigma_factor_hv25_snw_spw' A2N_hv25_snw='-1*sigma_factor_hv25_snw_spw' A2P_hv25_spw='-1*sigma_factor_hv25_snw_spw' A3N_hv25_snw='1*sigma_factor_hv25_snw_spw' A3P_hv25_spw='1*sigma_factor_hv25_snw_spw' A4NP_hv25_snw_spw='-1*sigma_factor_hv25_snw_spw'
+toxp_hv25_spw = '5.9e-09-3e-010*A4NP_hv25_snw_spw'
+dxlp_hv25_spw = '-1e-008*A2P_hv25_spw'                  dxwp_hv25_spw = '-1.2e-008*A3P_hv25_spw'                cjdp_hv25_spw = '0.000575*(1-0.07*A1P_hv25_spw)'
+cjswdp_hv25_spw = '5.21e-10*(1-0.07*A1P_hv25_spw)'      cjswgdp_hv25_spw = '2.39e-10*(1-0.07*A1P_hv25_spw)'     cjsp_hv25_spw = '0.001111*(1-0.07*A1P_hv25_spw)'
+cjswsp_hv25_spw = '9.7e-11*(1-0.07*A1P_hv25_spw)'       cjswgsp_hv25_spw = '1.68e-10*(1-0.07*A1P_hv25_spw)'     cgdop_hv25_spw = '3.00907e-13*(1+0.07*A4NP_hv25_snw_spw)'
+cgdlp_hv25_spw = '1.5319e-09*(1+0.07*A4NP_hv25_snw_spw)'    dlcp_hv25_spw = 1.63188e-07                       cgsop_hv25_spw = '1.19935e-10*(1+0.07*A4NP_hv25_snw_spw)'
+cgslp_hv25_spw = '2.49822e-10*(1+0.07*A4NP_hv25_snw_spw)'   dvthp_hv25_spw = '-0.0055*A1P_hv25_spw'                 dlvthp_hv25_spw = '7.1e-009*A1P_hv25_spw'
+dwvthp_hv25_spw = '2.3e-9 *A1P_hv25_spw'                    dpvthp_hv25_spw = '2.8e-015*A1P_hv25_spw'               du0p_hv25_spw = '-2.8e-005*A1P_hv25_spw'
+dlu0p_hv25_spw = '1.36e-010*A1P_hv25_spw'                dwu0p_hv25_spw = '1.08e-010*A1P_hv25_spw'                dpu0p_hv25_spw = '-2.2e-017*A1P_hv25_spw'
+dnfactorp_hv25_spw = 0                            dlnfactorp_hv25_spw = 0                           dwnfactorp_hv25_spw = 0
+dpnfactorp_hv25_spw = 0                           dvoffp_hv25_spw = 0                               dlvoffp_hv25_spw = 0
+dwvoffp_hv25_spw = 0                              dpvoffp_hv25_spw = 0                              dcitp_hv25_spw = 0
+dlcitp_hv25_spw = 0                               dwcitp_hv25_spw = 0                               dpcitp_hv25_spw = 0
+dvsatp_hv25_spw = 0                               dlvsatp_hv25_spw = 0                              dwvsatp_hv25_spw = '-0.0060*A1P_hv25_spw'
+dpvsatp_hv25_spw = 0                              da0p_hv25_spw = 0                                 dla0p_hv25_spw = 0
+dwa0p_hv25_spw = 0                                dpa0p_hv25_spw = 0                                dagsp_hv25_spw = '0.015*A1P_hv25_spw'
+dlagsp_hv25_spw = 0                               dwagsp_hv25_spw = '0.30e-008*A1P_hv25_spw'                dpagsp_hv25_spw = '-1.7e-013*A1P_hv25_spw'
+dpclmp_hv25_spw = 0                               dlpclmp_hv25_spw = '1.03e-8*A1P_hv25_spw'                             dwpclmp_hv25_spw = 0
+dppclmp_hv25_spw = 0                              deta0p_hv25_spw = '-0.0060*A1P_hv25_spw'                  dleta0p_hv25_spw = 0
+dweta0p_hv25_spw = '-0.7e-009*A1P_hv25_spw'               dpeta0p_hv25_spw = 0                              dk2p_hv25_spw = 0
+dlk2p_hv25_spw = '-7e-010*A1P_hv25_spw'                 dwk2p_hv25_spw = 0                                dpk2p_hv25_spw = 0
+cfp_hv25_spw = '9e-11*(1+0.07*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidlp_hv25_spw = '5.7e-008*A1P_hv25_spw'              dlagidlp_hv25_spw = 0                             dwagidlp_hv25_spw = 0
+dpagidlp_hv25_spw = 0
+dketap_hv25_spw      = 0                          dlketap_hv25_spw     = 0                          dwketap_hv25_spw     = 0
+dpketap_hv25_spw     = 0
.param
+toxn_hv25_snw = '5.6e-09-3e-010*A4NP_hv25_snw_spw'
+dxln_hv25_snw = '-1e-008*A2N_hv25_snw'                  dxwn_hv25_snw = '-1.2e-008*A3N_hv25_snw'                cjdn_hv25_snw = '0.000141*(1-0.07*A1N_hv25_snw)'
+cjswdn_hv25_snw = '6.64e-10*(1-0.07*A1N_hv25_snw)'      cjswgdn_hv25_snw = '9.14e-10*(1-0.07*A1N_hv25_snw)'     cjsn_hv25_snw = '0.001195*(1-0.07*A1N_hv25_snw)'
+cjswsn_hv25_snw = '1.65e-10*(1-0.07*A1N_hv25_snw)'      cjswgsn_hv25_snw = '2.08e-10*(1-0.07*A1N_hv25_snw)'     cgdon_hv25_snw = '1.75494e-13*(1+0.07*A4NP_hv25_snw_spw)'
+cgdln_hv25_snw = '2.33505e-09*(1+0.07*A4NP_hv25_snw_spw)'   dlcn_hv25_snw = 2.18800e-07                       cgson_hv25_snw = '9.95494e-11*(1+0.07*A4NP_hv25_snw_spw)'
+cgsln_hv25_snw = '2.67995e-10*(1+0.07*A4NP_hv25_snw_spw)'   dvthn_hv25_snw = '0.0075*A1N_hv25_snw'                    dlvthn_hv25_snw = '-1.30e-008*A1N_hv25_snw'
+dwvthn_hv25_snw = '-2.3e-009*A1N_hv25_snw'                 dpvthn_hv25_snw = '-8.0e-015*A1N_hv25_snw'              dcitn_hv25_snw = '-8e-005*A1N_hv25_snw'
+dlcitn_hv25_snw = '-1e-011*A1N_hv25_snw'                dwcitn_hv25_snw = 0                               dpcitn_hv25_snw = 0
+du0n_hv25_snw = '0.00072*A1N_hv25_snw'                   dlu0n_hv25_snw = '3.30e-009*A1N_hv25_snw'                dwu0n_hv25_snw = '-0.18e-009*A1N_hv25_snw'
+dpu0n_hv25_snw = '-0.65e-015*A1N_hv25_snw'               da0n_hv25_snw = '-0.05*A1N_hv25_snw'                    dla0n_hv25_snw = '-1e-008*A1N_hv25_snw'
+dwa0n_hv25_snw = 0                                dpa0n_hv25_snw = 0                                dagsn_hv25_snw = '0.006*A1N_hv25_snw'
+dlagsn_hv25_snw = 0                               dwagsn_hv25_snw = '-1.7e-008*A1N_hv25_snw'              dpagsn_hv25_snw = 0
+dvsatn_hv25_snw = '-17200*A1N_hv25_snw'                 dlvsatn_hv25_snw = 0                              dwvsatn_hv25_snw = '0.0060*A1N_hv25_snw'
+dpvsatn_hv25_snw = 0                              dpclmn_hv25_snw = 0                               dlpclmn_hv25_snw = 0
+dwpclmn_hv25_snw = 0                              dppclmn_hv25_snw = 0                              deta0n_hv25_snw = '0.0000*A1N_hv25_snw'
+dleta0n_hv25_snw = 0                              dweta0n_hv25_snw = 0                              dpeta0n_hv25_snw = 0
+dk2n_hv25_snw = '-0.007*A1N_hv25_snw'                   dlk2n_hv25_snw = '-7e-010*A1N_hv25_snw'                 dwk2n_hv25_snw = 0
+dpk2n_hv25_snw = 0
+cfn_hv25_snw = '9e-11*(1+0.07*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidln_hv25_snw = '8e-009*A1N_hv25_snw'                dlagidln_hv25_snw = 0                             dwagidln_hv25_snw = 0
+dpagidln_hv25_snw = 0                             dpdiblc2n_hv25_snw = 0                            dlpdiblc2n_hv25_snw = 0
+dwpdiblc2n_hv25_snw = 0                           dppdiblc2n_hv25_snw = 0                           dketan_hv25_snw      = 0
+dlketan_hv25_snw     = 0                          dwketan_hv25_snw     = 0                          dpketan_hv25_snw     = 0
+ducn_hv25_snw        = 0                          dlucn_hv25_snw       = 0                          dwucn_hv25_snw       = 0
+dpucn_hv25_snw       = 0                          duc1n_hv25_snw       = 0                          dluc1n_hv25_snw      = 0
+dwuc1n_hv25_snw      = 0                          dpuc1n_hv25_snw      = 0
.lib 'crn65lp_v1d5.l' MOS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' MAC_hv25_snw_spw
.ENDL SS_hv25_snw_spw


***************************     LIBRARY OF FNFP CORNER CASE     ***************************
.LIB FF_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+parn1_hv25_snw_spw=AGAUSS(0,1,1)
+parn2_hv25_snw_spw=AGAUSS(0,1,1)
+parp1_hv25_snw_spw=AGAUSS(0,1,1)
+parp2_hv25_snw_spw=AGAUSS(0,1,1)
+A1N_hv25_snw='-1*sigma_factor_hv25_snw_spw' A1P_hv25_spw='-1*sigma_factor_hv25_snw_spw' A2N_hv25_snw='-1*sigma_factor_hv25_snw_spw' A2P_hv25_spw='-1*sigma_factor_hv25_snw_spw' A3N_hv25_snw='1*sigma_factor_hv25_snw_spw' A3P_hv25_spw='1*sigma_factor_hv25_snw_spw' A4NP_hv25_snw_spw='-1*sigma_factor_hv25_snw_spw'
+toxp_hv25_spw = '5.9e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxlp_hv25_spw = '1e-008*A2P_hv25_spw'                   dxwp_hv25_spw = '1.2e-008*A3P_hv25_spw'                 cjdp_hv25_spw = '0.000575*(1+0.070*A1P_hv25_spw)'
+cjswdp_hv25_spw = '5.21e-10*(1+0.070*A1P_hv25_spw)'     cjswgdp_hv25_spw = '2.39e-10*(1+0.070*A1P_hv25_spw)'    cjsp_hv25_spw = '0.001111*(1+0.070*A1P_hv25_spw)'
+cjswsp_hv25_spw = '9.7e-11*(1+0.070*A1P_hv25_spw)'      cjswgsp_hv25_spw = '1.68e-10*(1+0.070*A1P_hv25_spw)'    cgdop_hv25_spw = '3.00907e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdlp_hv25_spw = '1.5319e-09*(1-0.070*A4NP_hv25_snw_spw)'   dlcp_hv25_spw = 1.63188e-07                       cgsop_hv25_spw = '1.19935e-10*(1-0.070*A4NP_hv25_snw_spw)'
+cgslp_hv25_spw = '2.49822e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthp_hv25_spw = '0.005*A1P_hv25_spw'                   dlvthp_hv25_spw = '-6.5e-009*A1P_hv25_spw'
+dwvthp_hv25_spw = '-3.0e-009*A1P_hv25_spw'                dpvthp_hv25_spw = '-2.7e-015*A1P_hv25_spw'              du0p_hv25_spw = '0.00005*A1P_hv25_spw'
+dlu0p_hv25_spw = '-1.08e-010*A1P_hv25_spw'               dwu0p_hv25_spw = '-0.7e-010*A1P_hv25_spw'               dpu0p_hv25_spw = '2.0e-017*A1P_hv25_spw'
+dnfactorp_hv25_spw = 0                            dlnfactorp_hv25_spw = 0                           dwnfactorp_hv25_spw = 0
+dpnfactorp_hv25_spw = 0                           dvoffp_hv25_spw = 0                               dlvoffp_hv25_spw = 0
+dwvoffp_hv25_spw = 0                              dpvoffp_hv25_spw = 0                              dcitp_hv25_spw = 0
+dlcitp_hv25_spw = 0                               dwcitp_hv25_spw = 0                               dpcitp_hv25_spw = 0
+dvsatp_hv25_spw = 0                               dlvsatp_hv25_spw = 0                              dwvsatp_hv25_spw = '0.0010*A1P_hv25_spw'
+dpvsatp_hv25_spw = 0                              da0p_hv25_spw = 0                                 dla0p_hv25_spw = 0
+dwa0p_hv25_spw = 0                                dpa0p_hv25_spw = '-0.86e-13*A1P_hv25_spw'         dagsp_hv25_spw = '-0.01*A1P_hv25_spw'
+dlagsp_hv25_spw = '4e-008*A1P_hv25_spw'                 dwagsp_hv25_spw = '1.3e-008*A1P_hv25_spw'       dpagsp_hv25_spw = 0
+dpclmp_hv25_spw = 0                               dlpclmp_hv25_spw = '-0.47e-8*A1P_hv25_spw'             dwpclmp_hv25_spw = 0
+dppclmp_hv25_spw = 0                              deta0p_hv25_spw = '0.003*A1P_hv25_spw'                 dleta0p_hv25_spw = 0
+dweta0p_hv25_spw = 0                              dpeta0p_hv25_spw = 0                              dk2p_hv25_spw = 0
+dlk2p_hv25_spw = '7e-010*A1P_hv25_spw'                  dwk2p_hv25_spw = 0                                dpk2p_hv25_spw = 0
+cfp_hv25_spw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidlp_hv25_spw = '-2.7e-007*A1P_hv25_spw'             dlagidlp_hv25_spw = 0                             dwagidlp_hv25_spw = 0
+dpagidlp_hv25_spw = 0
+dketap_hv25_spw      = 0                          dlketap_hv25_spw     = '-8e-10*A1P_hv25_spw'            dwketap_hv25_spw     = 0
+dpketap_hv25_spw     = 0
.param
+toxn_hv25_snw = '5.6e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxln_hv25_snw = '1e-008*A2N_hv25_snw'                   dxwn_hv25_snw = '1.2e-008*A3N_hv25_snw'                 cjdn_hv25_snw = '0.000141*(1+0.070*A1N_hv25_snw)'
+cjswdn_hv25_snw = '6.64e-10*(1+0.070*A1N_hv25_snw)'     cjswgdn_hv25_snw = '9.14e-10*(1+0.070*A1N_hv25_snw)'    cjsn_hv25_snw = '0.001195*(1+0.070*A1N_hv25_snw)'
+cjswsn_hv25_snw = '1.65e-10*(1+0.070*A1N_hv25_snw)'     cjswgsn_hv25_snw = '2.08e-10*(1+0.070*A1N_hv25_snw)'    cgdon_hv25_snw = '1.75494e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdln_hv25_snw = '2.33505e-09*(1-0.070*A4NP_hv25_snw_spw)'  dlcn_hv25_snw = 2.18800e-07                       cgson_hv25_snw = '9.95494e-11*(1-0.070*A4NP_hv25_snw_spw)'
+cgsln_hv25_snw = '2.67995e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthn_hv25_snw = '-0.0065*A1N_hv25_snw'                   dlvthn_hv25_snw = '1.25e-008*A1N_hv25_snw'
+dwvthn_hv25_snw = '25e-010*A1N_hv25_snw'                 dpvthn_hv25_snw = '8.0e-015*A1N_hv25_snw'               dcitn_hv25_snw = '0.0001*A1N_hv25_snw'
+dlcitn_hv25_snw = '3e-011*A1N_hv25_snw'                 dwcitn_hv25_snw = 0                               dpcitn_hv25_snw = 0
+du0n_hv25_snw = '-0.00067*A1N_hv25_snw'                  dlu0n_hv25_snw = '-3.27e-009*A1N_hv25_snw'               dwu0n_hv25_snw = '0.23e-009*A1N_hv25_snw'
+dpu0n_hv25_snw = '0.90e-015*A1N_hv25_snw'               da0n_hv25_snw = '0.05*A1N_hv25_snw'                     dla0n_hv25_snw = '1e-008*A1N_hv25_snw'
+dwa0n_hv25_snw = 0                                dpa0n_hv25_snw = 0                                dagsn_hv25_snw = '0.044*A1N_hv25_snw'
+dlagsn_hv25_snw = '-3.85e-007*A1N_hv25_snw'             dwagsn_hv25_snw = '1.7e-008*A1N_hv25_snw'               dpagsn_hv25_snw = 0
+dvsatn_hv25_snw = '3000*A1N_hv25_snw'                   dlvsatn_hv25_snw = 0                              dwvsatn_hv25_snw = '-0.0024*A1N_hv25_snw'
+dpvsatn_hv25_snw = 0                              dpclmn_hv25_snw = 0                               dlpclmn_hv25_snw = 0
+dwpclmn_hv25_snw = 0                              dppclmn_hv25_snw = 0                              deta0n_hv25_snw = '-0.0002*A1N_hv25_snw'
+dleta0n_hv25_snw = 0                              dweta0n_hv25_snw = 0                              dpeta0n_hv25_snw = 0
+dk2n_hv25_snw = '0.007*A1N_hv25_snw'                    dlk2n_hv25_snw = '7e-010*A1N_hv25_snw'                  dwk2n_hv25_snw = 0
+dpk2n_hv25_snw = 0
+cfn_hv25_snw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidln_hv25_snw = '-4.1e-008*A1N_hv25_snw'             dlagidln_hv25_snw = 0                             dwagidln_hv25_snw = 0
+dpagidln_hv25_snw = 0                             dpdiblc2n_hv25_snw = 0                            dlpdiblc2n_hv25_snw = 0
+dwpdiblc2n_hv25_snw = 0                           dppdiblc2n_hv25_snw = 0                           dketan_hv25_snw      = 0
+dlketan_hv25_snw     = '-4.6e-8*A1N_hv25_snw'           dwketan_hv25_snw     = 0                          dpketan_hv25_snw     = 0
+ducn_hv25_snw        = -0e-11                     dlucn_hv25_snw       = 0                          dwucn_hv25_snw       = 0
+dpucn_hv25_snw       = 0                          duc1n_hv25_snw       = '-2.5e-11*A1N_hv25_snw'          dluc1n_hv25_snw      = '5e-17*A1N_hv25_snw'
+dwuc1n_hv25_snw      = 0                          dpuc1n_hv25_snw      = 0
.lib 'crn65lp_v1d5.l' MOS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' MAC_hv25_snw_spw
.ENDL FF_hv25_snw_spw


***************************     LIBRARY OF SNFP CORNER CASE     ***************************
.LIB SF_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+parn1_hv25_snw_spw=AGAUSS(0,1,1)
+parn2_hv25_snw_spw=AGAUSS(0,1,1)
+parp1_hv25_snw_spw=AGAUSS(0,1,1)
+parp2_hv25_snw_spw=AGAUSS(0,1,1)
+A1N_hv25_snw='0.8*sigma_factor_hv25_snw_spw' A1P_hv25_spw='-0.8*sigma_factor_hv25_snw_spw' A2N_hv25_snw='0*sigma_factor_hv25_snw_spw' A2P_hv25_spw='0*sigma_factor_hv25_snw_spw' A3N_hv25_snw='-1*sigma_factor_hv25_snw_spw' A3P_hv25_spw='1*sigma_factor_hv25_snw_spw' A4NP_hv25_snw_spw='0*sigma_factor_hv25_snw_spw'
+toxp_hv25_spw = '5.9e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxlp_hv25_spw = '1e-008*A2P_hv25_spw'                   dxwp_hv25_spw = '1.2e-008*A3P_hv25_spw'                 cjdp_hv25_spw = '0.000575*(1+0.070*A1P_hv25_spw)'
+cjswdp_hv25_spw = '5.21e-10*(1+0.070*A1P_hv25_spw)'     cjswgdp_hv25_spw = '2.39e-10*(1+0.070*A1P_hv25_spw)'    cjsp_hv25_spw = '0.001111*(1+0.070*A1P_hv25_spw)'
+cjswsp_hv25_spw = '9.7e-11*(1+0.070*A1P_hv25_spw)'      cjswgsp_hv25_spw = '1.68e-10*(1+0.070*A1P_hv25_spw)'    cgdop_hv25_spw = '3.00907e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdlp_hv25_spw = '1.5319e-09*(1-0.070*A4NP_hv25_snw_spw)'   dlcp_hv25_spw = 1.63188e-07                       cgsop_hv25_spw = '1.19935e-10*(1-0.070*A4NP_hv25_snw_spw)'
+cgslp_hv25_spw = '2.49822e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthp_hv25_spw = '-0.033*A1P_hv25_spw'                  dlvthp_hv25_spw = '-6.6e-09*A1P_hv25_spw'
+dwvthp_hv25_spw = '-2e-009*A1P_hv25_spw'                dpvthp_hv25_spw = '-3.3e-015*A1P_hv25_spw'              du0p_hv25_spw = '-0.000130*A1P_hv25_spw'
+dlu0p_hv25_spw = '-1.28e-010*A1P_hv25_spw'               dwu0p_hv25_spw = '-0.7e-010*A1P_hv25_spw'               dpu0p_hv25_spw = '-8.7e-017*A1P_hv25_spw'
+dnfactorp_hv25_spw = 0                            dlnfactorp_hv25_spw = 0                           dwnfactorp_hv25_spw = 0
+dpnfactorp_hv25_spw = 0                           dvoffp_hv25_spw = 0                               dlvoffp_hv25_spw = 0
+dwvoffp_hv25_spw = 0                              dpvoffp_hv25_spw = 0                              dcitp_hv25_spw = 0
+dlcitp_hv25_spw = 0                               dwcitp_hv25_spw = 0                               dpcitp_hv25_spw = 0
+dvsatp_hv25_spw = 0                               dlvsatp_hv25_spw = 0                              dwvsatp_hv25_spw = '0.001*A1P_hv25_spw'
+dpvsatp_hv25_spw = 0                              da0p_hv25_spw = 0                                 dla0p_hv25_spw = 0
+dwa0p_hv25_spw = 0                                dpa0p_hv25_spw = '-0.86e-13*A1P_hv25_spw'         dagsp_hv25_spw = '-0.02*A1P_hv25_spw'
+dlagsp_hv25_spw = '4e-008*A1P_hv25_spw'                 dwagsp_hv25_spw = '1.4e-008*A1P_hv25_spw'              dpagsp_hv25_spw = 0
+dpclmp_hv25_spw = 0                               dlpclmp_hv25_spw = '-0.50e-8*A1P_hv25_spw'                    dwpclmp_hv25_spw = 0
+dppclmp_hv25_spw = 0                              deta0p_hv25_spw = '0.003*A1P_hv25_spw'                 dleta0p_hv25_spw = 0
+dweta0p_hv25_spw = 0                              dpeta0p_hv25_spw = 0                              dk2p_hv25_spw = 0
+dlk2p_hv25_spw = '7e-010*A1P_hv25_spw'                  dwk2p_hv25_spw = 0                                dpk2p_hv25_spw = 0
+cfp_hv25_spw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidlp_hv25_spw = '-2.7e-007*A1P_hv25_spw'             dlagidlp_hv25_spw = 0                             dwagidlp_hv25_spw = 0
+dpagidlp_hv25_spw = 0
+dketap_hv25_spw      = 0                          dlketap_hv25_spw     = 0                          dwketap_hv25_spw     = 0
+dpketap_hv25_spw     = 0
.param
+toxn_hv25_snw = '5.6e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxln_hv25_snw = '1e-008*A2N_hv25_snw'                   dxwn_hv25_snw = '1.2e-008*A3N_hv25_snw'                 cjdn_hv25_snw = '0.000141*(1+0.070*A1N_hv25_snw)'
+cjswdn_hv25_snw = '6.64e-10*(1+0.070*A1N_hv25_snw)'     cjswgdn_hv25_snw = '9.14e-10*(1+0.070*A1N_hv25_snw)'    cjsn_hv25_snw = '0.001195*(1+0.070*A1N_hv25_snw)'
+cjswsn_hv25_snw = '1.65e-10*(1+0.070*A1N_hv25_snw)'     cjswgsn_hv25_snw = '2.08e-10*(1+0.070*A1N_hv25_snw)'    cgdon_hv25_snw = '1.75494e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdln_hv25_snw = '2.33505e-09*(1-0.070*A4NP_hv25_snw_spw)'  dlcn_hv25_snw = 2.18800e-07                       cgson_hv25_snw = '9.95494e-11*(1-0.070*A4NP_hv25_snw_spw)'
+cgsln_hv25_snw = '2.67995e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthn_hv25_snw = '0.032*A1N_hv25_snw'                   dlvthn_hv25_snw = '1.7e-08*A1N_hv25_snw'
+dwvthn_hv25_snw = '25e-010*A1N_hv25_snw'                 dpvthn_hv25_snw = '8.9e-015*A1N_hv25_snw'               dcitn_hv25_snw = '0.0001*A1N_hv25_snw'
+dlcitn_hv25_snw = '3e-011*A1N_hv25_snw'                 dwcitn_hv25_snw = 0                               dpcitn_hv25_snw = 0
+du0n_hv25_snw = '-0.0003*A1N_hv25_snw'                  dlu0n_hv25_snw = '-3.4e-009*A1N_hv25_snw'               dwu0n_hv25_snw = '0.23e-009*A1N_hv25_snw'
+dpu0n_hv25_snw = '0.80e-15*A1N_hv25_snw'                da0n_hv25_snw = '0.05*A1N_hv25_snw'                     dla0n_hv25_snw = '1e-008*A1N_hv25_snw'
+dwa0n_hv25_snw = 0                                dpa0n_hv25_snw = 0                                dagsn_hv25_snw = '0.033*A1N_hv25_snw'
+dlagsn_hv25_snw = '-3.1e-07*A1N_hv25_snw'               dwagsn_hv25_snw = '0.7e-008*A1N_hv25_snw'               dpagsn_hv25_snw = 0
+dvsatn_hv25_snw = '3000*A1N_hv25_snw'                   dlvsatn_hv25_snw = 0                              dwvsatn_hv25_snw = '-0.0025*A1N_hv25_snw'
+dpvsatn_hv25_snw = 0                              dpclmn_hv25_snw = 0                               dlpclmn_hv25_snw = 0
+dwpclmn_hv25_snw = 0                              dppclmn_hv25_snw = 0                              deta0n_hv25_snw = '-0.0000*A1N_hv25_snw'
+dleta0n_hv25_snw = 0                              dweta0n_hv25_snw = 0                              dpeta0n_hv25_snw = 0
+dk2n_hv25_snw = '0.007*A1N_hv25_snw'                    dlk2n_hv25_snw = '7e-010*A1N_hv25_snw'                  dwk2n_hv25_snw = 0
+dpk2n_hv25_snw = 0
+cfn_hv25_snw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidln_hv25_snw = '-8.0e-09*A1N_hv25_snw'              dlagidln_hv25_snw = 0                             dwagidln_hv25_snw = 0
+dpagidln_hv25_snw = 0                             dpdiblc2n_hv25_snw = 0                            dlpdiblc2n_hv25_snw = 0
+dwpdiblc2n_hv25_snw = 0                           dppdiblc2n_hv25_snw = 0                           dketan_hv25_snw      = 0
+dlketan_hv25_snw     = 0                          dwketan_hv25_snw     = 0                          dpketan_hv25_snw     = 0
+ducn_hv25_snw        = 0                          dlucn_hv25_snw       = 0                          dwucn_hv25_snw       = 0
+dpucn_hv25_snw       = 0                          duc1n_hv25_snw       = 0                          dluc1n_hv25_snw      = 0
+dwuc1n_hv25_snw      = 0                          dpuc1n_hv25_snw      = 0
.lib 'crn65lp_v1d5.l' MOS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' MAC_hv25_snw_spw
.ENDL SF_hv25_snw_spw


***************************     LIBRARY OF FNSP CORNER CASE     ***************************
.LIB FS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' post_simu_hv25_snw_spw
.param
+parn1_hv25_snw_spw=AGAUSS(0,1,1)
+parn2_hv25_snw_spw=AGAUSS(0,1,1)
+parp1_hv25_snw_spw=AGAUSS(0,1,1)
+parp2_hv25_snw_spw=AGAUSS(0,1,1)
+A1N_hv25_snw='-0.8*sigma_factor_hv25_snw_spw' A1P_hv25_spw='0.8*sigma_factor_hv25_snw_spw' A2N_hv25_snw='0*sigma_factor_hv25_snw_spw' A2P_hv25_spw='0*sigma_factor_hv25_snw_spw' A3N_hv25_snw='1*sigma_factor_hv25_snw_spw' A3P_hv25_spw='-1*sigma_factor_hv25_snw_spw' A4NP_hv25_snw_spw='0*sigma_factor_hv25_snw_spw'
+toxp_hv25_spw = '5.9e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxlp_hv25_spw = '1e-008*A2P_hv25_spw'                   dxwp_hv25_spw = '1.2e-008*A3P_hv25_spw'                 cjdp_hv25_spw = '0.000575*(1+0.070*A1P_hv25_spw)'
+cjswdp_hv25_spw = '5.21e-10*(1+0.070*A1P_hv25_spw)'     cjswgdp_hv25_spw = '2.39e-10*(1+0.070*A1P_hv25_spw)'    cjsp_hv25_spw = '0.001111*(1+0.070*A1P_hv25_spw)'
+cjswsp_hv25_spw = '9.7e-11*(1+0.070*A1P_hv25_spw)'      cjswgsp_hv25_spw = '1.68e-10*(1+0.070*A1P_hv25_spw)'    cgdop_hv25_spw = '3.00907e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdlp_hv25_spw = '1.5319e-09*(1-0.070*A4NP_hv25_snw_spw)'   dlcp_hv25_spw = 1.63188e-07                       cgsop_hv25_spw = '1.19935e-10*(1-0.070*A4NP_hv25_snw_spw)'
+cgslp_hv25_spw = '2.49822e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthp_hv25_spw = '-0.033*A1P_hv25_spw'                  dlvthp_hv25_spw = '-6.6e-09*A1P_hv25_spw'
+dwvthp_hv25_spw = '-2e-009*A1P_hv25_spw'                dpvthp_hv25_spw = '-3.3e-015*A1P_hv25_spw'              du0p_hv25_spw = '-0.000120*A1P_hv25_spw'
+dlu0p_hv25_spw = '-1.28e-010*A1P_hv25_spw'               dwu0p_hv25_spw = '-0.7e-010*A1P_hv25_spw'               dpu0p_hv25_spw = '-8.7e-017*A1P_hv25_spw'
+dnfactorp_hv25_spw = 0                            dlnfactorp_hv25_spw = 0                           dwnfactorp_hv25_spw = 0
+dpnfactorp_hv25_spw = 0                           dvoffp_hv25_spw = 0                               dlvoffp_hv25_spw = 0
+dwvoffp_hv25_spw = 0                              dpvoffp_hv25_spw = 0                              dcitp_hv25_spw = 0
+dlcitp_hv25_spw = 0                               dwcitp_hv25_spw = 0                               dpcitp_hv25_spw = 0
+dvsatp_hv25_spw = 0                               dlvsatp_hv25_spw = 0                              dwvsatp_hv25_spw = '0.005*A1P_hv25_spw'
+dpvsatp_hv25_spw = 0                              da0p_hv25_spw = 0                                 dla0p_hv25_spw = 0
+dwa0p_hv25_spw = 0                                dpa0p_hv25_spw = 0                                dagsp_hv25_spw = '-0.02*A1P_hv25_spw'
+dlagsp_hv25_spw = 0                               dwagsp_hv25_spw = '1.4e-008*A1P_hv25_spw'              dpagsp_hv25_spw = 0
+dpclmp_hv25_spw = 0                               dlpclmp_hv25_spw = '-0.50e-8*A1P_hv25_spw'              dwpclmp_hv25_spw = 0
+dppclmp_hv25_spw = 0                              deta0p_hv25_spw = '0.003*A1P_hv25_spw'                 dleta0p_hv25_spw = 0
+dweta0p_hv25_spw = 0                              dpeta0p_hv25_spw = 0                              dk2p_hv25_spw = 0
+dlk2p_hv25_spw = '7e-010*A1P_hv25_spw'                  dwk2p_hv25_spw = 0                                dpk2p_hv25_spw = 0
+cfp_hv25_spw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidlp_hv25_spw = '-5.7e-08*A1P_hv25_spw'              dlagidlp_hv25_spw = 0                             dwagidlp_hv25_spw = 0
+dpagidlp_hv25_spw = 0
+dketap_hv25_spw      = 0                          dlketap_hv25_spw     = 0                          dwketap_hv25_spw     = 0
+dpketap_hv25_spw     = 0
.param
+toxn_hv25_snw = '5.6e-09+3.0000e-010*A4NP_hv25_snw_spw'
+dxln_hv25_snw = '1e-008*A2N_hv25_snw'                   dxwn_hv25_snw = '1.2e-008*A3N_hv25_snw'                 cjdn_hv25_snw = '0.000141*(1+0.070*A1N_hv25_snw)'
+cjswdn_hv25_snw = '6.64e-10*(1+0.070*A1N_hv25_snw)'     cjswgdn_hv25_snw = '9.14e-10*(1+0.070*A1N_hv25_snw)'    cjsn_hv25_snw = '0.001195*(1+0.070*A1N_hv25_snw)'
+cjswsn_hv25_snw = '1.65e-10*(1+0.070*A1N_hv25_snw)'     cjswgsn_hv25_snw = '2.08e-10*(1+0.070*A1N_hv25_snw)'    cgdon_hv25_snw = '1.75494e-13*(1-0.070*A4NP_hv25_snw_spw)'
+cgdln_hv25_snw = '2.33505e-09*(1-0.070*A4NP_hv25_snw_spw)'  dlcn_hv25_snw = 2.18800e-07                       cgson_hv25_snw = '9.95494e-11*(1-0.070*A4NP_hv25_snw_spw)'
+cgsln_hv25_snw = '2.67995e-10*(1-0.070*A4NP_hv25_snw_spw)'  dvthn_hv25_snw = '0.032*A1N_hv25_snw'                   dlvthn_hv25_snw = '1.8e-08*A1N_hv25_snw'
+dwvthn_hv25_snw = '25e-010*A1N_hv25_snw'                 dpvthn_hv25_snw = '8.9e-015*A1N_hv25_snw'               dcitn_hv25_snw = '0.0001*A1N_hv25_snw'
+dlcitn_hv25_snw = '3e-011*A1N_hv25_snw'                 dwcitn_hv25_snw = 0                               dpcitn_hv25_snw = 0
+du0n_hv25_snw = '-0.0003*A1N_hv25_snw'                  dlu0n_hv25_snw = '-3.4e-009*A1N_hv25_snw'               dwu0n_hv25_snw = '0.23e-009*A1N_hv25_snw'
+dpu0n_hv25_snw = '1.00e-15*A1N_hv25_snw'                da0n_hv25_snw = '0.05*A1N_hv25_snw'                     dla0n_hv25_snw = '1e-008*A1N_hv25_snw'
+dwa0n_hv25_snw = 0                                dpa0n_hv25_snw = 0                                dagsn_hv25_snw = '0.033*A1N_hv25_snw'
+dlagsn_hv25_snw = '-3.0e-07*A1N_hv25_snw'               dwagsn_hv25_snw = '0.7e-008*A1N_hv25_snw'               dpagsn_hv25_snw = 0
+dvsatn_hv25_snw = '3000*A1N_hv25_snw'                   dlvsatn_hv25_snw = 0                              dwvsatn_hv25_snw = '-0.0025*A1N_hv25_snw'
+dpvsatn_hv25_snw = 0                              dpclmn_hv25_snw = 0                               dlpclmn_hv25_snw = 0
+dwpclmn_hv25_snw = 0                              dppclmn_hv25_snw = 0                              deta0n_hv25_snw = '-0.0002*A1N_hv25_snw'
+dleta0n_hv25_snw = 0                              dweta0n_hv25_snw = 0                              dpeta0n_hv25_snw = 0
+dk2n_hv25_snw = '0.007*A1N_hv25_snw'                    dlk2n_hv25_snw = '7e-010*A1N_hv25_snw'                  dwk2n_hv25_snw = 0
+dpk2n_hv25_snw = 0
+cfn_hv25_snw = '9e-11*(1-0.070*A4NP_hv25_snw_spw)+2.4e-11*ccoflag_hv25_snw_spw'
+dagidln_hv25_snw = '-4.1e-008*A1N_hv25_snw'             dlagidln_hv25_snw = 0                             dwagidln_hv25_snw = 0
+dpagidln_hv25_snw = 0                             dpdiblc2n_hv25_snw = 0                            dlpdiblc2n_hv25_snw = 0
+dwpdiblc2n_hv25_snw = 0                           dppdiblc2n_hv25_snw = 0                           dketan_hv25_snw      = 0
+dlketan_hv25_snw     = '-3.125e-8*A1N_hv25_snw'         dwketan_hv25_snw     = 0                          dpketan_hv25_snw     = 0
+ducn_hv25_snw        = 0                          dlucn_hv25_snw       = 0                          dwucn_hv25_snw       = 0
+dpucn_hv25_snw       = 0                          duc1n_hv25_snw       = '-2.75e-11*A1N_hv25_snw'         dluc1n_hv25_snw      = '2.5e-17*A1N_hv25_snw'
+dwuc1n_hv25_snw      = 0                          dpuc1n_hv25_snw      = 0
.lib 'crn65lp_v1d5.l' MOS_hv25_snw_spw
.lib 'crn65lp_v1d5.l' MAC_hv25_snw_spw
.ENDL FS_hv25_snw_spw



.LIB MAC
**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.25e-008' xw='+2.0e-08+dxwn'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1  temp2=parn2
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='l*scale-1e-09'
+       wef='w/nf*scale+2.0e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisn='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisn='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisn='0.00216908*geo_fac*toxn*fac2*mismatchflag' 
.param tnoiax='2.084e05/(l*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(l*scale*1e6)+0.4837'

.param fn_dice='noiseflagn_mc*par1fn_mc+noiseflagn_mc_mis*par2fn_mc'
.param arearatio='sigma_factor_flicker*(log(3.873)-min(0,0.555*log(((w*scale*l*scale*multi)/(12.7E-6*1E-6*1))**0.5)))'
.param noianmac='c1fn*2.718**((fn_dice+(1-fn_dice)*noiseflagn)*arearatio)'
.param noibnmac='c2fn*2.718**((fn_dice+(1-fn_dice)*noiseflagn)*arearatio)'
.param noicnmac='c3fn*2.718**((fn_dice+(1-fn_dice)*noiseflagn)*arearatio)'

.MODEL nch.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln+dlmisn)'
+LMAX       = 2.00001e-05         WMIN       = '1e-005-(dxwn+dwmisn)'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3971583+(dvthn+vthmisn)'   K1         = 0.31994
+K2         = '0.022565+dk2n'     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 0.001               VOFF       = -0.1282             NFACTOR    = '0.75+dnfactorn'
+ETA0       = '0.10102+deta0n'    ETAB       = -0.08565            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'      UA         = -1.683e-009
+UB         = 2.412312e-018       UC         = 1.289e-010          VSAT       = '110000+dvsatn'
+A0         = 2.203               AGS        = 0.8591              A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05109            DWG        = 0                   DWB        = 0
+PCLM       = 0.2722              PDIBLC1    = 0                   PDIBLC2    = '0.002415+dpdiblc2n'
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.001375            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2154432
+KT1L       = 0                   KT2        = -0.07264            UTE        = -1.379
+UA1        = 1.6e-009            UB1        = -1.44628e-018       UC1        = 3.03e-013
+PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'      LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln+dlmisn)'
+LMAX       = '1e-005-(dxln+dlmisn)'       WMIN       = '1e-005-(dxwn+dwmisn)'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39304444+(dvthn+vthmisn)'  LVTH0      = '4.099508e-008+dlvthn'
+K1         = 0.31994             K2         = '0.023370867+dk2n'  LK2        = -8.0305518e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00098244461
+LCIT       = '1.7494141e-010+dlcitn'
+VOFF       = -0.1255394          LVOFF      = '-2.65132e-008+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10102+deta0n'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'
+UA         = -1.7047351e-009     LUA        = 2.1659301e-016      UB         = 2.4380817e-018
+LUB        = -2.5679813e-025     UC         = 1.3000452e-010      LUC        = -1.1006611e-017
+VSAT       = '110000+dvsatn'     A0         = 2.2653681           LA0        = '-6.2150487e-007+dla0n'
+AGS        = 0.81477464          LAGS       = 4.4170706e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04934744         LKETA      = -1.7364799e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0025667367+dpdiblc2n'
+LPDIBLC2   = -1.5120733e-009     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0013986988
+LTVOFF     = -2.3616127e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21318399         LKT1       = -2.2513329e-008     KT1L       = 0
+KT2        = -0.071975146        LKT2       = -6.6253388e-009     UTE        = -1.3590544
+LUTE       = -1.9876016e-007     UA1        = 1.662196e-009       LUA1       = -6.1978976e-016
+UB1        = -1.4469534e-018     LUB1       = 6.7108271e-027      UC1        = -3.5356714e-012
+LUC1       = 3.8252783e-017      PRT        = 0                   AT         = 201072.34
+LAT        = -0.01068603
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln+dlmisn)'
+LMAX       = '1.000002e-006-(dxln+dlmisn)'
+WMIN       = '1e-005-(dxwn+dwmisn)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43676534+(dvthn+vthmisn)'  LVTH0      = '-1.2003913e-009+dlvthn'
+K1         = 0.31994             K2         = '0.021314478+dk2n'  LK2        = -6.0459107e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010868883
+LCIT       = '7.4141765e-011+dlcitn'
+VOFF       = -0.15239595         LVOFF      = '-5.9367112e-010+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10102+deta0n'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'
+UA         = -1.5453265e-009     LUA        = 6.2746135e-017      UB         = 2.269578e-018
+LUB        = -9.4173528e-026     UC         = 1.2925162e-010      LUC        = -1.0279988e-017
+VSAT       = '113946.42+dvsatn'  LVSAT      = '-0.0038087297+dlvsatn'
+A0         = 2.2094596           LA0        = '-5.6754699e-007+dla0n'
+AGS        = 0.42887173          LAGS       = 8.1414582e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073052413        LKETA      = 5.5131064e-009      DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0012164964+dpdiblc2n'
+LPDIBLC2   = -2.0894285e-010     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012118355
+LTVOFF     = -5.5817591e-011     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.22714346         LKT1       = -9.0408975e-009     KT1L       = 0
+KT2        = -0.075960598        LKT2       = -2.7789399e-009     UTE        = -1.5971652
+LUTE       = 3.1042938e-008      UA1        = 1.1007222e-009      LUA1       = -7.7905835e-017
+UB1        = -1.5451554e-018     LUB1       = 1.0148653e-025      UC1        = 1.2934884e-011
+LUC1       = 2.2356885e-017      PRT        = 0                   AT         = 234845.69
+LAT        = -0.043281019
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln+dlmisn)'
+LMAX       = '2.399959e-007-(dxln+dlmisn)'
+WMIN       = '1e-005-(dxwn+dwmisn)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44301989+(dvthn+vthmisn)'  LVTH0      = '-2.6263045e-009+dlvthn'
+K1         = 0.31994             K2         = '0.0060518885+dk2n' LK2        = -2.5663454e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00089174876
+LCIT       = '1.1862968e-010+dlcitn'
+VOFF       = -0.13778537         LVOFF      = '-3.9245908e-009+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.1010175+deta0n'  LETA0      = '5.6985851e-013+dleta0n'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021399889+du0n'  LU0        = '4.7901151e-011+dlu0n'
+UA         = -1.318498e-009      LUA        = 1.1033782e-017      UB         = 1.9551074e-018
+LUB        = -2.2480505e-026     UC         = 8.770291e-011       LUC        = -8.077125e-019
+VSAT       = '101196.2+dvsatn'   LVSAT      = '-0.0009019344+dlvsatn'
+A0         = 0.76497717          LA0        = '-2.3823389e-007+dla0n'
+AGS        = 3.2754786           LAGS       = 1.6517638e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073974665        LKETA      = 5.7233616e-009      DWG        = 0
+DWB        = 0                   PCLM       = -0.03535932         LPCLM      = 7.0117374e-008
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020716496+dpdiblc2n'
+LPDIBLC2   = 1.1562347e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00087063866
+LTVOFF     = 2.1968459e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.25962724         LKT1       = -1.6352462e-009     KT1L       = 0
+KT2        = -0.10603119         LKT2       = 4.0765531e-009      UTE        = -1.5964855
+LUTE       = 3.0887983e-008      UA1        = 8.2927857e-010      LUA1       = -1.6022109e-017
+UB1        = -1.389084e-018      LUB1       = 6.5905376e-026      UC1        = 1.2396893e-010
+LUC1       = -2.9566572e-018     PRT        = 0                   AT         = 54781.038
+LAT        = -0.0022298811
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+WETA0      = '0+dweta0n'         PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln+dlmisn)'
+WMIN       = '1e-005-(dxwn+dwmisn)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41002329+(dvthn+vthmisn)'  LVTH0      = '5.3414286e-010+dlvthn'
+K1         = 0.31994             K2         = '-0.00024866313+dk2n'
+LK2        = -1.9628723e-009     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = -6.5754395e-005     LCIT       = '2.1034029e-010+dlcitn'
+VOFF       = -0.13659885         LVOFF      = '-4.0382368e-009+dlvoffn'
+NFACTOR    = '0.75+dnfactorn-0.320672*ss_flag+0.320672*ff_flag'
+ETA0       = '0.00050744458+deta0n'
+LETA0      = '9.6275235e-009+dleta0n'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021162477+du0n'  LU0        = '7.0640674e-011+dlu0n'
+UA         = -1.3961783e-009     LUA        = 1.8474072e-017      UB         = 1.7190372e-018
+LUB        = 1.3053168e-028      UC         = 1.2291211e-010      LUC        = -4.1800851e-018
+VSAT       = '85039.349+dvsatn+962.017*ff_flag'
+LVSAT      = '0.00064558489+dlvsatn-9.21423e-05*ff_flag'
+A0         = 1.4250678           LA0        = '-3.0145803e-007+dla0n'
+AGS        = 3.3966895           LAGS       = 1.5356668e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.13066844         LKETA      = 1.1153548e-008      DWG        = 0
+DWB        = 0                   PCLM       = 0.69140908          LPCLM      = 5.0677006e-010
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn'         RDW        = '65+drdswn'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon'              CGDO       = 'cgon'
+CGBO       = 0                   CGDL       = 'cgln'              CGSL       = 'cgln'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011288596        LTVOFF     = -2.7642003e-012     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.28118927         LKT1       = 4.2998671e-010
+KT1L       = 0                   KT2        = -0.095343813        LKT2       = 3.0529057e-009
+UTE        = -1.7133071          LUTE       = 4.2077271e-008      UA1        = -1.2041553e-010
+LUA1       = 7.4940541e-017      UB1        = 2.8533105e-021      LUB1       = -6.7415774e-026
+UC1        = 1.5113984e-010      LUC1       = -5.5591139e-018     PRT        = 0
+AT         = 31500
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+WETA0      = '0+dweta0n'         PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn+0.0*ff_flag'
+WVSAT      = '0+dwvsatn+0.0*ff_flag'
+LNFACTOR   = '0+dlnfactorn+3.07141e-08*ss_flag-3.07141e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn+0.0*ss_flag+0.0*ff_flag'
+PNFACTOR   = '0+dpnfactorn+0.0*ss_flag+0.0*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln+dlmisn)'
+LMAX       = 2.00001e-05         WMIN       = '1e-006-(dxwn+dwmisn)'       WMAX       = '1e-005-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39547494+(dvthn+vthmisn)'  WVTH0      = '1.6867314e-008+dwvthn'
+K1         = 0.31994             K2         = '0.022969033+dk2n'  WK2        = -4.048414e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010453333
+WCIT       = '-4.5424e-010+dwcitn'
+VOFF       = -0.12669799         WVOFF      = '-1.5050107e-008+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'      UA         = -1.7121267e-009
+WUA        = 2.918492e-016       UB         = 2.4287286e-018      WUB        = -1.6449393e-025
+UC         = 1.3399547e-010      WUC        = -5.1056576e-017     VSAT       = '110000+dvsatn'
+A0         = 2.1942733           WA0        = 8.74412e-008        AGS        = 0.85684215
+WAGS       = 2.262365e-008       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.052544067
+WKETA      = 1.4569748e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.265162            WPCLM      = 7.052076e-008       PDIBLC1    = 0
+PDIBLC2    = '0.0024053667+dpdiblc2n'
+WPDIBLC2   = 9.6526e-011         PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00136514
+LTVOFF     = 0                   WTVOFF     = 9.87972e-011        PTVOFF     = 0
+KT1        = -0.21658778         WKT1       = 1.1468652e-008      KT1L       = 0
+KT2        = -0.0729256          WKT2       = 2.861712e-009       UTE        = -1.3799067
+WUTE       = 9.0848e-009         UA1        = 1.6328667e-009      WUA1       = -3.29324e-016
+UB1        = -1.4643317e-018     WUB1       = 1.8087837e-025      UC1        = -3.5953267e-012
+WUC1       = 3.9061233e-017      PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+LETA0      = '0+dleta0n'         PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'      LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln+dlmisn)'
+LMAX       = '1e-005-(dxln+dlmisn)'       WMIN       = '1e-006-(dxwn+dwmisn)'       WMAX       = '1e-005-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3912083+(dvthn+vthmisn)'   LVTH0      = '4.2517486e-008+dlvthn'
+WVTH0      = '1.8398106e-008+dwvthn'
+PVTH0      = '-1.5254509e-014+dpvthn'
+K1         = 0.31994             K2         = '0.023700073+dk2n'  LK2        = -7.2848877e-009
+WK2        = -3.2986427e-009     PK2        = -7.471554e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0010309425        LCIT       = '1.4340605e-010+dlcitn'
+WCIT       = '-4.8594906e-010+dwcitn'
+PCIT       = 3.1598426e-016      VOFF       = -0.12386568         LVOFF      = '-2.8224355e-008+dlvoffn'
+WVOFF      = '-1.6770688e-008+dwvoffn'
+PVOFF      = '1.7145779e-014+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021608056+du0n'  LU0        = '1.9377335e-011+dlu0n'
+WU0        = '1.948407e-011+dwu0n'
+PU0        = '-1.941609e-016+dpu0n'
+UA         = -1.7350077e-009     LUA        = 2.2801148e-016      WUA        = 3.0333057e-016
+PUA        = -1.1441307e-022     UB         = 2.4549474e-018      LUB        = -2.6127333e-025
+WUB        = -1.6899378e-025     PUB        = 4.4841459e-032      UC         = 1.3493348e-010
+LUC        = -9.347427e-018      WUC        = -4.9388253e-017     PUC        = -1.6625027e-023
+VSAT       = '110000+dvsatn'
+A0         = '2.2627307+0.0048613*ff_flag-0.00364597*ss_flag'
+LA0        = '-6.8218549e-007+dla0n-4.84434e-08*ff_flag+3.63325e-08*ss_flag'
+WA0        = '2.6426333e-008-4.87102e-08*ff_flag+3.65326e-08*ss_flag'
+PA0        = '6.0801986e-013+4.85402e-13*ff_flag-3.64052e-13*ss_flag'
+AGS        = 0.81261905
+LAGS       = 4.4068808e-007      WAGS       = 2.1599056e-008      PAGS       = 1.0210194e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050703795        LKETA      = -1.833851e-008
+WKETA      = 1.3590674e-008      PKETA      = 9.7565851e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0025925301+dpdiblc2n'
+LPDIBLC2   = -1.8651041e-009     WPDIBLC2   = -2.5844939e-010     PPDIBLC2   = 3.5373688e-015
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013867485        LTVOFF     = -2.1533064e-010
+WTVOFF     = 1.1974258e-010      PTVOFF     = -2.0872296e-016     KT1        = -0.21442694
+LKT1       = -2.1532981e-008     WKT1       = 1.2454399e-008      PKT1       = -9.8230852e-015
+KT1L       = 0                   KT2        = -0.072099838        LKT2       = -8.2288133e-009
+WKT2       = 1.2494052e-009      PKT2       = 1.6066814e-014      UTE        = -1.3572144
+LUTE       = -2.2613065e-007     WUTE       = -1.8436448e-008     PUTE       = 2.7425227e-013
+UA1        = 1.7006531e-009      LUA1       = -6.754996e-016      WUA1       = -3.853407e-016
+PUA1       = 5.5821258e-022      UB1        = -1.4668194e-018     LUB1       = 2.4789881e-026
+WUB1       = 1.9905701e-025      PUB1       = -1.8115212e-031     UC1        = -7.765745e-012
+LUC1       = 4.1558677e-017      WUC1       = 4.2385337e-017      PUC1       = -3.3125063e-023
+PRT        = 0                   AT         = 201084.5            LAT        = -0.010807139
+WAT        = -0.00012177544      PAT        = 1.2135056e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln+dlmisn)'
+LMAX       = '1.000002e-006-(dxln+dlmisn)'
+WMIN       = '1e-006-(dxwn+dwmisn)'       WMAX       = '1e-005-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43644065+(dvthn+vthmisn)'  LVTH0      = '-1.136705e-009+dlvthn'
+WVTH0      = '3.253333e-009+dwvthn'
+PVTH0      = '-6.3813721e-016+dpvthn'
+K1         = 0.31994             K2         = '0.022589005+dk2n'  LK2        = -6.2125854e-009
+WK2        = -1.2770759e-008     PK2        = 1.6700806e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.001096553         LCIT       = '8.0084763e-011+dlcitn'
+WCIT       = '-9.6839942e-011+dwcitn'
+PCIT       = -5.9548836e-017     VOFF       = -0.15284142         LVOFF      = '-2.5957307e-010+dlvoffn'
+WVOFF      = '4.4636181e-009+dwvoffn'
+PVOFF      = '-3.3476624e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021606051+du0n'  LU0        = '2.1312171e-011+dlu0n'
+WU0        = '3.9571993e-011+dwu0n'
+PU0        = '-2.1354795e-016+dpu0n'
+UA         = -1.5657172e-009     LUA        = 6.4627591e-017      WUA        = 2.0431503e-016
+PUA        = -1.8852183e-023     UB         = 2.2803345e-018      LUB        = -9.2752717e-026
+WUB        = -1.0778004e-025     PUB        = -1.423653e-032      UC         = 1.3678552e-010
+LUC        = -1.1134843e-017     WUC        = -7.5489601e-017     PUC        = 8.5656457e-024
+VSAT       = '114148.32+dvsatn+35.0518*ff_flag-56.0828*ss_flag'
+LVSAT      = '-0.0040035838+dlvsatn-3.38288e-05*ff_flag+5.41261e-05*ss_flag'
+WVSAT      = '-0.0020230217+dwvsatn-0.000351219*ff_flag+0.00056195*ss_flag'
+PVSAT      = '1.9524384e-009+dpvsatn+3.38965e-10*ff_flag-5.42344e-10*ss_flag'
+A0         = '2.1280013-0.0488385*ff_flag+0.0445155*ss_flag'
+LA0        = '-5.5215676e-007+dla0n+3.38286e-09*ff_flag-1.01486e-08*ss_flag'
+WA0        = '8.1621195e-007+4.89361e-07*ff_flag-4.46046e-07*ss_flag'
+PA0        = '-1.5421014e-013-3.38966e-14*ff_flag+1.01689e-13*ss_flag'
+AGS        = 0.42466709
+LAGS       = 8.151044e-007       WAGS       = 4.2130504e-008      PAGS       = -9.6049124e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.076145004        LKETA      = 6.2150549e-009
+WKETA      = 3.0987767e-008      PKETA      = -7.0335238e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00079587727+dpdiblc2n'
+LPDIBLC2   = -1.3113651e-010     WPDIBLC2   = 4.2146038e-009      PPDIBLC2   = -7.7961951e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0012284441        LTVOFF     = -6.254953e-011
+WTVOFF     = -1.6641859e-010     PTVOFF     = 6.7454036e-017      KT1        = -0.22675482
+LKT1       = -9.6352162e-009     WKT1       = -3.8941599e-009     PKT1       = 5.9550728e-015
+KT1L       = 0                   KT2        = -0.07738044         LKT2       = -3.1324513e-009
+WKT2       = 1.4226817e-008      PKT2       = 3.5421843e-015      UTE        = -1.6184239
+LUTE       = 2.5965229e-008      WUTE       = 2.1301242e-007      PUTE       = 5.0878647e-014
+UA1        = 1.0856968e-009      LUA1       = -8.1999125e-017     WUA1       = 1.505545e-016
+PUA1       = 4.1014766e-023      UB1        = -1.5438351e-018     LUB1       = 9.9118509e-026
+WUB1       = -1.3229333e-026     PUB1       = 2.372755e-032       UC1        = 1.0815775e-011
+LUC1       = 2.3625467e-017      WUC1       = 2.1233474e-017      PUC1       = -1.2711188e-023
+PRT        = 0                   AT         = 235012.77           LAT        = -0.04355165
+WAT        = -0.0016741523       PAT        = 2.71172e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln+dlmisn)'
+LMAX       = '2.399959e-007-(dxln+dlmisn)'
+WMIN       = '1e-006-(dxwn+dwmisn)'       WMAX       = '1e-005-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthn+vthmisn)'  LVTH0      = '-2.6209825e-009+dlvthn'
+WVTH0      = '6.8814839e-010+dwvthn'
+PVTH0      = '-5.3326435e-017+dpvthn'
+K1         = 0.31994             K2         = '0.0071010498+dk2n' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitn'
+WCIT       = '-2.634146e-010+dwcitn'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffn'
+WVOFF      = '-2.7301032e-008+dwvoffn'
+PVOFF      = '3.8940424e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10402516+deta0n' LETA0      = '-1.6784547e-010+dleta0n'
+WETA0      = '-3.0136772e-008+dweta0n'
+PETA0      = '1.6875216e-015+dpeta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0n'  LU0        = '6.0443544e-011+dlu0n'
+WU0        = '-3.4587047e-010+dwu0n'
+PU0        = '-1.2567478e-016+dpu0n'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatn-195.445*ff_flag+312.712*ss_flag'
+LVSAT      = '-0.00073522225+dlvsatn+1.87198e-05*ff_flag-2.99517e-05*ss_flag'
+WVSAT      = '0.013868259+dwvsatn+0.00195836*ff_flag-0.00313337*ss_flag'
+PVSAT      = '-1.6704557e-009+dpvsatn-1.87572e-10*ff_flag+3.00116e-10*ss_flag'
+A0         = '0.71811517-0.157167*ff_flag'
+LA0        = '-2.3073092e-007+dla0n+2.80797e-08*ff_flag'
+WA0        = '4.6955716e-007+1.57482e-06*ff_flag'
+PA0        = '-7.5179779e-014-2.81358e-13*ff_flag'
+AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2n'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln+dlmisn)'
+WMIN       = '1e-006-(dxwn+dwmisn)'       WMAX       = '1e-005-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41095635+(dvthn+vthmisn)'  LVTH0      = '4.4351783e-010+dlvthn'
+WVTH0      = '-9.3492206e-009+dwvthn'
+PVTH0      = '9.0806281e-016+dpvthn'
+K1         = 0.31994             K2         = '0.0013060071+dk2n' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 9.8452363e-005      LCIT       = '1.9928338e-010+dlcitn'
+WCIT       = '-1.6453517e-009+dwcitn'
+PCIT       = 1.1079017e-016      VOFF       = -0.13957401         LVOFF      = '-3.8809298e-009+dlvoffn'
+WVOFF      = '2.9811114e-008+dwvoffn'
+PVOFF      = '-1.576216e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn-0.357015*ss_flag+0.357015*ff_flag'
+ETA0       = '0.00035892377+deta0n-0.00181714*ff_flag'
+LETA0      = '9.7614105e-009+dleta0n+1.74047e-10*ff_flag'
+WETA0      = '1.4881786e-009+dweta0n+1.82078e-08*ff_flag'
+PETA0      = '-1.3415478e-015+dpeta0n-1.74395e-15*ff_flag'
+ETAB       = -0.081412532        LETAB      = -1.9907778e-010     WETAB      = -4.2459433e-008
+PETAB      = 1.9947594e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0n'   LU0        = '4.5926676e-011+dlu0n'
+WU0        = '-4.2433976e-009+dwu0n'
+PU0        = '2.4763426e-016+dpu0n'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024      UB         = 1.7366172e-018      LUB        = 9.8246845e-028
+WUB        = -1.7615195e-025     PUB        = -8.5364064e-033     UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '84649.699+dvsatn+1470.82*ff_flag'
+LVSAT      = '0.00071705169+dlvsatn-0.000140875*ff_flag'
+WVSAT      = '0.0039042958+dwvsatn-0.00509818*ff_flag'
+PVSAT      = '-7.1609734e-010+dpvsatn+4.88305e-10*ff_flag'
+A0         = '1.6696481+0.354057*ff_flag'
+LA0        = '-3.2186969e-007+dla0n-2.08856e-08*ff_flag'
+WA0        = '-2.4506944e-006-3.54765e-06*ff_flag'
+PA0        = '2.0452483e-013+2.09274e-13*ff_flag'
+AGS        = '3.3966895+1.45371*ss_flag'
+Pags     = '0+1.39516e-12*ss_flag'
+Wags     = '0-1.45662e-05*ss_flag'
+LAGS       = '1.5356668e-007-1.39237e-07*ss_flag'
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn'         RDW        = '65+drdswn'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon'              CGDO       = 'cgon'
+CGBO       = 0                   CGDL       = 'cgln'              CGSL       = 'cgln'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.097099973        LKT2       = 3.1797651e-009      WKT2       = 1.7596724e-008
+PKT2       = -1.2711311e-015     UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn+3.4195e-08*ss_flag-3.4195e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn+3.64155e-07*ss_flag-3.64155e-07*ff_flag'
+PNFACTOR   = '0+dpnfactorn-3.48789e-14*ss_flag+3.48789e-14*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln+dlmisn)'
+LMAX       = 2.00001e-05         WMIN       = '6e-007-(dxwn+dwmisn)'       WMAX       = '1e-006-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41234586+(dvthn+vthmisn)'  WVTH0      = '-3.4102328e-010+dwvthn'
+K1         = 0.31994             K2         = '0.024897369+dk2n'  WK2        = -6.0153161e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00033
+WCIT       = '9.486e-010+dwcitn' VOFF       = -0.13118588         WVOFF      = '-1.047246e-008+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220595+du0n'    WU0        = '-4.5849e-010+dwu0n'
+UA         = -1.5544144e-009     WUA        = 1.3098269e-016      UB         = 2.3962278e-018
+WUB        = -1.3134316e-025     UC         = 1.369035e-010       WUC        = -5.402277e-017
+VSAT       = '110000+dvsatn'     A0         = 2.6356816           WA0        = -3.6279523e-007
+AGS        = 0.93377161          WAGS       = -5.5844398e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05097            WKETA      = 1.29642e-008        DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0041275+dpdiblc2n'
+WPDIBLC2   = -1.66005e-009       PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0015829
+LTVOFF     = 0                   WTVOFF     = -1.23318e-010       PTVOFF     = 0
+KT1        = -0.2248802          WKT1       = 1.9926924e-008      KT1L       = 0
+KT2        = -0.0734525          WKT2       = 3.39915e-009        UTE        = -1.619
+WUTE       = 2.5296e-007         UA1        = 1.155e-009          WUA1       = 1.581e-016
+UB1        = -1.12735e-018       WUB1       = -1.62843e-025       UC1        = -2e-014
+WUC1       = 3.54144e-017        PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln+dlmisn)'
+LMAX       = '1e-005-(dxln+dlmisn)'       WMIN       = '6e-007-(dxwn+dwmisn)'       WMAX       = '1e-006-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40885016+(dvthn+vthmisn)'  LVTH0      = '3.4835029e-008+dlvthn'
+WVTH0      = '4.0341437e-010+dwvthn'
+PVTH0      = '-7.418403e-015+dpvthn'
+K1         = 0.31994             K2         = '0.026722076+dk2n'  LK2        = -1.8183407e-008
+WK2        = -6.3810858e-009     PK2        = 3.6449353e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00046259057      LCIT       = '1.3212796e-009+dlcitn'
+WCIT       = '1.0374547e-009+dwcitn'
+PCIT       = -8.8544672e-016     VOFF       = -0.12858922         LVOFF      = '-2.5875987e-008+dlvoffn'
+WVOFF      = '-1.1952669e-008+dwvoffn'
+PVOFF      = '1.4750443e-014+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021971943+du0n'  LU0        = '8.7251438e-010+dlu0n'
+WU0        = '-3.5168128e-010+dwu0n'
+PU0        = '-1.0643607e-015+dpu0n'
+UA         = -1.5717657e-009     LUA        = 1.7290734e-016      WUA        = 1.3682375e-016
+PUA        = -5.8206845e-023     UB         = 2.4217449e-018      LUB        = -2.542805e-025
+WUB        = -1.3512724e-025     PUB        = 3.7708778e-032      UC         = 1.4062234e-010
+LUC        = -3.7058619e-017     WUC        = -5.5190885e-017     PUC        = 1.1640389e-023
+VSAT       = '110000+dvsatn'
+A0         = '2.5755871-0.109379*ff_flag+0.0820344*ss_flag'
+LA0        = '5.9884843e-007+dla0n+1.08998e-06*ff_flag-8.17482e-07*ss_flag'
+WA0        = '-2.9268715e-007+6.78151e-08*ff_flag-5.08613e-08*ss_flag'
+PA0        = '-6.9863474e-013-6.75785e-13*ff_flag+5.06839e-13*ss_flag'
+AGS        = 0.87470677
+LAGS       = 5.8858761e-007      WAGS       = -4.1730422e-008     PAGS       = -1.4064732e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050917348        LKETA      = -5.2468409e-010
+WKETA      = 1.3808498e-008      PKETA      = -8.4135178e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.003974959+dpdiblc2n'
+LPDIBLC2   = 1.5200878e-009      WPDIBLC2   = -1.6685269e-009     PPDIBLC2   = 8.447307e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016380078        LTVOFF     = -5.491551e-010
+WTVOFF     = -1.3654194e-010     PTVOFF     = 1.3177799e-016      KT1        = -0.22424568
+LKT1       = -6.3230738e-009     WKT1       = 2.2469514e-008      PKT1       = -2.5337191e-014
+KT1L       = 0                   KT2        = -0.074820758        LKT2       = 1.363484e-008
+WKT2       = 4.024744e-009       PKT2       = -6.2341126e-015     UTE        = -1.6586596
+LUTE       = 3.9521215e-007      WUTE       = 2.8903761e-007      PUTE       = -3.5951739e-013
+UA1        = 1.1037098e-009      LUA1       = 5.1111283e-016      WUA1       = 2.2354154e-016
+PUA1       = -6.521321e-022      UB1        = -1.0463944e-018     LUB1       = -8.0673118e-025
+WUB1       = -2.2977647e-025     PUB1       = 6.6699936e-031      UC1        = -1.9453945e-012
+LUC1       = 1.9186768e-017      WUC1       = 3.644858e-017       PUC1       = -1.0305715e-023
+PRT        = 0                   AT         = 200798.9            LAT        = -0.0079610926
+WAT        = 0.00016953766       PAT        = -1.6894614e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln+dlmisn)'
+LMAX       = '1.000002e-006-(dxln+dlmisn)'
+WMIN       = '6e-007-(dxwn+dwmisn)'       WMAX       = '1e-006-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44786427+(dvthn+vthmisn)'  LVTH0      = '-2.817881e-009+dlvthn'
+WVTH0      = '-8.3987589e-009+dwvthn'
+PVTH0      = '1.0766624e-015+dpvthn'
+K1         = 0.31994             K2         = '0.014852277+dk2n'  LK2        = -6.7277449e-009
+WK2        = -4.8792964e-009     PK2        = 2.1955433e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00094891812       LCIT       = '-4.0981585e-011+dlcitn'
+WCIT       = '5.3747588e-011+dwcitn'
+PCIT       = 6.3938839e-017      VOFF       = -0.15657613         LVOFF      = '1.1344586e-009+dlvoffn'
+WVOFF      = '8.2730227e-009+dwvoffn'
+PVOFF      = '-4.7695748e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220162+du0n'    LU0        = '8.2980161e-010+dlu0n'
+WU0        = '-3.7878026e-010+dwu0n'
+PU0        = '-1.0382072e-015+dpu0n'
+UA         = -1.5168324e-009     LUA        = 1.1989066e-016      WUA        = 1.5445249e-016
+PUA        = -7.5220517e-023     UB         = 2.285951e-018       LUB        = -1.2322447e-025
+WUB        = -1.1350885e-025     PUB        = 1.6844661e-032      UC         = 1.0610996e-010
+LUC        = -3.750375e-018      WUC        = -4.420053e-017      PUC        = 1.0334881e-024
+VSAT       = '112500.53+dvsatn-788.665*ff_flag+1261.86*ss_flag'
+LVSAT      = '-0.0024132899+dlvsatn+0.000761148*ff_flag-0.00121784*ss_flag'
+WVSAT      = '-0.00034228083+dwvsatn+0.000488972*ff_flag-0.000782355*ss_flag'
+PVSAT      = '3.3033865e-010+dpvsatn-4.71912e-10*ff_flag+7.55059e-10*ss_flag'
+A0         = '4.506443+1.09887*ff_flag-1.0016*ss_flag'
+LA0        = '-1.26464e-006+dla0n-7.61145e-08*ff_flag+2.28345e-07*ss_flag'
+WA0        = '-1.6097986e-006-6.81297e-07*ff_flag+6.20992e-07*ss_flag'
+PA0        = '5.7252272e-013+4.71914e-14*ff_flag-1.41574e-13*ss_flag'
+AGS        = -0.80346274
+LAGS       = 2.2082058e-006      WAGS       = 1.2948229e-006      PAGS       = -1.4305683e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055175769        LKETA      = 3.5851609e-009
+WKETA      = 9.5991475e-009      PKETA      = -4.3510319e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0069572267+dpdiblc2n'
+LPDIBLC2   = -1.3581285e-009     WPDIBLC2   = -2.0699726e-009     PPDIBLC2   = 4.7191236e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0010163914        LTVOFF     = 5.0773113e-011
+WTVOFF     = 4.9875206e-011      PTVOFF     = -4.813506e-017      KT1        = -0.22821446
+LKT1       = -2.4927658e-009     WKT1       = -2.4053332e-009     PKT1       = -1.3302266e-015
+KT1L       = 0                   KT2        = -0.057541276        LKT2       = -3.0417602e-009
+WKT2       = -6.0091298e-009     PKT2       = 3.4496793e-015      UTE        = -1.265572
+LUTE       = 1.5839361e-008      WUTE       = -1.4689655e-007     PUTE       = 6.1207033e-014
+UA1        = 1.9047865e-009      LUA1       = -2.6201434e-016     WUA1       = -6.8491696e-016
+PUA1       = 2.2463028e-022      UB1        = -2.1825365e-018     LUB1       = 2.897709e-025
+WUB1       = 6.3824609e-025      PUB1       = -1.7073789e-031     UC1        = 2.4369497e-012
+LUC1       = 1.4957323e-017      WUC1       = 2.9779875e-017      PUC1       = -3.8696813e-024
+PRT        = 0                   AT         = 224902.3            LAT        = -0.031223524
+WAT        = 0.0086385276        PAT        = -9.8629682e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln+dlmisn)'
+LMAX       = '2.399959e-007-(dxln+dlmisn)'
+WMIN       = '6e-007-(dxwn+dwmisn)'       WMAX       = '1e-006-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthn+vthmisn)'  LVTH0      = '-2.4452732e-009+dlvthn'
+WVTH0      = '-2.656096e-009+dwvthn'
+PVTH0      = '-2.3254991e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0077298678+dk2n'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitn'
+WCIT       = '4.0796102e-010+dwcitn'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffn'
+WVOFF      = '-1.6424805e-008+dwvoffn'
+PVOFF      = '8.6103596e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.044118879+deta0n'
+LETA0      = '3.7906852e-009+dleta0n'
+WETA0      = '3.0967637e-008+dweta0n'
+PETA0      = '-2.3501797e-015+dpeta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0n'  LU0        = '-6.7466293e-010+dlu0n'
+WU0        = '-7.6703892e-009+dwu0n'
+PU0        = '6.2413382e-016+dpu0n'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatn+4397.51*ff_flag-7036.02*ss_flag'
+LVSAT      = '-0.0010680136+dlvsatn-0.000421195*ff_flag+0.000673912*ss_flag'
+WVSAT      = '0.0069449685+dwvsatn-0.00272646*ff_flag+0.00436233*ss_flag'
+PVSAT      = '-1.3310085e-009+dpvsatn+2.61141e-10*ff_flag-4.17826e-10*ss_flag'
+A0         = '2.0693451+3.53626*ff_flag'
+LA0        = '-7.0903035e-007+dla0n-6.31793e-07*ff_flag'
+WA0        = '-9.0869732e-007-2.19248e-06*ff_flag'
+PA0        = '4.1268564e-013+3.91711e-13*ff_flag'
+AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln+dlmisn)'
+WMIN       = '6e-007-(dxwn+dwmisn)'       WMAX       = '1e-006-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.4204795+(dvthn+vthmisn)-0.00994084*ff_flag'
+LVTH0      = '2.1124771e-011+dlvthn+9.52137e-10*ff_flag'
+WVTH0      = '-1.9062833e-008+dwvthn+1.01397e-08*ff_flag'
+PVTH0      = '1.3389037e-015+dpvthn-9.7118e-16*ff_flag'
+K1         = 0.31994             K2         = '-0.014947392+dk2n' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitn'
+WCIT       = '-4.2348127e-010+dwcitn'
+PCIT       = 6.2821635e-017      VOFF       = -0.10368237         LVOFF      = '-5.3664414e-009+dlvoffn'
+WVOFF      = '-6.7983641e-009+dwvoffn'
+PVOFF      = '-6.0994162e-017+dpvoffn'
+NFACTOR    = '0.75+dnfactorn-0.745563*ss_flag'
+ETA0       = '-0.051871703+deta0n+0.0408857*ff_flag'
+LETA0      = '1.2984759e-008+dleta0n-3.91605e-09*ff_flag'
+WETA0      = '5.4763418e-008+dweta0n-2.53491e-08*ff_flag'
+PETA0      = '-4.6293634e-015+dpeta0n+2.42795e-15*ff_flag'
+ETAB       = -0.16081204         LETAB      = 4.4792501e-009      WETAB      = 3.8528064e-008
+PETAB      = -2.7771351e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0n'  LU0        = '1.4350807e-010+dlu0n'
+WU0        = '-2.7003787e-009+dwu0n'
+PU0        = '1.4810125e-016+dpu0n'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023      UB         = 9.4237903e-019      LUB        = 5.867745e-026
+WUB        = 6.3397101e-025      PUB        = -6.7385287e-032     UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatn-11977.1*ff_flag'
+LVSAT      = '-0.00026235326+dlvsatn+0.00114717*ff_flag'
+WVSAT      = '-0.0099049722+dwvsatn+0.00861872*ff_flag'
+PVSAT      = '2.8289571e-010+dpvsatn-8.25503e-10*ff_flag'
+A0         = '-8.937762-7.96629*ff_flag'
+LA0        = '3.4524137e-007+dla0n+4.69926e-07*ff_flag'
+WA0        = '8.3688639e-006+4.9391e-06*ff_flag'
+PA0        = '-4.7592845e-013-2.91354e-13*ff_flag'
+AGS        = '6.4966895-32.7086*ss_flag'
+LAGS       = '1.5356668e-007+3.13284e-06*ss_flag'
+WAGS       = '-3.162e-006+2.02793e-05*ss_flag'
+PAGS       = '-1.6753592e-027-1.94236e-12*ss_flag'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0                   KT2        = -0.10354588
+LKT2       = 3.8169646e-009      WKT2       = 2.4171549e-008      PKT2       = -1.9210747e-015
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn+7.14103e-08*ss_flag'
+WNFACTOR   = '0+dwnfactorn+7.60474e-07*ss_flag'
+PNFACTOR   = '0+dpnfactorn-7.28385e-14*ss_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln+dlmisn)'
+LMAX       = 2.00001e-05         WMIN       = '3e-007-(dxwn+dwmisn)'       WMAX       = '6e-007-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4276847+(dvthn+vthmisn)'   WVTH0      = '-9.851103e-009+dwvthn'
+K1         = 0.31994             K2         = '0.016999242+dk2n'  WK2        = -1.1184774e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00184
+WCIT       = '-3.968e-010+dwcitn'
+VOFF       = -0.15391902         WVOFF      = '3.6220876e-009+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022642667+du0n'  WU0        = '-8.2005333e-010+dwu0n'
+UA         = -1.3081355e-009     WUA        = -2.1710251e-017     UB         = 2.1698603e-018
+WUB        = 9.0047147e-027      UC         = 7.1487333e-011      WUC        = -1.3464747e-017
+VSAT       = '110000+dvsatn'     A0         = 1.7876245           WA0        = 1.6300015e-007
+AGS        = 0.82793509          WAGS       = 9.7742421e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.024641333        WKETA      = -3.3595733e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00032208424+dpdiblc2n'
+WPDIBLC2   = 6.9930778e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012677333
+LTVOFF     = 0                   WTVOFF     = 7.2085333e-011      PTVOFF     = 0
+KT1        = -0.20249189         WKT1       = 6.0461739e-009      KT1L       = 0
+KT2        = -0.070540667        WKT2       = 1.5938133e-009      UTE        = -1.3784667
+WUTE       = 1.0382933e-007      UA1        = 1.282e-009          WUA1       = 7.936e-017
+UB1        = -1.3882293e-018     WUB1       = -1.0978133e-027     UC1        = 5.4326667e-011
+WUC1       = 1.7194667e-018      PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln+dlmisn)'
+LMAX       = '1e-005-(dxln+dlmisn)'       WMIN       = '3e-007-(dxwn+dwmisn)'       WMAX       = '6e-007-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42605581+(dvthn+vthmisn)'  LVTH0      = '1.6232044e-008+dlvthn'
+WVTH0      = '-1.0264089e-008+dwvthn'
+PVTH0      = '4.1154478e-015+dpvthn'
+K1         = 0.31994             K2         = '0.018007345+dk2n'  LK2        = -1.0045864e-008
+WK2        = -9.7795291e-010     PK2        = -1.4003415e-015     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0018878992        LCIT       = '-4.7732075e-010+dlcitn'
+WCIT       = '-4.1984897e-010+dwcitn'
+PCIT       = 2.2968548e-016      VOFF       = -0.15467558         LVOFF      = '7.5391143e-009+dlvoffn'
+WVOFF      = '4.2208688e-009+dwvoffn'
+PVOFF      = '-5.9669201e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02272967+du0n'   LU0        = '-8.6699326e-010+dlu0n'
+WU0        = '-8.2147169e-010+dwu0n'
+PU0        = '1.4134056e-017+dpu0n'
+UA         = -1.314581e-009      LUA        = 6.423085e-017       WUA        = -2.263072e-017
+PUA        = 9.1725784e-024      UB         = 2.1840169e-018      LUB        = -1.410727e-025
+WUB        = 1.2264093e-026      PUB        = -3.2480061e-032     UC         = 7.141683e-011
+LUC        = 7.0257088e-019      WUC        = -1.228347e-017      PUC        = -1.1771549e-023
+VSAT       = '110000+dvsatn'     A0         = 1.8035366           LA0        = '-1.5856545e-007+dla0n'
+WA0        = 1.8598415e-007      PA0        = -2.2903814e-013     AGS        = 0.77479681
+LAGS       = 5.2952879e-007      WAGS       = 2.0213751e-008      PAGS       = -1.0403086e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022723624        LKETA      = -1.9110184e-008
+WKETA      = -3.6716113e-009     PKETA      = 3.1094924e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '9.2111129e-005+dpdiblc2n'
+LPDIBLC2   = 2.2917073e-009      WPDIBLC2   = 7.388388e-010       PPDIBLC2   = -3.9393101e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013017628        LTVOFF     = -3.3910735e-010
+WTVOFF     = 7.1929953e-011      PTVOFF     = 1.5483859e-018      KT1        = -0.20000319
+LKT1       = -2.4800253e-008     WKT1       = 7.4391679e-009      PKT1       = -1.3881339e-014
+KT1L       = 0                   KT2        = -0.07226453         LKT2       = 1.7178492e-008
+WKT2       = 2.4398829e-009      PKT2       = -8.4311765e-015     UTE        = -1.3598451
+LUTE       = -1.8556648e-007     WUTE       = 1.037726e-007       PUTE       = 5.6536225e-016
+UA1        = 1.3460976e-009      LUA1       = -6.3873965e-016     WUA1       = 7.3261077e-017
+PUA1       = 6.0776441e-023      UB1        = -1.4247522e-018     LUB1       = 3.639548e-025
+WUB1       = 4.8053771e-027      PUB1       = -5.8825942e-032     UC1        = 8.1281117e-011
+LUC1       = -2.6860406e-016     WUC1       = -1.5151857e-017     PUC1       = 1.681246e-022
+PRT        = 0                   AT         = 202216.18           LAT        = -0.022084463
+WAT        = -0.00070917713      PAT        = 7.0670281e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln+dlmisn)'
+LMAX       = '1.000002e-006-(dxln+dlmisn)'
+WMIN       = '3e-007-(dxwn+dwmisn)'       WMAX       = '6e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44379242+(dvthn+vthmisn)'  LVTH0      = '-8.8573346e-010+dlvthn'
+WVTH0      = '-5.8742089e-009+dwvthn'
+PVTH0      = '-1.2126911e-016+dpvthn'
+K1         = 0.31994             K2         = '0.011976931+dk2n'  LK2        = -4.2258503e-009
+WK2        = -3.096582e-009      PK2        = 6.4436865e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0011530249        LCIT       = '2.3191383e-010+dlcitn'
+WCIT       = '-7.279858e-011+dwcitn'
+PCIT       = -1.0525632e-016     VOFF       = -0.13612071         LVOFF      = '-1.0368368e-008+dlvoffn'
+WVOFF      = '-4.4093367e-009+dwvoffn'
+PVOFF      = '2.3621775e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02296062+du0n'   LU0        = '-1.0898857e-009+dlu0n'
+WU0        = '-9.6432059e-010+dwu0n'
+PU0        = '1.5199896e-016+dpu0n'
+UA         = -1.2231707e-009     LUA        = -2.3990174e-017     WUA        = -2.7617741e-017
+PUA        = 1.3985602e-023      UB         = 2.1388512e-018      LUB        = -9.748279e-026
+WUB        = -2.230697e-026      PUB        = 8.8481753e-034      UC         = 7.9956073e-011
+LUC        = -7.5387377e-018     WUC        = -2.7985123e-017     PUC        = 3.382273e-024
+VSAT       = '114026.83+dvsatn'  LVSAT      = '-0.0038863371+dlvsatn'
+WVSAT      = '-0.0012885866+dwvsatn'
+PVSAT      = '1.2436279e-009+dpvsatn'
+A0         = 2.1012026           LA0        = '-4.4584588e-007+dla0n'
+WA0        = -1.1854956e-007     PA0        = 6.4870393e-014      AGS        = 1.8492877
+LAGS       = -5.0747307e-007     WAGS       = -3.4988232e-007     PAGS       = 2.5315256e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.036180291        LKETA      = -6.1230205e-009
+WKETA      = -2.1780491e-009     PKETA      = 1.6680405e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0029202782+dpdiblc2n'
+LPDIBLC2   = -4.3778502e-010     WPDIBLC2   = 4.3293545e-010      PPDIBLC2   = -9.8700623e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00097124062       LTVOFF     = -2.0117097e-011
+WTVOFF     = 7.786867e-011       PTVOFF     = -4.1831298e-018     KT1        = -0.20791948
+LKT1       = -1.7160154e-008     WKT1       = -1.4988217e-008     PKT1       = 7.7635542e-015
+KT1L       = 0                   KT2        = -0.05401687         LKT2       = -4.3250772e-010
+WKT2       = -8.1942617e-009     PKT2       = 1.8319428e-015      UTE        = -1.7274986
+LUTE       = 1.6925963e-007      WUTE       = 1.3949795e-007      PUTE       = -3.3913534e-014
+UA1        = 3.3391362e-010      LUA1       = 3.3812923e-016      WUA1       = 2.8902423e-016
+PUA1       = -1.4745873e-022     UB1        = -8.5309426e-019     LUB1       = -1.8775804e-025
+WUB1       = -1.860081e-025      PUB1       = 1.2533005e-031      UC1        = -2.9157422e-010
+LUC1       = 9.1242359e-017      WUC1       = 2.120668e-016       PUC1       = -5.1166403e-023
+PRT        = 0                   AT         = 224176.96           LAT        = -0.043279029
+WAT        = 0.0090882378        PAT        = -2.3885551e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln+dlmisn)'
+LMAX       = '2.399959e-007-(dxln+dlmisn)'
+WMIN       = '3e-007-(dxwn+dwmisn)'       WMAX       = '6e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45421094+(dvthn+vthmisn)'  LVTH0      = '-3.2609491e-009+dlvthn'
+WVTH0      = '-7.6043531e-009+dwvthn'
+PVTH0      = '2.7316917e-016+dpvthn'
+K1         = 0.31994             K2         = '0.0033553434+dk2n' LK2        = -2.2603008e-009
+WK2        = -2.2578918e-009     PK2        = 4.5316404e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0024283835        LCIT       = '-5.8842434e-011+dlcitn'
+WCIT       = '-9.3654447e-010+dwcitn'
+PCIT       = 9.166047e-017       VOFF       = -0.18990686         LVOFF      = '1.8937985e-009+dlvoffn'
+WVOFF      = '1.0968765e-008+dwvoffn'
+PVOFF      = '-1.143722e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.12614967+deta0n' LETA0      = '-5.1093057e-009+dleta0n'
+WETA0      = '-1.9891452e-008+dweta0n'
+PETA0      = '3.1678146e-015+dpeta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014783927+du0n'  LU0        = '7.7423676e-010+dlu0n'
+WU0        = '9.0506683e-010+dwu0n'
+PU0        = '-2.7418398e-016+dpu0n'
+UA         = -1.660424e-009      LUA        = 7.569483e-017       WUA        = 1.2189162e-016
+PUA        = -2.0099543e-023     UB         = 1.8854943e-018      LUB        = -3.9722495e-026
+WUB        = -1.9210541e-026     PUB        = 1.7889358e-034      UC         = 5.728725e-011
+LUC        = -2.3706995e-018     WUC        = -1.9686336e-017     PUC        = 1.4903156e-024
+VSAT       = '108347.65+dvsatn'  LVSAT      = '-0.0025915958+dlvsatn'
+WVSAT      = '0.0058612307+dwvsatn'
+PVSAT      = '-3.863875e-010+dpvsatn'
+A0         = -0.98300577         LA0        = '2.5729195e-007+dla0n'
+WA0        = 9.8376019e-007      PA0        = -1.8643419e-013     AGS        = -2.8231338
+LAGS       = 5.5774558e-007      WAGS       = 1.311556e-006       PAGS       = -1.2562214e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041656409        LKETA      = -4.8745752e-009
+WKETA      = -7.736204e-009      PKETA      = 2.9351887e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.22629814          LPCLM      = 8.9111726e-008
+WPCLM      = -2.8028223e-008     PPCLM      = -6.2145624e-015     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00094709599
+LTVOFF     = -1.4612604e-011     WTVOFF     = 2.7416941e-011      PTVOFF     = 7.3188553e-018
+KT1        = -0.277058           LKT1       = -1.397956e-009      WKT1       = 2.8183098e-008
+PKT1       = -2.0786423e-015     KT1L       = 0                   KT2        = -0.046538569
+LKT2       = -2.1374107e-009     WKT2       = -5.5723834e-009     PKT2       = 1.234207e-015
+UTE        = -0.65956337         LUTE       = -7.4208242e-008     WUTE       = -1.1179679e-007
+PUTE       = 2.3376642e-014      UA1        = 2.5612467e-009      LUA1       = -1.6965817e-016
+WUA1       = -5.4560818e-016     PUA1       = 4.2820766e-023      UB1        = -2.0582479e-018
+LUB1       = 8.6992894e-026      WUB1       = 4.4039735e-025      PUB1       = -1.7477864e-032
+UC1        = 1.6622197e-010      LUC1       = -1.3126016e-017     WUC1       = -2.8658038e-017
+PUC1       = 3.714046e-024       PRT        = 0                   AT         = 44971.144
+LAT        = -0.0024236881       WAT        = -0.0047907659       PAT        = 7.7558019e-010
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln+dlmisn)'
+WMIN       = '3e-007-(dxwn+dwmisn)'       WMAX       = '6e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.42266826+(dvthn+vthmisn)+0.0132545*ff_flag'
+LVTH0      = '-2.3975895e-010+dlvthn-1.26952e-09*ff_flag'
+WVTH0      = '-2.0419864e-008+dwvthn-4.24143e-09*ff_flag'
+PVTH0      = '1.5006516e-015+dpvthn+4.06245e-16*ff_flag'
+K1         = 0.31994             K2         = '-0.013299183+dk2n' LK2        = -6.6511353e-010
+WK2        = -2.1217758e-011     PK2        = 2.3893317e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0036006898       LCIT       = '5.1862823e-010+dlcitn'
+WCIT       = '1.1272813e-009+dwcitn'
+PCIT       = -1.0601483e-016     VOFF       = -0.10535026         LVOFF      = '-6.2051173e-009+dlvoffn'
+WVOFF      = '-5.7642711e-009+dwvoffn'
+PVOFF      = '4.5898489e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn+0.652034*ss_flag+0.171025*ff_flag'
+ETA0       = '-0.024024221+deta0n'
+LETA0      = '9.2744996e-009+dleta0n'
+WETA0      = '3.7497979e-008+dweta0n'
+PETA0      = '-2.3290025e-015+dpeta0n'
+ETAB       = -0.051005772        LETAB      = -2.9378167e-009     WETAB      = -2.9551821e-008
+PETAB      = 1.8214463e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022141568+du0n'  LU0        = '6.9514519e-011+dlu0n'
+WU0        = '-3.982763e-009+dwu0n'
+PU0        = '1.9397724e-016+dpu0n'
+UA         = -8.2122219e-010     LUA        = -4.684758e-018      WUA        = -5.3101284e-016
+PUA        = 4.24363e-023        UB         = 1.5660551e-018      LUB        = -9.1262856e-027
+WUB        = 2.4729184e-025      PUB        = -2.5346971e-032     UC         = -1.4219741e-011
+LUC        = 4.4783116e-018      WUC        = 2.9941448e-017      PUC        = -3.2630832e-024
+VSAT       = '77105.7+dvsatn+3976.34*ff_flag'
+LVSAT      = '0.00040078898+dlvsatn-0.000380855*ff_flag'
+WVSAT      = '0.0031661761+dwvsatn-0.00127243*ff_flag'
+PVSAT      = '-1.2825247e-010+dpvsatn+1.21874e-10*ff_flag'
+A0         = 8.073381            LA0        = '-6.1013784e-007+dla0n'
+WA0        = -2.1780448e-006     PA0        = 1.1640666e-013      AGS        = 1.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.36913643
+LKETA      = 2.6491789e-008      WKETA      = 8.6846044e-008      PKETA      = -6.1239936e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 1.2610378
+LPCLM      = -9.9966741e-009     WPCLM      = -3.0393451e-007     PPCLM      = 2.0212018e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0013591416+dpdiblc2n'
+LPDIBLC2   = -3.4398937e-011     WPDIBLC2   = -2.2266776e-010     PPDIBLC2   = 2.1327341e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = -0.00086115198      LTVOFF     = 1.585832e-010
+WTVOFF     = 8.4605521e-010      PTVOFF     = -7.1091137e-017     KT1        = -0.34419326
+LKT1       = 5.032327e-009       WKT1       = 3.0784511e-008      PKT1       = -2.3278082e-015
+KT1L       = 0                   KT2        = -0.086391456        LKT2       = 1.6797387e-009
+WKT2       = 1.3535807e-008      PKT2       = -5.9599457e-016     UTE        = -0.52365297
+LUTE       = -8.7225876e-008     WUTE       = -1.699253e-007      PUTE       = 2.8944249e-014
+UA1        = 4.9577924e-009      LUA1       = -3.9920171e-016     WUA1       = -1.6816004e-015
+PUA1       = 1.5162724e-022      UB1        = -5.0063038e-018     LUB1       = 3.6936063e-025
+WUB1       = 1.9058735e-024      PUB1       = -1.5784264e-031     UC1        = -2.9832515e-011
+LUC1       = 5.6522777e-018      WUC1       = 6.8152816e-019      PUC1       = 9.0387302e-025
+PRT        = 0                   AT         = 19666.667           WAT        = 0.0033066667
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn-6.2452e-08*ss_flag-1.63809e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn-1.06036e-07*ss_flag-1.06036e-07*ff_flag'
+PNFACTOR   = '0+dpnfactorn+1.01561e-14*ss_flag+1.01561e-14*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln+dlmisn)'
+LMAX       = 2.00001e-05         WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40171155+(dvthn+vthmisn)'  WVTH0      = '-1.5396969e-009+dwvthn'
+K1         = 0.31994             K2         = '0.0081248889+dk2n' WK2        = 1.7213156e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0001
+WCIT       = '2.24e-010+dwcitn'  VOFF       = -0.14674927         WVOFF      = '1.3277655e-009+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019737031+du0n'  WU0        = '1.0975004e-010+dwu0n'
+UA         = -1.3876311e-009     WUA        = 3.7283556e-018      UB         = 2.1326667e-018
+WUB        = 2.0906667e-026      UC         = 3.6184444e-011      WUC        = -2.1678222e-018
+VSAT       = '110000+dvsatn'     A0         = 2.4502222           WA0        = -4.9031111e-008
+AGS        = 0.79150093          WAGS       = 2.1433174e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.019631111        WKETA      = -4.9628444e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0021243041+dpdiblc2n'
+WPDIBLC2   = 1.2259743e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0016550111
+LTVOFF     = 0                   WTVOFF     = -5.1843556e-011     PTVOFF     = 0
+KT1        = -0.17096587         WKT1       = -4.0421547e-009     KT1L       = 0
+KT2        = -0.074963333        WKT2       = 3.0090667e-009      UTE        = -0.94635556
+WUTE       = -3.4446222e-008     UA1        = 1.6e-009            WUA1       = -2.24e-017
+UB1        = -1.3369511e-018     WUB1       = -1.7506844e-026     UC1        = 7.9455556e-011
+WUC1       = -6.3217778e-018     PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln+dlmisn)'
+LMAX       = '1e-005-(dxln+dlmisn)'       WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn+dwmisn)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn+toxmisn)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39757681+(dvthn+vthmisn)'  LVTH0      = '4.120314e-008+dlvthn'
+WVTH0      = '-1.1508097e-009+dwvthn'
+PVTH0      = '-3.875303e-015+dpvthn'
+K1         = 0.31994             K2         = '0.0095210115+dk2n' LK2        = -1.3912516e-008
+WK2        = 1.7376739e-009      PK2        = -1.6301281e-016     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00022358126      LCIT       = '1.2315009e-009+dlcitn'
+WCIT       = '2.5582478e-010+dwcitn'
+PCIT       = -3.1713744e-016     VOFF       = -0.14555693         LVOFF      = '-1.188177e-008+dlvoffn'
+WVOFF      = '1.3029025e-009+dwvoffn'
+PVOFF      = '2.4776275e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019787828+du0n'  LU0        = '-5.0619488e-010+dlu0n'
+WU0        = '1.1991766e-010+dwu0n'
+PU0        = '-1.0132143e-016+dpu0n'
+UA         = -1.4160953e-009     LUA        = 2.8364855e-016      WUA        = 9.8538358e-018
+PUA        = -6.1041084e-023     UB         = 2.1751911e-018      LUB        = -4.2376047e-025
+WUB        = 1.5088364e-026      PUB        = 5.7980026e-032      UC         = 4.1488701e-011
+LUC        = -5.2857499e-017     WUC        = -2.7064689e-018     PUC        = 5.3676738e-024
+VSAT       = '109991.66+dvsatn'  LVSAT      = '8.3113569e-005+dlvsatn'
+WVSAT      = '2.6689462e-006+dwvsatn'
+PVSAT      = '-2.6596342e-011+dpvsatn'
+A0         = 2.5602871           LA0        = '-1.0968083e-006+dla0n'
+WA0        = -5.6175997e-008     PA0        = 7.1199573e-014      AGS        = 0.78787773
+LAGS       = 3.6105576e-008      WAGS       = 1.6027857e-008      PAGS       = 5.3864572e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020217326        LKETA      = 5.8416966e-009
+WKETA      = -4.4736266e-009     PKETA      = -4.8751095e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0018516752+dpdiblc2n'
+LPDIBLC2   = 2.7167764e-009      WPDIBLC2   = 1.7577829e-010      PPDIBLC2   = -5.2995312e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016612908        LTVOFF     = -6.2577869e-011
+WTVOFF     = -4.3119011e-011     PTVOFF     = -8.6941049e-017     KT1        = -0.16216021
+LKT1       = -8.7749359e-008     WKT1       = -4.6705847e-009     PKT1       = 6.2623747e-015
+KT1L       = 0                   KT2        = -0.073651203        LKT2       = -1.3075522e-008
+WKT2       = 2.8836182e-009      PKT2       = 1.2501079e-015      UTE        = -0.91695187
+LUTE       = -2.9301095e-007     WUTE       = -3.7953218e-008     PUTE       = 3.4947594e-014
+UA1        = 1.6683918e-009      LUA1       = -6.8153127e-016     WUA1       = -2.9873049e-017
+PUA1       = 7.4469758e-023      UB1        = -1.3894768e-018     LUB1       = 5.2342433e-025
+WUB1       = -6.4827623e-027     PUB1       = -1.0985619e-031     UC1        = 3.4504068e-011
+LUC1       = 4.4794652e-016      WUC1       = -1.8320158e-019     PUC1       = -6.1171587e-023
+PRT        = 0                   AT         = 199165.95           LAT        = 0.0083113569
+WAT        = 0.00026689462       PAT        = -2.6596342e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln+dlmisn)'
+LMAX       = '1.000002e-006-(dxln+dlmisn)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44102656+(dvthn+vthmisn)'  LVTH0      = '-7.3064059e-010+dlvthn'
+WVTH0      = '-4.989133e-009+dwvthn'
+PVTH0      = '-1.7089884e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0030841439+dk2n'
+LK2        = -1.7471541e-009     WK2        = 1.722962e-009       PK2        = -1.4881416e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011992438
+LCIT       = '-1.4168183e-010+dlcitn'
+WCIT       = '-8.7588649e-011+dwcitn'
+PCIT       = 1.4294291e-017      VOFF       = -0.15305248         LVOFF      = '-4.6477361e-009+dlvoffn'
+WVOFF      = '1.0088296e-009+dwvoffn'
+PVOFF      = '5.3157543e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019886018+du0n'  LU0        = '-6.0095944e-010+dlu0n'
+WU0        = '1.9551924e-011+dwu0n'
+PU0        = '-4.4574475e-018+dpu0n'
+UA         = -1.1110295e-009     LUA        = -1.0773486e-017     WUA        = -6.3502928e-017
+PUA        = 9.756262e-024       UB         = 1.7905694e-018      LUB        = -5.2558224e-026
+WUB        = 8.9143207e-026      PUB        = -1.3491044e-032     UC         = -2.0787412e-011
+LUC        = 7.2457998e-018      WUC        = 4.2527925e-018      PUC        = -1.348779e-024
+VSAT       = '110077.78+dvsatn'  WVSAT      = '-2.4888889e-005+dwvsatn'
+A0         = 1.4387986           LA0        = '-1.4448542e-008+dla0n'
+WA0        = 9.3419726e-008      PA0        = -7.3176755e-014     AGS        = 0.48121726
+LAGS       = 3.3206667e-007      WAGS       = 8.7900211e-008      PAGS       = -1.5500155e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.006990853        LKETA      = -6.9233048e-009
+WKETA      = -1.1518669e-008     PKETA      = 1.9241315e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.25972553          LPCLM      = -1.0447143e-012
+WPCLM      = 5.9095831e-008      PPCLM      = 3.3430856e-019      PDIBLC1    = 0
+PDIBLC2    = '0.0056323094+dpdiblc2n'
+LPDIBLC2   = -9.3195145e-010     WPDIBLC2   = -4.3491454e-010     PPDIBLC2   = 5.9432633e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016763501        LTVOFF     = -7.7111719e-011
+WTVOFF     = -1.4776636e-010     PTVOFF     = 1.4055149e-017      KT1        = -0.27465483
+LKT1       = 2.0820326e-008      WKT1       = 6.3670941e-009      PKT1       = -4.3901995e-015
+KT1L       = 0                   KT2        = -0.096034015        LKT2       = 8.5263542e-009
+WKT2       = 5.2512249e-009      PKT2       = -1.034893e-015      UTE        = -1.3450582
+LUTE       = 1.2015872e-007      WUTE       = 1.7117021e-008      PUTE       = -1.8201244e-014
+UA1        = 9.9167261e-010      LUA1       = -2.8422861e-017     WUA1       = 7.8541349e-017
+PUA1       = -3.0162062e-023     UB1        = -9.5222251e-019     LUB1       = 1.0142584e-025
+WUB1       = -1.5428706e-025     PUB1       = 3.2791213e-032      UC1        = 6.2488934e-010
+LUC1       = -1.2184022e-016     WUC1       = -8.1201539e-017     PUC1       = 1.702002e-023
+PRT        = 0                   AT         = 272864.16           LAT        = -0.062815518
+WAT        = -0.006491667        PAT        = 3.8631212e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln+dlmisn)'
+LMAX       = '2.399959e-007-(dxln+dlmisn)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45945038+(dvthn+vthmisn)'  LVTH0      = '-4.9309045e-009+dlvthn'
+WVTH0      = '-9.2809733e-009+dwvthn'
+PVTH0      = '8.0755491e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0051767884+dk2n'
+LK2        = -1.270073e-009      WK2        = 4.7239043e-010      PK2        = 1.3629114e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00052078982
+LCIT       = '2.5045144e-010+dlcitn'
+WCIT       = '7.1909851e-012+dwcitn'
+PCIT       = -7.3135697e-018     VOFF       = -0.16902629         LVOFF      = '-1.0060278e-009+dlvoffn'
+WVOFF      = '4.2869811e-009+dwvoffn'
+PVOFF      = '-2.1577756e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.053643565+deta0n'
+LETA0      = '8.5157601e-009+dleta0n'
+WETA0      = '3.3105009e-009+dweta0n'
+PETA0      = '-1.1922064e-015+dpeta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018716753+du0n'  LU0        = '-3.3439041e-010+dlu0n'
+WU0        = '-3.5343762e-010+dwu0n'
+PU0        = '8.0576709e-017+dpu0n'
+UA         = -1.0699161e-009     LUA        = -2.0146527e-017     WUA        = -6.7070912e-017
+PUA        = 1.0569691e-023      UB         = 1.6471084e-018      LUB        = -1.9851994e-026
+WUB        = 5.7072951e-026      PUB        = -6.1796667e-033     UC         = -4.4895282e-012
+LUC        = 3.5302083e-018      WUC        = 8.223327e-020       PUC        = -3.9797494e-025
+VSAT       = '127361.64+dvsatn'  LVSAT      = '-0.0039403743+dlvsatn'
+WVSAT      = '-0.00022324674+dwvsatn'
+PVSAT      = '4.5221623e-011+dpvsatn'
+A0         = 2.9007007           LA0        = '-3.4773299e-007+dla0n'
+WA0        = -2.5902588e-007     PA0        = 7.1737938e-015      AGS        = 1.1681751
+LAGS       = 1.7545402e-007      WAGS       = 3.4337137e-008      PAGS       = -3.2888453e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.091684306        LKETA      = 1.2385109e-008
+WKETA      = 8.2727232e-009      PKETA      = -2.5879101e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.10444213         LPCLM      = 8.3021898e-008
+WPCLM      = 7.7808664e-008      PPCLM      = -4.2658173e-015     PDIBLC1    = 0
+PDIBLC2    = '0.0019389061+dpdiblc2n'
+LPDIBLC2   = -8.9929363e-011     WPDIBLC2   = -3.0044995e-010     PPDIBLC2   = 2.8777396e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0014974253        LTVOFF     = -3.6320451e-011
+WTVOFF     = -1.4868844e-010     PTVOFF     = 1.4265366e-017      KT1        = -0.11754841
+LKT1       = -1.4996797e-008     WKT1       = -2.2859971e-008     PKT1       = 2.2729868e-015
+KT1L       = 0                   KT2        = -0.070200221        LKT2       = 2.6367656e-009
+WKT2       = 1.999345e-009       PKT2       = -2.9352944e-016     UTE        = -0.85631913
+LUTE       = 8.7359953e-009      WUTE       = -4.8834951e-008     PUTE       = -3.1655136e-015
+UA1        = 8.5127789e-010      LUA1       = 3.5843275e-018      WUA1       = 1.58184e-018
+PUA1       = -1.2616833e-023     UB1        = -5.9081832e-019     LUB1       = 1.9032907e-026
+WUB1       = -2.9180118e-026     PUB1       = 4.2693323e-033      UC1        = 8.9570029e-011
+LUC1       = 2.0188224e-019      WUC1       = -4.1294185e-018     PUC1       = -5.5088158e-025
+PRT        = 0                   AT         = -24643.815          LAT        = 0.0050103502
+WAT        = 0.017486021         PAT        = -1.6033121e-009
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln+dlmisn)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn+dwmisn)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn+toxmisn)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln+dlmisn)'       XW         = '2.0e-08+(dxwn+dwmisn)'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.36071788+(dvthn+vthmisn)'  LVTH0      = '4.5257928e-009+dlvthn'
+WVTH0      = '-5.95745e-010+dwvthn'
+PVTH0      = '-2.4324941e-017+dpvthn'
+K1         = 0.31994             K2         = '-0.017993665+dk2n' LK2        = -4.245975e-011
+WK2        = 1.4810162e-009      PK2        = 3.9683957e-017      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -5.9211109e-005     LCIT       = '2.0624097e-010+dlcitn'
+WCIT       = '-5.9918863e-012+dwcitn'
+PCIT       = -6.0509011e-018     VOFF       = -0.13155585         LVOFF      = '-4.5949844e-009+dlvoffn'
+WVOFF      = '2.6215158e-009+dwvoffn'
+PVOFF      = '-5.6257627e-017+dpvoffn'
+NFACTOR    = '0.75+dnfactorn+0.69479*ss_flag-0.285042*ff_flag'
+ETA0       = '0.10887736+deta0n' LETA0      = '3.2254122e-009+dleta0n'
+WETA0      = '-5.030526e-009+dweta0n'
+PETA0      = '-3.9329451e-016+dpeta0n'
+ETAB       = -0.2088503          LETAB      = 6.034125e-009       WETAB      = 2.0958427e-008
+PETAB      = -1.049575e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0038987013+du0n' LU0        = '1.0848974e-009+dlu0n'
+WU0        = '1.8549544e-009+dwu0n'
+PU0        = '-1.3094529e-016+dpu0n'
+UA         = -2.711597e-009      LUA        = 1.3709532e-016      WUA        = 7.3907108e-017
+PUA        = -2.9333248e-024     UB         = 2.065192e-018       LUB        = -5.9896453e-026
+WUB        = 8.7568051e-026      PUB        = -9.1005179e-033     UC         = 8.4822175e-011
+LUC        = -5.0241559e-018     WUC        = -1.7519653e-018     PUC        = -2.2229358e-025
+VSAT       = '86222.222+dvsatn+1247.06*ss_flag'
+WVSAT      = '0.00024888889+dwvsatn-0.000399059*ss_flag'
+A0         = -0.45808519         LA0        = '-2.6025116e-008+dla0n'
+WA0        = 5.5202439e-007      PA0        = -7.0509412e-014     AGS        = 1.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.087025563
+LKETA      = -4.7319014e-009     WKETA      = -5.9125793e-008     PKETA      = 3.8675872e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.089655853
+LPCLM      = 8.1605653e-008      WPCLM      = 1.2828746e-007      PPCLM      = -9.1007273e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.00040143075+dpdiblc2n'
+LPDIBLC2   = 5.7331562e-011      WPDIBLC2   = 8.3799696e-011      PPDIBLC2   = -8.0264186e-018
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0015650114        LTVOFF     = -4.2793916e-011
+WTVOFF     = 6.9682922e-011      PTVOFF     = -6.6504612e-018     KT1        = -0.27336375
+LKT1       = -7.2647279e-011     WKT1       = 8.1190665e-009      PKT1       = -6.9421642e-016
+KT1L       = 0                   KT2        = -0.046973328        LKT2       = 4.120706e-010
+WKT2       = 9.2200548e-010      PKT2       = -1.9034079e-016     UTE        = -0.38851129
+LUTE       = -3.6071108e-008     WUTE       = -2.1317063e-007     PUTE       = 1.2574723e-014
+UA1        = 9.3863422e-010      LUA1       = -4.782749e-018      WUA1       = -3.954698e-016
+PUA1       = 2.541317e-023       UB1        = 4.7400456e-019      LUB1       = -8.2956893e-026
+WUB1       = 1.5217483e-025      PUB1       = -1.3101026e-032     UC1        = 5.5175742e-011
+LUC1       = 3.4962015e-018      WUC1       = -2.6521114e-017     PUC1       = 1.5938174e-024
+PRT        = 0                   AT         = 27666.667           WAT        = 0.00074666667
+NOIA       = 'noianmac'
+NOIB       = 'noibnmac'
+NOIC       = 'noicnmac'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+PVSAT      = '0+dpvsatn+3.8222e-11*ss_flag'
+LVSAT      = '0+dlvsatn-0.000119444*ss_flag'
+LNFACTOR   = '0+dlnfactorn-6.65473e-08*ss_flag+2.73014e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn-1.19718e-07*ss_flag+3.99059e-08*ff_flag'
+PNFACTOR   = '0+dpnfactorn+1.14666e-14*ss_flag-3.8222e-15*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )

**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.ends nch_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.1e-008' xw='+2.0e-08+dxwp'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1  temp2=parp2
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='l*scale+2e-09'
+       wef='w/nf*scale+2.0e-08'
+       geo_fac  = '1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisp = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisp = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisp='0.00253346*geo_fac*toxp*fac2*mismatchflag' 
.param tnoiax='1.773e05/(l*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(l*scale*1e6)+0.4706'

.param fn_dice='noiseflagp_mc*par1fn_mc+noiseflagp_mc_mis*par2fp_mc'
.param arearatio='sigma_factor_flicker*(log(3.873)-min(0,0.5*log(((w*scale*l*scale*multi)/(10.3E-6*1E-6*1))**0.5)))'
.param noiapmac='c1fp*2.718**((fn_dice+(1-fn_dice)*noiseflagp)*arearatio)'
.param noibpmac='c2fp*2.718**((fn_dice+(1-fn_dice)*noiseflagp)*arearatio)'
.param noicpmac='c3fp*2.718**((fn_dice+(1-fn_dice)*noiseflagp)*arearatio)'

.MODEL pch.1 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp+dlmisp)'
+LMAX       = 2.000001e-05        WMIN       = '1e-005-(dxwp+dwmisp)'       WMAX       = 0.00090000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp+toxmisp)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40478507+(dvthp+vthmisp)' K1         = 0.23752
+K2         = '0.01799+dk2p'      K3         = -2.4570454          K3B        = 2.1204211
+W0         = 0                   DVT0       = 10.498235           DVT1       = 1.3326361
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.4494              MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1e-010              DVTP1      = 0.3712
+LPE0       = 1.4959847e-007      LPEB       = 3.4167544e-008      WEB        = -210
+WEC        = -3510               SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020
+NDEP       = 6.3687e+017         NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 3.295e-005          VOFF       = -0.090520243        NFACTOR    = '0.7+dnfactorp'
+ETA0       = '0.15257+deta0p'    ETAB       = -0.1161             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p'      UA         = 2.125e-009
+UB         = 1.1188572e-018      UC         = 5.989e-011          VSAT       = '110000+dvsatp'
+A0         = 4.1738374           AGS        = 1.0392952           A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04364            DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2p'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.002061            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2107
+KT1L       = 0                   KT2        = -0.04721            UTE        = -1.871
+UA1        = -4.98e-010          UB1        = -2e-018             UC1        = 2.97e-011
+PRT        = 0
+AT         = '190000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'
+WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'
+WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp+dlmisp)'
+LMAX       = '1.000249e-005-(dxlp+dlmisp)'
+WMIN       = '1e-005-(dxwp+dwmisp)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40465395+(dvthp+vthmisp)' LVTH0      = '-1.3068431e-009+dlvthp'
+K1         = 0.23752             K2         = '0.01701623+dk2p'   LK2        = '9.7051776e-009+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -1.7211113e-005
+LCIT       = '4.9993574e-010+dlcitp'
+VOFF       = -0.090095029        LVOFF      = '-4.2379431e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15257+deta0p'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p'
+LU0        = '1.4985763e-010+dlu0p'
+UA         = 2.1364918e-009      LUA        = -1.1453404e-016     UB         = 1.120458e-018
+LUB        = -1.5954699e-026     UC         = 5.655953e-011       LUC        = 3.3193464e-017
+VSAT       = '110000+dvsatp'     A0         = 4.2339233           LA0        = -5.9885154e-007
+AGS        = 1.0187726           LAGS       = 2.045409e-007       A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.039535177        LKETA      = -4.0911132e-008     DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035560074+dpdiblc2p'
+LPDIBLC2   = 6.4224697e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021063228
+LTVOFF     = -4.517137e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2088205          LKT1       = -1.8732203e-008     KT1L       = 0
+KT2        = -0.047125154        LKT2       = -8.4562518e-010     UTE        = -1.8654152
+LUTE       = -5.5661404e-008     UA1        = -5.2291677e-010     LUA1       = 2.4833549e-016
+UB1        = -1.9183761e-018     LUB1       = -8.1351283e-025     UC1        = 6.2424743e-011
+LUC1       = -3.2615442e-016     PRT        = 0
+AT         = '191611+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.016056174+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'
+PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'         WETA0      = '0+dweta0p'
+PETA0      = '0+dpeta0p'         WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp+dlmisp)'
+LMAX       = '1.002493e-006-(dxlp+dlmisp)'
+WMIN       = '1e-005-(dxwp+dwmisp)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40092504+(dvthp+vthmisp)' LVTH0      = '-4.9112115e-009+dlvthp'
+K1         = 0.23752             K2         = '0.026125594+dk2p'  LK2        = '9.0007509e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00023972529
+LCIT       = '2.5158128e-010+dlcitp'
+VOFF       = -0.086981097        LVOFF      = '-7.247866e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15257+deta0p'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p'
+UA         = 2.0886074e-009      LUA        = -6.8249074e-017     UB         = 1.0708166e-018
+LUB        = 3.2028626e-026      UC         = 6.8468081e-011      LUC        = 2.168267e-017
+VSAT       = '110000+dvsatp'     A0         = 4.0877297           LA0        = -4.5754098e-007
+AGS        = 0.54098468          LAGS       = 6.6637023e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.066038936        LKETA      = -1.5292624e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.007+dpdiblc2p'    PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 2.1                 DELTA      = 0.036
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55                  RSW        = '75+drdswp'         RDW        = '75+drdswp'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.945e-007          ALPHA1     = 0.23                BETA0      = 17.8
+AGIDL      = 1e-008              BGIDL      = 2.317e+009          CGIDL      = 4.6
+EGIDL      = 0.008744            AIGBACC    = 0.012459            BIGBACC    = 0.0046798592
+CIGBACC    = 0.245               NIGBACC    = 8.2582031           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.006941            BIGC       = 0.0013212138
+CIGC       = 0.1525875           AIGSD      = 0.00629             BIGSD      = 0.00033134367
+CIGSD      = 0.01328125          NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.84                NTOX       = 'ntoxp'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop'              CGDO       = 'cgop'
+CGBO       = 0                   CGDL       = 'cglp'              CGSL       = 'cglp'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 6.8381              NOFF       = 2.3364              VOFFCV     = -0.069707
+TVOFF      = 0.0013759405        LTVOFF     = 2.542731e-010       WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2366354          LKT1       = 8.1536504e-009
+KT1L       = 0                   KT2        = -0.046125466        LKT2       = -1.8119223e-009
+UTE        = -2.0398459          LUTE       = 1.1294316e-007      UA1        = -3.6894314e-010
+LUA1       = 9.9504733e-017      UB1        = -2.8318571e-018     LUB1       = 6.9457022e-026
+UC1        = -3.7734954e-010     LUC1       = 9.8930958e-017      PRT        = 0
+AT         = '209960.05+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.033792351+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'
+PVTH0      = '0+dpvthp'          WK2        = '0+dwk2p'           PK2        = '0+dpk2p'
+WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'         WVOFF      = '0+dwvoffp'
+PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'           WU0        = '0+dwu0p'
+PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp+dlmisp)'
+LMAX       = '2.399996e-007-(dxlp+dlmisp)'
+WMIN       = '1e-005-(dxwp+dwmisp)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43586814+(dvthp+vthmisp)' LVTH0      = '3.1291616e-009+dlvthp'
+K1         = 0.23752             K2         = '0.026688227+dk2p'  LK2        = '7.7061392e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00050750804
+LCIT       = '1.8996473e-010+dlcitp'
+VOFF       = -0.10209394         LVOFF      = '-3.7704156e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.1525715+deta0p'  LETA0      = '-3.4445173e-013+dleta0p'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p'      UA         = 1.9776245e-009      LUA        = -4.2712014e-017
+UB         = 8.7504948e-019      LUB        = 7.707445e-026       UC         = 1.1382387e-010
+LUC        = 1.1246349e-017      VSAT       = '102515.14+dvsatp'  LVSAT      = '0.0017222586+dlvsatp'
+A0         = 2.8553267           LA0        = -1.7396628e-007     AGS        = 2.3173399
+LAGS       = 2.5763267e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.15948292
+LKETA      = 6.2087424e-009      DWG        = 0                   DWB        = 0
+PCLM       = 2.1496972           LPCLM      = '-3.4445173e-008+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.009366305+dpdiblc2p'
+LPDIBLC2   = -5.4448442e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0024847424
+LTVOFF     = -8.6112932e-013     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.19244272         LKT1       = -2.0150426e-009     KT1L       = 0
+KT2        = -0.043364015        LKT2       = -2.4473295e-009     UTE        = -1.5257969
+LUTE       = -5.3390018e-009     UA1        = -4.5404703e-011     LUA1       = 2.5058863e-017
+UB1        = -2.6722123e-018     LUB1       = 3.2722914e-026      UC1        = 1.9891165e-011
+LUC1       = 7.5262703e-018      PRT        = 0
+AT         = '207632.63+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.033256814+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'
+PCIT       = '0+dpcitp'          WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'
+WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp+dlmisp)'
+WMIN       = '1e-005-(dxwp+dwmisp)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.37118957+(dvthp+vthmisp)' LVTH0      = '-3.2416772e-009+dlvthp'
+K1         = 0.23752             K2         = '0.032369455+dk2p'  LK2        = '2.1101295e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0025451145
+LCIT       = '4.9064805e-010+dlcitp'
+VOFF       = -0.069838389        LVOFF      = '-6.9475876e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp+0.679147*ff_flag-0.594253*ss_flag+0.339573*sf_flag-0.543317*fs_flag'
+ETA0       = '0.14371879+deta0p-0.0339573*ss_flag'
+LETA0      = '8.716477e-010+dleta0p+3.34479e-09*ss_flag'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018269064+du0p-0.000339573*ss_flag'
+LU0        = '5.0171587e-012+dlu0p+3.34479e-11*ss_flag'
+UA         = 2.8260496e-009      LUA        = -1.2628188e-016     UB         = 1.8598275e-019
+LUB        = 1.4494752e-025      UC         = 2.5109082e-010      LUC        = -2.2744453e-018
+VSAT       = '116757.1+dvsatp+5093.6*ff_flag-8489.33*ss_flag+4074.88*sf_flag-4074.88*fs_flag'
+LVSAT      = '0.00031942577+dlvsatp-0.000501718*ff_flag+0.000836197*ss_flag-0.000401374*sf_flag+0.000401374*fs_flag'
+A0         = -2.4686737          LA0        = 3.5044776e-007      AGS        = 5.584986
+LAGS       = -6.4230468e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.27139688
+LKETA      = 1.7232268e-008      DWG        = 0                   DWB        = 0
+PCLM       = '1.7679439+0.50936*ff_flag-0.50936*ss_flag+0.407488*sf_flag-0.407488*fs_flag'
+Wpclm    = '0+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+LPCLM      = '3.1575288e-009+dlpclmp-5.01718e-08*ff_flag+5.01718e-08*ss_flag-4.01374e-08*sf_flag+4.01374e-08*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035644164+dpdiblc2p'
+LPDIBLC2   = 2.7001609e-011      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0038291897
+LTVOFF     = -1.3328918e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20152438         LKT1       = -1.1204988e-009     KT1L       = 0
+KT2        = -0.07256623         LKT2       = 4.2908867e-010      WKT2       = -3.4270439e-007
+PKT2       = 3.3756383e-014      UTE        = -2.5647553          LUTE       = 9.6998401e-008
+UA1        = -4.88626e-009       LUA1       = 5.0188311e-016      UB1        = 4.1052355e-019
+LUB1       = -2.7092657e-025     UC1        = -2.6143785e-010     LUC1       = 3.5237178e-017
+PRT        = 0
+AT         = '-191122.75+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '0.0060205904+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'          WK2        = '0+dwk2p'
+PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'
+WETA0      = '0+dweta0p+0.0*ss_flag'
+PETA0      = '0+dpeta0p+0.0*ss_flag'
+WVOFF      = '0+dwvoffp'
+PVOFF      = '0+dpvoffp'
+WU0        = '0+dwu0p+0.0*ss_flag'
+PU0        = '0+dpu0p+0.0*ss_flag'
+LNFACTOR   = '0+dlnfactorp-6.68957e-08*ff_flag+5.85338e-08*ss_flag-3.34479e-08*sf_flag+5.35166e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PNFACTOR   = '0+dpnfactorp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PVSAT      = '0+dpvsatp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+WVSAT      = '0+dwvsatp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PPCLM      = '0+dppclmp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp+dlmisp)'
+LMAX       = 2.000001e-05        WMIN       = '1e-006-(dxwp+dwmisp)'       WMAX       = '1e-005-(dxwp+dwmisp)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp+toxmisp)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40568103+(dvthp+vthmisp)' WVTH0      = '8.9774574e-009+dwvthp'
+K1         = 0.23752             K2         = '0.018667733+dk2p'  WK2        = '-6.790888e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.2646354e-005
+WCIT       = '8.5767547e-010+dwcitp'
+VOFF       = -0.090248724        WVOFF      = '-2.7206214e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p'      UA         = 2.17566e-009
+WUA        = -5.076132e-016      UB         = 1.1405421e-018      WUB        = -2.1728252e-025
+UC         = 6.2729e-011         WUC        = -2.844678e-017      VSAT       = '110000+dvsatp'
+A0         = 4.0329858           WA0        = 1.4113335e-006      AGS        = 1.0486742
+WAGS       = -9.3977301e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.045544
+WKETA      = 1.907808e-008       DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.00097393333+dpdiblc2p'
+WPDIBLC2   = 2.61188e-010        PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0020859333
+LTVOFF     = 0                   WTVOFF     = -2.49832e-010       PTVOFF     = 0
+KT1        = -0.210632           WKT1       = -6.8136e-010        KT1L       = 0
+KT2        = -0.047049067        WKT2       = -1.612552e-009      UTE        = -1.86964
+WUTE       = -1.36272e-008       UA1        = -5.46178e-010       WUA1       = 4.8274356e-016
+UB1        = -2.017e-018         WUB1       = 1.7034e-025         UC1        = 3.0346e-011
+WUC1       = -6.47292e-018       PRT        = 0
+AT         = '189433.33+datp'
+PAT      = '0+dpatp'
+LAT      = '0+dlatp'
+WAT        = '0.005678+dwatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'          PVTH0      = '0+dpvthp'
+LK2        = '0+dlk2p'           PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'
+PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'
+LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp+dlmisp)'
+LMAX       = '1.000249e-005-(dxlp+dlmisp)'
+WMIN       = '1e-006-(dxwp+dwmisp)'       WMAX       = '1e-005-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40577219+(dvthp+vthmisp)' LVTH0      = '9.0853098e-010+dlvthp'
+WVTH0      = '1.1204701e-008+dwvthp'
+PVTH0      = '-2.2198048e-014+dpvthp'
+K1         = 0.23752             K2         = '0.017700018+dk2p'  LK2        = '9.6448336e-009+dlk2p'
+WK2        = '-6.8515553e-009+dwk2p'
+PK2        = '6.046471e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00010956611
+LCIT       = '5.6729641e-010+dlcitp'
+WCIT       = '9.2539704e-010+dwcitp'
+PCIT       = '-6.7495389e-016+dpcitp'
+VOFF       = -0.089885889        LVOFF      = '-3.6162331e-009+dlvoffp'
+WVOFF      = '-2.0955804e-009+dwvoffp'
+PVOFF      = '-6.2295337e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p'  LU0        = '1.4985763e-010+dlu0p'
+UA         = 2.185679e-009       LUA        = -9.9855131e-017     WUA        = -4.9285564e-016
+PUA        = -1.4708269e-022     UB         = 1.1467823e-018      LUB        = -6.2193658e-026
+WUB        = -2.6376923e-025     PUB        = 4.6331437e-031      UC         = 5.9336696e-011
+LUC        = 3.3809736e-017      WUC        = -2.7827206e-017     PUC        = -6.1750419e-024
+VSAT       = '110000+dvsatp'     A0         = 4.082638            LA0        = -4.9486334e-007
+WA0        = 1.5158789e-006      PA0        = -1.0419617e-012     AGS        = 1.02975
+LAGS       = 1.8860985e-007      WAGS       = -1.0999371e-007     PAGS       = 1.5962908e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041373691        LKETA      = -4.1563798e-008
+WKETA      = 1.8421917e-008      PKETA      = 6.5397097e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035107849+dpdiblc2p'
+LPDIBLC2   = 6.2077451e-009      WPDIBLC2   = 4.5312959e-011      PPDIBLC2   = 2.1515402e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0021301728        LTVOFF     = -4.4091682e-010
+WTVOFF     = -2.3897727e-010     PTVOFF     = -1.0818479e-016     KT1        = -0.20872938
+LKT1       = -1.8962699e-008     WKT1       = -9.1309027e-010     PKT1       = 2.3095629e-015
+KT1L       = 0                   KT2        = -0.046972985        LKT2       = -7.5827959e-010
+WKT2       = -1.5247384e-009     PKT2       = -8.7520279e-016     UTE        = -1.8648342
+LUTE       = -4.7897352e-008     WUTE       = -5.8215488e-009     PUTE       = -7.7795803e-014
+UA1        = -5.7456501e-010     LUA1       = 2.8292192e-016      WUA1       = 5.175153e-016
+PUA1       = -3.4655599e-022     UB1        = -1.9361064e-018     LUB1       = -8.0623403e-025
+WUB1       = 1.776578e-025       PUB1       = -7.2933566e-032     UC1        = 6.6506529e-011
+LUC1       = -3.6039753e-016     WUC1       = -4.0899501e-017     PUC1       = 3.4311596e-022
+PRT        = 0
+AT         = '191166.05+datp'
+LAT        = '-0.017269307+dlatp'
+WAT        = '0.004458367+dwatp'
+PAT        = '1.2155594e-08+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp+dlmisp)'
+LMAX       = '1.002493e-006-(dxlp+dlmisp)'
+WMIN       = '1e-006-(dxwp+dwmisp)'       WMAX       = '1e-005-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.3990933+(dvthp+vthmisp)'  LVTH0      = '-5.5472718e-009+dlvthp'
+WVTH0      = '-1.8353959e-008+dwvthp'
+PVTH0      = '6.3733239e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0267055+dk2p'    LK2        = '9.4014377e-010+dlk2p'
+WK2        = '-5.8106529e-009+dwk2p'
+PK2        = '-4.0148817e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00019073515
+LCIT       = '2.7702552e-010+dlcitp'
+WCIT       = '4.9088123e-010+dwcitp'
+PCIT       = '-2.5495134e-016+dpcitp'
+VOFF       = -0.085868797        LVOFF      = '-7.4991505e-009+dlvoffp'
+WVOFF      = '-1.1145253e-008+dwvoffp'
+PVOFF      = '2.5178708e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018320708+du0p'  LU0        = '-6.8450398e-013+dlu0p'
+WU0        = '-7.0957345e-012+dwu0p'
+PU0        = '6.8587299e-018+dpu0p'
+UA         = 2.1571943e-009      LUA        = -7.2321872e-017     WUA        = -6.8724042e-016
+PUA        = 4.0809443e-023      UB         = 1.0503811e-018      LUB        = 3.0987619e-026
+WUB        = 2.0476372e-025      PUB        = 1.0430894e-032      UC         = 7.0564226e-011
+LUC        = 2.2957217e-017      WUC        = -2.100337e-017      PUC        = -1.2770955e-023
+VSAT       = '110000+dvsatp'     A0         = 3.9990876           LA0        = -4.1410363e-007
+WA0        = 8.881941e-007       PA0        = -4.3524225e-013     AGS        = 0.51343683
+LAGS       = 6.8767767e-007      WAGS       = 2.7602949e-007      PAGS       = -2.1350055e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.068491768        LKETA      = -1.5351492e-008
+WKETA      = 2.4577375e-008      PKETA      = 5.8985077e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0067025176+dpdiblc2p'
+LPDIBLC2   = 6.8450398e-011      WPDIBLC2   = 2.9807735e-009      PPDIBLC2   = -6.8587299e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001417086         LTVOFF     = 2.4835214e-010
+WTVOFF     = -4.122785e-010      PTVOFF     = 5.9328014e-017      KT1        = -0.23702705
+LKT1       = 8.3898043e-009      WKT1       = 3.9243084e-009      PKT1       = -2.3662618e-015
+KT1L       = 0                   KT2        = -0.046499384        LKT2       = -1.2160616e-009
+WKT2       = 3.7466529e-009      PKT2       = -5.9705244e-015     UTE        = -2.0256028
+LUTE       = 1.0750135e-007      WUTE       = -1.4271669e-007     PUTE       = 5.4526903e-014
+UA1        = -3.2474037e-010     LUA1       = 4.1441683e-017      WUA1       = -4.4291168e-016
+PUA1       = 5.8179177e-022      UB1        = -2.8877333e-018     LUB1       = 1.1360753e-025
+WUB1       = 5.5987888e-025      PUB1       = -4.4238808e-031     UC1        = -4.1188686e-010
+LUC1       = 1.0201704e-016      WUC1       = 3.4606401e-016      PUC1       = -3.0922584e-023
+PRT        = 0
+AT         = '202541.68+datp'
+LAT        = '-0.028264981+dlatp'
+WAT        = '0.074332056+dwatp'
+PAT        = '-5.5384244e-08+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp+dlmisp)'
+LMAX       = '2.399996e-007-(dxlp+dlmisp)'
+WMIN       = '1e-006-(dxwp+dwmisp)'       WMAX       = '1e-005-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthp+vthmisp)' LVTH0      = '3.2178643e-009+dlvthp'
+WVTH0      = '1.3206912e-008+dwvthp'
+PVTH0      = '-8.8880115e-016+dpvthp'
+K1         = 0.23752             K2         = '0.027489247+dk2p'  LK2        = '7.5980421e-010+dlk2p'
+WK2        = '-8.0262273e-009+dwk2p'
+PK2        = '1.0831329e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitp'
+WCIT       = '-9.439202e-010+dwcitp'
+PCIT       = '7.5195034e-017+dpcitp'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffp'
+WVOFF      = '-5.7821145e-009+dwvoffp'
+PVOFF      = '1.283818e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15306049+deta0p' LETA0      = '-4.6449316e-013+dleta0p'
+WETA0      = '-4.8996634e-009+dweta0p'
+PETA0      = '1.2028151e-018+dpeta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0p'  LU0        = '1.3663252e-012+dlu0p'
+WU0        = '8.2210644e-011+dwu0p'
+PU0        = '-1.3690578e-017+dpu0p'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatp'  LVSAT      = '0.0017671522+dlvsatp'
+WVSAT      = '0.0019549554+dwvsatp'
+PVSAT      = '-4.4983329e-010+dpvsatp'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmp'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2p'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datp'
+LAT        = '-0.036846346+dlatp'
+WAT        = '-0.32267684+dwatp'
+PAT        = '3.5967105e-08+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp+dlmisp)'
+WMIN       = '1e-006-(dxwp+dwmisp)'       WMAX       = '1e-005-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+(dvthp+vthmisp)' LVTH0      = '-3.4158001e-009+dlvthp'
+WVTH0      = '-1.3529255e-008+dwvthp'
+PVTH0      = '1.7447113e-015+dpvthp'
+K1         = 0.23752             K2         = '0.03417205+dk2p'   LK2        = '1.0154813e-010+dlk2p'
+WK2        = '-1.8062006e-008+dwk2p'
+PK2        = '1.0968375e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitp'
+WCIT       = '-9.8077622e-010+dwcitp'
+PCIT       = '7.8825353e-017+dpcitp'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffp'
+WVOFF      = '-1.7801351e-008+dwvoffp'
+PVOFF      = '2.4677127e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.756116*ff_flag-0.661602*ss_flag+0.378058*sf_flag-0.604893*fs_flag'
+ETA0       = '0.14447861+deta0p-0.0378058*ss_flag'
+LETA0      = '8.4485e-010+dleta0p+3.72386e-09*ss_flag'
+WETA0      = '-7.6134723e-009+dweta0p+3.85619e-08*ss_flag'
+PETA0      = '2.6851299e-016+dpeta0p-3.79834e-15*ss_flag'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0p-1.92425e-05*ff_flag-0.000320331*ss_flag+0.0*sf_flag+1.5394e-05*fs_flag'
+LU0        = '4.0694732e-012+dlu0p+1.89538e-12*ff_flag+3.15525e-11*ss_flag+0.0*sf_flag-1.5163e-12*fs_flag'
+WU0        = '-1.5318415e-010+dwu0p+1.9281e-10*ff_flag-1.9281e-10*ss_flag+0.0*sf_flag-1.54248e-10*fs_flag'
+PU0        = '9.495809e-018+dpu0p-1.89917e-17*ff_flag+1.89917e-17*ss_flag+0.0*sf_flag+1.51934e-17*fs_flag'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatp+5670.87*ff_flag-8489.34*ss_flag+4536.7*sf_flag-4536.7*fs_flag'
+LVSAT      = '0.00035562736+dlvsatp-0.000558579*ff_flag+0.000836197*ss_flag-0.000446864*sf_flag+0.000446864*fs_flag'
+WVSAT      = '0.0010707586+dwvsatp-0.00578429*ff_flag-4.8e-09*ss_flag-0.00462743*sf_flag+0.00462743*fs_flag'
+PVSAT      = '-3.6273991e-010+dpvsatp+5.69751e-10*ff_flag-2e-17*ss_flag+4.55801e-10*sf_flag-4.55801e-10*fs_flag'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flag-0.547845*ss_flag+0.45367*sf_flag-0.450591*fs_flag'
+LPCLM      = '3.5007467e-009+dlpclmp-5.54788e-08*ff_flag+5.39625e-08*ss_flag-4.46864e-08*sf_flag+4.43831e-08*fs_flag'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flag+3.85619e-07*ss_flag-4.62743e-07*sf_flag+4.31893e-07*fs_flag'
+PPCLM      = '-3.439044e-015+dppclmp+5.31768e-14*ff_flag-3.79834e-14*ss_flag+4.55801e-14*sf_flag-4.25414e-14*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2p'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datp'
+LAT        = '0.0065683527+dlatp'
+WAT        = '0.09819304+dwatp'
+PAT        = '-5.4885776e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp-7.44773e-08*ff_flag+6.51676e-08*ss_flag-3.72386e-08*sf_flag+5.95818e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-7.71239e-07*ff_flag+6.74834e-07*ss_flag-3.85619e-07*sf_flag+6.16991e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp+7.59668e-14*ff_flag-6.64709e-14*ss_flag+3.79834e-14*sf_flag-6.07734e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.11 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp+dlmisp)'
+LMAX       = 2.000001e-05        WMIN       = '6e-007-(dxwp+dwmisp)'       WMAX       = '1e-006-(dxwp+dwmisp)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp+toxmisp)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39498798+(dvthp+vthmisp)' WVTH0      = '-1.9294524e-009+dwvthp'
+K1         = 0.23752             K2         = '0.01549285+dk2p'   WK2        = '-3.552507e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001967827
+WCIT       = '-1.2032073e-009+dwcitp'
+VOFF       = -0.09144815         WVOFF      = '-1.497207e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0182575+du0p'    WU0        = '-7.905e-011+dwu0p'
+UA         = 1.99885e-009        WUA        = -3.27267e-016       UB         = 8.73301e-019
+WUB        = 5.530338e-026       UC         = 5.0433e-011         WUC        = -1.590486e-017
+VSAT       = '110000+dvsatp'     A0         = 5.6976187           WA0        = -2.8659209e-007
+AGS        = 0.9868853           WAGS       = -3.0952611e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0371165          WKETA      = 1.048203e-008       DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00265352+dpdiblc2p'
+WPDIBLC2   = -1.4519904e-009     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.001624
+LTVOFF     = 0                   WTVOFF     = 2.2134e-010         PTVOFF     = 0
+KT1        = -0.23085728         WKT1       = 1.9948426e-008      KT1L       = 0
+KT2        = -0.0375475          WKT2       = -1.130415e-008      UTE        = -1.70165
+WUTE       = -1.84977e-007       UA1        = 5.98405e-010        WUA1       = -6.847311e-016
+UB1        = -2.3925e-018        WUB1       = 5.5335e-025         UC1        = -5.605e-012
+WUC1       = 3.01971e-017        PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'          PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'
+PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'
+PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp+dlmisp)'
+LMAX       = '1.000249e-005-(dxlp+dlmisp)'
+WMIN       = '6e-007-(dxwp+dwmisp)'       WMAX       = '1e-006-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39111725+(dvthp+vthmisp)' LVTH0      = '-3.8578036e-008+dlvthp'
+WVTH0      = '-3.7433358e-009+dwvthp'
+PVTH0      = '1.807825e-014+dpvthp'
+K1         = 0.23752             K2         = '0.014568275+dk2p'  LK2        = '9.2148693e-009+dlk2p'
+WK2        = '-3.6571777e-009+dwk2p'
+PK2        = '1.0432107e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020873444
+LCIT       = '-1.1911829e-009+dlcitp'
+WCIT       = '-1.3154517e-009+dwcitp'
+PCIT       = '1.118695e-015+dpcitp'
+VOFF       = -0.089940125        LVOFF      = '-1.5029884e-008+dlvoffp'
+WVOFF      = '-2.0402598e-009+dwvoffp'
+PVOFF      = '5.4123897e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018250788+du0p'  LU0        = '6.6900726e-011+dlu0p'
+WU0        = '-8.753996e-011+dwu0p'
+PU0        = '8.4616038e-017+dpu0p'
+UA         = 2.0283313e-009      LUA        = -2.9382799e-016     WUA        = -3.3236098e-016
+PUA        = 5.0769623e-023      UB         = 8.391319e-019       LUB        = 3.4054974e-025
+WUB        = 5.0034171e-026      PUB        = 5.2516098e-032      UC         = 5.0128521e-011
+LUC        = 3.0346169e-018      WUC        = -1.8434868e-017     PUC        = 2.5215579e-023
+VSAT       = '110000+dvsatp'     A0         = 5.8948522           LA0        = -1.9657469e-006
+WA0        = -3.3257964e-007     PA0        = 4.5833947e-013      AGS        = 0.95157211
+LAGS       = 3.5195244e-007      WAGS       = -3.0252237e-008     PAGS       = -6.980351e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033294837        LKETA      = -3.8088992e-008
+WKETA      = 1.0181485e-008      PKETA      = 2.9954078e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.001805439+dpdiblc2p'
+LPDIBLC2   = 8.4524839e-009      WPDIBLC2   = -1.4381348e-009     PPDIBLC2   = -1.3809337e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001669892         LTVOFF     = -4.5738688e-010
+WTVOFF     = 2.3050916e-010      PTVOFF     = -9.1385321e-017     KT1        = -0.23024672
+LKT1       = -6.0852472e-009     WKT1       = 2.1034597e-008      PKT1       = -1.0825437e-014
+KT1L       = 0                   KT2        = -0.035304454        LKT2       = -2.2355547e-008
+WKT2       = -1.342664e-008      PKT2       = 2.115401e-014       UTE        = -1.6698811
+LUTE       = -3.1662776e-007     WUTE       = -2.0467371e-007     PUTE       = 1.9630921e-013
+UA1        = 6.3625325e-010      LUA1       = -3.7721841e-016     WUA1       = -7.1751933e-016
+PUA1       = 3.2678714e-022      UB1        = -2.2894498e-018     LUB1       = -1.0270599e-024
+WUB1       = 5.3806807e-025      PUB1       = 1.5230887e-031      UC1        = -1.1364694e-011
+LUC1       = 5.7404569e-017      WUC1       = 3.8529147e-017      PUC1       = -8.304218e-023
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp+dlmisp)'
+LMAX       = '1.002493e-006-(dxlp+dlmisp)'
+WMIN       = '6e-007-(dxwp+dwmisp)'       WMAX       = '1e-006-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43560449+(dvthp+vthmisp)' LVTH0      = '4.4232917e-009+dlvthp'
+WVTH0      = '1.8887457e-008+dwvthp'
+PVTH0      = '-3.7966508e-015+dpvthp'
+K1         = 0.23752             K2         = '0.023882732+dk2p'  LK2        = '2.115241e-010+dlk2p'
+WK2        = '-2.9314302e-009+dwk2p'
+PK2        = '3.417039e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001104327
+LCIT       = '-2.4099921e-010+dlcitp'
+WCIT       = '-4.4098244e-010+dwcitp'
+PCIT       = '2.7343389e-016+dpcitp'
+VOFF       = -0.10137833         LVOFF      = '-3.9737264e-009+dlvoffp'
+WVOFF      = '4.6744705e-009+dwvoffp'
+PVOFF      = '-1.0780618e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018313752+du0p'  LU0        = '6.039741e-012+dlu0p'
+UA         = 1.7761809e-009      LUA        = -5.0099652e-017     WUA        = -2.9860671e-016
+PUA        = 1.8142778e-023      UB         = 1.0785501e-018      LUB        = 1.0912836e-025
+WUB        = 1.7603136e-025      PUB        = -6.927266e-032      UC         = 3.4403006e-011
+LUC        = 1.8234884e-017      WUC        = 1.5881074e-017      PUC        = -7.9541759e-024
+VSAT       = '110000+dvsatp'     A0         = 4.9641532           LA0        = -1.0661342e-006
+WA0        = -9.6172823e-008     PA0        = 2.2982888e-013      AGS        = 0.67053007
+LAGS       = 6.2360739e-007      WAGS       = 1.1579439e-007      PAGS       = -1.4814887e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057803706        LKETA      = -1.4398743e-008
+WKETA      = 1.3675552e-008      PKETA      = -3.8195322e-016     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.012869735+dpdiblc2p'
+LPDIBLC2   = -2.2422539e-009     WPDIBLC2   = -3.3097886e-009     PPDIBLC2   = 1.6710454e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00085005187       LTVOFF     = 3.3506973e-010
+WTVOFF     = 1.6609632e-010      PTVOFF     = -2.9123933e-017     KT1        = -0.24612493
+LKT1       = 9.2626193e-009      WKT1       = 1.3204148e-008      PKT1       = -3.2565332e-015
+KT1L       = 0                   KT2        = -0.052092046        LKT2       = -6.1286762e-009
+WKT2       = 9.4511686e-009      PKT2       = -9.5965747e-016     UTE        = -2.2598535
+LUTE       = 2.5363892e-007      WUTE       = 9.6219042e-008      PUTE       = -9.4533423e-014
+UA1        = -7.5839073e-010     LUA1       = 9.7084307e-016      WUA1       = -5.8832305e-019
+PUA1       = -3.6619765e-022     UB1        = -2.7883902e-018     LUB1       = -5.4478464e-025
+WUB1       = 4.5854899e-025      PUB1       = 2.2917193e-031      UC1        = -4.0697082e-011
+LUC1       = 8.5757226e-017      WUC1       = -3.2549564e-017     PUC1       = -1.4337569e-023
+PRT        = 0
+AT         = '253818.5+datp'
+LAT        = '-0.061686895+dlatp'
+WAT        = '0.022029706+dwatp'
+PAT        = '-2.1293892e-08+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp+dlmisp)'
+LMAX       = '2.399996e-007-(dxlp+dlmisp)'
+WMIN       = '6e-007-(dxwp+dwmisp)'       WMAX       = '1e-006-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthp+vthmisp)' LVTH0      = '1.8657789e-009+dlvthp'
+WVTH0      = '2.5644645e-010+dwvthp'
+PVTH0      = '4.9032594e-016+dpvthp'
+K1         = 0.23752             K2         = '0.021012137+dk2p'  LK2        = '8.7204533e-010+dlk2p'
+WK2        = '-1.4195742e-009+dwk2p'
+PK2        = '-6.1726576e-018+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitp'
+WCIT       = '1.6122937e-009+dwcitp'
+PCIT       = '-1.9902291e-016+dpcitp'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffp'
+WVOFF      = '-2.10792e-009+dwvoffp'
+PVOFF      = '4.8255944e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14756059+deta0p' LETA0      = '-1.9572049e-010+dleta0p'
+WETA0      = '7.102273e-010+dweta0p'
+PETA0      = '2.0036393e-016+dpeta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0p'  LU0        = '-1.2055811e-011+dlu0p'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatp'  LVSAT      = '0.0033816548+dlvsatp'
+WVSAT      = '0.0091118432+dwvsatp'
+PVSAT      = '-2.096626e-009+dpvsatp'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmp'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2p'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datp'
+LAT        = '-0.010714171+dlatp'
+WAT        = '-0.11098338+dwatp'
+PAT        = '9.3122869e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p'
+PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp+dlmisp)'
+WMIN       = '6e-007-(dxwp+dwmisp)'       WMAX       = '1e-006-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+(dvthp+vthmisp)'  LVTH0      = '1.2618987e-009+dlvthp'
+WVTH0      = '3.5960684e-008+dwvthp'
+PVTH0      = '-3.0265415e-015+dpvthp'
+K1         = 0.23752             K2         = '0.022738541+dk2p'  LK2        = '7.0199448e-010+dlk2p'
+WK2        = '-6.399827e-009+dwk2p'
+PK2        = '4.8438224e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitp'
+WCIT       = '3.1067772e-010+dwcitp'
+PCIT       = '-7.0813731e-017+dpcitp'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffp'
+WVOFF      = '2.1045293e-008+dwvoffp'
+PVOFF      = '-1.798032e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.394754*ff_flag+0.394754*ss_flag+0.315803*sf_flag-0.315803*fs_flag'
+ETA0       = '0.11688678+deta0p' LETA0      = '2.82565e-009+dleta0p'
+WETA0      = '2.0530196e-008+dweta0p'
+PETA0      = '-1.751903e-015+dpeta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0p+0.000432956*ff_flag-0.00129887*ss_flag+0.0*sf_flag-0.000346365*fs_flag'
+LU0        = '1.337909e-011+dlu0p-4.2646e-11*ff_flag+1.27938e-10*ss_flag+0.0*sf_flag+3.41168e-11*fs_flag'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatp+2631.69*ff_flag-21647.8*ss_flag+2105.35*sf_flag-2105.35*fs_flag'
+LVSAT      = '-0.00025921987+dlvsatp-0.000259221*ff_flag+0.0021323*ss_flag-0.000207377*sf_flag+0.000207377*fs_flag'
+WVSAT      = '-0.014858007+dwvsatp-0.00268433*ff_flag+0.0134216*ss_flag-0.00214746*sf_flag+0.00214746*fs_flag'
+PVSAT      = '2.6440426e-010+dpvsatp+2.64405e-10*ff_flag-1.32203e-09*ss_flag+2.11524e-10*sf_flag-2.11524e-10*fs_flag'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flag-0.432956*ss_flag+0.0*sf_flag-0.0692729*fs_flag'
+LPCLM      = '-7.7061899e-009+dlpclmp-8.52921e-09*ff_flag+4.2646e-08*ss_flag+0.0*sf_flag+6.82337e-09*fs_flag'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flag+2.68433e-07*ss_flag+0.0*sf_flag+4.29492e-08*fs_flag'
+PPCLM      = '7.9920313e-015+dppclmp+5.28811e-15*ff_flag-2.64405e-14*ss_flag+0.0*sf_flag-4.23049e-15*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2p'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datp'
+LAT        = '-0.0064077479+dlatp'
+WAT        = '-0.095092602+dwatp'
+PAT        = '7.7470449e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p-2.68433e-10*ff_flag+8.05298e-10*ss_flag+0.0*sf_flag+2.14746e-10*fs_flag'
+PU0        = '0+dpu0p+2.64405e-17*ff_flag-7.93216e-17*ss_flag+0.0*sf_flag-2.11524e-17*fs_flag'
+LNFACTOR   = '0+dlnfactorp-3.88831e-08*ff_flag-3.88831e-08*ss_flag-3.11065e-08*sf_flag+3.11065e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-4.02649e-07*ff_flag-4.02649e-07*ss_flag-3.22119e-07*sf_flag+3.22119e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp+3.96608e-14*ff_flag+3.96608e-14*ss_flag+3.17286e-14*sf_flag-3.17286e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.16 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp+dlmisp)'
+LMAX       = 2.000001e-05        WMIN       = '3e-007-(dxwp+dwmisp)'       WMAX       = '6e-007-(dxwp+dwmisp)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp+toxmisp)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39586+(dvthp+vthmisp)'    WVTH0      = '-1.3888e-009+dwvthp'
+K1         = 0.23752             K2         = '0.0081982+dk2p'    WK2        = '9.70176e-010+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 2.2391333e-005
+WCIT       = '2.9627733e-012+dwcitp'
+VOFF       = -0.091604867        WVOFF      = '-1.4000427e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01813+du0p'      UA         = 1.8358e-009
+WUA        = -2.26176e-016       UB         = 9.8152549e-019      WUB        = -1.1795806e-026
+UC         = 1.2716e-011         WUC        = 7.47968e-018        VSAT       = '110000+dvsatp'
+A0         = 4.9147812           WA0        = 1.9876721e-007      AGS        = 0.91700495
+WAGS       = 1.2373205e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.024978
+WKETA      = 2.95616e-009        DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '-0.0010155488+dpdiblc2p'
+WPDIBLC2   = 8.2283226e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021580667
+LTVOFF     = 0                   WTVOFF     = -1.0978133e-010     PTVOFF     = 0
+KT1        = -0.20282363         WKT1       = 2.5675605e-009      KT1L       = 0
+KT2        = -0.068142667        WKT2       = 7.6648533e-009      UTE        = -2
+UA1        = -6.0133333e-011     WUA1       = -2.7643733e-016     UB1        = -2.9933333e-018
+WUB1       = 9.2586667e-025      UC1        = 1.2064667e-010      WUC1       = -4.8078933e-017
+PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'           PK2        = '0+dpk2p'
+LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'
+LU0        = '0+dlu0p'           WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp+dlmisp)'
+LMAX       = '1.000249e-005-(dxlp+dlmisp)'
+WMIN       = '3e-007-(dxwp+dwmisp)'       WMAX       = '6e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39511135+(dvthp+vthmisp)' LVTH0      = '-7.4615193e-009+dlvthp'
+WVTH0      = '-1.2669942e-009+dwvthp'
+PVTH0      = '-1.21399e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0067699412+dk2p' LK2        = '1.4234884e-008+dlk2p'
+WK2        = '1.1777893e-009+dwk2p'
+PK2        = '-2.0691983e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -2.2145724e-005
+LCIT       = '4.4388304e-010+dlcitp'
+WCIT       = '-7.5678113e-012+dwcitp'
+PCIT       = '1.0495413e-016+dpcitp'
+VOFF       = -0.090810617        LVOFF      = '-7.9159727e-009+dlvoffp'
+WVOFF      = '-1.5005549e-009+dwvoffp'
+PVOFF      = '1.001765e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018093556+du0p'  LU0        = '3.6322634e-010+dlu0p'
+WU0        = '9.9437966e-012+dwu0p'
+PU0        = '-9.9105843e-017+dpu0p'
+UA         = 1.8814664e-009      LUA        = -4.5513902e-016     WUA        = -2.4130478e-016
+PUA        = 1.5078246e-022      UB         = 8.9943727e-019      LUB        = 8.1814046e-025
+WUB        = 1.2644841e-026      PUB        = -2.4359015e-031     UC         = 5.3614712e-012
+LUC        = 7.3299647e-017      WUC        = 9.3207029e-018      PUC        = -1.8348739e-023
+VSAT       = '110000+dvsatp'     A0         = 4.9358235           LA0        = -2.0972081e-007
+WA0        = 2.6201814e-007      PA0        = -6.3039668e-013     AGS        = 0.88551891
+LAGS       = 3.1380883e-007      WAGS       = 1.070075e-008       PAGS       = 1.6668688e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021109528        LKETA      = -3.8555513e-008
+WKETA      = 2.6265942e-009      PKETA      = 3.2846508e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '-0.0022129374+dpdiblc2p'
+LPDIBLC2   = 1.1933893e-008      WPDIBLC2   = 1.0532586e-009      PPDIBLC2   = -2.296567e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0022502516        LTVOFF     = -9.1876997e-010
+WTVOFF     = -1.2931379e-010     PTVOFF     = 1.9467219e-016      KT1        = -0.20007204
+LKT1       = -2.7424003e-008     WKT1       = 2.3262956e-009      PKT1       = 2.4045909e-015
+KT1L       = 0                   KT2        = -0.071334663        LKT2       = 3.1813347e-008
+WKT2       = 8.9120895e-009      PKT2       = -1.2430704e-014     UTE        = -2
+UA1        = -2.1898977e-011     LUA1       = -3.8106653e-016     WUA1       = -3.0946494e-016
+PUA1       = 3.2917298e-022      UB1        = -3.0398017e-018     LUB1       = 4.6313143e-025
+WUB1       = 1.0032862e-024      PUB1       = -7.7160978e-031     UC1        = 1.3668863e-010
+LUC1       = -1.5988382e-016     WUC1       = -5.3263913e-017     PUC1       = 5.1676618e-023
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp+dlmisp)'
+LMAX       = '1.002493e-006-(dxlp+dlmisp)'
+WMIN       = '3e-007-(dxwp+dwmisp)'       WMAX       = '6e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4015281+(dvthp+vthmisp)'  LVTH0      = '-1.25909e-009+dlvthp'
+WVTH0      = '-2.2399062e-009+dwvthp'
+PVTH0      = '-2.7357417e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020322269+dk2p'  LK2        = '1.135217e-009+dlk2p'
+WK2        = '-7.2394308e-010+dwk2p'
+PK2        = '-2.309857e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00012950653
+LCIT       = '2.9729612e-010+dlcitp'
+WCIT       = '1.6340624e-010+dwcitp'
+PCIT       = '-6.0309219e-017+dpcitp'
+VOFF       = -0.094380138        LVOFF      = '-4.4656764e-009+dlvoffp'
+WVOFF      = '3.3559208e-010+dwvoffp'
+PVOFF      = '-7.7305283e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018516405+du0p'  LU0        = '-4.5499382e-011+dlu0p'
+WU0        = '-1.2564511e-010+dwu0p'
+PU0        = '3.1954257e-017+dpu0p'
+UA         = 1.3874016e-009      LUA        = 2.2423545e-017      WUA        = -5.7563571e-017
+PUA        = -2.6821604e-023     UB         = 1.8599319e-018      LUB        = -1.1027271e-025
+WUB        = -3.0842538e-025     PUB        = 6.6756003e-032      UC         = 6.9923054e-011
+LUC        = 1.0894485e-017      WUC        = -6.141356e-018      PUC        = -3.4031283e-024
+VSAT       = '110000+dvsatp'     A0         = 5.5679137           LA0        = -8.2069853e-007
+WA0        = -4.7050432e-007     PA0        = 7.7658793e-014      AGS        = 0.81346956
+LAGS       = 3.8345165e-007      WAGS       = 2.7171899e-008      PAGS       = 7.4769166e-016
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.040814855        LKETA      = -1.9508364e-008
+WKETA      = 3.1424638e-009      PKETA      = 2.7860117e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0094980747+dpdiblc2p'
+LPDIBLC2   = 6.1404034e-010      WPDIBLC2   = -1.219359e-009      PPDIBLC2   = -9.9857052e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00090537312       LTVOFF     = 3.8118819e-010
+WTVOFF     = 1.3179714e-010      PTVOFF     = -5.7717376e-017     KT1        = -0.23415174
+LKT1       = 5.5174081e-009      WKT1       = 5.7807717e-009      PKT1       = -9.3450223e-016
+KT1L       = 0                   KT2        = -0.030743494        LKT2       = -7.4220364e-009
+WKT2       = -3.7849339e-009     PKT2       = -1.5777414e-016     UTE        = -2.1773101
+LUTE       = 1.7138772e-007      WUTE       = 4.5042127e-008      PUTE       = -4.3537675e-014
+UA1        = -1.1220652e-009     LUA1       = 6.8235303e-016      WUA1       = 2.2488985e-016
+PUA1       = -1.8733383e-022     UB1        = -2.1861765e-018     LUB1       = -3.6198181e-025
+WUB1       = 8.5176483e-026      PUB1       = 1.1583418e-031      UC1        = -9.4282854e-011
+LUC1       = 6.3372989e-017      WUC1       = 6.736151e-019       PUC1       = -4.5934244e-025
+PRT        = 0
+AT         = '274020.76+datp'
+LAT        = '-0.081214384+dlatp'
+WAT        = '0.0095043019+dwatp'
+PAT        = '-9.1868488e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp+dlmisp)'
+LMAX       = '2.399996e-007-(dxlp+dlmisp)'
+WMIN       = '3e-007-(dxwp+dwmisp)'       WMAX       = '6e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.41517553+(dvthp+vthmisp)' LVTH0      = '1.8811701e-009+dlvthp'
+WVTH0      = '-5.5183106e-009+dwvthp'
+PVTH0      = '4.807834e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020374292+dk2p'  LK2        = '1.1232467e-009+dlk2p'
+WK2        = '-1.0241103e-009+dwk2p'
+PK2        = '-1.6191751e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00085869844
+LCIT       = '1.2950979e-010+dlcitp'
+WCIT       = '-1.0081518e-010+dwcitp'
+PCIT       = '4.878646e-019+dpcitp'
+VOFF       = -0.10161713         LVOFF      = '-2.8004515e-009+dlvoffp'
+WVOFF      = '-4.2791006e-009+dwvoffp'
+PVOFF      = '2.8878333e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15634998+deta0p' LETA0      = '2.6339076e-010+dleta0p'
+WETA0      = '-4.7391943e-009+dweta0p'
+PETA0      = '-8.4285042e-017+dpeta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.017556708+du0p'  LU0        = '1.7532593e-010+dlu0p'
+WU0        = '5.1812534e-010+dwu0p'
+PU0        = '-1.1617668e-016+dpu0p'
+UA         = 1.7606824e-009      LUA        = -6.3467987e-017     WUA        = -2.1515951e-016
+PUA        = 9.4410636e-024      UB         = 1.070533e-018       LUB        = 7.1367198e-026
+WUB        = 1.0174729e-025      PUB        = -2.7624318e-032     UC         = 1.2252387e-010
+LUC        = -1.2089108e-018     WUC        = -2.7979981e-017     PUC        = 1.6219176e-024
+VSAT       = '107365.33+dvsatp'  LVSAT      = '0.00060623504+dlvsatp'
+WVSAT      = '0.0016334957+dwvsatp'
+PVSAT      = '-3.7586573e-010+dpvsatp'
+A0         = 2.4886762           LA0        = -1.1216906e-007     WA0        = -1.7134175e-007
+PA0        = 8.821785e-015       AGS        = 4.7607057           LAGS       = -5.2480344e-007
+WAGS       = -2.1052918e-007     PAGS       = 5.5442473e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.12603645         LKETA      = 1.0103917e-010      WKETA      = 1.2478354e-008
+PKETA      = 6.3783275e-016      DWG        = 0                   DWB        = 0
+PCLM       = 2.6591518           LPCLM      = '-1.5167017e-007+dlpclmp'
+WPCLM      = 3.3108978e-008      PPCLM      = '-7.6183427e-015+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.018189484+dpdiblc2p'
+LPDIBLC2   = -1.3858441e-009     WPDIBLC2   = -2.7423305e-009     PPDIBLC2   = 2.5057715e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0028034616        LTVOFF     = -5.5560064e-011
+WTVOFF     = -2.6970243e-011     PTVOFF     = -2.1185159e-017     KT1        = -0.21668017
+LKT1       = 1.4972169e-009      WKT1       = 9.2746875e-010      PKT1       = 1.8223793e-016
+KT1L       = 0                   KT2        = -0.053089879        LKT2       = -2.2801556e-009
+WKT2       = -6.6189077e-009     PKT2       = 4.9432038e-016      UTE        = -1.3070703
+LUTE       = -2.8853573e-008     WUTE       = -2.817803e-007      PUTE       = 3.166384e-014
+UA1        = 3.5137962e-009      LUA1       = -3.8435405e-016     WUA1       = -1.2145568e-015
+PUA1       = 1.438814e-022       UB1        = -5.6340411e-018     LUB1       = 4.3136838e-025
+WUB1       = 1.0687354e-024      PUB1       = -1.1048174e-031     UC1        = 9.1514618e-011
+LUC1       = 2.0621177e-017      WUC1       = 1.897228e-017       PUC1       = -4.6698469e-024
+PRT        = 0
+AT         = '-52217.376+datp'
+LAT        = '-0.0061473152+dlatp'
+WAT        = '-0.058586759+dwatp'
+PAT        = '6.4808363e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp+dlmisp)'
+WMIN       = '3e-007-(dxwp+dwmisp)'       WMAX       = '6e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36316023+(dvthp+vthmisp)' LVTH0      = '-3.2423373e-009+dlvthp'
+WVTH0      = '1.7375122e-009+dwvthp'
+PVTH0      = '-2.3391514e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020043122+dk2p'  LK2        = '1.1558669e-009+dlk2p'
+WK2        = '-4.7286672e-009+dwk2p'
+PK2        = '2.0298134e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0040898917
+LCIT       = '6.1694592e-010+dlcitp'
+WCIT       = '5.4412491e-010+dwcitp'
+PCIT       = '-6.3038734e-017+dpcitp'
+VOFF       = -0.064317116        LVOFF      = '-6.474503e-009+dlvoffp'
+WVOFF      = '-4.8890811e-009+dwvoffp'
+PVOFF      = '3.4886642e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp-0.707445*ff_flag-0.345233*ss_flag-0.565956*sf_flag+0.565956*fs_flag'
+ETA0       = '0.159024+deta0p'   WETA0      = '-5.59488e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.019574783+du0p'  LU0        = '-2.3454436e-011+dlu0p'
+WU0        = '-8.9317888e-010+dwu0p'
+PU0        = '2.2836786e-017+dpu0p'
+UA         = 2.5413757e-009      LUA        = -1.4036628e-016     WUA        = -3.0638876e-016
+PUA        = 1.8427145e-023      UB         = -3.1570734e-019     LUB        = 2.0791187e-025
+WUB        = 1.9979745e-026      PUB        = -1.9570215e-032     UC         = -1.5114415e-010
+LUC        = 2.574739e-017       WUC        = 4.4193923e-018      PUC        = -1.5694208e-024
+VSAT       = '115987.55+dvsatp+113.195*ff_flag+90.5518*sf_flag-90.5518*fs_flag'
+LVSAT      = '-0.00024305347+dlvsatp-1.11493e-05*ff_flag-8.91981e-06*sf_flag+8.91981e-06*fs_flag'
+WVSAT      = '-0.0047649492+dwvsatp-0.00112285*ff_flag-0.000898285*sf_flag+0.000898285*fs_flag'
+PVSAT      = '2.543811e-010+dpvsatp+1.10601e-10*ff_flag+8.84807e-11*sf_flag-8.84807e-11*fs_flag'
+A0         = -3.5451926          LA0        = 4.8216702e-007      WA0        = -6.7893192e-008
+PA0        = -1.3678978e-015     AGS        = -1.544912           LAGS       = 9.62999e-008
+WAGS       = 9.5467378e-007      PAGS       = -5.9330019e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.28207926         LKETA      = 1.5471256e-008      WKETA      = 1.8752824e-008
+PKETA      = 1.9797485e-017      DWG        = 0                   DWB        = 0
+PCLM       = 1.4321929           LPCLM      = '-3.0814716e-008+dlpclmp'
+WPCLM      = -2.7082666e-007     PPCLM      = '2.2319318e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0057499399+dpdiblc2p'
+LPDIBLC2   = -1.6054908e-010     WPDIBLC2   = -1.2089627e-009     PPDIBLC2   = 9.9540429e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.003039542         LTVOFF     = -7.8813989e-011
+WTVOFF     = -8.0234889e-010     PTVOFF     = 5.5189638e-017      KT1        = -0.24843132
+LKT1       = 4.6247054e-009      WKT1       = 3.7361302e-008      PKT1       = -3.4064947e-015
+KT1L       = 0                   KT2        = -0.092007203        LKT2       = 1.5532008e-009
+WKT2       = -7.877144e-009      PKT2       = 6.1825666e-016      UTE        = -2.9967679
+LUTE       = 1.3758164e-007      WUTE       = 4.2144814e-007      PUTE       = -3.7604162e-014
+UA1        = -4.748832e-009      LUA1       = 4.2951483e-016      WUA1       = 6.6412562e-016
+PUA1       = -4.1168815e-023     UB1        = -7.634209e-019      LUB1       = -4.8387708e-026
+WUB1       = 8.0045741e-025      PUB1       = -8.4056362e-032     UC1        = 2.3476355e-010
+LUC1       = 6.5111571e-018      WUC1       = 2.0967956e-017      PUC1       = -4.866421e-024
+PRT        = 0
+AT         = '-240720.63+datp'
+LAT        = '0.012420255+dlatp'
+WAT        = '0.047069619+dwatp'
+PAT        = '-3.9263169e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'
+LNFACTOR   = '0+dlnfactorp+6.96831e-08*ff_flag+3.40053e-08*ss_flag+5.57465e-08*sf_flag-5.57465e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp+2.80714e-07*ff_flag+5.61424e-08*ss_flag+2.24571e-07*sf_flag-2.24571e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp-2.76502e-14*ff_flag-5.53001e-15*ss_flag-2.21202e-14*sf_flag+2.21202e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.21 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp+dlmisp)'
+LMAX       = 2.000001e-05        WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp+dwmisp)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp+toxmisp)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39886347+(dvthp+vthmisp)' WVTH0      = '-4.2769067e-010+dwvthp'
+K1         = 0.23752             K2         = '0.0042611111+dk2p' WK2        = '2.2300444e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 3.3905556e-005
+WCIT       = '-7.2177778e-013+dwcitp'
+VOFF       = -0.094192791        WVOFF      = '-5.7190684e-010+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018635556+du0p'  WU0        = '-1.6177778e-010+dwu0p'
+UA         = 1.7390889e-009      WUA        = -1.9522844e-016     UB         = 9.0724751e-019
+WUB        = 1.1973148e-026      UC         = 2.7868889e-011      WUC        = 2.6307556e-018
+VSAT       = '110000+dvsatp'     A0         = 4.9424518           WA0        = 1.8991262e-007
+AGS        = 0.96980191          WAGS       = -4.5218203e-009     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.025255333        WKETA      = 3.0449067e-009      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.0012224845+dpdiblc2p'
+WPDIBLC2   = 1.0666159e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0019168889
+LTVOFF     = 0                   WTVOFF     = -3.2604444e-011     PTVOFF     = 0
+KT1        = -0.18476667         WKT1       = -3.2106667e-009     KT1L       = 0
+KT2        = -0.046056667        WKT2       = 5.9733333e-010      UTE        = -2
+UA1        = -1.4863333e-009     WUA1       = 1.7994667e-016      UB1        = 1.9633333e-019
+WUB1       = -9.4826667e-026     UC1        = -8.8333333e-012     WUC1       = -6.6453333e-018
+PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'           PK2        = '0+dpk2p'
+LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'
+LU0        = '0+dlu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp+dlmisp)'
+LMAX       = '1.000249e-005-(dxlp+dlmisp)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39822143+(dvthp+vthmisp)' LVTH0      = '-6.3989092e-009+dlvthp'
+WVTH0      = '-2.7176737e-010+dwvthp'
+PVTH0      = '-1.5540252e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0031573454+dk2p' LK2        = '1.1000792e-008+dlk2p'
+WK2        = '2.3338199e-009+dwk2p'
+PK2        = '-1.0342889e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.0119082e-005
+LCIT       = '8.3743995e-010+dlcitp'
+WCIT       = '1.3836631e-012+dwcitp'
+PCIT       = '-2.0984087e-017+dpcitp'
+VOFF       = -0.093830612        LVOFF      = '-3.6096908e-009+dlvoffp'
+WVOFF      = '-5.3415624e-010+dwvoffp'
+PVOFF      = '-3.7624521e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018684482+du0p'  LU0        = '-4.8763196e-010+dlu0p'
+WU0        = '-1.7915269e-010+dwu0p'
+PU0        = '1.7316881e-016+dpu0p'
+UA         = 1.7479112e-009      LUA        = -8.7928367e-017     WUA        = -1.985671e-016
+PUA        = 3.3275053e-023      UB         = 9.0136967e-019      LUB        = 5.8582143e-026
+WUB        = 1.2026475e-026      PUB        = -5.3148705e-034     UC         = 2.5555018e-011
+LUC        = 2.3061424e-017      WUC        = 2.8587679e-018      PUC        = -2.2725076e-024
+VSAT       = '110000+dvsatp'     A0         = 5.1522506           LA0        = -2.0909813e-006
+WA0        = 1.9276147e-007      PA0        = -2.8393315e-014     AGS        = 0.94067619
+LAGS       = 2.9028438e-007      WAGS       = -6.94958e-009       PAGS       = 2.419651e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022063743        LKETA      = -3.1809303e-008
+WKETA      = 2.931943e-009       PKETA      = 1.1258637e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00073443994+dpdiblc2p'
+LPDIBLC2   = 4.8641453e-009      WPDIBLC2   = 1.1009784e-010      PPDIBLC2   = -3.4247737e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0019628202        LTVOFF     = -4.5777937e-010
+WTVOFF     = -3.7335767e-011     PTVOFF     = 4.71552e-017        KT1        = -0.18211747
+LKT1       = -2.6403487e-008     WKT1       = -3.4191656e-009     PKT1       = 2.0780258e-015
+KT1L       = 0                   KT2        = -0.045396993        LKT2       = -6.574706e-009
+WKT2       = 6.1203518e-010      PKT2       = -1.4652746e-016     UTE        = -2
+UA1        = -1.5686016e-009     LUA1       = 8.199353e-016       WUA1       = 1.8547991e-016
+PUA1       = -5.5147606e-023     UB1        = 4.3030993e-019      LUB1       = -2.3319512e-024
+WUB1       = -1.0714949e-025     PUB1       = 1.2281665e-031      UC1        = -8.5684136e-012
+LUC1       = -2.6403487e-018     WUC1       = -6.7816596e-018     PUC1       = 1.3587091e-024
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp+dlmisp)'
+LMAX       = '1.002493e-006-(dxlp+dlmisp)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40428089+(dvthp+vthmisp)' LVTH0      = '-5.4184208e-010+dlvthp'
+WVTH0      = '-1.3590142e-009+dwvthp'
+PVTH0      = '-5.0309352e-016+dpvthp'
+K1         = 0.23752             K2         = '0.013617963+dk2p'  LK2        = '8.8956963e-010+dlk2p'
+WK2        = '1.421435e-009+dwk2p'
+PK2        = '-1.5237854e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00066489035
+LCIT       = '1.4631255e-010+dlcitp'
+WCIT       = '-7.916586e-012+dwcitp'
+PCIT       = '-1.1994475e-017+dpcitp'
+VOFF       = -0.09086501         LVOFF      = '-6.476239e-009+dlvoffp'
+WVOFF      = '-7.89249e-010+dwvoffp'
+PVOFF      = '-1.296728e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018126194+du0p'  LU0        = '5.2008881e-011+dlu0p'
+WU0        = '-7.7758431e-013+dwu0p'
+PU0        = '7.5161222e-019+dpu0p'
+UA         = 1.7085045e-009      LUA        = -4.983793e-017      WUA        = -1.6031651e-016
+PUA        = -3.6979321e-024     UB         = 8.8465665e-019      LUB        = 7.4736926e-026
+WUB        = 3.6627113e-027      PUB        = 7.5529189e-033      UC         = 5.2502842e-011
+LUC        = -2.9863164e-018     WUC        = -5.6688818e-019     PUC        = 1.0387281e-024
+VSAT       = '110000+dvsatp'     A0         = 3.324562            LA0        = -3.2433938e-007
+WA0        = 2.4736821e-007      PA0        = -8.1176135e-014     AGS        = 0.63607723
+LAGS       = 5.8470942e-007      WAGS       = 8.3937444e-008      PAGS       = -6.3654797e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.039544464        LKETA      = -1.4912456e-008
+WKETA      = 2.7359386e-009      PKETA      = 1.3153214e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.63897871          LPCLM      = '3.4896282e-007+dlpclmp'
+WPCLM      = 1.5551686e-008      PPCLM      = '-1.5032244e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0048953557+dpdiblc2p'
+LPDIBLC2   = 8.4220833e-010      WPDIBLC2   = 2.5351106e-010      PPDIBLC2   = -1.7287081e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0014875213        LTVOFF     = 1.6441517e-012
+WTVOFF     = -5.4490261e-011     PTVOFF     = 6.3736716e-017      KT1        = -0.19632548
+LKT1       = -1.2670035e-008     WKT1       = -6.3236314e-009     PKT1       = 4.8854794e-015
+KT1L       = 0                   KT2        = -0.040190418        LKT2       = -1.1607376e-008
+WKT2       = -7.6191809e-010     PKT2       = 1.1815344e-015      UTE        = -1.9417853
+LUTE       = -5.6270254e-008     WUTE       = -3.0325788e-008     PUTE       = 2.9312876e-014
+UA1        = -7.5913757e-010     LUA1       = 3.7508134e-017      WUA1       = 1.0875301e-016
+PUA1       = 1.9016541e-023      UB1        = -1.8971739e-018     LUB1       = -8.2207586e-026
+WUB1       = -7.3043398e-027     PUB1       = 2.6306428e-032      UC1        = -8.4465824e-011
+LUC1       = 7.0722012e-017      WUC1       = -2.4678347e-018     PUC1       = -2.8110297e-024
+PRT        = 0
+AT         = '310768.56+datp'
+LAT        = '-0.11673477+dlatp'
+WAT        = '-0.0022549945+dwatp'
+PAT        = '2.1796754e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp+dlmisp)'
+LMAX       = '2.399996e-007-(dxlp+dlmisp)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42302095+(dvthp+vthmisp)' LVTH0      = '3.7702272e-009+dlvthp'
+WVTH0      = '-3.0077769e-009+dwvthp'
+PVTH0      = '-1.2371486e-016+dpvthp'
+K1         = 0.23752             K2         = '0.015925729+dk2p'  LK2        = '3.5855486e-010+dlk2p'
+WK2        = '3.9942964e-010+dwk2p'
+PK2        = '8.2783879e-017+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00087740207
+LCIT       = '9.7413814e-011+dlcitp'
+WCIT       = '-1.0680034e-010+dwcitp'
+PCIT       = '1.0758577e-017+dpcitp'
+VOFF       = -0.11205689         LVOFF      = '-1.6000077e-009+dlvoffp'
+WVOFF      = '-9.3837657e-010+dwvoffp'
+PVOFF      = '-9.5358696e-017+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018941031+du0p'  LU0        = '-1.3548435e-010+dlu0p'
+WU0        = '7.5141923e-011+dwu0p'
+PU0        = '-1.6717391e-017+dpu0p'
+UA         = 1.6454109e-009      LUA        = -3.5320138e-017     WUA        = -1.7827262e-016
+PUA        = 4.3375199e-025      UB         = 1.4480642e-018      LUB        = -5.4902581e-026
+WUB        = -1.9062694e-026     PUB        = 1.2782012e-032      UC         = 3.5249758e-011
+LUC        = 9.8360105e-019      WUC        = -5.2264908e-020     PUC        = 9.2031378e-025
+VSAT       = '114391.12+dvsatp'  LVSAT      = '-0.0010103917+dlvsatp'
+WVSAT      = '-0.00061475644+dwvsatp'
+PVSAT      = '1.4145484e-010+dpvsatp'
+A0         = 2.7585035           LA0        = -1.9408989e-007     WA0        = -2.576865e-007
+PA0        = 3.5036449e-014      AGS        = 4.8481565           LAGS       = -3.844858e-007
+WAGS       = -2.3851344e-007     PAGS       = 1.0540829e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.081442179        LKETA      = -5.2718337e-009     WKETA      = -1.7918112e-009
+PKETA      = 2.3571521e-015      DWG        = 0                   DWB        = 0
+PCLM       = 3.228392            LPCLM      = '-2.468586e-007+dlpclmp'
+WPCLM      = -1.490479e-007      PPCLM      = '2.2841957e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.013031169+dpdiblc2p'
+LPDIBLC2   = -1.0298341e-009     WPDIBLC2   = -1.0916698e-009     PPDIBLC2   = 1.3665395e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0016914353        LTVOFF     = -4.5276266e-011
+WTVOFF     = 3.2887816e-010      PTVOFF     = -2.4475974e-017     KT1        = -0.29006066
+LKT1       = 8.8983363e-009      WKT1       = 2.4409226e-008      PKT1       = -2.1861203e-015
+KT1L       = 0                   KT2        = -0.081513175        LKT2       = -2.0990506e-009
+WKT2       = 2.4765473e-009      PKT2       = 4.3636676e-016      UTE        = -2.4467233
+LUTE       = 5.9915465e-008      WUTE       = 8.290864e-008       PUTE       = 3.2577479e-015
+UA1        = -2.3362551e-010     LUA1       = -8.3411665e-017     WUA1       = -1.5381806e-017
+PUA1       = 4.7579837e-023      UB1        = -3.3796683e-018     LUB1       = 2.5891288e-025
+WUB1       = 3.4733611e-025      PUB1       = -5.5295984e-032     UC1        = 1.9960266e-010
+LUC1       = 5.358138e-018       WUC1       = -1.5615894e-017     PUC1       = 2.1432552e-025
+PRT        = 0
+AT         = '-253490.39+datp'
+LAT        = '0.013100647+dlatp'
+WAT        = '0.005820604+dwatp'
+PAT        = '3.2148828e-10+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp+dlmisp)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp+dwmisp)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp+toxmisp)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp+dlmisp)'        XW         = '2.0e-08+(dxwp+dwmisp)'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.34168801+(dvthp+vthmisp)' LVTH0      = '-4.2410674e-009+dlvthp'
+WVTH0      = '-5.1335978e-009+dwvthp'
+PVTH0      = '8.5678502e-017+dpvthp'
+K1         = 0.23752             K2         = '-9.6172764e-005+dk2p'
+LK2        = '1.9367122e-009+dlk2p'
+WK2        = '1.7159072e-009+dwk2p'
+PK2        = '-4.6889159e-017+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0031308002
+LCIT       = '4.9222174e-010+dlcitp'
+WCIT       = '2.3721565e-010+dwcitp'
+PCIT       = '-2.3126998e-017+dpcitp'
+VOFF       = -0.071895358        LVOFF      = '-5.555919e-009+dlvoffp'
+WVOFF      = '-2.4640438e-009+dwvoffp'
+PVOFF      = '5.4919529e-017+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.222609*ff_flag-0.288637*ss_flag+0.178087*sf_flag-0.178087*fs_flag'
+ETA0       = '0.18434054+deta0p' LETA0      = '-6.5037242e-010+dleta0p'
+WETA0      = '-1.3696174e-008+dweta0p'
+PETA0      = '2.0811918e-016+dpeta0p'
+ETAB       = 0.017265187         LETAB      = -4.8777932e-009     WETAB      = -3.058086e-008
+PETAB      = 1.5608938e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.016700842+du0p'  LU0        = '8.5174259e-011+dlu0p'
+WU0        = '2.6482083e-011+dwu0p'
+PU0        = '-1.1924396e-017+dpu0p'
+UA         = 2.1146812e-009      LUA        = -8.1543267e-017     WUA        = -1.6984654e-016
+PUA        = -3.9621729e-025     UB         = -6.9986034e-019     LUB        = 1.5666798e-025
+WUB        = 1.429087e-025       PUB        = -3.1721708e-033     UC         = -3.0466952e-010
+LUC        = 3.446565e-017       WUC        = 5.3547512e-017      PUC        = -4.3592643e-024
+VSAT       = '94172.59+dvsatp-13960.2*ff_flag-11168.2*sf_flag+11168.2*fs_flag'
+LVSAT      = '0.00098113326+dlvsatp+0.00137508*ff_flag+0.00110006*sf_flag-0.00110006*fs_flag'
+WVSAT      = '0.0022158375+dwvsatp+0.00338064*ff_flag+0.00270451*sf_flag-0.00270451*fs_flag'
+PVSAT      = '-1.3735866e-010+dpvsatp-3.32992e-10*ff_flag-2.66394e-10*sf_flag+2.66394e-10*fs_flag'
+A0         = -3.9507937          LA0        = 4.6677589e-007      WA0        = 6.1899155e-008
+PA0        = 3.557262e-015       AGS        = 3.8863976           LAGS       = -2.8975255e-007
+WAGS       = -7.8334526e-007     PAGS       = 6.4206764e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.29827237         LKETA      = 1.608594e-008       WKETA      = 2.3934619e-008
+PKETA      = -1.769013e-016      DWG        = 0                   DWB        = 0
+PCLM       = 0.10668465          LPCLM      = '6.0629576e-008+dlpclmp'
+WPCLM      = 1.5333598e-007      PPCLM      = '-6.9428557e-015+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00014056647+dpdiblc2p'
+LPDIBLC2   = 2.675818e-010       WPDIBLC2   = 6.7599931e-010      PPDIBLC2   = -3.7461452e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 4.9882714e-005      LTVOFF     = 1.1641666e-010
+WTVOFF     = 1.5434209e-010      PTVOFF     = -7.2841711e-018     KT1        = -0.1018881
+LKT1       = -9.6366611e-009     WKT1       = -9.5325297e-009     PKT1       = 1.1571426e-015
+KT1L       = 0
+KT2        = '-0.097480753-0.079233761'
+LKT2       = '-5.262442e-010+7.8045026e-09'
+WKT2       = '-6.1256082e-009+2.5354803e-08'
+PKT2       = '1.2836791e-015-2.4974408e-15'
+UTE        = -2.1874478
+LUTE       = 3.4376828e-008      WUTE       = 1.6246569e-007      PUTE       = -4.5786219e-015
+UA1        = -6.1936262e-009     LUA1       = 5.0364841e-016      WUA1       = 1.1264598e-015
+PUA1       = -6.4891559e-023     UB1        = 4.2688773e-018      LUB1       = -4.9446886e-025
+WUB1       = -8.0987802e-025     PUB1       = 5.8689608e-032      UC1        = 4.6642041e-010
+LUC1       = -2.092341e-017      WUC1       = -5.3162239e-017     PUC1       = 3.9126405e-024
+PRT        = 0
+AT         = '-88342.852+datp'
+LAT        = '-0.0031663846+dlatp'
+WAT        = '-0.0016912692+dwatp'
+PAT        = '1.0614078e-09+dpatp'
+NOIA       = 'noiapmac'
+NOIB       = 'noibpmac'
+NOIC       = 'noicpmac'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp-2.19269e-08*ff_flag+2.84306e-08*ss_flag-1.75416e-08*sf_flag+1.75416e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-1.69032e-08*ff_flag+3.80322e-08*ss_flag-1.35226e-08*sf_flag+1.35226e-08*fs_flag'
+PNFACTOR   = '0+dpnfactorp+1.66496e-15*ff_flag-3.74616e-15*ss_flag+1.33197e-15*sf_flag-1.33197e-15*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_mac
.ENDL MAC







.LIB MAC_hvt
**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT NMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_hvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.25e-008' xw='+2e-08+dxwn_hvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_hvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_hvt  temp2=parn2_hvt
+fac1='0.513264*temp1*sigma+0.858231*temp2*sigma'
+fac2='0.513264*temp1*sigma-0.858231*temp2*sigma'
.param  lef='l*scale-1e-09'
+       wef='w/nf*scale+2e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_hvt='(0.0065945219859-0.000546287615/(lef*1e6)+0.00003025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisn_hvt='0.00226307*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_hvt='-0.00226307*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_hvt='0.00226307*geo_fac*toxn_hvt*fac2*mismatchflag' 
.param tnoiax='4.491e05/(l*scale*1e6)+1.770e07'
.param rnoiax='0.0152/(l*scale*1e6)+0.4761'

.param fn_dice='noiseflagn_hvt_mc*par1fn_mc+noiseflagn_hvt_mc_mis*par2fn_hvt_mc'
.param arearatio='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((w*scale*l*scale*multi)/(7.5E-6*1E-6*1))**0.5)))'
.param noianmac_hvt='c1fn_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_hvt)*arearatio)'
.param noibnmac_hvt='c2fn_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_hvt)*arearatio)'
.param noicnmac_hvt='c3fn_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_hvt)*arearatio)'

.MODEL nch_hvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hvt+dlmisn_hvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48907152+(dvthn_hvt+vthmisn_hvt)'
+K1         = 0.48686             K2         = '-0.0095062275+dk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0006173+dcitn_hvt'
+VOFF       = '-0.13532+dvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.01078+du0n_hvt'  UA         = -2.072e-009         UB         = 1.982334e-018
+UC         = 3.335e-011          VSAT       = '85000+dvsatn_hvt'  A0         = '2.5+da0n_hvt'
+AGS        = 0.7622              A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.02183
+DWG        = 0                   DWB        = 0                   PCLM       = '0.05608+dpclmn_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '1.037e-005+dpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01371
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01205             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.01095
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.001653            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2369144
+KT1L       = 0                   KT2        = -0.08116            UTE        = -1
+UA1        = 7.57716e-010        UB1        = -4.33e-019          UC1        = 7.68e-011
+PRT        = 0                   AT         = '180000+datn_hvt'   NOIA       = 'noianmac_hvt'
+NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'               EM         = 2e+06
+EF         = 1.00                   JSS        = 1.99e-07            JSD        = 1.99e-07
+JSWS       = 5.1e-13             JSWD       = 5.1e-13             JSWGS      = 5.1e-13
+JSWGD      = 5.1e-13             NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 8.85                BVD        = 8.85
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1.02
+PBD        = 1.02                CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'
+MJS        = 0.5                 MJD        = 0.5                 PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'
+MJSWS      = 0.05                MJSWD      = 0.05                PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'
+MJSWGS     = 0.445               MJSWGD     = 0.445               TPB        = 0.0015
+TCJ        = 0.000773            TPBSW      = 0.0018              TCJSW      = 0.0005
+TPBSWG     = 0.00198             TCJSWG     = 0.00104             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010
+NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045
+TNJTSSWG   = 1                   VTSSWGS    = 24.384              VTSSWGD    = 24.384
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'
+WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'
+WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'
+WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '1e-005-(dxln_hvt+dlmisn_hvt)'   WMIN       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48903673+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '3.4673952e-010+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.009315043+dk2n_hvt'
+LK2        = '-1.9051743e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00059199273+dcitn_hvt'
+LCIT       = '2.5218974e-010+dlcitn_hvt'
+VOFF       = '-0.13344662+dvoffn_hvt'
+LVOFF      = '-1.8668452e-008+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010796085+du0n_hvt'
+LU0        = '-1.6029009e-010+dlu0n_hvt'
+UA         = -2.0930179e-009     LUA        = 2.0944571e-016      UB         = 2.0091892e-018
+LUB        = -2.6761545e-025     UC         = 3.094152e-011       LUC        = 2.4000769e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5647695+da0n_hvt'
+LA0        = '-6.4543475e-007+dla0n_hvt'
+AGS        = 0.73187417          LAGS       = 3.0220025e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.027071608         LKETA      = -5.2233197e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.044936222+dpclmn_hvt'
+LPCLM      = 1.1104897e-007      PDIBLC1    = 0                   PDIBLC2    = '-6.7292224e-005+dpdiblc2n_hvt'
+LPDIBLC2   = '7.739126e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.013682119
+LAIGBACC   = 2.7783615e-010      BIGBACC    = 0.005651            CIGBACC    = 0.17808
+NIGBACC    = 10                  AIGBINV    = 0.012070375         LAIGBINV   = -2.0303411e-010
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010974664         LAIGSD     = -2.4577813e-010
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016943924        LTVOFF     = -4.1247983e-010
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2306225
+LKT1       = -6.2699498e-008     KT1L       = 0                   KT2        = -0.079945037
+LKT2       = -1.2107245e-008     UTE        = -1                  UA1        = 7.5516683e-010
+LUA1       = 2.5402773e-017      UB1        = -4.1723657e-019     LUB1       = -1.5708429e-025
+UC1        = 7.4655316e-011      LUC1       = 2.1372012e-017      PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     WETA0      = '0+dweta0n_hvt'
+PETA0      = '0+dpeta0n_hvt'     WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48729786+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '2.0249303e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.0098625756+dk2n_hvt'
+LK2        = '-1.3767462e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00078875148+dcitn_hvt'
+LCIT       = '6.229629e-011+dlcitn_hvt'
+VOFF       = '-0.15153322+dvoffn_hvt'
+LVOFF      = '-1.21293e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010595978+du0n_hvt'
+LU0        = '3.2834652e-011+dlu0n_hvt'
+UA         = -1.9245583e-009     LUA        = 4.6864003e-017      UB         = 1.7876818e-018
+LUB        = -5.3836875e-026     UC         = 5.6805909e-011      LUC        = -9.6115981e-019
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.2604038+da0n_hvt'
+LA0        = '-3.5168897e-007+dla0n_hvt'
+AGS        = 0.71746344          LAGS       = 3.1610815e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.012457767        LKETA      = -1.4083081e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.1133964+dpclmn_hvt'
+LPCLM      = 4.4977503e-008      PDIBLC1    = 0                   PDIBLC2    = '0.00095871047+dpdiblc2n_hvt'
+LPDIBLC2   = '-2.1629081e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010704536
+LAIGSD     = 1.4924842e-011      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0013851482
+LTVOFF     = -1.1402579e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.28148673         LKT1       = -1.3610023e-008     KT1L       = 0
+KT2        = -0.095734437        LKT2       = 3.1312318e-009      UTE        = -1
+UA1        = 7.9493834e-010      LUA1       = -1.298103e-017      UB1        = -5.6793775e-019
+LUB1       = -1.1641377e-026     UC1        = 9.0243083e-011      LUC1       = 6.3281329e-018
+PRT        = 0                   AT         = '153475+datn_hvt'   LAT        = -0.02265591
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      WK2        = '0+dwk2n_hvt'
+PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'
+PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '2.4e-007-(dxln_hvt+dlmisn_hvt)' WMIN       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.5104748+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-3.2590414e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.0088279616+dk2n_hvt'
+LK2        = '-1.6126217e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049761697+dcitn_hvt'
+LCIT       = '1.286703e-010+dlcitn_hvt'
+VOFF       = '-0.14489542+dvoffn_hvt'
+LVOFF      = '-2.7262414e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787235+deta0n_hvt'
+LETA0      = '-5.3516274e-014+dleta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010674795+du0n_hvt'
+LU0        = '1.4865632e-011+dlu0n_hvt'
+UA         = -1.7371124e-009     LUA        = 4.1293422e-018      UB         = 1.5411949e-018
+LUB        = 2.358193e-027       UC         = 4.809812e-011       LUC        = 1.0240769e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.3726002+da0n_hvt'
+LA0        = '-1.4928398e-007+dla0n_hvt'
+AGS        = 2.7589451           LAGS       = -1.4931701e-007     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.045344311        LKETA      = -6.5854749e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.012856326+dpclmn_hvt'
+LPCLM      = 6.7899033e-008      PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2n_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.01074102
+LAIGSD     = 6.6069475e-012      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0014691618
+LTVOFF     = -1.3317954e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.29118213         LKT1       = -1.1399627e-008     KT1L       = 0
+KT2        = -0.082470923        LKT2       = 1.073629e-010       UTE        = -1
+UA1        = 5.5687579e-010      LUA1       = 4.1293422e-017      UB1        = -4.7482513e-019
+LUB1       = -3.2869564e-026     UC1        = 1.4400944e-010      LUC1       = -5.9297353e-018
+PRT        = 0                   AT         = '63373.56+datn_hvt' LAT        = -0.0021142232
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      WK2        = '0+dwk2n_hvt'
+PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     WU0        = '0+dwu0n_hvt'
+PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'
+PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'
+WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46352798+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.2375625e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.010711104+dk2n_hvt'
+LK2        = '-1.4322528e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.4878744e-005+dcitn_hvt'
+LCIT       = '1.7107612e-010+dlcitn_hvt'
+VOFF       = '-0.13095522+dvoffn_hvt'
+LVOFF      = '-4.0614453e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.0030442456+deta0n_hvt'
+LETA0      = '5.4433111e-009+dleta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010717766+du0n_hvt'
+LU0        = '1.0749846e-011+dlu0n_hvt'
+UA         = -1.8778919e-009     LUA        = 1.7613311e-017      UB         = 1.6074375e-018
+LUB        = -3.9865789e-027     UC         = 7.3636933e-011      LUC        = -1.4220511e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '3.1457415+da0n_hvt'
+LA0        = '-3.1911686e-007+dla0n_hvt'
+AGS        = -1.8335201          LAGS       = 2.9055298e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.21515855         LKETA      = 9.6794686e-009      DWG        = 0
+DWB        = 0                   PCLM       = '0.70882167+dpclmn_hvt'
+LPCLM      = 1.2389152e-009      PDIBLC1    = 0
+PDIBLC2    = '-0.00060334045+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+Ppdiblc2 = '0+0.0*ff_flag_hvt'
+Wpdiblc2 = '0+0.0*ff_flag_hvt'
+LPDIBLC2   = '1.5356923e-010+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.0107619
+LAIGSD     = 4.6070769e-012      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = -0.001042516
+LTVOFF     = 1.0739096e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.49186518         LKT1       = 7.8219566e-009      KT1L       = 0
+KT2        = -0.097046703        LKT2       = 1.5034428e-009      UTE        = -1
+UA1        = 2.1520252e-009      LUA1       = -1.1149126e-016     UB1        = -1.7094573e-018
+LUB1       = 8.5384492e-026      UC1        = 8.883403e-011       LUC1       = -6.4499077e-019
+PRT        = 0                   AT         = '54607.726+datn_hvt'
+LAT        = -0.0012746246       NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'
+PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hvt+dlmisn_hvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-005-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48720312+(dvthn_hvt+vthmisn_hvt)'
+WVTH0      = '1.872136e-008+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.0090150096+dk2n_hvt'
+WK2        = '-4.9220037e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00067671727+dcitn_hvt'
+WCIT       = '-5.9536101e-010+dwcitn_hvt'
+VOFF       = '-0.13380079+dvoffn_hvt'
+WVOFF      = '-1.5222491e-008+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010791333+du0n_hvt'
+WU0        = '-1.1356e-010+dwu0n_hvt'
+UA         = -2.0880933e-009     WUA        = 1.612552e-016       UB         = 1.9952467e-018
+WUB        = -1.2938586e-025     UC         = 3.5864867e-011      WUC        = -2.5198964e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5020782+da0n_hvt'
+WA0        = '-2.0823565e-008+dwa0n_hvt'
+AGS        = 0.76721602          WAGS       = -5.0260498e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.021492267         WKETA      = 3.384088e-009       DWG        = 0
+DWB        = 0                   PCLM       = '0.050807733+dpclmn_hvt'
+WPCLM      = 5.2828112e-008      PDIBLC1    = 0                   PDIBLC2    = '-9.9880667e-006+dpdiblc2n_hvt'
+WPDIBLC2   = 2.0398783e-010      PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = 6.5276e-009
+BGIDL      = 1.7187e+009         CGIDL      = 64.8                EGIDL      = -0.075922
+AIGBACC    = 0.013680533         WAIGBACC   = 2.95256e-010        BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.012071533
+WAIGBINV   = -2.15764e-010       BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010981733
+WAIGSD     = -3.17968e-010       BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0018936067
+LTVOFF     = 0                   WTVOFF     = -2.4108788e-009     PTVOFF     = 0
+KT1        = -0.22891783         WKT1       = -8.0125665e-008     KT1L       = 0
+KT2        = -0.082194733        WKT2       = 1.0368028e-008      UTE        = -1
+UA1        = 7.4419715e-010      WUA1       = 1.3545891e-016      UB1        = -4.4240667e-019
+WUB1       = 9.42548e-026        UC1        = 8.1197333e-011      WUC1       = -4.406128e-017
+PRT        = 0                   AT         = '180000+datn_hvt'   NOIA       = 'noianmac_hvt'
+NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'               EM         = 2e+06
+EF         = 1.00                   JSS        = 1.99e-07            JSD        = 1.99e-07
+JSWS       = 5.1e-13             JSWD       = 5.1e-13             JSWGS      = 5.1e-13
+JSWGD      = 5.1e-13             NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 8.85                BVD        = 8.85
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1.02
+PBD        = 1.02                CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'
+MJS        = 0.5                 MJD        = 0.5                 PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'
+MJSWS      = 0.05                MJSWD      = 0.05                PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'
+MJSWGS     = 0.445               MJSWGD     = 0.445               TPB        = 0.0015
+TCJ        = 0.000773            TPBSW      = 0.0018              TCJSW      = 0.0005
+TPBSWG     = 0.00198             TCJSWG     = 0.00104             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010
+NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045
+TNJTSSWG   = 1                   VTSSWGS    = 24.384              VTSSWGD    = 24.384
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'
+PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'
+LCIT       = '0+dlcitn_hvt'      PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'
+WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'
+PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '1e-005-(dxln_hvt+dlmisn_hvt)'   WMIN       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-005-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4870433+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.5926236e-009+dlvthn_hvt'
+WVTH0      = '1.9974106e-008+dwvthn_hvt'
+PVTH0      = '-1.2483759e-014+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0088515496+dk2n_hvt'
+LK2        = '-1.6288964e-009+dlk2n_hvt'
+WK2        = '-4.644204e-009+dwk2n_hvt'
+PK2        = '-2.7683047e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00065956444+dcitn_hvt'
+LCIT       = '1.7092986e-010+dlcitn_hvt'
+WCIT       = '-6.7706849e-010+dwcitn_hvt'
+PCIT       = '8.1422399e-016+dpcitn_hvt'
+VOFF       = '-0.13192345+dvoffn_hvt'
+LVOFF      = '-1.8707891e-008+dlvoffn_hvt'
+WVOFF      = '-1.5262147e-008+dwvoffn_hvt'
+PVOFF      = '3.9517719e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010809241+du0n_hvt'
+LU0        = '-1.784563e-010+dlu0n_hvt'
+WU0        = '-1.3182627e-010+dwu0n_hvt'
+PU0        = '1.8202542e-016+dpu0n_hvt'
+UA         = -2.1093908e-009     LUA        = 2.122312e-016       WUA        = 1.6405603e-016
+PUA        = -2.7910565e-023     UB         = 2.0225716e-018      LUB        = -2.7229571e-025
+WUB        = -1.3409191e-025     PUB        = 4.6896278e-032      UC         = 3.3104478e-011
+LUC        = 2.7507574e-017      WUC        = -2.1672843e-017     PUC        = -3.5138188e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5666992+da0n_hvt'
+LA0        = '-6.4395506e-007+dla0n_hvt'
+WA0        = '-1.9335724e-008+dwa0n_hvt'
+PA0        = '-1.4826505e-014+dpa0n_hvt'
+AGS        = 0.73609148          LAGS       = 3.1015948e-007      WAGS       = -4.2257426e-008
+PAGS       = -7.975149e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.027044741
+LKETA      = -5.533102e-008      WKETA      = 2.6920129e-010      PKETA      = 3.1040189e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.039694095+dpclmn_hvt'
+LPCLM      = 1.1074863e-007      WPCLM      = 5.252611e-008       PPCLM      = 3.009487e-015
+PDIBLC1    = 0                   PDIBLC2    = '-8.6607909e-005+dpdiblc2n_hvt'
+LPDIBLC2   = '7.6352516e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.9354317e-010      PPDIBLC2   = 1.0408214e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.013649493         LAIGBACC   = 3.0932425e-010
+WAIGBACC   = 3.2691754e-010      PAIGBACC   = -3.1551073e-016     BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.012094217
+LAIGBINV   = -2.2604464e-010     WAIGBINV   = -2.3890128e-010     PAIGBINV   = 2.3056554e-016
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.011008828         LAIGSD     = -2.6999975e-010
+WAIGSD     = -3.4232303e-010     PAIGSD     = 2.4270056e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0019525118        LTVOFF     = -5.8699655e-010     WTVOFF     = -2.5863568e-009
+PTVOFF     = 1.7486576e-015      KT1        = -0.22197516         LKT1       = -6.9184447e-008
+WKT1       = -8.6646335e-008     PKT1       = 6.4979193e-014      KT1L       = 0
+KT2        = -0.080921921        LKT2       = -1.2683719e-008     WKT2       = 9.7883783e-009
+PKT2       = 5.7762734e-015      UTE        = -1                  UA1        = 7.399493e-010
+LUA1       = 4.233029e-017       WUA1       = 1.5247967e-016      PUA1       = -1.6961372e-022
+UB1        = -4.2755473e-019     LUB1       = -1.4800118e-025     WUB1       = 1.0338794e-025
+PUB1       = -9.1012712e-032     UC1        = 7.9141368e-011      LUC1       = 2.0487923e-017
+WUC1       = -4.4950239e-017     PUC1       = 8.8585706e-024      PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4867008+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.9231706e-009+dlvthn_hvt'
+WVTH0      = '5.9825209e-009+dwvthn_hvt'
+PVTH0      = '1.0196325e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0092646587+dk2n_hvt'
+LK2        = '-1.2302016e-009+dlk2n_hvt'
+WK2        = '-5.9911282e-009+dwk2n_hvt'
+PK2        = '-1.4683773e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076480999+dcitn_hvt'
+LCIT       = '6.9356536e-011+dlcitn_hvt'
+WCIT       = '2.3989382e-010+dwcitn_hvt'
+PCIT       = '-7.0743667e-017+dpcitn_hvt'
+VOFF       = '-0.15028908+dvoffn_hvt'
+LVOFF      = '-9.8307814e-010+dlvoffn_hvt'
+WVOFF      = '-1.2466302e-008+dwvoffn_hvt'
+PVOFF      = '-2.3031152e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010588559+du0n_hvt'
+LU0        = '3.4526134e-011+dlu0n_hvt'
+WU0        = '7.4341403e-011+dwu0n_hvt'
+PU0        = '-1.694865e-017+dpu0n_hvt'
+UA         = -1.9374491e-009     LUA        = 4.62889e-017        WUA        = 1.2916552e-016
+PUA        = 5.7625411e-024      UB         = 1.7937358e-018      LUB        = -5.1444368e-026
+WUB        = -6.0660547e-026     PUB        = -2.3972914e-032     UC         = 6.1830105e-011
+LUC        = -2.1575749e-019     WUC        = -5.0342439e-017     PUC        = -7.4689313e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.2665477+da0n_hvt'
+LA0        = '-3.5427643e-007+dla0n_hvt'
+WA0        = '-6.1561936e-008+dwa0n_hvt'
+PA0        = '2.5926351e-014+dpa0n_hvt'
+AGS        = 0.68632144          LAGS       = 3.5819293e-007      WAGS       = 3.1204285e-007
+PAGS       = -4.2168952e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.014745192
+LKETA      = -1.4999221e-008     WKETA      = 2.2919993e-008      PKETA      = 9.179728e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.10751264+dpclmn_hvt'
+LPCLM      = 4.5296405e-008      WPCLM      = 5.8955317e-008      PPCLM      = -3.1953928e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.00091932882+dpdiblc2n_hvt'
+LPDIBLC2   = '-2.0731242e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 3.9460417e-010      PPDIBLC2   = -8.9963436e-017     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010711499         LAIGSD     = 1.695462e-011
+WAIGSD     = -6.9774317e-011     PAIGSD     = -2.0338381e-017     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0014648952        LTVOFF     = -1.1639387e-010     WTVOFF     = -7.9906516e-010
+PTVOFF     = 2.3728111e-017      KT1        = -0.27891208         LKT1       = -1.4234166e-008
+WKT1       = -2.5797936e-008     PKT1       = 6.2539164e-015      KT1L       = 0
+KT2        = -0.097891213        LKT2       = 3.6934805e-009      WKT2       = 2.1610894e-008
+PKT2       = -5.6337314e-015     UTE        = -1                  UA1        = 7.9464426e-010
+LUA1       = -1.0456257e-017     WUA1       = 2.9466796e-018      PUA1       = -2.5298234e-023
+UB1        = -5.6747736e-019     LUB1       = -1.2960733e-026     WUB1       = -4.6130942e-027
+PUB1       = 1.3219947e-032      UC1        = 9.416361e-011       LUC1       = 5.9898365e-018
+WUC1       = -3.9283681e-017     PUC1       = 3.3897301e-024      PRT        = 0
+AT         = '153257.67+datn_hvt'
+LAT        = -0.022446166        WAT        = 0.002177614         PAT        = -2.1016327e-009
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '2.4e-007-(dxln_hvt+dlmisn_hvt)' WMIN       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-005-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51029903+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-3.4568481e-009+dlvthn_hvt'
+WVTH0      = '1.7612109e-009+dwvthn_hvt'
+PVTH0      = '1.9820236e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0068379101+dk2n_hvt'
+LK2        = '-1.7834614e-009+dlk2n_hvt'
+WK2        = '-1.9940316e-008+dwk2n_hvt'
+PK2        = '1.7118143e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049520102+dcitn_hvt'
+LCIT       = '1.3082307e-010+dlcitn_hvt'
+WCIT       = '2.420774e-011+dwcitn_hvt'
+PCIT       = '-2.1570692e-017+dpcitn_hvt'
+VOFF       = '-0.14181909+dvoffn_hvt'
+LVOFF      = '-2.9141003e-009+dlvoffn_hvt'
+WVOFF      = '-3.0824876e-008+dwvoffn_hvt'
+PVOFF      = '1.882346e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322285+deta0n_hvt'
+LETA0      = '-5.43961e-014+dleta0n_hvt'
+WETA0      = '-5.3612063e-009+dweta0n_hvt'
+PETA0      = '8.8158482e-021+dpeta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010674795+du0n_hvt'
+LU0        = '1.4865632e-011+dlu0n_hvt'
+UA         = -1.7554817e-009     LUA        = 4.8032508e-018      WUA        = 1.8406019e-016
+PUA        = -6.7525646e-024     UB         = 1.5597693e-018      LUB        = 1.8962419e-027
+WUB        = -1.8611524e-025     PUB        = 4.6287498e-033      UC         = 6.0350359e-011
+LUC        = 1.2160087e-019      WUC        = -1.2276744e-016     PUC        = 9.0428094e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.405171+da0n_hvt' LA0        = '-1.5789634e-007+dla0n_hvt'
+WA0        = '-3.2635924e-007+dwa0n_hvt'
+PA0        = '8.62959e-014+dpa0n_hvt'
+AGS        = 3.0235749           LAGS       = -1.7466347e-007     WAGS       = -2.6515905e-006
+PAGS       = 2.5397146e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.053375301
+LKETA      = -6.1921743e-009     WKETA      = 8.0470522e-008      PKETA      = -3.9408717e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.012039198+dpclmn_hvt'
+LPCLM      = 6.7062822e-008      WPCLM      = 8.1876225e-009      PPCLM      = 8.3788294e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2n_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010745391
+LAIGSD     = 9.2277033e-012      WAIGSD     = -4.3800595e-011     PAIGSD     = -2.6259973e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016164685        LTVOFF     = -1.5095014e-010
+WTVOFF     = -1.476013e-009      PTVOFF     = 1.7806138e-016      KT1        = -0.2886127
+LKT1       = -1.2022581e-008     WKT1       = -2.5745648e-008     PKT1       = 6.2419957e-015
+KT1L       = 0                   KT2        = -0.081503825        LKT2       = -4.2581776e-011
+WKT2       = -9.6903242e-009     PKT2       = 1.5024456e-015      UTE        = -1
+UA1        = 5.5431357e-010      LUA1       = 4.4335296e-017      WUA1       = 2.5673461e-017
+PUA1       = -3.0479576e-023     UB1        = -4.7522522e-019     LUB1       = -3.3992745e-026
+WUB1       = 4.0088836e-027      PUB1       = 1.1254274e-032      UC1        = 1.4667601e-010
+LUC1       = -5.9821505e-018     WUC1       = -2.6719068e-017     PUC1       = 5.2519947e-025
+PRT        = 0                   AT         = '63846.319+datn_hvt'
+LAT        = -0.0020618081       WAT        = -0.0047370519       PAT        = -5.2519947e-010
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-005-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46122686+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.2433235e-009+dlvthn_hvt'
+WVTH0      = '2.3057213e-008+dwvthn_hvt'
+PVTH0      = '-5.7724504e-017+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0089135286+dk2n_hvt'
+LK2        = '-1.584657e-009+dlk2n_hvt'
+WK2        = '-1.8011708e-008+dwk2n_hvt'
+PK2        = '1.5270907e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.2775734e-005+dcitn_hvt'
+LCIT       = '1.7415672e-010+dlcitn_hvt'
+WCIT       = '1.2127215e-010+dwcitn_hvt'
+PCIT       = '-3.08676e-017+dpcitn_hvt'
+VOFF       = '-0.12918363+dvoffn_hvt'
+LVOFF      = '-4.1243344e-009+dlvoffn_hvt'
+WVOFF      = '-1.7751302e-008+dwvoffn_hvt'
+PVOFF      = '6.3014862e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.0038339129+deta0n_hvt'
+LETA0      = '5.5701928e-009+dleta0n_hvt'
+WETA0      = '7.9124665e-009+dweta0n_hvt'
+PETA0      = '-1.2713542e-015+dpeta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010717766+du0n_hvt'
+LU0        = '1.0749846e-011+dlu0n_hvt'
+UA         = -1.8691811e-009     LUA        = 1.5693471e-017      WUA        = -8.7281901e-017
+PUA        = 1.9236798e-023      UB         = 1.5879251e-018      LUB        = -8.0054308e-028
+WUB        = 1.9551478e-025      PUB        = -3.1924079e-032     UC         = 7.2032623e-011
+LUC        = -9.9733571e-019     WUC        = 1.6075185e-017      PUC        = -4.255648e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '3.1625332+da0n_hvt'
+LA0        = '-3.262179e-007+dla0n_hvt'
+WA0        = '-1.6825379e-007+dwa0n_hvt'
+PA0        = '7.1152433e-014+dpa0n_hvt'
+AGS        = -1.0966783          LAGS       = 2.1997769e-007      WAGS       = -7.3831551e-006
+PAGS       = 7.071645e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.22825247
+LKETA      = 1.05577e-008        WKETA      = 1.3120105e-007      PKETA      = -8.7998818e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.71125481+dpclmn_hvt'
+LPCLM      = 9.1391598e-011      WPCLM      = -2.438004e-008      PPCLM      = 1.1498186e-014
+PDIBLC1    = 0
+PDIBLC2    = '-0.00078408711+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '1.7088129e-010+dlpdiblc2n_hvt+3.07143e-10*ff_flag_hvt'
+WPDIBLC2   = '1.8110816e-009-4.5e-15*ff_flag_hvt'
+PPDIBLC2   = '-1.7346684e-016-4.2e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 8.9756956e-009      LAGIDL     = -2.3448056e-016     WAGIDL     = -2.4529918e-014
+PAGIDL     = 2.3494952e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010802719         LAIGSD     = 3.7368513e-012
+WAIGSD     = -4.0900567e-010     PAIGSD     = 8.7196609e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0011725623       LTVOFF     = 1.1618546e-010      WTVOFF     = 1.3030646e-009
+PTVOFF     = -8.8120893e-017     KT1        = -0.50365453         LKT1       = 8.574298e-009
+WKT1       = 1.1812929e-007      PKT1       = -7.5384608e-015     KT1L       = 0
+KT2        = -0.0972308          LKT2       = 1.4637605e-009      WKT2       = 1.8446502e-009
+PKT2       = 3.9761654e-016      UTE        = -1                  UA1        = 2.2638308e-009
+LUA1       = -1.1940363e-016     WUA1       = -1.1202924e-015     PUA1       = 7.9281947e-023
+UB1        = -1.7844563e-018     LUB1       = 9.1406454e-026      WUB1       = 7.5148988e-025
+PUB1       = -6.0340054e-032     UC1        = 9.2788654e-011      LUC1       = -8.2077635e-019
+WUC1       = -3.9625329e-017     PUC1       = 1.7613715e-024      PRT        = 0
+AT         = '56281.889+datn_hvt'
+LAT        = -0.0013372809       WAT        = -0.016775112        PAT        = 6.2781559e-010
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hvt+dlmisn_hvt)'
+LMAX       = 2.001e-05           WMIN       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-006-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50870165+(dvthn_hvt+vthmisn_hvt)'
+WVTH0      = '-3.2071391e-009+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.013455713+dk2n_hvt'
+WK2        = '-3.924861e-010+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002187195+dcitn_hvt'
+WCIT       = '-1.2820329e-010+dwcitn_hvt'
+VOFF       = '-0.14654054+dvoffn_hvt'
+WVOFF      = '-2.2279452e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.01255705+du0n_hvt'
+WU0        = '-1.914591e-009+dwu0n_hvt'
+UA         = -1.8649e-009        WUA        = -6.6402e-017        UB         = 1.8935558e-018
+WUB        = -2.5661085e-026     UC         = 2.8458e-011         WUC        = -1.764396e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.3943405+da0n_hvt'
+WA0        = '8.9068892e-008+dwa0n_hvt'
+AGS        = 0.7006446           WAGS       = 1.7642347e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.028716            WKETA      = -3.98412e-009       DWG        = 0
+DWB        = 0                   PCLM       = '0.12089+dpclmn_hvt'
+WPCLM      = -1.86558e-008       PDIBLC1    = 0                   PDIBLC2    = '0.0001745+dpdiblc2n_hvt'
+WPDIBLC2   = 1.581e-011          PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = -3.50462e-009
+WAGIDL     = 1.0232864e-014      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010732            WAIGSD     = -6.324e-011
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -0.0006746          LTVOFF     = 0
+WTVOFF     = 2.08692e-010        PTVOFF     = 0                   KT1        = -0.33479425
+WKT1       = 2.7868287e-008      KT1L       = 0                   KT2        = -0.0657215
+WKT2       = -6.43467e-009       UTE        = -1                  UA1        = 9.824e-010
+WUA1       = -1.07508e-016       UB1        = -1.95e-019          WUB1       = -1.581e-025
+UC1        = 4.699e-011          WUC1       = -9.1698e-018        PRT        = 0
+AT         = '180000+datn_hvt'   NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LU0        = '0+dlu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'
+PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '1e-005-(dxln_hvt+dlmisn_hvt)'   WMIN       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-006-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.5110559+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-2.3460394e-008+dlvthn_hvt'
+WVTH0      = '-4.5187473e-009+dwvthn_hvt'
+PVTH0      = '1.3070319e-014+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.014045764+dk2n_hvt'
+LK2        = '5.8799205e-009+dlk2n_hvt'
+WK2        = '6.5389451e-010+dwk2n_hvt'
+PK2        = '-1.0427298e-014+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-2.4513613e-005+dcitn_hvt'
+LCIT       = '2.4238447e-009+dlcitn_hvt'
+WCIT       = '2.069112e-011+dwcitn_hvt'
+PCIT       = '-1.4837492e-015+dpcitn_hvt'
+VOFF       = '-0.14564436+dvoffn_hvt'
+LVOFF      = '-8.9305867e-009+dlvoffn_hvt'
+WVOFF      = '-1.2668245e-009+dwvoffn_hvt'
+PVOFF      = '-9.5776732e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.012656944+du0n_hvt'
+LU0        = '-9.9545487e-010+dlu0n_hvt'
+WU0        = '-2.0164829e-009+dwu0n_hvt'
+PU0        = '1.015364e-015+dpu0n_hvt'
+UA         = -1.8756395e-009     LUA        = 1.0702035e-016      WUA        = -7.4370252e-017
+PUA        = 7.9404504e-023      UB         = 1.9143814e-018      LUB        = -2.0752927e-025
+WUB        = -2.3737825e-026     PUB        = -1.9165493e-032     UC         = 2.643967e-011
+LUC        = 2.011288e-017       WUC        = -1.4874738e-017     PUC        = -2.7595599e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4989486+da0n_hvt'
+LA0        = '-1.0424316e-006+dla0n_hvt'
+WA0        = '4.9769824e-008+dwa0n_hvt'
+PA0        = '3.9161953e-013+dpa0n_hvt'
+AGS        = 0.69822263          LAGS       = 2.4135222e-008      WAGS       = -3.6312008e-009
+PAGS       = 2.1199325e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.035331927
+LKETA      = -6.5928435e-008     WKETA      = -8.1837277e-009     PKETA      = 4.1849552e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.10163503+dpclmn_hvt'
+LPCLM      = 1.9187792e-007      WPCLM      = -1.0653641e-008     PPCLM      = -7.9742395e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.00055802311+dpdiblc2n_hvt'
+LPDIBLC2   = '-3.82185e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = -4.6398047e-010     PPDIBLC2   = 4.7811648e-015      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -5.3329631e-009     LAGIDL     = 1.821964e-014       WAGIDL     = 1.2097774e-014
+PAGIDL     = -1.8584033e-020     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010673718         LAIGSD     = 5.8078442e-010
+WAIGSD     = -5.1121097e-013     PAIGSD     = -6.2509928e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0008685116       LTVOFF     = 1.9323504e-009      WTVOFF     = 2.9108711e-010
+PTVOFF     = -8.2107636e-016     KT1        = -0.33583509         LKT1       = 1.0372115e-008
+WKT1       = 2.9490798e-008      PKT1       = -1.61685e-014       KT1L       = 0
+KT2        = -0.063489474        LKT2       = -2.2242387e-008     WKT2       = -7.9927175e-009
+PKT2       = 1.5526115e-014      UTE        = -1                  UA1        = 1.0008468e-009
+LUA1       = -1.8382409e-016     WUA1       = -1.1363576e-016     PUA1       = 6.1063753e-023
+UB1        = -1.5440649e-019     LUB1       = -4.0451875e-025     WUB1       = -1.7522326e-025
+PUB1       = 1.7063521e-031      UC1        = 4.2151057e-011      LUC1       = 4.8220601e-017
+WUC1       = -7.2201214e-018     PUC1       = -1.9428762e-023     PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48558584+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.1209657e-009+dlvthn_hvt'
+WVTH0      = '7.119782e-009+dwvthn_hvt'
+PVTH0      = '1.8378815e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0053868824+dk2n_hvt'
+LK2        = '-2.4768353e-009+dlk2n_hvt'
+WK2        = '-9.94646e-009+dwk2n_hvt'
+PK2        = '-1.9681093e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.002506147+dcitn_hvt'
+LCIT       = '-1.8516057e-011+dlcitn_hvt'
+WCIT       = '-1.5362699e-009+dwcitn_hvt'
+PCIT       = '1.8886378e-017+dpcitn_hvt'
+VOFF       = '-0.15441346+dvoffn_hvt'
+LVOFF      = '-4.6745788e-010+dlvoffn_hvt'
+WVOFF      = '-8.2594361e-009+dwvoffn_hvt'
+PVOFF      = '-2.8290478e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011582973+du0n_hvt'
+LU0        = '4.1043315e-011+dlu0n_hvt'
+WU0        = '-9.3996074e-010+dwu0n_hvt'
+PU0        = '-2.3596175e-017+dpu0n_hvt'
+UA         = -1.7768587e-009     LUA        = 1.1686151e-017      WUA        = -3.463671e-017
+PUA        = 4.1057344e-023      UB         = 1.7305426e-018      LUB        = -3.0105021e-026
+WUB        = 3.7964552e-027      PUB        = -4.5739047e-032     UC         = 5.9157679e-011
+LUC        = -1.1463532e-017     WUC        = -4.7616564e-017     PUC        = 4.003799e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.6053222+da0n_hvt'
+LA0        = '-1.7998555e-007+dla0n_hvt'
+WA0        = '6.1288803e-007+dwa0n_hvt'
+PA0        = '-1.5185035e-013+dpa0n_hvt'
+AGS        = 1.325703            LAGS       = -5.8145107e-007     WAGS       = -3.401263e-007
+PAGS       = 5.3674736e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.033557198
+LKETA      = 5.5701002e-010      WKETA      = 4.210824e-008       PKETA      = -6.6876279e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.29773631+dpclmn_hvt'
+LPCLM      = 2.6190056e-009      WPCLM      = -1.3507283e-007     PPCLM      = 4.0335554e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.003503292+dpdiblc2n_hvt'
+LPDIBLC2   = '9.7757714e-011+dlpdiblc2n_hvt'
+WPDIBLC2   = 4.9056774e-009      PPDIBLC2   = -4.0113497e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.1215736e-008      LAGIDL     = -7.4027216e-015     WAGIDL     = -1.4981898e-014
+PAGIDL     = 7.550776e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.011537467         LAIGSD     = -2.5282682e-010
+WAIGSD     = -9.1226199e-010     PAIGSD     = 2.5483869e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0013812082        LTVOFF     = -2.3887209e-010     WTVOFF     = -7.1370433e-010
+PTVOFF     = 1.486559e-016       KT1        = -0.30478929         LKT1       = -1.9590434e-008
+WKT1       = 5.9681959e-010      PKT1       = 1.1717309e-014      KT1L       = 0
+KT2        = -0.083000523        LKT2       = -3.4121173e-009     WKT2       = 6.4223907e-009
+PKT2       = 1.6139784e-015      UTE        = -1                  UA1        = 7.6350827e-010
+LUA1       = 4.5233196e-017      WUA1       = 3.4705392e-017      PUA1       = -8.2101475e-023
+UB1        = -4.8486151e-019     LUB1       = -8.5593968e-026     WUB1       = -8.8881256e-026
+PUB1       = 8.7305847e-032      UC1        = 8.4574546e-011      LUC1       = 7.2773529e-018
+WUC1       = -2.9502835e-017     PUC1       = 2.0764634e-024      PRT        = 0
+AT         = '156495.2+datn_hvt' LAT        = -0.025570732        WAT        = -0.0011246659
+PAT        = 1.0854241e-009      NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '2.4e-007-(dxln_hvt+dlmisn_hvt)' WMIN       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-006-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48556798+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '1.1250376e-009+dlvthn_hvt'
+WVTH0      = '2.6986884e-008+dwvthn_hvt'
+PVTH0      = '-2.6914998e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.014789467+dk2n_hvt'
+LK2        = '-3.3319642e-010+dlk2n_hvt'
+WK2        = '-1.1829728e-008+dwk2n_hvt'
+PK2        = '2.3254395e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028841387+dcitn_hvt'
+LCIT       = '-1.0469212e-010+dlcitn_hvt'
+WCIT       = '-2.4125087e-009+dwcitn_hvt'
+PCIT       = '2.186548e-016+dpcitn_hvt'
+VOFF       = '-0.13884306+dvoffn_hvt'
+LVOFF      = '-4.0172593e-009+dlvoffn_hvt'
+WVOFF      = '-3.3860426e-008+dwvoffn_hvt'
+PVOFF      = '3.0075683e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.013614777+deta0n_hvt'
+LETA0      = '-8.5871322e-014+dleta0n_hvt'
+WETA0      = '3.6160453e-008+dweta0n_hvt'
+PETA0      = '4.0920575e-020+dpeta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011933619+du0n_hvt'
+LU0        = '-3.8898403e-011+dlu0n_hvt'
+WU0        = '-1.2840002e-009+dwu0n_hvt'
+PU0        = '5.4839316e-017+dpu0n_hvt'
+UA         = -1.6143173e-009     LUA        = -2.5370678e-017     WUA        = 4.0072486e-017
+PUA        = 2.4024843e-023      UB         = 1.427875e-018       LUB        = 3.8898349e-026
+WUB        = -5.158308e-026      PUB        = -3.3113399e-032     UC         = -9.4317845e-011
+LUC        = 2.3526431e-017      WUC        = 3.4994131e-017      PUC        = -1.4830118e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.4060353+da0n_hvt'
+LA0        = '-1.3455132e-007+dla0n_hvt'
+WA0        = '-3.2724079e-007+dwa0n_hvt'
+PA0        = '6.2483975e-014+dpa0n_hvt'
+AGS        = -4.3278073          LAGS       = 7.0745881e-007      WAGS       = 4.8468194e-006
+PAGS       = -6.4579327e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.06923171
+LKETA      = -2.2877216e-008     WKETA      = -4.4588629e-008     PKETA      = 1.3077871e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.18340503+dpclmn_hvt'
+LPCLM      = 1.1231153e-007      WPCLM      = 2.0754074e-007      PPCLM      = -3.7774855e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.0060264624+dpdiblc2n_hvt'
+LPDIBLC2   = '6.7300019e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 5.4255947e-009      PPDIBLC2   = -5.196678e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.125462e-008      WAGIDL     = 1.8137864e-014      BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010725544
+LAIGSD     = -6.7721212e-011     WAIGSD     = -2.3555899e-011     PAIGSD     = 5.222792e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -2.3944289e-005     LTVOFF     = 8.148018e-011
+WTVOFF     = 1.9720807e-010      PTVOFF     = -5.9017549e-017     KT1        = -0.3895338
+LKT1       = -2.7004246e-010     WKT1       = 7.7193873e-008      PKT1       = -5.7455934e-015
+KT1L       = 0                   KT2        = -0.11399975         LKT2       = 3.6552111e-009
+WKT2       = 2.3455522e-008      PKT2       = -2.2693031e-015     UTE        = -1
+UA1        = 7.384309e-010       LUA1       = 5.0950433e-017      WUA1       = -1.6212622e-016
+PUA1       = -3.7227017e-023     UB1        = -5.5970626e-019     LUB1       = -6.8530563e-026
+WUB1       = 9.017955e-026       PUB1       = 4.6482849e-032      UC1        = 1.8326101e-010
+LUC1       = -1.5221581e-017     WUC1       = -6.4035764e-017     PUC1       = 9.9494187e-024
+PRT        = 0                   AT         = '50471.488+datn_hvt'
+LAT        = -0.0013990211       WAT        = 0.0089052757        PAT        = -1.2012422e-009
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '1e-006-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.52889853+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-3.0251973e-009+dlvthn_hvt'
+WVTH0      = '-4.5967889e-008+dwvthn_hvt'
+PVTH0      = '4.2961667e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0034807992+dk2n_hvt'
+LK2        = '-1.4163497e-009+dlk2n_hvt'
+WK2        = '-2.3553092e-008+dwk2n_hvt'
+PK2        = '1.3554172e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0022436261+dcitn_hvt+0.00149113*ff_flag_hvt'
+LCIT       = '3.8644929e-010+dlcitn_hvt-1.42821e-10*ff_flag_hvt'
+WCIT       = '2.453402e-009+dwcitn_hvt-1.52096e-09*ff_flag_hvt'
+PCIT       = '-2.4740602e-016+dpcitn_hvt+1.45678e-16*ff_flag_hvt'
+VOFF       = '-0.15526103+dvoffn_hvt'
+LVOFF      = '-2.4447333e-009+dlvoffn_hvt'
+WVOFF      = '8.8476402e-009+dwvoffn_hvt'
+PVOFF      = '-1.0830445e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.098943963+deta0n_hvt'
+LETA0      = '1.078088e-008+dleta0n_hvt'
+WETA0      = '1.0492472e-007+dweta0n_hvt'
+PETA0      = '-6.5862555e-015+dpeta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011390414+du0n_hvt'
+LU0        = '1.3130169e-011+dlu0n_hvt'
+WU0        = '-6.8610119e-010+dwu0n_hvt'
+PU0        = '-2.4279295e-018+dpu0n_hvt'
+UA         = -2.6549763e-009     LUA        = 7.4304472e-017      WUA        = 7.1422917e-016
+PUA        = -4.0546423e-023     UB         = 2.8034532e-018      LUB        = -9.2855625e-026
+WUB        = -1.0443238e-024     PUB        = 6.1972105e-032      UC         = 3.5201396e-010
+LUC        = -1.9223586e-017     WUC        = -2.6950578e-016     PUC        = 1.4335127e-023
+VSAT       = '75059.289+dvsatn_hvt'
+LVSAT      = '0.00095212923+dlvsatn_hvt'
+WVSAT      = '0.010139525+dwvsatn_hvt'
+PVSAT      = '-9.7117181e-010+dpvsatn_hvt'
+A0         = '3.6588742+da0n_hvt'
+LA0        = '-3.5033003e-007+dla0n_hvt'
+WA0        = '-6.7452153e-007+dwa0n_hvt'
+PA0        = '9.5746803e-014+dpa0n_hvt'
+AGS        = -12.31189           LAGS       = 1.4721806e-006      WAGS       = 4.0563604e-006
+PAGS       = -5.7008247e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.30170439
+LKETA      = 1.265134e-008       WKETA      = 2.0612201e-007      PKETA      = -1.0935395e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '1.4612224+dpclmn_hvt'
+LPCLM      = -4.5212201e-008     WPCLM      = -7.8934701e-007     PPCLM      = 5.770785e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0020245416+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '-9.8131414e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-1.0537197e-009+3.3e-15*ff_flag_hvt'
+PPDIBLC2   = '1.0092612e-016-3.3e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 7.6302591e-010      LAGIDL     = -1.1510597e-015     WAGIDL     = -1.6152995e-014
+PAGIDL     = 3.284406e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0084736815        LAIGSD     = 1.4796395e-010
+WAIGSD     = 1.9666123e-009      PAIGSD     = -1.3839198e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00087605272       LTVOFF     = -4.7222538e-012     WTVOFF     = -7.8652278e-010
+PTVOFF     = 3.5204978e-017      KT1        = -0.38345064         LKT1       = -8.5269239e-010
+WKT1       = -4.478684e-009      PKT1       = 2.0770694e-015      KT1L       = 0
+KT2        = -0.10972811         LKT2       = 3.2460696e-009      WKT2       = 1.4591905e-008
+PKT2       = -1.4203388e-015     UTE        = -1                  UA1        = 2.7399852e-009
+LUA1       = -1.4076004e-016     WUA1       = -1.6059698e-015     PUA1       = 1.0106548e-022
+UB1        = -2.8047868e-018     LUB1       = 1.4650505e-025      WUB1       = 1.792227e-024
+PUB1       = -1.1654062e-031     UC1        = -5.9952012e-012     LUC1       = 2.9055298e-018
+WUC1       = 6.1134203e-017      PUC1       = -2.0394608e-024     PRT        = 0
+AT         = '30229.258+datn_hvt'
+LAT        = 0.00053979585       WAT        = 0.0097985706        PAT        = -1.2868027e-009
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hvt+dlmisn_hvt)'
+LMAX       = 2.001e-05           WMIN       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '6e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50469668+(dvthn_hvt+vthmisn_hvt)'
+WVTH0      = '-7.2405683e-010+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.018663811+dk2n_hvt'
+WK2        = '2.8365349e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.6815733e-005+dcitn_hvt'
+WCIT       = '-3.0229547e-012+dwcitn_hvt'
+VOFF       = '-0.1479146+dvoffn_hvt'
+WVOFF      = '-1.3760297e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0097100667+du0n_hvt'
+WU0        = '-1.4946133e-010+dwu0n_hvt'
+UA         = -2.0093333e-009     WUA        = 2.3146667e-017      UB         = 1.8696767e-018
+WUB        = -1.0856031e-026     UC         = 6.7605333e-012      WUC        = -4.1915307e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4846667+da0n_hvt'
+WA0        = '3.3066667e-008+dwa0n_hvt'
+AGS        = 0.70916528          WAGS       = 1.2359526e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.03349             WKETA      = -6.944e-009         DWG        = 0
+DWB        = 0                   PCLM       = '0.086064+dpclmn_hvt'
+WPCLM      = 2.93632e-009        PDIBLC1    = 0                   PDIBLC2    = '0.0002+dpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 1.9903893e-008      WAGIDL     = -4.2804139e-015
+BGIDL      = 1.7187e+009         CGIDL      = 64.8                EGIDL      = -0.075922
+AIGBACC    = 0.01397             BIGBACC    = 0.005651            CIGBACC    = 0.17808
+NIGBACC    = 10                  AIGBINV    = 0.01186             BIGBINV    = 0.002321
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3.056
+AIGC       = 0.00986             BIGC       = 0.002797            CIGC       = 0.40778504
+AIGSD      = 0.010811333         WAIGSD     = -1.1242667e-010     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00080189333      LTVOFF     = 0                   WTVOFF     = 2.8761387e-010
+PTVOFF     = 0                   KT1        = -0.30268081         WKT1       = 7.9579563e-009
+KT1L       = 0                   KT2        = -0.087758667        WKT2       = 7.2283733e-009
+UTE        = -1                  UA1        = 9.1015413e-010      WUA1       = -6.2715563e-017
+UB1        = -4.8333333e-019     WUB1       = 2.0666667e-026      UC1        = 6.6546667e-011
+WUC1       = -2.1294933e-017     PRT        = 0                   AT         = '180000+datn_hvt'
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'
+PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'
+PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'
+PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'
+LVOFF      = '0+dlvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '1e-005-(dxln_hvt+dlmisn_hvt)'   WMIN       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '6e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50415216+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '5.4262158e-009+dlvthn_hvt'
+WVTH0      = '-2.3842459e-010+dwvthn_hvt'
+PVTH0      = '-4.8393788e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.017442304+dk2n_hvt'
+LK2        = '-1.2172452e-008+dlk2n_hvt'
+WK2        = '2.7597496e-009+dwk2n_hvt'
+PK2        = '7.6517329e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.0177693e-005+dcitn_hvt'
+LCIT       = '6.6148798e-011+dlcitn_hvt'
+WCIT       = '-8.1748978e-013+dwcitn_hvt'
+PCIT       = '-2.19777e-017+dpcitn_hvt'
+VOFF       = '-0.14440888+dvoffn_hvt'
+LVOFF      = '-3.4934865e-008+dlvoffn_hvt'
+WVOFF      = '-2.0328191e-009+dwvoffn_hvt'
+PVOFF      = '6.5449795e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0096095882+du0n_hvt'
+LU0        = '1.0012788e-009+dlu0n_hvt'
+WU0        = '-1.2712231e-010+dwu0n_hvt'
+PU0        = '-2.2261087e-016+dpu0n_hvt'
+UA         = -2.0329249e-009     LUA        = 2.3509213e-016      WUA        = 2.3146667e-017
+PUA        = -7.7459245e-038     UB         = 1.8882828e-018      LUB        = -1.8541258e-025
+WUB        = -7.5567356e-027     PUB        = -3.2877845e-032     UC         = 1.0353437e-011
+LUC        = -3.5803676e-017     WUC        = -4.9012735e-018     PUC        = 7.0726655e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.51877+da0n_hvt'  LA0        = '-3.3984348e-007+dla0n_hvt'
+WA0        = '3.7480575e-008+dwa0n_hvt'
+PA0        = '-4.3985082e-014+dpa0n_hvt'
+AGS        = 0.64577863          LAGS       = 6.3165497e-007      WAGS       = 2.888408e-008
+PAGS       = -1.6466899e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.032417644
+LKETA      = 1.0686148e-008      WKETA      = -6.3768724e-009     PKETA      = -5.6514894e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.098718676+dpclmn_hvt'
+LPCLM      = -1.2610524e-007     WPCLM      = -8.8455033e-009     PPCLM      = 1.1740717e-013
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020706102+dpdiblc2n_hvt'
+LPDIBLC2   = '4.0564078e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.0371692e-011      PPDIBLC2   = -1.0335505e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.2738868e-008      LAGIDL     = -2.8250836e-014     WAGIDL     = -5.306761e-015
+PAGIDL     = 1.0227662e-020      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010911419         LAIGSD     = -9.9736054e-010
+WAIGSD     = -1.4788544e-010     PAIGSD     = 3.5335059e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00093907733      LTVOFF     = 1.3670536e-009      WTVOFF     = 3.3483786e-010
+PTVOFF     = -4.7059232e-016     KT1        = -0.30301138         LKT1       = 3.294083e-009
+WKT1       = 9.1400928e-009      PKT1       = -1.1780121e-014     KT1L       = 0
+KT2        = -0.088205476        LKT2       = 4.4525024e-009      WKT2       = 7.3312038e-009
+PKT2       = -1.0247167e-015     UTE        = -1                  UA1        = 9.1845297e-010
+LUA1       = -8.2698857e-017     WUA1       = -6.2551601e-017     PUA1       = -1.6338931e-024
+UB1        = -4.635236e-019      LUB1       = -1.9740615e-025     WUB1       = 1.6429343e-026
+PUB1       = 4.2225396e-032      UC1        = 6.3683371e-011      LUC1       = 2.853306e-017
+WUC1       = -2.0570156e-017     PUC1       = -7.2224861e-024     PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50581834+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '3.8181642e-009+dlvthn_hvt'
+WVTH0      = '-5.4243698e-009+dwvthn_hvt'
+PVTH0      = '1.6561842e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.027975813+dk2n_hvt'
+LK2        = '-2.0064785e-009+dlk2n_hvt'
+WK2        = '4.0586773e-009+dwk2n_hvt'
+PK2        = '-4.8843216e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.3137364e-005+dcitn_hvt'
+LCIT       = '2.4688076e-011+dlcitn_hvt'
+WCIT       = '-1.5403957e-011+dwcitn_hvt'
+PCIT       = '-7.9001844e-018+dpcitn_hvt'
+VOFF       = '-0.17703749+dvoffn_hvt'
+LVOFF      = '-3.4447304e-009+dlvoffn_hvt'
+WVOFF      = '5.7674668e-009+dwvoffn_hvt'
+PVOFF      = '-9.8313887e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010777257+du0n_hvt'
+LU0        = '-1.2564727e-010+dlu0n_hvt'
+WU0        = '-4.4041663e-010+dwu0n_hvt'
+PU0        = '7.9751987e-017+dpu0n_hvt'
+UA         = -1.8624698e-009     LUA        = 7.0584552e-017      WUA        = 1.8442182e-017
+PUA        = 4.5403359e-024      UB         = 1.8138374e-018      LUB        = -1.1356466e-025
+WUB        = -4.7846291e-026     PUB        = 6.0059267e-033      UC         = -2.3484559e-011
+LUC        = -3.1463557e-018     WUC        = 3.6216234e-018      PUC        = -1.1528505e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.7847738+da0n_hvt'
+LA0        = '-5.9656583e-007+dla0n_hvt'
+WA0        = '-1.1837193e-007+dwa0n_hvt'
+PA0        = '1.0642942e-013+dpa0n_hvt'
+AGS        = 0.99230228          LAGS       = 2.9722222e-007      WAGS       = -1.3341787e-007
+PAGS       = -8.0300815e-015     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.062487913
+LKETA      = -1.833491e-008      WKETA      = -1.7439729e-008     PKETA      = 5.0253622e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.11357953+dpclmn_hvt'
+LPCLM      = 7.8785457e-008      WPCLM      = 1.19943e-007        PPCLM      = -6.8876455e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.0039568235+dpdiblc2n_hvt'
+LPDIBLC2   = '3.7809599e-011+dlpdiblc2n_hvt'
+WPDIBLC2   = 2.8040582e-010      PPDIBLC2   = -3.6396714e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.6100659e-008     LAGIDL     = 9.2335022e-015      WAGIDL     = 8.1542661e-015
+PAGIDL     = -2.7636827e-021     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0095557214        LAIGSD     = 3.110337e-010
+WAIGSD     = 3.1642055e-010      PAIGSD     = -9.4754836e-017     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00054146397       LTVOFF     = -6.1828645e-011     WTVOFF     = -1.9306294e-010
+PTVOFF     = 3.8888964e-017      KT1        = -0.29802416         LKT1       = -1.5191142e-009
+WKT1       = -3.5975613e-009     PKT1       = 5.1309112e-016      KT1L       = 0
+KT2        = -0.082955072        LKT2       = -6.1470449e-010     WKT2       = 6.3942111e-009
+PKT2       = -1.204176e-016      UTE        = -1                  UA1        = 9.5675293e-010
+LUA1       = -1.1966245e-016     WUA1       = -8.5106296e-017     PUA1       = 2.0133823e-023
+UB1        = -7.6916278e-019     LUB1       = 9.7568666e-026      WUB1       = 8.7385528e-026
+PUB1       = -2.6254986e-032     UC1        = 8.6004875e-011      LUC1       = 6.9903979e-018
+WUC1       = -3.0389639e-017     PUC1       = 2.2543755e-024      PRT        = 0
+AT         = '155308.05+datn_hvt'
+LAT        = -0.024425001        WAT        = -0.00038863135      PAT        = 3.7507123e-010
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '2.4e-007-(dxln_hvt+dlmisn_hvt)' WMIN       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '6e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.54957039+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-6.1566027e-009+dlvthn_hvt'
+WVTH0      = '-1.2694612e-008+dwvthn_hvt'
+PVTH0      = '1.8231172e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.035957904+dk2n_hvt'
+LK2        = '-1.866895e-010+dlk2n_hvt'
+WK2        = '1.2947034e-009+dwk2n_hvt'
+PK2        = '1.4170966e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0011513917+dcitn_hvt'
+LCIT       = '2.9930144e-010+dlcitn_hvt'
+WCIT       = '8.9520178e-011+dwcitn_hvt'
+PCIT       = '-3.1821208e-017+dpcitn_hvt'
+VOFF       = '-0.20682982+dvoffn_hvt'
+LVOFF      = '3.3474436e-009+dlvoffn_hvt'
+WVOFF      = '8.2913661e-009+dwvoffn_hvt'
+PVOFF      = '-1.5585475e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394461+deta0n_hvt'
+LETA0      = '-1.0512644e-013+dleta0n_hvt'
+WETA0      = '3.3704815e-010+dweta0n_hvt'
+PETA0      = '5.2858751e-020+dpeta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0098673625+du0n_hvt'
+LU0        = '8.179401e-011+dlu0n_hvt'
+WU0        = '-2.9211617e-012+dwu0n_hvt'
+PU0        = '-1.998998e-017+dpu0n_hvt'
+UA         = -1.5798663e-009     LUA        = 6.1554727e-018      WUA        = 1.8712843e-017
+PUA        = 4.4786295e-024      UB         = 1.3403576e-018      LUB        = -5.6188355e-027
+WUB        = 2.6777448e-027      PUB        = -5.512745e-033      UC         = -1.6318395e-011
+LUC        = -4.7801265e-018     WUC        = -1.3365528e-017     PUC        = 2.7199481e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '-0.21513096+da0n_hvt'
+LA0        = '8.7364448e-008+dla0n_hvt'
+WA0        = '6.7788229e-007+dwa0n_hvt'
+PA0        = '-7.5103801e-014+dpa0n_hvt'
+AGS        = 4.0738385           LAGS       = -4.0531873e-007     WAGS       = -3.62201e-007
+PAGS       = 4.412881e-014       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.041036755
+LKETA      = 5.2670585e-009      WKETA      = 2.3777819e-008      PKETA      = -4.3715793e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.037239891+dpclmn_hvt'
+LPCLM      = 6.1381241e-008      WPCLM      = 1.1691835e-007      PPCLM      = -6.1980744e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.0063850288+dpdiblc2n_hvt'
+LPDIBLC2   = '-5.1578237e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = -2.2695298e-009     PPDIBLC2   = 2.1737738e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.5172797e-008      LAGIDL     = -1.7618527e-016     WAGIDL     = -4.4471339e-015
+PAGIDL     = 1.0923487e-022      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010855278         LAIGSD     = 1.4755516e-011
+WAIGSD     = -1.0399134e-010     PAIGSD     = 1.0923487e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00034199185       LTVOFF     = -1.6352195e-011     WTVOFF     = -2.9672342e-011
+PTVOFF     = 1.638523e-018       KT1        = -0.2610052          LKT1       = -9.9588457e-009
+WKT1       = -2.4938587e-009     PKT1       = 2.6146457e-016      KT1L       = 0
+KT2        = -0.08304073         LKT2       = -5.9517585e-010     WKT2       = 4.2609281e-009
+PKT2       = 3.659368e-016       UTE        = -1                  UA1        = 5.3903002e-010
+LUA1       = -2.4428307e-017     WUA1       = -3.8497671e-017     PUA1       = 9.5078026e-024
+UB1        = -4.6064538e-019     LUB1       = 2.7231635e-026      WUB1       = 2.8761801e-026
+PUB1       = -1.2889714e-032     UC1        = 8.9319326e-011      LUC1       = 6.2347561e-018
+WUC1       = -5.7919224e-018     PUC1       = -3.3535103e-024     PRT        = 0
+AT         = '62885.449+datn_hvt'
+LAT        = -0.003354127        WAT        = 0.0012086199        PAT        = 1.0923487e-011
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+WMIN       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   WMAX       = '6e-007-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42852522+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '5.4372004e-009+dlvthn_hvt'
+WVTH0      = '1.6263563e-008+dwvthn_hvt'
+PVTH0      = '-9.505199e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.042921137+dk2n_hvt'
+LK2        = '4.8025448e-010+dlk2n_hvt'
+WK2        = '8.9991682e-010+dwk2n_hvt'
+PK2        = '1.7952263e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0029497941+dcitn_hvt-0.00198818*ff_flag_hvt'
+LCIT       = '-9.3513424e-011+dlcitn_hvt+1.90428e-10*ff_flag_hvt'
+WCIT       = '-7.6651852e-010+dwcitn_hvt+6.36217e-10*ff_flag_hvt'
+PCIT       = '5.0170863e-017+dpcitn_hvt-6.0937e-17*ff_flag_hvt'
+VOFF       = '-0.11162465+dvoffn_hvt'
+LVOFF      = '-5.7713837e-009+dlvoffn_hvt'
+WVOFF      = '-1.8206912e-008+dwvoffn_hvt'
+PVOFF      = '9.7947875e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.081002552+deta0n_hvt'
+LETA0      = '-9.2037575e-010+dleta0n_hvt'
+WETA0      = '-6.6421214e-009+dweta0n_hvt'
+PETA0      = '6.6852331e-016+dpeta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0084941866+du0n_hvt'
+LU0        = '2.133179e-010+dlu0n_hvt'
+WU0        = '1.1095601e-009+dwu0n_hvt'
+PU0        = '-1.2654432e-016+dpu0n_hvt'
+UA         = -1.5470255e-009     LUA        = 3.0099569e-018      WUA        = 2.7299671e-017
+PUA        = 3.6561762e-024      UB         = 8.6403595e-019      LUB        = 4.0003629e-026
+WUB        = 1.5811482e-025      PUB        = -2.0400633e-032     UC         = -1.7596009e-010
+LUC        = 1.0510483e-017      WUC        = 5.7838133e-017      PUC        = -4.0999954e-024
+VSAT       = '91413.362+dvsatn_hvt'
+LVSAT      = '-0.00061427692+dlvsatn_hvt'
+A0         = '1.9053792+da0n_hvt'
+LA0        = '-1.1573971e-007+dla0n_hvt'
+WA0        = '4.1264533e-007+dwa0n_hvt'
+PA0        = '-4.9699193e-014+dpa0n_hvt'
+AGS        = -4.8405472          LAGS       = 4.4850827e-007      WAGS       = -5.7587186e-007
+PAGS       = 6.4594377e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.096747294
+LKETA      = -7.9300079e-009     WKETA      = -4.0918034e-008     PKETA      = 1.8250413e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.34167982+dpclmn_hvt'
+LPCLM      = 9.0540741e-008      WPCLM      = 3.2845239e-007      PPCLM      = -2.6458974e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0013152167+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '-3.0191711e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-6.139383e-010-4.4e-15*ff_flag_hvt'
+PPDIBLC2   = '5.8803501e-017+3.1e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -7.7202355e-008     LAGIDL     = 9.6293887e-015      WAGIDL     = 3.2185541e-014
+PAGIDL     = -3.399472e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.012273835         LAIGSD     = -1.2111493e-010
+WAIGSD     = -3.8948256e-010     PAIGSD     = 2.8436926e-017      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 3.1348491e-005      LTVOFF     = 1.3401475e-011      WTVOFF     = -2.6280616e-010
+PTVOFF     = 2.3968267e-017      KT1        = -0.3821311          LKT1       = 1.6426901e-009
+WKT1       = -5.2967973e-009     PKT1       = 5.2993228e-016      KT1L       = 0
+KT2        = -0.12696737         LKT2       = 3.6121531e-009      WKT2       = 2.5280248e-008
+PKT2       = -1.6473105e-015     UTE        = -1                  UA1        = -3.8008776e-010
+LUA1       = 6.3605529e-017      WUA1       = 3.2847538e-016      PUA1       = -2.564117e-023
+UB1        = 5.7809179e-019      LUB1       = -7.2259442e-026     WUB1       = -3.0515772e-025
+PUB1       = 1.9093365e-032      UC1        = 2.7796675e-010      LUC1       = -1.1834045e-017
+WUC1       = -1.1492221e-016     PUC1       = 7.0990755e-024      PRT        = 0
+AT         = '54161.45+datn_hvt' LAT        = -0.0025185354       WAT        = -0.0050393882
+PAT        = 6.0936271e-010      NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hvt+dlmisn_hvt)'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51228418+(dvthn_hvt+vthmisn_hvt)'
+WVTH0      = '-3.1520563e-009+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.027700402+dk2n_hvt'
+WK2        = '5.7282437e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.2115556e-006+dcitn_hvt'
+WCIT       = '-5.8961778e-013+dwcitn_hvt'
+VOFF       = '-0.16804363+dvoffn_hvt'
+WVOFF      = '5.0652597e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.009243+du0n_hvt' UA         = -1.9128889e-009
+WUA        = -7.7155556e-018     UB         = 1.7494485e-018      WUB        = 2.7616975e-026
+UC         = -1.1097778e-012     WUC        = -1.6730311e-018     VSAT       = '85000+dvsatn_hvt'
+A0         = '2.4627778+da0n_hvt'
+WA0        = '4.0071111e-008+dwa0n_hvt'
+AGS        = 0.70174031          WAGS       = 1.4735516e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.023713333         WKETA      = -3.8154667e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.10196778+dpclmn_hvt'
+WPCLM      = -2.1528889e-009     PDIBLC1    = 0                   PDIBLC2    = '0.00016111111+dpdiblc2n_hvt'
+WPDIBLC2   = 1.2444444e-011      PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = -3.9509333e-009
+WAGIDL     = 3.3531307e-015      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010226667         WAIGSD     = 7.4666667e-011
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.00057671111       LTVOFF     = 0
+WTVOFF     = -1.5353956e-010     PTVOFF     = 0                   KT1        = -0.25007282
+WKT1       = -8.8766023e-009     KT1L       = 0                   KT2        = -0.078571111
+WKT2       = 4.2883556e-009      UTE        = -1                  UA1        = 6.9660797e-010
+WUA1       = 5.6192102e-018      UB1        = -5.3755556e-019     WUB1       = 3.8017778e-026
+UC1        = -2.2012222e-027     WUC1       = 2.5959111e-034      PRT        = 0
+AT         = '180000+datn_hvt'   NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'
+NOIC       = 'noicnmac_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LU0        = '0+dlu0n_hvt'       WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '1e-005-(dxln_hvt+dlmisn_hvt)'   WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51234878+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-6.4382948e-010+dlvthn_hvt'
+WVTH0      = '-2.8613456e-009+dwvthn_hvt'
+PVTH0      = '-2.8969643e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.026542885+dk2n_hvt'
+LK2        = '-1.1534782e-008+dlk2n_hvt'
+WK2        = '5.6719354e-009+dwk2n_hvt'
+PK2        = '5.6111864e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.8095546e-005+dcitn_hvt'
+LCIT       = '-1.8818104e-010+dlcitn_hvt'
+WCIT       = '-6.5512025e-012+dwcitn_hvt'
+PCIT       = '5.9407847e-017+dpcitn_hvt'
+VOFF       = '-0.16583617+dvoffn_hvt'
+LVOFF      = '-2.1997539e-008+dlvoffn_hvt'
+WVOFF      = '4.8239142e-009+dwvoffn_hvt'
+PVOFF      = '2.405035e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.009196234+du0n_hvt'
+LU0        = '4.6602859e-010+dlu0n_hvt'
+WU0        = '5.1510543e-012+dwu0n_hvt'
+PU0        = '-5.1330823e-017+dpu0n_hvt'
+UA         = -1.9494081e-009     LUA        = 3.6391787e-016      WUA        = -3.5786985e-018
+PUA        = -4.1224236e-023     UB         = 1.7949578e-018      LUB        = -4.535054e-025
+WUB        = 2.2307263e-026      PUB        = 5.291186e-032       UC         = 2.4818506e-012
+LUC        = -3.5790972e-017     WUC        = -2.382366e-018      PUC        = 7.0686e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4767003+da0n_hvt'
+LA0        = '-1.387395e-007+dla0n_hvt'
+WA0        = '5.0942878e-008+dwa0n_hvt'
+PA0        = '-1.0833836e-013+dpa0n_hvt'
+AGS        = 0.69695355          LAGS       = 4.7700611e-008      WAGS       = 1.2508105e-008
+PAGS       = 2.21964e-014        A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.021443805
+LKETA      = 2.26161e-008        WKETA      = -2.8652439e-009     PKETA      = -9.469074e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.078433349+dpclmn_hvt'
+LPCLM      = 2.3452317e-007      WPCLM      = -2.3541986e-009     PPCLM      = 2.0060734e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00033562153+dpdiblc2n_hvt'
+LPDIBLC2   = '4.9499954e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = 5.1511054e-011      PPDIBLC2   = -3.8930307e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -5.7365638e-009     LAGIDL     = 1.7794005e-014      WAGIDL     = 3.8053772e-015
+PAGIDL     = -4.5066867e-021     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010177577         LAIGSD     = 4.891816e-010
+WAIGSD     = 8.6943791e-011      PAIGSD     = -1.2234289e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0006678292        LTVOFF     = -9.0800179e-010     WTVOFF     = -1.7937223e-010
+PTVOFF     = 2.5742541e-016      KT1        = -0.24668894         LKT1       = -3.3720694e-008
+WKT1       = -8.8830857e-009     PKT1       = 6.4607686e-017      KT1L       = 0
+KT2        = -0.079299589        LKT2       = 7.25936e-009        WKT2       = 4.4813199e-009
+PKT2       = -1.9229111e-015     UTE        = -1                  UA1        = 7.1237702e-010
+LUA1       = -1.5714029e-016     WUA1       = 3.3927053e-018      PUA1       = 2.2187367e-023
+UB1        = -5.5056664e-019     LUB1       = 1.2965687e-025      WUB1       = 4.4283115e-026
+PUB1       = -6.243477e-032      UC1        = -4.5276662e-015     LUC1       = 4.5118691e-020
+WUC1       = -1.9002853e-019     PUC1       = 1.8936552e-024      PRT        = 0
+AT         = '186195.75+datn_hvt'
+LAT        = -0.061741367        WAT        = -0.00026689401      PAT        = 2.6596281e-009
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '9.999998e-007-(dxln_hvt+dlmisn_hvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50579229+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '5.6838921e-009+dlvthn_hvt'
+WVTH0      = '-5.4160336e-009+dwvthn_hvt'
+PVTH0      = '-4.3141451e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.033880681+dk2n_hvt'
+LK2        = '-4.4530155e-009+dlk2n_hvt'
+WK2        = '5.948235e-009+dwk2n_hvt'
+PK2        = '2.9445968e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.1708385e-005+dcitn_hvt'
+LCIT       = '-1.8201674e-010+dlcitn_hvt'
+WCIT       = '-5.3466832e-012+dwcitn_hvt'
+PCIT       = '5.8245356e-017+dpcitn_hvt'
+VOFF       = '-0.18317423+dvoffn_hvt'
+LVOFF      = '-5.2644364e-009+dlvoffn_hvt'
+WVOFF      = '7.7312239e-009+dwvoffn_hvt'
+PVOFF      = '-4.0083295e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0092676886+du0n_hvt'
+LU0        = '3.9706713e-010+dlu0n_hvt'
+WU0        = '4.2645093e-011+dwu0n_hvt'
+PU0        = '-8.7516619e-017+dpu0n_hvt'
+UA         = -1.6998633e-009     LUA        = 1.230802e-016       WUA        = -3.3591884e-017
+PUA        = -1.225827e-023      UB         = 1.4354528e-018      LUB        = -1.0654419e-025
+WUB        = 7.3236778e-026      PUB        = 3.7593782e-033      UC         = -2.1093222e-011
+LUC        = -1.3038481e-017     WUC        = 2.8563953e-018      PUC        = 2.0126297e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5873486+da0n_hvt'
+LA0        = '-2.4552705e-007+dla0n_hvt'
+WA0        = '-5.5195882e-008+dwa0n_hvt'
+PA0        = '-5.9029885e-015+dpa0n_hvt'
+AGS        = 0.5431558           LAGS       = 1.9613205e-007      WAGS       = 1.0308999e-008
+PAGS       = 2.4318775e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.042376717
+LKETA      = 2.4135791e-009      WKETA      = -1.1004146e-008     PKETA      = -1.6141542e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.32342178+dpclmn_hvt'
+LPCLM      = -1.917125e-009      WPCLM      = -1.9897424e-008     PPCLM      = 1.8937181e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0063906368+dpdiblc2n_hvt'
+LPDIBLC2   = '-1.5415703e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = -4.9841445e-010     PPDIBLC2   = 1.4143444e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 1.1601063e-008      LAGIDL     = 1.0613221e-015      WAGIDL     = -7.1028482e-016
+PAGIDL     = -1.4858509e-022     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010724308         LAIGSD     = -3.8472926e-011
+WAIGSD     = -5.7527272e-011     PAIGSD     = 1.7087286e-017      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00037839866      LTVOFF     = 1.0172109e-010      WTVOFF     = 1.0129311e-010
+PTVOFF     = -1.3446951e-017     KT1        = -0.28676733         LKT1       = 4.9592795e-009
+WKT1       = -7.1997481e-009     PKT1       = -1.5599949e-015     KT1L       = 0
+KT2        = -0.071167105        LKT2       = -5.8936542e-010     WKT2       = 2.6220617e-009
+PKT2       = -1.2852611e-016     UTE        = -1                  UA1        = 6.1336742e-010
+LUA1       = -6.1585337e-017     WUA1       = 2.4777067e-017      PUA1       = 1.5491482e-024
+UB1        = -4.4649813e-019     LUB1       = 2.9219524e-026      WUB1       = -1.5867159e-026
+PUB1       = -4.3832602e-033     UC1        = -2.6148331e-011     LUC1       = 2.5276712e-017
+WUC1       = 5.4993869e-018      PUC1       = -3.5972451e-024     PRT        = 0
+AT         = '145546.01+datn_hvt'
+LAT        = -0.022509978        WAT        = 0.00273522          PAT        = -2.3773615e-010
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax  



.MODEL nch_hvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+LMAX       = '2.4e-007-(dxln_hvt+dlmisn_hvt)' WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_hvt+dwmisn_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_hvt+toxmisn_hvt)'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.54277891+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '-2.7484641e-009+dlvthn_hvt'
+WVTH0      = '-1.0521336e-008+dwvthn_hvt'
+PVTH0      = '7.3251285e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.057011061+dk2n_hvt'
+LK2        = '8.2034108e-010+dlk2n_hvt'
+WK2        = '8.0317137e-009+dwk2n_hvt'
+PK2        = '-1.8054013e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0024251868+dcitn_hvt'
+LCIT       = '3.7583621e-010+dlcitn_hvt'
+WCIT       = '4.9713459e-010+dwcitn_hvt'
+PCIT       = '-5.6312335e-017+dpcitn_hvt'
+VOFF       = '-0.19831769+dvoffn_hvt'
+LVOFF      = '-1.8119706e-009+dlvoffn_hvt'
+WVOFF      = '5.5674846e-009+dwvoffn_hvt'
+PVOFF      = '9.2464993e-017+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049331+deta0n_hvt'
+LETA0      = '1.0676827e-013+dleta0n_hvt'
+WETA0      = '-1.2174583e-008+dweta0n_hvt'
+PETA0      = '-1.4947558e-020+dpeta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011644154+du0n_hvt'
+LU0        = '-1.4472886e-010+dlu0n_hvt'
+WU0        = '-5.714943e-010+dwu0n_hvt'
+PU0        = '5.2497336e-017+dpu0n_hvt'
+UA         = -1.0911728e-009     LUA        = -1.56915e-017       WUA        = -1.3766906e-016
+PUA        = 1.1469661e-023      UB         = 9.6663712e-019      LUB        = 3.3827571e-028
+WUB        = 1.2226828e-025      PUB        = -7.4190206e-033     UC         = -1.1464114e-010
+LUC        = 8.2889478e-018      WUC        = 1.8097751e-017      PUC        = -1.4621557e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.1662588+da0n_hvt'
+LA0        = '-1.4952532e-007+dla0n_hvt'
+WA0        = '-8.4162443e-008+dwa0n_hvt'
+PA0        = '7.0092372e-016+dpa0n_hvt'
+AGS        = 2.9032334           LAGS       = -3.4192788e-007     WAGS       = 1.2392635e-008
+PAGS       = 2.3843739e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.094645246
+LKETA      = -9.5028092e-009     WKETA      = -1.9640422e-008     PKETA      = 3.547784e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.1577434+dpclmn_hvt'
+LPCLM      = 3.5854896e-008      WPCLM      = 5.4523696e-008      PPCLM      = 1.970356e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.001258821+dpdiblc2n_hvt'
+LPDIBLC2   = '2.0238365e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.7650212e-010      PPDIBLC2   = -1.2435743e-017     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.2559981e-008      LAGIDL     = -1.4371359e-015     WAGIDL     = -3.6110329e-015
+PAGIDL     = 5.1273906e-022      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010515306         LAIGSD     = 9.1763159e-012
+WAIGSD     = 4.7998774e-012      PAIGSD     = 2.8776927e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00019311573       LTVOFF     = -2.8575048e-011     WTVOFF     = 1.7968017e-011
+PTVOFF     = 5.5498359e-018      KT1        = -0.1993459          LKT1       = -1.4971409e-008
+WKT1       = -2.2224836e-008     PKT1       = 1.8654848e-015      KT1L       = 0
+KT2        = -0.078321382        LKT2       = 1.0416954e-009      WKT2       = 2.7507369e-009
+PKT2       = -1.57862e-016       UTE        = -1                  UA1        = 3.8300931e-010
+LUA1       = -9.0673747e-018     WUA1       = 1.1428955e-017      PUA1       = 4.5923042e-024
+UB1        = -3.6816262e-019     LUB1       = 1.1360279e-026      WUB1       = -8.3268299e-028
+PUB1       = -7.8108801e-033     UC1        = 1.2007767e-010      LUC1       = -8.0604759e-018
+WUC1       = -1.5634592e-017     PUC1       = 1.2209639e-024      PRT        = 0
+AT         = '60359.202+datn_hvt'
+LAT        = -0.0030887479       WAT        = 0.002017019         PAT        = -7.3997812e-011
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_hvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-(dxln_hvt+dlmisn_hvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_hvt+dwmisn_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_hvt+toxmisn_hvt)'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_hvt+dlmisn_hvt)'   XW         = '2e-08+(dxwn_hvt+dwmisn_hvt)'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4884551+(dvthn_hvt+vthmisn_hvt)'
+LVTH0      = '2.4547135e-009+dlvthn_hvt'
+WVTH0      = '-2.9139982e-009+dwvthn_hvt'
+PVTH0      = '3.8759072e-018+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.059489688+dk2n_hvt'
+LK2        = '1.057746e-009+dlk2n_hvt'
+WK2        = '6.2018534e-009+dwk2n_hvt'
+PK2        = '-5.2746416e-018+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0020076336+dcitn_hvt'
+LCIT       = '-4.8742874e-011+dlcitn_hvt'
+WCIT       = '-4.6502715e-010+dwcitn_hvt'
+PCIT       = '3.5844287e-017+dpcitn_hvt'
+VOFF       = '-0.19091382+dvoffn_hvt'
+LVOFF      = '-2.5211195e-009+dlvoffn_hvt'
+WVOFF      = '7.1656209e-009+dwvoffn_hvt'
+PVOFF      = '-6.0605779e-017+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.12787478+deta0n_hvt'
+LETA0      = '-1.6647044e-009+dleta0n_hvt'
+WETA0      = '-2.1641235e-008+dweta0n_hvt'
+PETA0      = '9.0670848e-016+dpeta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.012025944+du0n_hvt-0.000773181*ss_flag_hvt'
+LU0        = '-1.8129701e-010+dlu0n_hvt+7.40554e-11*ss_flag_hvt'
+WU0        = '-2.060218e-011+dwu0n_hvt+2.47418e-10*ss_flag_hvt'
+PU0        = '-2.6755173e-019+dpu0n_hvt-2.36977e-17*ss_flag_hvt'
+UA         = -1.4443723e-009     LUA        = 1.8138233e-017      WUA        = -5.5493377e-018
+PUA        = -1.1848719e-024     UB         = 1.2479661e-018      LUB        = -2.6607642e-026
+WUB        = 3.5257163e-026      PUB        = 9.1497416e-034      UC         = -1.8256357e-011
+LUC        = -9.4286389e-019     WUC        = 7.3729378e-018      PUC        = -4.3492444e-025
+VSAT       = '88919.277+dvsatn_hvt'
+LVSAT      = '-0.00037539145+dlvsatn_hvt'
+WVSAT      = '0.00079810724+dwvsatn_hvt'
+PVSAT      = '-7.644335e-011+dpvsatn_hvt'
+A0         = '3.3212421+da0n_hvt'
+LA0        = '-2.6015054e-007+dla0n_hvt'
+WA0        = '-4.0430801e-008+dwa0n_hvt'
+PA0        = '-3.4877279e-015+dpa0n_hvt'
+AGS        = -9.2463195          LAGS       = 8.2176602e-007      WAGS       = 8.3397528e-007
+PAGS       = -5.4848104e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.16625457
+LKETA      = -1.6361607e-008     WKETA      = -6.3160361e-008     PKETA      = 4.523153e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.4610665+dpclmn_hvt'
+LPCLM      = 6.8023664e-009      WPCLM      = 7.1573562e-008      PPCLM      = 3.3730625e-016
+PDIBLC1    = 0
+PDIBLC2    = '0.00026404831+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '5.6522009e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-2.775644e-010-7e-17*ff_flag_hvt'
+PPDIBLC2   = '3.1055111e-017-4.2e-23*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 9.2037183e-009      LAGIDL     = -1.5786234e-016     WAGIDL     = 4.5355976e-015
+PAGIDL     = -2.6755173e-022     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010947813         LAIGSD     = -3.2249538e-011
+WAIGSD     = 3.4844444e-011      PAIGSD     = 9.7315253e-031      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0010982244       LTVOFF     = 9.5110543e-011      WTVOFF     = 9.8657168e-011
+PTVOFF     = -2.1786355e-018     KT1        = -0.3903388          LKT1       = 3.3220437e-009
+WKT1       = -2.6703358e-009     PKT1       = -7.460871e-018      KT1L       = 0
+KT2        = -0.028142337        LKT2       = -3.7644937e-009     WKT2       = -6.3437628e-009
+PKT2       = 7.1321646e-016      UTE        = -1                  UA1        = 2.20354e-010
+LUA1       = 6.5118814e-018      WUA1       = 1.3633402e-016      PUA1       = -7.3712029e-024
+UB1        = 3.2461847e-019      LUB1       = -5.4994848e-026     WUB1       = -2.2404626e-025
+PUB1       = 1.3568695e-032      UC1        = -1.2102699e-010     LUC1       = 1.5032721e-017
+WUC1       = 1.2755791e-017      PUC1       = -1.4982897e-024     PRT        = 0
+AT         = '27042.218+datn_hvt'
+LAT        = 0.00010237949       WAT        = 0.0036387662        PAT        = -2.2933005e-010
+NOIA       = 'noianmac_hvt'             NOIB       = 'noibnmac_hvt'          NOIC       = 'noicnmac_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT PMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************



.ends nch_hvt_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_hvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.10e-008' xw='+2e-08+dxwp_hvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_hvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_hvt  temp2=parp2_hvt
+fac1='0.865112*temp1*sigma+0.501579*temp2*sigma'
+fac2='0.865112*temp1*sigma-0.501579*temp2*sigma'
.param  lef='l*scale+2e-09'
+       wef='w/nf*scale+2e-08'
+       geo_fac  = '1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_hvt='(0.0037385-0.0003287615/(lef*1e6)+0.000021625807/(lef*lef*1e12)-0.00002287615/(wef*wef*1e12)-0.00005130245219859*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisp_hvt = '0.00203822*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_hvt = '-0.00203822*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_hvt='0.00203822*geo_fac*toxp_hvt*fac2*mismatchflag' 
.param tnoiax='1.131e06/(l*scale*1e6)+2.64e07'
.param rnoiax='0.00561/(l*scale*1e6)+0.5135'

.param fn_dice='noiseflagp_hvt_mc*par1fn_mc+noiseflagp_hvt_mc_mis*par2fp_hvt_mc'
.param arearatio='sigma_factor_flicker_hvt*(log(3.873)-min(0,0.5*log(((w*scale*l*scale*multi)/(10.3E-6*1E-6*1))**0.5)))'
.param noiapmac_hvt='c1fp_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_hvt)*arearatio)'
.param noibpmac_hvt='c2fp_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_hvt)*arearatio)'
.param noicpmac_hvt='c3fp_hvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_hvt)*arearatio)'

.MODEL pch_hvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.6126+(dvthp_hvt+vthmisp_hvt)' K1         = 0.45227
+K2         = '0.00875238+dk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.998e-006+dcitp_hvt'
+VOFF       = '-0.1169336+dvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.0155+du0p_hvt'
+UA         = 2.182e-009          UB         = '2.35199e-020+dubp_hvt'
+UC         = -1.587e-010         VSAT       = '80000+dvsatp_hvt'  A0         = '1.9367211+da0p_hvt'
+AGS        = 0.6941              A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.005274
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0007+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01331             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.006741            BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006354            BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.000826
+LTVOFF     = 0                   WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2284             KT1L       = 0                   KT2        = -0.062
+UTE        = -1                  UA1        = 3.2470362e-009      UB1        = -3.44e-018
+UC1        = 1.5e-010            PRT        = 0                   AT         = '160000+datp_hvt'
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LA0        = '0+dla0p_hvt'       WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'
+LVOFF      = '0+dlvoffp_hvt'     WVOFF      = '0+dwvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1e-005-(dxlp_hvt+dlmisp_hvt)'   WMIN       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61212866+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-4.6965102e-009+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0086881253+dk2p_hvt'
+LK2        = '6.4024108e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-6.9962746e-006+dcitp_hvt'
+LCIT       = '1.2947638e-010+dlcitp_hvt'
+VOFF       = '-0.1162912+dvoffp_hvt'
+LVOFF      = '-6.4009164e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015481789+du0p_hvt'
+LU0        = '1.8145608e-010+dlu0p_hvt'
+UA         = 2.1793219e-009      LUA        = 2.6684717e-017      UB         = '2.3131224e-020+dubp_hvt'
+LUB        = '3.8728063e-027+dlubp_hvt'
+UC         = -1.6405617e-010     LUC        = 5.3369434e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9439756+da0p_hvt'
+LA0        = '-7.2284714e-008+dla0p_hvt'
+AGS        = 0.67174336          LAGS       = 2.2276402e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0080574927        LKETA      = -2.7735027e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00067199796+dpdiblc2p_hvt'
+LPDIBLC2   = 2.790154e-010       PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.013307858         LAIGBACC   = 2.1347774e-011
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.006740143
+LAIGC      = 8.5391094e-012      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063562496        LAIGSD     = -2.2415162e-011     BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00077115285       LTVOFF     = 5.46503e-010        WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2291634          LKT1       = 7.6066387e-009
+KT1L       = 0                   KT2        = -0.061571507        LKT2       = -4.2695547e-009
+UTE        = -1                  UA1        = 3.3091074e-009      LUA1       = -6.1848365e-016
+UB1        = -3.4560685e-018     LUB1       = 1.601083e-025       UC1        = 1.7142467e-010
+LUC1       = -2.1347774e-016     PRT        = 0                   AT         = '163213.7+datp_hvt'
+LAT        = -0.03202166         NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'
+PPCLM      = '0+dppclmp_hvt'     WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61593416+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-1.0275907e-009+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0089735747+dk2p_hvt'
+LK2        = '3.6503647e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-5.5398165e-005+dcitp_hvt'
+LCIT       = '1.7614113e-010+dlcitp_hvt'
+VOFF       = '-0.12126605+dvoffp_hvt'
+LVOFF      = '-1.604613e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015729562+du0p_hvt'
+LU0        = '-5.7424184e-011+dlu0p_hvt'
+UA         = 2.2430506e-009      LUA        = -3.4756743e-017     UB         = '3.148352e-020+dubp_hvt'
+LUB        = '-4.179725e-027+dlubp_hvt'
+UC         = -1.1646812e-010     LUC        = 7.4893225e-018      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.8505045+da0p_hvt'
+LA0        = '1.783172e-008+dla0p_hvt'
+AGS        = 0.54473918          LAGS       = 3.4521001e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0081330433       LKETA      = -1.212557e-008      DWG        = 0
+DWB        = 0                   PCLM       = '0.48798566+dpclmp_hvt'
+LPCLM      = '6.779076e-008+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0011060413+dpdiblc2p_hvt'
+LPDIBLC2   = -1.394501e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 6.0595496e-009      LAGIDL     = 9.0669764e-016      BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067486865
+LAIGC      = 3.0223255e-013      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006324536         LAIGSD     = 8.1602787e-012      BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.0014439574        LTVOFF     = -1.021546e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2170348          LKT1       = -4.0866676e-009
+KT1L       = 0                   KT2        = -0.066153607        LKT2       = 1.4809395e-010
+UTE        = -0.99028201         LUTE       = -9.3692089e-009     UA1        = 3.5037294e-009
+LUA1       = -8.0612069e-016     UB1        = -4.3840573e-018     LUB1       = 1.0547916e-024
+UC1        = -5e-011             PRT        = 0                   AT         = '131880.9+datp_hvt'
+LAT        = -0.0018133953       NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61781514+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-5.9477527e-010+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0081498936+dk2p_hvt'
+LK2        = '5.5456548e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.2678647e-005+dcitp_hvt'
+LCIT       = '1.4206865e-010+dlcitp_hvt'
+VOFF       = '-0.12004674+dvoffp_hvt'
+LVOFF      = '-1.8851782e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.014783015+du0p_hvt'
+LU0        = '1.603762e-010+dlu0p_hvt'
+UA         = 1.9999369e-009      LUA        = 2.1183712e-017      UB         = '1.4122343e-020+dubp_hvt'
+LUB        = '-1.8491831e-028+dlubp_hvt'
+UC         = -1.8034671e-010     LUC        = 2.2187786e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.7431254+da0p_hvt'
+LA0        = '4.253965e-008+dla0p_hvt'
+AGS        = -1.2093921          LAGS       = 7.4883562e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.031512029        LKETA      = -6.7460652e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.76508556+dpclmp_hvt'
+LPCLM      = '4.0300721e-009+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.2515198e-009
+LAGIDL     = 1.722253e-016       BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067911664        LAIGC      = -9.4723917e-012
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0062694339
+LAIGSD     = 2.0839262e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0011848746
+LTVOFF     = -4.253965e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20254588         LKT1       = -7.4205683e-009     KT1L       = 0
+KT2        = -0.066872234        LKT2       = 3.1345005e-010      UTE        = -1.0542029
+LUTE       = 5.3389844e-009      UA1        = -1.1145711e-009     LUA1       = 2.5655026e-016
+UB1        = 1.52481e-018        LUB1       = -3.0483879e-025     UC1        = 1.3712006e-010
+LUC1       = -4.3056326e-017     PRT        = 0                   AT         = '164417.93+datp_hvt'
+LAT        = -0.0093001664       NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62049874+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-3.3044111e-010+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.036036684+dk2p_hvt'
+LK2        = '-2.1922834e-009+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0013071458+dcitp_hvt'
+LCIT       = '2.7995136e-010+dlcitp_hvt'
+VOFF       = '-0.097292557+dvoffp_hvt'
+LVOFF      = '-4.1264647e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0012648024+deta0p_hvt'
+LETA0      = '3.6791697e-010+dleta0p_hvt'
+ETAB       = -0.002981           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020077263+du0p_hvt'
+LU0        = '-3.6110716e-010+dlu0p_hvt'
+UA         = 3.1589863e-009      LUA        = -9.2982651e-017     UB         = '5.1450685e-021+dubp_hvt'
+LUB        = '6.9934326e-028+dlubp_hvt'
+UC         = 3.1029579e-010      LUC        = -2.61405e-017       VSAT       = '80000+dvsatp_hvt'
+A0         = '2.8116814+da0p_hvt'
+LA0        = '-6.2713119e-008+dla0p_hvt'
+AGS        = 0.15077171          LAGS       = 6.1485949e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10276744         LKETA      = 2.7259302e-010      DWG        = 0
+DWB        = 0                   PCLM       = '0.69003909+dpclmp_hvt'
+LPCLM      = '1.1422149e-008+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0014100442+dpdiblc2p_hvt'
+LPDIBLC2   = 1.8813936e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 1.7791268e-008      LAGIDL     = -6.6893994e-016     BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067595171
+LAIGC      = -6.3549294e-012     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063672463        LAIGSD     = 1.1204744e-011      BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00061717463       LTVOFF     = 1.3378799e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.26051769         LKT1       = -1.7103456e-009
+KT1L       = 0                   KT2        = -0.062569441        LKT2       = -1.1037509e-010
+UTE        = -1                  UA1        = 3.5443587e-009      LUA1       = -2.0235433e-016
+UB1        = -4.2355728e-018     LUB1       = 2.6255893e-025      UC1        = -7.2445427e-010
+LUC1       = 4.1808746e-017      PRT        = 0                   AT         = '138591.81+datp_hvt'
+LAT        = -0.0067562934       NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  WETA0      = '0+dweta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     WA0        = '0+dwa0p_hvt'
+PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'     WUB        = '0+dwubp_hvt'
+PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-005-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61229953+(dvthp_hvt+vthmisp_hvt)'
+WVTH0      = '-3.0107027e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '0.010141663+dk2p_hvt'
+WK2        = '-1.3920616e-008+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '6.1111067e-006+dcitp_hvt'
+WCIT       = '-1.1333288e-012+dwcitp_hvt'
+VOFF       = '-0.11533828+dvoffp_hvt'
+WVOFF      = '-1.598516e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01548252+du0p_hvt'
+WU0        = '1.7515494e-010+dwu0p_hvt'
+UA         = 2.2249533e-009      WUA        = -4.303924e-016      UB         = '2.2806161e-020+dubp_hvt'
+WUB        = '7.1516681e-027+dwubp_hvt'
+UC         = -1.4579133e-010     WUC        = -1.2934484e-016     VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9316529+da0p_hvt'
+WA0        = '5.0782806e-008+dwa0p_hvt'
+AGS        = 0.69754533          WAGS       = -3.452224e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0027765867        WKETA      = 2.5024082e-008      DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00069773333+dpdiblc2p_hvt'
+WPDIBLC2   = 2.2712e-011         PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.013307733         WAIGBACC   = 2.2712e-011
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067383933
+WAIGC      = 2.61188e-011        BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063455           WAIGSD     = 8.517e-011          BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00080628          LTVOFF     = 0                   WTVOFF     = 1.975944e-010
+PTVOFF     = 0                   KT1        = -0.23137449         WKT1       = 2.9804351e-008
+KT1L       = 0                   KT2        = -0.062              UTE        = -0.99988667
+WUTE       = -1.1356e-009        UA1        = 3.3109785e-009      WUA1       = -6.4070122e-016
+UB1        = -3.5034667e-018     WUB1       = 6.35936e-025        UC1        = 1.5566667e-010
+WUC1       = -5.678e-017         PRT        = 0                   AT         = '158866.67+datp_hvt'
+WAT        = 0.011356            NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'
+PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1e-005-(dxlp_hvt+dlmisp_hvt)'   WMIN       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-005-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61180329+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-4.9446453e-009+dlvthp_hvt'
+WVTH0      = '-3.2602297e-009+dwvthp_hvt'
+PVTH0      = '2.486314e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.010100557+dk2p_hvt'
+LK2        = '4.0958863e-010+dlk2p_hvt'
+WK2        = '-1.4152563e-008+dwk2p_hvt'
+PK2        = '2.3111375e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.3558524e-006+dcitp_hvt'
+LCIT       = '1.4415037e-010+dlcitp_hvt'
+WCIT       = '1.3622969e-011+dwcitp_hvt'
+PCIT       = '-1.4703338e-016+dpcitp_hvt'
+VOFF       = '-0.11472162+dvoffp_hvt'
+LVOFF      = '-6.1444404e-009+dlvoffp_hvt'
+WVOFF      = '-1.5727245e-008+dwvoffp_hvt'
+PVOFF      = '-2.5698902e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015462922+du0p_hvt'
+LU0        = '1.9527577e-010+dlu0p_hvt'
+WU0        = '1.8905216e-010+dwu0p_hvt'
+PU0        = '-1.3847334e-016+dpu0p_hvt'
+UA         = 2.2229673e-009      LUA        = 1.9789386e-017      WUA        = -4.3732641e-016
+PUA        = 6.9091215e-023      UB         = '2.2282248e-020+dubp_hvt'
+LUB        = '5.2203233e-027+dlubp_hvt'
+WUB        = '8.5067435e-027+dwubp_hvt'
+PUB        = '-1.350212e-032+dpubp_hvt'
+UC         = -1.5148622e-010     LUC        = 5.6744517e-017      WUC        = -1.2595083e-016
+PUC        = -3.3818332e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.937358+da0p_hvt'
+LA0        = '-5.6845594e-008+dla0p_hvt'
+WA0        = '6.6308526e-008+dwa0p_hvt'
+PA0        = '-1.5469998e-013+dpa0p_hvt'
+AGS        = 0.67532224          LAGS       = 2.2143334e-007      WAGS       = -3.5860382e-008
+PAGS       = 1.3333392e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.0055851012
+LKETA      = -2.7984348e-008     WKETA      = 2.4773363e-008      PKETA      = 2.4981929e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00067845556+dpdiblc2p_hvt'
+LPDIBLC2   = 1.9208584e-010      WPDIBLC2   = -6.4705156e-011     PPDIBLC2   = 8.7103416e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.013305348         LAIGBACC   = 2.3767188e-011      WAIGBACC   = 2.5144985e-011
+PAIGBACC   = -2.4242532e-017     BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067373785        LAIGC      = 1.0111729e-011      WAIGC      = 2.770024e-011
+PAIGC      = -1.5757646e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063484416        LAIGSD     = -2.9310493e-011     WAIGSD     = 7.8235992e-011
+PAIGSD     = 6.9091215e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00072432279
+LTVOFF     = 8.1663061e-010      WTVOFF     = 4.6923719e-010      PTVOFF     = -2.7066787e-015
+KT1        = -0.23287197         LKT1       = 1.4921105e-008      WKT1       = 3.7159845e-008
+PKT1       = -7.329095e-014      KT1L       = 0                   KT2        = -0.061498663
+LKT2       = -4.995379e-009      WKT2       = -7.2989554e-010     PKT2       = 7.2727595e-015
+UTE        = -0.99987453         LUTE       = -1.2097072e-010     WUTE       = -1.2572493e-009
+PUTE       = 1.2121266e-015      UA1        = 3.3871642e-009      LUA1       = -7.591229e-016
+WUA1       = -7.8212933e-016     PUA1       = 1.4092052e-021      UB1        = -3.5249985e-018
+LUB1       = 2.1454512e-025      WUB1       = 6.9067817e-025      PUB1       = -5.4545696e-031
+UC1        = 1.7769837e-010      LUC1       = -2.1952627e-016     WUC1       = -6.2862463e-017
+PUC1       = 6.0606329e-023      PRT        = 0                   AT         = '162323.18+datp_hvt'
+LAT        = -0.034441075        WAT        = 0.0089230149        PAT        = 2.4242532e-008
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61596443+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-9.3284166e-010+dlvthp_hvt'
+WVTH0      = '3.0336679e-010+dwvthp_hvt'
+PVTH0      = '-9.4938494e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.010146379+dk2p_hvt'
+LK2        = '3.6541093e-010+dlk2p_hvt'
+WK2        = '-1.1751499e-008+dwk2p_hvt'
+PK2        = '-3.7520902e-018+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-5.1890394e-005+dcitp_hvt'
+LCIT       = '1.8612246e-010+dlcitp_hvt'
+WCIT       = '-3.5147862e-011+dwcitp_hvt'
+PCIT       = '-1.0001293e-016+dpcitp_hvt'
+VOFF       = '-0.11940365+dvoffp_hvt'
+LVOFF      = '-1.630445e-009+dlvoffp_hvt'
+WVOFF      = '-1.8661273e-008+dwvoffp_hvt'
+PVOFF      = '2.588358e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015731779+du0p_hvt'
+LU0        = '-6.3932258e-011+dlu0p_hvt'
+WU0        = '-2.2214447e-011+dwu0p_hvt'
+PU0        = '6.5210903e-017+dpu0p_hvt'
+UA         = 2.2824572e-009      LUA        = -3.7565491e-017     WUA        = -3.9485453e-016
+PUA        = 2.8143653e-023      UB         = '3.2122294e-020+dubp_hvt'
+LUB        = '-4.2665633e-027+dlubp_hvt'
+WUB        = '-6.4005179e-027+dwubp_hvt'
+PUB        = '8.7011938e-034+dpubp_hvt'
+UC         = -9.9178128e-011     LUC        = 6.3137588e-018      WUC        = -1.7324572e-016
+PUC        = 1.1779148e-023      VSAT       = '80000+dvsatp_hvt'  A0         = '1.8541774+da0p_hvt'
+LA0        = '2.3349608e-008+dla0p_hvt'
+WA0        = '-3.680289e-008+dwa0p_hvt'
+PA0        = '-5.5289236e-014+dpa0p_hvt'
+AGS        = 0.54517566          LAGS       = 3.4690896e-007      WAGS       = -4.3734454e-009
+PAGS       = -1.7023478e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.010393893
+LKETA      = -1.257884e-008      WKETA      = 2.2653713e-008      PKETA      = 4.5417678e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.48952403+dpclmp_hvt'
+LPCLM      = '6.6307604e-008+dlpclmp_hvt'
+WPCLM      = '-1.5414446e-008+dwpclmp_hvt'
+PPCLM      = '1.4861222e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0009960922+dpdiblc2p_hvt'
+LPDIBLC2   = -1.1415082e-010     WPDIBLC2   = 1.1016897e-009      PPDIBLC2   = -2.5349881e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 5.9529652e-009
+LAGIDL     = 1.0094567e-015      WAGIDL     = 1.0679755e-015      PAGIDL     = -1.0296458e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067463808        LAIGC      = 1.4325823e-012      WAIGC      = 2.310373e-011
+PAIGC      = -1.1326104e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063062363        LAIGSD     = 1.1380063e-011      WAIGSD     = 1.8336243e-010
+PAIGSD     = -3.2262236e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0017455958
+LTVOFF     = -1.6798891e-010     WTVOFF     = -3.0224167e-009     PTVOFF     = 6.5965977e-016
+KT1        = -0.2115147          LKT1       = -5.6696539e-009     WKT1       = -5.5311421e-008
+PKT1       = 1.5861523e-014      KT1L       = 0                   KT2        = -0.066914966
+LKT2       = 2.2653337e-010      WKT2       = 7.6288213e-009      PKT2       = -7.8596299e-016
+UTE        = -0.99518489         LUTE       = -4.6422919e-009     WUTE       = 4.9126872e-008
+PUTE       = -4.7363709e-014     UA1        = 3.4120518e-009      LUA1       = -7.8311729e-016
+WUA1       = 9.1860953e-016      PUA1       = -2.304941e-022      UB1        = -4.4075377e-018
+LUB1       = 1.06541e-024        WUB1       = 2.3527347e-025      PUB1       = -1.0639674e-031
+UC1        = -4.4670781e-011     LUC1       = -5.1379533e-018     WUC1       = -5.3398774e-017
+PUC1       = 5.1482292e-023      PRT        = 0                   AT         = '126846.61+datp_hvt'
+LAT        = -0.00023775627      WAT        = 0.050443624         PAT        = -1.5787903e-008
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-7.2984626e-010+dlvthp_hvt'
+WVTH0      = '-9.7044399e-009+dwvthp_hvt'
+PVTH0      = '1.3534114e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2p_hvt'
+LK2        = '5.9104693e-010+dlk2p_hvt'
+WK2        = '-1.0179173e-008+dwk2p_hvt'
+PK2        = '-3.6554416e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitp_hvt'
+LCIT       = '1.4213307e-010+dlcitp_hvt'
+WCIT       = '-4.6699281e-010+dwcitp_hvt'
+PCIT       = '-6.4541088e-019+dpcitp_hvt'
+VOFF       = '-0.11759164+dvoffp_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffp_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffp_hvt'
+PVOFF      = '1.6253402e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0p_hvt'
+LU0        = '1.7777142e-010+dlu0p_hvt'
+WU0        = '1.018685e-009+dwu0p_hvt'
+PU0        = '-1.7430005e-016+dpu0p_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubp_hvt'
+LUB        = '-8.2046654e-029+dlubp_hvt'
+WUB        = '1.8606441e-027+dwubp_hvt'
+PUB        = '-1.030774e-033+dpubp_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.8037767+da0p_hvt'
+LA0        = '3.4946811e-008+dla0p_hvt'
+WA0        = '-6.0772635e-007+dwa0p_hvt'
+PA0        = '7.6080253e-014+dpa0p_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmp_hvt'
+LPCLM      = '3.3020183e-009+dlpclmp_hvt'
+WPCLM      = '1.7467444e-008+dwpclmp_hvt'
+PPCLM      = '7.2950988e-015+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datp_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-005-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-3.0821854e-010+dlvthp_hvt'
+WVTH0      = '6.2963879e-009+dwvthp_hvt'
+PVTH0      = '-2.2267017e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2p_hvt'
+LK2        = '-2.378406e-009+dlk2p_hvt'
+WK2        = '-3.2823766e-008+dwk2p_hvt'
+PK2        = '1.8649482e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitp_hvt'
+LCIT       = '2.7955334e-010+dlcitp_hvt'
+WCIT       = '-5.1403406e-010+dwcitp_hvt'
+PCIT       = '3.988153e-018+dpcitp_hvt'
+VOFF       = '-0.094349901+dvoffp_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffp_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffp_hvt'
+PVOFF      = '2.1065519e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0016702266+deta0p_hvt'
+LETA0      = '3.5030935e-010+dleta0p_hvt'
+WETA0      = '-4.0623502e-009+dweta0p_hvt'
+PETA0      = '1.7642829e-016+dpeta0p_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0p_hvt'
+LU0        = '-3.7049814e-010+dlu0p_hvt'
+WU0        = '-1.7061645e-009+dwu0p_hvt'
+PU0        = '9.4097621e-017+dpu0p_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubp_hvt'
+LUB        = '6.3755797e-028+dlubp_hvt'
+WUB        = '-1.488923e-026+dwubp_hvt'
+PUB        = '6.1908859e-034+dpubp_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatp_hvt+384.85*ff_flag_hvt'
+A0         = '2.8058311+da0p_hvt'
+LA0        = '-6.375555e-008+dla0p_hvt'
+WA0        = '5.861974e-008+dwa0p_hvt'
+PA0        = '1.0445163e-014+dpa0p_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmp_hvt'
+LPCLM      = '1.4911452e-008+dlpclmp_hvt'
+WPCLM      = '4.4648173e-007+dwpclmp_hvt'
+PPCLM      = '-3.4962808e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2p_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datp_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt-3.79076e-05*ff_flag_hvt'
+WVSAT      = '0+dwvsatp_hvt-0.00385619*ff_flag_hvt'
+PVSAT      = '0+dpvsatp_hvt+3.79834e-10*ff_flag_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = 2.001e-05           WMIN       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-006-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61125883+(dvthp_hvt+vthmisp_hvt)'
+WVTH0      = '-4.0722196e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.0002448+dk2p_hvt'
+WK2        = '-3.326424e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.11496425+dvoffp_hvt'
+WVOFF      = '-1.636667e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01565424+du0p_hvt'
+UA         = 2.06805e-009        WUA        = -2.70351e-016       UB         = '2.375152e-020+dubp_hvt'
+WUB        = '6.1874016e-027+dwubp_hvt'
+UC         = -2.77715e-010       WUC        = 5.2173e-018         VSAT       = '80000+dvsatp_hvt'
+A0         = '2.0352044+da0p_hvt'
+WA0        = '-5.4839704e-008+dwa0p_hvt'
+AGS        = 0.65564             WAGS       = 8.2212e-009         A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0231715           WKETA      = 4.22127e-009        DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.001061+dpdiblc2p_hvt'
+WPDIBLC2   = -3.4782e-010        PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067268           WAIGC      = 3.7944e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0064972
+WAIGSD     = -6.9564e-011        BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0004854
+LTVOFF     = 0                   WTVOFF     = 5.24892e-010        PTVOFF     = 0
+KT1        = -0.23359227         WKT1       = 3.206649e-008       KT1L       = 0
+KT2        = -0.0837             WKT2       = 2.2134e-008         UTE        = -1.00255
+WUTE       = 1.581e-009          UA1        = 2.548672e-009       WUA1       = 1.3685136e-016
+UB1        = -2.7095e-018        WUB1       = -1.7391e-025        UC1        = -5.5e-011
+WUC1       = 1.581e-016          PRT        = 0                   AT         = '201000+datp_hvt'
+WAT        = -0.03162            NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'
+WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     LU0        = '0+dlu0p_hvt'       WU0        = '0+dwu0p_hvt'
+PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'
+PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'       PA0        = '0+dpa0p_hvt'
+LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'     LUB        = '0+dlubp_hvt'
+PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1e-005-(dxlp_hvt+dlmisp_hvt)'   WMIN       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-006-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61062935+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-6.2721597e-009+dlvthp_hvt'
+WVTH0      = '-4.4576408e-009+dwvthp_hvt'
+PVTH0      = '3.8403787e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.00076317335+dk2p_hvt'
+LK2        = '5.165129e-009+dlk2p_hvt'
+WK2        = '-3.0715579e-009+dwk2p_hvt'
+PK2        = '-2.5395137e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.11307253+dvoffp_hvt'
+LVOFF      = '-1.8849246e-008+dlvoffp_hvt'
+WVOFF      = '-1.7409313e-008+dwvoffp_hvt'
+PVOFF      = '1.0389012e-014+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015658701+du0p_hvt'
+LU0        = '-4.4448199e-011+dlu0p_hvt'
+WU0        = '-1.0642708e-011+dwu0p_hvt'
+PU0        = '1.0604511e-016+dpu0p_hvt'
+UA         = 2.0622546e-009      LUA        = 5.7745727e-017      WUA        = -2.7339952e-016
+PUA        = 3.0375747e-023      UB         = '2.3581866e-020+dubp_hvt'
+LUB        = '1.6904501e-027+dlubp_hvt'
+WUB        = '7.1811331e-027+dwubp_hvt'
+PUB        = '-9.9016497e-033+dpubp_hvt'
+UC         = -2.8634218e-010     LUC        = 8.5962147e-017      WUC        = 1.1602247e-017
+PUC        = -6.3620315e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '2.1050058+da0p_hvt'
+LA0        = '-6.9550813e-007+dla0p_hvt'
+WA0        = '-1.0469221e-007+dwa0p_hvt'
+PA0        = '4.9673581e-013+dpa0p_hvt'
+AGS        = 0.63185714          LAGS       = 2.3697506e-007      WAGS       = 8.4740236e-009
+PAGS       = -2.519162e-015      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.027363574
+LKETA      = -4.1770281e-008     WKETA      = 2.5593208e-009      PKETA      = 1.6559845e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0011621759+dpdiblc2p_hvt'
+LPDIBLC2   = -1.0081273e-009     WPDIBLC2   = -5.5809985e-010     PPDIBLC2   = 2.0952515e-015
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7.1660412e-009
+LAGIDL     = -1.6544525e-015     WAGIDL     = -1.6936199e-016     PAGIDL     = 1.6875415e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067238488        LAIGC      = 2.9406558e-011      WAIGC      = 4.1500602e-011
+PAIGC      = -3.5438372e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0065014796        LAIGSD     = -4.2642178e-011     WAIGSD     = -7.7862738e-011
+PAIGSD     = 8.2689533e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00073434927
+LTVOFF     = -2.4805579e-009     WTVOFF     = 4.5901019e-010      PTVOFF     = 6.5645364e-016
+KT1        = -0.22642694         LKT1       = -7.139614e-008      WKT1       = 3.0585913e-008
+PKT1       = 1.475264e-014       KT1L       = 0                   KT2        = -0.086238823
+LKT2       = 2.5297112e-008      WKT2       = 2.4505068e-008      PKT2       = -2.3625581e-014
+UTE        = -1.0028232          LUTE       = 2.7218411e-009      WUTE       = 1.750362e-009
+PUTE       = -1.6875415e-015     UA1        = 2.4093999e-009      LUA1       = 1.3877227e-015
+WUA1       = 2.1519025e-016      PUA1       = -7.8057732e-022     UB1        = -2.6242298e-018
+LUB1       = -8.4964139e-025     WUB1       = -2.2810584e-025     PUB1       = 5.4001328e-031
+UC1        = -5.5535617e-011     LUC1       = 5.3369434e-018      WUC1       = 1.750362e-016
+PUC1       = -1.6875415e-022     PRT        = 0                   AT         = '203731.65+datp_hvt'
+LAT        = -0.027218411        WAT        = -0.03331362         PAT        = 1.6875415e-008
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61554806+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-1.5299835e-009+dlvthp_hvt'
+WVTH0      = '-1.2133172e-010+dwvthp_hvt'
+PVTH0      = '-3.4030025e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0039528553+dk2p_hvt'
+LK2        = '6.1835871e-010+dlk2p_hvt'
+WK2        = '-5.4341046e-009+dwk2p_hvt'
+PK2        = '-2.6175882e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00016326695+dcitp_hvt'
+LCIT       = '1.6222785e-010+dlcitp_hvt'
+WCIT       = '7.8456228e-011+dwcitp_hvt'
+PCIT       = '-7.5640434e-017+dpcitp_hvt'
+VOFF       = '-0.13509166+dvoffp_hvt'
+LVOFF      = '2.3796189e-009+dlvoffp_hvt'
+WVOFF      = '-2.6595015e-009+dwvoffp_hvt'
+PVOFF      = '-3.8314293e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015786336+du0p_hvt'
+LU0        = '-1.6750272e-010+dlu0p_hvt'
+WU0        = '-7.7862904e-011+dwu0p_hvt'
+PU0        = '1.7085277e-016+dpu0p_hvt'
+UA         = 2.1436706e-009      LUA        = -2.0748264e-017     WUA        = -2.532922e-016
+PUA        = 1.0990082e-023      UB         = '3.5198781e-020+dubp_hvt'
+LUB        = '-9.509534e-027+dlubp_hvt'
+WUB        = '-9.5385351e-027+dwubp_hvt'
+PUB        = '6.2179495e-033+dpubp_hvt'
+UC         = -2.2887475e-010     LUC        = 3.0557222e-017      WUC        = -4.095517e-017
+PUC        = -1.2949184e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.3900194+da0p_hvt'
+LA0        = '-6.1826503e-009+dla0p_hvt'
+WA0        = '4.3663828e-007+dwa0p_hvt'
+PA0        = '-2.5166332e-014+dpa0p_hvt'
+AGS        = 0.43032981          LAGS       = 4.3126957e-007      WAGS       = 1.1276932e-007
+PAGS       = -1.030713e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.0068503314
+LKETA      = -8.7843134e-009     WKETA      = 1.9039281e-008      PKETA      = 6.7135067e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.60978339+dpclmp_hvt'
+LPCLM      = '-4.9635651e-008+dlpclmp_hvt'
+WPCLM      = '-1.38079e-007+dwpclmp_hvt'
+PPCLM      = '1.3312334e-013+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-3.6946401e-006+dpdiblc2p_hvt'
+LPDIBLC2   = 1.1590014e-010      WPDIBLC2   = 2.1214723e-009      PPDIBLC2   = -4.8815078e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 5.9358994e-009
+LAGIDL     = -4.6846045e-016     WAGIDL     = 1.0853826e-015      PAGIDL     = 4.7782966e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068008239        LAIGC      = -4.4805975e-011     WAIGC      = -3.2428302e-011
+PAIGC      = 3.5837224e-017      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063732991        LAIGSD     = 8.0937876e-011      WAIGSD     = 1.1495835e-010
+PAIGSD     = -1.0321121e-016     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0022457023
+LTVOFF     = 3.9253963e-010      WTVOFF     = 1.0487074e-009      PTVOFF     = 8.7920657e-017
+KT1        = -0.30383985         LKT1       = 3.2384172e-009      WKT1       = 3.8860227e-008
+PKT1       = 6.77529e-015        KT1L       = 0                   KT2        = -0.056881843
+LKT2       = -3.0062467e-009     WKT2       = -2.6049649e-009     PKT2       = 2.5114727e-015
+UTE        = -0.95965468         LUTE       = -3.8897329e-008     WUTE       = 1.2886051e-008
+PUTE       = -1.2423571e-014     UA1        = 5.0021852e-009      LUA1       = -1.1120075e-015
+WUA1       = -7.0332653e-016     PUA1       = 1.049739e-022       UB1        = -4.5013337e-018
+LUB1       = 9.6009324e-025      WUB1       = 3.3094541e-025      PUB1       = 1.0263781e-033
+UC1        = -9.702252e-011      LUC1       = 4.5334882e-017      PRT        = 0
+AT         = '168477.97+datp_hvt'
+LAT        = 0.006770009         WAT        = 0.0079796334        PAT        = -2.2935823e-008
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '1.4188652e-009+dlvthp_hvt'
+WVTH0      = '2.0428322e-009+dwvthp_hvt'
+PVTH0      = '-8.3827437e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2p_hvt'
+LK2        = '-5.8855075e-010+dlk2p_hvt'
+WK2        = '-1.0212046e-008+dwk2p_hvt'
+PK2        = '8.3764547e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitp_hvt'
+LCIT       = '1.2700497e-010+dlcitp_hvt'
+WCIT       = '-3.1452806e-010+dwcitp_hvt'
+PCIT       = '1.478525e-017+dpcitp_hvt'
+VOFF       = '-0.1071063+dvoffp_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffp_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffp_hvt'
+PVOFF      = '3.6780146e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0p_hvt'
+LU0        = '2.8729247e-010+dlu0p_hvt'
+WU0        = '1.9076404e-009+dwu0p_hvt'
+PU0        = '-2.8601153e-016+dpu0p_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubp_hvt'
+LUB        = '1.9066399e-027+dlubp_hvt'
+WUB        = '3.0779517e-026+dwubp_hvt'
+PUB        = '-3.0592342e-033+dpubp_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatp_hvt'  A0         = '-0.4400886+da0p_hvt'
+LA0        = '4.149252e-007+dla0p_hvt'
+WA0        = '1.6810163e-006+dwa0p_hvt'
+PA0        = '-3.1149771e-013+dpa0p_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmp_hvt'
+LPCLM      = '1.2227911e-007+dlpclmp_hvt'
+WPCLM      = '9.3617077e-007+dwpclmp_hvt'
+PPCLM      = '-1.1406153e-013+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datp_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '1e-006-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-1.262382e-009+dlvthp_hvt'
+WVTH0      = '-1.4087635e-008+dwvthp_hvt'
+PVTH0      = '7.505766e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2p_hvt'
+LK2        = '-1.0794234e-009+dlk2p_hvt'
+WK2        = '-7.190122e-009+dwk2p_hvt'
+PK2        = '5.3998597e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitp_hvt'
+LCIT       = '9.8047363e-011+dlcitp_hvt'
+WCIT       = '-2.0844672e-009+dwcitp_hvt'
+PCIT       = '1.8912425e-016+dpcitp_hvt'
+VOFF       = '-0.12945599+dvoffp_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffp_hvt'
+WVOFF      = '6.3228005e-009+dwvoffp_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '-0.0055935647+deta0p_hvt'
+LETA0      = '8.1593113e-010+dleta0p_hvt'
+WETA0      = '3.3467169e-009+dweta0p_hvt'
+PETA0      = '-2.9850592e-016+dpeta0p_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0p_hvt'
+LU0        = '-6.3113981e-010+dlu0p_hvt'
+WU0        = '-4.6503664e-009+dwu0p_hvt'
+PU0        = '3.5995213e-016+dpu0p_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubp_hvt'
+LUB        = '7.2916293e-029+dlubp_hvt'
+WUB        = '-1.2410913e-026+dwubp_hvt'
+PUB        = '1.1950231e-033+dpubp_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatp_hvt-8659.12*ff_flag_hvt'
+A0         = '6.2698767+da0p_hvt'
+LA0        = '-2.4600638e-007+dla0p_hvt'
+WA0        = '-3.4747068e-006+dwa0p_hvt'
+PA0        = '1.9634101e-013+dpa0p_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmp_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmp_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmp_hvt'
+PPCLM      = '8.7145749e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2p_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datp_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt+0.000852921*ff_flag_hvt'
+WVSAT      = '0+dwvsatp_hvt+0.00536865*ff_flag_hvt'
+PVSAT      = '0+dpvsatp_hvt-5.28811e-10*ff_flag_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = 2.001e-05           WMIN       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '6e-007-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60946352+(dvthp_hvt+vthmisp_hvt)'
+WVTH0      = '-5.185311e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.0078104336+dk2p_hvt'
+WK2        = '1.3642688e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.1239429+dvoffp_hvt'
+WVOFF      = '-1.0799904e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015256672+du0p_hvt'
+WU0        = '2.4649216e-010+dwu0p_hvt'
+UA         = 1.9008e-009         WUA        = -1.66656e-016       UB         = '6.2627968e-020+dubp_hvt'
+WUB        = '-1.7915996e-026+dwubp_hvt'
+UC         = -3.4706e-010        WUC        = 4.82112e-017        VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9467547+da0p_hvt'
+WA0        = '-8.4650667e-013+dwa0p_hvt'
+AGS        = 0.66356667          WAGS       = 3.3066667e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.032593333         WKETA      = -1.6202667e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00018+dpdiblc2p_hvt'
+WPDIBLC2   = 1.984e-010          PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067954667        WAIGC      = -4.6293333e-012
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0062346
+WAIGSD     = 9.3248e-011         BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0022290667
+LTVOFF     = 0                   WTVOFF     = -5.5618133e-010     PTVOFF     = 0
+KT1        = -0.18142866         WKT1       = -2.7494801e-010     KT1L       = 0
+KT2        = -0.043733333        WKT2       = -2.6453333e-009     UTE        = -0.8688
+WUTE       = -8.1344e-008        UA1        = 3.0774107e-009      WUA1       = -1.9096661e-016
+UB1        = -3.2566667e-018     WUB1       = 1.6533333e-025      UC1        = 3.1221333e-010
+WUC1       = -6.9572267e-017     PRT        = 0                   AT         = '150000+datp_hvt'
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'      LK2        = '0+dlk2p_hvt'
+PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'
+PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1e-005-(dxlp_hvt+dlmisp_hvt)'   WMIN       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '6e-007-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60953143+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '6.7664387e-010+dlvthp_hvt'
+WVTH0      = '-5.1383545e-009+dwvthp_hvt'
+PVTH0      = '-4.6787951e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.0078994556+dk2p_hvt'
+LK2        = '8.8702447e-010+dlk2p_hvt'
+WK2        = '1.3529371e-009+dwk2p_hvt'
+PK2        = '1.1291113e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.12326781+dvoffp_hvt'
+LVOFF      = '-6.7266941e-009+dlvoffp_hvt'
+WVOFF      = '-1.1088242e-008+dwvoffp_hvt'
+PVOFF      = '2.8730295e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015215739+du0p_hvt'
+LU0        = '4.0785918e-010+dlu0p_hvt'
+WU0        = '2.6399352e-010+dwu0p_hvt'
+PU0        = '-1.7438547e-016+dpu0p_hvt'
+UA         = 1.8840316e-009      LUA        = 1.6708191e-016      WUA        = -1.6290126e-016
+PUA        = -3.7412685e-023     UB         = '6.9551697e-020+dubp_hvt'
+LUB        = '-6.8988797e-026+dlubp_hvt'
+WUB        = '-2.1320162e-026+dwubp_hvt'
+PUB        = '3.3919484e-032+dpubp_hvt'
+UC         = -3.4529746e-010     LUC        = -1.7562102e-017     WUC        = 4.8154525e-017
+PUC        = 5.6471977e-025      VSAT       = '80000+dvsatp_hvt'  A0         = '1.9042621+da0p_hvt'
+LA0        = '4.2340038e-007+dla0p_hvt'
+WA0        = '1.9768854e-008+dwa0p_hvt'
+PA0        = '-1.9698747e-013+dpa0p_hvt'
+AGS        = 0.64171048          LAGS       = 2.1777741e-007      WAGS       = 2.3649485e-009
+PAGS       = 9.3833837e-015      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.034535622
+LKETA      = -1.935318e-008      WKETA      = -1.8873494e-009     PKETA      = 2.6612419e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00022138005+dpdiblc2p_hvt'
+LPDIBLC2   = 3.999395e-009       WPDIBLC2   = 2.9970481e-010      PPDIBLC2   = -1.0094123e-015
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 6.7786118e-009
+LAGIDL     = 2.2059366e-015      WAGIDL     = 7.0844231e-017      PAGIDL     = -7.0589971e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067298072        LAIGC      = 6.542381e-010       WAIGC      = 3.7806361e-011
+PAIGC      = -4.2283393e-016     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006204127         LAIGSD     = 3.036365e-010       WAIGSD     = 1.0649587e-010
+PAIGSD     = -1.3200325e-016     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0024678517
+LTVOFF     = -2.3792805e-009     WTVOFF     = -6.1576133e-010     PTVOFF     = 5.9366166e-016
+KT1        = -0.17487517         LKT1       = -6.5299718e-008     WKT1       = -1.3761862e-009
+PKT1       = 1.0972858e-014      KT1L       = 0                   KT2        = -0.041746715
+LKT2       = -1.9794885e-008     WKT2       = -3.0800392e-009     PKT2       = 4.3314571e-015
+UTE        = -0.86697176         LUTE       = -1.8216767e-008     WUTE       = -8.2477508e-008
+PUTE       = 1.1294395e-014      UA1        = 3.0689205e-009      LUA1       = 8.4596957e-017
+WUA1       = -1.9371254e-016     PUA1       = 2.7360673e-023      UB1        = -3.2828048e-018
+LUB1       = 2.6044284e-025      WUB1       = 1.8021062e-025      PUB1       = -1.4823894e-031
+UC1        = 3.5101483e-010      LUC1       = -3.8662241e-016     WUC1       = -7.702508e-017
+PUC1       = 7.426065e-023       PRT        = 0                   AT         = '150000+datp_hvt'
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60497167+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-3.7194647e-009+dlvthp_hvt'
+WVTH0      = '-6.6786949e-009+dwvthp_hvt'
+PVTH0      = '1.0171781e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.0071439048+dk2p_hvt'
+LK2        = '1.5859044e-010+dlk2p_hvt'
+WK2        = '1.4458866e-009+dwk2p_hvt'
+PK2        = '2.32975e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-7.9441997e-005+dcitp_hvt'
+LCIT       = '8.1411373e-011+dlcitp_hvt'
+WCIT       = '2.6484755e-011+dwcitp_hvt'
+PCIT       = '-2.5534217e-017+dpcitp_hvt'
+VOFF       = '-0.12333821+dvoffp_hvt'
+LVOFF      = '-6.6588147e-009+dlvoffp_hvt'
+WVOFF      = '-9.9466397e-009+dwvoffp_hvt'
+PVOFF      = '1.7723995e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015302442+du0p_hvt'
+LU0        = '3.2426812e-010+dlu0p_hvt'
+WU0        = '2.2215149e-010+dwu0p_hvt'
+PU0        = '-1.3404515e-016+dpu0p_hvt'
+UA         = 2.0644808e-009      LUA        = -6.8909021e-018     WUA        = -2.0419447e-016
+PUA        = 2.3985175e-024      UB         = '-1.9042134e-020+dubp_hvt'
+LUB        = '1.6425402e-026+dlubp_hvt'
+WUB        = '2.4090833e-026+dwubp_hvt'
+PUB        = '-9.8617105e-033+dpubp_hvt'
+UC         = -3.8641853e-010     LUC        = 2.2083125e-017      WUC        = 5.6721974e-017
+PUC        = -7.6952436e-024     VSAT       = '80000+dvsatp_hvt'  A0         = '2.466526+da0p_hvt'
+LA0        = '-1.186839e-007+dla0p_hvt'
+WA0        = '-2.3079583e-007+dwa0p_hvt'
+PA0        = '4.4584443e-014+dpa0p_hvt'
+AGS        = 0.62045294          LAGS       = 2.3827202e-007      WAGS       = -5.1070245e-009
+PAGS       = 1.6587188e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.023873986
+LKETA      = -9.0741897e-009     WKETA      = -9.7960693e-012     PKETA      = 8.5107395e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.29963434+dpclmp_hvt'
+LPCLM      = '2.4938215e-007+dlpclmp_hvt'
+WPCLM      = '5.4213413e-008+dwpclmp_hvt'
+PPCLM      = '-5.2267694e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.005001172+dpdiblc2p_hvt'
+LPDIBLC2   = -1.0357197e-009     WPDIBLC2   = -9.8154501e-010     PPDIBLC2   = 2.2585351e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 8.4188008e-009
+LAGIDL     = 6.2461393e-016      WAGIDL     = -4.5401627e-016     PAGIDL     = -1.9987646e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0075985591        LAIGC      = -1.8333426e-010     WAIGC      = -5.2702409e-010
+PAIGC      = 1.2172476e-016      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006620489         LAIGSD     = -9.7782303e-011     WAIGSD     = -3.8299382e-011
+PAIGSD     = 7.5953054e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0011137942
+LTVOFF     = 1.0738202e-009      WTVOFF     = 3.4692438e-010      PTVOFF     = -3.3447326e-016
+KT1        = -0.27645852         LKT1       = 3.2637808e-008      WKT1       = 2.1883805e-008
+PKT1       = -1.1452332e-014     KT1L       = 0                   KT2        = -0.066569307
+LKT2       = 4.1368237e-009      WKT2       = 3.4012628e-009      PKT2       = -1.917231e-015
+UTE        = -0.72375392         LUTE       = -1.5629452e-007     WUTE       = -1.3337242e-007
+PUTE       = 6.036269e-014       UA1        = 5.1540208e-009      LUA1       = -1.9256691e-015
+WUA1       = -7.9746463e-016     PUA1       = 6.0944411e-022      UB1        = -5.0007075e-018
+LUB1       = 1.9166901e-024      WUB1       = 6.4055717e-025      PUB1       = -5.9206365e-031
+UC1        = -1.4717988e-010     LUC1       = 9.3692089e-017      WUC1       = 3.109756e-017
+PUC1       = -2.9981469e-023     PRT        = 0                   AT         = '181716.17+datp_hvt'
+LAT        = -0.030577874        WAT        = -0.00022804877      PAT        = 2.198641e-010
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62344662+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '5.3162157e-010+dlvthp_hvt'
+WVTH0      = '-1.0056772e-009+dwvthp_hvt'
+PVTH0      = '-2.8818329e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.010828147+dk2p_hvt'
+LK2        = '1.0063345e-009+dlk2p_hvt'
+WK2        = '2.2041694e-009+dwk2p_hvt'
+PK2        = '-1.5118335e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00036434146+dcitp_hvt'
+LCIT       = '1.4696674e-010+dlcitp_hvt'
+WCIT       = '-9.4954476e-011+dwcitp_hvt'
+PCIT       = '2.4089498e-018+dpcitp_hvt'
+VOFF       = '-0.16938362+dvoffp_hvt'
+LVOFF      = '3.9362323e-009+dlvoffp_hvt'
+WVOFF      = '3.3168691e-009+dwvoffp_hvt'
+PVOFF      = '-1.2795339e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.018908997+du0p_hvt'
+LU0        = '-5.0560022e-010+dlu0p_hvt'
+WU0        = '-1.2538463e-009+dwu0p_hvt'
+PU0        = '2.0558194e-016+dpu0p_hvt'
+UA         = 2.4318766e-009      LUA        = -9.1428673e-017     WUA        = -3.4127916e-016
+PUA        = 3.3941704e-023      UB         = '1.0514043e-019+dubp_hvt'
+LUB        = '-1.2149006e-026+dlubp_hvt'
+WUB        = '-4.3344965e-026+dwubp_hvt'
+PUB        = '5.6552664e-033+dpubp_hvt'
+UC         = -2.8434905e-010     LUC        = -1.4030621e-018     WUC        = -8.2731996e-019
+PUC        = 5.5468489e-024      VSAT       = '80000+dvsatp_hvt'  A0         = '2.2721747+da0p_hvt'
+LA0        = '-7.3963649e-008+dla0p_hvt'
+WA0        = '-5.8695218e-010+dwa0p_hvt'
+PA0        = '-8.3866191e-015+dpa0p_hvt'
+AGS        = -0.062865982        LAGS       = 3.955037e-007       WAGS       = 1.3493275e-007
+PAGS       = -1.5635963e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.015770614
+LKETA      = -7.2096038e-009     WKETA      = -1.1097571e-008     PKETA      = 3.402371e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '1.8738875+dpclmp_hvt'
+LPCLM      = '-1.128535e-007+dlpclmp_hvt'
+WPCLM      = '-3.1079476e-007+dwpclmp_hvt'
+PPCLM      = '3.1720686e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.4227052e-008
+LAGIDL     = -7.1186459e-016     WAGIDL     = -2.3126565e-015     PAGIDL     = 2.2779667e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067904231        LAIGC      = 2.6178246e-012      WAIGC      = 3.4689848e-012
+PAIGC      = -3.41695e-019       BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0060709363        LAIGSD     = 2.8669772e-011      WAIGSD     = -9.2506261e-012
+PAIGSD     = 9.1118668e-019      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0059536555
+LTVOFF     = -5.5240003e-010     WTVOFF     = -2.005289e-009      PTVOFF     = 2.0677104e-016
+KT1        = -0.036864169        LKT1       = -2.2492852e-008     WKT1       = -5.3963786e-008
+PKT1       = 6.0001987e-015      KT1L       = 0                   KT2        = -0.040088397
+LKT2       = -1.9564335e-009     WKT2       = -8.8492812e-009     PKT2       = 9.0161922e-016
+UTE        = -1.6644192          LUTE       = 6.0152558e-008      WUTE       = 2.1261414e-007
+PUTE       = -1.9248819e-014     UA1        = -4.6503985e-009     LUA1       = 3.3032779e-016
+WUA1       = 2.4470503e-015      PUA1       = -1.3711879e-022     UB1        = 4.3837938e-018
+LUB1       = -2.4268369e-025     WUB1       = -2.4879715e-024     PUB1       = 1.2781079e-031
+UC1        = 6.8164387e-010      LUC1       = -9.7020255e-017     WUC1       = -1.9819899e-016
+PUC1       = 2.2779667e-023      PRT        = 0                   AT         = '23298.501+datp_hvt'
+LAT        = 0.005874031         WAT        = 0.023051738         PAT        = -5.1368149e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   WMAX       = '6e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62909134+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '1.0876261e-009+dlvthp_hvt'
+WVTH0      = '3.2404668e-009+dwvthp_hvt'
+PVTH0      = '-7.0642847e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0034488545+dk2p_hvt'
+LK2        = '-3.9995015e-010+dlk2p_hvt'
+WK2        = '-5.3589046e-010+dwk2p_hvt'
+PK2        = '1.1871254e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0029965967+dcitp_hvt'
+LCIT       = '4.0624388e-010+dlcitp_hvt'
+WCIT       = '-5.0624166e-011+dwcitp_hvt'
+PCIT       = '-1.9575858e-018+dpcitp_hvt'
+VOFF       = '-0.083323642+dvoffp_hvt'
+LVOFF      = '-4.5406751e-009+dlvoffp_hvt'
+WVOFF      = '-2.2279257e-008+dwvoffp_hvt'
+PVOFF      = '1.2416845e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '-0.0037654749+deta0p_hvt'
+LETA0      = '6.0204594e-010+dleta0p_hvt'
+WETA0      = '2.2133012e-009+dweta0p_hvt'
+PETA0      = '-1.658971e-016+dpeta0p_hvt'
+ETAB       = -0.011349295        LETAB      = 3.6533273e-010      WETAB      = 1.8349744e-009
+PETAB      = -1.1690647e-016     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.012677915+du0p_hvt'
+LU0        = '1.0816134e-010+dlu0p_hvt'
+WU0        = '1.8324129e-009+dwu0p_hvt'
+PU0        = '-9.8414586e-017+dpu0p_hvt'
+UA         = 1.5154382e-009      LUA        = -1.1594959e-018     WUA        = 5.4956527e-017
+PUA        = -5.0875112e-024     UB         = '-1.1729084e-019+dubp_hvt'
+LUB        = '9.760474e-027+dlubp_hvt'
+WUB        = '6.2914214e-026+dwubp_hvt'
+PUB        = '-4.8112627e-033+dpubp_hvt'
+UC         = -6.5804385e-010     LUC        = 3.5405876e-017      WUC        = 1.9381767e-016
+PUC        = -1.3625682e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '-0.81406652+da0p_hvt'
+LA0        = '2.3003111e-007+dla0p_hvt'
+WA0        = '9.1733806e-007+dwa0p_hvt'
+PA0        = '-9.8802232e-014+dpa0p_hvt'
+AGS        = -5.0263359          LAGS       = 8.8440549e-007      WAGS       = 2.2398033e-006
+PAGS       = -2.2296571e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.20075656
+LKETA      = 1.4118323e-008      WKETA      = 9.0477925e-008      PKETA      = -6.6028153e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14323689+dpclmp_hvt'
+LPCLM      = '5.7615583e-008+dlpclmp_hvt'
+WPCLM      = '1.4884328e-007+dwpclmp_hvt'
+PPCLM      = '-1.3553661e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0037445427+dpdiblc2p_hvt'
+LPDIBLC2   = 4.1808746e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.007030925         LAIGC      = -2.1071608e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0061922183
+LAIGSD     = 1.6723498e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00034779709
+LTVOFF     = -2.2297998e-013     WTVOFF     = 2.0925836e-011      PTVOFF     = 7.1888745e-018
+KT1        = -0.16638377         LKT1       = -9.7351721e-009     WKT1       = -1.7094442e-008
+PKT1       = 2.3685683e-015      KT1L       = 0                   KT2        = -0.087134982
+LKT2       = 2.6776551e-009      WKT2       = 8.9162661e-009      PKT2       = -8.4828719e-016
+UTE        = -1.1449627          LUTE       = 8.9860931e-009      WUTE       = 4.6388066e-008
+PUTE       = -2.8755498e-015     UA1        = -4.7140308e-009     LUA1       = 3.3659557e-016
+WUA1       = 2.8460346e-015      PUA1       = -1.7641874e-022     UB1        = 6.3241376e-018
+LUB1       = -4.3380755e-025     WUB1       = -3.3967473e-024     PUB1       = 2.1732521e-031
+UC1        = -7.33447e-010       LUC1       = 4.2366196e-017      WUC1       = 8.9207819e-017
+PUC1       = -5.5299035e-024     PRT        = 0                   AT         = '160127.42+datp_hvt'
+LAT        = -0.0076036173       WAT        = -0.053800774        PAT        = 2.4331575e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60269827+(dvthp_hvt+vthmisp_hvt)'
+WVTH0      = '-7.3501919e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.024832611+dk2p_hvt'
+WK2        = '6.8113655e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.1579187+dvoffp_hvt'
+WVOFF      = '7.2352e-011+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015495489+du0p_hvt'
+WU0        = '1.7007076e-010+dwu0p_hvt'
+UA         = 1.8133e-009         WUA        = -1.38656e-016       UB         = '-9.9141467e-021+dubp_hvt'
+WUB        = '5.2974805e-027+dwubp_hvt'
+UC         = -2.8331667e-010     WUC        = 2.7813333e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '2.1848858+da0p_hvt'
+WA0        = '-7.6202819e-008+dwa0p_hvt'
+AGS        = 0.8260856           WAGS       = -4.8699392e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.038138889         WKETA      = -3.3948444e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00072222222+dpdiblc2p_hvt'
+WPDIBLC2   = 2.4888889e-011      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 1.1666667e-008      WAGIDL     = -1.4933333e-015     BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0066993333
+WAIGC      = 2.6133333e-011      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0071              WAIGSD     = -1.8368e-010        BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 9.5111111e-005      LTVOFF     = 0                   WTVOFF     = 1.2668444e-010
+PTVOFF     = 0                   KT1        = -0.19143704         WKT1       = 2.927733e-009
+KT1L       = 0                   KT2        = -0.045046667        WKT2       = -2.2250667e-009
+UTE        = -0.86477778         WUTE       = -8.2631111e-008     UA1        = 3.6091411e-009
+WUA1       = -3.6112036e-016     UB1        = -3.7822222e-018     WUB1       = 3.3351111e-025
+UC1        = 9.6044444e-011      WUC1       = -3.9822222e-019     PRT        = 0
+AT         = '165555.56+datp_hvt'
+WAT        = -0.0049777778       NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'
+WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LA0        = '0+dla0p_hvt'       PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'
+PPCLM      = '0+dppclmp_hvt'     LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1e-005-(dxlp_hvt+dlmisp_hvt)'   WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_hvt+dwmisp_hvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_hvt+toxmisp_hvt)'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60230381+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-3.9303708e-009+dlvthp_hvt'
+WVTH0      = '-7.4511909e-009+dwvthp_hvt'
+PVTH0      = '1.0063652e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.025238793+dk2p_hvt'
+LK2        = '4.0472409e-009+dlk2p_hvt'
+WK2        = '6.9015249e-009+dwk2p_hvt'
+PK2        = '-8.9835813e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.15841107+dvoffp_hvt'
+LVOFF      = '4.9060386e-009+dlvoffp_hvt'
+WVOFF      = '1.5760246e-010+dwvoffp_hvt'
+PVOFF      = '-8.4944499e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015515143+du0p_hvt'
+LU0        = '-1.9583973e-010+dlu0p_hvt'
+WU0        = '1.6818417e-010+dwu0p_hvt'
+PU0        = '1.8798185e-017+dpu0p_hvt'
+UA         = 1.8181384e-009      LUA        = -4.8210389e-017     WUA        = -1.4181542e-016
+PUA        = 3.148085e-023       UB         = '-2.4318365e-020+dubp_hvt'
+LUB        = '1.4352521e-025+dlubp_hvt'
+WUB        = '8.7182576e-027+dwubp_hvt'
+PUB        = '-3.4084999e-032+dpubp_hvt'
+UC         = -2.9171692e-010     LUC        = 8.3701062e-017      WUC        = 3.1008751e-017
+PUC        = -3.1839493e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '2.2293021+da0p_hvt'
+LA0        = '-4.4256898e-007+dla0p_hvt'
+WA0        = '-8.4243951e-008+dwa0p_hvt'
+PA0        = '8.0122724e-014+dpa0p_hvt'
+AGS        = 0.81265962          LAGS       = 1.3377797e-007      WAGS       = -5.2338774e-008
+PAGS       = 3.6263203e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.041993544
+LKETA      = -3.8408203e-008     WKETA      = -4.2738842e-009     PKETA      = 8.7588492e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00053813492+dpdiblc2p_hvt'
+LPDIBLC2   = 1.8342661e-009      WPDIBLC2   = 5.6660018e-011      PPDIBLC2   = -3.1657102e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.2166576e-008
+LAGIDL     = -4.9811472e-015     WAGIDL     = -1.6533042e-015     PAGIDL     = 1.5939671e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068113605        LAIGC      = -1.1162514e-009     WAIGC      = 1.1709296e-011
+PAIGC      = 1.437227e-016       BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0071657499        LAIGSD     = -6.5513945e-010     WAIGSD     = -2.0122347e-010
+PAIGSD     = 1.7480506e-016      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00010529973
+LTVOFF     = -1.0152052e-010     WTVOFF     = 1.402553e-010       PTVOFF     = -1.3522154e-016
+KT1        = -0.18899726         LKT1       = -2.4310255e-008     WKT1       = 3.1428822e-009
+PKT1       = -2.1437702e-015     KT1L       = 0                   KT2        = -0.044164557
+LKT2       = -8.7894382e-009     WKT2       = -2.3063297e-009     PKT2       = 8.0971403e-016
+UTE        = -0.85566039         LUTE       = -9.0846636e-008     WUTE       = -8.6097146e-008
+PUTE       = 3.4535954e-014      UA1        = 3.6524298e-009      LUA1       = -4.3133295e-016
+WUA1       = -3.804355e-016      PUA1       = 1.9245824e-022      UB1        = -3.8185251e-018
+LUB1       = 3.6172616e-025      WUB1       = 3.5164114e-025      PUB1       = -1.806496e-031
+UC1        = 1.267698e-010       LUC1       = -3.0615079e-016     WUC1       = -5.2666683e-018
+PUC1       = 4.8509732e-023      PRT        = 0                   AT         = '165555.56+datp_hvt'
+WAT        = -0.0049777778       NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'
+NOIC       = 'noicpmac_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '1.000004e-006-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60606174+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-3.0731472e-010+dlvthp_hvt'
+WVTH0      = '-6.3298716e-009+dwvthp_hvt'
+PVTH0      = '-7.4709908e-017+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.021004313+dk2p_hvt'
+LK2        = '-3.5263419e-011+dlk2p_hvt'
+WK2        = '5.8812172e-009+dwk2p_hvt'
+PK2        = '8.5330736e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.0184239e-006+dcitp_hvt'
+LCIT       = '2.8745673e-012+dlcitp_hvt'
+WCIT       = '4.1742065e-013+dwcitp_hvt'
+PCIT       = '-4.0243943e-019+dpcitp_hvt'
+VOFF       = '-0.15171065+dvoffp_hvt'
+LVOFF      = '-1.5539e-009+dlvoffp_hvt'
+WVOFF      = '-8.6745876e-010+dwvoffp_hvt'
+PVOFF      = '1.3882678e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015271181+du0p_hvt'
+LU0        = '3.9366797e-011+dlu0p_hvt'
+WU0        = '2.3215499e-010+dwu0p_hvt'
+PU0        = '-4.2876724e-017+dpu0p_hvt'
+UA         = 1.7360291e-009      LUA        = 3.0951971e-017      WUA        = -9.9089955e-017
+PUA        = -9.7112018e-024     UB         = '1.628309e-019+dubp_hvt'
+LUB        = '-3.6907268e-026+dlubp_hvt'
+WUB        = '-3.4108539e-026+dwubp_hvt'
+PUB        = '7.2047437e-033+dpubp_hvt'
+UC         = -1.8530728e-010     LUC        = -1.8889534e-017     WUC        = -7.6336237e-018
+PUC        = 5.4160072e-024      VSAT       = '80000+dvsatp_hvt'  A0         = '1.5490252+da0p_hvt'
+LA0        = '2.1329282e-007+dla0p_hvt'
+WA0        = '6.2804447e-008+dwa0p_hvt'
+PA0        = '-6.1648106e-014+dpa0p_hvt'
+AGS        = 0.47861947          LAGS       = 4.5582942e-007      WAGS       = 4.0279688e-008
+PAGS       = -5.3031182e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.0040958789
+LKETA      = -1.8706851e-009     WKETA      = 6.3191982e-009      PKETA      = -1.4540475e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.39987939+dpclmp_hvt'
+LPCLM      = '1.527349e-007+dlpclmp_hvt'
+WPCLM      = '2.2134998e-008+dwpclmp_hvt'
+PPCLM      = '-2.1340573e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0030490557+dpdiblc2p_hvt'
+LPDIBLC2   = -5.8653772e-010     WPDIBLC2   = -3.568678e-010      PPDIBLC2   = 8.211528e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0052916563        LAIGC      = 3.4891068e-010      WAIGC      = 2.1118479e-010
+PAIGC      = -4.859362e-017      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0065825313        LAIGSD     = -9.2852554e-011     WAIGSD     = -2.6152915e-011
+PAIGSD     = 6.0177858e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 4.9927467e-005
+LTVOFF     = -4.813557e-011      WTVOFF     = -2.5466561e-011     PTVOFF     = 2.4552566e-017
+KT1        = -0.20981498         LKT1       = -4.23968e-009       WKT1       = 5.5787206e-010
+PKT1       = 3.4846395e-016      KT1L       = 0                   KT2        = -0.049387055
+LKT2       = -3.7543757e-009     WKT2       = -2.0970578e-009     PKT2       = 6.0795283e-016
+UTE        = -1.008789           LUTE       = 5.6786137e-008      WUTE       = -4.216121e-008
+PUTE       = -7.8231215e-015     UA1        = 3.1502487e-009      LUA1       = 5.2824876e-017
+WUA1       = -1.5625754e-016     PUA1       = -2.3673969e-023     UB1        = -3.4708502e-018
+LUB1       = 2.6529301e-026      WUB1       = 1.5100283e-025      PUB1       = 1.2787795e-032
+UC1        = -2.0272498e-010     LUC1       = 1.1518418e-017      WUC1       = 4.8871994e-017
+PUC1       = -3.6858938e-024     PRT        = 0                   AT         = '194340.3+datp_hvt'
+LAT        = -0.027751664        WAT        = -0.0042677726       PAT        = -6.8452314e-010
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+LMAX       = '2.400007e-007-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60369893+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-8.509968e-010+dlvthp_hvt'
+WVTH0      = '-7.3249368e-009+dwvthp_hvt'
+PVTH0      = '1.5425459e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.025922797+dk2p_hvt'
+LK2        = '1.0964798e-009+dlk2p_hvt'
+WK2        = '7.0344576e-009+dwk2p_hvt'
+PK2        = '-1.8002987e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0011791319+dcitp_hvt'
+LCIT       = '2.7465726e-010+dlcitp_hvt'
+WCIT       = '1.6577847e-010+dwcitp_hvt'
+PCIT       = '-3.8452016e-017+dpcitp_hvt'
+VOFF       = '-0.16813777+dvoffp_hvt'
+LVOFF      = '2.2259785e-009+dlvoffp_hvt'
+WVOFF      = '2.9181973e-009+dwvoffp_hvt'
+PVOFF      = '-7.3225267e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013440681+du0p_hvt'
+LU0        = '4.6056491e-010+dlu0p_hvt'
+WU0        = '4.9601496e-010+dwu0p_hvt'
+PU0        = '-1.035909e-016+dpu0p_hvt'
+UA         = 1.6835658e-009      LUA        = 4.3023795e-017      WUA        = -1.0181971e-016
+PUA        = -9.083086e-024      UB         = '-3.1571517e-020+dubp_hvt'
+LUB        = '7.8247287e-027+dlubp_hvt'
+WUB        = '4.0285811e-028+dwubp_hvt'
+PUB        = '-7.3632879e-034+dpubp_hvt'
+UC         = -4.2168673e-010     LUC        = 3.5501376e-017      WUC        = 4.3120738e-017
+PUC        = -6.2625713e-024     VSAT       = '80000+dvsatp_hvt'  A0         = '3.5672722+da0p_hvt'
+LA0        = '-2.5110582e-007+dla0p_hvt'
+WA0        = '-4.1501816e-007+dwa0p_hvt'
+PA0        = '4.8298875e-014+dpa0p_hvt'
+AGS        = 0.37783775          LAGS       = 4.7901929e-007      WAGS       = -6.0924509e-009
+PAGS       = -4.2360953e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.0031038886
+LKETA      = -2.1401864e-010     WKETA      = -5.0577305e-009     PKETA      = 1.1637838e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '1.5263677+dpclmp_hvt'
+LPCLM      = '-1.0647007e-007+dlpclmp_hvt'
+WPCLM      = '-1.9958843e-007+dwpclmp_hvt'
+PPCLM      = '2.9677987e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068012637        LAIGC      = 1.5500277e-012      BIGC       = 0.001375
+CIGC       = 0.1952244           AIGSD      = 0.0060420281        LAIGSD     = 3.1517231e-011
+BIGSD      = 0.0002969           CIGSD      = 0                   NIGC       = 2.605
+POXEDGE    = 1                   PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_hvt'
+CGDO       = 'cgop_hvt'          CGBO       = 0                   CGDL       = 'cglp_hvt'
+CGSL       = 'cglp_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.05                MOIN       = 9.6576              NOFF       = 2.0069
+VOFFCV     = -0.068319           TVOFF      = -0.00071076354      LTVOFF     = 1.2689943e-010
+WTVOFF     = 1.2732509e-010      PTVOFF     = -1.0604792e-017     KT1        = -0.19325598
+LKT1       = -8.0499058e-009     WKT1       = -3.9184069e-009     PKT1       = 1.3784557e-015
+KT1L       = 0                   KT2        = -0.070678731        LKT2       = 1.144839e-009
+WKT2       = 9.3962553e-010      PKT2       = -9.0787995e-017     UTE        = -0.62752305
+LUTE       = -3.0943146e-008     WUTE       = -1.1919262e-007     PUTE       = 9.9018068e-015
+UA1        = 4.0586439e-009      LUA1       = -1.5619687e-016     WUA1       = -3.3984325e-016
+PUA1       = 1.8569103e-023      UB1        = -4.3859634e-018     LUB1       = 2.3709684e-025
+WUB1       = 3.1835083e-025      PUB1       = -2.5718979e-032     UC1        = 7.0214117e-011
+LUC1       = -5.1284868e-017     WUC1       = -2.5414657e-018     PUC1       = 8.1443433e-024
+PRT        = 0                   AT         = '134909.12+datp_hvt'
+LAT        = -0.014076548        WAT        = -0.01266366         PAT        = 1.2473705e-009
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_hvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_hvt+dlmisp_hvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_hvt+dwmisp_hvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_hvt+toxmisp_hvt)'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_hvt+dlmisp_hvt)'    XW         = '2e-08+(dxwp_hvt+dwmisp_hvt)'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61122051+(dvthp_hvt+vthmisp_hvt)'
+LVTH0      = '-1.1012175e-010+dlvthp_hvt'
+WVTH0      = '-2.4781984e-009+dwvthp_hvt'
+PVTH0      = '-3.2314914e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.013137726+dk2p_hvt'
+LK2        = '-1.6284971e-010+dlk2p_hvt'
+WK2        = '4.7718152e-009+dwk2p_hvt'
+PK2        = '4.28404e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0022823135+dcitp_hvt'
+LCIT       = '3.8332065e-010+dlcitp_hvt'
+WCIT       = '-2.7919479e-010+dwcitp_hvt'
+PCIT       = '5.377849e-018+dpcitp_hvt'
+VOFF       = '-0.11498327+dvoffp_hvt'
+LVOFF      = '-3.0097392e-009+dlvoffp_hvt'
+WVOFF      = '-1.2148175e-008+dwvoffp_hvt'
+PVOFF      = '7.5178503e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0087857358+deta0p_hvt'
+LETA0      = '-2.4156164e-010+dleta0p_hvt'
+WETA0      = '-1.8030862e-009+dweta0p_hvt'
+PETA0      = '1.0405732e-016+dpeta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020704853+du0p_hvt'
+LU0        = '-2.5495605e-010+dlu0p_hvt'
+WU0        = '-7.3620721e-010+dwu0p_hvt'
+PU0        = '1.778298e-017+dpu0p_hvt'
+UA         = 2.3445051e-009      LUA        = -2.2078734e-017     WUA        = -2.103449e-016
+PUA        = 1.6066451e-024      UB         = '1.4386965e-019+dubp_hvt'
+LUB        = '-9.4562264e-027+dlubp_hvt'
+WUB        = '-2.0657144e-026+dwubp_hvt'
+PUB        = '1.3380815e-033+dpubp_hvt'
+UC         = 2.4429891e-010      LUC        = -3.0098209e-017     WUC        = -9.4932018e-017
+PUC        = 7.3356251e-024
+VSAT       = '66794.756+dvsatp_hvt+5942.53*ff_flag_hvt-2641.13*ss_flag_hvt'
+LVSAT      = '0.0013007165+dlvsatp_hvt-0.000585338*ff_flag_hvt+0.00026015*ss_flag_hvt'
+WVSAT      = '0.0042256781+dwvsatp_hvt-0.00190161*ff_flag_hvt+0.00084516*ss_flag_hvt'
+PVSAT      = '-4.1622929e-010+dpvsatp_hvt+1.87308e-10*ff_flag_hvt-8.3248e-11*ss_flag_hvt'
+A0         = '0.7142333+da0p_hvt'
+LA0        = '2.9918511e-008+dla0p_hvt'
+WA0        = '4.2828211e-007+dwa0p_hvt'
+PA0        = '-3.4766202e-014+dpa0p_hvt'
+AGS        = 18.855358           LAGS       = -1.3410165e-006     WAGS       = -5.4023388e-006
+PAGS       = 4.8916932e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.022865595
+LKETA      = -2.7720128e-009     WKETA      = 1.8918835e-008      PKETA      = -1.1979079e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.0021081653+dpclmp_hvt'
+LPCLM      = '4.3669499e-008+dlpclmp_hvt'
+WPCLM      = '1.9400448e-007+dwpclmp_hvt'
+PPCLM      = '-9.090914e-015+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0037445427+dpdiblc2p_hvt'
+LPDIBLC2   = 4.1808746e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.007030925         LAIGC      = -2.1071608e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0061922183
+LAIGSD     = 1.6723498e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00067923594
+LTVOFF     = -1.0015517e-011     WTVOFF     = -8.5134595e-011     PTVOFF     = 1.0322487e-017
+KT1        = -0.2827156          LKT1       = 7.6186684e-010      WKT1       = 2.0131745e-008
+PKT1       = -9.904842e-016      KT1L       = 0                   KT2        = -0.039628068
+LKT2       = -1.9136513e-009     WKT2       = -6.2859466e-009     PKT2       = 6.2093086e-016
+UTE        = -0.84262734         LUTE       = -9.7553741e-009     WUTE       = -5.0359253e-008
+PUTE       = 3.1217197e-015      UA1        = 5.3683084e-009      LUA1       = -2.8519883e-016
+WUA1       = -3.8031394e-016     PUA1       = 2.2555465e-023      UB1        = -4.5646643e-018
+LUB1       = 2.5469888e-025      WUB1       = 8.7669327e-026      PUB1       = -2.9968509e-033
+UC1        = -9.0187515e-010     LUC1       = 4.4465924e-017      WUC1       = 1.4310483e-016
+PUC1       = -6.2018165e-024     PRT        = 0                   AT         = '-8000+datp_hvt'
+NOIA       = 'noiapmac_hvt'        NOIB       = 'noibpmac_hvt'        NOIC       = 'noicpmac_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_hvt_mac
.ENDL MAC_hvt








.LIB MAC_mlvt
**********************************************************************************************
*                                                                                            *
*                               1.2V mlvt-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_mlvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.25e-008' xw='+2.0e-08+dxwn_mlvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_mlvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_mlvt  temp2=parn2_mlvt
+fac1='0.533552*temp1*sigma+0.845767*temp2*sigma'
+fac2='0.533552*temp1*sigma-0.845767*temp2*sigma'
.param  lef='l*scale-1e-09'
+       wef='w/nf*scale+2.0e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_mlvt='(0.00423845050+0.00004287615/(lef*1e6)+0.0001287615/(wef*1e6)-0.0000287615/(wef*wef*1e12)-0.00010867615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisn_mlvt='0.00216908*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_mlvt='-0.00216908*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_mlvt='0.00216908*geo_fac*toxn_mlvt*fac2*mismatchflag' 
.param tnoiax='2.084e05/(l*scale*1e6)+1.745e07'
.param rnoiax='0.0183/(l*scale*1e6)+0.4837'

.param fn_dice='noiseflagn_mlvt_mc*par1fn_mc+noiseflagn_mlvt_mc_mis*par2fn_mlvt_mc'
.param arearatio='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.555*log(((w*scale*l*scale*multi)/(12.7E-6*1E-6*1))**0.5)))'
.param noianmac_mlvt='c1fn_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_mlvt)*arearatio)'
.param noibnmac_mlvt='c2fn_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_mlvt)*arearatio)'
.param noicnmac_mlvt='c3fn_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_mlvt)*arearatio)'


.MODEL nch_mlvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = 2.00001e-05         WMIN       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3971583+(dvthn_mlvt+vthmisn_mlvt)'   K1         = 0.31994
+K2         = '0.022565+dk2n_mlvt'     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 0.001               VOFF       = -0.1282             NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'      UA         = -1.683e-009
+UB         = 2.412312e-018       UC         = 1.289e-010          VSAT       = '110000+dvsatn_mlvt'
+A0         = 2.203               AGS        = 0.8591              A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05109            DWG        = 0                   DWB        = 0
+PCLM       = 0.2722              PDIBLC1    = 0                   PDIBLC2    = '0.002415+dpdiblc2n_mlvt'
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.001375            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2154432
+KT1L       = 0                   KT2        = -0.07264            UTE        = -1.379
+UA1        = 1.6e-009            UB1        = -1.44628e-018       UC1        = 3.03e-013
+PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          WVOFF      = '0+dwvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'      LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'       WMIN       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39304444+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '4.099508e-008+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.023370867+dk2n_mlvt'  LK2        = -8.0305518e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00098244461
+LCIT       = '1.7494141e-010+dlcitn_mlvt'
+VOFF       = -0.1255394          LVOFF      = '-2.65132e-008+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'
+UA         = -1.7047351e-009     LUA        = 2.1659301e-016      UB         = 2.4380817e-018
+LUB        = -2.5679813e-025     UC         = 1.3000452e-010      LUC        = -1.1006611e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.2653681           LA0        = '-6.2150487e-007+dla0n_mlvt'
+AGS        = 0.81477464          LAGS       = 4.4170706e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04934744         LKETA      = -1.7364799e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0025667367+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.5120733e-009     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0013986988
+LTVOFF     = -2.3616127e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21318399         LKT1       = -2.2513329e-008     KT1L       = 0
+KT2        = -0.071975146        LKT2       = -6.6253388e-009     UTE        = -1.3590544
+LUTE       = -1.9876016e-007     UA1        = 1.662196e-009       LUA1       = -6.1978976e-016
+UB1        = -1.4469534e-018     LUB1       = 6.7108271e-027      UC1        = -3.5356714e-012
+LUC1       = 3.8252783e-017      PRT        = 0                   AT         = 201072.34
+LAT        = -0.01068603
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43676534+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-1.2003913e-009+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.021314478+dk2n_mlvt'  LK2        = -6.0459107e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010868883
+LCIT       = '7.4141765e-011+dlcitn_mlvt'
+VOFF       = -0.15239595         LVOFF      = '-5.9367112e-010+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'
+UA         = -1.5453265e-009     LUA        = 6.2746135e-017      UB         = 2.269578e-018
+LUB        = -9.4173528e-026     UC         = 1.2925162e-010      LUC        = -1.0279988e-017
+VSAT       = '113946.42+dvsatn_mlvt'  LVSAT      = '-0.0038087297+dlvsatn_mlvt'
+A0         = 2.2094596           LA0        = '-5.6754699e-007+dla0n_mlvt'
+AGS        = 0.42887173          LAGS       = 8.1414582e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073052413        LKETA      = 5.5131064e-009      DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0012164964+dpdiblc2n_mlvt'
+LPDIBLC2   = -2.0894285e-010     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012118355
+LTVOFF     = -5.5817591e-011     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.22714346         LKT1       = -9.0408975e-009     KT1L       = 0
+KT2        = -0.075960598        LKT2       = -2.7789399e-009     UTE        = -1.5971652
+LUTE       = 3.1042938e-008      UA1        = 1.1007222e-009      LUA1       = -7.7905835e-017
+UB1        = -1.5451554e-018     LUB1       = 1.0148653e-025      UC1        = 1.2934884e-011
+LUC1       = 2.2356885e-017      PRT        = 0                   AT         = 234845.69
+LAT        = -0.043281019
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44301989+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-2.6263045e-009+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.0060518885+dk2n_mlvt' LK2        = -2.5663454e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00089174876
+LCIT       = '1.1862968e-010+dlcitn_mlvt'
+VOFF       = -0.13778537         LVOFF      = '-3.9245908e-009+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.1010175+deta0n_mlvt'  LETA0      = '5.6985851e-013+dleta0n_mlvt'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021399889+du0n_mlvt'  LU0        = '4.7901151e-011+dlu0n_mlvt'
+UA         = -1.318498e-009      LUA        = 1.1033782e-017      UB         = 1.9551074e-018
+LUB        = -2.2480505e-026     UC         = 8.770291e-011       LUC        = -8.077125e-019
+VSAT       = '101196.2+dvsatn_mlvt'   LVSAT      = '-0.0009019344+dlvsatn_mlvt'
+A0         = 0.76497717          LA0        = '-2.3823389e-007+dla0n_mlvt'
+AGS        = 3.2754786           LAGS       = 1.6517638e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073974665        LKETA      = 5.7233616e-009      DWG        = 0
+DWB        = 0                   PCLM       = -0.03535932         LPCLM      = 7.0117374e-008
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020716496+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.1562347e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00087063866
+LTVOFF     = 2.1968459e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.25962724         LKT1       = -1.6352462e-009     KT1L       = 0
+KT2        = -0.10603119         LKT2       = 4.0765531e-009      UTE        = -1.5964855
+LUTE       = 3.0887983e-008      UA1        = 8.2927857e-010      LUA1       = -1.6022109e-017
+UB1        = -1.389084e-018      LUB1       = 6.5905376e-026      UC1        = 1.2396893e-010
+LUC1       = -2.9566572e-018     PRT        = 0                   AT         = 54781.038
+LAT        = -0.0022298811
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+WETA0      = '0+dweta0n_mlvt'         PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.40966629+(dvthn_mlvt+vthmisn_mlvt)'
+LVTH0      = '5.6833647e-10+dlvthn_mlvt'
+K1         = 0.31994             K2         = '-0.00024866313+dk2n_mlvt'
+LK2        = -1.9628723e-009     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = -4.4334382e-05
+Pcit     = 1.8464961e-15
+LCIT       = '2.0828867e-10+dlcitn_mlvt'
+VOFF       = -0.13637037
+LVOFF      = '-4.0601207e-09+dlvoffn_mlvt'
+NFACTOR    = '0.751428+dnfactorn_mlvt-0.00210174*ss_flag_mlvt'
+ETA0       = '0.00065024466+deta0n_mlvt-7.14e-05*ff_flag_mlvt-0.0001428*ss_flag_mlvt'
+LETA0      = '9.6138461e-09+dleta0n_mlvt+6.83872e-12*ff_flag_mlvt+1.36774e-11*ss_flag_mlvt'
+ETAB       = -0.12377292
+Petab    = -6.154987e-15
+Wetab    = 6.426147e-08
+Letab    = 3.6514274e-09
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021162477+du0n_mlvt'  LU0        = '7.0640674e-011+dlu0n_mlvt'
+UA         = -1.3961783e-009     LUA        = 1.8474072e-017      UB         = 1.7190372e-018
+LUB        = 1.3053168e-028      UC         = 1.2291211e-010      LUC        = -4.1800851e-018
+VSAT       = '84982.229+dvsatn_mlvt'
+LVSAT      = '0.00065105587+dlvsatn_mlvt'
+A0         = 1.4250678           LA0        = '-3.0145803e-007+dla0n_mlvt'
+AGS        = 3.3966895           LAGS       = 1.5356668e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.13066844         LKETA      = 1.1153548e-008      DWG        = 0
+DWB        = 0                   PCLM       = 0.69140908          LPCLM      = 5.0677006e-010
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'
+CGBO       = 0                   CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011288596        LTVOFF     = -2.7642003e-012     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.28118927         LKT1       = 4.2998671e-010
+KT1L       = 0
+KT2        = -0.12709626
+Pkt2     = -3.692993e-15
+Wkt2     = 3.855689e-08
+LKT2       = 6.0941662e-09
+UTE        = -1.7133071          LUTE       = 4.2077271e-008      UA1        = -1.2041553e-010
+LUA1       = 7.4940541e-017      UB1        = 2.8533105e-021      LUB1       = -6.7415774e-026
+UC1        = 1.5113984e-010      LUC1       = -5.5591139e-018     PRT        = 0
+AT         = 31500
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '3.2130737e-07+dwvthn_mlvt'
+PVTH0      = '-3.0774936e-14+dpvthn_mlvt'
+WCIT       = '-1.9278442e-08+dwcitn_mlvt'
+WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+WETA0      = '-1.2852295e-07+dweta0n_mlvt+6.42615e-08*ff_flag_mlvt+1.28523e-07*ss_flag_mlvt'
+PETA0      = '1.2309974e-14+dpeta0n_mlvt-6.15499e-15*ff_flag_mlvt-1.231e-14*ss_flag_mlvt'
+WVOFF      = '-2.0563671e-07+dwvoffn_mlvt'
+PVOFF      = '1.9695959e-14+dpvoffn_mlvt'
+PVSAT      = '-4.9239897e-09+dpvsatn_mlvt'
+WVSAT      = '0.051409179+dwvsatn_mlvt'
+LNFACTOR   = '-1.3677444e-10+dlnfactorn_mlvt+2.01306e-10*ss_flag_mlvt'
+WNFACTOR   = '-1.2852295e-06+dwnfactorn_mlvt+1.89161e-06*ss_flag_mlvt'
+PNFACTOR   = '1.2309974e-13+dpnfactorn_mlvt-1.81179e-13*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = 2.00001e-05         WMIN       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39547494+(dvthn_mlvt+vthmisn_mlvt)'  WVTH0      = '1.6867314e-008+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.022969033+dk2n_mlvt'  WK2        = -4.048414e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010453333
+WCIT       = '-4.5424e-010+dwcitn_mlvt'
+VOFF       = -0.12669799         WVOFF      = '-1.5050107e-008+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'      UA         = -1.7121267e-009
+WUA        = 2.918492e-016       UB         = 2.4287286e-018      WUB        = -1.6449393e-025
+UC         = 1.3399547e-010      WUC        = -5.1056576e-017     VSAT       = '110000+dvsatn_mlvt'
+A0         = 2.1942733           WA0        = 8.74412e-008        AGS        = 0.85684215
+WAGS       = 2.262365e-008       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.052544067
+WKETA      = 1.4569748e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.265162            WPCLM      = 7.052076e-008       PDIBLC1    = 0
+PDIBLC2    = '0.0024053667+dpdiblc2n_mlvt'
+WPDIBLC2   = 9.6526e-011         PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00136514
+LTVOFF     = 0                   WTVOFF     = 9.87972e-011        PTVOFF     = 0
+KT1        = -0.21658778         WKT1       = 1.1468652e-008      KT1L       = 0
+KT2        = -0.0729256          WKT2       = 2.861712e-009       UTE        = -1.3799067
+WUTE       = 9.0848e-009         UA1        = 1.6328667e-009      WUA1       = -3.29324e-016
+UB1        = -1.4643317e-018     WUB1       = 1.8087837e-025      UC1        = -3.5953267e-012
+WUC1       = 3.9061233e-017      PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+LETA0      = '0+dleta0n_mlvt'         PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'      LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'       WMIN       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3912083+(dvthn_mlvt+vthmisn_mlvt)'   LVTH0      = '4.2517486e-008+dlvthn_mlvt'
+WVTH0      = '1.8398106e-008+dwvthn_mlvt'
+PVTH0      = '-1.5254509e-014+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.023700073+dk2n_mlvt'  LK2        = -7.2848877e-009
+WK2        = -3.2986427e-009     PK2        = -7.471554e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0010309425        LCIT       = '1.4340605e-010+dlcitn_mlvt'
+WCIT       = '-4.8594906e-010+dwcitn_mlvt'
+PCIT       = 3.1598426e-016      VOFF       = -0.12386568         LVOFF      = '-2.8224355e-008+dlvoffn_mlvt'
+WVOFF      = '-1.6770688e-008+dwvoffn_mlvt'
+PVOFF      = '1.7145779e-014+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021608056+du0n_mlvt'  LU0        = '1.9377335e-011+dlu0n_mlvt'
+WU0        = '1.948407e-011+dwu0n_mlvt'
+PU0        = '-1.941609e-016+dpu0n_mlvt'
+UA         = -1.7350077e-009     LUA        = 2.2801148e-016      WUA        = 3.0333057e-016
+PUA        = -1.1441307e-022     UB         = 2.4549474e-018      LUB        = -2.6127333e-025
+WUB        = -1.6899378e-025     PUB        = 4.4841459e-032      UC         = 1.3493348e-010
+LUC        = -9.347427e-018      WUC        = -4.9388253e-017     PUC        = -1.6625027e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.2627307           LA0        = '-6.8218549e-007+dla0n_mlvt'
+WA0        = 2.6426333e-008      PA0        = 6.0801986e-013      AGS        = 0.81261905
+LAGS       = 4.4068808e-007      WAGS       = 2.1599056e-008      PAGS       = 1.0210194e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050703795        LKETA      = -1.833851e-008
+WKETA      = 1.3590674e-008      PKETA      = 9.7565851e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0025925301+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.8651041e-009     WPDIBLC2   = -2.5844939e-010     PPDIBLC2   = 3.5373688e-015
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013867485        LTVOFF     = -2.1533064e-010
+WTVOFF     = 1.1974258e-010      PTVOFF     = -2.0872296e-016     KT1        = -0.21442694
+LKT1       = -2.1532981e-008     WKT1       = 1.2454399e-008      PKT1       = -9.8230852e-015
+KT1L       = 0                   KT2        = -0.072099838        LKT2       = -8.2288133e-009
+WKT2       = 1.2494052e-009      PKT2       = 1.6066814e-014      UTE        = -1.3572144
+LUTE       = -2.2613065e-007     WUTE       = -1.8436448e-008     PUTE       = 2.7425227e-013
+UA1        = 1.7006531e-009      LUA1       = -6.754996e-016      WUA1       = -3.853407e-016
+PUA1       = 5.5821258e-022      UB1        = -1.4668194e-018     LUB1       = 2.4789881e-026
+WUB1       = 1.9905701e-025      PUB1       = -1.8115212e-031     UC1        = -7.765745e-012
+LUC1       = 4.1558677e-017      WUC1       = 4.2385337e-017      PUC1       = -3.3125063e-023
+PRT        = 0                   AT         = 201084.5            LAT        = -0.010807139
+WAT        = -0.00012177544      PAT        = 1.2135056e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43644065+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-1.136705e-009+dlvthn_mlvt'
+WVTH0      = '3.253333e-009+dwvthn_mlvt'
+PVTH0      = '-6.3813721e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.022589005+dk2n_mlvt'  LK2        = -6.2125854e-009
+WK2        = -1.2770759e-008     PK2        = 1.6700806e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.001096553         LCIT       = '8.0084763e-011+dlcitn_mlvt'
+WCIT       = '-9.6839942e-011+dwcitn_mlvt'
+PCIT       = -5.9548836e-017     VOFF       = -0.15284142         LVOFF      = '-2.5957307e-010+dlvoffn_mlvt'
+WVOFF      = '4.4636181e-009+dwvoffn_mlvt'
+PVOFF      = '-3.3476624e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021606051+du0n_mlvt'  LU0        = '2.1312171e-011+dlu0n_mlvt'
+WU0        = '3.9571993e-011+dwu0n_mlvt'
+PU0        = '-2.1354795e-016+dpu0n_mlvt'
+UA         = -1.5657172e-009     LUA        = 6.4627591e-017      WUA        = 2.0431503e-016
+PUA        = -1.8852183e-023     UB         = 2.2803345e-018      LUB        = -9.2752717e-026
+WUB        = -1.0778004e-025     PUB        = -1.423653e-032      UC         = 1.3678552e-010
+LUC        = -1.1134843e-017     WUC        = -7.5489601e-017     PUC        = 8.5656457e-024
+VSAT       = '114148.32+dvsatn_mlvt'  LVSAT      = '-0.0040035838+dlvsatn_mlvt'
+WVSAT      = '-0.0020230217+dwvsatn_mlvt'
+PVSAT      = '1.9524384e-009+dpvsatn_mlvt'
+A0         = 2.1280013           LA0        = '-5.5215676e-007+dla0n_mlvt'
+WA0        = 8.1621195e-007      PA0        = -1.5421014e-013     AGS        = 0.42466709
+LAGS       = 8.151044e-007       WAGS       = 4.2130504e-008      PAGS       = -9.6049124e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.076145004        LKETA      = 6.2150549e-009
+WKETA      = 3.0987767e-008      PKETA      = -7.0335238e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00079587727+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.3113651e-010     WPDIBLC2   = 4.2146038e-009      PPDIBLC2   = -7.7961951e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0012284441        LTVOFF     = -6.254953e-011
+WTVOFF     = -1.6641859e-010     PTVOFF     = 6.7454036e-017      KT1        = -0.22675482
+LKT1       = -9.6352162e-009     WKT1       = -3.8941599e-009     PKT1       = 5.9550728e-015
+KT1L       = 0                   KT2        = -0.07738044         LKT2       = -3.1324513e-009
+WKT2       = 1.4226817e-008      PKT2       = 3.5421843e-015      UTE        = -1.6184239
+LUTE       = 2.5965229e-008      WUTE       = 2.1301242e-007      PUTE       = 5.0878647e-014
+UA1        = 1.0856968e-009      LUA1       = -8.1999125e-017     WUA1       = 1.505545e-016
+PUA1       = 4.1014766e-023      UB1        = -1.5438351e-018     LUB1       = 9.9118509e-026
+WUB1       = -1.3229333e-026     PUB1       = 2.372755e-032       UC1        = 1.0815775e-011
+LUC1       = 2.3625467e-017      WUC1       = 2.1233474e-017      PUC1       = -1.2711188e-023
+PRT        = 0                   AT         = 235012.77           LAT        = -0.04355165
+WAT        = -0.0016741523       PAT        = 2.71172e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-2.6209825e-009+dlvthn_mlvt'
+WVTH0      = '6.8814839e-010+dwvthn_mlvt'
+PVTH0      = '-5.3326435e-017+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0071010498+dk2n_mlvt' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitn_mlvt'
+WCIT       = '-2.634146e-010+dwcitn_mlvt'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffn_mlvt'
+WVOFF      = '-2.7301032e-008+dwvoffn_mlvt'
+PVOFF      = '3.8940424e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10402516+deta0n_mlvt' LETA0      = '-1.6784547e-010+dleta0n_mlvt'
+WETA0      = '-3.0136772e-008+dweta0n_mlvt'
+PETA0      = '1.6875216e-015+dpeta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0n_mlvt'  LU0        = '6.0443544e-011+dlu0n_mlvt'
+WU0        = '-3.4587047e-010+dwu0n_mlvt'
+PU0        = '-1.2567478e-016+dpu0n_mlvt'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatn_mlvt'  LVSAT      = '-0.00073522225+dlvsatn_mlvt'
+WVSAT      = '0.013868259+dwvsatn_mlvt'
+PVSAT      = '-1.6704557e-009+dpvsatn_mlvt'
+A0         = 0.71811517          LA0        = '-2.3073092e-007+dla0n_mlvt'
+WA0        = 4.6955716e-007      PA0        = -7.5179779e-014     AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-005-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44338471+(dvthn_mlvt+vthmisn_mlvt)'
+LVTH0      = '-2.6624817e-09+dlvthn_mlvt'
+WVTH0      = '-1.6551106e-08+dwvthn_mlvt'
+PVTH0      = '1.597862e-15+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0013060071+dk2n_mlvt' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0020197491
+LCIT       = '4.0216548e-10+dlcitn_mlvt'
+WCIT       = '5.152138e-10+dwcitn_mlvt'
+PCIT       = -9.614958e-17
+VOFF       = -0.16044316
+LVOFF      = '-1.8820754e-09+dlvoffn_mlvt'
+WVOFF      = '3.5572622e-08+dwvoffn_mlvt'
+PVOFF      = '-2.1280553e-15+dpvoffn_mlvt'
+NFACTOR    = '0.60878657+dnfactorn_mlvt+0.207839*ss_flag_mlvt'
+ETA0       = '-0.013762419+deta0n_mlvt+0.00706067*ff_flag_mlvt+0.0141213*ss_flag_mlvt'
+LETA0      = '1.1113958e-08+dleta0n_mlvt-6.76274e-10*ff_flag_mlvt-1.35255e-09*ss_flag_mlvt'
+WETA0      = '1.5891949e-08+dweta0n_mlvt-7.20189e-09*ff_flag_mlvt-1.44038e-08*ss_flag_mlvt'
+PETA0      = '-2.7211461e-15+dpeta0n_mlvt+6.89799e-16*ff_flag_mlvt+1.3796e-15*ss_flag_mlvt'
+ETAB       = -0.11384089
+LETAB      = 2.9069217e-09
+WETAB      = -3.5257548e-08
+PETAB      = 1.3049602e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0n_mlvt'   LU0        = '4.5926676e-011+dlu0n_mlvt'
+WU0        = '-4.2433976e-009+dwu0n_mlvt'
+PU0        = '2.4763426e-016+dpu0n_mlvt'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024
+UB         = 1.7538672e-18
+LUB        = -6.6974505e-28
+WUB        = -3.4899719e-25
+PUB        = 8.0187736e-33
+UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '90298.236+dvsatn_mlvt+72.6857*ff_flag_mlvt'
+LVSAT      = '0.00017603274+dlvsatn_mlvt-6.96186e-06*ff_flag_mlvt'
+WVSAT      = '-0.0018572123+dwvsatn_mlvt-0.000728311*ff_flag_mlvt'
+PVSAT      = '-1.6425802e-10+dpvsatn_mlvt+6.97579e-11*ff_flag_mlvt'
+A0         = 1.6696481           LA0        = '-3.2186969e-007+dla0n_mlvt'
+WA0        = -2.4506944e-006     PA0        = 2.0452483e-013      AGS        = 3.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'
+CGBO       = 0                   CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.12701693
+LKT2       = 6.0452217e-09
+WKT2       = 3.7762002e-08
+PKT2       = -3.2025688e-15
+UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '1.3525474e-08+dlnfactorn_mlvt-1.99069e-08*ss_flag_mlvt'
+WNFACTOR   = '1.440377e-07+dwnfactorn_mlvt-2.11996e-07*ss_flag_mlvt'
+PNFACTOR   = '-1.3795983e-14+dpnfactorn_mlvt+2.0305e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = 2.00001e-05         WMIN       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41234586+(dvthn_mlvt+vthmisn_mlvt)'  WVTH0      = '-3.4102328e-010+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.024897369+dk2n_mlvt'  WK2        = -6.0153161e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00033
+WCIT       = '9.486e-010+dwcitn_mlvt' VOFF       = -0.13118588         WVOFF      = '-1.047246e-008+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220595+du0n_mlvt'    WU0        = '-4.5849e-010+dwu0n_mlvt'
+UA         = -1.5544144e-009     WUA        = 1.3098269e-016      UB         = 2.3962278e-018
+WUB        = -1.3134316e-025     UC         = 1.369035e-010       WUC        = -5.402277e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.6356816           WA0        = -3.6279523e-007
+AGS        = 0.93377161          WAGS       = -5.5844398e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05097            WKETA      = 1.29642e-008        DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0041275+dpdiblc2n_mlvt'
+WPDIBLC2   = -1.66005e-009       PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0015829
+LTVOFF     = 0                   WTVOFF     = -1.23318e-010       PTVOFF     = 0
+KT1        = -0.2248802          WKT1       = 1.9926924e-008      KT1L       = 0
+KT2        = -0.0734525          WKT2       = 3.39915e-009        UTE        = -1.619
+WUTE       = 2.5296e-007         UA1        = 1.155e-009          WUA1       = 1.581e-016
+UB1        = -1.12735e-018       WUB1       = -1.62843e-025       UC1        = -2e-014
+WUC1       = 3.54144e-017        PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'       WMIN       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40885016+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '3.4835029e-008+dlvthn_mlvt'
+WVTH0      = '4.0341437e-010+dwvthn_mlvt'
+PVTH0      = '-7.418403e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.026722076+dk2n_mlvt'  LK2        = -1.8183407e-008
+WK2        = -6.3810858e-009     PK2        = 3.6449353e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00046259057      LCIT       = '1.3212796e-009+dlcitn_mlvt'
+WCIT       = '1.0374547e-009+dwcitn_mlvt'
+PCIT       = -8.8544672e-016     VOFF       = -0.12858922         LVOFF      = '-2.5875987e-008+dlvoffn_mlvt'
+WVOFF      = '-1.1952669e-008+dwvoffn_mlvt'
+PVOFF      = '1.4750443e-014+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021971943+du0n_mlvt'  LU0        = '8.7251438e-010+dlu0n_mlvt'
+WU0        = '-3.5168128e-010+dwu0n_mlvt'
+PU0        = '-1.0643607e-015+dpu0n_mlvt'
+UA         = -1.5717657e-009     LUA        = 1.7290734e-016      WUA        = 1.3682375e-016
+PUA        = -5.8206845e-023     UB         = 2.4217449e-018      LUB        = -2.542805e-025
+WUB        = -1.3512724e-025     PUB        = 3.7708778e-032      UC         = 1.4062234e-010
+LUC        = -3.7058619e-017     WUC        = -5.5190885e-017     PUC        = 1.1640389e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.5755871           LA0        = '5.9884843e-007+dla0n_mlvt'
+WA0        = -2.9268715e-007     PA0        = -6.9863474e-013     AGS        = 0.87470677
+LAGS       = 5.8858761e-007      WAGS       = -4.1730422e-008     PAGS       = -1.4064732e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050917348        LKETA      = -5.2468409e-010
+WKETA      = 1.3808498e-008      PKETA      = -8.4135178e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.003974959+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.5200878e-009      WPDIBLC2   = -1.6685269e-009     PPDIBLC2   = 8.447307e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016380078        LTVOFF     = -5.491551e-010
+WTVOFF     = -1.3654194e-010     PTVOFF     = 1.3177799e-016      KT1        = -0.22424568
+LKT1       = -6.3230738e-009     WKT1       = 2.2469514e-008      PKT1       = -2.5337191e-014
+KT1L       = 0                   KT2        = -0.074820758        LKT2       = 1.363484e-008
+WKT2       = 4.024744e-009       PKT2       = -6.2341126e-015     UTE        = -1.6586596
+LUTE       = 3.9521215e-007      WUTE       = 2.8903761e-007      PUTE       = -3.5951739e-013
+UA1        = 1.1037098e-009      LUA1       = 5.1111283e-016      WUA1       = 2.2354154e-016
+PUA1       = -6.521321e-022      UB1        = -1.0463944e-018     LUB1       = -8.0673118e-025
+WUB1       = -2.2977647e-025     PUB1       = 6.6699936e-031      UC1        = -1.9453945e-012
+LUC1       = 1.9186768e-017      WUC1       = 3.644858e-017       PUC1       = -1.0305715e-023
+PRT        = 0                   AT         = 200798.9            LAT        = -0.0079610926
+WAT        = 0.00016953766       PAT        = -1.6894614e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44786427+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-2.817881e-009+dlvthn_mlvt'
+WVTH0      = '-8.3987589e-009+dwvthn_mlvt'
+PVTH0      = '1.0766624e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.014852277+dk2n_mlvt'  LK2        = -6.7277449e-009
+WK2        = -4.8792964e-009     PK2        = 2.1955433e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00094891812       LCIT       = '-4.0981585e-011+dlcitn_mlvt'
+WCIT       = '5.3747588e-011+dwcitn_mlvt'
+PCIT       = 6.3938839e-017      VOFF       = -0.15657613         LVOFF      = '1.1344586e-009+dlvoffn_mlvt'
+WVOFF      = '8.2730227e-009+dwvoffn_mlvt'
+PVOFF      = '-4.7695748e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220162+du0n_mlvt'    LU0        = '8.2980161e-010+dlu0n_mlvt'
+WU0        = '-3.7878026e-010+dwu0n_mlvt'
+PU0        = '-1.0382072e-015+dpu0n_mlvt'
+UA         = -1.5168324e-009     LUA        = 1.1989066e-016      WUA        = 1.5445249e-016
+PUA        = -7.5220517e-023     UB         = 2.285951e-018       LUB        = -1.2322447e-025
+WUB        = -1.1350885e-025     PUB        = 1.6844661e-032      UC         = 1.0610996e-010
+LUC        = -3.750375e-018      WUC        = -4.420053e-017      PUC        = 1.0334881e-024
+VSAT       = '112500.53+dvsatn_mlvt'  LVSAT      = '-0.0024132899+dlvsatn_mlvt'
+WVSAT      = '-0.00034228083+dwvsatn_mlvt'
+PVSAT      = '3.3033865e-010+dpvsatn_mlvt'
+A0         = 4.506443            LA0        = '-1.26464e-006+dla0n_mlvt'
+WA0        = -1.6097986e-006     PA0        = 5.7252272e-013      AGS        = -0.80346274
+LAGS       = 2.2082058e-006      WAGS       = 1.2948229e-006      PAGS       = -1.4305683e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055175769        LKETA      = 3.5851609e-009
+WKETA      = 9.5991475e-009      PKETA      = -4.3510319e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0069572267+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.3581285e-009     WPDIBLC2   = -2.0699726e-009     PPDIBLC2   = 4.7191236e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0010163914        LTVOFF     = 5.0773113e-011
+WTVOFF     = 4.9875206e-011      PTVOFF     = -4.813506e-017      KT1        = -0.22821446
+LKT1       = -2.4927658e-009     WKT1       = -2.4053332e-009     PKT1       = -1.3302266e-015
+KT1L       = 0                   KT2        = -0.057541276        LKT2       = -3.0417602e-009
+WKT2       = -6.0091298e-009     PKT2       = 3.4496793e-015      UTE        = -1.265572
+LUTE       = 1.5839361e-008      WUTE       = -1.4689655e-007     PUTE       = 6.1207033e-014
+UA1        = 1.9047865e-009      LUA1       = -2.6201434e-016     WUA1       = -6.8491696e-016
+PUA1       = 2.2463028e-022      UB1        = -2.1825365e-018     LUB1       = 2.897709e-025
+WUB1       = 6.3824609e-025      PUB1       = -1.7073789e-031     UC1        = 2.4369497e-012
+LUC1       = 1.4957323e-017      WUC1       = 2.9779875e-017      PUC1       = -3.8696813e-024
+PRT        = 0                   AT         = 224902.3            LAT        = -0.031223524
+WAT        = 0.0086385276        PAT        = -9.8629682e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-2.4452732e-009+dlvthn_mlvt'
+WVTH0      = '-2.656096e-009+dwvthn_mlvt'
+PVTH0      = '-2.3254991e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0077298678+dk2n_mlvt'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitn_mlvt'
+WCIT       = '4.0796102e-010+dwcitn_mlvt'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffn_mlvt'
+WVOFF      = '-1.6424805e-008+dwvoffn_mlvt'
+PVOFF      = '8.6103596e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.044118879+deta0n_mlvt'
+LETA0      = '3.7906852e-009+dleta0n_mlvt'
+WETA0      = '3.0967637e-008+dweta0n_mlvt'
+PETA0      = '-2.3501797e-015+dpeta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0n_mlvt'  LU0        = '-6.7466293e-010+dlu0n_mlvt'
+WU0        = '-7.6703892e-009+dwu0n_mlvt'
+PU0        = '6.2413382e-016+dpu0n_mlvt'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatn_mlvt'  LVSAT      = '-0.0010680136+dlvsatn_mlvt'
+WVSAT      = '0.0069449685+dwvsatn_mlvt'
+PVSAT      = '-1.3310085e-009+dpvsatn_mlvt'
+A0         = 2.0693451           LA0        = '-7.0903035e-007+dla0n_mlvt'
+WA0        = -9.0869732e-007     PA0        = 4.1268564e-013      AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '1e-006-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44977917+(dvthn_mlvt+vthmisn_mlvt)-0.00994084*ff_flag_mlvt'
+LVTH0      = '-2.7852085e-09+dlvthn_mlvt+9.52137e-10*ff_flag_mlvt'
+WVTH0      = '-2.3073464e-08+dwvthn_mlvt+1.01397e-08*ff_flag_mlvt'
+PVTH0      = '1.7230434e-15+dpvthn_mlvt-9.7118e-16*ff_flag_mlvt'
+K1         = 0.31994             K2         = '-0.014947392+dk2n_mlvt' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitn_mlvt'
+WCIT       = '-4.2348127e-010+dwcitn_mlvt'
+PCIT       = 6.2821635e-017
+VOFF       = -0.11890298
+LVOFF      = '-3.9086059e-09+dlvoffn_mlvt'
+WVOFF      = '-6.798364e-09+dwvoffn_mlvt'
+PVOFF      = '-6.09942e-17+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt+0.745563*ff_flag_mlvt-0.745563*ss_flag_mlvt'
+ETA0       = '-0.051871703+deta0n_mlvt+0.0294899*ff_flag_mlvt-0.0393199*ss_flag_mlvt'
+LETA0      = '1.2984759e-008+dleta0n_mlvt-2.82456e-09*ff_flag_mlvt+3.76608e-09*ss_flag_mlvt'
+WETA0      = '5.4763418e-008+dweta0n_mlvt-3.00797e-08*ff_flag_mlvt+4.01063e-08*ss_flag_mlvt'
+PETA0      = '-4.6293634e-015+dpeta0n_mlvt+2.88105e-15*ff_flag_mlvt-3.8414e-15*ss_flag_mlvt'
+ETAB       = -0.18617972
+LETAB      = 6.908976e-09
+WETAB      = 3.8528064e-08
+PETAB      = -2.7771351e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0n_mlvt'  LU0        = '1.4350807e-010+dlu0n_mlvt'
+WU0        = '-2.7003787e-009+dwu0n_mlvt'
+PU0        = '1.4810125e-016+dpu0n_mlvt'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023
+UB         = 6.5255326e-19
+LUB        = 8.6437068e-26
+WUB        = 7.7434308e-25
+PUB        = -8.0830175e-32
+UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatn_mlvt-5278.06*ff_flag_mlvt+3931.99*ss_flag_mlvt'
+LVSAT      = '-0.00026235326+dlvsatn_mlvt+0.000505535*ff_flag_mlvt-0.000376608*ss_flag_mlvt'
+WVSAT      = '-0.0099049722+dwvsatn_mlvt+0.00472945*ff_flag_mlvt-0.00401063*ss_flag_mlvt'
+PVSAT      = '2.8289571e-010+dpvsatn_mlvt-4.52989e-10*ff_flag_mlvt+3.8414e-10*ss_flag_mlvt'
+A0         = -8.937762           LA0        = '3.4524137e-007+dla0n_mlvt'
+WA0        = 8.3688639e-006      PA0        = -4.7592845e-013     AGS        = 6.4966895
+LAGS       = 1.5356668e-007      WAGS       = -3.162e-006         PAGS       = -1.6753592e-027
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0
+KT2        = -0.080271035
+LKT2       = 1.5876912e-09
+WKT2       = -9.918812e-09
+PKT2       = 1.3441123e-15
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt-7.14103e-08*ff_flag_mlvt+7.14103e-08*ss_flag_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt-7.60474e-07*ff_flag_mlvt+7.60474e-07*ss_flag_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt+7.28385e-14*ff_flag_mlvt-7.28385e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = 2.00001e-05         WMIN       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4276847+(dvthn_mlvt+vthmisn_mlvt)'   WVTH0      = '-9.851103e-009+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.016999242+dk2n_mlvt'  WK2        = -1.1184774e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00184
+WCIT       = '-3.968e-010+dwcitn_mlvt'
+VOFF       = -0.15391902         WVOFF      = '3.6220876e-009+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022642667+du0n_mlvt'  WU0        = '-8.2005333e-010+dwu0n_mlvt'
+UA         = -1.3081355e-009     WUA        = -2.1710251e-017     UB         = 2.1698603e-018
+WUB        = 9.0047147e-027      UC         = 7.1487333e-011      WUC        = -1.3464747e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 1.7876245           WA0        = 1.6300015e-007
+AGS        = 0.82793509          WAGS       = 9.7742421e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.024641333        WKETA      = -3.3595733e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00032208424+dpdiblc2n_mlvt'
+WPDIBLC2   = 6.9930778e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012677333
+LTVOFF     = 0                   WTVOFF     = 7.2085333e-011      PTVOFF     = 0
+KT1        = -0.20249189         WKT1       = 6.0461739e-009      KT1L       = 0
+KT2        = -0.070540667        WKT2       = 1.5938133e-009      UTE        = -1.3784667
+WUTE       = 1.0382933e-007      UA1        = 1.282e-009          WUA1       = 7.936e-017
+UB1        = -1.3882293e-018     WUB1       = -1.0978133e-027     UC1        = 5.4326667e-011
+WUC1       = 1.7194667e-018      PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'       WMIN       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42605581+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '1.6232044e-008+dlvthn_mlvt'
+WVTH0      = '-1.0264089e-008+dwvthn_mlvt'
+PVTH0      = '4.1154478e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.018007345+dk2n_mlvt'  LK2        = -1.0045864e-008
+WK2        = -9.7795291e-010     PK2        = -1.4003415e-015     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0018878992        LCIT       = '-4.7732075e-010+dlcitn_mlvt'
+WCIT       = '-4.1984897e-010+dwcitn_mlvt'
+PCIT       = 2.2968548e-016      VOFF       = -0.15467558         LVOFF      = '7.5391143e-009+dlvoffn_mlvt'
+WVOFF      = '4.2208688e-009+dwvoffn_mlvt'
+PVOFF      = '-5.9669201e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02272967+du0n_mlvt'   LU0        = '-8.6699326e-010+dlu0n_mlvt'
+WU0        = '-8.2147169e-010+dwu0n_mlvt'
+PU0        = '1.4134056e-017+dpu0n_mlvt'
+UA         = -1.314581e-009      LUA        = 6.423085e-017       WUA        = -2.263072e-017
+PUA        = 9.1725784e-024      UB         = 2.1840169e-018      LUB        = -1.410727e-025
+WUB        = 1.2264093e-026      PUB        = -3.2480061e-032     UC         = 7.141683e-011
+LUC        = 7.0257088e-019      WUC        = -1.228347e-017      PUC        = -1.1771549e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 1.8035366           LA0        = '-1.5856545e-007+dla0n_mlvt'
+WA0        = 1.8598415e-007      PA0        = -2.2903814e-013     AGS        = 0.77479681
+LAGS       = 5.2952879e-007      WAGS       = 2.0213751e-008      PAGS       = -1.0403086e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022723624        LKETA      = -1.9110184e-008
+WKETA      = -3.6716113e-009     PKETA      = 3.1094924e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '9.2111129e-005+dpdiblc2n_mlvt'
+LPDIBLC2   = 2.2917073e-009      WPDIBLC2   = 7.388388e-010       PPDIBLC2   = -3.9393101e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013017628        LTVOFF     = -3.3910735e-010
+WTVOFF     = 7.1929953e-011      PTVOFF     = 1.5483859e-018      KT1        = -0.20000319
+LKT1       = -2.4800253e-008     WKT1       = 7.4391679e-009      PKT1       = -1.3881339e-014
+KT1L       = 0                   KT2        = -0.07226453         LKT2       = 1.7178492e-008
+WKT2       = 2.4398829e-009      PKT2       = -8.4311765e-015     UTE        = -1.3598451
+LUTE       = -1.8556648e-007     WUTE       = 1.037726e-007       PUTE       = 5.6536225e-016
+UA1        = 1.3460976e-009      LUA1       = -6.3873965e-016     WUA1       = 7.3261077e-017
+PUA1       = 6.0776441e-023      UB1        = -1.4247522e-018     LUB1       = 3.639548e-025
+WUB1       = 4.8053771e-027      PUB1       = -5.8825942e-032     UC1        = 8.1281117e-011
+LUC1       = -2.6860406e-016     WUC1       = -1.5151857e-017     PUC1       = 1.681246e-022
+PRT        = 0                   AT         = 202216.18           LAT        = -0.022084463
+WAT        = -0.00070917713      PAT        = 7.0670281e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44379242+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-8.8573346e-010+dlvthn_mlvt'
+WVTH0      = '-5.8742089e-009+dwvthn_mlvt'
+PVTH0      = '-1.2126911e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.011976931+dk2n_mlvt'  LK2        = -4.2258503e-009
+WK2        = -3.096582e-009      PK2        = 6.4436865e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0011530249        LCIT       = '2.3191383e-010+dlcitn_mlvt'
+WCIT       = '-7.279858e-011+dwcitn_mlvt'
+PCIT       = -1.0525632e-016     VOFF       = -0.13612071         LVOFF      = '-1.0368368e-008+dlvoffn_mlvt'
+WVOFF      = '-4.4093367e-009+dwvoffn_mlvt'
+PVOFF      = '2.3621775e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02296062+du0n_mlvt'   LU0        = '-1.0898857e-009+dlu0n_mlvt'
+WU0        = '-9.6432059e-010+dwu0n_mlvt'
+PU0        = '1.5199896e-016+dpu0n_mlvt'
+UA         = -1.2231707e-009     LUA        = -2.3990174e-017     WUA        = -2.7617741e-017
+PUA        = 1.3985602e-023      UB         = 2.1388512e-018      LUB        = -9.748279e-026
+WUB        = -2.230697e-026      PUB        = 8.8481753e-034      UC         = 7.9956073e-011
+LUC        = -7.5387377e-018     WUC        = -2.7985123e-017     PUC        = 3.382273e-024
+VSAT       = '114026.83+dvsatn_mlvt'  LVSAT      = '-0.0038863371+dlvsatn_mlvt'
+WVSAT      = '-0.0012885866+dwvsatn_mlvt'
+PVSAT      = '1.2436279e-009+dpvsatn_mlvt'
+A0         = 2.1012026           LA0        = '-4.4584588e-007+dla0n_mlvt'
+WA0        = -1.1854956e-007     PA0        = 6.4870393e-014      AGS        = 1.8492877
+LAGS       = -5.0747307e-007     WAGS       = -3.4988232e-007     PAGS       = 2.5315256e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.036180291        LKETA      = -6.1230205e-009
+WKETA      = -2.1780491e-009     PKETA      = 1.6680405e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0029202782+dpdiblc2n_mlvt'
+LPDIBLC2   = -4.3778502e-010     WPDIBLC2   = 4.3293545e-010      PPDIBLC2   = -9.8700623e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00097124062       LTVOFF     = -2.0117097e-011
+WTVOFF     = 7.786867e-011       PTVOFF     = -4.1831298e-018     KT1        = -0.20791948
+LKT1       = -1.7160154e-008     WKT1       = -1.4988217e-008     PKT1       = 7.7635542e-015
+KT1L       = 0                   KT2        = -0.05401687         LKT2       = -4.3250772e-010
+WKT2       = -8.1942617e-009     PKT2       = 1.8319428e-015      UTE        = -1.7274986
+LUTE       = 1.6925963e-007      WUTE       = 1.3949795e-007      PUTE       = -3.3913534e-014
+UA1        = 3.3391362e-010      LUA1       = 3.3812923e-016      WUA1       = 2.8902423e-016
+PUA1       = -1.4745873e-022     UB1        = -8.5309426e-019     LUB1       = -1.8775804e-025
+WUB1       = -1.860081e-025      PUB1       = 1.2533005e-031      UC1        = -2.9157422e-010
+LUC1       = 9.1242359e-017      WUC1       = 2.120668e-016       PUC1       = -5.1166403e-023
+PRT        = 0                   AT         = 224176.96           LAT        = -0.043279029
+WAT        = 0.0090882378        PAT        = -2.3885551e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45421094+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-3.2609491e-009+dlvthn_mlvt'
+WVTH0      = '-7.6043531e-009+dwvthn_mlvt'
+PVTH0      = '2.7316917e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0033553434+dk2n_mlvt' LK2        = -2.2603008e-009
+WK2        = -2.2578918e-009     PK2        = 4.5316404e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0024283835        LCIT       = '-5.8842434e-011+dlcitn_mlvt'
+WCIT       = '-9.3654447e-010+dwcitn_mlvt'
+PCIT       = 9.166047e-017       VOFF       = -0.18990686         LVOFF      = '1.8937985e-009+dlvoffn_mlvt'
+WVOFF      = '1.0968765e-008+dwvoffn_mlvt'
+PVOFF      = '-1.143722e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.10296523+deta0n_mlvt'
+LETA0      = '1.762797e-10+dleta0n_mlvt'
+WETA0      = '-5.5171e-09+dweta0n_mlvt'
+PETA0      = '-1.092484e-16+dpeta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014783927+du0n_mlvt'  LU0        = '7.7423676e-010+dlu0n_mlvt'
+WU0        = '9.0506683e-010+dwu0n_mlvt'
+PU0        = '-2.7418398e-016+dpu0n_mlvt'
+UA         = -1.660424e-009      LUA        = 7.569483e-017       WUA        = 1.2189162e-016
+PUA        = -2.0099543e-023     UB         = 1.8854943e-018      LUB        = -3.9722495e-026
+WUB        = -1.9210541e-026     PUB        = 1.7889358e-034      UC         = 5.728725e-011
+LUC        = -2.3706995e-018     WUC        = -1.9686336e-017     PUC        = 1.4903156e-024
+VSAT       = '108347.65+dvsatn_mlvt'  LVSAT      = '-0.0025915958+dlvsatn_mlvt'
+WVSAT      = '0.0058612307+dwvsatn_mlvt'
+PVSAT      = '-3.863875e-010+dpvsatn_mlvt'
+A0         = -0.98300577         LA0        = '2.5729195e-007+dla0n_mlvt'
+WA0        = 9.8376019e-007      PA0        = -1.8643419e-013     AGS        = -2.8231338
+LAGS       = 5.5774558e-007      WAGS       = 1.311556e-006       PAGS       = -1.2562214e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041656409        LKETA      = -4.8745752e-009
+WKETA      = -7.736204e-009      PKETA      = 2.9351887e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.22629814          LPCLM      = 8.9111726e-008
+WPCLM      = -2.8028223e-008     PPCLM      = -6.2145624e-015     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00094709599
+LTVOFF     = -1.4612604e-011     WTVOFF     = 2.7416941e-011      PTVOFF     = 7.3188553e-018
+KT1        = -0.277058           LKT1       = -1.397956e-009      WKT1       = 2.8183098e-008
+PKT1       = -2.0786423e-015     KT1L       = 0                   KT2        = -0.046538569
+LKT2       = -2.1374107e-009     WKT2       = -5.5723834e-009     PKT2       = 1.234207e-015
+UTE        = -0.65956337         LUTE       = -7.4208242e-008     WUTE       = -1.1179679e-007
+PUTE       = 2.3376642e-014      UA1        = 2.5612467e-009      LUA1       = -1.6965817e-016
+WUA1       = -5.4560818e-016     PUA1       = 4.2820766e-023      UB1        = -2.0582479e-018
+LUB1       = 8.6992894e-026      WUB1       = 4.4039735e-025      PUB1       = -1.7477864e-032
+UC1        = 1.6622197e-010      LUC1       = -1.3126016e-017     WUC1       = -2.8658038e-017
+PUC1       = 3.714046e-024       PRT        = 0                   AT         = 44971.144
+LAT        = -0.0024236881       WAT        = -0.0047907659       PAT        = 7.7558019e-010
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       WMAX       = '6e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44820506+(dvthn_mlvt+vthmisn_mlvt)+0.0132545*ff_flag_mlvt'
+LVTH0      = '-2.685683e-09+dlvthn_mlvt-1.26952e-09*ff_flag_mlvt'
+WVTH0      = '-2.2097514e-08+dwvthn_mlvt-4.24143e-09*ff_flag_mlvt'
+PVTH0      = '1.6613375e-15+dpvthn_mlvt+4.06245e-16*ff_flag_mlvt'
+K1         = 0.31994             K2         = '-0.013299183+dk2n_mlvt' LK2        = -6.6511353e-010
+WK2        = -2.1217758e-011     PK2        = 2.3893317e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0036006898
+LCIT       = '5.1862823e-10+dlcitn_mlvt'
+WCIT       = '1.1272813e-09+dwcitn_mlvt'
+PCIT       = -1.0601483e-16
+VOFF       = -0.15236504
+LVOFF      = '-1.7020255e-09+dlvoffn_mlvt'
+WVOFF      = '1.3948109e-08+dwvoffn_mlvt'
+PVOFF      = '-1.4290741e-15+dpvoffn_mlvt'
+NFACTOR    = '0.88529431+dnfactorn_mlvt-0.823059*ff_flag_mlvt+0.652034*ss_flag_mlvt'
+ETA0       = '-0.019083082+deta0n_mlvt-0.0325552*ff_flag_mlvt+0.0524265*ss_flag_mlvt'
+LETA0      = '1.1866207e-08+dleta0n_mlvt+3.11815e-09*ff_flag_mlvt-5.02143e-09*ss_flag_mlvt'
+WETA0      = '3.4434473e-08+dweta0n_mlvt+8.38828e-09*ff_flag_mlvt-1.67765e-08*ss_flag_mlvt'
+PETA0      = '-3.9358612e-15+dpeta0n_mlvt-8.03425e-16*ff_flag_mlvt+1.60686e-15*ss_flag_mlvt'
+ETAB       = -0.076373459
+LETAB      = -5.080909e-10
+WETAB      = -2.9551821e-08
+PETAB      = 1.8214463e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.024170983+du0n_mlvt'
+LU0        = '-1.2486354e-10+dlu0n_mlvt'
+WU0        = '-5.2410001e-09+dwu0n_mlvt'
+PU0        = '3.1449164e-16+dpu0n_mlvt'
+UA         = -8.2122219e-010     LUA        = -4.684758e-018      WUA        = -5.3101284e-016
+PUA        = 4.24363e-023
+UB         = 1.6379302e-18
+LUB        = -1.6010509e-26
+WUB        = 1.6340937e-25
+PUB        = -1.7312678e-32
+UC         = -1.4219741e-011
+LUC        = 4.4783116e-018      WUC        = 2.9941448e-017      PUC        = -3.2630832e-024
+VSAT       = '73723.342+dvsatn_mlvt+4856.85*ff_flag_mlvt-5242.65*ss_flag_mlvt'
+LVSAT      = '0.00072475242+dlvsatn_mlvt-0.00046519*ff_flag_mlvt+0.000502143*ss_flag_mlvt'
+WVSAT      = '0.0052632379+dwvsatn_mlvt-0.00155419*ff_flag_mlvt+0.00167765*ss_flag_mlvt'
+PVSAT      = '-3.291098e-10+dpvsatn_mlvt+1.48861e-10*ff_flag_mlvt-1.60686e-10*ss_flag_mlvt'
+A0         = 4.0145518
+LA0        = '-2.2138171e-07+dla0n_mlvt'
+WA0        = 3.384293e-07
+PA0        = -1.2462214e-13
+AGS        = 2.7496326
+Pags     = 8.0342933e-14
+Wags     = -8.388247e-07
+LAGS       = 2.39813e-08
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.36913643
+LKETA      = 2.6491789e-008      WKETA      = 8.6846044e-008      PKETA      = -6.1239936e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 1.2610378
+LPCLM      = -9.9966741e-009     WPCLM      = -3.0393451e-007     PPCLM      = 2.0212018e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0013591416+dpdiblc2n_mlvt'
+LPDIBLC2   = -3.4398937e-011     WPDIBLC2   = -2.2266776e-010     PPDIBLC2   = 2.1327341e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = -0.00086115198      LTVOFF     = 1.585832e-010
+WTVOFF     = 8.4605521e-010      PTVOFF     = -7.1091137e-017     KT1        = -0.34419326
+LKT1       = 5.032327e-009       WKT1       = 3.0784511e-008      PKT1       = -2.3278082e-015
+KT1L       = 0
+KT2        = -0.13839521
+LKT2       = 6.6606766e-09
+WKT2       = 2.6118178e-08
+PKT2       = -1.8011386e-15
+UTE        = -0.52365297
+LUTE       = -8.7225876e-008     WUTE       = -1.699253e-007      PUTE       = 2.8944249e-014
+UA1        = 4.9577924e-009      LUA1       = -3.9920171e-016     WUA1       = -1.6816004e-015
+PUA1       = 1.5162724e-022      UB1        = -5.0063038e-018     LUB1       = 3.6936063e-025
+WUB1       = 1.9058735e-024      PUB1       = -1.5784264e-031     UC1        = -2.9832515e-011
+LUC1       = 5.6522777e-018      WUC1       = 6.8152816e-019      PUC1       = 9.0387302e-025
+PRT        = 0                   AT         = 19666.667           WAT        = 0.0033066667
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '-1.2958538e-08+dlnfactorn_mlvt+7.88328e-08*ff_flag_mlvt-6.2452e-08*ss_flag_mlvt'
+WNFACTOR   = '-8.388247e-08+dwnfactorn_mlvt+2.12071e-07*ff_flag_mlvt-1.06036e-07*ss_flag_mlvt'
+PNFACTOR   = '8.0342933e-15+dpnfactorn_mlvt-2.03123e-14*ff_flag_mlvt+1.01561e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = 2.00001e-05         WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40171155+(dvthn_mlvt+vthmisn_mlvt)'  WVTH0      = '-1.5396969e-009+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.0081248889+dk2n_mlvt' WK2        = 1.7213156e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0001
+WCIT       = '2.24e-010+dwcitn_mlvt'  VOFF       = -0.14674927         WVOFF      = '1.3277655e-009+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019737031+du0n_mlvt'  WU0        = '1.0975004e-010+dwu0n_mlvt'
+UA         = -1.3876311e-009     WUA        = 3.7283556e-018      UB         = 2.1326667e-018
+WUB        = 2.0906667e-026      UC         = 3.6184444e-011      WUC        = -2.1678222e-018
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.4502222           WA0        = -4.9031111e-008
+AGS        = 0.79150093          WAGS       = 2.1433174e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.019631111        WKETA      = -4.9628444e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0021243041+dpdiblc2n_mlvt'
+WPDIBLC2   = 1.2259743e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0016550111
+LTVOFF     = 0                   WTVOFF     = -5.1843556e-011     PTVOFF     = 0
+KT1        = -0.17096587         WKT1       = -4.0421547e-009     KT1L       = 0
+KT2        = -0.074963333        WKT2       = 3.0090667e-009      UTE        = -0.94635556
+WUTE       = -3.4446222e-008     UA1        = 1.6e-009            WUA1       = -2.24e-017
+UB1        = -1.3369511e-018     WUB1       = -1.7506844e-026     UC1        = 7.9455556e-011
+WUC1       = -6.3217778e-018     PRT        = 0                   AT         = 200000
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1e-005-(dxln_mlvt+dlmisn_mlvt)'       WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_mlvt+toxmisn_mlvt)'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39757681+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '4.120314e-008+dlvthn_mlvt'
+WVTH0      = '-1.1508097e-009+dwvthn_mlvt'
+PVTH0      = '-3.875303e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0095210115+dk2n_mlvt' LK2        = -1.3912516e-008
+WK2        = 1.7376739e-009      PK2        = -1.6301281e-016     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00022358126      LCIT       = '1.2315009e-009+dlcitn_mlvt'
+WCIT       = '2.5582478e-010+dwcitn_mlvt'
+PCIT       = -3.1713744e-016     VOFF       = -0.14555693         LVOFF      = '-1.188177e-008+dlvoffn_mlvt'
+WVOFF      = '1.3029025e-009+dwvoffn_mlvt'
+PVOFF      = '2.4776275e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019787828+du0n_mlvt'  LU0        = '-5.0619488e-010+dlu0n_mlvt'
+WU0        = '1.1991766e-010+dwu0n_mlvt'
+PU0        = '-1.0132143e-016+dpu0n_mlvt'
+UA         = -1.4160953e-009     LUA        = 2.8364855e-016      WUA        = 9.8538358e-018
+PUA        = -6.1041084e-023     UB         = 2.1751911e-018      LUB        = -4.2376047e-025
+WUB        = 1.5088364e-026      PUB        = 5.7980026e-032      UC         = 4.1488701e-011
+LUC        = -5.2857499e-017     WUC        = -2.7064689e-018     PUC        = 5.3676738e-024
+VSAT       = '109991.66+dvsatn_mlvt'  LVSAT      = '8.3113569e-005+dlvsatn_mlvt'
+WVSAT      = '2.6689462e-006+dwvsatn_mlvt'
+PVSAT      = '-2.6596342e-011+dpvsatn_mlvt'
+A0         = 2.5602871           LA0        = '-1.0968083e-006+dla0n_mlvt'
+WA0        = -5.6175997e-008     PA0        = 7.1199573e-014      AGS        = 0.78787773
+LAGS       = 3.6105576e-008      WAGS       = 1.6027857e-008      PAGS       = 5.3864572e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020217326        LKETA      = 5.8416966e-009
+WKETA      = -4.4736266e-009     PKETA      = -4.8751095e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0018516752+dpdiblc2n_mlvt'
+LPDIBLC2   = 2.7167764e-009      WPDIBLC2   = 1.7577829e-010      PPDIBLC2   = -5.2995312e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016612908        LTVOFF     = -6.2577869e-011
+WTVOFF     = -4.3119011e-011     PTVOFF     = -8.6941049e-017     KT1        = -0.16216021
+LKT1       = -8.7749359e-008     WKT1       = -4.6705847e-009     PKT1       = 6.2623747e-015
+KT1L       = 0                   KT2        = -0.073651203        LKT2       = -1.3075522e-008
+WKT2       = 2.8836182e-009      PKT2       = 1.2501079e-015      UTE        = -0.91695187
+LUTE       = -2.9301095e-007     WUTE       = -3.7953218e-008     PUTE       = 3.4947594e-014
+UA1        = 1.6683918e-009      LUA1       = -6.8153127e-016     WUA1       = -2.9873049e-017
+PUA1       = 7.4469758e-023      UB1        = -1.3894768e-018     LUB1       = 5.2342433e-025
+WUB1       = -6.4827623e-027     PUB1       = -1.0985619e-031     UC1        = 3.4504068e-011
+LUC1       = 4.4794652e-016      WUC1       = -1.8320158e-019     PUC1       = -6.1171587e-023
+PRT        = 0                   AT         = 199165.95           LAT        = 0.0083113569
+WAT        = 0.00026689462       PAT        = -2.6596342e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '1.000002e-006-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44102656+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-7.3064059e-010+dlvthn_mlvt'
+WVTH0      = '-4.989133e-009+dwvthn_mlvt'
+PVTH0      = '-1.7089884e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0030841439+dk2n_mlvt'
+LK2        = -1.7471541e-009     WK2        = 1.722962e-009       PK2        = -1.4881416e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011992438
+LCIT       = '-1.4168183e-010+dlcitn_mlvt'
+WCIT       = '-8.7588649e-011+dwcitn_mlvt'
+PCIT       = 1.4294291e-017      VOFF       = -0.15305248         LVOFF      = '-4.6477361e-009+dlvoffn_mlvt'
+WVOFF      = '1.0088296e-009+dwvoffn_mlvt'
+PVOFF      = '5.3157543e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019886018+du0n_mlvt'  LU0        = '-6.0095944e-010+dlu0n_mlvt'
+WU0        = '1.9551924e-011+dwu0n_mlvt'
+PU0        = '-4.4574475e-018+dpu0n_mlvt'
+UA         = -1.1110295e-009     LUA        = -1.0773486e-017     WUA        = -6.3502928e-017
+PUA        = 9.756262e-024       UB         = 1.7905694e-018      LUB        = -5.2558224e-026
+WUB        = 8.9143207e-026      PUB        = -1.3491044e-032     UC         = -2.0787412e-011
+LUC        = 7.2457998e-018      WUC        = 4.2527925e-018      PUC        = -1.348779e-024
+VSAT       = '110077.78+dvsatn_mlvt'  WVSAT      = '-2.4888889e-005+dwvsatn_mlvt'
+A0         = 1.4387986           LA0        = '-1.4448542e-008+dla0n_mlvt'
+WA0        = 9.3419726e-008      PA0        = -7.3176755e-014     AGS        = 0.48121726
+LAGS       = 3.3206667e-007      WAGS       = 8.7900211e-008      PAGS       = -1.5500155e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.006990853        LKETA      = -6.9233048e-009
+WKETA      = -1.1518669e-008     PKETA      = 1.9241315e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.25972553          LPCLM      = -1.0447143e-012
+WPCLM      = 5.9095831e-008      PPCLM      = 3.3430856e-019      PDIBLC1    = 0
+PDIBLC2    = '0.0056323094+dpdiblc2n_mlvt'
+LPDIBLC2   = -9.3195145e-010     WPDIBLC2   = -4.3491454e-010     PPDIBLC2   = 5.9432633e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016763501        LTVOFF     = -7.7111719e-011
+WTVOFF     = -1.4776636e-010     PTVOFF     = 1.4055149e-017      KT1        = -0.27465483
+LKT1       = 2.0820326e-008      WKT1       = 6.3670941e-009      PKT1       = -4.3901995e-015
+KT1L       = 0                   KT2        = -0.096034015        LKT2       = 8.5263542e-009
+WKT2       = 5.2512249e-009      PKT2       = -1.034893e-015      UTE        = -1.3450582
+LUTE       = 1.2015872e-007      WUTE       = 1.7117021e-008      PUTE       = -1.8201244e-014
+UA1        = 9.9167261e-010      LUA1       = -2.8422861e-017     WUA1       = 7.8541349e-017
+PUA1       = -3.0162062e-023     UB1        = -9.5222251e-019     LUB1       = 1.0142584e-025
+WUB1       = -1.5428706e-025     PUB1       = 3.2791213e-032      UC1        = 6.2488934e-010
+LUC1       = -1.2184022e-016     WUC1       = -8.1201539e-017     PUC1       = 1.702002e-023
+PRT        = 0                   AT         = 272864.16           LAT        = -0.062815518
+WAT        = -0.006491667        PAT        = 3.8631212e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+LMAX       = '2.399959e-007-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45945038+(dvthn_mlvt+vthmisn_mlvt)'  LVTH0      = '-4.9309045e-009+dlvthn_mlvt'
+WVTH0      = '-9.2809733e-009+dwvthn_mlvt'
+PVTH0      = '8.0755491e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0051767884+dk2n_mlvt'
+LK2        = -1.270073e-009      WK2        = 4.7239043e-010      PK2        = 1.3629114e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00052078982
+LCIT       = '2.5045144e-010+dlcitn_mlvt'
+WCIT       = '7.1909851e-012+dwcitn_mlvt'
+PCIT       = -7.3135697e-018     VOFF       = -0.16902629         LVOFF      = '-1.0060278e-009+dlvoffn_mlvt'
+WVOFF      = '4.2869811e-009+dwvoffn_mlvt'
+PVOFF      = '-2.1577756e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.092284295+deta0n_mlvt'
+LETA0      = '-2.93549e-10+dleta0n_mlvt'
+WETA0      = '-2.0992013e-09+dweta0n_mlvt'
+PETA0      = '4.10969e-17+dpeta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018716753+du0n_mlvt'  LU0        = '-3.3439041e-010+dlu0n_mlvt'
+WU0        = '-3.5343762e-010+dwu0n_mlvt'
+PU0        = '8.0576709e-017+dpu0n_mlvt'
+UA         = -1.0699161e-009     LUA        = -2.0146527e-017     WUA        = -6.7070912e-017
+PUA        = 1.0569691e-023      UB         = 1.6471084e-018      LUB        = -1.9851994e-026
+WUB        = 5.7072951e-026      PUB        = -6.1796667e-033     UC         = -4.4895282e-012
+LUC        = 3.5302083e-018      WUC        = 8.223327e-020       PUC        = -3.9797494e-025
+VSAT       = '127361.64+dvsatn_mlvt'  LVSAT      = '-0.0039403743+dlvsatn_mlvt'
+WVSAT      = '-0.00022324674+dwvsatn_mlvt'
+PVSAT      = '4.5221623e-011+dpvsatn_mlvt'
+A0         = 2.9007007           LA0        = '-3.4773299e-007+dla0n_mlvt'
+WA0        = -2.5902588e-007     PA0        = 7.1737938e-015      AGS        = 1.1681751
+LAGS       = 1.7545402e-007      WAGS       = 3.4337137e-008      PAGS       = -3.2888453e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.091684306        LKETA      = 1.2385109e-008
+WKETA      = 8.2727232e-009      PKETA      = -2.5879101e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.10444213         LPCLM      = 8.3021898e-008
+WPCLM      = 7.7808664e-008      PPCLM      = -4.2658173e-015     PDIBLC1    = 0
+PDIBLC2    = '0.0019389061+dpdiblc2n_mlvt'
+LPDIBLC2   = -8.9929363e-011     WPDIBLC2   = -3.0044995e-010     PPDIBLC2   = 2.8777396e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0014974253        LTVOFF     = -3.6320451e-011
+WTVOFF     = -1.4868844e-010     PTVOFF     = 1.4265366e-017      KT1        = -0.11754841
+LKT1       = -1.4996797e-008     WKT1       = -2.2859971e-008     PKT1       = 2.2729868e-015
+KT1L       = 0                   KT2        = -0.070200221        LKT2       = 2.6367656e-009
+WKT2       = 1.999345e-009       PKT2       = -2.9352944e-016     UTE        = -0.85631913
+LUTE       = 8.7359953e-009      WUTE       = -4.8834951e-008     PUTE       = -3.1655136e-015
+UA1        = 8.5127789e-010      LUA1       = 3.5843275e-018      WUA1       = 1.58184e-018
+PUA1       = -1.2616833e-023     UB1        = -5.9081832e-019     LUB1       = 1.9032907e-026
+WUB1       = -2.9180118e-026     PUB1       = 4.2693323e-033      UC1        = 8.9570029e-011
+LUC1       = 2.0188224e-019      WUC1       = -4.1294185e-018     PUC1       = -5.5088158e-025
+PRT        = 0                   AT         = -24643.815          LAT        = 0.0050103502
+WAT        = 0.017486021         PAT        = -1.6033121e-009
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_mlvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-(dxln_mlvt+dlmisn_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_mlvt+dwmisn_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_mlvt+toxmisn_mlvt)'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+(dxln_mlvt+dlmisn_mlvt)'       XW         = '2.0e-08+(dxwn_mlvt+dwmisn_mlvt)'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.36917377+(dvthn_mlvt+vthmisn_mlvt)'
+LVTH0      = '3.7158842e-09+dlvthn_mlvt'
+WVTH0      = '3.1924955e-09+dwvthn_mlvt'
+PVTH0      = '-3.87164e-16+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.017993665+dk2n_mlvt' LK2        = -4.245975e-011
+WK2        = 1.4810162e-009      PK2        = 3.9683957e-017      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -5.92111e-05
+LCIT       = '2.0624097e-10+dlcitn_mlvt'
+WCIT       = '-5.99189e-12+dwcitn_mlvt'
+PCIT       = -6.050901e-18
+VOFF       = -0.07602881
+LVOFF      = '-9.9133842e-09+dlvoffn_mlvt'
+WVOFF      = '-1.0479483e-08+dwvoffn_mlvt'
+PVOFF      = '1.1985608e-15+dpvoffn_mlvt'
+NFACTOR    = '0.52450949+dnfactorn_mlvt+0.69479*ss_flag_mlvt-0.285042*ff_flag_mlvt'
+ETA0       = '0.14010297+deta0n_mlvt-0.0112745*ff_flag_mlvt'
+LETA0      = '-4.8736735e-09+dleta0n_mlvt+1.07988e-09*ff_flag_mlvt'
+WETA0      = '-1.6505063e-08+dweta0n_mlvt+1.57843e-09*ff_flag_mlvt'
+PETA0      = '1.4209008e-15+dpeta0n_mlvt-1.51183e-16*ff_flag_mlvt'
+ETAB       = -0.22928538
+LETAB      = 7.9914046e-09
+WETAB      = 1.9379993e-08
+PETAB      = -8.9839211e-16
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0005163436+du0n_mlvt'
+LU0        = '1.4088608e-09+dlu0n_mlvt'
+WU0        = '2.3284845e-09+dwu0n_mlvt'
+PU0        = '-1.7630017e-16+dpu0n_mlvt'
+UA         = -2.711597e-009      LUA        = 1.3709532e-016      WUA        = 7.3907108e-017
+PUA        = -2.9333248e-024
+UB         = 1.717091e-18
+LUB        = -2.6555216e-26
+WUB        = 1.3807793e-25
+PUB        = -1.3938372e-32
+UC         = 8.4822175e-011
+LUC        = -5.0241559e-018     WUC        = -1.7519653e-018     PUC        = -2.2229358e-025
+VSAT       = '86926.88+dvsatn_mlvt+986.521*ff_flag_mlvt'
+WVSAT      = '0.0010381057+dwvsatn_mlvt-0.000315687*ff_flag_mlvt'
+A0         = 7.8850637
+LA0        = '-8.2513494e-07+dla0n_mlvt'
+WA0        = -9.0013451e-07
+PA0        = 6.8578891e-14
+AGS        = -0.8582156
+Pags     = -3.0236588e-14
+Wags     = 3.1568672e-07
+LAGS       = 3.6954231e-07
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.087025563
+LKETA      = -4.7319014e-009     WKETA      = -5.9125793e-008     PKETA      = 3.8675872e-015
+DWG        = 0                   DWB        = 0
+PCLM       = -0.18830795
+LPCLM      = 9.1054587e-08
+WPCLM      = 1.5985613e-07
+PPCLM      = -1.2124386e-14
+PDIBLC1    = 0                   PDIBLC2    = '0.00040143075+dpdiblc2n_mlvt'
+LPDIBLC2   = 5.7331562e-011      WPDIBLC2   = 8.3799696e-011      PPDIBLC2   = -8.0264186e-018
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0015650114        LTVOFF     = -4.2793916e-011
+WTVOFF     = 6.9682922e-011      PTVOFF     = -6.6504612e-018     KT1        = -0.27336375
+LKT1       = -7.2647279e-011     WKT1       = 8.1190665e-009      PKT1       = -6.9421642e-016
+KT1L       = 0
+KT2        = -0.033021102
+LKT2       = -9.242786e-10
+WKT2       = -7.6015353e-09
+PKT2       = 6.2604703e-16
+UTE        = -0.38851129
+LUTE       = -3.6071108e-008     WUTE       = -2.1317063e-007     PUTE       = 1.2574723e-014
+UA1        = 9.3863422e-010      LUA1       = -4.782749e-018      WUA1       = -3.954698e-016
+PUA1       = 2.541317e-023       UB1        = 4.7400456e-019      LUB1       = -8.2956893e-026
+WUB1       = 1.5217483e-025      PUB1       = -1.3101026e-032     UC1        = 5.5175742e-011
+LUC1       = 3.4962015e-018      WUC1       = -2.6521114e-017     PUC1       = 1.5938174e-024
+PRT        = 0                   AT         = 27666.667           WAT        = 0.00074666667
+NOIA       = 'noianmac_mlvt'
+NOIB       = 'noibnmac_mlvt'
+NOIC       = 'noicnmac_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+PVSAT      = '-7.5591471e-11+dpvsatn_mlvt+3.02366e-11*ff_flag_mlvt'
+LVSAT      = '-6.749239e-05+dlvsatn_mlvt-9.44893e-05*ff_flag_mlvt'
+LNFACTOR   = '2.1597563e-08+dlnfactorn_mlvt-6.65473e-08*ss_flag_mlvt+2.73014e-08*ff_flag_mlvt'
+WNFACTOR   = '3.1568672e-08+dwnfactorn_mlvt-1.19718e-07*ss_flag_mlvt+3.99059e-08*ff_flag_mlvt'
+PNFACTOR   = '-3.0236588e-15+dpnfactorn_mlvt+1.14666e-14*ss_flag_mlvt-3.8222e-15*ff_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )

**********************************************************************************************
*                                                                                            *
*                               1.2V mlvt-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************



.ends nch_mlvt_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_mlvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.1e-008' xw='+2.0e-08+dxwp_mlvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_mlvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_mlvt  temp2=parp2_mlvt
+fac1='0.926872*temp1*sigma+0.375377*temp2*sigma'
+fac2='0.926872*temp1*sigma-0.375377*temp2*sigma'
.param  lef='l*scale+2e-09'
+       wef='w/nf*scale+2.0e-08'
+       geo_fac  = '1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_mlvt='(0.002727507+0.00012807/(lef*1e6)-0.0000020807/(lef*lef*1e12)-0.00017615*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisp_mlvt = '0.00253346*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_mlvt = '-0.00253346*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_mlvt='0.00253346*geo_fac*toxp_mlvt*fac2*mismatchflag' 
.param tnoiax='1.773e05/(l*scale*1e6)+6.520e07'
.param rnoiax='0.0143/(l*scale*1e6)+0.4706'

.param fn_dice='noiseflagp_mlvt_mc*par1fn_mc+noiseflagp_mlvt_mc_mis*par2fp_mlvt_mc'
.param arearatio='sigma_factor_flicker_mlvt*(log(3.873)-min(0,0.5*log(((w*scale*l*scale*multi)/(10.3E-6*1E-6*1))**0.5)))'
.param noiapmac_mlvt='c1fp_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_mlvt)*arearatio)'
.param noibpmac_mlvt='c2fp_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_mlvt)*arearatio)'
.param noicpmac_mlvt='c3fp_mlvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_mlvt)*arearatio)'

.MODEL pch_mlvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = 2.000001e-05        WMIN       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = 0.00090000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_mlvt+toxmisp_mlvt)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40478507+(dvthp_mlvt+vthmisp_mlvt)' K1         = 0.23752
+K2         = '0.01799+dk2p_mlvt'      K3         = -2.4570454          K3B        = 2.1204211
+W0         = 0                   DVT0       = 10.498235           DVT1       = 1.3326361
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.4494              MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1e-010              DVTP1      = 0.3712
+LPE0       = 1.4959847e-007      LPEB       = 3.4167544e-008      WEB        = -210
+WEC        = -3510               SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020
+NDEP       = 6.3687e+017         NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 3.295e-005          VOFF       = -0.090520243        NFACTOR    = '0.7+dnfactorp_mlvt'
+ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p_mlvt'      UA         = 2.125e-009
+UB         = 1.1188572e-018      UC         = 5.989e-011          VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.1738374           AGS        = 1.0392952           A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04364            DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2p_mlvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.002061            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2107
+KT1L       = 0                   KT2        = -0.04721            UTE        = -1.871
+UA1        = -4.98e-010          UB1        = -2e-018             UC1        = 2.97e-011
+PRT        = 0
+AT         = '190000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'
+WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'
+WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40465395+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-1.3068431e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.01701623+dk2p_mlvt'   LK2        = '9.7051776e-009+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -1.7211113e-005
+LCIT       = '4.9993574e-010+dlcitp_mlvt'
+VOFF       = -0.090095029        LVOFF      = '-4.2379431e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p_mlvt'
+LU0        = '1.4985763e-010+dlu0p_mlvt'
+UA         = 2.1364918e-009      LUA        = -1.1453404e-016     UB         = 1.120458e-018
+LUB        = -1.5954699e-026     UC         = 5.655953e-011       LUC        = 3.3193464e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.2339233           LA0        = -5.9885154e-007
+AGS        = 1.0187726           LAGS       = 2.045409e-007       A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.039535177        LKETA      = -4.0911132e-008     DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035560074+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.4224697e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021063228
+LTVOFF     = -4.517137e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2088205          LKT1       = -1.8732203e-008     KT1L       = 0
+KT2        = -0.047125154        LKT2       = -8.4562518e-010     UTE        = -1.8654152
+LUTE       = -5.5661404e-008     UA1        = -5.2291677e-010     LUA1       = 2.4833549e-016
+UB1        = -1.9183761e-018     LUB1       = -8.1351283e-025     UC1        = 6.2424743e-011
+LUC1       = -3.2615442e-016     PRT        = 0
+AT         = '191611+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.016056174+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'         WETA0      = '0+dweta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40092504+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-4.9112115e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.026125594+dk2p_mlvt'  LK2        = '9.0007509e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00023972529
+LCIT       = '2.5158128e-010+dlcitp_mlvt'
+VOFF       = -0.086981097        LVOFF      = '-7.247866e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p_mlvt'
+UA         = 2.0886074e-009      LUA        = -6.8249074e-017     UB         = 1.0708166e-018
+LUB        = 3.2028626e-026      UC         = 6.8468081e-011      LUC        = 2.168267e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.0877297           LA0        = -4.5754098e-007
+AGS        = 0.54098468          LAGS       = 6.6637023e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.066038936        LKETA      = -1.5292624e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.007+dpdiblc2p_mlvt'    PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 2.1                 DELTA      = 0.036
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55                  RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.945e-007          ALPHA1     = 0.23                BETA0      = 17.8
+AGIDL      = 1e-008              BGIDL      = 2.317e+009          CGIDL      = 4.6
+EGIDL      = 0.008744            AIGBACC    = 0.012459            BIGBACC    = 0.0046798592
+CIGBACC    = 0.245               NIGBACC    = 8.2582031           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.006941            BIGC       = 0.0013212138
+CIGC       = 0.1525875           AIGSD      = 0.00629             BIGSD      = 0.00033134367
+CIGSD      = 0.01328125          NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'
+CGBO       = 0                   CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 6.8381              NOFF       = 2.3364              VOFFCV     = -0.069707
+TVOFF      = 0.0013759405        LTVOFF     = 2.542731e-010       WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2366354          LKT1       = 8.1536504e-009
+KT1L       = 0                   KT2        = -0.046125466        LKT2       = -1.8119223e-009
+UTE        = -2.0398459          LUTE       = 1.1294316e-007      UA1        = -3.6894314e-010
+LUA1       = 9.9504733e-017      UB1        = -2.8318571e-018     LUB1       = 6.9457022e-026
+UC1        = -3.7734954e-010     LUC1       = 9.8930958e-017      PRT        = 0
+AT         = '209960.05+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.033792351+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         WVOFF      = '0+dwvoffp_mlvt'
+PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'           WU0        = '0+dwu0p_mlvt'
+PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43586814+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '3.1291616e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.026688227+dk2p_mlvt'  LK2        = '7.7061392e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00050750804
+LCIT       = '1.8996473e-010+dlcitp_mlvt'
+VOFF       = -0.10209394         LVOFF      = '-3.7704156e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.1525715+deta0p_mlvt'  LETA0      = '-3.4445173e-013+dleta0p_mlvt'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p_mlvt'      UA         = 1.9776245e-009      LUA        = -4.2712014e-017
+UB         = 8.7504948e-019      LUB        = 7.707445e-026       UC         = 1.1382387e-010
+LUC        = 1.1246349e-017      VSAT       = '102515.14+dvsatp_mlvt'  LVSAT      = '0.0017222586+dlvsatp_mlvt'
+A0         = 2.8553267           LA0        = -1.7396628e-007     AGS        = 2.3173399
+LAGS       = 2.5763267e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.15948292
+LKETA      = 6.2087424e-009      DWG        = 0                   DWB        = 0
+PCLM       = 2.1496972           LPCLM      = '-3.4445173e-008+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009366305+dpdiblc2p_mlvt'
+LPDIBLC2   = -5.4448442e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0024847424
+LTVOFF     = -8.6112932e-013     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.19244272         LKT1       = -2.0150426e-009     KT1L       = 0
+KT2        = -0.043364015        LKT2       = -2.4473295e-009     UTE        = -1.5257969
+LUTE       = -5.3390018e-009     UA1        = -4.5404703e-011     LUA1       = 2.5058863e-017
+UB1        = -2.6722123e-018     LUB1       = 3.2722914e-026      UC1        = 1.9891165e-011
+LUC1       = 7.5262703e-018      PRT        = 0
+AT         = '207632.63+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.033256814+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'
+WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37794575+(dvthp_mlvt+vthmisp_mlvt)-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVTH0      = '-2.5761951e-09+dlvthp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.032369455+dk2p_mlvt'  LK2        = '2.1101295e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0025451145
+LCIT       = '4.9064805e-010+dlcitp_mlvt'
+VOFF       = '-0.091458175-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVOFF      = '-4.8180449e-09+dlvoffp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.337809*ff_flag_mlvt+0.270247*sf_flag_mlvt-0.270247*fs_flag_mlvt'
+ETA0       = '0.13696261+deta0p_mlvt'
+LETA0      = '1.5371298e-09+dleta0p_mlvt'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018269064+du0p_mlvt-0.000310784*ss_flag_mlvt'
+LU0        = '5.0171587e-012+dlu0p_mlvt+3.06122e-11*ss_flag_mlvt'
+UA         = 2.7936199e-09
+Pua      = 0
+Wua      = 0
+LUA        = -1.2308757e-16
+UB         = -1.3831404e-19
+Pub      = 0
+Wub      = 0
+LUB        = 1.7689066e-25
+UC         = 2.5109082e-010      LUC        = -2.2744453e-018
+VSAT       = '130269.47+dvsatp_mlvt'
+LVSAT      = '-0.0010115384+dlvsatp_mlvt'
+A0         = -2.4686737          LA0        = 3.5044776e-007      AGS        = 5.584986
+LAGS       = -6.4230468e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.27139688
+LKETA      = 1.7232268e-008      DWG        = 0                   DWB        = 0
+PCLM       = '1.9030676-0.405371*ss_flag_mlvt'
+Wpclm    = '0+0.0*ss_flag_mlvt'
+LPCLM      = '-1.0152113e-08+dlpclmp_mlvt+3.99289e-08*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035644164+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.7001609e-011      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0038291897
+LTVOFF     = -1.3328918e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20152438         LKT1       = -1.1204988e-009     KT1L       = 0
+KT2        = -0.07256623         LKT2       = 4.2908867e-010      WKT2       = -3.4270439e-007
+PKT2       = 3.3756383e-014      UTE        = -2.5647553          LUTE       = 9.6998401e-008
+UA1        = -4.88626e-009       LUA1       = 5.0188311e-016      UB1        = 4.1052355e-019
+LUB1       = -2.7092657e-025     UC1        = -2.6143785e-010     LUC1       = 3.5237178e-017
+PRT        = 0
+AT         = '-191122.75+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '0.0060205904+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVTH0      = '0+dpvthp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WK2        = '0+dwk2p_mlvt'
+PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'
+WETA0      = '0+dweta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'
+WVOFF      = '0+dwvoffp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVOFF      = '0+dpvoffp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WU0        = '0+dwu0p_mlvt+0.0*ss_flag_mlvt'
+PU0        = '0+dpu0p_mlvt+0.0*ss_flag_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt-3.32741e-08*ff_flag_mlvt-2.66193e-08*sf_flag_mlvt+2.66193e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'
+PPCLM      = '0+dppclmp_mlvt+0.0*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = 2.000001e-05        WMIN       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_mlvt+toxmisp_mlvt)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40568103+(dvthp_mlvt+vthmisp_mlvt)' WVTH0      = '8.9774574e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.018667733+dk2p_mlvt'  WK2        = '-6.790888e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.2646354e-005
+WCIT       = '8.5767547e-010+dwcitp_mlvt'
+VOFF       = -0.090248724        WVOFF      = '-2.7206214e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p_mlvt'      UA         = 2.17566e-009
+WUA        = -5.076132e-016      UB         = 1.1405421e-018      WUB        = -2.1728252e-025
+UC         = 6.2729e-011         WUC        = -2.844678e-017      VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.0329858           WA0        = 1.4113335e-006      AGS        = 1.0486742
+WAGS       = -9.3977301e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.045544
+WKETA      = 1.907808e-008       DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.00097393333+dpdiblc2p_mlvt'
+WPDIBLC2   = 2.61188e-010        PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0020859333
+LTVOFF     = 0                   WTVOFF     = -2.49832e-010       PTVOFF     = 0
+KT1        = -0.210632           WKT1       = -6.8136e-010        KT1L       = 0
+KT2        = -0.047049067        WKT2       = -1.612552e-009      UTE        = -1.86964
+WUTE       = -1.36272e-008       UA1        = -5.46178e-010       WUA1       = 4.8274356e-016
+UB1        = -2.017e-018         WUB1       = 1.7034e-025         UC1        = 3.0346e-011
+WUC1       = -6.47292e-018       PRT        = 0
+AT         = '189433.33+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+WAT        = '0.005678+dwatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'
+LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40577219+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '9.0853098e-010+dlvthp_mlvt'
+WVTH0      = '1.1204701e-008+dwvthp_mlvt'
+PVTH0      = '-2.2198048e-014+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.017700018+dk2p_mlvt'  LK2        = '9.6448336e-009+dlk2p_mlvt'
+WK2        = '-6.8515553e-009+dwk2p_mlvt'
+PK2        = '6.046471e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00010956611
+LCIT       = '5.6729641e-010+dlcitp_mlvt'
+WCIT       = '9.2539704e-010+dwcitp_mlvt'
+PCIT       = '-6.7495389e-016+dpcitp_mlvt'
+VOFF       = -0.089885889        LVOFF      = '-3.6162331e-009+dlvoffp_mlvt'
+WVOFF      = '-2.0955804e-009+dwvoffp_mlvt'
+PVOFF      = '-6.2295337e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p_mlvt'  LU0        = '1.4985763e-010+dlu0p_mlvt'
+UA         = 2.185679e-009       LUA        = -9.9855131e-017     WUA        = -4.9285564e-016
+PUA        = -1.4708269e-022     UB         = 1.1467823e-018      LUB        = -6.2193658e-026
+WUB        = -2.6376923e-025     PUB        = 4.6331437e-031      UC         = 5.9336696e-011
+LUC        = 3.3809736e-017      WUC        = -2.7827206e-017     PUC        = -6.1750419e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.082638            LA0        = -4.9486334e-007
+WA0        = 1.5158789e-006      PA0        = -1.0419617e-012     AGS        = 1.02975
+LAGS       = 1.8860985e-007      WAGS       = -1.0999371e-007     PAGS       = 1.5962908e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041373691        LKETA      = -4.1563798e-008
+WKETA      = 1.8421917e-008      PKETA      = 6.5397097e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035107849+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.2077451e-009      WPDIBLC2   = 4.5312959e-011      PPDIBLC2   = 2.1515402e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0021301728        LTVOFF     = -4.4091682e-010
+WTVOFF     = -2.3897727e-010     PTVOFF     = -1.0818479e-016     KT1        = -0.20872938
+LKT1       = -1.8962699e-008     WKT1       = -9.1309027e-010     PKT1       = 2.3095629e-015
+KT1L       = 0                   KT2        = -0.046972985        LKT2       = -7.5827959e-010
+WKT2       = -1.5247384e-009     PKT2       = -8.7520279e-016     UTE        = -1.8648342
+LUTE       = -4.7897352e-008     WUTE       = -5.8215488e-009     PUTE       = -7.7795803e-014
+UA1        = -5.7456501e-010     LUA1       = 2.8292192e-016      WUA1       = 5.175153e-016
+PUA1       = -3.4655599e-022     UB1        = -1.9361064e-018     LUB1       = -8.0623403e-025
+WUB1       = 1.776578e-025       PUB1       = -7.2933566e-032     UC1        = 6.6506529e-011
+LUC1       = -3.6039753e-016     WUC1       = -4.0899501e-017     PUC1       = 3.4311596e-022
+PRT        = 0
+AT         = '191166.05+datp_mlvt'
+LAT        = '-0.017269307+dlatp_mlvt'
+WAT        = '0.004458367+dwatp_mlvt'
+PAT        = '1.2155594e-08+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.3990933+(dvthp_mlvt+vthmisp_mlvt)'  LVTH0      = '-5.5472718e-009+dlvthp_mlvt'
+WVTH0      = '-1.8353959e-008+dwvthp_mlvt'
+PVTH0      = '6.3733239e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0267055+dk2p_mlvt'    LK2        = '9.4014377e-010+dlk2p_mlvt'
+WK2        = '-5.8106529e-009+dwk2p_mlvt'
+PK2        = '-4.0148817e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00019073515
+LCIT       = '2.7702552e-010+dlcitp_mlvt'
+WCIT       = '4.9088123e-010+dwcitp_mlvt'
+PCIT       = '-2.5495134e-016+dpcitp_mlvt'
+VOFF       = -0.085868797        LVOFF      = '-7.4991505e-009+dlvoffp_mlvt'
+WVOFF      = '-1.1145253e-008+dwvoffp_mlvt'
+PVOFF      = '2.5178708e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018320708+du0p_mlvt'  LU0        = '-6.8450398e-013+dlu0p_mlvt'
+WU0        = '-7.0957345e-012+dwu0p_mlvt'
+PU0        = '6.8587299e-018+dpu0p_mlvt'
+UA         = 2.1571943e-009      LUA        = -7.2321872e-017     WUA        = -6.8724042e-016
+PUA        = 4.0809443e-023      UB         = 1.0503811e-018      LUB        = 3.0987619e-026
+WUB        = 2.0476372e-025      PUB        = 1.0430894e-032      UC         = 7.0564226e-011
+LUC        = 2.2957217e-017      WUC        = -2.100337e-017      PUC        = -1.2770955e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 3.9990876           LA0        = -4.1410363e-007
+WA0        = 8.881941e-007       PA0        = -4.3524225e-013     AGS        = 0.51343683
+LAGS       = 6.8767767e-007      WAGS       = 2.7602949e-007      PAGS       = -2.1350055e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.068491768        LKETA      = -1.5351492e-008
+WKETA      = 2.4577375e-008      PKETA      = 5.8985077e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0067025176+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.8450398e-011      WPDIBLC2   = 2.9807735e-009      PPDIBLC2   = -6.8587299e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001417086         LTVOFF     = 2.4835214e-010
+WTVOFF     = -4.122785e-010      PTVOFF     = 5.9328014e-017      KT1        = -0.23702705
+LKT1       = 8.3898043e-009      WKT1       = 3.9243084e-009      PKT1       = -2.3662618e-015
+KT1L       = 0                   KT2        = -0.046499384        LKT2       = -1.2160616e-009
+WKT2       = 3.7466529e-009      PKT2       = -5.9705244e-015     UTE        = -2.0256028
+LUTE       = 1.0750135e-007      WUTE       = -1.4271669e-007     PUTE       = 5.4526903e-014
+UA1        = -3.2474037e-010     LUA1       = 4.1441683e-017      WUA1       = -4.4291168e-016
+PUA1       = 5.8179177e-022      UB1        = -2.8877333e-018     LUB1       = 1.1360753e-025
+WUB1       = 5.5987888e-025      PUB1       = -4.4238808e-031     UC1        = -4.1188686e-010
+LUC1       = 1.0201704e-016      WUC1       = 3.4606401e-016      PUC1       = -3.0922584e-023
+PRT        = 0
+AT         = '202541.68+datp_mlvt'
+LAT        = '-0.028264981+dlatp_mlvt'
+WAT        = '0.074332056+dwatp_mlvt'
+PAT        = '-5.5384244e-08+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '3.2178643e-009+dlvthp_mlvt'
+WVTH0      = '1.3206912e-008+dwvthp_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2p_mlvt'  LK2        = '7.5980421e-010+dlk2p_mlvt'
+WK2        = '-8.0262273e-009+dwk2p_mlvt'
+PK2        = '1.0831329e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitp_mlvt'
+WCIT       = '-9.439202e-010+dwcitp_mlvt'
+PCIT       = '7.5195034e-017+dpcitp_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffp_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffp_mlvt'
+PVOFF      = '1.283818e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15306049+deta0p_mlvt' LETA0      = '-4.6449316e-013+dleta0p_mlvt'
+WETA0      = '-4.8996634e-009+dweta0p_mlvt'
+PETA0      = '1.2028151e-018+dpeta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0p_mlvt'  LU0        = '1.3663252e-012+dlu0p_mlvt'
+WU0        = '8.2210644e-011+dwu0p_mlvt'
+PU0        = '-1.3690578e-017+dpu0p_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatp_mlvt'  LVSAT      = '0.0017671522+dlvsatp_mlvt'
+WVSAT      = '0.0019549554+dwvsatp_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatp_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmp_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2p_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datp_mlvt'
+LAT        = '-0.036846346+dlatp_mlvt'
+WAT        = '-0.32267684+dwatp_mlvt'
+PAT        = '3.5967105e-08+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-005-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+(dvthp_mlvt+vthmisp_mlvt)-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVTH0      = '-2.750318e-09+dlvthp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthp_mlvt-1.6e-15*ff_flag_mlvt+2.7e-15*sf_flag_mlvt-2.7e-15*fs_flag_mlvt'
+PVTH0      = '1.7447113e-15+dpvthp_mlvt+4.7e-22*ff_flag_mlvt+1.7e-22*sf_flag_mlvt-1.7e-22*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2p_mlvt'   LK2        = '1.0154813e-010+dlk2p_mlvt'
+WK2        = '-1.8062006e-008+dwk2p_mlvt'
+PK2        = '1.0968375e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitp_mlvt'
+WCIT       = '9.334878e-11+dwcitp_mlvt'
+PCIT       = '-2.6975657e-17+dpcitp_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flag_mlvt-0.00601751*sf_flag_mlvt+0.00601751*fs_flag_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffp_mlvt+7.40903e-10*ff_flag_mlvt+5.92723e-10*sf_flag_mlvt-5.92723e-10*fs_flag_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffp_mlvt+7.67232e-09*ff_flag_mlvt+6.13786e-09*sf_flag_mlvt-6.13786e-09*fs_flag_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffp_mlvt-7.55721e-16*ff_flag_mlvt-6.04577e-16*sf_flag_mlvt+6.04577e-16*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.36078*ff_flag_mlvt+0.288624*sf_flag_mlvt-0.288624*fs_flag_mlvt'
+ETA0       = '0.14001953+deta0p_mlvt'
+LETA0      = '1.2840682e-09+dleta0p_mlvt'
+WETA0      = '-3.0630437e-08+dweta0p_mlvt'
+PETA0      = '2.5356774e-15+dpeta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0p_mlvt-0.000346007*ss_flag_mlvt'
+LU0        = '4.0694732e-012+dlu0p_mlvt+3.40816e-11*ss_flag_mlvt'
+WU0        = '-1.5318415e-010+dwu0p_mlvt+3.52927e-10*ss_flag_mlvt'
+PU0        = '9.495809e-018+dpu0p_mlvt-3.47632e-17*ss_flag_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatp_mlvt'
+LVSAT      = '-0.0010658424+dlvsatp_mlvt'
+WVSAT      = '-0.0081360267+dwvsatp_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatp_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flag_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmp_mlvt+4.44542e-08*ss_flag_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flag_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmp_mlvt-4.53433e-14*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2p_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datp_mlvt'
+LAT        = '0.0065683527+dlatp_mlvt'
+WAT        = '0.09819304+dwatp_mlvt'
+PAT        = '-5.4885776e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt-3.55368e-08*ff_flag_mlvt-2.84294e-08*sf_flag_mlvt+2.84294e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-2.3017e-07*ff_flag_mlvt-1.84136e-07*sf_flag_mlvt+1.84136e-07*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+2.26717e-14*ff_flag_mlvt+1.81374e-14*sf_flag_mlvt-1.81374e-14*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = 2.000001e-05        WMIN       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_mlvt+toxmisp_mlvt)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39498798+(dvthp_mlvt+vthmisp_mlvt)' WVTH0      = '-1.9294524e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.01549285+dk2p_mlvt'   WK2        = '-3.552507e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001967827
+WCIT       = '-1.2032073e-009+dwcitp_mlvt'
+VOFF       = -0.09144815         WVOFF      = '-1.497207e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0182575+du0p_mlvt'    WU0        = '-7.905e-011+dwu0p_mlvt'
+UA         = 1.99885e-009        WUA        = -3.27267e-016       UB         = 8.73301e-019
+WUB        = 5.530338e-026       UC         = 5.0433e-011         WUC        = -1.590486e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.6976187           WA0        = -2.8659209e-007
+AGS        = 0.9868853           WAGS       = -3.0952611e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0371165          WKETA      = 1.048203e-008       DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00265352+dpdiblc2p_mlvt'
+WPDIBLC2   = -1.4519904e-009     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.001624
+LTVOFF     = 0                   WTVOFF     = 2.2134e-010         PTVOFF     = 0
+KT1        = -0.23085728         WKT1       = 1.9948426e-008      KT1L       = 0
+KT2        = -0.0375475          WKT2       = -1.130415e-008      UTE        = -1.70165
+WUTE       = -1.84977e-007       UA1        = 5.98405e-010        WUA1       = -6.847311e-016
+UB1        = -2.3925e-018        WUB1       = 5.5335e-025         UC1        = -5.605e-012
+WUC1       = 3.01971e-017        PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'
+PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'
+PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39111725+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-3.8578036e-008+dlvthp_mlvt'
+WVTH0      = '-3.7433358e-009+dwvthp_mlvt'
+PVTH0      = '1.807825e-014+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.014568275+dk2p_mlvt'  LK2        = '9.2148693e-009+dlk2p_mlvt'
+WK2        = '-3.6571777e-009+dwk2p_mlvt'
+PK2        = '1.0432107e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020873444
+LCIT       = '-1.1911829e-009+dlcitp_mlvt'
+WCIT       = '-1.3154517e-009+dwcitp_mlvt'
+PCIT       = '1.118695e-015+dpcitp_mlvt'
+VOFF       = -0.089940125        LVOFF      = '-1.5029884e-008+dlvoffp_mlvt'
+WVOFF      = '-2.0402598e-009+dwvoffp_mlvt'
+PVOFF      = '5.4123897e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018250788+du0p_mlvt'  LU0        = '6.6900726e-011+dlu0p_mlvt'
+WU0        = '-8.753996e-011+dwu0p_mlvt'
+PU0        = '8.4616038e-017+dpu0p_mlvt'
+UA         = 2.0283313e-009      LUA        = -2.9382799e-016     WUA        = -3.3236098e-016
+PUA        = 5.0769623e-023      UB         = 8.391319e-019       LUB        = 3.4054974e-025
+WUB        = 5.0034171e-026      PUB        = 5.2516098e-032      UC         = 5.0128521e-011
+LUC        = 3.0346169e-018      WUC        = -1.8434868e-017     PUC        = 2.5215579e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.8948522           LA0        = -1.9657469e-006
+WA0        = -3.3257964e-007     PA0        = 4.5833947e-013      AGS        = 0.95157211
+LAGS       = 3.5195244e-007      WAGS       = -3.0252237e-008     PAGS       = -6.980351e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033294837        LKETA      = -3.8088992e-008
+WKETA      = 1.0181485e-008      PKETA      = 2.9954078e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.001805439+dpdiblc2p_mlvt'
+LPDIBLC2   = 8.4524839e-009      WPDIBLC2   = -1.4381348e-009     PPDIBLC2   = -1.3809337e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001669892         LTVOFF     = -4.5738688e-010
+WTVOFF     = 2.3050916e-010      PTVOFF     = -9.1385321e-017     KT1        = -0.23024672
+LKT1       = -6.0852472e-009     WKT1       = 2.1034597e-008      PKT1       = -1.0825437e-014
+KT1L       = 0                   KT2        = -0.035304454        LKT2       = -2.2355547e-008
+WKT2       = -1.342664e-008      PKT2       = 2.115401e-014       UTE        = -1.6698811
+LUTE       = -3.1662776e-007     WUTE       = -2.0467371e-007     PUTE       = 1.9630921e-013
+UA1        = 6.3625325e-010      LUA1       = -3.7721841e-016     WUA1       = -7.1751933e-016
+PUA1       = 3.2678714e-022      UB1        = -2.2894498e-018     LUB1       = -1.0270599e-024
+WUB1       = 5.3806807e-025      PUB1       = 1.5230887e-031      UC1        = -1.1364694e-011
+LUC1       = 5.7404569e-017      WUC1       = 3.8529147e-017      PUC1       = -8.304218e-023
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43560449+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '4.4232917e-009+dlvthp_mlvt'
+WVTH0      = '1.8887457e-008+dwvthp_mlvt'
+PVTH0      = '-3.7966508e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.023882732+dk2p_mlvt'  LK2        = '2.115241e-010+dlk2p_mlvt'
+WK2        = '-2.9314302e-009+dwk2p_mlvt'
+PK2        = '3.417039e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001104327
+LCIT       = '-2.4099921e-010+dlcitp_mlvt'
+WCIT       = '-4.4098244e-010+dwcitp_mlvt'
+PCIT       = '2.7343389e-016+dpcitp_mlvt'
+VOFF       = -0.10137833         LVOFF      = '-3.9737264e-009+dlvoffp_mlvt'
+WVOFF      = '4.6744705e-009+dwvoffp_mlvt'
+PVOFF      = '-1.0780618e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018313752+du0p_mlvt'  LU0        = '6.039741e-012+dlu0p_mlvt'
+UA         = 1.7761809e-009      LUA        = -5.0099652e-017     WUA        = -2.9860671e-016
+PUA        = 1.8142778e-023      UB         = 1.0785501e-018      LUB        = 1.0912836e-025
+WUB        = 1.7603136e-025      PUB        = -6.927266e-032      UC         = 3.4403006e-011
+LUC        = 1.8234884e-017      WUC        = 1.5881074e-017      PUC        = -7.9541759e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9641532           LA0        = -1.0661342e-006
+WA0        = -9.6172823e-008     PA0        = 2.2982888e-013      AGS        = 0.67053007
+LAGS       = 6.2360739e-007      WAGS       = 1.1579439e-007      PAGS       = -1.4814887e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057803706        LKETA      = -1.4398743e-008
+WKETA      = 1.3675552e-008      PKETA      = -3.8195322e-016     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.012869735+dpdiblc2p_mlvt'
+LPDIBLC2   = -2.2422539e-009     WPDIBLC2   = -3.3097886e-009     PPDIBLC2   = 1.6710454e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00085005187       LTVOFF     = 3.3506973e-010
+WTVOFF     = 1.6609632e-010      PTVOFF     = -2.9123933e-017     KT1        = -0.24612493
+LKT1       = 9.2626193e-009      WKT1       = 1.3204148e-008      PKT1       = -3.2565332e-015
+KT1L       = 0                   KT2        = -0.052092046        LKT2       = -6.1286762e-009
+WKT2       = 9.4511686e-009      PKT2       = -9.5965747e-016     UTE        = -2.2598535
+LUTE       = 2.5363892e-007      WUTE       = 9.6219042e-008      PUTE       = -9.4533423e-014
+UA1        = -7.5839073e-010     LUA1       = 9.7084307e-016      WUA1       = -5.8832305e-019
+PUA1       = -3.6619765e-022     UB1        = -2.7883902e-018     LUB1       = -5.4478464e-025
+WUB1       = 4.5854899e-025      PUB1       = 2.2917193e-031      UC1        = -4.0697082e-011
+LUC1       = 8.5757226e-017      WUC1       = -3.2549564e-017     PUC1       = -1.4337569e-023
+PRT        = 0
+AT         = '253818.5+datp_mlvt'
+LAT        = '-0.061686895+dlatp_mlvt'
+WAT        = '0.022029706+dwatp_mlvt'
+PAT        = '-2.1293892e-08+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '1.8657789e-009+dlvthp_mlvt'
+WVTH0      = '2.5644645e-010+dwvthp_mlvt'
+PVTH0      = '4.9032594e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2p_mlvt'  LK2        = '8.7204533e-010+dlk2p_mlvt'
+WK2        = '-1.4195742e-009+dwk2p_mlvt'
+PK2        = '-6.1726576e-018+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitp_mlvt'
+WCIT       = '1.6122937e-009+dwcitp_mlvt'
+PCIT       = '-1.9902291e-016+dpcitp_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffp_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffp_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14756059+deta0p_mlvt' LETA0      = '-1.9572049e-010+dleta0p_mlvt'
+WETA0      = '7.102273e-010+dweta0p_mlvt'
+PETA0      = '2.0036393e-016+dpeta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0p_mlvt'  LU0        = '-1.2055811e-011+dlu0p_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatp_mlvt'  LVSAT      = '0.0033816548+dlvsatp_mlvt'
+WVSAT      = '0.0091118432+dwvsatp_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatp_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmp_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datp_mlvt'
+LAT        = '-0.010714171+dlatp_mlvt'
+WAT        = '-0.11098338+dwatp_mlvt'
+PAT        = '9.3122869e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p_mlvt'
+PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '1e-006-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+(dvthp_mlvt+vthmisp_mlvt)-0.0172283*ff_flag_mlvt-0.0137826*sf_flag_mlvt+0.0137826*fs_flag_mlvt'
+LVTH0      = '2.958878e-09+dlvthp_mlvt+1.69698e-09*ff_flag_mlvt+1.35758e-09*sf_flag_mlvt-1.35758e-09*fs_flag_mlvt'
+WVTH0      = '4.664221e-08+dwvthp_mlvt+1.06815e-08*ff_flag_mlvt+8.54522e-09*sf_flag_mlvt-8.54522e-09*fs_flag_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthp_mlvt-1.05213e-15*ff_flag_mlvt-8.41702e-16*sf_flag_mlvt+8.41702e-16*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2p_mlvt'  LK2        = '7.0199448e-010+dlk2p_mlvt'
+WK2        = '-6.399827e-009+dwk2p_mlvt'
+PK2        = '4.8438224e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitp_mlvt'
+WCIT       = '9.515692e-10+dwcitp_mlvt'
+PCIT       = '-1.3394136e-16+dpcitp_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flag_mlvt-0.0117287*sf_flag_mlvt+0.0117287*fs_flag_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffp_mlvt+1.4441e-09*ff_flag_mlvt+1.15528e-09*sf_flag_mlvt-1.15528e-09*fs_flag_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffp_mlvt+1.49541e-08*ff_flag_mlvt+1.19633e-08*sf_flag_mlvt-1.19633e-08*fs_flag_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffp_mlvt-1.47298e-15*ff_flag_mlvt-1.17838e-15*sf_flag_mlvt+1.17838e-15*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.97289*ff_flag_mlvt+0.275652*sf_flag_mlvt-0.275652*fs_flag_mlvt'
+ETA0       = '0.07520113+deta0p_mlvt'
+LETA0      = '6.9316746e-09+dleta0p_mlvt'
+WETA0      = '3.5484332e-08+dweta0p_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0p_mlvt+0.000837767*ff_flag_mlvt+0.000670213*sf_flag_mlvt-0.000670213*fs_flag_mlvt'
+LU0        = '1.337909e-011+dlu0p_mlvt-8.25198e-11*ff_flag_mlvt-6.60158e-11*sf_flag_mlvt+6.60158e-11*fs_flag_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatp_mlvt-4188.83*ff_flag_mlvt-3351.07*sf_flag_mlvt+3351.07*fs_flag_mlvt'
+LVSAT      = '-0.0022357018+dlvsatp_mlvt+0.000412599*ff_flag_mlvt+0.000330079*sf_flag_mlvt-0.000330079*fs_flag_mlvt'
+WVSAT      = '-0.029812142+dwvsatp_mlvt+0.00427261*ff_flag_mlvt+0.00341809*sf_flag_mlvt-0.00341809*fs_flag_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatp_mlvt-4.20851e-10*ff_flag_mlvt-3.36681e-10*sf_flag_mlvt+3.36681e-10*fs_flag_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmp_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2p_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datp_mlvt'
+LAT        = '-0.0064077479+dlatp_mlvt'
+WAT        = '-0.095092602+dwatp_mlvt'
+PAT        = '7.7470449e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p_mlvt-8.54522e-10*ff_flag_mlvt-6.83618e-10*sf_flag_mlvt+6.83618e-10*fs_flag_mlvt'
+PU0        = '0+dpu0p_mlvt+8.41702e-17*ff_flag_mlvt+6.73361e-17*sf_flag_mlvt-6.73361e-17*fs_flag_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt-9.58294e-08*ff_flag_mlvt-2.71517e-08*sf_flag_mlvt+2.71517e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-8.54523e-07*ff_flag_mlvt-1.70904e-07*sf_flag_mlvt+1.70904e-07*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+8.41701e-14*ff_flag_mlvt+1.6834e-14*sf_flag_mlvt-1.6834e-14*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = 2.000001e-05        WMIN       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_mlvt+toxmisp_mlvt)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39586+(dvthp_mlvt+vthmisp_mlvt)'    WVTH0      = '-1.3888e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.0081982+dk2p_mlvt'    WK2        = '9.70176e-010+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 2.2391333e-005
+WCIT       = '2.9627733e-012+dwcitp_mlvt'
+VOFF       = -0.091604867        WVOFF      = '-1.4000427e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01813+du0p_mlvt'      UA         = 1.8358e-009
+WUA        = -2.26176e-016       UB         = 9.8152549e-019      WUB        = -1.1795806e-026
+UC         = 1.2716e-011         WUC        = 7.47968e-018        VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.9147812           WA0        = 1.9876721e-007      AGS        = 0.91700495
+WAGS       = 1.2373205e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.024978
+WKETA      = 2.95616e-009        DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '-0.0010155488+dpdiblc2p_mlvt'
+WPDIBLC2   = 8.2283226e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021580667
+LTVOFF     = 0                   WTVOFF     = -1.0978133e-010     PTVOFF     = 0
+KT1        = -0.20282363         WKT1       = 2.5675605e-009      KT1L       = 0
+KT2        = -0.068142667        WKT2       = 7.6648533e-009      UTE        = -2
+UA1        = -6.0133333e-011     WUA1       = -2.7643733e-016     UB1        = -2.9933333e-018
+WUB1       = 9.2586667e-025      UC1        = 1.2064667e-010      WUC1       = -4.8078933e-017
+PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+LU0        = '0+dlu0p_mlvt'           WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39511135+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-7.4615193e-009+dlvthp_mlvt'
+WVTH0      = '-1.2669942e-009+dwvthp_mlvt'
+PVTH0      = '-1.21399e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0067699412+dk2p_mlvt' LK2        = '1.4234884e-008+dlk2p_mlvt'
+WK2        = '1.1777893e-009+dwk2p_mlvt'
+PK2        = '-2.0691983e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -2.2145724e-005
+LCIT       = '4.4388304e-010+dlcitp_mlvt'
+WCIT       = '-7.5678113e-012+dwcitp_mlvt'
+PCIT       = '1.0495413e-016+dpcitp_mlvt'
+VOFF       = -0.090810617        LVOFF      = '-7.9159727e-009+dlvoffp_mlvt'
+WVOFF      = '-1.5005549e-009+dwvoffp_mlvt'
+PVOFF      = '1.001765e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018093556+du0p_mlvt'  LU0        = '3.6322634e-010+dlu0p_mlvt'
+WU0        = '9.9437966e-012+dwu0p_mlvt'
+PU0        = '-9.9105843e-017+dpu0p_mlvt'
+UA         = 1.8814664e-009      LUA        = -4.5513902e-016     WUA        = -2.4130478e-016
+PUA        = 1.5078246e-022      UB         = 8.9943727e-019      LUB        = 8.1814046e-025
+WUB        = 1.2644841e-026      PUB        = -2.4359015e-031     UC         = 5.3614712e-012
+LUC        = 7.3299647e-017      WUC        = 9.3207029e-018      PUC        = -1.8348739e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9358235           LA0        = -2.0972081e-007
+WA0        = 2.6201814e-007      PA0        = -6.3039668e-013     AGS        = 0.88551891
+LAGS       = 3.1380883e-007      WAGS       = 1.070075e-008       PAGS       = 1.6668688e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021109528        LKETA      = -3.8555513e-008
+WKETA      = 2.6265942e-009      PKETA      = 3.2846508e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '-0.0022129374+dpdiblc2p_mlvt'
+LPDIBLC2   = 1.1933893e-008      WPDIBLC2   = 1.0532586e-009      PPDIBLC2   = -2.296567e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0022502516        LTVOFF     = -9.1876997e-010
+WTVOFF     = -1.2931379e-010     PTVOFF     = 1.9467219e-016      KT1        = -0.20007204
+LKT1       = -2.7424003e-008     WKT1       = 2.3262956e-009      PKT1       = 2.4045909e-015
+KT1L       = 0                   KT2        = -0.071334663        LKT2       = 3.1813347e-008
+WKT2       = 8.9120895e-009      PKT2       = -1.2430704e-014     UTE        = -2
+UA1        = -2.1898977e-011     LUA1       = -3.8106653e-016     WUA1       = -3.0946494e-016
+PUA1       = 3.2917298e-022      UB1        = -3.0398017e-018     LUB1       = 4.6313143e-025
+WUB1       = 1.0032862e-024      PUB1       = -7.7160978e-031     UC1        = 1.3668863e-010
+LUC1       = -1.5988382e-016     WUC1       = -5.3263913e-017     PUC1       = 5.1676618e-023
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4015281+(dvthp_mlvt+vthmisp_mlvt)'  LVTH0      = '-1.25909e-009+dlvthp_mlvt'
+WVTH0      = '-2.2399062e-009+dwvthp_mlvt'
+PVTH0      = '-2.7357417e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020322269+dk2p_mlvt'  LK2        = '1.135217e-009+dlk2p_mlvt'
+WK2        = '-7.2394308e-010+dwk2p_mlvt'
+PK2        = '-2.309857e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00012950653
+LCIT       = '2.9729612e-010+dlcitp_mlvt'
+WCIT       = '1.6340624e-010+dwcitp_mlvt'
+PCIT       = '-6.0309219e-017+dpcitp_mlvt'
+VOFF       = -0.094380138        LVOFF      = '-4.4656764e-009+dlvoffp_mlvt'
+WVOFF      = '3.3559208e-010+dwvoffp_mlvt'
+PVOFF      = '-7.7305283e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018516405+du0p_mlvt'  LU0        = '-4.5499382e-011+dlu0p_mlvt'
+WU0        = '-1.2564511e-010+dwu0p_mlvt'
+PU0        = '3.1954257e-017+dpu0p_mlvt'
+UA         = 1.3874016e-009      LUA        = 2.2423545e-017      WUA        = -5.7563571e-017
+PUA        = -2.6821604e-023     UB         = 1.8599319e-018      LUB        = -1.1027271e-025
+WUB        = -3.0842538e-025     PUB        = 6.6756003e-032      UC         = 6.9923054e-011
+LUC        = 1.0894485e-017      WUC        = -6.141356e-018      PUC        = -3.4031283e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.5679137           LA0        = -8.2069853e-007
+WA0        = -4.7050432e-007     PA0        = 7.7658793e-014      AGS        = 0.81346956
+LAGS       = 3.8345165e-007      WAGS       = 2.7171899e-008      PAGS       = 7.4769166e-016
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.040814855        LKETA      = -1.9508364e-008
+WKETA      = 3.1424638e-009      PKETA      = 2.7860117e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0094980747+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.1404034e-010      WPDIBLC2   = -1.219359e-009      PPDIBLC2   = -9.9857052e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00090537312       LTVOFF     = 3.8118819e-010
+WTVOFF     = 1.3179714e-010      PTVOFF     = -5.7717376e-017     KT1        = -0.23415174
+LKT1       = 5.5174081e-009      WKT1       = 5.7807717e-009      PKT1       = -9.3450223e-016
+KT1L       = 0                   KT2        = -0.030743494        LKT2       = -7.4220364e-009
+WKT2       = -3.7849339e-009     PKT2       = -1.5777414e-016     UTE        = -2.1773101
+LUTE       = 1.7138772e-007      WUTE       = 4.5042127e-008      PUTE       = -4.3537675e-014
+UA1        = -1.1220652e-009     LUA1       = 6.8235303e-016      WUA1       = 2.2488985e-016
+PUA1       = -1.8733383e-022     UB1        = -2.1861765e-018     LUB1       = -3.6198181e-025
+WUB1       = 8.5176483e-026      PUB1       = 1.1583418e-031      UC1        = -9.4282854e-011
+LUC1       = 6.3372989e-017      WUC1       = 6.736151e-019       PUC1       = -4.5934244e-025
+PRT        = 0
+AT         = '274020.76+datp_mlvt'
+LAT        = '-0.081214384+dlatp_mlvt'
+WAT        = '0.0095043019+dwatp_mlvt'
+PAT        = '-9.1868488e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.41517553+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '1.8811701e-009+dlvthp_mlvt'
+WVTH0      = '-5.5183106e-009+dwvthp_mlvt'
+PVTH0      = '4.807834e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020374292+dk2p_mlvt'  LK2        = '1.1232467e-009+dlk2p_mlvt'
+WK2        = '-1.0241103e-009+dwk2p_mlvt'
+PK2        = '-1.6191751e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00085869844
+LCIT       = '1.2950979e-010+dlcitp_mlvt'
+WCIT       = '-1.0081518e-010+dwcitp_mlvt'
+PCIT       = '4.878646e-019+dpcitp_mlvt'
+VOFF       = -0.10161713         LVOFF      = '-2.8004515e-009+dlvoffp_mlvt'
+WVOFF      = '-4.2791006e-009+dwvoffp_mlvt'
+PVOFF      = '2.8878333e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15634998+deta0p_mlvt' LETA0      = '2.6339076e-010+dleta0p_mlvt'
+WETA0      = '-4.7391943e-009+dweta0p_mlvt'
+PETA0      = '-8.4285042e-017+dpeta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.017556708+du0p_mlvt'  LU0        = '1.7532593e-010+dlu0p_mlvt'
+WU0        = '5.1812534e-010+dwu0p_mlvt'
+PU0        = '-1.1617668e-016+dpu0p_mlvt'
+UA         = 1.7606824e-009      LUA        = -6.3467987e-017     WUA        = -2.1515951e-016
+PUA        = 9.4410636e-024      UB         = 1.070533e-018       LUB        = 7.1367198e-026
+WUB        = 1.0174729e-025      PUB        = -2.7624318e-032     UC         = 1.2252387e-010
+LUC        = -1.2089108e-018     WUC        = -2.7979981e-017     PUC        = 1.6219176e-024
+VSAT       = '107365.33+dvsatp_mlvt'  LVSAT      = '0.00060623504+dlvsatp_mlvt'
+WVSAT      = '0.0016334957+dwvsatp_mlvt'
+PVSAT      = '-3.7586573e-010+dpvsatp_mlvt'
+A0         = 2.4886762           LA0        = -1.1216906e-007     WA0        = -1.7134175e-007
+PA0        = 8.821785e-015       AGS        = 4.7607057           LAGS       = -5.2480344e-007
+WAGS       = -2.1052918e-007     PAGS       = 5.5442473e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.12603645         LKETA      = 1.0103917e-010      WKETA      = 1.2478354e-008
+PKETA      = 6.3783275e-016      DWG        = 0                   DWB        = 0
+PCLM       = 2.6591518           LPCLM      = '-1.5167017e-007+dlpclmp_mlvt'
+WPCLM      = 3.3108978e-008      PPCLM      = '-7.6183427e-015+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.018189484+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.3858441e-009     WPDIBLC2   = -2.7423305e-009     PPDIBLC2   = 2.5057715e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0028034616        LTVOFF     = -5.5560064e-011
+WTVOFF     = -2.6970243e-011     PTVOFF     = -2.1185159e-017     KT1        = -0.21668017
+LKT1       = 1.4972169e-009      WKT1       = 9.2746875e-010      PKT1       = 1.8223793e-016
+KT1L       = 0                   KT2        = -0.053089879        LKT2       = -2.2801556e-009
+WKT2       = -6.6189077e-009     PKT2       = 4.9432038e-016      UTE        = -1.3070703
+LUTE       = -2.8853573e-008     WUTE       = -2.817803e-007      PUTE       = 3.166384e-014
+UA1        = 3.5137962e-009      LUA1       = -3.8435405e-016     WUA1       = -1.2145568e-015
+PUA1       = 1.438814e-022       UB1        = -5.6340411e-018     LUB1       = 4.3136838e-025
+WUB1       = 1.0687354e-024      PUB1       = -1.1048174e-031     UC1        = 9.1514618e-011
+LUC1       = 2.0621177e-017      WUC1       = 1.897228e-017       PUC1       = -4.6698469e-024
+PRT        = 0
+AT         = '-52217.376+datp_mlvt'
+LAT        = '-0.0061473152+dlatp_mlvt'
+WAT        = '-0.058586759+dwatp_mlvt'
+PAT        = '6.4808363e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       WMAX       = '6e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37757342+(dvthp_mlvt+vthmisp_mlvt)'
+LVTH0      = '-1.8226422e-09+dlvthp_mlvt'
+WVTH0      = '1.067369e-08+dwvthp_mlvt'
+PVTH0      = '-1.1141261e-15+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020043122+dk2p_mlvt'  LK2        = '1.1558669e-009+dlk2p_mlvt'
+WK2        = '-4.7286672e-009+dwk2p_mlvt'
+PK2        = '2.0298134e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.00057667646
+LCIT       = '2.7089523e-10+dlcitp_mlvt'
+WCIT       = '-7.9630182e-10+dwcitp_mlvt'
+PCIT       = '6.8992913e-17+dpcitp_mlvt'
+VOFF       = '-0.078279894+0.00945867*ff_flag_mlvt+0.00756691*sf_flag_mlvt-0.00756691*fs_flag_mlvt'
+LVOFF      = '-5.0991733e-09+dlvoffp_mlvt-9.31673e-10*ff_flag_mlvt-7.45341e-10*sf_flag_mlvt+7.45341e-10*fs_flag_mlvt'
+WVOFF      = '-4.20992e-10+dwvoffp_mlvt+4.8e-15*ff_flag_mlvt-2e-16*sf_flag_mlvt+2e-16*fs_flag_mlvt'
+PVOFF      = '-9.123907e-17+dpvoffp_mlvt+3.1e-22*ff_flag_mlvt-1.5e-22*sf_flag_mlvt+1.5e-22*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt-0.261239*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+ETA0       = '0.12992738+deta0p_mlvt'
+WETA0      = '1.5540629e-09+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.019574783+du0p_mlvt-0.00111702*ff_flag_mlvt-0.000288264*ss_flag_mlvt-0.000893618*sf_flag_mlvt+0.000893618*fs_flag_mlvt'
+LU0        = '-2.3454436e-011+dlu0p_mlvt+1.10026e-10*ff_flag_mlvt+2.83939e-11*ss_flag_mlvt+8.80211e-11*sf_flag_mlvt-8.80211e-11*fs_flag_mlvt'
+WU0        = '-8.9317888e-010+dwu0p_mlvt+3.57447e-10*ff_flag_mlvt+1.78724e-10*ss_flag_mlvt+2.85958e-10*sf_flag_mlvt-2.85958e-10*fs_flag_mlvt'
+PU0        = '2.2836786e-017+dpu0p_mlvt-3.52084e-17*ff_flag_mlvt-1.76042e-17*ss_flag_mlvt-2.81668e-17*sf_flag_mlvt+2.81668e-17*fs_flag_mlvt'
+UA         = 2.4017479e-09
+LUA        = -1.2661298e-16
+WUA        = -2.6170787e-16
+PUA        = 1.402609e-23
+UB         = -3.9047577e-19
+LUB        = 2.1527654e-25
+WUB        = -4.257349e-26
+PUB        = -1.3408738e-32
+UC         = -1.5114415e-010
+LUC        = 2.574739e-017       WUC        = 4.4193923e-018      PUC        = -1.5694208e-024
+VSAT       = '107609.88+dvsatp_mlvt+5585.11*ff_flag_mlvt+4468.09*sf_flag_mlvt-4468.09*fs_flag_mlvt'
+LVSAT      = '0.00058214433+dlvsatp_mlvt-0.000550132*ff_flag_mlvt-0.000440105*sf_flag_mlvt+0.000440105*fs_flag_mlvt'
+WVSAT      = '-0.0020840957+dwvsatp_mlvt-0.00178724*ff_flag_mlvt-0.00142979*sf_flag_mlvt+0.00142979*fs_flag_mlvt'
+PVSAT      = '-9.68219e-12+dpvsatp_mlvt+1.76042e-10*ff_flag_mlvt+1.40834e-10*sf_flag_mlvt-1.40834e-10*fs_flag_mlvt'
+A0         = -3.5451926          LA0        = 4.8216702e-007      WA0        = -6.7893192e-008
+PA0        = -1.3678978e-015     AGS        = -1.544912           LAGS       = 9.62999e-008
+WAGS       = 9.5467378e-007      PAGS       = -5.9330019e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.28207926         LKETA      = 1.5471256e-008      WKETA      = 1.8752824e-008
+PKETA      = 1.9797485e-017      DWG        = 0                   DWB        = 0
+PCLM       = '1.5673166-0.288264*ss_flag_mlvt'
+LPCLM      = '-4.4124358e-08+dlpclmp_mlvt+2.83939e-08*ss_flag_mlvt'
+WPCLM      = '-2.7082666e-07+1.78724e-07*ss_flag_mlvt'
+PPCLM      = '2.2319318e-14+dppclmp_mlvt-1.76042e-14*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0057499399+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.6054908e-010     WPDIBLC2   = -1.2089627e-009     PPDIBLC2   = 9.9540429e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.003039542         LTVOFF     = -7.8813989e-011
+WTVOFF     = -8.0234889e-010     PTVOFF     = 5.5189638e-017
+KT1        = -0.22681153
+LKT1       = 2.4951627e-09
+WKT1       = 2.3957035e-08
+PKT1       = -2.0861782e-15
+KT1L       = 0                   KT2        = -0.092007203        LKT2       = 1.5532008e-009
+WKT2       = -7.877144e-009      PKT2       = 6.1825666e-016      UTE        = -2.9967679
+LUTE       = 1.3758164e-007      WUTE       = 4.2144814e-007      PUTE       = -3.7604162e-014
+UA1        = -4.748832e-009      LUA1       = 4.2951483e-016      WUA1       = 6.6412562e-016
+PUA1       = -4.1168815e-023     UB1        = -7.634209e-019      LUB1       = -4.8387708e-026
+WUB1       = 8.0045741e-025      PUB1       = -8.4056362e-032     UC1        = 2.3476355e-010
+LUC1       = 6.5111571e-018      WUC1       = 2.0967956e-017      PUC1       = -4.866421e-024
+PRT        = 0
+AT         = '-240720.63+datp_mlvt'
+LAT        = '0.012420255+dlatp_mlvt'
+WAT        = '0.047069619+dwatp_mlvt'
+PAT        = '-3.9263169e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '2.8660095e-09+dleta0p_mlvt'
+PETA0      = '-7.0416881e-16+dpeta0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt+2.5732e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-8.93621e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+8.80214e-15*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = 2.000001e-05        WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_mlvt+toxmisp_mlvt)'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39886347+(dvthp_mlvt+vthmisp_mlvt)' WVTH0      = '-4.2769067e-010+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.0042611111+dk2p_mlvt' WK2        = '2.2300444e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 3.3905556e-005
+WCIT       = '-7.2177778e-013+dwcitp_mlvt'
+VOFF       = -0.094192791        WVOFF      = '-5.7190684e-010+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018635556+du0p_mlvt'  WU0        = '-1.6177778e-010+dwu0p_mlvt'
+UA         = 1.7390889e-009      WUA        = -1.9522844e-016     UB         = 9.0724751e-019
+WUB        = 1.1973148e-026      UC         = 2.7868889e-011      WUC        = 2.6307556e-018
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9424518           WA0        = 1.8991262e-007
+AGS        = 0.96980191          WAGS       = -4.5218203e-009     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.025255333        WKETA      = 3.0449067e-009      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.0012224845+dpdiblc2p_mlvt'
+WPDIBLC2   = 1.0666159e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0019168889
+LTVOFF     = 0                   WTVOFF     = -3.2604444e-011     PTVOFF     = 0
+KT1        = -0.18476667         WKT1       = -3.2106667e-009     KT1L       = 0
+KT2        = -0.046056667        WKT2       = 5.9733333e-010      UTE        = -2
+UA1        = -1.4863333e-009     WUA1       = 1.7994667e-016      UB1        = 1.9633333e-019
+WUB1       = -9.4826667e-026     UC1        = -8.8333333e-012     WUC1       = -6.6453333e-018
+PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+LU0        = '0+dlu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.000249e-005-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39822143+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-6.3989092e-009+dlvthp_mlvt'
+WVTH0      = '-2.7176737e-010+dwvthp_mlvt'
+PVTH0      = '-1.5540252e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0031573454+dk2p_mlvt' LK2        = '1.1000792e-008+dlk2p_mlvt'
+WK2        = '2.3338199e-009+dwk2p_mlvt'
+PK2        = '-1.0342889e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.0119082e-005
+LCIT       = '8.3743995e-010+dlcitp_mlvt'
+WCIT       = '1.3836631e-012+dwcitp_mlvt'
+PCIT       = '-2.0984087e-017+dpcitp_mlvt'
+VOFF       = -0.093830612        LVOFF      = '-3.6096908e-009+dlvoffp_mlvt'
+WVOFF      = '-5.3415624e-010+dwvoffp_mlvt'
+PVOFF      = '-3.7624521e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018684482+du0p_mlvt'  LU0        = '-4.8763196e-010+dlu0p_mlvt'
+WU0        = '-1.7915269e-010+dwu0p_mlvt'
+PU0        = '1.7316881e-016+dpu0p_mlvt'
+UA         = 1.7479112e-009      LUA        = -8.7928367e-017     WUA        = -1.985671e-016
+PUA        = 3.3275053e-023      UB         = 9.0136967e-019      LUB        = 5.8582143e-026
+WUB        = 1.2026475e-026      PUB        = -5.3148705e-034     UC         = 2.5555018e-011
+LUC        = 2.3061424e-017      WUC        = 2.8587679e-018      PUC        = -2.2725076e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.1522506           LA0        = -2.0909813e-006
+WA0        = 1.9276147e-007      PA0        = -2.8393315e-014     AGS        = 0.94067619
+LAGS       = 2.9028438e-007      WAGS       = -6.94958e-009       PAGS       = 2.419651e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022063743        LKETA      = -3.1809303e-008
+WKETA      = 2.931943e-009       PKETA      = 1.1258637e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00073443994+dpdiblc2p_mlvt'
+LPDIBLC2   = 4.8641453e-009      WPDIBLC2   = 1.1009784e-010      PPDIBLC2   = -3.4247737e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0019628202        LTVOFF     = -4.5777937e-010
+WTVOFF     = -3.7335767e-011     PTVOFF     = 4.71552e-017        KT1        = -0.18211747
+LKT1       = -2.6403487e-008     WKT1       = -3.4191656e-009     PKT1       = 2.0780258e-015
+KT1L       = 0                   KT2        = -0.045396993        LKT2       = -6.574706e-009
+WKT2       = 6.1203518e-010      PKT2       = -1.4652746e-016     UTE        = -2
+UA1        = -1.5686016e-009     LUA1       = 8.199353e-016       WUA1       = 1.8547991e-016
+PUA1       = -5.5147606e-023     UB1        = 4.3030993e-019      LUB1       = -2.3319512e-024
+WUB1       = -1.0714949e-025     PUB1       = 1.2281665e-031      UC1        = -8.5684136e-012
+LUC1       = -2.6403487e-018     WUC1       = -6.7816596e-018     PUC1       = 1.3587091e-024
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '1.002493e-006-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40428089+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '-5.4184208e-010+dlvthp_mlvt'
+WVTH0      = '-1.3590142e-009+dwvthp_mlvt'
+PVTH0      = '-5.0309352e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.013617963+dk2p_mlvt'  LK2        = '8.8956963e-010+dlk2p_mlvt'
+WK2        = '1.421435e-009+dwk2p_mlvt'
+PK2        = '-1.5237854e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00066489035
+LCIT       = '1.4631255e-010+dlcitp_mlvt'
+WCIT       = '-7.916586e-012+dwcitp_mlvt'
+PCIT       = '-1.1994475e-017+dpcitp_mlvt'
+VOFF       = -0.09086501         LVOFF      = '-6.476239e-009+dlvoffp_mlvt'
+WVOFF      = '-7.89249e-010+dwvoffp_mlvt'
+PVOFF      = '-1.296728e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018126194+du0p_mlvt'  LU0        = '5.2008881e-011+dlu0p_mlvt'
+WU0        = '-7.7758431e-013+dwu0p_mlvt'
+PU0        = '7.5161222e-019+dpu0p_mlvt'
+UA         = 1.7085045e-009      LUA        = -4.983793e-017      WUA        = -1.6031651e-016
+PUA        = -3.6979321e-024     UB         = 8.8465665e-019      LUB        = 7.4736926e-026
+WUB        = 3.6627113e-027      PUB        = 7.5529189e-033      UC         = 5.2502842e-011
+LUC        = -2.9863164e-018     WUC        = -5.6688818e-019     PUC        = 1.0387281e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 3.324562            LA0        = -3.2433938e-007
+WA0        = 2.4736821e-007      PA0        = -8.1176135e-014     AGS        = 0.63607723
+LAGS       = 5.8470942e-007      WAGS       = 8.3937444e-008      PAGS       = -6.3654797e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.039544464        LKETA      = -1.4912456e-008
+WKETA      = 2.7359386e-009      PKETA      = 1.3153214e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.63897871          LPCLM      = '3.4896282e-007+dlpclmp_mlvt'
+WPCLM      = 1.5551686e-008      PPCLM      = '-1.5032244e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0048953557+dpdiblc2p_mlvt'
+LPDIBLC2   = 8.4220833e-010      WPDIBLC2   = 2.5351106e-010      PPDIBLC2   = -1.7287081e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0014875213        LTVOFF     = 1.6441517e-012
+WTVOFF     = -5.4490261e-011     PTVOFF     = 6.3736716e-017      KT1        = -0.19632548
+LKT1       = -1.2670035e-008     WKT1       = -6.3236314e-009     PKT1       = 4.8854794e-015
+KT1L       = 0                   KT2        = -0.040190418        LKT2       = -1.1607376e-008
+WKT2       = -7.6191809e-010     PKT2       = 1.1815344e-015      UTE        = -1.9417853
+LUTE       = -5.6270254e-008     WUTE       = -3.0325788e-008     PUTE       = 2.9312876e-014
+UA1        = -7.5913757e-010     LUA1       = 3.7508134e-017      WUA1       = 1.0875301e-016
+PUA1       = 1.9016541e-023      UB1        = -1.8971739e-018     LUB1       = -8.2207586e-026
+WUB1       = -7.3043398e-027     PUB1       = 2.6306428e-032      UC1        = -8.4465824e-011
+LUC1       = 7.0722012e-017      WUC1       = -2.4678347e-018     PUC1       = -2.8110297e-024
+PRT        = 0
+AT         = '310768.56+datp_mlvt'
+LAT        = '-0.11673477+dlatp_mlvt'
+WAT        = '-0.0022549945+dwatp_mlvt'
+PAT        = '2.1796754e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+LMAX       = '2.399996e-007-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42302095+(dvthp_mlvt+vthmisp_mlvt)' LVTH0      = '3.7702272e-009+dlvthp_mlvt'
+WVTH0      = '-3.0077769e-009+dwvthp_mlvt'
+PVTH0      = '-1.2371486e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.015925729+dk2p_mlvt'  LK2        = '3.5855486e-010+dlk2p_mlvt'
+WK2        = '3.9942964e-010+dwk2p_mlvt'
+PK2        = '8.2783879e-017+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00087740207
+LCIT       = '9.7413814e-011+dlcitp_mlvt'
+WCIT       = '-1.0680034e-010+dwcitp_mlvt'
+PCIT       = '1.0758577e-017+dpcitp_mlvt'
+VOFF       = -0.11205689         LVOFF      = '-1.6000077e-009+dlvoffp_mlvt'
+WVOFF      = '-9.3837657e-010+dwvoffp_mlvt'
+PVOFF      = '-9.5358696e-017+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018941031+du0p_mlvt'  LU0        = '-1.3548435e-010+dlu0p_mlvt'
+WU0        = '7.5141923e-011+dwu0p_mlvt'
+PU0        = '-1.6717391e-017+dpu0p_mlvt'
+UA         = 1.6454109e-009      LUA        = -3.5320138e-017     WUA        = -1.7827262e-016
+PUA        = 4.3375199e-025      UB         = 1.4480642e-018      LUB        = -5.4902581e-026
+WUB        = -1.9062694e-026     PUB        = 1.2782012e-032      UC         = 3.5249758e-011
+LUC        = 9.8360105e-019      WUC        = -5.2264908e-020     PUC        = 9.2031378e-025
+VSAT       = '114391.12+dvsatp_mlvt'  LVSAT      = '-0.0010103917+dlvsatp_mlvt'
+WVSAT      = '-0.00061475644+dwvsatp_mlvt'
+PVSAT      = '1.4145484e-010+dpvsatp_mlvt'
+A0         = 2.7585035           LA0        = -1.9408989e-007     WA0        = -2.576865e-007
+PA0        = 3.5036449e-014      AGS        = 4.8481565           LAGS       = -3.844858e-007
+WAGS       = -2.3851344e-007     PAGS       = 1.0540829e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.081442179        LKETA      = -5.2718337e-009     WKETA      = -1.7918112e-009
+PKETA      = 2.3571521e-015      DWG        = 0                   DWB        = 0
+PCLM       = 3.228392            LPCLM      = '-2.468586e-007+dlpclmp_mlvt'
+WPCLM      = -1.490479e-007      PPCLM      = '2.2841957e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.013031169+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.0298341e-009     WPDIBLC2   = -1.0916698e-009     PPDIBLC2   = 1.3665395e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0016914353        LTVOFF     = -4.5276266e-011
+WTVOFF     = 3.2887816e-010      PTVOFF     = -2.4475974e-017     KT1        = -0.29006066
+LKT1       = 8.8983363e-009      WKT1       = 2.4409226e-008      PKT1       = -2.1861203e-015
+KT1L       = 0                   KT2        = -0.081513175        LKT2       = -2.0990506e-009
+WKT2       = 2.4765473e-009      PKT2       = 4.3636676e-016      UTE        = -2.4467233
+LUTE       = 5.9915465e-008      WUTE       = 8.290864e-008       PUTE       = 3.2577479e-015
+UA1        = -2.3362551e-010     LUA1       = -8.3411665e-017     WUA1       = -1.5381806e-017
+PUA1       = 4.7579837e-023      UB1        = -3.3796683e-018     LUB1       = 2.5891288e-025
+WUB1       = 3.4733611e-025      PUB1       = -5.5295984e-032     UC1        = 1.9960266e-010
+LUC1       = 5.358138e-018       WUC1       = -1.5615894e-017     PUC1       = 2.1432552e-025
+PRT        = 0
+AT         = '-253490.39+datp_mlvt'
+LAT        = '0.013100647+dlatp_mlvt'
+WAT        = '0.005820604+dwatp_mlvt'
+PAT        = '3.2148828e-10+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_mlvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_mlvt+dlmisp_mlvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_mlvt+dwmisp_mlvt)'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_mlvt+toxmisp_mlvt)'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_mlvt+dlmisp_mlvt)'        XW         = '2.0e-08+(dxwp_mlvt+dwmisp_mlvt)'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.32081892+(dvthp_mlvt+vthmisp_mlvt)-0.00525481*ff_flag_mlvt-0.00420385*sf_flag_mlvt+0.00420385*fs_flag_mlvt'
+LVTH0      = '-6.2966677e-09+dlvthp_mlvt+5.17597e-10*ff_flag_mlvt+4.14078e-10*sf_flag_mlvt-4.14078e-10*fs_flag_mlvt'
+WVTH0      = '-7.4877523e-09+dwvthp_mlvt+1.68154e-09*ff_flag_mlvt+1.34523e-09*sf_flag_mlvt-1.34523e-09*fs_flag_mlvt'
+PVTH0      = '3.1756204e-16+dpvthp_mlvt-1.65631e-16*ff_flag_mlvt-1.32505e-16*sf_flag_mlvt+1.32505e-16*fs_flag_mlvt'
+K1         = 0.23752             K2         = '-9.6172764e-005+dk2p_mlvt'
+LK2        = '1.9367122e-009+dlk2p_mlvt'
+WK2        = '1.7159072e-009+dwk2p_mlvt'
+PK2        = '-4.6889159e-017+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0037013223
+LCIT       = '5.4841801e-10+dlcitp_mlvt'
+WCIT       = '2.0358487e-10+dwcitp_mlvt'
+PCIT       = '-1.9814376e-17+dpcitp_mlvt'
+VOFF       = '-0.050876122+0.0168154*ff_flag_mlvt+0.0134523*sf_flag_mlvt-0.0134523*fs_flag_mlvt'
+LVOFF      = '-7.6263077e-09+dlvoffp_mlvt-1.65631e-09*ff_flag_mlvt-1.32505e-09*sf_flag_mlvt+1.32505e-09*fs_flag_mlvt'
+WVOFF      = '-9.1901995e-09+dwvoffp_mlvt-2.35415e-09*ff_flag_mlvt-1.88332e-09*sf_flag_mlvt+1.88332e-09*fs_flag_mlvt'
+PVOFF      = '7.1744393e-16+dpvoffp_mlvt+2.31884e-16*ff_flag_mlvt+1.85507e-16*sf_flag_mlvt-1.85507e-16*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt-0.960879*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+ETA0       = '0.18967042+deta0p_mlvt'
+LETA0      = '-1.1753638e-09+dleta0p_mlvt'
+WETA0      = '-1.7563713e-08+dweta0p_mlvt'
+PETA0      = '5.8907071e-16+dpeta0p_mlvt'
+ETAB       = 0.017265187         LETAB      = -4.8777932e-009     WETAB      = -3.058086e-008
+PETAB      = 1.5608938e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.016385553+du0p_mlvt+0.00048044*ss_flag_mlvt'
+LU0        = '1.1623009e-10+dlu0p_mlvt-4.73232e-11*ss_flag_mlvt'
+WU0        = '1.2737441e-10+dwu0p_mlvt-6.72616e-11*ss_flag_mlvt'
+PU0        = '-2.1862262e-17+dpu0p_mlvt+6.62524e-18*ss_flag_mlvt'
+UA         = 2.1146812e-009      LUA        = -8.1543267e-017     WUA        = -1.6984654e-016
+PUA        = -3.9621729e-025
+UB         = -8.6501145e-19
+LUB        = 1.7293532e-25
+WUB        = 1.0927793e-25
+PUB        = 1.404511e-34
+UC         = -3.0466952e-010
+LUC        = 3.446565e-017       WUC        = 5.3547512e-017      PUC        = -4.3592643e-024
+VSAT       = '102580.28+dvsatp_mlvt-6305.77*ff_flag_mlvt-5044.62*sf_flag_mlvt+5044.62*fs_flag_mlvt'
+LVSAT      = '0.00015297777+dlvsatp_mlvt+0.000621117*ff_flag_mlvt+0.000496893*sf_flag_mlvt-0.000496893*fs_flag_mlvt'
+WVSAT      = '-0.0004746248+dwvsatp_mlvt+0.00201785*ff_flag_mlvt+0.00161428*sf_flag_mlvt-0.00161428*fs_flag_mlvt'
+PVSAT      = '1.276511e-10+dpvsatp_mlvt-1.98757e-10*ff_flag_mlvt-1.59006e-10*sf_flag_mlvt+1.59006e-10*fs_flag_mlvt'
+A0         = -3.9507937          LA0        = 4.6677589e-007      WA0        = 6.1899155e-008
+PA0        = 3.557262e-015       AGS        = 3.8863976           LAGS       = -2.8975255e-007
+WAGS       = -7.8334526e-007     PAGS       = 6.4206764e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.29827237         LKETA      = 1.608594e-008       WKETA      = 2.3934619e-008
+PKETA      = -1.769013e-016      DWG        = 0                   DWB        = 0
+PCLM       = '-0.15755717+0.48044*ss_flag_mlvt'
+LPCLM      = '8.665732e-08+dlpclmp_mlvt-4.73232e-08*ss_flag_mlvt'
+WPCLM      = '2.8113294e-07-6.72616e-08*ss_flag_mlvt'
+PPCLM      = '-1.9530819e-14+dppclmp_mlvt+6.62524e-15*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00014056647+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.675818e-010       WPDIBLC2   = 6.7599931e-010      PPDIBLC2   = -3.7461452e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 4.9882714e-005      LTVOFF     = 1.1641666e-010
+WTVOFF     = 1.5434209e-010      PTVOFF     = -7.2841711e-018
+KT1        = -0.13792108
+LKT1       = -6.0874233e-09
+WKT1       = -4.487913e-09
+PKT1       = 6.602493e-16
+KT1L       = 0
+KT2        = -0.16053846
+LKT2       = 5.684922e-09
+WKT2       = 1.4052859e-08
+PKT2       = -7.038941e-16
+UTE        = -2.1874478
+LUTE       = 3.4376828e-008      WUTE       = 1.6246569e-007      PUTE       = -4.5786219e-015
+UA1        = -6.1936262e-009     LUA1       = 5.0364841e-016      WUA1       = 1.1264598e-015
+PUA1       = -6.4891559e-023     UB1        = 4.2688773e-018      LUB1       = -4.9446886e-025
+WUB1       = -8.0987802e-025     PUB1       = 5.8689608e-032      UC1        = 4.6642041e-010
+LUC1       = -2.092341e-017      WUC1       = -5.3162239e-017     PUC1       = 3.9126405e-024
+PRT        = 0
+AT         = '-88342.852+datp_mlvt'
+LAT        = '-0.0031663846+dlatp_mlvt'
+WAT        = '-0.0016912692+dwatp_mlvt'
+PAT        = '1.0614078e-09+dpatp_mlvt'
+NOIA       = 'noiapmac_mlvt'
+NOIB       = 'noibpmac_mlvt'
+NOIC       = 'noicpmac_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt+9.46463e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt+1.34523e-07*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt-1.32505e-14*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_mlvt_mac
.ENDL MAC_mlvt







.LIB MAC_lvt
**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_lvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.25e-008' xw='+2e-08+dxwn_lvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_lvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_lvt  temp2=parn2_lvt
+fac1='0.498419*temp1*sigma+0.866936*temp2*sigma'
+fac2='0.498419*temp1*sigma-0.866936*temp2*sigma'
.param  lef='l*scale-1e-09'
+       wef='w/nf*scale+2e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_lvt='(0.00386541332-0/(lef*1e6)+0.00000403525807/(lef*lef*1e12)+0.00000587615/(wef*wef*1e12)-0.0002168162130245*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisn_lvt='0.00177811*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_lvt='-0.00177811*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_lvt='0.00177811*geo_fac*toxn_lvt*fac2*mismatchflag' 
.param tnoiax='1.349e05/(l*scale*1e6)+1.651e07'
.param rnoiax='0.0184/(l*scale*1e6)+0.4433'

.param fn_dice='noiseflagn_lvt_mc*par1fn_mc+noiseflagn_lvt_mc_mis*par2fn_lvt_mc'
.param arearatio='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.35*log(((w*scale*l*scale*multi)/(15.2E-6*1E-6*1))**0.5)))'
.param noianmac_lvt='c1fn_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_lvt)*arearatio)'
.param noibnmac_lvt='c2fn_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_lvt)*arearatio)'
.param noicnmac_lvt='c3fn_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagn_lvt)*arearatio)'

.MODEL nch_lvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_lvt+dlmisn_lvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24337292+(dvthn_lvt+vthmisn_lvt)'
+K1         = 0.217               K2         = '0.04171545+dk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.093354003+dvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02039+du0n_lvt'
+UA         = '-1.859e-009+duan_lvt'
+UB         = '2.749548e-018+dubn_lvt'
+UC         = 1.1e-010            VSAT       = '100000+dvsatn_lvt' A0         = 3.632
+AGS        = 0.90740823          A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.05681
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.004               PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0007635           LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.2450448+dkt1n_lvt'
+KT1L       = 0                   KT2        = -0.0668             UTE        = -1.31
+UA1        = '1.928e-009+dua1n_lvt'
+UB1        = '-1.661e-018+dub1n_lvt'
+UC1        = 9.447e-012          PRT        = 0                   AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'
+LU0        = '0+dlu0n_lvt'       WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+LUB        = '0+dlubn_lvt'       WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'
+LUA1       = '0+dlua1n_lvt'      WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+LKT1       = '0+dlkt1n_lvt'      WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+LVOFF      = '0+dlvoffn_lvt'     WVOFF      = '0+dwvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1e-005-(dxln_lvt+dlmisn_lvt)'   WMIN       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24049678+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.8661084e-008+dlvthn_lvt'
+K1         = 0.217               K2         = '0.043164517+dk2n_lvt'
+LK2        = '-1.444011e-008+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.091965081+dvoffn_lvt'
+LVOFF      = '-1.3840758e-008+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020675244+du0n_lvt'
+LU0        = '-2.8424841e-009+dlu0n_lvt'
+UA         = '-1.8593217e-009+duan_lvt'
+LUA        = '3.2058091e-018+dluan_lvt'
+UB         = '2.7766269e-018+dubn_lvt'
+LUB        = '-2.6984417e-025+dlubn_lvt'
+UC         = 1.1257899e-010      LUC        = -2.5699903e-017     VSAT       = '100000+dvsatn_lvt'
+A0         = 3.7051339           LA0        = -7.2878727e-007     AGS        = 0.8707789
+LAGS       = 3.6501531e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.055983222
+LKETA      = -8.2389294e-009     DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0036782967
+LPDIBLC2   = 3.2058091e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00075734474
+LTVOFF     = 6.1337814e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = '-0.24469058+dkt1n_lvt'
+LKT1       = '-3.5298095e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066867558        LKT2       = 6.7321991e-010
+UTE        = -1.3197583          LUTE       = 9.7242876e-008      UA1        = '1.957275e-009+dua1n_lvt'
+LUA1       = '-2.9172863e-016+dlua1n_lvt'
+UB1        = '-1.6246475e-018+dub1n_lvt'
+LUB1       = '-3.6225643e-025+dlub1n_lvt'
+UC1        = 7.5883054e-012      LUC1       = 1.8522096e-017      PRT        = 0
+AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'
+PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'
+PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27177817+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-1.5288943e-009+dlvthn_lvt'
+K1         = 0.217               K2         = '0.033801092+dk2n_lvt'
+LK2        = '-5.4033748e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '3.8143882e-005+dcitn_lvt'
+LCIT       = '5.9697958e-011+dlcitn_lvt'
+VOFF       = '-0.10018652+dvoffn_lvt'
+LVOFF      = '-5.9061631e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018444438+du0n_lvt'
+LU0        = '-6.8951141e-010+dlu0n_lvt'
+UA         = '-1.8411545e-009+duan_lvt'
+LUA        = '-1.432751e-017+dluan_lvt'
+UB         = '2.5673703e-018+dubn_lvt'
+LUB        = '-6.7888553e-026+dlubn_lvt'
+UC         = 9.6276879e-011      LUC        = -9.966574e-018      VSAT       = '100000+dvsatn_lvt'
+A0         = 3.4293849           LA0        = -4.6265917e-007     AGS        = 1.2332136
+LAGS       = 1.5225964e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.076554108
+LKETA      = 1.1614238e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.81271454          LPCLM      = -1.4297661e-008     PDIBLC1    = 0
+PDIBLC2    = 0.0063814388        LPDIBLC2   = 5.9697958e-010      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00076844601       LTVOFF     = 5.0623868e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.25006822+dkt1n_lvt'
+LKT1       = '1.6602002e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066689591        LKT2       = 5.0146285e-010
+UTE        = -1.2731241          LUTE       = 5.2235713e-008      UA1        = '1.7750009e-009+dua1n_lvt'
+LUA1       = '-1.1581404e-016+dlua1n_lvt'
+UB1        = '-2.3399606e-018+dub1n_lvt'
+LUB1       = '3.2809938e-025+dlub1n_lvt'
+UC1        = 1.0394314e-011      LUC1       = 1.5813989e-017      PRT        = 0
+AT         = 232497.29           LAT        = -0.050665657
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3
+XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1                   VTSSWGS    = 10
+VTSSWGD    = 10                  DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'
+PVTH0      = '0+dpvthn_lvt'      WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'
+WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'
+PUA        = '0+dpuan_lvt'       WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'
+WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'
+PUB1       = '0+dpub1n_lvt'      WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28699282+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-4.9975315e-009+dlvthn_lvt'
+K1         = 0.217               K2         = '0.027201124+dk2n_lvt'
+LK2        = '-3.8987143e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '8.2647504e-005+dcitn_lvt'
+LCIT       = '4.9552022e-011+dlcitn_lvt'
+VOFF       = '-0.11213032+dvoffn_lvt'
+LVOFF      = '-3.1832158e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.45669658+deta0n_lvt'
+LETA0      = '7.8060952e-013+dleta0n_lvt'
+ETAB       = -0.005528           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015977871+du0n_lvt'
+LU0        = '-1.2718352e-010+dlu0n_lvt'
+UA         = '-1.943848e-009+duan_lvt'
+LUA        = '9.0845374e-018+dluan_lvt'
+UB         = '2.4016641e-018+dubn_lvt'
+LUB        = '-3.0110845e-026+dlubn_lvt'
+UC         = 7.1737735e-011      LUC        = -4.3721401e-018     VSAT       = '103187.84+dvsatn_lvt'
+LVSAT      = '-0.00072676299+dlvsatn_lvt'
+A0         = 4.8899566           LA0        = -7.956403e-007      AGS        = -2.8296974
+LAGS       = 9.4148842e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.06610277
+LKETA      = 9.2315417e-009      DWG        = 0                   DWB        = 0
+PCLM       = 1.0035779           LPCLM      = -5.7810692e-008     PDIBLC1    = 0
+PDIBLC2    = -0.0033166415       LPDIBLC2   = 2.8079479e-009      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0011396763        LTVOFF     = -3.4009205e-011     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.23042531+dkt1n_lvt'
+LKT1       = '-2.8179905e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.076299486        LKT2       = 2.6923265e-009
+UTE        = -1.0758784          LUTE       = 7.2676299e-009      UA1        = '1.5001468e-009+dua1n_lvt'
+LUA1       = '-5.3152802e-017+dlua1n_lvt'
+UB1        = '-1.0912977e-018+dub1n_lvt'
+LUB1       = '4.3429209e-026+dlub1n_lvt'
+UC1        = 1.0224874e-010      LUC1       = -5.1269826e-018     PRT        = 0
+AT         = 10260
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  WETA0      = '0+dweta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'
+WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'       WUB        = '0+dwubn_lvt'
+PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'      WKT1       = '0+dwkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.23452+(dvthn_lvt+vthmisn_lvt)' LVTH0      = '2.8314967e-011+dlvthn_lvt'
+K1         = 0.217               K2         = '-0.02954405+dk2n_lvt'
+LK2        = '1.5363385e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0021258222+dcitn_lvt'
+LCIT       = '2.6107925e-010+dlcitn_lvt'
+VOFF       = '-0.098511915+dvoffn_lvt'
+LVOFF      = '-4.4875867e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.320681*ss_flag_lvt'
+ETA0       = '0.40323648+deta0n_lvt'
+LETA0      = '5.1211884e-009+dleta0n_lvt'
+ETAB       = -0.021562051
+Petab    = 0
+Wetab    = 0
+Letab    = 1.5357311e-09
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010513164+du0n_lvt'
+LU0        = '3.9622616e-010+dlu0n_lvt'
+UA         = '-2.4560086e-009+duan_lvt'
+LUA        = '5.8139284e-017+dluan_lvt'
+UB         = '2.2770536e-018+dubn_lvt'
+LUB        = '-1.8175653e-026+dlubn_lvt'
+UC         = 6.6351602e-11
+Puc      = 0
+Wuc      = 0
+LUC        = -3.8562356e-18
+VSAT       = '99768.905+dvsatn_lvt+962.043*ss_flag_lvt'
+LVSAT      = '-0.00039929768+dlvsatn_lvt-9.21439e-05*ss_flag_lvt'
+A0         = -2.4822033          LA0        = -8.9534826e-008     AGS        = 10.20685
+LAGS       = -3.0715206e-007     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.003472093
+LKETA      = 3.2327755e-009      DWG        = 0                   DWB        = 0
+PCLM       = 0.3871726           LPCLM      = 1.2286083e-009      PDIBLC1    = 0
+PDIBLC2    = 0.032413699         LPDIBLC2   = -6.1430413e-010     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0014346284        LTVOFF     = -6.2259723e-011     WTVOFF     = 0
+PTVOFF     = 0
+KT1        = '-0.20571+dkt1n_lvt'
+LKT1       = '-5.185192e-09+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.04520763         LKT2       = -2.8565142e-010
+UTE        = 0.49599538          LUTE       = -1.4328644e-007     UA1        = '3.3115344e-009+dua1n_lvt'
+LUA1       = '-2.2664751e-016+dlua1n_lvt'
+UB1        = '-1.1113672e-018+dub1n_lvt'
+LUB1       = '4.5351463e-026+dlub1n_lvt'
+UC1        = -3.4335819e-11
+Puc1     = 0
+Wuc1     = 0
+LUC1       = 7.9550049e-18
+PRT        = 0
+AT         = -33234.502          LAT        = 0.0041659034
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3
+XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1                   VTSSWGS    = 10
+VTSSWGD    = 10                  DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'
+PVTH0      = '0+dpvthn_lvt'      WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt+3.07146e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+0.0*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt+0.0*ss_flag_lvt'
+WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'
+PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'
+PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+WKT1       = '0+dwkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt+0.0*ss_flag_lvt'
+WVSAT      = '0+dwvsatn_lvt+0.0*ss_flag_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+WVOFF      = '0+dwvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_lvt+dlmisn_lvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-005-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24297418+(dvthn_lvt+vthmisn_lvt)'
+WVTH0      = '3.9954076e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.041528569+dk2n_lvt'
+WK2        = '1.8725433e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.093027422+dvoffn_lvt'
+WVOFF      = '-3.2723326e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020540733+du0n_lvt'
+WU0        = '-1.510348e-009+dwu0n_lvt'
+UA         = '-1.8724867e-009+duan_lvt'
+WUA        = '1.351364e-016+dwuan_lvt'
+UB         = '2.7691924e-018+dubn_lvt'
+WUB        = '-1.9683659e-025+dwubn_lvt'
+UC         = 1.1326513e-010      WUC        = -3.2716636e-017     VSAT       = '100000+dvsatn_lvt'
+A0         = 3.6182867           WA0        = 1.374076e-007       AGS        = 0.90926944
+WAGS       = -1.8649302e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.056897267
+WKETA      = 8.74412e-010        DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.004085
+WPDIBLC2   = -8.517e-010         PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00081586
+LTVOFF     = 0                   WTVOFF     = -5.246472e-010      PTVOFF     = 0
+KT1        = '-0.24254521+dkt1n_lvt'
+WKT1       = '-2.5045885e-008+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.0674086          WKT2       = 6.098172e-009
+UTE        = -1.31612            WUTE       = 6.13224e-008        UA1        = '1.9516867e-009+dua1n_lvt'
+WUA1       = '-2.373404e-016+dwua1n_lvt'
+UB1        = '-1.7011653e-018+dub1n_lvt'
+WUB1       = '4.0245664e-025+dwub1n_lvt'
+UC1        = 1.0537448e-011      WUC1       = -1.0926289e-017     PRT        = 0
+AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1e-005-(dxln_lvt+dlmisn_lvt)'   WMIN       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-005-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24004061+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.9233374e-008+dlvthn_lvt'
+WVTH0      = '4.5708499e-009+dwvthn_lvt'
+PVTH0      = '-5.7343455e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.042950901+dk2n_lvt'
+LK2        = '-1.4173692e-008+dlk2n_lvt'
+WK2        = '2.1404293e-009+dwk2n_lvt'
+PK2        = '-2.6695136e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.091634281+dvoffn_lvt'
+LVOFF      = '-1.3882805e-008+dlvoffn_lvt'
+WVOFF      = '-3.3146117e-009+dwvoffn_lvt'
+PVOFF      = '4.2131592e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020828043+du0n_lvt'
+LU0        = '-2.8630725e-009+dlu0n_lvt'
+WU0        = '-1.5310498e-009+dwu0n_lvt'
+PU0        = '2.0629595e-016+dpu0n_lvt'
+UA         = '-1.8740359e-009+duan_lvt'
+LUA        = '1.5437752e-017+dluan_lvt'
+WUA        = '1.4743572e-016+dwuan_lvt'
+PUA        = '-1.2256407e-022+dpuan_lvt'
+UB         = '2.7976914e-018+dubn_lvt'
+LUB        = '-2.8399583e-025+dlubn_lvt'
+WUB        = '-2.110662e-025+dwubn_lvt'
+PUB        = '1.4179956e-031+dpubn_lvt'
+UC         = 1.158299e-010       LUC        = -2.5558206e-017     WUC        = -3.2574159e-017
+PUC        = -1.4198016e-024     VSAT       = '100000+dvsatn_lvt' A0         = 3.6910438
+LA0        = -7.2503291e-007     WA0        = 1.4118264e-007      PA0        = -3.7618674e-014
+AGS        = 0.87248295          LAGS       = 3.6658144e-007      WAGS       = -1.7074554e-008
+PAGS       = -1.5692542e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.056055662
+LKETA      = -8.3866816e-009     WKETA      = 7.2584597e-010      PKETA      = 1.4804768e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0038331778        LPDIBLC2   = 2.5094361e-009
+WPDIBLC2   = -1.5519088e-009     PPDIBLC2   = 6.9776572e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00081370559       LTVOFF     = 2.1468947e-011      WTVOFF     = -5.6473567e-010
+PTVOFF     = 3.9948605e-016      KT1        = '-0.24200164+dkt1n_lvt'
+LKT1       = '-5.4167744e-009+dlkt1n_lvt'
+WKT1       = '-2.6943244e-008+dwkt1n_lvt'
+PKT1       = '1.8907388e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.067575085        LKT2       = 1.6590418e-009
+WKT2       = 7.089424e-009       PKT2       = -9.8779356e-015     UTE        = -1.3254044
+LUTE       = 9.2519651e-008      WUTE       = 5.6573158e-008      PUTE       = 4.7326719e-014
+UA1        = '1.9820555e-009+dua1n_lvt'
+LUA1       = '-3.0262838e-016+dlua1n_lvt'
+WUA1       = '-2.4830019e-016+dwua1n_lvt'
+PUA1       = '1.0921551e-022+dpua1n_lvt'
+UB1        = '-1.6648663e-018+dub1n_lvt'
+LUB1       = '-3.6172355e-025+dlub1n_lvt'
+WUB1       = '4.0299245e-025+dwub1n_lvt'
+PUB1       = '-5.3394247e-033+dpub1n_lvt'
+UC1        = 8.855967e-012       LUC1       = 1.6756143e-017      WUC1       = -1.270197e-017
+PUC1       = 1.7694853e-023      PRT        = 0                   AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27221843+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-1.8217676e-009+dlvthn_lvt'
+WVTH0      = '-4.4114797e-009+dwvthn_lvt'
+PVTH0      = '2.9345905e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.033870413+dk2n_lvt'
+LK2        = '-5.4100219e-009+dlk2n_lvt'
+WK2        = '-6.9460171e-010+dwk2n_lvt'
+PK2        = '6.6603234e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '3.1133522e-005+dcitn_lvt'
+LCIT       = '6.6463726e-011+dlcitn_lvt'
+WCIT       = '7.0243807e-011+dwcitn_lvt'
+PCIT       = '-6.7793001e-017+dpcitn_lvt'
+VOFF       = '-0.10019977+dvoffn_lvt'
+LVOFF      = '-5.6161626e-009+dlvoffn_lvt'
+WVOFF      = '1.3278935e-010+dwvoffn_lvt'
+PVOFF      = '-2.9058053e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018581163+du0n_lvt'
+LU0        = '-6.9458574e-010+dlu0n_lvt'
+WU0        = '-1.3699789e-009+dwu0n_lvt'
+PU0        = '5.0844751e-017+dpu0n_lvt'
+UA         = '-1.8432646e-009+duan_lvt'
+LUA        = '-1.4259852e-017+dluan_lvt'
+WUA        = '2.1143238e-017+dwuan_lvt'
+PUA        = '-6.7793001e-025+dpuan_lvt'
+UB         = '2.5720568e-018+dubn_lvt'
+LUB        = '-6.6233617e-026+dlubn_lvt'
+WUB        = '-4.6958447e-026+dwubn_lvt'
+PUB        = '-1.6582466e-032+dpubn_lvt'
+UC         = 9.9785376e-011      LUC        = -1.0073473e-017     WUC        = -3.515514e-017
+PUC        = 1.0711294e-024      VSAT       = '100000+dvsatn_lvt' A0         = 3.4160303
+LA0        = -4.5961458e-007     WA0        = 1.3381371e-007      PA0        = -3.050685e-014
+AGS        = 1.2445797           LAGS       = 7.4671837e-009      WAGS       = -1.1388789e-007
+PAGS       = 7.774298e-014       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.076697269
+LKETA      = 1.153474e-008       WKETA      = 1.4344793e-009      PKETA      = 7.9656776e-016
+DWG        = 0                   DWB        = 0                   PCLM       = 0.81397991
+LPCLM      = -1.5518882e-008     WPCLM      = -1.2679007e-008     PPCLM      = 1.2236637e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.0057096168        LPDIBLC2   = 6.9846611e-010
+WPDIBLC2   = 6.7316571e-009      PPDIBLC2   = -1.016895e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00077057308       LTVOFF     = 6.3096562e-011      WTVOFF     = -2.1313221e-011
+PTVOFF     = -1.249764e-016      KT1        = '-0.24937656+dkt1n_lvt'
+LKT1       = '1.7008354e-009+dlkt1n_lvt'
+WKT1       = '-6.9304443e-009+dwkt1n_lvt'
+PKT1       = '-4.0716476e-016+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066424731        LKT2       = 5.4882322e-010
+WKT2       = -2.6539054e-009     PKT2       = -4.7455101e-016     UTE        = -1.2853816
+LUTE       = 5.3893326e-008      WUTE       = 1.2282053e-007      PUTE       = -1.6609285e-014
+UA1        = '1.7912566e-009+dua1n_lvt'
+LUA1       = '-1.1848652e-016+dlua1n_lvt'
+WUA1       = '-1.628827e-016+dwua1n_lvt'
+PUA1       = '2.6778235e-023+dpua1n_lvt'
+UB1        = '-2.3986323e-018+dub1n_lvt'
+LUB1       = '3.4644131e-025+dlub1n_lvt'
+WUB1       = '5.8789026e-025+dwub1n_lvt'
+PUB1       = '-1.8378615e-031+dpub1n_lvt'
+UC1        = 8.9748141e-012      LUC1       = 1.6641443e-017      WUC1       = 1.4223394e-017
+PUC1       = -8.291084e-024      PRT        = 0                   AT         = 233196.22
+LAT        = -0.051340204        WAT        = -0.0070033076       PAT        = 6.7589622e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28615208+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-4.9983609e-009+dlvthn_lvt'
+WVTH0      = '8.4242078e-009+dwvthn_lvt'
+PVTH0      = '8.3105172e-018+dpvthn_lvt'
+K1         = 0.217               K2         = '0.027871333+dk2n_lvt'
+LK2        = '-4.0423516e-009+dlk2n_lvt'
+WK2        = '-6.7154904e-009+dwk2n_lvt'
+PK2        = '1.4392454e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00018742511+dcitn_lvt'
+LCIT       = '3.0832369e-011+dlcitn_lvt'
+WCIT       = '-1.0498717e-009+dwcitn_lvt'
+PCIT       = '1.8757092e-016+dpcitn_lvt'
+VOFF       = '-0.10966747+dvoffn_lvt'
+LVOFF      = '-3.4577165e-009+dlvoffn_lvt'
+WVOFF      = '-2.4677729e-008+dwvoffn_lvt'
+PVOFF      = '2.7504967e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915055+deta0n_lvt'
+LETA0      = '8.164015e-013+dleta0n_lvt'
+WETA0      = '-3.2518884e-007+dweta0n_lvt'
+PETA0      = '-3.586356e-019+dpeta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.016001195+du0n_lvt'
+LU0        = '-1.0640471e-010+dlu0n_lvt'
+WU0        = '-2.3370167e-010+dwu0n_lvt'
+PU0        = '-2.0820372e-016+dpu0n_lvt'
+UA         = '-1.9487815e-009+duan_lvt'
+LUA        = '9.7958842e-018+dluan_lvt'
+WUA        = '4.9434163e-017+dwuan_lvt'
+PUA        = '-7.127695e-024+dpuan_lvt'
+UB         = '2.4060267e-018+dubn_lvt'
+LUB        = '-2.8382073e-026+dlubn_lvt'
+WUB        = '-4.3713318e-026+dwubn_lvt'
+PUB        = '-1.7322291e-032+dpubn_lvt'
+UC         = 7.6073046e-011      LUC        = -4.6675362e-018     WUC        = -4.3439813e-017
+PUC        = 2.9598691e-024      VSAT       = '103154.99+dvsatn_lvt'
+LVSAT      = '-0.00071927513+dlvsatn_lvt'
+WVSAT      = '0.00032910066+dwvsatn_lvt'
+PVSAT      = '-7.5028368e-011+dpvsatn_lvt'
+A0         = 4.9425076           LA0        = -8.0762088e-007     WA0        = -5.2656106e-007
+PA0        = 1.2004539e-013      AGS        = -2.8687863          LAGS       = 9.4523235e-007
+WAGS       = 3.9167033e-007      PAGS       = -3.7514184e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.067891169        LKETA      = 9.527125e-009       WKETA      = 1.7919753e-008
+PKETA      = -2.9617448e-015     DWG        = 0                   DWB        = 0
+PCLM       = 0.99881327          LPCLM      = -5.7657191e-008     WPCLM      = 4.7741724e-008
+PPCLM      = -1.5380816e-015     PDIBLC1    = 0                   PDIBLC2    = -0.0030506425
+LPDIBLC2   = 2.69563e-009        WPDIBLC2   = -2.6653099e-009     PPDIBLC2   = 1.1254255e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.0012247098        LTVOFF     = -4.0437533e-011
+WTVOFF     = -8.5203632e-010     PTVOFF     = 6.4411854e-017      KT1        = '-0.22886246+dkt1n_lvt'
+LKT1       = '-2.9759694e-009+dlkt1n_lvt'
+WKT1       = '-1.5659777e-008+dwkt1n_lvt'
+PKT1       = '1.5829485e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.075879437        LKT2       = 2.7043071e-009
+WKT2       = -4.2088909e-009     PKT2       = -1.2004539e-016     UTE        = -1.0844779
+LUTE       = 8.0912946e-009      WUTE       = 8.6167473e-008      PUTE       = -8.2531205e-015
+UA1        = '1.5080138e-009+dua1n_lvt'
+LUA1       = '-5.391282e-017+dlua1n_lvt'
+WUA1       = '-7.8827717e-017+dwua1n_lvt'
+PUA1       = '7.6153794e-024+dpua1n_lvt'
+UB1        = '-1.0938144e-018+dub1n_lvt'
+LUB1       = '4.8968935e-026+dlub1n_lvt'
+WUB1       = '2.5217669e-026+dwub1n_lvt'
+PUB1       = '-5.550805e-032+dpub1n_lvt'
+UC1        = 1.0838036e-010      LUC1       = -6.0210332e-018     WUC1       = -6.1438819e-017
+PUC1       = 8.9583872e-024      PRT        = 0                   AT         = 8000.1333
+WAT        = 0.022643864
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-005-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.23439418+(dvthn_lvt+vthmisn_lvt)+0.000545158*ff_flag_lvt-0.000545158*ss_flag_lvt'
+LVTH0      = '-4.0988817e-011+dlvthn_lvt-5.22149e-11*ff_flag_lvt+5.22149e-11*ss_flag_lvt'
+WVTH0      = '1.260777e-009+dwvthn_lvt-5.46248e-09*ff_flag_lvt+5.46248e-09*ss_flag_lvt'
+PVTH0      = '6.9442391e-016+dpvthn_lvt+5.23193e-16*ff_flag_lvt-5.23193e-16*ss_flag_lvt'
+K1         = 0.217               K2         = '-0.030127783+dk2n_lvt'
+LK2        = '1.5128037e-009+dlk2n_lvt'
+WK2        = '5.8489997e-009+dwk2n_lvt'
+PK2        = '2.3581857e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0025254154+dcitn_lvt'
+LCIT       = '2.9066824e-010+dlcitn_lvt'
+WCIT       = '4.0039237e-009+dwcitn_lvt'
+PCIT       = '-2.964816e-016+dpcitn_lvt'
+VOFF       = '-0.099451744+dvoffn_lvt'
+LVOFF      = '-4.436179e-009+dlvoffn_lvt'
+WVOFF      = '9.4170876e-009+dwvoffn_lvt'
+PVOFF      = '-5.1510487e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.357025*ss_flag_lvt'
+ETA0       = '0.48409488+deta0n_lvt-0.00181719*ff_flag_lvt'
+LETA0      = '4.8504901e-010+dleta0n_lvt+1.7405e-10*ff_flag_lvt'
+WETA0      = '-8.1020112e-007+dweta0n_lvt+1.82083e-08*ff_flag_lvt'
+PETA0      = '4.6454117e-014+dpeta0n_lvt-1.74398e-15*ff_flag_lvt'
+ETAB       = -0.018461361
+Petab    = 8.719881e-16
+Letab    = 1.4487063e-09
+WETAB      = -3.1068909e-08
+UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010669839+du0n_lvt'
+LU0        = '4.0423259e-010+dlu0n_lvt'
+WU0        = '-1.5698813e-009+dwu0n_lvt'
+PU0        = '-8.0224433e-017+dpu0n_lvt'
+UA         = '-2.4269058e-009+duan_lvt'
+LUA        = '5.5590629e-017+dluan_lvt'
+WUA        = '-2.9161008e-016+dwuan_lvt'
+PUA        = '2.5537523e-023+dpuan_lvt'
+UB         = '2.2307279e-018+dubn_lvt'
+LUB        = '-1.1591957e-026+dlubn_lvt'
+WUB        = '4.6418333e-025+dwubn_lvt'
+PUB        = '-6.5968632e-032+dpubn_lvt'
+UC         = 6.6545728e-11
+LUC        = -3.7549892e-18
+WUC        = -1.945144e-18
+PUC        = -1.0144903e-24
+VSAT       = '99160.041+dvsatn_lvt+1071.07*ss_flag_lvt'
+LVSAT      = '-0.00033663866+dlvsatn_lvt-0.000102587*ss_flag_lvt'
+WVSAT      = '0.0061008173+dwvsatn_lvt-0.0010925*ss_flag_lvt'
+PVSAT      = '-6.2784339e-010+dpvsatn_lvt+1.04639e-10*ss_flag_lvt'
+A0         = -2.4893169          LA0        = -9.5800729e-008     WA0        = 7.1278269e-008
+PA0        = 6.2784339e-014      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = 0.0036497472        LKETA      = 2.6749361e-009
+WKETA      = -7.1360839e-008     PKETA      = 5.5895502e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.38255683          LPCLM      = 1.3678505e-009
+WPCLM      = 4.6250034e-008      PPCLM      = -1.3952075e-015     PDIBLC1    = 0
+PDIBLC2    = 0.030053261         LPDIBLC2   = -4.7506186e-010     WPDIBLC2   = 2.3651594e-008
+PPDIBLC2   = -1.3952075e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0016506047
+LTVOFF     = -8.1229742e-011     WTVOFF     = -2.164082e-009      PTVOFF     = 1.9007959e-016
+KT1        = '-0.19451937+dkt1n_lvt'
+LKT1       = '-6.2653157e-09+dlkt1n_lvt'
+WKT1       = '-1.1213008e-07+dwkt1n_lvt'
+PKT1       = '1.0822839e-14+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.044506216        LKT2       = -3.0061996e-010
+WKT2       = -7.0281664e-009     PKT2       = 1.4998481e-016      UTE        = 0.66554152
+LUTE       = -1.5952557e-007     WUTE       = -1.6988524e-006     PUTE       = 1.6271608e-013
+UA1        = '3.4887539e-009+dua1n_lvt'
+LUA1       = '-2.436281e-016+dlua1n_lvt'
+WUA1       = '-1.7757392e-015+dwua1n_lvt'
+PUA1       = '1.7014556e-022+dpua1n_lvt'
+UB1        = '-9.5527444e-019+dub1n_lvt'
+LUB1       = '3.5699574e-026+dlub1n_lvt'
+WUB1       = '-1.5640491e-024+dwub1n_lvt'
+PUB1       = '9.6711924e-032+dpub1n_lvt'
+UC1        = -4.3940601e-11
+LUC1       = 8.5681829e-18
+WUC1       = 9.6239901e-17
+PUC1       = -6.144046e-24
+PRT        = 0                   AT         = -40423.746
+LAT        = 0.0046380392        WAT        = 0.072036221         PAT        = -4.7307999e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt+3.41956e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+3.64165e-07*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt-3.48795e-14*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_lvt+dlmisn_lvt)'
+LMAX       = 2.001e-05           WMIN       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-006-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25979956+(dvthn_lvt+vthmisn_lvt)'
+WVTH0      = '-1.316648e-008+dwvthn_lvt'
+K1         = 0.217               K2         = '0.04162729+dk2n_lvt'
+WK2        = '1.7718485e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.10252774+dvoffn_lvt'
+WVOFF      = '6.417995e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0217105+du0n_lvt'
+WU0        = '-2.70351e-009+dwu0n_lvt'
+UA         = '-1.6005e-009+duan_lvt'
+WUA        = '-1.4229e-016+dwuan_lvt'
+UB         = '2.5142567e-018+dubn_lvt'
+WUB        = '6.3197756e-026+dwubn_lvt'
+UC         = 1.1622e-010         WUC        = -3.57306e-017       VSAT       = '100000+dvsatn_lvt'
+A0         = 3.2105              WA0        = 5.5335e-007         AGS        = 0.91545379
+WAGS       = -2.495734e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.067014
+WKETA      = 1.119348e-008       DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0034353969
+WPDIBLC2   = -1.8910482e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 6.032e-005
+LTVOFF     = 0                   WTVOFF     = 2.460036e-010       PTVOFF     = 0
+KT1        = '-0.28309631+dkt1n_lvt'
+WKT1       = '1.6316236e-008+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.048441           WKT2       = -1.324878e-008
+UTE        = -1.38465            WUTE       = 1.31223e-007        UA1        = '1.7934e-009+dua1n_lvt'
+WUA1       = '-7.5888e-017+dwua1n_lvt'
+UB1        = '-1.44703e-018+dub1n_lvt'
+WUB1       = '1.432386e-025+dwub1n_lvt'
+UC1        = -4.444973e-011      WUC1       = 4.5160633e-017      PRT        = 0
+AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1e-005-(dxln_lvt+dlmisn_lvt)'   WMIN       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-006-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25761053+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.181388e-008+dlvthn_lvt'
+WVTH0      = '-1.3350475e-008+dwvthn_lvt'
+PVTH0      = '1.8335387e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.04315219+dk2n_lvt'
+LK2        = '-1.5195793e-008+dlk2n_lvt'
+WK2        = '1.9351152e-009+dwk2n_lvt'
+PK2        = '-1.6269704e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00011662134+dcitn_lvt'
+LCIT       = '-1.6563347e-010+dlcitn_lvt'
+WCIT       = '-1.6953766e-011+dwcitn_lvt'
+PCIT       = '1.6894614e-016+dpcitn_lvt'
+VOFF       = '-0.10160741+dvoffn_lvt'
+LVOFF      = '-9.1712041e-009+dlvoffn_lvt'
+WVOFF      = '6.8579819e-009+dwvoffn_lvt'
+PVOFF      = '-4.3845171e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022015743+du0n_lvt'
+LU0        = '-3.0417785e-009+dlu0n_lvt'
+WU0        = '-2.7425037e-009+dwu0n_lvt'
+PU0        = '3.8857612e-016+dpu0n_lvt'
+UA         = '-1.5913207e-009+duan_lvt'
+LUA        = '-9.147242e-017+dluan_lvt'
+WUA        = '-1.409337e-016+dwuan_lvt'
+PUA        = '-1.3515691e-023+dpuan_lvt'
+UB         = '2.5309015e-018+dubn_lvt'
+LUB        = '-1.658671e-025+dlubn_lvt'
+WUB        = '6.1059469e-026+dwubn_lvt'
+PUB        = '2.1308264e-032+dpubn_lvt'
+UC         = 1.2039877e-010      LUC        = -4.1641857e-017     WUC        = -3.7234399e-017
+PUC        = 1.4985523e-023      VSAT       = '100000+dvsatn_lvt' A0         = 3.3002552
+LA0        = -8.9442074e-007     WA0        = 5.3978699e-007      PA0        = 1.3515691e-013
+AGS        = 0.88315909          LAGS       = 3.2182028e-007      WAGS       = -2.7964215e-008
+PAGS       = 2.9963838e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.066991213
+LKETA      = -2.2707815e-010     WKETA      = 1.1880108e-008      PKETA      = -6.8423187e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0026000831        LPDIBLC2   = 8.3239935e-009
+WPDIBLC2   = -2.941522e-010      PPDIBLC2   = 1.0468087e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = -1.2650895e-005     LTVOFF     = 7.2716299e-010      WTVOFF     = 2.7814794e-010
+PTVOFF     = -3.2032188e-016     KT1        = '-0.28601635+dkt1n_lvt'
+LKT1       = '2.9098542e-008+dlkt1n_lvt'
+WKT1       = '1.7951766e-008+dwkt1n_lvt'
+PKT1       = '-1.6298234e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.046679942        LKT2       = -1.7549133e-008
+WKT2       = -1.4223622e-008     PKT2       = 9.714403e-015       UTE        = -1.4007513
+LUTE       = 1.6045075e-007      WUTE       = 1.3342699e-007      PUTE       = -2.1962998e-014
+UA1        = '1.8176779e-009+dua1n_lvt'
+LUA1       = '-2.4193173e-016+dlua1n_lvt'
+WUA1       = '-8.0635054e-017+dwua1n_lvt'
+PUA1       = '4.7304919e-023+dpua1n_lvt'
+UB1        = '-1.416954e-018+dub1n_lvt'
+LUB1       = '-2.9971109e-025+dlub1n_lvt'
+WUB1       = '1.5012183e-025+dwub1n_lvt'
+PUB1       = '-6.8592133e-032+dpub1n_lvt'
+UC1        = -5.0274623e-011     LUC1       = 5.8045694e-017      WUC1       = 4.7611232e-017
+PUC1       = -2.4420489e-023     PRT        = 0                   AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.2817733+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-1.5058442e-009+dlvthn_lvt'
+WVTH0      = '-1.415744e-008+dwvthn_lvt'
+PVTH0      = '2.6123487e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.03325103+dk2n_lvt'
+LK2        = '-5.640085e-009+dlk2n_lvt'
+WK2        = '-6.2831239e-011+dwk2n_lvt'
+PK2        = '3.0126767e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-7.0615088e-006+dcitn_lvt'
+LCIT       = '-4.6265917e-011+dlcitn_lvt'
+WCIT       = '1.0920274e-010+dwcitn_lvt'
+PCIT       = '4.7191236e-017+dpcitn_lvt'
+VOFF       = '-0.10079487+dvoffn_lvt'
+LVOFF      = '-9.9553928e-009+dlvoffn_lvt'
+WVOFF      = '7.3979162e-010+dwvoffn_lvt'
+PVOFF      = '1.5202095e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019623129+du0n_lvt'
+LU0        = '-7.3264319e-010+dlu0n_lvt'
+WU0        = '-2.4327848e-009+dwu0n_lvt'
+PU0        = '8.9663348e-017+dpu0n_lvt'
+UA         = '-1.6380378e-009+duan_lvt'
+LUA        = '-4.6385313e-017+dluan_lvt'
+WUA        = '-1.8818814e-016+dwuan_lvt'
+PUA        = '3.209004e-023+dpuan_lvt'
+UB         = '2.3981278e-018+dubn_lvt'
+LUB        = '-3.7725886e-026+dlubn_lvt'
+WUB        = '1.3044909e-025+dwubn_lvt'
+PUB        = '-4.5660352e-032+dpubn_lvt'
+UC         = 9.5009464e-011      LUC        = -1.7138388e-017     WUC        = -3.028371e-017
+PUC        = 8.2773427e-024      VSAT       = '100000+dvsatn_lvt' A0         = 2.6745847
+LA0        = -2.9057981e-007     WA0        = 8.9008822e-007      PA0        = -2.0292231e-013
+AGS        = 1.1289677           LAGS       = 8.4587949e-008      WAGS       = 4.0363224e-009
+PAGS       = -9.2020078e-016     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.085198331
+LKETA      = 1.7344794e-008      WKETA      = 1.0105562e-008      PKETA      = -5.1296873e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.79200975
+LPCLM      = 5.684738e-009       WPCLM      = 9.7305549e-009      PPCLM      = -9.3910559e-015
+PDIBLC1    = 0                   PDIBLC2    = 0.013691513         LPDIBLC2   = -2.3804561e-009
+WPDIBLC2   = -1.4098767e-009     PPDIBLC2   = 2.1236056e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00077131362       LTVOFF     = -2.9449003e-011     WTVOFF     = -2.2068575e-011
+PTVOFF     = -3.0579921e-017     KT1        = '-0.26171967+dkt1n_lvt'
+LKT1       = '5.6495669e-009+dlkt1n_lvt'
+WKT1       = '5.6595266e-009+dwkt1n_lvt'
+PKT1       = '-4.4348709e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.059868619        LKT2       = -4.8206101e-009
+WKT2       = -9.3411397e-009     PKT2       = 5.002271e-015       UTE        = -1.3070263
+LUTE       = 6.9995855e-008      WUTE       = 1.4489808e-007      PUTE       = -3.3033865e-014
+UA1        = '1.6318871e-009+dua1n_lvt'
+LUA1       = '-6.2623158e-017+dlua1n_lvt'
+WUA1       = '-3.2575296e-019+dwua1n_lvt'
+PUA1       = '-3.0202391e-023+dpua1n_lvt'
+UB1        = '-1.8757435e-018+dub1n_lvt'
+LUB1       = '1.4307126e-025+dlub1n_lvt'
+WUB1       = '5.4543671e-026+dwub1n_lvt'
+PUB1       = '2.3651303e-032+dpub1n_lvt'
+UC1        = -1.2800613e-011     LUC1       = 2.1879152e-017      WUC1       = 3.6434329e-017
+PUC1       = -1.3633548e-023     PRT        = 0                   AT         = 221958.24
+LAT        = -0.040494319        WAT        = 0.0044594302        PAT        = -4.3038407e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30139764+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-5.9798022e-009+dlvthn_lvt'
+WVTH0      = '-7.126262e-009+dwvthn_lvt'
+PVTH0      = '1.0093807e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.022481655+dk2n_lvt'
+LK2        = '-3.1848829e-009+dlk2n_lvt'
+WK2        = '-1.2180193e-009+dwk2n_lvt'
+PK2        = '5.6462745e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0012641596+dcitn_lvt'
+LCIT       = '2.4032731e-010+dlcitn_lvt'
+WCIT       = '4.3074477e-010+dwcitn_lvt'
+PCIT       = '-2.6113916e-017+dpcitn_lvt'
+VOFF       = '-0.1452694+dvoffn_lvt'
+LVOFF      = '1.8390894e-010+dlvoffn_lvt'
+WVOFF      = '1.1636233e-008+dwvoffn_lvt'
+PVOFF      = '-9.6396125e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.1243618+deta0n_lvt'
+LETA0      = '1.1852348e-012+dleta0n_lvt'
+WETA0      = '4.6895683e-008+dweta0n_lvt'
+PETA0      = '-7.3484559e-019+dpeta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017962484+du0n_lvt'
+LU0        = '-3.540492e-010+dlu0n_lvt'
+WU0        = '-2.2342161e-009+dwu0n_lvt'
+PU0        = '4.4393657e-017+dpu0n_lvt'
+UA         = '-1.8908752e-009+duan_lvt'
+LUA        = '1.1256568e-017+dluan_lvt'
+WUA        = '-9.6302274e-018+dwuan_lvt'
+PUA        = '-8.6175922e-024+dpuan_lvt'
+UB         = '2.5042067e-018+dubn_lvt'
+LUB        = '-6.1909735e-026+dlubn_lvt'
+WUB        = '-1.4385689e-025+dwubn_lvt'
+PUB        = '1.6875925e-032+dpubn_lvt'
+UC         = 1.7203086e-011      LUC        = 5.9990981e-019      WUC        = 1.6607546e-017
+PUC        = -2.4129258e-024     VSAT       = '98536.493+dvsatn_lvt'
+LVSAT      = '0.00033365028+dlvsatn_lvt'
+WVSAT      = '0.0050399697+dwvsatn_lvt'
+PVSAT      = '-1.1490123e-009+dpvsatn_lvt'
+A0         = 4.7238631           LA0        = -7.577743e-007      WA0        = -3.0354363e-007
+PA0        = 6.9201876e-014      AGS        = -2.4847958          LAGS       = 9.0845374e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.038058485        LKETA      = 6.5978517e-009
+WKETA      = -1.2509585e-008     PKETA      = 2.6113916e-017      DWG        = 0
+DWB        = 0                   PCLM       = 1.2105486           LPCLM      = -8.9733757e-008
+WPCLM      = -1.6822835e-007     PPCLM      = 3.1180015e-014      PDIBLC1    = 0
+PDIBLC2    = -0.0237901          LPDIBLC2   = 6.1646019e-009      WPDIBLC2   = 1.8488936e-008
+PPDIBLC2   = -2.4129258e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00034240366
+LTVOFF     = 6.833389e-011       WTVOFF     = 4.7915972e-011      PTVOFF     = -4.6534998e-017
+KT1        = '-0.26987595+dkt1n_lvt'
+LKT1       = '7.5090358e-009+dlkt1n_lvt'
+WKT1       = '2.6173983e-008+dwkt1n_lvt'
+PKT1       = '-9.1117568e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.10692445         LKT2       = 5.9071791e-009
+WKT2       = 2.7457026e-008      PKT2       = -3.3869749e-015     UTE        = -1
+UA1        = '1.5826054e-009+dua1n_lvt'
+LUA1       = '-5.1387925e-017+dlua1n_lvt'
+WUA1       = '-1.5491114e-016+dwua1n_lvt'
+PUA1       = '5.0399857e-024+dpua1n_lvt'
+UB1        = '-9.7987827e-019+dub1n_lvt'
+LUB1       = '-6.116809e-026+dlub1n_lvt'
+WUB1       = '-9.0997215e-026+dwub1n_lvt'
+PUB1       = '5.6831715e-032+dpub1n_lvt'
+UC1        = 4.047626e-011       LUC1       = 9.7330908e-018      WUC1       = 7.8233597e-018
+PUC1       = -7.1108192e-024     PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '1e-006-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.25840312+(dvthn_lvt+vthmisn_lvt)-0.012266*ff_flag_lvt+0.012266*ss_flag_lvt'
+LVTH0      = '-1.8617867e-009+dlvthn_lvt+1.17483e-09*ff_flag_lvt-1.17483e-09*ss_flag_lvt'
+WVTH0      = '-2.3228341e-008+dwvthn_lvt+7.60495e-09*ff_flag_lvt-7.60495e-09*ss_flag_lvt'
+PVTH0      = '2.5516377e-015+dpvthn_lvt-7.28397e-16*ff_flag_lvt+7.28397e-16*ss_flag_lvt'
+K1         = 0.217               K2         = '-0.025394525+dk2n_lvt'
+LK2        = '1.4006976e-009+dlk2n_lvt'
+WK2        = '1.0210766e-009+dwk2n_lvt'
+PK2        = '3.5016685e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '2.3457461e-006+dcitn_lvt'
+LCIT       = '1.1902142e-010+dlcitn_lvt'
+WCIT       = '1.4256073e-009+dwcitn_lvt'
+PCIT       = '-1.2140185e-016+dpcitn_lvt'
+VOFF       = '-0.1240989+dvoffn_lvt'
+LVOFF      = '-1.8438017e-009+dlvoffn_lvt'
+WVOFF      = '3.4557183e-008+dwvoffn_lvt'
+PVOFF      = '-3.1593298e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.0994111*ss_flag_lvt'
+ETA0       = '-0.5294399+deta0n_lvt+0.0408868*ff_flag_lvt'
+LETA0      = '6.2622312e-008+dleta0n_lvt-3.91611e-09*ff_flag_lvt'
+WETA0      = '2.2360436e-007+dweta0n_lvt-2.53498e-08*ff_flag_lvt'
+PETA0      = '-1.6925892e-014+dpeta0n_lvt+2.42799e-15*ff_flag_lvt'
+ETAB       = 0.039736442
+LETAB      = -2.4572377e-09
+WETAB      = -9.0430667e-08
+PETAB      = 4.856051e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0082323123+du0n_lvt'
+LU0        = '5.7790661e-010+dlu0n_lvt'
+WU0        = '9.1639556e-010+dwu0n_lvt'
+PU0        = '-2.5737193e-016+dpu0n_lvt'
+UA         = '-3.0749301e-009+duan_lvt'
+LUA        = '1.2466534e-016+dluan_lvt'
+WUA        = '3.6937472e-016+dwuan_lvt'
+PUA        = '-4.4918686e-023+dpuan_lvt'
+UB         = '3.1425635e-018+dubn_lvt'
+LUB        = '-1.2305155e-025+dlubn_lvt'
+WUB        = '-4.6588894e-025+dwubn_lvt'
+PUB        = '4.7720155e-032+dpubn_lvt'
+UC         = 8.9822988e-11
+LUC        = -6.3555719e-18
+WUC        = -2.5687948e-17
+PUC        = 1.6381041e-24
+VSAT       = '120396.91+dvsatn_lvt-2485.28*ff_flag_lvt'
+LVSAT      = '-0.0017601405+dlvsatn_lvt+0.000238038*ff_flag_lvt'
+WVSAT      = '-0.01556079+dwvsatn_lvt+0.00253498*ff_flag_lvt'
+PVSAT      = '8.2412849e-010+dpvsatn_lvt-2.42799e-10*ff_flag_lvt'
+A0         = -3.488793           LA0        = 2.88339e-008        WA0        = 1.0907439e-006
+PA0        = -6.4342982e-014     AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0461879          LKETA      = 7.3764872e-009
+WKETA      = -2.0526438e-008     PKETA      = 7.9396812e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.17475972          LPCLM      = 9.4741054e-009
+WPCLM      = 2.5820308e-007      PPCLM      = -9.6635875e-015     PDIBLC1    = 0
+PDIBLC2    = 0.052953647         LPDIBLC2   = -1.1859141e-009     WPDIBLC2   = 2.9320051e-010
+PPDIBLC2   = -6.7013823e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0014296083
+LTVOFF     = -3.5798573e-011     WTVOFF     = -1.9386657e-009     PTVOFF     = 1.4373979e-016
+KT1        = '-0.12546444+dkt1n_lvt'
+LKT1       = '-6.3226983e-009+dlkt1n_lvt'
+WKT1       = '-1.8256611e-007+dwkt1n_lvt'
+PKT1       = '1.088137e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.03619065         LKT2       = -8.6770458e-010
+WKT2       = -1.5510044e-008     PKT2       = 7.2841112e-016      UTE        = -1
+UA1        = '2.032528e-009+dua1n_lvt'
+LUA1       = '-9.448151e-017+dlua1n_lvt'
+WUA1       = '-2.9038879e-016+dwua1n_lvt'
+PUA1       = '1.8016035e-023+dpua1n_lvt'
+UB1        = '-3.5815882e-018+dub1n_lvt'
+LUB1       = '1.8802369e-025+dlub1n_lvt'
+WUB1       = '1.1147909e-024+dwub1n_lvt'
+PUB1       = '-5.8658669e-032+dpub1n_lvt'
+UC1        = 1.6779532e-10
+LUC1       = -2.461659e-18
+WUC1       = -1.1973073e-16
+PUC1       = 5.106393e-24
+PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt+9.52153e-09*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+1.01399e-07*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt-9.71196e-15*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_lvt+dlmisn_lvt)'
+LMAX       = 2.001e-05           WMIN       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '6e-007-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24595584+(dvthn_lvt+vthmisn_lvt)'
+WVTH0      = '-4.583372e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.040769245+dk2n_lvt'
+WK2        = '2.3038361e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.099522454+dvoffn_lvt'
+WVOFF      = '4.5547152e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017403333+du0n_lvt'
+WU0        = '-3.3066667e-011+dwu0n_lvt'
+UA         = '-1.8950667e-009+duan_lvt'
+WUA        = '4.0341333e-017+dwuan_lvt'
+UB         = '2.6268698e-018+dubn_lvt'
+WUB        = '-6.6223275e-027+dwubn_lvt'
+UC         = 7.4440667e-011      WUC        = -9.8274133e-018     VSAT       = '100000+dvsatn_lvt'
+A0         = 4.6209909           WA0        = -3.2115438e-007     AGS        = 0.92102174
+WAGS       = -2.8409466e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.048789333
+WKETA      = -1.0581333e-010     DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0026028042
+WPDIBLC2   = 3.2710267e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00075843333
+LTVOFF     = 0                   WTVOFF     = -1.8682667e-010     PTVOFF     = 0
+KT1        = '-0.25769564+dkt1n_lvt'
+WKT1       = '5.678208e-010+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.080647333        WKT2       = 6.7191467e-009
+UTE        = -1.2071333          WUTE       = 2.1162667e-008      UA1        = '1.7158e-009+dua1n_lvt'
+WUA1       = '-2.7776e-017+dwua1n_lvt'
+UB1        = '-1.2896e-018+dub1n_lvt'
+WUB1       = '4.5632e-026+dwub1n_lvt'
+UC1        = 3.7414e-011         WUC1       = -5.59488e-018       PRT        = 0
+AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1e-005-(dxln_lvt+dlmisn_lvt)'   WMIN       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '6e-007-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24360281+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.3448206e-008+dlvthn_lvt'
+WVTH0      = '-4.6656848e-009+dwvthn_lvt'
+PVTH0      = '8.2025652e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.042674088+dk2n_lvt'
+LK2        = '-1.8981971e-008+dlk2n_lvt'
+WK2        = '2.2315379e-009+dwk2n_lvt'
+PK2        = '7.2046005e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '7.7838215e-005+dcitn_lvt'
+LCIT       = '2.2084463e-010+dlcitn_lvt'
+WCIT       = '7.0917713e-012+dwcitn_lvt'
+PCIT       = '-7.0670281e-017+dpcitn_lvt'
+VOFF       = '-0.098319641+dvoffn_lvt'
+LVOFF      = '-1.1986162e-008+dlvoffn_lvt'
+WVOFF      = '4.8195635e-009+dwvoffn_lvt'
+PVOFF      = '-2.6392432e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017645683+du0n_lvt'
+LU0        = '-2.4150429e-009+dlu0n_lvt'
+WU0        = '-3.3066667e-011+dwu0n_lvt'
+PU0        = '8.4471169e-030+dpu0n_lvt'
+UA         = '-1.8846149e-009+duan_lvt'
+LUA        = '-1.0415318e-016+dluan_lvt'
+WUA        = '4.0908675e-017+dwuan_lvt'
+PUA        = '-5.6536225e-024+dpuan_lvt'
+UB         = '2.6370304e-018+dubn_lvt'
+LUB        = '-1.0125132e-025+dlubn_lvt'
+WUB        = '-4.7404097e-027+dwubn_lvt'
+PUB        = '-1.8753518e-032+dpubn_lvt'
+UC         = 7.6521086e-011      LUC        = -2.0731611e-017     WUC        = -1.0030238e-017
+PUC        = 2.02117e-024        VSAT       = '100000+dvsatn_lvt' A0         = 4.7592867
+LA0        = -1.378132e-006      WA0        = -3.6481249e-007     PA0        = 4.3505791e-013
+AGS        = 0.89156087          LAGS       = 2.9358074e-007      WAGS       = -3.3173322e-008
+PAGS       = 4.7472353e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.047450905
+LKETA      = -1.3337591e-008     WKETA      = -2.3488357e-010     PKETA      = 1.2861991e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0014842922        LPDIBLC2   = 1.1146095e-008
+WPDIBLC2   = 3.976382e-010       PPDIBLC2   = -7.0289431e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00074609279       LTVOFF     = 1.2297484e-010      WTVOFF     = -1.9227315e-010
+PTVOFF     = 5.4274776e-017      KT1        = '-0.25910969+dkt1n_lvt'
+LKT1       = '1.4091184e-008+dlkt1n_lvt'
+WKT1       = '1.2696367e-009+dwkt1n_lvt'
+PKT1       = '-6.9936723e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.08054782         LKT2       = -9.9166362e-010
+WKT2       = 6.7744625e-009      PKT2       = -5.5122819e-016     UTE        = -1.2236832
+LUTE       = 1.6492107e-007      WUTE       = 2.3644787e-008      PUTE       = -2.4734598e-014
+UA1        = '1.718009e-009+dua1n_lvt'
+LUA1       = '-2.2013223e-017+dlua1n_lvt'
+WUA1       = '-1.8840368e-017+dwua1n_lvt'
+PUA1       = '-8.9044554e-023+dpua1n_lvt'
+UB1        = '-1.2219994e-018+dub1n_lvt'
+LUB1       = '-6.7364735e-025+dlub1n_lvt'
+WUB1       = '2.9250008e-026+dwub1n_lvt'
+PUB1       = '1.6324835e-031+dpub1n_lvt'
+UC1        = 3.5612604e-011      LUC1       = 1.7951106e-017      WUC1       = -5.638849e-018
+PUC1       = 4.3815574e-025      PRT        = 0                   AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.26663383+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '1.2207367e-009+dlvthn_lvt'
+WVTH0      = '-4.7709703e-009+dwvthn_lvt'
+PVTH0      = '9.2186856e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.02840131+dk2n_lvt'
+LK2        = '-5.20717e-009+dlk2n_lvt'
+WK2        = '2.9439952e-009+dwk2n_lvt'
+PK2        = '3.2860339e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00024274868+dcitn_lvt'
+LCIT       = '6.168789e-011+dlcitn_lvt'
+WCIT       = '-4.5679577e-011+dwcitn_lvt'
+PCIT       = '-1.9740125e-017+dpcitn_lvt'
+VOFF       = '-0.10568462+dvoffn_lvt'
+LVOFF      = '-4.8781474e-009+dlvoffn_lvt'
+WVOFF      = '3.7714337e-009+dwvoffn_lvt'
+PVOFF      = '-1.6276826e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015755915+du0n_lvt'
+LU0        = '-5.9120877e-010+dlu0n_lvt'
+WU0        = '-3.5112042e-011+dwu0n_lvt'
+PU0        = '1.9740125e-018+dpu0n_lvt'
+UA         = '-2.0192139e-009+duan_lvt'
+LUA        = '2.5749719e-017+dluan_lvt'
+WUA        = '4.8141071e-017+dwuan_lvt'
+PUA        = '-1.263368e-023+dpuan_lvt'
+UB         = '2.6847752e-018+dubn_lvt'
+LUB        = '-1.4733035e-025+dlubn_lvt'
+WUB        = '-4.7272283e-026+dwubn_lvt'
+PUB        = '2.2294418e-032+dpubn_lvt'
+UC         = 5.8440231e-011      LUC        = -3.2815967e-018     WUC        = -7.6107853e-018
+PUC        = -3.1386798e-025     VSAT       = '100000+dvsatn_lvt' A0         = 3.8626774
+LA0        = -5.1280546e-007     WA0        = 1.5347073e-007      PA0        = -6.5142411e-014
+AGS        = 1.2666075           LAGS       = -6.8380511e-008     WAGS       = -8.1300367e-008
+PAGS       = 9.3920244e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.071378987
+LKETA      = 9.7556413e-009      WKETA      = 1.5375691e-009      PKETA      = -4.2441268e-016
+DWG        = 0                   DWB        = 0                   PCLM       = 0.82739918
+LPCLM      = -2.8469956e-008     WPCLM      = -1.2210893e-008     PPCLM      = 1.1784854e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.010961153         LPDIBLC2   = 1.9998816e-009
+WPDIBLC2   = 2.8294602e-010      PPDIBLC2   = -5.9220374e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00095856343       LTVOFF     = -8.2082702e-011     WTVOFF     = -1.3816346e-010
+PTVOFF     = 2.052973e-018       KT1        = '-0.24294349+dkt1n_lvt'
+LKT1       = '-1.5109831e-009+dlkt1n_lvt'
+WKT1       = '-5.9817051e-009+dwkt1n_lvt'
+PKT1       = '4.6701187e-018+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.087807131        LKT2       = 6.0143703e-009
+WKT2       = 7.9807381e-009      PKT2       = -1.7154168e-015     UTE        = -1.0694599
+LUTE       = 1.607865e-008       WUTE       = -2.3930751e-009     PUTE       = 3.9480249e-016
+UA1        = '1.6411584e-009+dua1n_lvt'
+LUA1       = '5.2156116e-017+dlua1n_lvt'
+WUA1       = '-6.0739617e-018+dwua1n_lvt'
+PUA1       = '-1.0136554e-022+dpua1n_lvt'
+UB1        = '-1.8791885e-018+dub1n_lvt'
+LUB1       = '-3.9387558e-026+dlub1n_lvt'
+WUB1       = '5.6679605e-026+dwub1n_lvt'
+PUB1       = '1.3677577e-031+dpub1n_lvt'
+UC1        = 5.9031464e-011      LUC1       = -4.6506699e-018     WUC1       = -8.101559e-018
+PUC1       = 2.8149418e-024      PRT        = 0                   AT         = 235814.84
+LAT        = -0.053867457        WAT        = -0.0041316588       PAT        = 3.9875052e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.29455797+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-5.1454089e-009+dlvthn_lvt'
+WVTH0      = '-2.8856656e-009+dwvthn_lvt'
+PVTH0      = '4.9205679e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.015783404+dk2n_lvt'
+LK2        = '-2.3305397e-009+dlk2n_lvt'
+WK2        = '2.9348965e-009+dwk2n_lvt'
+PK2        = '3.493466e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.00058791931+dcitn_lvt'
+LCIT       = '2.5106358e-010+dlcitn_lvt'
+WCIT       = '1.1475784e-011+dwcitn_lvt'
+PCIT       = '-3.2770404e-017+dpcitn_lvt'
+VOFF       = '-0.1214655+dvoffn_lvt'
+LVOFF      = '-1.2804224e-009+dlvoffn_lvt'
+WVOFF      = '-3.1221832e-009+dwvoffn_lvt'
+PVOFF      = '-5.6075841e-017+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712743+deta0n_lvt'
+LETA0      = '-4.7887074e-013+dleta0n_lvt'
+WETA0      = '-4.419009e-009+dweta0n_lvt'
+PETA0      = '2.9689986e-019+dpeta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014401576+du0n_lvt'
+LU0        = '-2.8244653e-010+dlu0n_lvt'
+WU0        = '-2.6453333e-011+dwu0n_lvt'
+UA         = '-1.7663883e-009+duan_lvt'
+LUA        = '-3.1889479e-017+dluan_lvt'
+WUA        = '-8.6812156e-017+dwuan_lvt'
+PUA        = '1.8132957e-023+dpuan_lvt'
+UB         = '2.0198222e-018+dubn_lvt'
+LUB        = '4.2656435e-027+dlubn_lvt'
+WUB        = '1.564615e-025+dwubn_lvt'
+PUB        = '-2.415281e-032+dpubn_lvt'
+UC         = 5.8795347e-011      LUC        = -3.3625562e-018     WUC        = -9.1796557e-018
+PUC        = 4.3803107e-026      VSAT       = '108520.22+dvsatn_lvt'
+LVSAT      = '-0.0019424393+dlvsatn_lvt'
+WVSAT      = '-0.0011499396+dwvsatn_lvt'
+PVSAT      = '2.6216323e-010+dpvsatn_lvt'
+A0         = 3.3973626           LA0        = -4.06723e-007       WA0        = 5.1888664e-007
+PA0        = -1.4844993e-013     AGS        = -3.4045335          LAGS       = 9.9654622e-007
+WAGS       = 5.7023742e-007      PAGS       = -5.461734e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.046815963        LKETA      = 4.1557629e-009      WKETA      = -7.0799485e-009
+PKETA      = 1.540209e-015       DWG        = 0                   DWB        = 0
+PCLM       = 0.90629038          LPCLM      = -4.6455571e-008     WPCLM      = 2.0411768e-008
+PPCLM      = 4.3475403e-015      PDIBLC1    = 0                   PDIBLC2    = 0.010722382
+LPDIBLC2   = 2.0543167e-009      WPDIBLC2   = -2.9088021e-009     PPDIBLC2   = 1.35451e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.00072028087       LTVOFF     = -2.7759043e-011
+WTVOFF     = -1.863679e-010      PTVOFF     = 1.3042621e-017      KT1        = '-0.20011431+dkt1n_lvt'
+LKT1       = '-1.1275179e-008+dlkt1n_lvt'
+WKT1       = '-1.7078234e-008+dwkt1n_lvt'
+PKT1       = '2.5344567e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.071566702        LKT2       = 2.3118771e-009
+WKT2       = 5.5352199e-009      PKT2       = -1.1578876e-015     UTE        = -0.99816052
+LUTE       = -1.7618497e-010     WUTE       = -1.1404748e-009     PUTE       = 1.0923468e-016
+UA1        = '2.5321001e-009+dua1n_lvt'
+LUA1       = '-1.5096079e-016+dlua1n_lvt'
+WUA1       = '-7.4359787e-016+dwua1n_lvt'
+PUA1       = '6.677516e-023+dpua1n_lvt'
+UB1        = '-2.9465928e-018+dub1n_lvt'
+LUB1       = '2.0395926e-025+dlub1n_lvt'
+WUB1       = '1.1283658e-024+dwub1n_lvt'
+PUB1       = '-1.0754724e-031+dpub1n_lvt'
+UC1        = 6.9229918e-011      LUC1       = -6.9757134e-018     WUC1       = -1.0003908e-017
+PUC1       = 3.2486394e-024      PRT        = 0                   AT         = -8480.6947
+LAT        = 0.0018270381        WAT        = 0.018327631         PAT        = -1.1327636e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+PU0        = '0+dpu0n_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+WMIN       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   WMAX       = '6e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.20722595+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '3.2192517e-009+dlvthn_lvt'
+WVTH0      = '8.5015011e-009+dwvthn_lvt'
+PVTH0      = '-5.9860604e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '-0.014596791+dk2n_lvt'
+LK2        = '5.7927533e-010+dlk2n_lvt'
+WK2        = '-5.6735185e-009+dwk2n_lvt'
+PK2        = '8.5944865e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0036902057+dcitn_lvt'
+LCIT       = '-1.5869523e-010+dlcitn_lvt'
+WCIT       = '-8.6086582e-010+dwcitn_lvt'
+PCIT       = '5.0782474e-017+dpcitn_lvt'
+VOFF       = '-0.031594726+dvoffn_lvt'
+LVOFF      = '-9.8882451e-009+dlvoffn_lvt'
+WVOFF      = '-2.2795403e-008+dwvoffn_lvt'
+PVOFF      = '1.8282251e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt+0.132548*ss_flag_lvt'
+ETA0       = '-0.13563792+deta0n_lvt'
+LETA0      = '3.2829586e-008+dleta0n_lvt'
+WETA0      = '-2.0552874e-008+dweta0n_lvt'
+PETA0      = '1.5455985e-015+dpeta0n_lvt'
+ETAB       = -0.027749981
+LETAB      = 1.3813223e-09
+WETAB      = -4.8589085e-08
+PETAB      = 2.4761438e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0066402542+du0n_lvt'
+LU0        = '4.6093286e-010+dlu0n_lvt'
+WU0        = '1.9034716e-009+dwu0n_lvt'
+PU0        = '-1.8484821e-016+dpu0n_lvt'
+UA         = '-2.998534e-009+duan_lvt'
+LUA        = '8.6125439e-017+dluan_lvt'
+WUA        = '3.2200911e-016+dwuan_lvt'
+PUA        = '-2.1023944e-023+dpuan_lvt'
+UB         = '2.7905183e-018+dubn_lvt'
+LUB        = '-6.9551629e-026+dlubn_lvt'
+WUB        = '-2.4762091e-025+dwubn_lvt'
+PUB        = '1.4550203e-032+dpubn_lvt'
+UC         = 1.1740653e-010      LUC        = -8.9763348e-018     WUC        = -4.2789741e-017
+PUC        = 3.2629771e-024
+VSAT       = '92003.053+dvsatn_lvt+1603.4*ff_flag_lvt'
+LVSAT      = '-0.00036042523+dlvsatn_lvt-0.000153573*ff_flag_lvt'
+WVSAT      = '0.0020434015+dwvsatn_lvt-4.8e-09*ff_flag_lvt'
+PVSAT      = '-4.3694978e-011+dpvsatn_lvt-1e-17*ff_flag_lvt'
+A0         = 2.5997933           LA0        = -3.3033181e-007     WA0        = -2.6841796e-006
+PA0        = 1.5833976e-013      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.11385734         LKETA      = 1.0576986e-008
+WKETA      = 2.1428615e-008      PKETA      = -1.1903412e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.24683542          LPCLM      = 1.6707025e-008
+WPCLM      = 2.1351615e-007      PPCLM      = -1.4147997e-014     PDIBLC1    = 0
+PDIBLC2    = 0.05799222          LPDIBLC2   = -2.4731884e-009     WPDIBLC2   = -2.8307152e-009
+PPDIBLC2   = 1.2797184e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = -0.0023296862
+LTVOFF     = 2.6436681e-010      WTVOFF     = 3.9209693e-010      PTVOFF     = -4.236274e-017
+KT1        = '-0.48975663+dkt1n_lvt'
+LKT1       = '1.6466763e-008+dlkt1n_lvt'
+WKT1       = '4.3295048e-008+dwkt1n_lvt'
+PKT1       = '-3.2480962e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.045077644        LKT2       = -2.2524485e-010
+WKT2       = -1.0000108e-008     PKT2       = 3.3008608e-016      UTE        = -1
+UA1        = '1.622791e-009+dua1n_lvt'
+LUA1       = '-6.3867152e-017+dlua1n_lvt'
+WUA1       = '-3.6351816e-017+dwua1n_lvt'
+PUA1       = '-9.6486701e-025+dpua1n_lvt'
+UB1        = '-2.0632181e-018+dub1n_lvt'
+LUB1       = '1.1934964e-025+dlub1n_lvt'
+WUB1       = '1.7340143e-025+dwub1n_lvt'
+PUB1       = '-1.6080758e-032+dpub1n_lvt'
+UC1        = -1.5321945e-010     LUC1       = 1.4330487e-017      WUC1       = 7.9298416e-017
+PUC1       = -5.3047373e-024     PRT        = 0                   AT         = 10594.667
+WAT        = 0.0065009067
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt-1.26954e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt-4.24154e-08*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt+4.06252e-15*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_lvt+dlmisn_lvt)'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.2394201+(dvthn_lvt+vthmisn_lvt)'
+WVTH0      = '-2.4919353e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.03608656+dk2n_lvt'
+WK2        = '3.8022953e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.095458708+dvoffn_lvt'
+WVOFF      = '3.2543167e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.01751+du0n_lvt'  WU0        = '-6.72e-011+dwu0n_lvt'
+UA         = '-1.7238889e-009+duan_lvt'
+WUA        = '-1.4435556e-017+dwuan_lvt'
+UB         = '2.5175667e-018+dubn_lvt'
+WUB        = '2.8354667e-026+dwubn_lvt'
+UC         = 5.2511111e-011      WUC        = -2.8099556e-018     VSAT       = '100000+dvsatn_lvt'
+A0         = 2.8072373           WA0        = 2.5924677e-007      AGS        = 0.80255092
+WAGS       = 9.5011955e-009      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.049983333
+WKETA      = 2.7626667e-010      DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0022930556
+WPDIBLC2   = 4.2622222e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0003104
+LTVOFF     = 0                   WTVOFF     = -4.3456e-011        PTVOFF     = 0
+KT1        = '-0.25072969+dkt1n_lvt'
+WKT1       = '-1.6612836e-009+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.061485556        WKT2       = 5.8737778e-010
+UTE        = -1.1456667          WUTE       = 1.4933333e-009      UA1        = '1.6608889e-009+dua1n_lvt'
+WUA1       = '-1.0204444e-017+dwua1n_lvt'
+UB1        = '-1.2131111e-018+dub1n_lvt'
+WUB1       = '2.1155556e-026+dwub1n_lvt'
+UC1        = 1.4563333e-011      WUC1       = 1.7173333e-018      PRT        = 0
+AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1e-005-(dxln_lvt+dlmisn_lvt)'   WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_lvt+dwmisn_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'
+XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.23550929+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '3.8971661e-008+dlvthn_lvt'
+WVTH0      = '-2.0757584e-009+dwvthn_lvt'
+PVTH0      = '-4.147249e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.037766478+dk2n_lvt'
+LK2        = '-1.6740567e-008+dlk2n_lvt'
+WK2        = '3.8019731e-009+dwk2n_lvt'
+PK2        = '3.2107104e-018+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.092405221+dvoffn_lvt'
+LVOFF      = '-3.0428341e-008+dlvoffn_lvt'
+WVOFF      = '2.9269491e-009+dwvoffn_lvt'
+PVOFF      = '3.262254e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017755686+du0n_lvt'
+LU0        = '-2.4482883e-009+dlu0n_lvt'
+WU0        = '-6.8267579e-011+dwu0n_lvt'
+PU0        = '1.0638537e-017+dpu0n_lvt'
+UA         = '-1.7185033e-009+duan_lvt'
+LUA        = '-5.3667619e-017+dluan_lvt'
+WUA        = '-1.224702e-017+dwuan_lvt'
+PUA        = '-2.1809001e-023+dpuan_lvt'
+UB         = '2.5474812e-018+dubn_lvt'
+LUB        = '-2.9810178e-025+dlubn_lvt'
+WUB        = '2.3915315e-026+dwubn_lvt'
+PUB        = '4.4238627e-032+dpubn_lvt'
+UC         = 5.2058665e-011      LUC        = 4.5086737e-018      WUC        = -2.2022632e-018
+PUC        = -6.0557212e-024     VSAT       = '100000+dvsatn_lvt'
+A0         = '2.7222259+0.0667237*ff_flag_lvt-0.0250214*ss_flag_lvt'
+LA0        = '8.4714859e-007-6.64909e-07*ff_flag_lvt+2.49341e-07*ss_flag_lvt'
+WA0        = '2.8704696e-007-2.13516e-08*ff_flag_lvt+8.00684e-09*ss_flag_lvt'
+PA0        = '-2.7703189e-013+2.12771e-13*ff_flag_lvt-7.97891e-14*ss_flag_lvt'
+AGS        = 0.75433639          LAGS       = 4.8046309e-007      WAGS       = 1.0738512e-008
+PAGS       = -1.2329999e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.047646218
+LKETA      = -2.328961e-008      WKETA      = -1.7238319e-010     PKETA      = 4.4708451e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0011687322        LPDIBLC2   = 1.1204006e-008
+WPDIBLC2   = 4.9861739e-010      PPDIBLC2   = -7.2142578e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00025820304       LTVOFF     = 5.2014846e-010      WTVOFF     = -3.6148425e-011
+PTVOFF     = -7.2820785e-017     KT1        = '-0.25257404+dkt1n_lvt'
+LKT1       = '1.8379165e-008+dlkt1n_lvt'
+WKT1       = '-8.2177188e-010+dwkt1n_lvt'
+PKT1       = '-8.3658263e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.062433389        LKT2       = 9.4452635e-009
+WKT2       = 9.778446e-010       PKT2       = -3.8910449e-015     UTE        = -1.1560446
+LUTE       = 1.0341703e-007      WUTE       = 2.0004331e-009      PUTE       = -5.053305e-015
+UA1        = '1.7057844e-009+dua1n_lvt'
+LUA1       = '-4.4738847e-016+dlua1n_lvt'
+WUA1       = '-1.4928479e-017+dwua1n_lvt'
+PUA1       = '4.7075526e-023+dpua1n_lvt'
+UB1        = '-1.2163043e-018+dub1n_lvt'
+LUB1       = '3.1820624e-026+dlub1n_lvt'
+WUB1       = '2.7427579e-026+dwub1n_lvt'
+PUB1       = '-6.2501404e-032+dpub1n_lvt'
+UC1        = 1.4644593e-011      LUC1       = -8.0976363e-019     WUC1       = 1.0709146e-018
+PUC1       = 6.4416341e-024      PRT        = 0                   AT         = 180000
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '1.000002e-006-(dxln_lvt+dlmisn_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27355976+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.2487734e-009+dlvthn_lvt'
+WVTH0      = '-6.9872667e-009+dwvthn_lvt'
+PVTH0      = '5.9289683e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.027085174+dk2n_lvt'
+LK2        = '-6.4319331e-009+dlk2n_lvt'
+WK2        = '3.3651588e-009+dwk2n_lvt'
+PK2        = '4.2478454e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.11498798+dvoffn_lvt'
+LVOFF      = '-8.633498e-009+dlvoffn_lvt'
+WVOFF      = '6.7485077e-009+dwvoffn_lvt'
+PVOFF      = '-4.2597046e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015832295+du0n_lvt'
+LU0        = '-5.9200475e-010+dlu0n_lvt'
+WU0        = '-5.955374e-011+dwu0n_lvt'
+PU0        = '2.2287238e-018+dpu0n_lvt'
+UA         = '-1.7646952e-009+duan_lvt'
+LUA        = '-9.0873558e-018+dluan_lvt'
+WUA        = '-3.3304914e-017+dwuan_lvt'
+PUA        = '-1.4858158e-024+dpuan_lvt'
+UB         = '2.3113844e-018+dubn_lvt'
+LUB        = '-7.0242343e-026+dlubn_lvt'
+WUB        = '7.2212786e-026+dwubn_lvt'
+PUB        = '-2.3737453e-033+dpubn_lvt'
+UC         = 6.5906414e-011      LUC        = -8.8559267e-018     WUC        = -9.9999637e-018
+PUC        = 1.4699176e-024      VSAT       = '100000+dvsatn_lvt'
+A0         = '4.2941631-0.814663*ff_flag_lvt+0.305499*ss_flag_lvt'
+LA0        = '-6.6994375e-007+1.85727e-07*ff_flag_lvt-6.96476e-08*ss_flag_lvt'
+WA0        = '1.53953e-008+2.60692e-07*ff_flag_lvt-9.77596e-08*ss_flag_lvt'
+PA0        = '-1.4858158e-014-5.94326e-14*ff_flag_lvt+2.22872e-14*ss_flag_lvt'
+AGS        = 1.0810171           LAGS       = 1.6518028e-007      WAGS       = -2.1911435e-008
+PAGS       = 1.9180791e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.085652449
+LKETA      = 1.3390584e-008      WKETA      = 6.1050767e-009      PKETA      = -1.5875942e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.83112017
+LPCLM      = -3.206112e-008      WPCLM      = -1.3401609e-008     PPCLM      = 1.2934027e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.014427274         LPDIBLC2   = -1.5919455e-009
+WPDIBLC2   = -8.2621265e-010     PPDIBLC2   = 5.5718094e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00098342151       LTVOFF     = -1.7976713e-010     WTVOFF     = -1.4611804e-010
+PTVOFF     = 3.3311991e-017      KT1        = '-0.22997626+dkt1n_lvt'
+LKT1       = '-3.4301783e-009+dlkt1n_lvt'
+WKT1       = '-1.0131217e-008+dwkt1n_lvt'
+PKT1       = '6.1881258e-016+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.050372423        LKT2       = -2.1948949e-009
+WKT2       = -3.9983684e-009     PKT2       = 9.1154802e-016      UTE        = -1.0637
+LUTE       = 1.4294344e-008      WUTE       = -4.2362501e-009     PUTE       = 9.6578029e-016
+UA1        = '1.4836845e-009+dua1n_lvt'
+LUA1       = '-2.3303761e-016+dlua1n_lvt'
+WUA1       = '4.4317693e-017+dwua1n_lvt'
+PUA1       = '-1.0103548e-023+dpua1n_lvt'
+UB1        = '-1.5493154e-018+dub1n_lvt'
+LUB1       = '3.5321292e-025+dlub1n_lvt'
+WUB1       = '-4.8879809e-026+dwub1n_lvt'
+PUB1       = '1.1143619e-032+dpub1n_lvt'
+UC1        = 2.0236834e-012      LUC1       = 1.1370803e-017      WUC1       = 1.0140931e-017
+PUC1       = -2.3119294e-024     PRT        = 0                   AT         = 230119.95
+LAT        = -0.048371265        WAT        = -0.0023092951       PAT        = 2.2287238e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+LMAX       = '2.399959e-007-(dxln_lvt+dlmisn_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30108161+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '-4.0256597e-009+dlvthn_lvt'
+WVTH0      = '-4.9732314e-009+dwvthn_lvt'
+PVTH0      = '1.3373705e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.01076282+dk2n_lvt'
+LK2        = '-2.7107629e-009+dlk2n_lvt'
+WK2        = '4.5414834e-009+dwk2n_lvt'
+PK2        = '1.5660607e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.00055205749+dcitn_lvt'
+LCIT       = '1.4865607e-010+dlcitn_lvt'
+VOFF       = '-0.14844234+dvoffn_lvt'
+LVOFF      = '-1.0065716e-009+dlvoffn_lvt'
+WVOFF      = '5.5104062e-009+dwvoffn_lvt'
+PVOFF      = '-1.4370807e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812094+deta0n_lvt'
+LETA0      = '7.981179e-013+dleta0n_lvt'
+WETA0      = '1.6630679e-009+dweta0n_lvt'
+PETA0      = '-1.1173651e-019+dpeta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.01477312+du0n_lvt'
+LU0        = '-3.5053396e-10+dlu0n_lvt'
+WU0        = '-1.4534752e-10+dwu0n_lvt'
+PU0        = '2.1787978e-17+dpu0n_lvt'
+UA         = '-1.8935091e-009+duan_lvt'
+LUA        = '2.0279624e-017+dluan_lvt'
+WUA        = '-4.6133495e-017+dwuan_lvt'
+PUA        = '1.4388439e-024+dpuan_lvt'
+UB         = '2.317566e-18+dubn_lvt'
+LUB        = '-7.1651638e-26+dlubn_lvt'
+WUB        = '6.1183458e-26+dwubn_lvt'
+PUB        = '1.407198e-34+dpubn_lvt'
+UC         = 4.0332202e-011      LUC        = -3.025518e-018      WUC        = -3.2714493e-018
+PUC        = -6.4049109e-026     VSAT       = '104306.8+dvsatn_lvt'
+LVSAT      = '-0.00098186414+dlvsatn_lvt'
+WVSAT      = '0.00019835428+dwvsatn_lvt'
+PVSAT      = '-4.5220808e-011+dpvsatn_lvt'
+A0         = 5.3012189
+LA0        = -8.9953223e-07
+WA0        = -9.034737e-08
+PA0        = 9.249022e-15
+AGS        = -1.9578627          LAGS       = 8.5798409e-007
+WAGS       = 1.0730274e-007      PAGS       = -1.0277456e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.041609695        LKETA      = 3.3497167e-009      WKETA      = -8.7459541e-009
+PKETA      = 1.7981438e-015      DWG        = 0                   DWB        = 0
+PCLM       = 0.85991114          LPCLM      = -3.8624884e-008     WPCLM      = 3.5253127e-008
+PPCLM      = 1.8417202e-015      PDIBLC1    = 0
+PDIBLC2    = -0.011808163
+LPDIBLC2   = 4.3892094e-09
+WPDIBLC2   = 4.3009722e-09
+PPDIBLC2   = -6.1171466e-16
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.00016194292       LTVOFF     = 7.5135548e-012
+WTVOFF     = -7.6997524e-012     PTVOFF     = 1.7553896e-018      KT1        = '-0.20845774+dkt1n_lvt'
+LKT1       = '-8.3359715e-009+dlkt1n_lvt'
+WKT1       = '-1.4408336e-008+dwkt1n_lvt'
+PKT1       = '1.5939102e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.04821708         LKT2       = -2.6862702e-009
+WKT2       = -1.936659e-009      PKT2       = 4.4151953e-016      UTE        = -1.0017245
+LUTE       = 1.6517341e-010      UA1        = '1.826609e-010+dua1n_lvt'
+LUA1       = '6.3569739e-017+dlua1n_lvt'
+WUA1       = '8.2226864e-018+dwua1n_lvt'
+PUA1       = '-1.8746081e-024+dpua1n_lvt'
+UB1        = '5.9907951e-019+dub1n_lvt'
+LUB1       = '-1.3657815e-025+dlub1n_lvt'
+WUB1       = '-6.2493499e-027+dwub1n_lvt'
+PUB1       = '1.4247268e-033+dpub1n_lvt'
+UC1        = 3.1233803e-011      LUC1       = 4.7114797e-018      WUC1       = 2.1548488e-018
+PUC1       = -4.9126242e-025     PRT        = 0                   AT         = 5787.807
+LAT        = 0.0027719768        WAT        = 0.01376171          PAT        = -1.435144e-009
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_lvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-(dxln_lvt+dlmisn_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwn_lvt+dwmisn_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_lvt+toxmisn_lvt)'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+(dxln_lvt+dlmisn_lvt)'   XW         = '2e-08+(dxwn_lvt+dwmisn_lvt)'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25624615+(dvthn_lvt+vthmisn_lvt)'
+LVTH0      = '2.686806e-010+dlvthn_lvt'
+WVTH0      = '-7.184963e-009+dwvthn_lvt'
+PVTH0      = '3.455767e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '-0.043265034+dk2n_lvt'
+LK2        = '2.4640249e-009+dlk2n_lvt'
+WK2        = '3.5003192e-009+dwk2n_lvt'
+PK2        = '2.5632877e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0015487276+dcitn_lvt'
+LCIT       = '-5.2557131e-011+dlcitn_lvt'
+WCIT       = '-1.7559284e-010+dwcitn_lvt'
+PCIT       = '1.6818282e-017+dpcitn_lvt'
+VOFF       = '-0.094631602+dvoffn_lvt'
+LVOFF      = '-6.1605643e-009+dlvoffn_lvt'
+WVOFF      = '-2.6236025e-009+dwvoffn_lvt'
+PVOFF      = '6.3536728e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '-0.28639279+deta0n_lvt'
+LETA0      = '4.5449723e-008+dleta0n_lvt'
+WETA0      = '2.7688684e-008+dweta0n_lvt'
+PETA0      = '-2.4928453e-015+dpeta0n_lvt'
+ETAB       = -0.11934949
+LETAB      = 5.7950445e-09
+WETAB      = -1.9277245e-08
+PETAB      = 1.0637527e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.012830788+du0n_lvt'
+LU0        = '-1.6449814e-10+dlu0n_lvt'
+WU0        = '-7.749898e-11+dwu0n_lvt'
+PU0        = '1.5289711e-17+dpu0n_lvt'
+UA         = '-1.8189597e-009+duan_lvt'
+LUA        = '1.3139283e-017+dluan_lvt'
+WUA        = '-5.5454663e-017+dwuan_lvt'
+PUA        = '2.3316254e-024+dpuan_lvt'
+UB         = '1.736574e-18+dubn_lvt'
+LUB        = '-1.6004302e-26+dlubn_lvt'
+WUB        = '8.9641261e-26+dwubn_lvt'
+PUB        = '-2.5849419e-33+dpubn_lvt'
+UC         = 2.1635444e-012      LUC        = 6.3027603e-019      WUC        = -5.9119877e-018
+PUC        = 1.8886166e-025
+VSAT       = '97543.183+dvsatn_lvt+2850.5*ff_flag_lvt'
+LVSAT      = '-0.00033404493+dlvsatn_lvt-0.000273019*ff_flag_lvt'
+WVSAT      = '0.00027056001+dwvsatn_lvt-0.00039907*ff_flag_lvt'
+PVSAT      = '-5.2136674e-011+dpvsatn_lvt+3.82226e-11*ff_flag_lvt'
+A0         = -5.8388671
+LA0        = 1.6746271e-07
+WA0        = 1.61917e-08
+PA0        = -9.54492e-16
+AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12857534         LKETA      = 1.1679287e-008
+WKETA      = 2.6138376e-008      PKETA      = -1.5430774e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.52046075          LPCLM      = -6.1123261e-009
+WPCLM      = 1.2595604e-007      PPCLM      = -6.8458052e-015     PDIBLC1    = 0
+PDIBLC2    = 0.076715215
+LPDIBLC2   = -4.0895614e-09
+WPDIBLC2   = -8.8220735e-09
+PPDIBLC2   = 6.4521118e-16
+PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = -0.0025740261
+LTVOFF     = 2.6956467e-010      WTVOFF     = 4.702857e-010       PTVOFF     = -4.4026057e-017
+KT1        = '-0.4429226+dkt1n_lvt'
+LKT1       = '1.4121057e-08+dlkt1n_lvt'
+WKT1       = '2.8308156e-08+dwkt1n_lvt'
+PKT1       = '-2.4974703e-15+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.10473481         LKT2       = 2.7269984e-009
+WKT2       = 9.0901867e-009      PKT2       = -6.1463176e-016     UTE        = -1.2618927
+LUTE       = 2.5084085e-008      WUTE       = 8.3805672e-008      PUTE       = -8.0269073e-015
+UA1        = '1.5556327e-009+dua1n_lvt'
+LUA1       = '-6.7933504e-017+dlua1n_lvt'
+WUA1       = '-1.486119e-017+dwua1n_lvt'
+PUA1       = '3.3636564e-025+dpua1n_lvt'
+UB1        = '-1.9656468e-018+dub1n_lvt'
+LUB1       = '1.0907134e-025+dlub1n_lvt'
+WUB1       = '1.421786e-025+dwub1n_lvt'
+PUB1       = '-1.2791702e-032+dpub1n_lvt'
+UC1        = 1.1243771e-010      LUC1       = -3.0662308e-018     WUC1       = -5.7118742e-018
+PUC1       = 2.622123e-025       PRT        = 0                   AT         = 44705.755
+LAT        = -0.0009555842       WAT        = -0.0044146415       PAT        = 3.0578694e-010
+NOIA       = 'noianmac_lvt'
+NOIB       = 'noibnmac_lvt'
+NOIC       = 'noicnmac_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )

**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************



.ends nch_lvt_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_lvt_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.1e-008' xw='+2e-08+dxwp_lvt'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_lvt w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_lvt  temp2=parp2_lvt
+fac1='0.870389*temp1*sigma+0.492365*temp2*sigma'
+fac2='0.870389*temp1*sigma-0.492365*temp2*sigma'
.param  lef='l*scale+2e-09'
+       wef='w/nf*scale+2e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_lvt='(0.004252047-0.00028546287615/(lef*1e6)+0.0000152025807/(lef*lef*1e12)-0.00003287615/(wef*wef*1e12)+0.000032802452198*(wef*lef*1e12))*geo_fac*fac1*mismatchflag'
+       dlmisp_lvt = '0.00181396*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_lvt = '-0.00181396*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_lvt='0.00181396*geo_fac*toxp_lvt*fac2*mismatchflag' 
.param tnoiax='1.205e06/(l*scale*1e6)+3.273e07'
.param rnoiax='0.0152/(l*scale*1e6)+0.4814'

.param fn_dice='noiseflagp_lvt_mc*par1fn_mc+noiseflagp_lvt_mc_mis*par2fp_lvt_mc'
.param arearatio='sigma_factor_flicker_lvt*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(2.3E-6*1E-6*1))**0.5)))'
.param noiapmac_lvt='c1fp_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_lvt)*arearatio)'
.param noibpmac_lvt='c2fp_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_lvt)*arearatio)'
.param noicpmac_lvt='c3fp_lvt*2.718**((fn_dice+(1-fn_dice)*noiseflagp_lvt)*arearatio)'

.MODEL pch_lvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_lvt+toxmisp_lvt)'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.245727+(dvthp_lvt+vthmisp_lvt)'
+K1         = 0.1515              K2         = '0.02271+dk2p_lvt'  K3         = -3.625
+K3B        = 2.128               W0         = 0                   DVT0       = 34.51
+DVT1       = 2                   DVT2       = 0.03192             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.6563
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 1.291e-006
+DVTP1      = 2.22e-015           LPE0       = 1.366e-007          LPEB       = 4.44089e-021
+WEB        = -210                WEC        = -3550               SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007
+NGATE      = 1.5987e+020         NDEP       = 6.3687e+017         NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'  VOFF       = '-0.07321+dvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01172+du0p_lvt'  UA         = '2.506e-010+duap_lvt'
+UB         = '1.39584e-018+dubp_lvt'
+UC         = 1.261e-011          VSAT       = '95420+dvsatp_lvt'  A0         = '3.245+da0p_lvt'
+AGS        = '0.9114+dagsp_lvt'  A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.02694
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.004575+dpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001548            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2285
+KT1L       = 0                   KT2        = -0.04746            UTE        = '-1.423+dutep_lvt'
+UA1        = '1.0400723e-009+dua1p_lvt'
+UB1        = '-2.0192616e-018+dub1p_lvt'
+UC1        = 4.302e-011          PRT        = 0                   AT         = '180000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'
+LK2        = '0+dlk2p_lvt'       WK2        = '0+dwk2p_lvt'       PK2        = '0+dpk2p_lvt'
+LU0        = '0+dlu0p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'
+LUB        = '0+dlubp_lvt'       WUB        = '0+dwubp_lvt'       PUB        = '0+dpubp_lvt'
+LUA1       = '0+dlua1p_lvt'      WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'
+LCIT       = '0+dlcitp_lvt'      WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'
+LVOFF      = '0+dlvoffp_lvt'     WVOFF      = '0+dwvoffp_lvt'     PVOFF      = '0+dpvoffp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LA0        = '0+dla0p_lvt'       WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+LPDIBLC2   = '0+dlpdiblc2p_lvt'  WPDIBLC2   = '0+dwpdiblc2p_lvt'  PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24557714+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '-1.4932598e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.023357018+dk2p_lvt'
+LK2        = '-6.4469543e-009+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.7151111e-005+dcitp_lvt'
+LCIT       = '4.2695061e-010+dlcitp_lvt'
+VOFF       = '-0.073267478+dvoffp_lvt'
+LVOFF      = '5.7271155e-010+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011883897+du0p_lvt'
+LU0        = '-1.6330861e-009+dlu0p_lvt'
+UA         = '3.1555892e-010+duap_lvt'
+LUA        = '-6.4725713e-016+dluap_lvt'
+UB         = '1.350014e-018+dubp_lvt'
+LUB        = '4.5661484e-025+dlubp_lvt'
+UC         = 1.2906943e-011      LUC        = -2.9587678e-018     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.3958281+da0p_lvt'
+LA0        = '-1.5028662e-006+dla0p_lvt'
+AGS        = '0.83495758+dagsp_lvt'
+LAGS       = '7.616799e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025262466        LKETA      = -1.6715117e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035233811+dpdiblc2p_lvt'
+LPDIBLC2   = '1.0478435e-008+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015817435        LTVOFF     = -3.3622361e-010
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.22058367
+LKT1       = -7.8879126e-008     KT1L       = 0                   KT2        = -0.046051343
+LKT2       = -1.4036001e-008     UTE        = '-1.4262137+dutep_lvt'
+LUTE       = '3.2021296e-008+dlutep_lvt'
+UA1        = '1.0282469e-009+dua1p_lvt'
+LUA1       = '1.1782963e-016+dlua1p_lvt'
+UB1        = '-2.0087181e-018+dub1p_lvt'
+LUB1       = '-1.0505657e-025+dlub1p_lvt'
+UC1        = 4.0713659e-011      LUC1       = 2.2980617e-017      PRT        = 0
+AT         = '181606.83+datp_lvt'
+LAT        = '-0.016010648+dlatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      WUTE       = '0+dwutep_lvt'
+PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24492653+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '-2.1205141e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.017249919+dk2p_lvt'
+LK2        = '-5.5910011e-010+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0005+dcitp_lvt'
+VOFF       = '-0.063746806+dvoffp_lvt'
+LVOFF      = '-8.6061682e-009+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010606915+du0p_lvt'
+LU0        = '-4.0194765e-010+dlu0p_lvt'
+UA         = '-2.4621094e-010+duap_lvt'
+LUA        = '-1.0565481e-016+dluap_lvt'
+UB         = '1.8280273e-018+dubp_lvt'
+LUB        = '-4.2377854e-027+dlubp_lvt'
+UC         = 4.0005646e-012      LUC        = 5.6278715e-018      VSAT       = '95420+dvsatp_lvt'
+A0         = '2.0210068+da0p_lvt'
+LA0        = '-1.7740095e-007+dla0p_lvt'
+AGS        = '-0.05990041+dagsp_lvt'
+LAGS       = '1.6244125e-006+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024606831        LKETA      = -1.7347214e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '2.1880819+dpclmp_lvt'
+LPCLM      = '-1.8132977e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.012634061+dpdiblc2p_lvt'
+LPDIBLC2   = '1.6948289e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001129555         LTVOFF     = 9.9731371e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.30563125
+LKT1       = 3.1152454e-009      KT1L       = 0                   KT2        = -0.058986226
+LKT2       = -1.5654803e-009     UTE        = '-1.5161937+dutep_lvt'
+LUTE       = '1.18771e-007+dlutep_lvt'
+UA1        = '1.0511404e-009+dua1p_lvt'
+LUA1       = '9.5758046e-017+dlua1p_lvt'
+UB1        = '-2.2556104e-018+dub1p_lvt'
+LUB1       = '1.3297232e-025+dlub1p_lvt'
+UC1        = 5.1337246e-011      LUC1       = 1.2738416e-017      PRT        = 0
+AT         = '201049.03+datp_lvt'
+LAT        = '-0.034754872+dlatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      WUTE       = '0+dwutep_lvt'
+PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25992226+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '1.3298543e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.012592179+dk2p_lvt'
+LK2        = '5.1259931e-010+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00074032601+dcitp_lvt'
+LCIT       = '2.8538661e-010+dlcitp_lvt'
+VOFF       = '-0.079227655+dvoffp_lvt'
+LVOFF      = '-5.0441796e-009+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007075+deta0p_lvt'
+LETA0      = '-1.7223091e-013+dleta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0097253089+du0p_lvt'
+LU0        = '-1.9909893e-010+dlu0p_lvt'
+UA         = '-5.8982587e-010+duap_lvt'
+LUA        = '-2.6592452e-017+dluap_lvt'
+UB         = '1.8974557e-018+dubp_lvt'
+LUB        = '-2.0212565e-026+dlubp_lvt'
+UC         = 1.8758959e-011      LUC        = 2.2321126e-018      VSAT       = '95420+dvsatp_lvt'
+A0         = '5.1798199+da0p_lvt'
+LA0        = '-9.0421226e-007+dla0p_lvt'
+AGS        = '9.3204651+dagsp_lvt'
+LAGS       = '-5.3391581e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10047906         LKETA      = 1.1022778e-010
+DWG        = 0                   DWB        = 0                   PCLM       = '1.5497074+dpclmp_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0072748689+dpdiblc2p_lvt'
+LPDIBLC2   = '2.9279254e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017381577        LTVOFF     = -4.0302032e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.25915816
+LKT1       = -7.5777465e-009     KT1L       = 0                   KT2        = -0.065131287
+LKT2       = -1.515632e-010      UTE        = '-1+dutep_lvt'      UA1        = '1.3871611e-009+dua1p_lvt'
+LUA1       = '1.844303e-017+dlua1p_lvt'
+UB1        = '-1.8107081e-018+dub1p_lvt'
+LUB1       = '3.0604743e-026+dlub1p_lvt'
+UC1        = 5.9991284e-011      LUC1       = 1.0747209e-017      PRT        = 0
+AT         = '93415.153+datp_lvt'
+LAT        = '-0.0099893926+dlatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'
+PAT        = '0+dpatp_lvt'       WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     WCIT       = '0+dwcitp_lvt'
+PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'     PVOFF      = '0+dpvoffp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'       WAGS       = '0+dwagsp_lvt'
+PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'  PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.2308502+(dvthp_lvt+vthmisp_lvt)-0.0135829*ff_flag_lvt+0.0271658*ss_flag_lvt-0.00679147*sf_flag_lvt+0.00679147*fs_flag_lvt'
+LVTH0      = '-1.5337437e-009+dlvthp_lvt+1.33792e-09*ff_flag_lvt-2.67583e-09*ss_flag_lvt+6.68957e-10*sf_flag_lvt-6.68957e-10*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0057584566+dk2p_lvt'
+LK2        = '2.3201369e-009+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023303306+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.4200206e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.080417806+dvoffp_lvt-0.0458424*ff_flag_lvt+0.050936*ss_flag_lvt-0.0339573*sf_flag_lvt+0.0339573*fs_flag_lvt'
+LVOFF      = '-4.9269497e-009+dlvoffp_lvt+4.51546e-09*ff_flag_lvt-5.01718e-09*ss_flag_lvt+3.34479e-09*sf_flag_lvt-3.34479e-09*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.0*ff_flag_lvt-0.679147*ss_flag_lvt'
+ETA0       = '-0.080311783+deta0p_lvt+0.0848933*ff_flag_lvt-0.0848933*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LETA0      = '3.8452507e-008+dleta0p_lvt-8.36197e-09*ff_flag_lvt+8.36197e-09*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0054866509+du0p_lvt+0.000169787*ff_flag_lvt-0.0011885*ss_flag_lvt+6.79147e-05*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '2.1840889e-010+dlu0p_lvt-1.67239e-11*ff_flag_lvt+1.17067e-10*ss_flag_lvt-6.68957e-12*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '-1.3372262e-009+duap_lvt'
+LUA        = '4.7026478e-017+dluap_lvt'
+UB         = '1.7168674e-018+dubp_lvt'
+LUB        = '-2.4246129e-027+dlubp_lvt'
+UC         = 3.8058322e-011      LUC        = 3.3112527e-019
+VSAT       = '90190.723+dvsatp_lvt+0.0*ff_flag_lvt+5093.6*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LVSAT      = '0.00051508375+dlvsatp_lvt+0.0*ff_flag_lvt-0.000501718*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+A0         = '-14.186903+da0p_lvt'
+LA0        = '1.0034099e-006+dla0p_lvt'
+AGS        = '-4.4583536+dagsp_lvt'
+LAGS       = '8.2329783e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26537425         LKETA      = 1.6352404e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '1.794236+dpclmp_lvt'
+LPCLM      = '-5.8532244e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.04888472+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.1706449e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0016023486        LTVOFF     = -2.6924832e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.29154839
+LKT1       = -4.3873095e-009     KT1L       = 0                   KT2        = -0.063427169
+LKT2       = -3.1941882e-010     UTE        = '-1+dutep_lvt'      UA1        = '2.1847177e-009+dua1p_lvt'
+LUA1       = '-6.0116294e-017+dlua1p_lvt'
+UB1        = '-1.2998712e-018+dub1p_lvt'
+LUB1       = '-1.9712687e-026+dlub1p_lvt'
+UC1        = 2.202043e-010       LUC1       = -5.033773e-018      PRT        = 0
+AT         = '-8000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07            JSD        = 1.15e-07            JSWS       = 1.7e-13
+JSWD       = 1.7e-13             JSWGS      = 1.7e-13             JSWGD      = 1.7e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjp_lvt'           CJD        = 'cjp_lvt'           MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.9                 PBSWD      = 0.9
+CJSWS      = 'cjswp_lvt'         CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06
+MJSWD      = 0.06                PBSWGS     = 0.5                 PBSWGD     = 0.5
+CJSWGS     = 'cjswgp_lvt'        CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9
+MJSWGD     = 0.9                 TPB        = 0.0017              TCJ        = 0.00091
+TPBSW      = 0.003               TCJSW      = 0.00022             TPBSWG     = 0.0005
+TCJSWG     = 0.003               XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9
+XTSSWGS    = 0.4055              XTSSWGD    = 0.4055              TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVTH0      = '0+dpvthp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WK2        = '0+dwk2p_lvt'       PK2        = '0+dpk2p_lvt'
+WU0        = '0+dwu0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '0+dpu0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'
+WUB        = '0+dwubp_lvt'       PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'
+PUA1       = '0+dpua1p_lvt'      WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+WETA0      = '0+dweta0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PETA0      = '0+dpeta0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '0+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '0+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WVOFF      = '0+dwvoffp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVOFF      = '0+dpvoffp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+0.0*ff_flag_lvt+6.68957e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt'
+WA0        = '0+dwa0p_lvt'
+PA0        = '0+dpa0p_lvt'       WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'
+WVSAT      = '0+dwvsatp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVSAT      = '0+dpvsatp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = 2.001e-05           WMIN       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-005-(dxwp_lvt+dwmisp_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_lvt+toxmisp_lvt)'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24613661+(dvthp_lvt+vthmisp_lvt)'
+WVTH0      = '4.1042855e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.022589867+dk2p_lvt'
+WK2        = '1.203736e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.073647406+dvoffp_lvt'
+WVOFF      = '4.3828091e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011690533+du0p_lvt'
+WU0        = '2.95256e-010+dwu0p_lvt'
+UA         = '2.7867675e-010+duap_lvt'
+WUA        = '-2.81329e-016+dwuap_lvt'
+UB         = '1.3827405e-018+dubp_lvt'
+WUB        = '1.3125719e-025+dwubp_lvt'
+UC         = 1.4039133e-011      WUC        = -1.4319916e-017     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.1594333+da0p_lvt'
+WA0        = '8.57378e-007+dwa0p_lvt'
+AGS        = '0.913406+dagsp_lvt'
+WAGS       = '-2.010012e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027008           WKETA      = 6.8136e-010
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0047535+dpdiblc2p_lvt'
+WPDIBLC2   = '-1.78857e-009+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015770133        LTVOFF     = 0
+WTVOFF     = -2.907136e-010      PTVOFF     = 0                   KT1        = -0.22664063
+WKT1       = -1.8630881e-008     KT1L       = 0                   KT2        = -0.047979067
+WKT2       = 5.201048e-009       UTE        = '-1.40974+dutep_lvt'
+WUTE       = '-1.328652e-007+dwutep_lvt'
+UA1        = '1.0481258e-009+dua1p_lvt'
+WUA1       = '-8.0696003e-017+dwua1p_lvt'
+UB1        = '-2.0755539e-018+dub1p_lvt'
+WUB1       = '5.6404955e-025+dwub1p_lvt'
+UC1        = 4.4673533e-011      WUC1       = -1.6568404e-017     PRT        = 0
+AT         = '178866.67+datp_lvt'
+WAT        = '0.011356+dwatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.24628366+(dvthp_lvt+vthmisp_lvt)+1.82108e-05*ff_flag_lvt+1.82108e-05*ss_flag_lvt'
+LVTH0      = '1.4651906e-009+dlvthp_lvt-1.81454e-10*ff_flag_lvt-1.81454e-10*ss_flag_lvt'
+WVTH0      = '7.0793332e-009+dwvthp_lvt-1.82472e-10*ff_flag_lvt-1.82472e-10*ss_flag_lvt'
+PVTH0      = '-2.9643673e-014+dpvthp_lvt+1.81817e-15*ff_flag_lvt+1.81817e-15*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.023221102+dk2p_lvt'
+LK2        = '-6.2896941e-009+dlk2p_lvt'
+WK2        = '1.3618784e-009+dwk2p_lvt'
+PK2        = '-1.5757466e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.717782e-005+dcitp_lvt'
+LCIT       = '4.2668448e-010+dlcitp_lvt'
+WCIT       = '-2.6762559e-013+dwcitp_lvt'
+PCIT       = '2.6666481e-018+dpcitp_lvt'
+VOFF       = '-0.074024001+dvoffp_lvt'
+LVOFF      = '3.7524325e-009+dlvoffp_lvt'
+WVOFF      = '7.5803687e-009+dwvoffp_lvt'
+PVOFF      = '-3.1860804e-014+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011873005+du0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '-1.8181692e-009+dlu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WU0        = '1.0913457e-010+dwu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '1.8545326e-015+dpu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '3.4845103e-010+duap_lvt'
+LUA        = '-6.9523793e-016+dluap_lvt'
+WUA        = '-3.2957898e-016+dwuap_lvt'
+PUA        = '4.8076757e-022+dpuap_lvt'
+UB         = '1.3338644e-018+dubp_lvt'
+LUB        = '4.8700614e-025+dlubp_lvt'
+WUB        = '1.6181899e-025+dwubp_lvt'
+PUB        = '-3.0452079e-031+dpubp_lvt'
+UC         = 1.4333952e-011      LUC        = -2.9375981e-018     WUC        = -1.4298628e-017
+PUC        = -2.1211974e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '3.3128595+da0p_lvt'
+LA0        = '-1.5287536e-006+dla0p_lvt'
+WA0        = '8.3134533e-007+dwa0p_lvt'
+PA0        = '2.5939214e-013+dpa0p_lvt'
+AGS        = '0.83488391+dagsp_lvt'
+LAGS       = '7.8240194e-007+dlagsp_lvt'
+WAGS       = '7.3818164e-010+dwagsp_lvt'
+PAGS       = '-2.0763492e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025309949        LKETA      = -1.6919555e-008
+WKETA      = 4.7577489e-010      PKETA      = 2.0484706e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '0.0038497891+dpdiblc2p_lvt'
+LPDIBLC2   = '9.004666e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.2706075e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '1.476717e-014+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0016125536        LTVOFF     = -3.5412707e-010
+WTVOFF     = -3.087175e-010      PTVOFF     = 1.7939269e-016      KT1        = -0.21827619
+LKT1       = -8.3344177e-008     WKT1       = -2.3120981e-008     PKT1       = 4.473981e-014
+KT1L       = 0                   KT2        = -0.046399107        LKT2       = -1.5742879e-008
+WKT2       = 3.4845948e-009      PKT2       = 1.7102912e-014      UTE        = '-1.4113511+dutep_lvt'
+LUTE       = '1.6053343e-008+dlutep_lvt'
+WUTE       = '-1.4892274e-007+dwutep_lvt'
+PUTE       = '1.5999889e-013+dputep_lvt'
+UA1        = '1.0402771e-009+dua1p_lvt'
+LUA1       = '7.8205071e-017+dlua1p_lvt'
+WUA1       = '-1.2054286e-016+dwua1p_lvt'
+PUA1       = '3.9703806e-022+dpua1p_lvt'
+UB1        = '-2.0747062e-018+dub1p_lvt'
+LUB1       = '-8.4472996e-027+dlub1p_lvt'
+WUB1       = '6.612008e-025+dwub1p_lvt'
+PUB1       = '-9.6802486e-031+dpub1p_lvt'
+UC1        = 4.1972261e-011      LUC1       = 2.6915749e-017      WUC1       = -1.2611195e-017
+PUC1       = -3.9430029e-023     PRT        = 0                   AT         = '180534.2+datp_lvt'
+LAT        = '-0.016615495+dlatp_lvt'
+WAT        = '0.01074776+dwatp_lvt'
+PAT        = '6.060564e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.24218566+(dvthp_lvt+vthmisp_lvt)-0.00022329*ff_flag_lvt-0.00022329*ss_flag_lvt'
+LVTH0      = '-2.4856887e-009+dlvthp_lvt+5.13767e-11*ff_flag_lvt+5.13767e-11*ss_flag_lvt'
+WVTH0      = '-2.7463476e-008+dwvthp_lvt+2.23736e-09*ff_flag_lvt+2.23736e-09*ss_flag_lvt'
+PVTH0      = '3.6590497e-015+dpvthp_lvt-5.14795e-16*ff_flag_lvt-5.14795e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.017269303+dk2p_lvt'
+LK2        = '-5.5156485e-010+dlk2p_lvt'
+WK2        = '-1.942292e-010+dwk2p_lvt'
+PK2        = '-7.5503297e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00052375953+dcitp_lvt'
+LCIT       = '-2.3146946e-011+dlcitp_lvt'
+WCIT       = '-2.380705e-010+dwcitp_lvt'
+PCIT       = '2.319324e-016+dpcitp_lvt'
+VOFF       = '-0.060877121+dvoffp_lvt'
+LVOFF      = '-8.9224745e-009+dlvoffp_lvt'
+WVOFF      = '-2.8754236e-008+dwvoffp_lvt'
+PVOFF      = '3.1693892e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010395877+du0p_lvt+1.77633e-06*ff_flag_lvt+1.42106e-06*sf_flag_lvt-1.42106e-06*fs_flag_lvt'
+LU0        = '-3.9406988e-010+dlu0p_lvt-1.71256e-12*ff_flag_lvt-1.37005e-12*sf_flag_lvt+1.37005e-12*fs_flag_lvt'
+WU0        = '2.1145986e-009+dwu0p_lvt-1.77988e-11*ff_flag_lvt-1.4239e-11*sf_flag_lvt+1.4239e-11*fs_flag_lvt'
+PU0        = '-7.8935265e-017+dpu0p_lvt+1.71598e-17*ff_flag_lvt+1.37279e-17*sf_flag_lvt-1.37279e-17*fs_flag_lvt'
+UA         = '-2.5869874e-010+duap_lvt'
+LUA        = '-1.0988483e-016+dluap_lvt'
+WUA        = '1.2512776e-016+dwuap_lvt'
+PUA        = '4.2384805e-023+dpuap_lvt'
+UB         = '1.8394369e-018+dubp_lvt'
+LUB        = '-4.1626778e-028+dlubp_lvt'
+WUB        = '-1.1432372e-025+dwubp_lvt'
+PUB        = '-3.8291607e-032+dpubp_lvt'
+UC         = 5.6728158e-012      LUC        = 5.4126028e-018      WUC        = -1.6755957e-017
+PUC        = 2.1569919e-024      VSAT       = '95420+dvsatp_lvt'  A0         = '1.8687681+da0p_lvt'
+LA0        = '-1.3650505e-007+dla0p_lvt'
+WA0        = '1.5254322e-006+dwa0p_lvt'
+PA0        = '-4.0977698e-013+dpa0p_lvt'
+AGS        = '-0.014002595+dagsp_lvt'
+LAGS       = '1.6008134e-006+dlagsp_lvt'
+WAGS       = '-4.5989611e-007+dwagsp_lvt'
+PAGS       = '2.364626e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024608797        LKETA      = -1.7595535e-008
+WKETA      = 1.969543e-011       PKETA      = 2.4881768e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.1880819+dpclmp_lvt'
+LPCLM      = '-1.8132977e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.011019429+dpdiblc2p_lvt'
+LPDIBLC2   = '2.0924166e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.6178618e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-3.9838285e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0011426831        LTVOFF     = 9.8875092e-011
+WTVOFF     = -1.3154421e-010     PTVOFF     = 8.5799201e-018      KT1        = -0.30860044
+LKT1       = 3.7374386e-009      WKT1       = 2.9751321e-008      PKT1       = -6.2343759e-015
+KT1L       = 0                   KT2        = -0.061534653        LKT2       = -1.1506986e-009
+WKT2       = 2.5535238e-008      PKT2       = -4.1561133e-015     UTE        = '-1.523649+dutep_lvt'
+LUTE       = '1.2431969e-007+dlutep_lvt'
+WUTE       = '7.4702169e-008+dwutep_lvt'
+PUTE       = '-5.5597882e-014+dputep_lvt'
+UA1        = '1.0105665e-009+dua1p_lvt'
+LUA1       = '1.068491e-016+dlua1p_lvt'
+WUA1       = '4.0655021e-016+dwua1p_lvt'
+PUA1       = '-1.1113237e-022+dpua1p_lvt'
+UB1        = '-2.2150103e-018+dub1p_lvt'
+LUB1       = '1.2681996e-025+dlub1p_lvt'
+WUB1       = '-4.0681235e-025+dwub1p_lvt'
+PUB1       = '6.1646616e-032+dpub1p_lvt'
+UC1        = 5.7156411e-011      LUC1       = 1.227671e-017       WUC1       = -5.8308033e-017
+PUC1       = 4.6262929e-024      PRT        = 0                   AT         = '198771.73+datp_lvt'
+LAT        = '-0.03419829+dlatp_lvt'
+WAT        = '0.022818616+dwatp_lvt'
+PAT        = '-5.5769481e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '1.2831097e-009+dlvthp_lvt'
+WVTH0      = '-1.3596429e-008+dwvthp_lvt'
+PVTH0      = '4.6838072e-016+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2p_lvt'
+LK2        = '4.6584946e-010+dlk2p_lvt'
+WK2        = '-2.5582468e-009+dwk2p_lvt'
+PK2        = '4.6843351e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitp_lvt'
+LCIT       = '3.0389251e-010+dlcitp_lvt'
+WCIT       = '1.5758347e-009+dwcitp_lvt'
+PCIT       = '-1.8542906e-016+dpcitp_lvt'
+VOFF       = '-0.076341704+dvoffp_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffp_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffp_lvt'
+PVOFF      = '3.2068922e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908066+deta0p_lvt'
+LETA0      = '-2.3078942e-013+dleta0p_lvt'
+WETA0      = '1.9302674e-007+dweta0p_lvt'
+PETA0      = '5.8675625e-019+dpeta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0p_lvt-5.66666e-06*ff_flag_lvt+8.48339e-06*ss_flag_lvt-4.53333e-06*sf_flag_lvt+4.53333e-06*fs_flag_lvt'
+LU0        = '-1.9519503e-010+dlu0p_lvt+5e-20*ff_flag_lvt-1.95194e-12*ss_flag_lvt+2.4e-19*sf_flag_lvt-2.4e-19*fs_flag_lvt'
+WU0        = '1.9415438e-009+dwu0p_lvt+5.678e-11*ff_flag_lvt-8.50036e-11*ss_flag_lvt+4.5424e-11*sf_flag_lvt-4.5424e-11*fs_flag_lvt'
+PU0        = '-3.9117084e-017+dpu0p_lvt-1e-24*ff_flag_lvt+1.95585e-17*ss_flag_lvt+3.2e-24*sf_flag_lvt-3.2e-24*fs_flag_lvt'
+UA         = '-6.2902859e-010+duap_lvt'
+LUA        = '-2.4675637e-017+dluap_lvt'
+WUA        = '3.9281125e-016+dwuap_lvt'
+PUA        = '-1.9206488e-023+dpuap_lvt'
+UB         = '1.9421977e-018+dubp_lvt'
+LUB        = '-2.4060497e-026+dlubp_lvt'
+WUB        = '-4.483143e-025+dwubp_lvt'
+PUB        = '3.8556285e-032+dpubp_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatp_lvt'  A0         = '5.3771092+da0p_lvt'
+LA0        = '-9.4373925e-007+dla0p_lvt'
+WA0        = '-1.9768385e-006+dwa0p_lvt'
+PA0        = '3.9606047e-013+dpa0p_lvt'
+AGS        = '9.1959311+dagsp_lvt'
+LAGS       = '-5.1830021e-007+dlagsp_lvt'
+WAGS       = '1.247831e-006+dwagsp_lvt'
+PAGS       = '-1.5646833e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmp_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2p_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+dutep_lvt'
+LUTE       = '-2.8693669e-009+dlutep_lvt'
+WUTE       = '-2.918889e-007+dwutep_lvt'
+PUTE       = '2.8751056e-014+dputep_lvt'
+UA1        = '1.3742656e-009+dua1p_lvt'
+LUA1       = '2.3165574e-017+dlua1p_lvt'
+WUA1       = '1.292132e-016+dwua1p_lvt'
+PUA1       = '-4.7319897e-023+dpua1p_lvt'
+UB1        = '-1.8019021e-018+dub1p_lvt'
+LUB1       = '3.1767874e-026+dlub1p_lvt'
+WUB1       = '-8.8236177e-026+dwub1p_lvt'
+PUB1       = '-1.1654575e-032+dpub1p_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datp_lvt'
+LAT        = '-0.010013792+dlatp_lvt'
+WAT        = '-0.0024820485+dwatp_lvt'
+PAT        = '2.4448177e-010+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-005-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+(dvthp_lvt+vthmisp_lvt)-0.0126208*ff_flag_lvt+0.0275506*ss_flag_lvt-0.00555994*sf_flag_lvt+0.00555994*fs_flag_lvt'
+LVTH0      = '-1.5409072e-009+dlvthp_lvt+1.24315e-09*ff_flag_lvt-2.71373e-09*ss_flag_lvt+5.47654e-10*sf_flag_lvt-5.47654e-10*fs_flag_lvt'
+WVTH0      = '-9.5700168e-009+dwvthp_lvt-9.64051e-09*ff_flag_lvt-3.85616e-09*ss_flag_lvt-1.23398e-08*sf_flag_lvt+1.23398e-08*fs_flag_lvt'
+PVTH0      = '7.1779158e-017+dpvthp_lvt+9.49589e-16*ff_flag_lvt+3.79834e-16*ss_flag_lvt+1.21547e-15*sf_flag_lvt-1.21547e-15*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2p_lvt'
+LK2        = '2.3040232e-009+dlk2p_lvt'
+WK2        = '5.5823676e-010+dwk2p_lvt'
+PK2        = '1.6145988e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.5104142e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '6.1284302e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-9.0574373e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.081864514+dvoffp_lvt-0.0481515*ff_flag_lvt+0.0567087*ss_flag_lvt-0.0356506*sf_flag_lvt+0.0354005*fs_flag_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffp_lvt+4.7429e-09*ff_flag_lvt-5.58579e-09*ss_flag_lvt+3.51158e-09*sf_flag_lvt-3.48694e-09*fs_flag_lvt'
+WVOFF      = '1.4496007e-008+dwvoffp_lvt+2.31371e-08*ff_flag_lvt-5.78429e-08*ss_flag_lvt+1.69672e-08*sf_flag_lvt-1.44607e-08*fs_flag_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffp_lvt-2.27901e-15*ff_flag_lvt+5.69751e-15*ss_flag_lvt-1.67127e-15*sf_flag_lvt+1.42438e-15*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.0769699*ff_flag_lvt-0.756116*ss_flag_lvt+0.061576*sf_flag_lvt-0.061576*fs_flag_lvt'
+ETA0       = '-0.13126921+deta0p_lvt+0.0945146*ff_flag_lvt-0.0945146*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LETA0      = '4.1574237e-008+dleta0p_lvt-9.30966e-09*ff_flag_lvt+9.30966e-09*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WETA0      = '5.1059346e-007+dweta0p_lvt-9.64048e-08*ff_flag_lvt+9.64048e-08*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PETA0      = '-3.1279736e-014+dpeta0p_lvt+9.49585e-15*ff_flag_lvt-9.49585e-15*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0p_lvt+0.000206454*ff_flag_lvt-0.00127681*ss_flag_lvt+8.95511e-05*sf_flag_lvt-1.39395e-05*fs_flag_lvt'
+LU0        = '2.1404963e-010+dlu0p_lvt-2.08938e-11*ff_flag_lvt+1.24649e-10*ss_flag_lvt-9.26729e-12*sf_flag_lvt+1.81956e-12*fs_flag_lvt'
+WU0        = '1.1009666e-009+dwu0p_lvt-3.67401e-10*ff_flag_lvt+8.848e-10*ss_flag_lvt-2.16797e-10*sf_flag_lvt+1.39673e-10*fs_flag_lvt'
+PU0        = '4.3679771e-017+dpu0p_lvt+4.17817e-17*ff_flag_lvt-7.59665e-17*ss_flag_lvt+2.58287e-17*sf_flag_lvt-1.8232e-17*fs_flag_lvt'
+UA         = '-1.3371304e-009+duap_lvt'
+LUA        = '4.5072393e-017+dluap_lvt'
+WUA        = '-9.5951684e-019+dwuap_lvt'
+PUA        = '1.9579932e-023+dpuap_lvt'
+UB         = '1.6937477e-018+dubp_lvt'
+LUB        = '4.118249e-028+dlubp_lvt'
+WUB        = '2.3165923e-025+dwubp_lvt'
+PUB        = '-2.8421107e-032+dpubp_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatp_lvt-192.425*ff_flag_lvt+5478.45*ss_flag_lvt-153.94*sf_flag_lvt+153.94*fs_flag_lvt'
+LVSAT      = '0.00071788404+dlvsatp_lvt+1.89538e-05*ff_flag_lvt-0.000539625*ss_flag_lvt+1.5163e-05*sf_flag_lvt-1.5163e-05*fs_flag_lvt'
+WVSAT      = '0.02063004+dwvsatp_lvt+0.0019281*ff_flag_lvt-0.00385619*ss_flag_lvt+0.00154248*sf_flag_lvt-0.00154248*fs_flag_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatp_lvt-1.89917e-10*ff_flag_lvt+3.79834e-10*ss_flag_lvt-1.51934e-10*sf_flag_lvt+1.51934e-10*fs_flag_lvt'
+A0         = '-14.929677+da0p_lvt'
+LA0        = '1.0564791e-006+dla0p_lvt'
+WA0        = '7.4425951e-006+dwa0p_lvt'
+PA0        = '-5.3175373e-013+dpa0p_lvt'
+AGS        = '-4.6385162+dagsp_lvt'
+LAGS       = '8.4439285e-007+dlagsp_lvt'
+WAGS       = '1.8052297e-006+dwagsp_lvt'
+PAGS       = '-2.1137211e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmp_lvt'
+LPCLM      = '-5.758458e-008+dlpclmp_lvt'
+WPCLM      = '9.6402055e-008+dwpclmp_lvt'
+PPCLM      = '-9.4956024e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+dutep_lvt'
+UA1        = '2.2956478e-009+dua1p_lvt'
+LUA1       = '-6.7590577e-017+dlua1p_lvt'
+WUA1       = '-1.1115199e-015+dwua1p_lvt'
+PUA1       = '7.4892317e-023+dpua1p_lvt'
+UB1        = '-1.2411257e-018+dub1p_lvt'
+LUB1       = '-2.3468592e-026+dlub1p_lvt'
+WUB1       = '-5.8862958e-025+dwub1p_lvt'
+PUB1       = '3.7634175e-032+dpub1p_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt-7.58152e-09*ff_flag_lvt+7.44773e-08*ss_flag_lvt-6.06521e-09*sf_flag_lvt+6.06521e-09*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt-7.71239e-07*ff_flag_lvt+7.71239e-07*ss_flag_lvt-6.16991e-07*sf_flag_lvt+6.16991e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+7.59668e-14*ff_flag_lvt-7.59668e-14*ss_flag_lvt+6.07734e-14*sf_flag_lvt-6.07734e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = 2.001e-05           WMIN       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-006-(dxwp_lvt+dwmisp_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_lvt+toxmisp_lvt)'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23966304+(dvthp_lvt+vthmisp_lvt)'
+WVTH0      = '-2.4987547e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.0218635+dk2p_lvt'
+WK2        = '1.94463e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.069351363+dvoffp_lvt'
+WVOFF      = '8.448864e-013+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0115615+du0p_lvt'
+WU0        = '4.2687e-010+dwu0p_lvt'
+UA         = '-1.213e-013+duap_lvt'
+WUA        = '3.045006e-018+dwuap_lvt'
+UB         = '1.6050812e-018+dubp_lvt'
+WUB        = '-9.5530344e-026+dwubp_lvt'
+UC         = -6.1535e-012        WUC        = 6.27657e-018        VSAT       = '95420+dvsatp_lvt'
+A0         = '4.90365+da0p_lvt'  WA0        = '-9.21723e-007+dwa0p_lvt'
+AGS        = '0.880215+dagsp_lvt'
+WAGS       = '1.37547e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0353765          WKETA      = 9.21723e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.003775+dpdiblc2p_lvt'
+WPDIBLC2   = '-7.905e-010+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00154465          LTVOFF     = 0
+WTVOFF     = -2.57703e-010       PTVOFF     = 0                   KT1        = -0.25164405
+WKT1       = 6.872607e-009       KT1L       = 0                   KT2        = -0.0534665
+WKT2       = 1.079823e-008       UTE        = '-1.50745+dutep_lvt'
+WUTE       = '-3.3201e-008+dwutep_lvt'
+UA1        = '1.0318411e-009+dua1p_lvt'
+WUA1       = '-6.4085573e-017+dwua1p_lvt'
+UB1        = '-1.6581697e-018+dub1p_lvt'
+WUB1       = '1.3831758e-025+dwub1p_lvt'
+UC1        = 9.3902e-011         WUC1       = -6.678144e-017      PRT        = 0
+AT         = '208600+datp_lvt'   WAT        = '-0.018972+dwatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23700857+(dvthp_lvt+vthmisp_lvt)-0.000409743*ff_flag_lvt-0.000409743*ss_flag_lvt'
+LVTH0      = '-2.6449461e-008+dlvthp_lvt+4.08272e-09*ff_flag_lvt+4.08272e-09*ss_flag_lvt'
+WVTH0      = '-2.38126e-009+dwvthp_lvt+2.5404e-10*ff_flag_lvt+2.5404e-10*ss_flag_lvt'
+PVTH0      = '-1.1707287e-015+dpvthp_lvt-2.53128e-15*ff_flag_lvt-2.53128e-15*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.022769641+dk2p_lvt'
+LK2        = '-9.0288794e-009+dlk2p_lvt'
+WK2        = '1.8223689e-009+dwk2p_lvt'
+PK2        = '1.2182224e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.0544859e-005+dcitp_lvt'
+LCIT       = '8.9133997e-010+dlcitp_lvt'
+WCIT       = '4.7297995e-011+dwcitp_lvt'
+PCIT       = '-4.7128195e-016+dpcitp_lvt'
+VOFF       = '-0.067296285+dvoffp_lvt'
+LVOFF      = '-2.0477e-008+dlvoffp_lvt'
+WVOFF      = '7.1809804e-010+dwvoffp_lvt'
+PVOFF      = '-7.1467822e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01130746+du0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '2.5312835e-009+dlu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WU0        = '6.8599116e-010+dwu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '-2.5819091e-015+dpu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '-4.4552523e-011+duap_lvt'
+LUA        = '4.4271715e-016+dluap_lvt'
+WUA        = '7.1284647e-017+dwuap_lvt'
+PUA        = '-6.7994661e-022+dpuap_lvt'
+UB         = '1.6089615e-018+dubp_lvt'
+LUB        = '-3.8663777e-026+dlubp_lvt'
+WUB        = '-1.1878006e-025+dwubp_lvt'
+PUB        = '2.3166252e-031+dpubp_lvt'
+UC         = -6.4772287e-012     LUC        = 3.2256653e-018      WUC        = 6.9287763e-018
+PUC        = -6.4986484e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '5.2249899+da0p_lvt'
+LA0        = '-3.2018628e-006+dla0p_lvt'
+WA0        = '-1.1190277e-006+dwa0p_lvt'
+PA0        = '1.9659635e-012+dpa0p_lvt'
+AGS        = '0.82899665+dagsp_lvt'
+LAGS       = '5.1034474e-007+dlagsp_lvt'
+WAGS       = '6.7431863e-009+dwagsp_lvt'
+PAGS       = '6.9863423e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.03395472         LKETA      = -1.4166755e-008
+WKETA      = 9.2934421e-009      PKETA      = -7.5938504e-016     DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '0.0016673703+dpdiblc2p_lvt'
+LPDIBLC2   = '2.1000633e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '-1.0445404e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '2.5312835e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0014756676        LTVOFF     = 6.8734779e-010
+WTVOFF     = -1.6909373e-010     PTVOFF     = -8.8291167e-016     KT1        = -0.25379916
+LKT1       = 2.1473739e-008      WKT1       = 1.3112455e-008      PKT1       = -6.2174464e-014
+KT1L       = 0                   KT2        = -0.055487093        LKT2       = 2.013339e-008
+WKT2       = 1.2754341e-008      PKT2       = -1.9490883e-014     UTE        = '-1.5470531+dutep_lvt'
+LUTE       = '3.9460911e-007+dlutep_lvt'
+WUTE       = '-1.0506729e-008+dwutep_lvt'
+PUTE       = '-2.2612799e-013+dputep_lvt'
+UA1        = '9.4498436e-010+dua1p_lvt'
+LUA1       = '8.6544905e-016+dlua1p_lvt'
+WUA1       = '-2.3344232e-017+dwua1p_lvt'
+PUA1       = '-4.059508e-022+dpua1p_lvt'
+UB1        = '-1.5086827e-018+dub1p_lvt'
+LUB1       = '-1.4895027e-024+dlub1p_lvt'
+WUB1       = '8.3856899e-026+dwub1p_lvt'
+PUB1       = '5.4265167e-031+dpub1p_lvt'
+UC1        = 1.0049273e-010      LUC1       = -6.5670715e-017     WUC1       = -7.2302076e-017
+PUC1       = 5.5008164e-023      PRT        = 0                   AT         = '211331.62+datp_lvt'
+LAT        = '-0.027218102+dlatp_lvt'
+WAT        = '-0.020665602+dwatp_lvt'
+PAT        = '1.6875223e-008+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.26707757+(dvthp_lvt+vthmisp_lvt)+0.00502402*ff_flag_lvt+0.00502402*ss_flag_lvt'
+LVTH0      = '2.5400675e-009+dlvthp_lvt-1.15598e-09*ff_flag_lvt-1.15598e-09*ss_flag_lvt'
+WVTH0      = '-2.0737266e-009+dwvthp_lvt-3.11489e-09*ff_flag_lvt-3.11489e-09*ss_flag_lvt'
+PVTH0      = '-1.4672217e-015+dpvthp_lvt+7.16705e-16*ff_flag_lvt+7.16705e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.013134035+dk2p_lvt'
+LK2        = '2.6080868e-010+dlk2p_lvt'
+WK2        = '4.0237449e-009+dwk2p_lvt'
+PK2        = '-9.041243e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0005295005+dcitp_lvt'
+LCIT       = '3.9101483e-010+dlcitp_lvt'
+WCIT       = '-2.4392629e-010+dwcitp_lvt'
+PCIT       = '-1.9051261e-016+dpcitp_lvt'
+VOFF       = '-0.083898674+dvoffp_lvt'
+LVOFF      = '-4.4706369e-009+dlvoffp_lvt'
+WVOFF      = '-5.2722525e-009+dwvoffp_lvt'
+PVOFF      = '-1.3714852e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.014500725+du0p_lvt-3.99673e-05*ff_flag_lvt-3.19739e-05*sf_flag_lvt+3.19739e-05*fs_flag_lvt'
+LU0        = '-5.473439e-010+dlu0p_lvt+3.85325e-11*ff_flag_lvt+3.0826e-11*sf_flag_lvt-3.0826e-11*fs_flag_lvt'
+WU0        = '-2.0723465e-009+dwu0p_lvt+2.47798e-11*ff_flag_lvt+1.98238e-11*sf_flag_lvt-1.98238e-11*fs_flag_lvt'
+PU0        = '7.7404237e-017+dpu0p_lvt-2.38902e-17*ff_flag_lvt-1.91121e-17*sf_flag_lvt+1.91121e-17*fs_flag_lvt'
+UA         = '4.9072443e-010+duap_lvt'
+LUA        = '-7.3343357e-017+dluap_lvt'
+WUA        = '-6.3928388e-016+dwuap_lvt'
+PUA        = '5.1125021e-024+dpuap_lvt'
+UB         = '1.6403507e-018+dubp_lvt'
+LUB        = '-6.8926099e-026+dlubp_lvt'
+WUB        = '8.8744158e-026+dwubp_lvt'
+PUB        = '3.1588421e-032+dpubp_lvt'
+UC         = -1.2857777e-011     LUC        = 9.3771515e-018      WUC        = 2.1452469e-018
+PUC        = -1.8868477e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '2.0457921+da0p_lvt'
+LA0        = '-1.367982e-007+dla0p_lvt'
+WA0        = '1.3448676e-006+dwa0p_lvt'
+PA0        = '-4.0947797e-013+dpa0p_lvt'
+AGS        = '-1.0041691+dagsp_lvt'
+LAGS       = '2.2776998e-006+dlagsp_lvt'
+WAGS       = '5.5007369e-007+dwagsp_lvt'
+PAGS       = '-4.5396152e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.028273774        LKETA      = -1.9643756e-008
+WKETA      = 3.757972e-009       PKETA      = 4.5773617e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.0909063+dpclmp_lvt'
+LPCLM      = '-8.764272e-008+dlpclmp_lvt'
+WPCLM      = '9.9119165e-008+dwpclmp_lvt'
+PPCLM      = '-9.5560787e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.032317748+dpdiblc2p_lvt'
+LPDIBLC2   = '-8.5493962e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-5.5456679e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '6.8708206e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0024398906        LTVOFF     = -2.4225959e-010
+WTVOFF     = -1.4546958e-009     PTVOFF     = 3.565373e-016       KT1        = -0.20936915
+LKT1       = -2.1361236e-008     WKT1       = -7.1464598e-008     PKT1       = 1.9366273e-014
+KT1L       = 0                   KT2        = -0.027274605        LKT2       = -7.0662699e-009
+WKT2       = -9.4100116e-009     PKT2       = 1.8777695e-015      UTE        = '-1.1635172+dutep_lvt'
+LUTE       = '2.4842178e-008+dlutep_lvt'
+WUTE       = '-2.926322e-007+dwutep_lvt'
+PUTE       = '4.5869178e-014+dputep_lvt'
+UA1        = '1.8881319e-009+dua1p_lvt'
+LUA1       = '-4.3839481e-017+dlua1p_lvt'
+WUA1       = '-4.8856649e-016+dwua1p_lvt'
+PUA1       = '4.2569984e-023+dpua1p_lvt'
+UB1        = '-3.3980433e-018+dub1p_lvt'
+LUB1       = '3.3202984e-025+dlub1p_lvt'
+WUB1       = '7.9988131e-025+dwub1p_lvt'
+PUB1       = '-1.4766746e-031+dpub1p_lvt'
+UC1        = 1.8904547e-011      LUC1       = 1.2988455e-017      WUC1       = -1.9291132e-017
+PUC1       = 3.9003135e-024      PRT        = 0                   AT         = '211542.06+datp_lvt'
+LAT        = '-0.027420989+dlatp_lvt'
+WAT        = '0.0097928748+dwatp_lvt'
+PAT        = '-1.2489795e-008+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '2.6146736e-011+dlvthp_lvt'
+WVTH0      = '-1.6058274e-008+dwvthp_lvt'
+PVTH0      = '1.7504829e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2p_lvt'
+LK2        = '5.5945104e-010+dlk2p_lvt'
+WK2        = '-1.5266232e-009+dwk2p_lvt'
+PK2        = '3.729599e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitp_lvt'
+LCIT       = '-4.9918717e-012+dlcitp_lvt'
+WCIT       = '-1.6353193e-009+dwcitp_lvt'
+PCIT       = '1.2963301e-016+dpcitp_lvt'
+VOFF       = '-0.082218583+dvoffp_lvt'
+LVOFF      = '-4.857209e-009+dlvoffp_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffp_lvt'
+PVOFF      = '2.6897322e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.72801286+deta0p_lvt'
+LETA0      = '1.4122934e-012+dleta0p_lvt'
+WETA0      = '-2.5292365e-007+dweta0p_lvt'
+PETA0      = '-1.0891883e-018+dpeta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0p_lvt+0.0001275*ff_flag_lvt-0.000190876*ss_flag_lvt+0.000102*sf_flag_lvt-0.000102*fs_flag_lvt'
+LU0        = '-2.7091922e-010+dlu0p_lvt+4.6e-17*ff_flag_lvt+4.39187e-11*ss_flag_lvt-2.3e-17*sf_flag_lvt+2.3e-17*fs_flag_lvt'
+WU0        = '-1.9016192e-009+dwu0p_lvt-7.90503e-11*ff_flag_lvt+1.18343e-10*ss_flag_lvt-6.32397e-11*sf_flag_lvt+6.32397e-11*fs_flag_lvt'
+PU0        = '3.8121589e-017+dpu0p_lvt+5e-24*ff_flag_lvt-2.72296e-17*ss_flag_lvt-3.6e-23*sf_flag_lvt+3.6e-23*fs_flag_lvt'
+UA         = '4.0037736e-010+duap_lvt'
+LUA        = '-5.25554e-017+dluap_lvt'
+WUA        = '-6.5718282e-016+dwuap_lvt'
+PUA        = '9.2308705e-024+dpuap_lvt'
+UB         = '1.3125234e-018+dubp_lvt'
+LUB        = '6.503691e-027+dlubp_lvt'
+WUB        = '1.9395346e-025+dwubp_lvt'
+PUB        = '7.3808134e-033+dpubp_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '4.8804857+da0p_lvt'
+LA0        = '-7.8903284e-007+dla0p_lvt'
+WA0        = '-1.4702825e-006+dwa0p_lvt'
+PA0        = '2.3825993e-013+dpa0p_lvt'
+AGS        = '13.322597+dagsp_lvt'
+LAGS       = '-1.0187458e-006+dlagsp_lvt'
+WAGS       = '-2.9613684e-006+dwagsp_lvt'
+PAGS       = '3.5398618e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmp_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmp_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmp_lvt'
+PPCLM      = '-1.3614853e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2p_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+dutep_lvt'
+LUTE       = '9.5674269e-009+dlutep_lvt'
+WUTE       = '-1.6310179e-007+dwutep_lvt'
+PUTE       = '1.6065527e-014+dputep_lvt'
+UA1        = '2.0289308e-009+dua1p_lvt'
+LUA1       = '-7.6235902e-017+dlua1p_lvt'
+WUA1       = '-5.385453e-016+dwua1p_lvt'
+PUA1       = '5.4069609e-023+dpua1p_lvt'
+UB1        = '-2.1814336e-018+dub1p_lvt'
+LUB1       = '5.2100107e-026+dlub1p_lvt'
+WUB1       = '2.9888601e-025+dwub1p_lvt'
+PUB1       = '-3.2393453e-032+dpub1p_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datp_lvt'
+LAT        = '-0.017286299+dlatp_lvt'
+WAT        = '-0.077791263+dwatp_lvt'
+PAT        = '7.6624394e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '1e-006-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+(dvthp_lvt+vthmisp_lvt)+0.00687633*ff_flag_lvt+0.0106116*ss_flag_lvt+0.0055011*sf_flag_lvt-0.0055011*fs_flag_lvt'
+LVTH0      = '-1.3621188e-010+dlvthp_lvt-6.77323e-10*ff_flag_lvt-1.04524e-09*ss_flag_lvt-5.41853e-10*sf_flag_lvt+5.41853e-10*fs_flag_lvt'
+WVTH0      = '1.5530487e-008+dwvthp_lvt-2.95276e-08*ff_flag_lvt+1.34216e-08*ss_flag_lvt-2.36221e-08*sf_flag_lvt+2.36221e-08*fs_flag_lvt'
+PVTH0      = '-1.3610101e-015+dpvthp_lvt+2.90846e-15*ff_flag_lvt-1.32203e-15*ss_flag_lvt+2.32676e-15*sf_flag_lvt-2.32676e-15*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2p_lvt'
+LK2        = '2.4320462e-009+dlk2p_lvt'
+WK2        = '1.9463059e-009+dwk2p_lvt'
+PK2        = '3.0876379e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.099571e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '1.7484688e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-4.8668363e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.078139928+dvoffp_lvt-0.00704616*ff_flag_lvt-0.0210535*ss_flag_lvt-0.00217331*sf_flag_lvt+0.0120124*fs_flag_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffp_lvt+6.94039e-10*ff_flag_lvt+2.07377e-09*ss_flag_lvt+2.14071e-10*sf_flag_lvt-1.18321e-09*fs_flag_lvt'
+WVOFF      = '1.0696929e-008+dwvoffp_lvt-1.87903e-08*ff_flag_lvt+2.14746e-08*ss_flag_lvt-1.71796e-08*sf_flag_lvt+9.39513e-09*fs_flag_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffp_lvt+1.85084e-15*ff_flag_lvt-2.11524e-15*ss_flag_lvt+1.6922e-15*sf_flag_lvt-9.25416e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.110365*ff_flag_lvt+0.0*ss_flag_lvt+0.0882879*sf_flag_lvt+0.70122*fs_flag_lvt'
+ETA0       = '0.90417384+deta0p_lvt-0.00394754*ff_flag_lvt-0.0263169*ss_flag_lvt+0.0*sf_flag_lvt-0.0184218*fs_flag_lvt'
+LETA0      = '-1.7350444e-008+dleta0p_lvt+3.88831e-10*ff_flag_lvt+2.59221e-09*ss_flag_lvt+0.0*sf_flag_lvt+1.81455e-09*fs_flag_lvt'
+WETA0      = '-5.4555845e-007+dweta0p_lvt+4.02649e-09*ff_flag_lvt+2.68433e-08*ss_flag_lvt+0.0*sf_flag_lvt+1.87903e-08*fs_flag_lvt'
+PETA0      = '2.8823439e-014+dpeta0p_lvt-3.96608e-16*ff_flag_lvt-2.64405e-15*ss_flag_lvt+0.0*sf_flag_lvt-1.85084e-15*fs_flag_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0p_lvt-0.000313096*ff_flag_lvt+0.000193026*ss_flag_lvt-0.000250477*sf_flag_lvt+0.000234687*fs_flag_lvt'
+LU0        = '2.8823786e-010+dlu0p_lvt+4.33987e-11*ff_flag_lvt+6.10414e-12*ss_flag_lvt+3.47189e-11*sf_flag_lvt-3.31636e-11*fs_flag_lvt'
+WU0        = '-1.1898039e-009+dwu0p_lvt+1.6254e-10*ff_flag_lvt-6.14436e-10*ss_flag_lvt+1.30031e-10*sf_flag_lvt-1.13925e-10*fs_flag_lvt'
+PU0        = '-3.199222e-017+dpu0p_lvt-2.37964e-17*ff_flag_lvt+4.49488e-17*ss_flag_lvt-1.90372e-17*sf_flag_lvt+1.74507e-17*fs_flag_lvt'
+UA         = '-7.9459861e-010+duap_lvt'
+LUA        = '6.5149733e-017+dluap_lvt'
+WUA        = '-5.5434195e-016+dwuap_lvt'
+PUA        = '-8.9895493e-025+dpuap_lvt'
+UB         = '1.6575544e-018+dubp_lvt'
+LUB        = '-2.7481865e-026+dlubp_lvt'
+WUB        = '2.6857637e-025+dwubp_lvt'
+PUB        = '3.0456064e-035+dpubp_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatp_lvt-2249.67*ff_flag_lvt+17488*ss_flag_lvt-1799.74*sf_flag_lvt+1799.74*fs_flag_lvt'
+LVSAT      = '-0.0018446019+dlvsatp_lvt+0.000221592*ff_flag_lvt-0.00172256*ss_flag_lvt+0.000177274*sf_flag_lvt-0.000177274*fs_flag_lvt'
+WVSAT      = '-0.0059053474+dwvsatp_lvt+0.00402649*ff_flag_lvt-0.016106*ss_flag_lvt+0.00322119*sf_flag_lvt-0.00322119*fs_flag_lvt'
+PVSAT      = '5.8167672e-010+dpvsatp_lvt-3.96609e-10*ff_flag_lvt+1.58643e-09*ss_flag_lvt-3.17287e-10*sf_flag_lvt+3.17287e-10*fs_flag_lvt'
+A0         = '-10.141985+da0p_lvt'
+LA0        = '6.9068048e-007+dla0p_lvt'
+WA0        = '2.5591493e-006+dwa0p_lvt'
+PA0        = '-1.5863911e-013+dpa0p_lvt'
+AGS        = '-8.9308661+dagsp_lvt'
+LAGS       = '1.1732203e-006+dlagsp_lvt'
+WAGS       = '6.1834266e-006+dwagsp_lvt'
+PAGS       = '-5.4677612e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmp_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmp_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmp_lvt'
+PPCLM      = '1.3219926e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2p_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flag_lvt-0.0210535*sf_flag_lvt+0.0210535*fs_flag_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flag_lvt+2.07377e-09*sf_flag_lvt-2.07377e-09*fs_flag_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flag_lvt+2.14746e-08*sf_flag_lvt-2.14746e-08*fs_flag_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flag_lvt-2.11524e-15*sf_flag_lvt+2.11524e-15*fs_flag_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+dutep_lvt'
+UA1        = '1.22313e-009+dua1p_lvt'
+LUA1       = '3.1354809e-018+dlua1p_lvt'
+WUA1       = '-1.7551692e-017+dwua1p_lvt'
+PUA1       = '2.7517381e-024+dpua1p_lvt'
+UB1        = '-1.6557558e-018+dub1p_lvt'
+LUB1       = '3.2084074e-028+dlub1p_lvt'
+WUB1       = '-1.6570695e-025+dwub1p_lvt'
+PUB1       = '1.3368954e-032+dpub1p_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt-1.08707e-08*ff_flag_lvt+0.0*ss_flag_lvt-8.69675e-09*sf_flag_lvt-6.90695e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt-8.05299e-07*ff_flag_lvt+0.0*ss_flag_lvt-6.44238e-07*sf_flag_lvt-1.6106e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+7.93218e-14*ff_flag_lvt+0.0*ss_flag_lvt+6.34573e-14*sf_flag_lvt+1.58643e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = 2.001e-05           WMIN       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '6e-007-(dxwp_lvt+dwmisp_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_lvt+toxmisp_lvt)'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23575365+(dvthp_lvt+vthmisp_lvt)'
+WVTH0      = '-4.9225791e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.017874667+dk2p_lvt'
+WK2        = '4.4177067e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.066934213+dvoffp_lvt'
+WVOFF      = '-1.4977877e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01353+du0p_lvt'  WU0        = '-7.936e-010+dwu0p_lvt'
+UA         = '5.9293933e-010+duap_lvt'
+WUA        = '-3.6465259e-016+dwuap_lvt'
+UB         = '1.2795536e-018+dubp_lvt'
+WUB        = '1.062968e-025+dwubp_lvt'
+UC         = 1.748e-013          WUC        = 2.353024e-018       VSAT       = '95420+dvsatp_lvt'
+A0         = '2.9295333+da0p_lvt'
+WA0        = '3.0222933e-007+dwa0p_lvt'
+AGS        = '0.9259776+dagsp_lvt'
+WAGS       = '-1.4618112e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022291333        WKETA      = 1.1044267e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0024703061+dpdiblc2p_lvt'
+WPDIBLC2   = '1.8410197e-011+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00153572          LTVOFF     = 0
+WTVOFF     = -2.521664e-010      PTVOFF     = 0                   KT1        = -0.23770992
+WKT1       = -1.7665536e-009     KT1L       = 0                   KT2        = -0.036412667
+WKT2       = 2.2485333e-010      UTE        = '-1.5215333+dutep_lvt'
+WUTE       = '-2.4469333e-008+dwutep_lvt'
+UA1        = '1.1222722e-009+dua1p_lvt'
+WUA1       = '-1.2015289e-016+dwua1p_lvt'
+UB1        = '-1.9038678e-018+dub1p_lvt'
+WUB1       = '2.9065041e-025+dwub1p_lvt'
+UC1        = -2.9513333e-012     WUC1       = -6.7323733e-018     PRT        = 0
+AT         = '175866.67+datp_lvt'
+WAT        = '0.0013226667+dwatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23088874+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '-4.8474388e-008+dlvthp_lvt'
+WVTH0      = '-6.1755499e-009+dwvthp_lvt'
+PVTH0      = '1.2484726e-014+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.018336586+dk2p_lvt'
+LK2        = '-4.6026059e-009+dlk2p_lvt'
+WK2        = '4.5708632e-009+dwk2p_lvt'
+PK2        = '-1.5260672e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016912175+dcitp_lvt'
+LCIT       = '-6.8873606e-010+dlcitp_lvt'
+WCIT       = '-5.101968e-011+dwcitp_lvt'
+PCIT       = '5.0836519e-016+dpcitp_lvt'
+VOFF       = '-0.060732147+dvoffp_lvt'
+LVOFF      = '-6.1798009e-008+dlvoffp_lvt'
+WVOFF      = '-3.3516675e-009+dwvoffp_lvt'
+PVOFF      = '1.8472243e-014+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013703952+du0p_lvt'
+LU0        = '-1.7332772e-009+dlu0p_lvt'
+WU0        = '-7.9983423e-010+dwu0p_lvt'
+PU0        = '6.2118468e-017+dpu0p_lvt'
+UA         = '6.7846422e-010+duap_lvt'
+LUA        = '-8.5217848e-016+dluap_lvt'
+WUA        = '-3.7698573e-016+dwuap_lvt'
+PUA        = '1.2288868e-022+dpuap_lvt'
+UB         = '1.2389008e-018+dubp_lvt'
+LUB        = '4.0506803e-025+dlubp_lvt'
+WUB        = '1.1065758e-025+dwubp_lvt'
+PUB        = '-4.3451198e-032+dpubp_lvt'
+UC         = 6.4009608e-013      LUC        = -4.6362567e-018     WUC        = 2.5160349e-018
+PUC        = -1.6242568e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '2.839515+da0p_lvt'
+LA0        = '8.9695208e-007+dla0p_lvt'
+WA0        = '3.5996678e-007+dwa0p_lvt'
+PA0        = '-5.7530172e-013+dpa0p_lvt'
+AGS        = '0.86185112+dagsp_lvt'
+LAGS       = '6.3896262e-007+dlagsp_lvt'
+WAGS       = '-1.3626586e-008+dwagsp_lvt'
+PAGS       = '-9.87966e-015+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020377559        LKETA      = -1.9069038e-008
+WKETA      = 8.7560217e-010      PKETA      = 2.2800301e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '-0.00096435659+dpdiblc2p_lvt'
+LPDIBLC2   = '3.4223323e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '5.8713031e-010+dwpdiblc2p_lvt'
+PPDIBLC2   = '-5.6667841e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001636702         LTVOFF     = -1.0061945e-009
+WTVOFF     = -2.6893506e-010     PTVOFF     = 1.6708456e-016      KT1        = -0.23113179
+LKT1       = -6.5545134e-008     WKT1       = -9.4131471e-010     PKT1       = -8.2227628e-015
+KT1L       = 0                   KT2        = -0.035745581        LKT2       = -6.6469095e-009
+WKT2       = 5.1460323e-010      PKT2       = -2.887097e-015      UTE        = '-1.5272751+dutep_lvt'
+LUTE       = '5.7211382e-008+dlutep_lvt'
+WUTE       = '-2.2769089e-008+dwutep_lvt'
+PUTE       = '-1.69414e-014+dputep_lvt'
+UA1        = '1.0849918e-009+dua1p_lvt'
+LUA1       = '3.7146639e-016+dlua1p_lvt'
+WUA1       = '-1.1014882e-016+dwua1p_lvt'
+PUA1       = '-9.9681548e-023+dpua1p_lvt'
+UB1        = '-1.8271261e-018+dub1p_lvt'
+LUB1       = '-7.6466195e-025+dlub1p_lvt'
+WUB1       = '2.8129178e-025+dwub1p_lvt'
+PUB1       = '9.3250387e-032+dpub1p_lvt'
+UC1        = -4.9914189e-012     LUC1       = 2.0327617e-017      WUC1       = -6.9019018e-018
+PUC1       = 1.6891988e-024      PRT        = 0                   AT         = '175866.67+datp_lvt'
+WAT        = '0.0013226667+dwatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'       LPCLM      = '0+dlpclmp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.2841419+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '2.866984e-009+dlvthp_lvt'
+WVTH0      = '8.5061597e-009+dwvthp_lvt'
+PVTH0      = '-1.6699099e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.014882296+dk2p_lvt'
+LK2        = '-1.2723252e-009+dlk2p_lvt'
+WK2        = '2.9398229e-009+dwk2p_lvt'
+PK2        = '4.6418728e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00087291832+dcitp_lvt'
+LCIT       = '3.1589478e-010+dlcitp_lvt'
+WCIT       = '6.2557338e-010+dwcitp_lvt'
+PCIT       = '-1.4393818e-016+dpcitp_lvt'
+VOFF       = '-0.12130234+dvoffp_lvt'
+LVOFF      = '-3.4022871e-009+dlvoffp_lvt'
+WVOFF      = '1.791802e-008+dwvoffp_lvt'
+PVOFF      = '-2.0338621e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.012392848+du0p_lvt'
+LU0        = '-4.6924114e-010+dlu0p_lvt'
+WU0        = '-7.6546234e-010+dwu0p_lvt'
+PU0        = '2.8980526e-017+dpu0p_lvt'
+UA         = '-1.4775568e-010+duap_lvt'
+LUA        = '-5.5619884e-017+dluap_lvt'
+WUA        = '-2.4342621e-016+dwuap_lvt'
+PUA        = '-5.8760515e-024+dpuap_lvt'
+UB         = '1.7096201e-018+dubp_lvt'
+LUB        = '-4.8752482e-026+dlubp_lvt'
+WUB        = '4.5797109e-026+dwubp_lvt'
+PUB        = '1.9080778e-032+dpubp_lvt'
+UC         = -1.1871005e-011     LUC        = 7.4256957e-018      WUC        = 1.5334484e-018
+PUC        = -6.7694512e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '4.8648962+da0p_lvt'
+LA0        = '-1.055718e-006+dla0p_lvt'
+WA0        = '-4.0297693e-007+dwa0p_lvt'
+PA0        = '1.6025232e-013+dpa0p_lvt'
+AGS        = '0.067371045+dagsp_lvt'
+LAGS       = '1.4049209e-006+dlagsp_lvt'
+WAGS       = '-1.1428118e-007+dwagsp_lvt'
+PAGS       = '8.7161431e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024690692        LKETA      = -1.4910747e-008
+WKETA      = 1.5364611e-009      PKETA      = 1.642896e-015       DWG        = 0
+DWB        = 0                   PCLM       = '2.2507759+dpclmp_lvt'
+LPCLM      = '-2.4177302e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.029773189+dpdiblc2p_lvt'
+LPDIBLC2   = '4.5892549e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.9680413e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '-1.2751432e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.000219292         LTVOFF     = 3.6033045e-010
+WTVOFF     = -7.7924692e-011     PTVOFF     = -1.7068531e-017     KT1        = -0.31187246
+LKT1       = 1.2296943e-008      WKT1       = -7.9125459e-009     PKT1       = -1.5017989e-015
+KT1L       = 0                   KT2        = -0.035773757        LKT2       = -6.6197453e-009
+WKT2       = -4.1405375e-009     PKT2       = 1.6009242e-015      UTE        = '-1.5590695+dutep_lvt'
+LUTE       = '8.7864345e-008+dlutep_lvt'
+WUTE       = '-4.7389807e-008+dwutep_lvt'
+PUTE       = '6.7954337e-015+dputep_lvt'
+UA1        = '1.5130551e-009+dua1p_lvt'
+LUA1       = '-4.1229464e-017+dlua1p_lvt'
+WUA1       = '-2.5601888e-016+dwua1p_lvt'
+PUA1       = '4.0951774e-023+dpua1p_lvt'
+UB1        = '-2.8218002e-018+dub1p_lvt'
+LUB1       = '1.9430338e-025+dlub1p_lvt'
+WUB1       = '4.4261056e-025+dwub1p_lvt'
+PUB1       = '-6.2277056e-032+dpub1p_lvt'
+UC1        = -1.1959973e-011     LUC1       = 2.7045999e-017      WUC1       = -1.5512966e-019
+PUC1       = -4.8153643e-024     PRT        = 0                   AT         = '230082.11+datp_lvt'
+LAT        = '-0.052269111+dlatp_lvt'
+WAT        = '-0.0017019579+dwatp_lvt'
+PAT        = '2.9160405e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.29225957+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '4.734777e-009+dlvthp_lvt'
+WVTH0      = '6.3285683e-009+dwvthp_lvt'
+PVTH0      = '-1.1688679e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.0023338612+dk2p_lvt'
+LK2        = '1.6149441e-009+dlk2p_lvt'
+WK2        = '4.3647633e-009+dwk2p_lvt'
+PK2        = '-2.814458e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00048392909+dcitp_lvt'
+LCIT       = '2.2639225e-010+dlcitp_lvt'
+WCIT       = '6.0085813e-011+dwcitp_lvt'
+PCIT       = '-1.3825145e-017+dpcitp_lvt'
+VOFF       = '-0.14449513+dvoffp_lvt'
+LVOFF      = '1.9341412e-009+dlvoffp_lvt'
+WVOFF      = '1.5688644e-008+dwvoffp_lvt'
+PVOFF      = '-1.520905e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36274136+deta0p_lvt'
+LETA0      = '-1.0793137e-012+dleta0p_lvt'
+WETA0      = '-2.6455314e-008+dweta0p_lvt'
+PETA0      = '4.5560816e-019+dpeta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011364291+du0p_lvt'
+LU0        = '-2.3258062e-010+dlu0p_lvt'
+WU0        = '-7.0188344e-010+dwu0p_lvt'
+PU0        = '1.4351657e-017+dpu0p_lvt'
+UA         = '-5.7550375e-011+duap_lvt'
+LUA        = '-7.6375221e-017+dluap_lvt'
+WUA        = '-3.7326763e-016+dwuap_lvt'
+PUA        = '2.399916e-023+dpuap_lvt'
+UB         = '1.1523993e-018+dubp_lvt'
+LUB        = '7.9458454e-026+dlubp_lvt'
+WUB        = '2.9323037e-025+dwubp_lvt'
+PUB        = '-3.785114e-032+dpubp_lvt'
+UC         = 1.9740141e-012      LUC        = 4.2400953e-018      WUC        = 9.5761559e-019
+PUC        = -5.4445175e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '0.16429284+da0p_lvt'
+LA0        = '2.5843822e-008+dla0p_lvt'
+WA0        = '1.453757e-006+dwa0p_lvt'
+PA0        = '-2.669636e-013+dpa0p_lvt'
+AGS        = '8.6744454+dagsp_lvt'
+LAGS       = '-5.7548087e-007+dlagsp_lvt'
+WAGS       = '-7.9514289e-008+dwagsp_lvt'
+PAGS       = '7.9161918e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10413855         LKETA      = 3.3694106e-009
+WKETA      = 1.3305248e-008      PKETA      = -1.0649841e-015     DWG        = 0
+DWB        = 0                   PCLM       = '1.2244921+dpclmp_lvt'
+LPCLM      = '-5.6353953e-009+dlpclmp_lvt'
+WPCLM      = '1.0083813e-007+dwpclmp_lvt'
+PPCLM      = '-2.3201846e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.070866338+dpdiblc2p_lvt'
+LPDIBLC2   = '-4.8658676e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-2.0588802e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '2.5491277e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017913715        LTVOFF     = -1.3893293e-012
+WTVOFF     = -5.2357608e-011     PTVOFF     = -2.2951261e-017
+KT1        = -0.23514196
+LKT1       = -5.3579814e-09
+WKT1       = -1.7955882e-08
+PKT1       = 8.090743e-16
+KT1L       = 0                   KT2        = -0.068827129        LKT2       = 9.8550525e-010
+WKT2       = 5.2082872e-009      PKT2       = -5.5014685e-016     UTE        = '-1.3098408+dutep_lvt'
+LUTE       = '3.0519317e-008+dlutep_lvt'
+WUTE       = '-3.1221879e-008+dwutep_lvt'
+PUTE       = '3.0753551e-015+dputep_lvt'
+UA1        = '1.3982017e-009+dua1p_lvt'
+LUA1       = '-1.4802841e-017+dlua1p_lvt'
+WUA1       = '-1.4749325e-016+dwua1p_lvt'
+PUA1       = '1.5981111e-023+dpua1p_lvt'
+UB1        = '-2.3054812e-018+dub1p_lvt'
+LUB1       = '7.5503531e-026+dlub1p_lvt'
+WUB1       = '3.7579549e-025+dwub1p_lvt'
+PUB1       = '-4.6903575e-032+dpub1p_lvt'
+UC1        = 1.074981e-010       LUC1       = -4.4010738e-019     WUC1       = -1.8078459e-017
+PUC1       = -6.9138538e-025     PRT        = 0                   AT         = '11083.534+datp_lvt'
+LAT        = '-0.0018797281+dlatp_lvt'
+WAT        = '0.01918411+dwatp_lvt'
+PAT        = '-1.8896348e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   WMAX       = '6e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.20377098+(dvthp_lvt+vthmisp_lvt)-0.0298825*ff_flag_lvt+0.0304485*ss_flag_lvt-0.0239059*sf_flag_lvt+0.0239059*fs_flag_lvt'
+LVTH0      = '-3.9813484e-009+dlvthp_lvt+2.94341e-09*ff_flag_lvt-2.99916e-09*ss_flag_lvt+2.35473e-09*sf_flag_lvt-2.35473e-09*fs_flag_lvt'
+WVTH0      = '-1.5923639e-008+dwvthp_lvt-6.73717e-09*ff_flag_lvt+1.12281e-09*ss_flag_lvt-5.38973e-09*sf_flag_lvt+5.38973e-09*fs_flag_lvt'
+PVTH0      = '1.0229745e-015+dpvthp_lvt+6.63608e-16*ff_flag_lvt-1.10599e-16*ss_flag_lvt+5.30883e-16*sf_flag_lvt-5.30883e-16*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0015527958+dk2p_lvt'
+LK2        = '1.9977798e-009+dlk2p_lvt'
+WK2        = '-1.5394737e-009+dwk2p_lvt'
+PK2        = '3.0012154e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.00080120866+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '2.5764428e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '-5.4489619e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '4.5765583e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.040953063+dvoffp_lvt-0.0445973*ff_flag_lvt+0.00996083*ss_flag_lvt-0.0356779*sf_flag_lvt+0.0300636*fs_flag_lvt'
+LVOFF      = '-8.264752e-009+dlvoffp_lvt+4.39282e-09*ff_flag_lvt-9.81134e-10*ss_flag_lvt+3.51425e-09*sf_flag_lvt-2.96125e-09*fs_flag_lvt'
+WVOFF      = '-1.2358927e-008+dwvoffp_lvt+4.4914e-09*ff_flag_lvt+2.24572e-09*ss_flag_lvt+3.59318e-09*sf_flag_lvt-1.79658e-09*fs_flag_lvt'
+PVOFF      = '1.2417808e-015+dpvoffp_lvt-4.42403e-16*ff_flag_lvt-2.21202e-16*ss_flag_lvt-3.53926e-16*sf_flag_lvt+1.76966e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt-1.73183*ff_flag_lvt+0.0*ss_flag_lvt-1.38546*sf_flag_lvt+0.332782*fs_flag_lvt'
+ETA0       = '0.12791292+deta0p_lvt+0.00797998*ff_flag_lvt+0.0169786*ss_flag_lvt+0.0126774*sf_flag_lvt+0.0155072*fs_flag_lvt'
+LETA0      = '2.3129522e-008+dleta0p_lvt-7.86025e-10*ff_flag_lvt-1.67239e-09*ss_flag_lvt-1.24872e-09*sf_flag_lvt-1.52746e-09*fs_flag_lvt'
+WETA0      = '-6.4276683e-008+dweta0p_lvt-3.36856e-09*ff_flag_lvt-4.4e-14*ss_flag_lvt-7.85999e-09*sf_flag_lvt-2.24571e-09*fs_flag_lvt'
+PETA0      = '3.7258605e-015+dpeta0p_lvt+3.31802e-16*ff_flag_lvt+5e-22*ss_flag_lvt+7.74207e-16*sf_flag_lvt+2.21202e-16*fs_flag_lvt'
+ETAB       = -0.19995624         LETAB      = 4.2114898e-009      WETAB      = 2.286949e-008
+PETAB      = -1.0801008e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0055557057+du0p_lvt-1.47151e-05*ff_flag_lvt-0.000816104*ss_flag_lvt-1.17719e-05*sf_flag_lvt+3.28257e-05*fs_flag_lvt'
+LU0        = '3.3956506e-010+dlu0p_lvt+1.44937e-12*ff_flag_lvt+8.03862e-11*ss_flag_lvt+1.15952e-12*sf_flag_lvt-3.23325e-12*fs_flag_lvt'
+WU0        = '9.1687561e-011+dwu0p_lvt-2.24571e-11*ff_flag_lvt+1.12284e-11*ss_flag_lvt-1.79657e-11*sf_flag_lvt+1.12285e-11*fs_flag_lvt'
+PU0        = '-6.3815086e-017+dpu0p_lvt+2.21202e-18*ff_flag_lvt-1.10596e-18*ss_flag_lvt+1.76962e-18*sf_flag_lvt-1.10601e-18*fs_flag_lvt'
+UA         = '-2.0770824e-009+duap_lvt'
+LUA        = '1.2254868e-016+dluap_lvt'
+WUA        = '2.4079799e-016+dwuap_lvt'
+PUA        = '-3.6486303e-023+dpuap_lvt'
+UB         = '3.0338164e-018+dubp_lvt'
+LUB        = '-1.0586113e-025+dlubp_lvt'
+WUB        = '-5.8470606e-025+dwubp_lvt'
+PUB        = '4.8625598e-032+dpubp_lvt'
+UC         = 5.3010594e-011      LUC        = -7.8700784e-019     WUC        = -1.4439428e-017
+PUC        = 9.7215703e-025
+VSAT       = '101362.36+dvsatp_lvt+1528.08*ff_flag_lvt-13922.5*ss_flag_lvt+1222.47*sf_flag_lvt-1222.47*fs_flag_lvt'
+LVSAT      = '-0.00058532244+dlvsatp_lvt-0.000150515*ff_flag_lvt+0.00137136*ss_flag_lvt-0.000120412*sf_flag_lvt+0.000120412*fs_flag_lvt'
+WVSAT      = '0.0020210815+dwvsatp_lvt+0.00168428*ff_flag_lvt+0.00336857*ss_flag_lvt+0.00134743*sf_flag_lvt-0.00134743*fs_flag_lvt'
+PVSAT      = '-1.9907653e-010+dpvsatp_lvt-1.65902e-10*ff_flag_lvt-3.31803e-10*ss_flag_lvt-1.32721e-10*sf_flag_lvt+1.32721e-10*fs_flag_lvt'
+A0         = '-0.54674847+da0p_lvt'
+LA0        = '9.5881391e-008+dla0p_lvt'
+WA0        = '-3.3898971e-006+dwa0p_lvt'
+PA0        = '2.1013633e-013+dpa0p_lvt'
+AGS        = '-1.6414085+dagsp_lvt'
+LAGS       = '4.4063074e-007+dlagsp_lvt'
+WAGS       = '1.6639629e-006+dwagsp_lvt'
+PAGS       = '-9.2570584e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.18027688         LKETA      = 1.0869036e-008
+WKETA      = -3.9978133e-009     PKETA      = 6.3936744e-016      DWG        = 0
+DWB        = 0                   PCLM       = '2.0398674+dpclmp_lvt'
+LPCLM      = '-8.5949863e-008+dlpclmp_lvt'
+WPCLM      = '-3.072915e-007+dwpclmp_lvt'
+PPCLM      = '1.6998923e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.03456476+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.2901622e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.2959548e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-7.5538481e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0026786944        LTVOFF     = -8.8790628e-011
+WTVOFF     = -7.9793405e-010     PTVOFF     = 5.0488019e-017
+KT1        = '-0.17394713+0.0350892*ff_flag_lvt+0.0280714*sf_flag_lvt-0.0280714*fs_flag_lvt'
+LKT1       = '-1.1385656e-08-3.45628e-09*ff_flag_lvt-2.76502e-09*sf_flag_lvt+2.76502e-09*fs_flag_lvt'
+WKT1       = '-2.0825425e-08-1.12286e-08*ff_flag_lvt-8.98284e-09*sf_flag_lvt+8.98284e-09*fs_flag_lvt'
+PKT1       = '1.0917144e-15+1.10601e-15*ff_flag_lvt+8.84808e-16*sf_flag_lvt-8.84808e-16*fs_flag_lvt'
+KT1L       = 0                   KT2        = -0.0502518          LKT2       = -8.4416474e-010
+WKT2       = -8.2725695e-010     PKT2       = 4.435425e-017       UTE        = '-1+dutep_lvt'
+UA1        = '1.2100567e-009+dua1p_lvt'
+LUA1       = '3.7294345e-018+dlua1p_lvt'
+WUA1       = '-9.4462998e-018+dwua1p_lvt'
+PUA1       = '2.3834868e-024+dpua1p_lvt'
+UB1        = '-1.3247201e-018+dub1p_lvt'
+LUB1       = '-2.1101433e-026+dlub1p_lvt'
+WUB1       = '-3.7094907e-025+dwub1p_lvt'
+PUB1       = '2.6650764e-032+dpub1p_lvt'
+UC1        = 9.9012965e-011      LUC1       = 3.9567797e-019      WUC1       = -6.1544436e-017
+PUC1       = 3.5900133e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+1.70585e-07*ff_flag_lvt+0.0*ss_flag_lvt+1.36468e-07*sf_flag_lvt-3.27789e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+3.36857e-07*ff_flag_lvt+0.0*ss_flag_lvt+2.69485e-07*sf_flag_lvt+6.73718e-08*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt-3.31803e-14*ff_flag_lvt+0.0*ss_flag_lvt-2.65442e-14*sf_flag_lvt-6.6361e-15*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_lvt+dwmisp_lvt)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = '(toxp_lvt+toxmisp_lvt)'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23207797+(dvthp_lvt+vthmisp_lvt)'
+WVTH0      = '-6.0987967e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.021475556+dk2p_lvt'
+WK2        = '3.2654222e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.077578135+dvoffp_lvt'
+WVOFF      = '1.9082672e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01049+du0p_lvt'  WU0        = '1.792e-010+dwu0p_lvt'
+UA         = '-3.0587778e-010+duap_lvt'
+WUA        = '-7.7031111e-017+dwuap_lvt'
+UB         = '1.5348392e-018+dubp_lvt'
+WUB        = '2.4605392e-026+dwubp_lvt'
+UC         = 1.3196289e-011      WUC        = -1.8138524e-018     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.2035556+da0p_lvt'
+WA0        = '2.1454222e-007+dwa0p_lvt'
+AGS        = '0.942204+dagsp_lvt'
+WAGS       = '-1.981056e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.026827778        WKETA      = 2.5560889e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00017273244+dpdiblc2p_lvt'
+WPDIBLC2   = '8.6418254e-010+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0011656           LTVOFF     = 0
+WTVOFF     = -1.33728e-010       PTVOFF     = 0                   KT1        = -0.225106
+WKT1       = -5.799808e-009      KT1L       = 0                   KT2        = -0.037973333
+WKT2       = 7.2426667e-010      UTE        = '-1.5163333+dutep_lvt'
+WUTE       = '-2.6133333e-008+dwutep_lvt'
+UA1        = '8.7548773e-010+dua1p_lvt'
+WUA1       = '-4.1181851e-017+dwua1p_lvt'
+UB1        = '-1.2078251e-018+dub1p_lvt'
+WUB1       = '6.7916763e-026+dwub1p_lvt'
+UC1        = -1.3583333e-011     WUC1       = -3.3301333e-018     PRT        = 0
+AT         = '164444.44+datp_lvt'
+WAT        = '0.0049777778+dwatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999994e-006-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23167235+(dvthp_lvt+vthmisp_lvt)+0.000208293*ff_flag_lvt+0.000208293*ss_flag_lvt'
+LVTH0      = '-4.0415773e-009+dlvthp_lvt-2.07545e-09*ff_flag_lvt-2.07545e-09*ss_flag_lvt'
+WVTH0      = '-5.9247948e-009+dwvthp_lvt-6.66538e-11*ff_flag_lvt-6.66538e-11*ss_flag_lvt'
+PVTH0      = '-1.7337731e-015+dpvthp_lvt+6.64145e-16*ff_flag_lvt+6.64145e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.022358933+dk2p_lvt'
+LK2        = '-8.8020613e-009+dlk2p_lvt'
+WK2        = '3.283712e-009+dwk2p_lvt'
+PK2        = '-1.822415e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-2.7232634e-005+dcitp_lvt'
+LCIT       = '1.2677587e-009+dlcitp_lvt'
+WCIT       = '1.1813724e-011+dwcitp_lvt'
+PCIT       = '-1.1771313e-016+dpcitp_lvt'
+VOFF       = '-0.078145166+dvoffp_lvt'
+LVOFF      = '5.6499486e-009+dlvoffp_lvt'
+WVOFF      = '2.2204984e-009+dwvoffp_lvt'
+PVOFF      = '-3.1111031e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010637138+du0p_lvt'
+LU0        = '-1.466101e-009+dlu0p_lvt'
+WU0        = '1.8154622e-010+dwu0p_lvt'
+PU0        = '-2.3377918e-017+dpu0p_lvt'
+UA         = '-2.4629273e-010+duap_lvt'
+LUA        = '-5.9371136e-016+dluap_lvt'
+WUA        = '-8.1063508e-017+dwuap_lvt'
+PUA        = '4.0179203e-023+dpuap_lvt'
+UB         = '1.4877119e-018+dubp_lvt'
+LUB        = '4.6958144e-025+dlubp_lvt'
+WUB        = '3.1038034e-026+dwubp_lvt'
+PUB        = '-6.409549e-032+dpubp_lvt'
+UC         = 1.4512412e-011      LUC        = -1.3113978e-017     WUC        = -1.9231061e-018
+PUC        = 1.088614e-024       VSAT       = '95420+dvsatp_lvt'  A0         = '3.1571597+da0p_lvt'
+LA0        = '4.6229264e-007+dla0p_lvt'
+WA0        = '2.5832046e-007+dwa0p_lvt'
+PA0        = '-4.362107e-013+dpa0p_lvt'
+AGS        = '0.87347719+dagsp_lvt'
+LAGS       = '6.848008e-007+dlagsp_lvt'
+WAGS       = '-1.7346928e-008+dwagsp_lvt'
+PAGS       = '-2.4547877e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025882365        LKETA      = -9.4201909e-009
+WKETA      = 2.6371399e-009      PKETA      = -8.0760081e-016     DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '-0.0026557284+dpdiblc2p_lvt'
+LPDIBLC2   = '2.474082e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.1283693e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '-2.6323831e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0012700025        LTVOFF     = -1.040277e-009
+WTVOFF     = -1.5159123e-010     PTVOFF     = 1.7799097e-016      KT1        = -0.21244842
+LKT1       = -1.2612135e-007     WKT1       = -6.9199922e-009     PKT1       = 1.1161628e-014
+KT1L       = 0                   KT2        = -0.036235811        LKT2       = -1.7312847e-008
+WKT2       = 6.7147684e-010      PKT2       = 5.2600316e-016      UTE        = '-1.5140957+dutep_lvt'
+LUTE       = '-2.229631e-008+dlutep_lvt'
+WUTE       = '-2.6986502e-008+dwutep_lvt'
+PUTE       = '8.5010611e-015+dputep_lvt'
+UA1        = '8.8114204e-010+dua1p_lvt'
+LUA1       = '-5.6340082e-017+dlua1p_lvt'
+WUA1       = '-4.4916912e-017+dwua1p_lvt'
+PUA1       = '3.7216523e-023+dpua1p_lvt'
+UB1        = '-1.1839841e-018+dub1p_lvt'
+LUB1       = '-2.3755459e-025+dlub1p_lvt'
+WUB1       = '7.5486335e-026+dwub1p_lvt'
+PUB1       = '-7.5423968e-032+dpub1p_lvt'
+UC1        = -1.6683093e-011     LUC1       = 3.0886319e-017      WUC1       = -3.160566e-018
+PUC1       = -1.6895859e-024     PRT        = 0                   AT         = '158612.24+datp_lvt'
+LAT        = '0.058112722+dlatp_lvt'
+WAT        = '0.0068440849+dwatp_lvt'
+PAT        = '-1.8596071e-008+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '9.999943e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22994433+(dvthp_lvt+vthmisp_lvt)-0.00255397*ff_flag_lvt-0.00255397*ss_flag_lvt'
+LVTH0      = '-5.7075599e-009+dlvthp_lvt+5.87642e-10*ff_flag_lvt+5.87642e-10*ss_flag_lvt'
+WVTH0      = '-8.8370624e-009+dwvthp_lvt+8.1727e-10*ff_flag_lvt+8.1727e-10*ss_flag_lvt'
+PVTH0      = '1.0739442e-015+dpvthp_lvt-1.88045e-16*ff_flag_lvt-1.88045e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.014372997+dk2p_lvt'
+LK2        = '-1.1028208e-009+dlk2p_lvt'
+WK2        = '3.1027984e-009+dwk2p_lvt'
+PK2        = '-7.8227004e-018+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.001534664+dcitp_lvt'
+LCIT       = '-2.3806584e-010+dlcitp_lvt'
+WCIT       = '-1.4485296e-010+dwcitp_lvt'
+PCIT       = '3.3329217e-017+dpcitp_lvt'
+VOFF       = '-0.058857695+dvoffp_lvt'
+LVOFF      = '-1.2945101e-008+dlvoffp_lvt'
+WVOFF      = '-2.0642663e-009+dwvoffp_lvt'
+PVOFF      = '1.0198385e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0094906926+du0p_lvt'
+LU0        = '-3.6081265e-010+dlu0p_lvt'
+WU0        = '1.6322723e-010+dwu0p_lvt'
+PU0        = '-5.7165888e-018+dpu0p_lvt'
+UA         = '-8.0920554e-010+duap_lvt'
+LUA        = '-5.1007123e-017+dluap_lvt'
+WUA        = '-3.1762255e-017+dwuap_lvt'
+PUA        = '-7.3521349e-024+dpuap_lvt'
+UB         = '2.0311877e-018+dubp_lvt'
+LUB        = '-5.4383563e-026+dlubp_lvt'
+WUB        = '-5.7104497e-026+dwubp_lvt'
+PUB        = '2.0882724e-032+dpubp_lvt'
+UC         = -5.4948441e-012     LUC        = 6.1750173e-018      WUC        = -5.0692306e-019
+PUC        = -2.7672803e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '4.4161338+da0p_lvt'
+LA0        = '-7.5148428e-007+dla0p_lvt'
+WA0        = '-2.5937296e-007+dwa0p_lvt'
+PA0        = '6.289752e-014+dpa0p_lvt'
+AGS        = '-0.54071184+dagsp_lvt'
+LAGS       = '2.0482204e-006+dlagsp_lvt'
+WAGS       = '8.0305347e-008+dwagsp_lvt'
+PAGS       = '-1.1869444e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021041111        LKETA      = -1.4087644e-008
+WKETA      = 3.6859525e-010      PKETA      = 1.3795031e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.1532519+dpclmp_lvt'
+LPCLM      = '-1.4775018e-007+dlpclmp_lvt'
+WPCLM      = '3.1207664e-008+dwpclmp_lvt'
+PPCLM      = '-3.0087309e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.023948764+dpdiblc2p_lvt'
+LPDIBLC2   = '-9.0857103e-010+dlpdiblc2p_lvt'
+WPDIBLC2   = '-2.1042251e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '4.8416115e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = -0.000116633        LTVOFF     = 2.9657826e-010
+WTVOFF     = 2.9571307e-011      PTVOFF     = 3.3321695e-018      KT1        = -0.35276219
+LKT1       = 9.1551518e-009      WKT1       = 5.1721695e-009      PKT1       = -4.9642556e-016
+KT1L       = 0                   KT2        = -0.051379872        LKT2       = -2.7124582e-009
+WKT2       = 8.5341936e-010      PKT2       = 3.5059237e-016      UTE        = '-1.6325867+dutep_lvt'
+LUTE       = '9.1940907e-008+dlutep_lvt'
+WUTE       = '-2.3864288e-008+dwutep_lvt'
+PUTE       = '5.490934e-015+dputep_lvt'
+UA1        = '7.282847e-010+dua1p_lvt'
+LUA1       = '9.1029681e-017+dlua1p_lvt'
+WUA1       = '-4.8923549e-018+dwua1p_lvt'
+PUA1       = '-1.3711525e-024+dpua1p_lvt'
+UB1        = '-1.4400093e-018+dub1p_lvt'
+LUB1       = '9.2793775e-027+dlub1p_lvt'
+WUB1       = '4.3748835e-028+dwub1p_lvt'
+PUB1       = '-3.0693749e-033+dpub1p_lvt'
+UC1        = 7.7213875e-012      LUC1       = 7.3579589e-018      WUC1       = -6.4531649e-018
+PUC1       = 1.4848087e-024      PRT        = 0                   AT         = '273160.97+datp_lvt'
+LAT        = '-0.052323711+dlatp_lvt'
+WAT        = '-0.015487192+dwatp_lvt'
+PAT        = '2.9335127e-009+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+LMAX       = '2.399901e-007-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.26672322+(dvthp_lvt+vthmisp_lvt)'
+LVTH0      = '2.7548946e-009+dlvthp_lvt'
+WVTH0      = '-1.8430616e-009+dwvthp_lvt'
+PVTH0      = '-5.3530549e-016+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.004357706+dk2p_lvt'
+LK2        = '1.2015976e-009+dlk2p_lvt'
+WK2        = '3.717133e-009+dwk2p_lvt'
+PK2        = '-1.4917493e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00033261947+dcitp_lvt'
+LCIT       = '1.9157741e-010+dlcitp_lvt'
+WCIT       = '1.1666733e-011+dwcitp_lvt'
+PCIT       = '-2.6843986e-018+dpcitp_lvt'
+VOFF       = '-0.11135937+dvoffp_lvt'
+LVOFF      = '-8.6499066e-010+dlvoffp_lvt'
+WVOFF      = '5.0852027e-009+dwvoffp_lvt'
+PVOFF      = '-6.2518281e-016+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339522+deta0p_lvt'
+LETA0      = '7.654707e-014+dleta0p_lvt'
+WETA0      = '-2.986455e-008+dweta0p_lvt'
+PETA0      = '8.5732718e-020+dpeta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0086965429+du0p_lvt'
+LU0        = '-1.7808676e-010+dlu0p_lvt'
+WU0        = '1.5179601e-010+dwu0p_lvt'
+PU0        = '-3.0863779e-018+dpu0p_lvt'
+UA         = '-1.0842845e-009+duap_lvt'
+LUA        = '1.2285805e-017+dluap_lvt'
+WUA        = '-4.4712693e-017+dwuap_lvt'
+PUA        = '-4.3723686e-024+dpuap_lvt'
+UB         = '2.1266618e-018+dubp_lvt'
+LUB        = '-7.6351201e-026+dlubp_lvt'
+WUB        = '-1.8533615e-026+dwubp_lvt'
+PUB        = '1.200795e-032+dpubp_lvt'
+UC         = 1.1100322e-011      LUC        = 2.3566355e-018      WUC        = -1.962803e-018
+PUC        = 5.8255382e-026      VSAT       = '95420+dvsatp_lvt'  A0         = '5.0674997+da0p_lvt'
+LA0        = '-9.0135705e-007+dla0p_lvt'
+WA0        = '-1.1526917e-007+dwa0p_lvt'
+PA0        = '2.974068e-014+dpa0p_lvt'
+AGS        = '10.168412+dagsp_lvt'
+LAGS       = '-4.1584196e-007+dlagsp_lvt'
+WAGS       = '-5.5758374e-007+dwagsp_lvt'
+PAGS       = '2.8077465e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.06629674         LKETA      = -3.674776e-009
+WKETA      = 1.1958692e-009      PKETA      = 1.1891557e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.9098153+dpclmp_lvt'
+LPCLM      = '-9.1737836e-008+dlpclmp_lvt'
+WPCLM      = '-1.1846527e-007+dwpclmp_lvt'
+PPCLM      = '4.3509354e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.010601701+dpdiblc2p_lvt'
+LPDIBLC2   = '2.1624547e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-1.304118e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '3.0006451e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0021459306        LTVOFF     = -2.24015e-010
+WTVOFF     = -1.6581652e-010     PTVOFF     = 4.8288953e-017
+KT1        = -0.29052289
+LKT1       = -5.1654891e-09
+WKT1       = -2.33983e-10
+PKT1       = 7.474767e-16
+KT1L       = 0                   KT2        = -0.053663548        LKT2       = -2.1870072e-009
+WKT2       = 3.5594117e-010      PKT2       = 4.6505713e-016      UTE        = '-1.4074092+dutep_lvt'
+LUTE       = '4.0129801e-008+dlutep_lvt'
+UA1        = '9.9069073e-010+dua1p_lvt'
+LUA1       = '3.0652677e-017+dlua1p_lvt'
+WUA1       = '-1.7089746e-017+dwua1p_lvt'
+PUA1       = '1.4353453e-024+dpua1p_lvt'
+UB1        = '-1.0503232e-018+dub1p_lvt'
+LUB1       = '-8.038351e-026+dlub1p_lvt'
+WUB1       = '-2.5855062e-026+dwub1p_lvt'
+PUB1       = '2.980278e-033+dpub1p_lvt'
+UC1        = 5.1002911e-011      LUC1       = -2.6006867e-018     PRT        = 0
+AT         = '85993.585+datp_lvt'
+LAT        = '-0.0092583681+dlatp_lvt'
+WAT        = '-0.0047871061+dwatp_lvt'
+PAT        = '4.7152995e-010+dpatp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'      LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_lvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-(dxlp_lvt+dlmisp_lvt)'
+WMIN       = 1.2e-07             WMAX       = '3e-007-(dxwp_lvt+dwmisp_lvt)'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = '(toxp_lvt+toxmisp_lvt)'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+(dxlp_lvt+dlmisp_lvt)'    XW         = '2e-08+(dxwp_lvt+dwmisp_lvt)'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23029373+(dvthp_lvt+vthmisp_lvt)-0.0641416*ff_flag_lvt+0.0339573*ss_flag_lvt-0.0513133*sf_flag_lvt+0.0513133*fs_flag_lvt'
+LVTH0      = '-8.3341025e-010+dlvthp_lvt+6.31793e-09*ff_flag_lvt-3.34479e-09*ss_flag_lvt+5.05435e-09*sf_flag_lvt-5.05435e-09*fs_flag_lvt'
+WVTH0      = '-7.4363591e-009+dwvthp_lvt+4.2258e-09*ff_flag_lvt+1.1e-15*ss_flag_lvt+3.38062e-09*sf_flag_lvt-3.38062e-09*fs_flag_lvt'
+PVTH0      = '1.5634322e-017+dpvthp_lvt-4.1624e-16*ff_flag_lvt-2.8e-22*ss_flag_lvt-3.32992e-16*sf_flag_lvt+3.32992e-16*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.01476424+dk2p_lvt'
+LK2        = '3.0851093e-009+dlk2p_lvt'
+WK2        = '2.6881883e-009+dwk2p_lvt'
+PK2        = '-4.7823884e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0033642604+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.9019404e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '2.7528035e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-2.865034e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.056041086+dvoffp_lvt-0.0226382*ff_flag_lvt-0.00547089*ss_flag_lvt-0.0170541*sf_flag_lvt+0.0170541*fs_flag_lvt'
+LVOFF      = '-6.3138418e-009+dlvoffp_lvt+2.22986e-09*ff_flag_lvt+5.38886e-10*ss_flag_lvt+1.67983e-09*sf_flag_lvt-1.67983e-09*fs_flag_lvt'
+WVOFF      = '-7.5307595e-009+dwvoffp_lvt-2.53548e-09*ff_flag_lvt+7.18386e-09*ss_flag_lvt-2.36645e-09*sf_flag_lvt+2.36645e-09*fs_flag_lvt'
+PVOFF      = '6.1748948e-016+dpvoffp_lvt+2.49744e-16*ff_flag_lvt-7.07608e-16*ss_flag_lvt+2.33094e-16*sf_flag_lvt-2.33094e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt-1.20737*ff_flag_lvt+0.0*ss_flag_lvt-0.965897*sf_flag_lvt+0.965897*fs_flag_lvt'
+ETA0       = '-0.056142859+deta0p_lvt+0.0218836*ff_flag_lvt+0.0301843*ss_flag_lvt+3e-09*sf_flag_lvt-0.0060369*fs_flag_lvt'
+LETA0      = '4.2309578e-008+dleta0p_lvt-2.15553e-09*ff_flag_lvt-2.97314e-09*ss_flag_lvt-7e-16*sf_flag_lvt+5.94631e-10*fs_flag_lvt'
+WETA0      = '-5.3788334e-009+dweta0p_lvt-7.81773e-09*ff_flag_lvt-4.2258e-09*ss_flag_lvt-3.80322e-09*sf_flag_lvt+4.64838e-09*fs_flag_lvt'
+PETA0      = '-2.4117574e-015+dpeta0p_lvt+7.70044e-16*ff_flag_lvt+4.1624e-16*ss_flag_lvt+3.74616e-16*sf_flag_lvt-4.57864e-16*fs_flag_lvt'
+ETAB       = -0.14145277         LETAB      = 9.7925374e-010      WETAB      = 4.1483802e-009
+PETAB      = -4.5785222e-017     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.004826651+du0p_lvt-0.000216949*ff_flag_lvt-0.000199974*ss_flag_lvt-0.00017356*sf_flag_lvt+0.00017356*fs_flag_lvt'
+LU0        = '2.030976e-010+dlu0p_lvt+2.13695e-11*ff_flag_lvt+1.96975e-11*ss_flag_lvt+1.70956e-11*sf_flag_lvt-1.70956e-11*fs_flag_lvt'
+WU0        = '3.2498504e-010+dwu0p_lvt+4.2258e-11*ff_flag_lvt-1.85935e-10*ss_flag_lvt+3.38064e-11*sf_flag_lvt-3.38064e-11*fs_flag_lvt'
+PU0        = '-2.0145498e-017+dpu0p_lvt-4.1624e-18*ff_flag_lvt+1.83146e-17*ss_flag_lvt-3.32992e-18*sf_flag_lvt+3.32992e-18*fs_flag_lvt'
+UA         = '-7.1760304e-010+duap_lvt'
+LUA        = '-2.3832323e-017+dluap_lvt'
+WUA        = '-1.942354e-016+dwuap_lvt'
+PUA        = '1.0355618e-023+dpuap_lvt'
+UB         = '1.1232978e-019+dubp_lvt'
+LUB        = '1.220605e-025+dlubp_lvt'
+WUB        = '3.5016965e-025+dwubp_lvt'
+PUB        = '-2.4309322e-032+dpubp_lvt'
+UC         = 1.9449027e-011      LUC        = 1.5342881e-018      WUC        = -3.6997264e-018
+PUC        = 2.2934234e-025
+VSAT       = '117212.43+dvsatp_lvt+5470.89*ff_flag_lvt-6036.86*ss_flag_lvt+4376.72*sf_flag_lvt-4376.72*fs_flag_lvt'
+LVSAT      = '-0.0021465539+dlvsatp_lvt-0.000538885*ff_flag_lvt+0.000594629*ss_flag_lvt-0.000431106*sf_flag_lvt+0.000431106*fs_flag_lvt'
+WVSAT      = '-0.0030509396+dwvsatp_lvt+0.00042258*ff_flag_lvt+0.00084516*ss_flag_lvt+0.00033806*sf_flag_lvt-0.00033806*fs_flag_lvt'
+PVSAT      = '3.0051755e-010+dpvsatp_lvt-4.16241e-11*ff_flag_lvt-8.3248e-11*ss_flag_lvt-3.32991e-11*sf_flag_lvt+3.32991e-11*fs_flag_lvt'
+A0         = '-17.084839+da0p_lvt'
+LA0        = '1.2806483e-006+dla0p_lvt'
+WA0        = '1.902292e-006+dwa0p_lvt'
+PA0        = '-1.6898909e-013+dpa0p_lvt'
+AGS        = '8.8272963+dagsp_lvt'
+LAGS       = '-2.8374202e-007+dlagsp_lvt'
+WAGS       = '-1.6860227e-006+dwagsp_lvt'
+PAGS       = '1.392287e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.30463264         LKETA      = 1.980131e-008
+WKETA      = 3.5796028e-008      PKETA      = -2.21896e-015       DWG        = 0
+DWB        = 0                   PCLM       = '1.4395749+dpclmp_lvt'
+LPCLM      = '-4.5419164e-008+dlpclmp_lvt'
+WPCLM      = '-1.151979e-007+dwpclmp_lvt'
+PPCLM      = '4.0290996e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.091843329+dpdiblc2p_lvt'
+LPDIBLC2   = '-5.8398456e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-5.369594e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '7.005139e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = -0.0025499865       LTVOFF     = 2.3853283e-010
+WTVOFF     = 8.7524381e-010      PTVOFF     = -5.4255488e-017
+KT1        = -0.28244227
+LKT1       = -5.9614337e-09
+WKT1       = 1.3893019e-08
+PKT1       = -6.440366e-16
+KT1L       = 0                   KT2        = -0.059474552        LKT2       = -1.6146233e-009
+WKT2       = 2.1240238e-009      PKT2       = 2.9090099e-016      UTE        = '-1+dutep_lvt'
+UA1        = '1.2992311e-009+dua1p_lvt'
+LUA1       = '2.6145406e-019+dlua1p_lvt'
+WUA1       = '-3.7982084e-017+dwua1p_lvt'
+PUA1       = '3.4932406e-024+dpua1p_lvt'
+UB1        = '-2.5120633e-018+dub1p_lvt'
+LUB1       = '6.3597893e-026+dlub1p_lvt'
+WUB1       = '9.0007619e-027+dwub1p_lvt'
+PUB1       = '-4.5302063e-034+dpub1p_lvt'
+UC1        = -2.1750872e-010     LUC1       = 2.3847709e-017      WUC1       = 3.9742503e-017
+PUC1       = -3.9146365e-024     PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiapmac_lvt'
+NOIB       = 'noibpmac_lvt'
+NOIC       = 'noicpmac_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+1.18926e-07*ff_flag_lvt+0.0*ss_flag_lvt+9.51406e-08*sf_flag_lvt-9.51406e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+1.69032e-07*ff_flag_lvt+0.0*ss_flag_lvt+1.35226e-07*sf_flag_lvt-1.35226e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt-1.66496e-14*ff_flag_lvt+0.0*ss_flag_lvt-1.33197e-14*sf_flag_lvt+1.33197e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1 
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_lvt_mac

.ENDL MAC_lvt








.LIB MAC_18
**********************************************************************************************
*                                                                                            *
*                                   1.8V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_18_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwn_18'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_18 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_18  temp2=parn2_18
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_18='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisn_18='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_18='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_18='0.00275107*geo_fac*toxn_18*fac2*mismatchflag' 
.param tnoiax='6.365e4/(l*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(l*scale*1e6)+0.5356'

.param fn_dice='noiseflagn_18_mc*par1fn_mc+noiseflagn_18_mc_mis*par2fn_18_mc'
.param arearatio='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noianmac_18='c1fn_18*2.718**((fn_dice+(1-fn_dice)*noiseflagn_18)*arearatio)'
.param noibnmac_18='c2fn_18*2.718**((fn_dice+(1-fn_dice)*noiseflagn_18)*arearatio)'
.param noicnmac_18='c3fn_18*2.718**((fn_dice+(1-fn_dice)*noiseflagn_18)*arearatio)'

.MODEL nch_18.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_18+dlmisn_18)'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-(dxwn_18+dwmisn_18)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+(dvthn_18+vthmisn_18)'
+K1         = 0.71631             K2         = '-0.048803+dk2n_18' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_18'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_18'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_18'   A0         = '1.1773+da0n_18'    AGS        = '0.3986+dagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       WVTH0      = '0+dwvthn_18'
+PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       LA0        = '0+dla0n_18'        WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'       WAGS       = '0+dwagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      WETA0      = '0+dweta0n_18'
+PETA0      = '0+dpeta0n_18'      LK2        = '0+dlk2n_18'        WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_18+dlmisn_18)'
+LMAX       = '1e-005-(dxln_18+dlmisn_18)'    WMIN       = '1e-005-(dxwn_18+dwmisn_18)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.4790281e-008+dlvthn_18'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_18'
+LK2        = '-1.2153578e-008+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_18'
+LCIT       = '7.5887589e-010+dlcitn_18'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_18'
+LU0        = '2.6891421e-011+dlu0n_18'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.2321467+da0n_18' LA0        = '-5.4764378e-007+dla0n_18'
+AGS        = '0.38027424+dagsn_18'
+LAGS       = '1.8298267e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'        WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'        PA0        = '0+dpa0n_18'
+WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'
+WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_18+dlmisn_18)'
+LMAX       = '1.2e-006-(dxln_18+dlmisn_18)'  WMIN       = '1e-005-(dxwn_18+dwmisn_18)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+(dvthn_18+vthmisn_18)'
+LVTH0      = '3.2469e-010+dlvthn_18'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_18'
+LK2        = '-6.7649162e-009+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_18'
+LCIT       = '5.941827e-011+dlcitn_18'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_18'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_18'
+A0         = '1.3065331+da0n_18' LA0        = '-6.3579172e-007+dla0n_18'
+AGS        = '0.9247153+dagsn_18'
+LAGS       = '-4.6217998e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'
+WCIT       = '0+dwcitn_18'       PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'
+LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'
+LETA0      = '0+dleta0n_18'      WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'
+WK2        = '0+dwk2n_18'        PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.4 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_18+dlmisn_18)'
+LMAX       = '7e-007-(dxln_18+dlmisn_18)'    WMIN       = '1e-005-(dxwn_18+dwmisn_18)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59985+(dvthn_18+vthmisn_18)'
+LVTH0      = '-2.50025e-009+dlvthn_18'
+K1         = 0.71631             K2         = '-0.060148641+dk2n_18'
+LK2        = '-1.2743462e-009+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00063515313+dcitn_18'
+LCIT       = '1.1360511e-010+dlcitn_18'
+VOFF       = -0.14569953         LVOFF      = 1.2165279e-008      NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_18'   UA         = -6.221e-010
+LUA        = -1.650165e-016      UB         = 2.8987125e-018      LUB        = 6.9381938e-026
+UC         = 1.8519984e-010      LUC        = -1.7056393e-017     VSAT       = '89640+dvsatn_18'
+A0         = '1.1521358+da0n_18' LA0        = '-5.3002956e-007+dla0n_18'
+AGS        = '-2.0187031+dagsn_18'
+LAGS       = '1.5540616e-006+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.053365313        LKETA      = 1.4642089e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.268725+dpclmn_18'
+LPCLM      = '-1.6251625e-008+dlpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00478125          LPDIBLC2   = -1.5626563e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0011922813        LTVOFF     = 1.4845234e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29436875         LKT1       = 5.9380938e-009
+KT1L       = 0                   KT2        = -0.055789375        LKT2       = -2.7815281e-009
+UTE        = -1.3999688          LUTE       = 1.1094859e-007      UA1        = 2.5822766e-009
+LUA1       = 2.1799055e-017      UB1        = -3.2810594e-018     LUB1       = 9.4228172e-026
+UC1        = -4.6245625e-011     LUC1       = 4.3535603e-017      PRT        = 0
+AT         = 14157.766           LAT        = -0.0055325845
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'
+WCIT       = '0+dwcitn_18'       PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.5 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxln_18+dlmisn_18)'  WMIN       = '1e-005-(dxwn_18+dwmisn_18)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55216667+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.4904167e-008+dlvthn_18'
+K1         = 0.71631             K2         = '-0.11018183+dk2n_18'
+LK2        = '1.6987769e-008+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00098580417+dcitn_18'
+LCIT       = '-1.4382521e-011+dlcitn_18'
+VOFF       = -0.082500417        LVOFF      = -1.0902398e-008     NFACTOR    = 0.55
+ETA0       = '0.51692083+deta0n_18'
+LETA0      = '3.2043958e-009+dleta0n_18'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04639875+du0n_18'
+LU0        = '-2.8392438e-009+dlu0n_18'
+UA         = -1.5034583e-010     LUA        = -3.3720677e-016     UB         = 1.854e-018
+LUB        = 4.50702e-025        UC         = 2.3945083e-010      LUC        = -3.6858004e-017
+VSAT       = '108015+dvsatn_18'  LVSAT      = '-0.006706875+dlvsatn_18'
+A0         = '0.472975+da0n_18'  LA0        = '-2.8213588e-007+dla0n_18'
+AGS        = '3.9374625+dagsn_18'
+LAGS       = '-6.1993881e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067201042        LKETA      = 1.969213e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.0075291667+dpclmn_18'
+LPCLM      = '8.4581146e-008+dlpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015416667       LPDIBLC2   = 7.4520833e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0012294583        LTVOFF     = 1.3488271e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.35874583         LKT1       = 2.9435729e-008
+KT1L       = 0                   KT2        = -0.13942125         LKT2       = 2.7744106e-008
+UTE        = -1.292              LUTE       = 7.154e-008          UA1        = 3.4635667e-009
+LUA1       = -2.9987183e-016     UB1        = -4.2291167e-018     LUB1       = 4.4026908e-025
+UC1        = 9.5549583e-011      LUC1       = -8.2196479e-018     PRT        = 0
+AT         = -37750              LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'        WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'        PA0        = '0+dpa0n_18'
+WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'       WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_18+dlmisn_18)'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-(dxwn_18+dwmisn_18)'    WMAX       = '1e-005-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+(dvthn_18+vthmisn_18)'
+WVTH0      = '-1.9034426e-009+dwvthn_18'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_18'
+WK2        = '8.915949e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_18'
+WCIT       = '3.148518e-010+dwcitn_18'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_18'
+WU0        = '-6.4829015e-009+dwu0n_18'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.1644663+da0n_18' WA0        = '1.2842639e-007+dwa0n_18'
+AGS        = '0.4003119+dagsn_18'
+WAGS       = '-1.7130983e-008+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       PCIT       = '0+dpcitn_18'
+LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'
+LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_18+dlmisn_18)'
+LMAX       = '1e-005-(dxln_18+dlmisn_18)'    WMIN       = '1e-006-(dxwn_18+dwmisn_18)'    WMAX       = '1e-005-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.6445149e-008+dlvthn_18'
+WVTH0      = '-2.4492827e-010+dwvthn_18'
+PVTH0      = '-1.6560265e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_18'
+LK2        = '-1.2004489e-008+dlk2n_18'
+WK2        = '9.0653661e-009+dwk2n_18'
+PK2        = '-1.4919294e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_18'
+LCIT       = '8.1447946e-010+dlcitn_18'
+WCIT       = '3.7057788e-010+dwcitn_18'
+PCIT       = '-5.5642492e-016+dpcitn_18'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_18'
+LU0        = '1.1847165e-011+dlu0n_18'
+WU0        = '-6.4979789e-009+dwu0n_18'
+PU0        = '1.5054787e-016+dpu0n_18'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_18'   A0         = '1.2162348+da0n_18' LA0        = '-5.1690836e-007+dla0n_18'
+WA0        = '1.5922953e-007+dwa0n_18'
+PA0        = '-3.0756929e-013+dpa0n_18'
+AGS        = '0.38190343+dagsn_18'
+LAGS       = '1.838086e-007+dlagsn_18'
+WAGS       = '-1.6303234e-008+dwagsn_18'
+PAGS       = '-8.2650779e-015+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.8 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_18+dlmisn_18)'
+LMAX       = '1.2e-006-(dxln_18+dlmisn_18)'  WMIN       = '1e-006-(dxwn_18+dwmisn_18)'    WMAX       = '1e-005-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.7778581e-009+dlvthn_18'
+WVTH0      = '-1.9482295e-009+dwvthn_18'
+PVTH0      = '-1.4541854e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_18'
+LK2        = '-6.2688409e-009+dlk2n_18'
+WK2        = '1.1995574e-008+dwk2n_18'
+PK2        = '-4.9642252e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_18'
+LCIT       = '6.6229996e-011+dlcitn_18'
+WCIT       = '-4.145586e-011+dwcitn_18'
+PCIT       = '-6.8164938e-017+dpcitn_18'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_18'
+LU0        = '-3.4512743e-011+dlu0n_18'
+WU0        = '-6.662385e-009+dwu0n_18'
+PU0        = '3.4536902e-016+dpu0n_18'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.3201499+da0n_18' LA0        = '-6.4004769e-007+dla0n_18'
+WA0        = '-1.3626309e-007+dwa0n_18'
+PA0        = '4.2589454e-014+dpa0n_18'
+AGS        = '0.94327311+dagsn_18'
+LAGS       = '-4.8141448e-007+dlagsn_18'
+WAGS       = '-1.8570803e-007+dwagsn_18'
+PAGS       = '1.9247961e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.9 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_18+dlmisn_18)'
+LMAX       = '7e-007-(dxln_18+dlmisn_18)'    WMIN       = '1e-006-(dxwn_18+dwmisn_18)'    WMAX       = '1e-005-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+(dvthn_18+vthmisn_18)'
+LVTH0      = '-3.3832116e-009+dlvthn_18'
+WVTH0      = '-3.6076185e-008+dwvthn_18'
+PVTH0      = '8.8357962e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.061138887+dk2n_18'
+LK2        = '-9.2107413e-010+dlk2n_18'
+WK2        = '9.9093956e-009+dwk2n_18'
+PK2        = '-3.5351933e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitn_18'
+LCIT       = '1.1765275e-010+dlcitn_18'
+WCIT       = '-8.1835785e-011+dwcitn_18'
+PCIT       = '-4.050469e-017+dpcitn_18'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0n_18'
+LETA0      = '-3.8911504e-009+dleta0n_18'
+WETA0      = '-7.9238321e-008+dweta0n_18'
+PETA0      = '3.8938742e-014+dpeta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0n_18'
+LU0        = '-6.818911e-010+dlu0n_18'
+WU0        = '-1.6119779e-008+dwu0n_18'
+PU0        = '6.8236842e-015+dpu0n_18'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatn_18'
+LVSAT      = '0.00017484387+dlvsatn_18'
+WVSAT      = '0.002554252+dwvsatn_18'
+PVSAT      = '-1.7496626e-009+dpvsatn_18'
+A0         = '1.1807466+da0n_18' LA0        = '-5.4455646e-007+dla0n_18'
+WA0        = '-2.8630873e-007+dwa0n_18'
+PA0        = '1.4537072e-013+dpa0n_18'
+AGS        = '-2.065376+dagsn_18'
+LAGS       = '1.5795102e-006+dlagsn_18'
+WAGS       = '4.6705548e-007+dwagsn_18'
+PAGS       = '-2.546634e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmn_18'
+LPCLM      = '-2.7249305e-008+dlpclmn_18'
+WPCLM      = '-1.6066245e-007+dwpclmn_18'
+PPCLM      = '1.1005378e-013+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.10 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxln_18+dlmisn_18)'  WMIN       = '1e-006-(dxwn_18+dwmisn_18)'    WMAX       = '1e-005-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55572846+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.4037009e-008+dlvthn_18'
+WVTH0      = '-3.5642896e-008+dwvthn_18'
+PVTH0      = '8.6776455e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.10872301+dk2n_18'
+LK2        = '1.644713e-008+dlk2n_18'
+WK2        = '-1.4598472e-008+dwk2n_18'
+PK2        = '5.4101782e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010116733+dcitn_18'
+LCIT       = '-1.6792218e-011+dlcitn_18'
+WCIT       = '-2.5887286e-010+dwcitn_18'
+PCIT       = '2.4113842e-017+dpcitn_18'
+VOFF       = -0.074529266        LVOFF      = -1.2586685e-008     WVOFF      = -7.9767307e-008
+PVOFF      = 1.6854658e-014      NFACTOR    = 0.55                ETA0       = '0.51487061+deta0n_18'
+LETA0      = '2.9517528e-009+dleta0n_18'
+WETA0      = '2.0516592e-008+dweta0n_18'
+PETA0      = '2.5281986e-015+dpeta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.045622847+du0n_18'
+LU0        = '-2.6499699e-009+dlu0n_18'
+WU0        = '7.7644596e-009+dwu0n_18'
+PU0        = '-1.894063e-015+dpu0n_18'
+UA         = -1.8818992e-010     LUA        = -3.3434682e-016     WUA        = 3.7870577e-016
+PUA        = -2.8619542e-023     UB         = 1.7929581e-018      LUB        = 4.7803414e-025
+WUB        = 6.1084645e-025      PUB        = -2.7351271e-031     UC         = 2.3992245e-010
+LUC        = -3.5871529e-017     WUC        = -4.7194646e-018     PUC        = -9.8716561e-024
+VSAT       = '108695.66+dvsatn_18'
+LVSAT      = '-0.0068736361+dlvsatn_18'
+WVSAT      = '-0.0068113387+dwvsatn_18'
+PVSAT      = '1.668778e-009+dpvsatn_18'
+A0         = '0.49116347+da0n_18'
+LA0        = '-2.9285861e-007+dla0n_18'
+WA0        = '-1.8201203e-007+dwa0n_18'
+PA0        = '1.0730242e-013+dpa0n_18'
+AGS        = '3.9145724+dagsn_18'
+LAGS       = '-6.0317099e-007+dlagsn_18'
+WAGS       = '2.2906159e-007+dwagsn_18'
+PAGS       = '-1.6779563e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067214855        LKETA      = 1.9482929e-008
+WKETA      = 1.3823285e-010      PKETA      = 2.093482e-015       DWG        = 0
+DWB        = 0                   PCLM       = '-0.064254502+dpclmn_18'
+LPCLM      = '1.0014829e-007+dlpclmn_18'
+WPCLM      = '5.6765043e-007+dwpclmn_18'
+PPCLM      = '-1.5578042e-013+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015463108       LPDIBLC2   = 7.6691395e-010
+WPDIBLC2   = 4.6473857e-011      PPDIBLC2   = -2.1720814e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0010417601
+LTVOFF     = 2.060063e-010       WTVOFF     = 1.8782966e-009      PTVOFF     = -7.1173381e-016
+KT1        = -0.38578061         LKT1       = 3.676321e-008       WKT1       = 2.7053704e-007
+PKT1       = -7.3326104e-014     KT1L       = 0                   KT2        = -0.14373694
+LKT2       = 2.8827219e-008      WKT2       = 4.3187153e-008      PKT2       = -1.0838713e-014
+UTE        = -1.3246716          LUTE       = 7.9544531e-008      WUTE       = 3.2694426e-007
+PUTE       = -8.0101343e-014     UA1        = 3.3726047e-009      LUA1       = -2.7712562e-016
+WUA1       = 9.102561e-016       PUA1       = -2.2762132e-022     UB1        = -4.0327032e-018
+LUB1       = 3.8096885e-025      WUB1       = -1.9655098e-024     PUB1       = 5.9341745e-031
+UC1        = 9.7340458e-011      LUC1       = -7.4108568e-018     WUC1       = -1.7921285e-017
+PUC1       = -8.0935732e-024     PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_18+dlmisn_18)'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-(dxwn_18+dwmisn_18)'    WMAX       = '1e-006-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+(dvthn_18+vthmisn_18)'
+WVTH0      = '-3.8203063e-009+dwvthn_18'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_18'
+WK2        = '2.9951201e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_18'
+WCIT       = '-9.5507656e-011+dwcitn_18'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_18'
+WU0        = '-4.3551491e-009+dwu0n_18'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.472886+da0n_18'  WA0        = '-1.821522e-007+dwa0n_18'
+AGS        = '0.4053948+dagsn_18'
+WAGS       = '-2.2249464e-008+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       PCIT       = '0+dpcitn_18'
+LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'
+LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_18+dlmisn_18)'
+LMAX       = '1e-005-(dxln_18+dlmisn_18)'    WMIN       = '6e-007-(dxwn_18+dwmisn_18)'    WMAX       = '1e-006-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+(dvthn_18+vthmisn_18)'
+LVTH0      = '1.4894822e-008+dlvthn_18'
+WVTH0      = '-2.3181445e-009+dwvthn_18'
+PVTH0      = '-1.4999085e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_18'
+LK2        = '-1.6226287e-008+dlk2n_18'
+WK2        = '2.7187635e-009+dwk2n_18'
+PK2        = '2.7594208e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_18'
+LCIT       = '2.1866624e-010+dlcitn_18'
+WCIT       = '-9.9870099e-011+dwcitn_18'
+PCIT       = '4.3558988e-017+dpcitn_18'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_18'
+LU0        = '-2.2871153e-009+dlu0n_18'
+WU0        = '-4.6020798e-009+dwu0n_18'
+PU0        = '2.4656031e-015+dpu0n_18'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.5788249+da0n_18' LA0        = '-1.0578002e-006+dla0n_18'
+WA0        = '-2.0589871e-007+dwa0n_18'
+PA0        = '2.3710883e-013+dpa0n_18'
+AGS        = '0.39080402+dagsn_18'
+LAGS       = '1.4568891e-007+dlagsn_18'
+WAGS       = '-2.5266134e-008+dwagsn_18'
+PAGS       = '3.0121451e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.13 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_18+dlmisn_18)'
+LMAX       = '1.2e-006-(dxln_18+dlmisn_18)'  WMIN       = '6e-007-(dxwn_18+dwmisn_18)'    WMAX       = '1e-006-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+(dvthn_18+vthmisn_18)'
+LVTH0      = '-3.5476441e-009+dlvthn_18'
+WVTH0      = '-7.2295476e-009+dwvthn_18'
+PVTH0      = '-9.1790728e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_18'
+LK2        = '-1.1063061e-008+dlk2n_18'
+WK2        = '5.1625327e-009+dwk2n_18'
+PK2        = '-1.3644568e-016+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_18'
+LCIT       = '4.2051414e-012+dlcitn_18'
+WCIT       = '-5.8296345e-011+dwcitn_18'
+PCIT       = '-5.7059101e-018+dpcitn_18'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_18'
+LU0        = '-3.7564604e-009+dlu0n_18'
+WU0        = '-5.975723e-009+dwu0n_18'
+PU0        = '4.0933703e-015+dpu0n_18'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.2496434+da0n_18' LA0        = '-6.6772012e-007+dla0n_18'
+WA0        = '-6.5263056e-008+dwa0n_18'
+PA0        = '7.0455585e-014+dpa0n_18'
+AGS        = '0.79778898+dagsn_18'
+LAGS       = '-3.3658827e-007+dlagsn_18'
+WAGS       = '-3.9205511e-008+dwagsn_18'
+PAGS       = '4.6639613e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.14 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_18+dlmisn_18)'
+LMAX       = '7e-007-(dxln_18+dlmisn_18)'    WMIN       = '6e-007-(dxwn_18+dwmisn_18)'    WMAX       = '1e-006-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58171161+(dvthn_18+vthmisn_18)'
+LVTH0      = '9.7781262e-009+dlvthn_18'
+WVTH0      = '-1.4180499e-008+dwvthn_18'
+PVTH0      = '-4.4176708e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.048365474+dk2n_18'
+LK2        = '-9.8169855e-009+dlk2n_18'
+WK2        = '-2.953431e-009+dwk2n_18'
+PK2        = '5.4229894e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074160091+dcitn_18'
+LCIT       = '-2.3146846e-013+dlcitn_18'
+WCIT       = '-1.8079361e-010+dwcitn_18'
+PCIT       = '7.8204713e-017+dpcitn_18'
+VOFF       = -0.11884305         LVOFF      = -1.1113064e-008     WVOFF      = 4.4821743e-009
+PVOFF      = 9.0741347e-016      NFACTOR    = 0.55                ETA0       = '0.44101649+deta0n_18'
+LETA0      = '8.7550883e-008+dleta0n_18'
+WETA0      = '1.401169e-008+dweta0n_18'
+PETA0      = '-5.3143386e-014+dpeta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.025036647+du0n_18'
+LU0        = '5.5370966e-009+dlu0n_18'
+WU0        = '-8.1921692e-010+dwu0n_18'
+PU0        = '5.6116359e-016+dpu0n_18'
+UA         = -1.4231724e-009     LUA        = 1.2263258e-016      WUA        = 5.0256129e-017
+PUA        = 8.5010314e-023      UB         = 2.596331e-018       LUB        = 2.9694512e-025
+WUB        = 7.5816365e-026      PUB        = -1.9115381e-031     UC         = 2.1086049e-010
+LUC        = -4.198412e-017      WUC        = -9.6723469e-017     PUC        = 4.0547054e-023
+VSAT       = '95383.047+dvsatn_18'
+LVSAT      = '-0.0039339871+dlvsatn_18'
+WVSAT      = '-0.0034860295+dwvsatn_18'
+PVSAT      = '2.3879302e-009+dpvsatn_18'
+A0         = '0.73982141+da0n_18'
+LA0        = '-3.1849206e-007+dla0n_18'
+WA0        = '1.5770296e-007+dwa0n_18'
+PA0        = '-8.2276134e-014+dpa0n_18'
+AGS        = '-0.68085015+dagsn_18'
+LAGS       = '6.7627954e-007+dlagsn_18'
+WAGS       = '-9.2716206e-007+dwagsn_18'
+PAGS       = '6.5488985e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0862105          LKETA      = 3.3782933e-008
+WKETA      = 2.4398099e-008      PKETA      = -1.4179529e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.15414038+dpclmn_18'
+LPCLM      = '6.223884e-008+dlpclmn_18'
+WPCLM      = '-2.9108346e-008+dwpclmn_18'
+PPCLM      = '1.9939217e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0056516605        LPDIBLC2   = -2.1588875e-009
+WPDIBLC2   = -3.1370779e-010     PPDIBLC2   = 2.1488984e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00060686363
+LTVOFF     = 5.281993e-010       WTVOFF     = 6.9751629e-010      PTVOFF     = -4.4534898e-016
+KT1        = -0.40438432         LKT1       = 7.9708361e-008      WKT1       = 4.7749053e-008
+PKT1       = -2.8416369e-014     KT1L       = 0                   KT2        = -0.063060512
+LKT2       = 1.0747559e-009      WKT2       = 5.0857827e-010      PKT2       = 3.0326713e-015
+UTE        = -2.3760029          LUTE       = 6.1191079e-007      WUTE       = 9.4373503e-007
+PUTE       = -4.549007e-013      UA1        = -1.6665862e-009     LUA1       = 2.0626574e-015
+WUA1       = 2.9130074e-015      PUA1       = -1.4626072e-021     UB1        = -1.9404259e-019
+LUB1       = -1.4505154e-024     WUB1       = -1.745708e-024      PUB1       = 9.4657552e-031
+UC1        = -7.7186558e-011     LUC1       = 5.2991232e-017      WUC1       = 5.4432153e-017
+PUC1       = -3.1179204e-023     PRT        = 0                   AT         = 24063.347
+LAT        = -0.0091481218       WAT        = 0.0068366768        PAT        = -2.495387e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.15 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxln_18+dlmisn_18)'  WMIN       = '6e-007-(dxwn_18+dwmisn_18)'    WMAX       = '1e-006-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59972388+(dvthn_18+vthmisn_18)'
+LVTH0      = '3.2036506e-009+dlvthn_18'
+WVTH0      = '-7.9946276e-008+dwvthn_18'
+PVTH0      = '1.9586838e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.12001801+dk2n_18'
+LK2        = '1.6336191e-008+dlk2n_18'
+WK2        = '-3.2244022e-009+dwk2n_18'
+PK2        = '5.5218939e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00065351553+dcitn_18'
+LCIT       = '3.1919695e-011+dlcitn_18'
+WCIT       = '1.0179206e-010+dwcitn_18'
+PCIT       = '-2.4939055e-017+dpcitn_18'
+VOFF       = -0.17478981         LVOFF      = 9.307503e-009       WVOFF      = 2.1195059e-008
+PVOFF      = -5.1927895e-015     NFACTOR    = 0.55                ETA0       = '0.93270502+deta0n_18'
+LETA0      = '-9.191543e-008+dleta0n_18'
+WETA0      = '-4.0024266e-007+dweta0n_18'
+PETA0      = '9.8059452e-014+dpeta0n_18'
+ETAB       = -0.085957954        LETAB      = 8.5944877e-010      WETAB      = 3.5325099e-009
+PETAB      = -8.6546491e-016     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.051163941+du0n_18'
+LU0        = '-3.9993655e-009+dlu0n_18'
+WU0        = '2.1845785e-009+dwu0n_18'
+PU0        = '-5.3522172e-016+dpu0n_18'
+UA         = -9.0783387e-010     LUA        = -6.5465993e-017     WUA        = 1.1033872e-015
+PUA        = -2.9938253e-022     UB         = 3.7524286e-018      LUB        = -1.250305e-025
+WUB        = -1.3623403e-024     PUB        = 3.3377338e-031      UC         = 2.1755704e-010
+LUC        = -4.4428363e-017     WUC        = 1.78025e-017        PUC        = -1.2549241e-024
+VSAT       = '92700.208+dvsatn_18'
+LVSAT      = '-0.002954751+dlvsatn_18'
+WVSAT      = '0.0092960785+dwvsatn_18'
+PVSAT      = '-2.2775392e-009+dpvsatn_18'
+A0         = '0.51493963+da0n_18'
+LA0        = '-2.3641021e-007+dla0n_18'
+WA0        = '-2.0595462e-007+dwa0n_18'
+PA0        = '5.0458882e-014+dpa0n_18'
+AGS        = '1.5230769+dagsn_18'
+LAGS       = '-1.2815385e-007+dlagsn_18'
+WAGS       = '2.6372975e-006+dwagsn_18'
+PAGS       = '-6.4613788e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023431248        LKETA      = 1.0868506e-008
+WKETA      = -4.3951859e-008     PKETA      = 1.0768206e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.42236732+dpclmn_18'
+LPCLM      = '-3.5663994e-008+dlpclmn_18'
+WPCLM      = '7.7622256e-008+dwpclmn_18'
+PPCLM      = '-1.9017453e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0023308989       LPDIBLC2   = 7.5474674e-010
+WPDIBLC2   = 8.3655411e-010      PPDIBLC2   = -2.0495576e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0044855794
+LTVOFF     = -8.8753195e-010     WTVOFF     = -1.5896294e-009     PTVOFF     = 3.8945921e-016
+KT1        = -0.026194302        LKT1       = -5.8330996e-008     WKT1       = -9.1566374e-008
+PKT1       = 2.2433762e-014      KT1L       = 0                   KT2        = -0.12748276
+LKT2       = 2.4588876e-008      WKT2       = 2.6819187e-008      PKT2       = -6.5707007e-015
+UTE        = -0.086085625        LUTE       = -2.2390902e-007     WUTE       = -9.2031178e-007
+PUTE       = 2.2547639e-013      UA1        = 7.5813954e-009      LUA1       = -1.3128559e-015
+WUA1       = -3.3279961e-015     PUA1       = 8.1535905e-022      UB1        = -8.544895e-018
+LUB1       = 1.5975458e-024      WUB1       = 2.5782674e-024      PUB1       = -6.3167551e-031
+UC1        = 1.7315074e-010      LUC1       = -3.8381881e-017     WUC1       = -9.4262236e-017
+PUC1       = 2.3094248e-023      PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_18+dlmisn_18)'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+(dvthn_18+vthmisn_18)'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_18'
+WK2        = '7.0038392e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_18'
+WCIT       = '-1.734284e-010+dwcitn_18'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_18'  WU0        = '2.47049e-010+dwu0n_18'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_18'   A0         = '0.761323+da0n_18'  WA0        = '2.4976654e-007+dwa0n_18'
+AGS        = '0.3716704+dagsn_18'
+WAGS       = '-1.7787528e-009+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'
+PCIT       = '0+dpcitn_18'       LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'
+LAGS       = '0+dlagsn_18'       PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'
+WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+PETA0      = '0+dpeta0n_18'      LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_18+dlmisn_18)'
+LMAX       = '1e-005-(dxln_18+dlmisn_18)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+(dvthn_18+vthmisn_18)'
+LVTH0      = '-2.9748634e-009+dlvthn_18'
+WVTH0      = '4.1584242e-010+dwvthn_18'
+PVTH0      = '-4.1521866e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_18'
+LK2        = '-8.5746992e-009+dlk2n_18'
+WK2        = '7.1926316e-009+dwk2n_18'
+PK2        = '-1.8850927e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_18'
+LCIT       = '2.8299186e-011+dlcitn_18'
+WCIT       = '-1.8936348e-010+dwcitn_18'
+PCIT       = '1.5911179e-016+dpcitn_18'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_18'
+LU0        = '-1.3444366e-009+dlu0n_18'
+WU0        = '5.7424856e-011+dwu0n_18'
+PU0        = '1.8933971e-015+dpu0n_18'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_18'   A0         = '0.77421149+da0n_18'
+LA0        = '-1.2869158e-007+dla0n_18'
+WA0        = '2.8250165e-007+dwa0n_18'
+PA0        = '-3.2686013e-013+dpa0n_18'
+AGS        = '0.35349094+dagsn_18'
+LAGS       = '1.8152193e-007+dlagsn_18'
+WAGS       = '-2.6170911e-009+dwagsn_18'
+PAGS       = '8.3708082e-015+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.18 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_18+dlmisn_18)'
+LMAX       = '1.2e-006-(dxln_18+dlmisn_18)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+(dvthn_18+vthmisn_18)'
+LVTH0      = '4.9190535e-010+dlvthn_18'
+WVTH0      = '6.7271443e-009+dwvthn_18'
+PVTH0      = '-1.1631079e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_18'
+LK2        = '-8.0997573e-009+dlk2n_18'
+WK2        = '7.2348917e-009+dwk2n_18'
+PK2        = '-1.935171e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_18'
+LCIT       = '-4.8473782e-011+dlcitn_18'
+WCIT       = '-7.7260869e-011+dwcitn_18'
+PCIT       = '2.6270196e-017+dpcitn_18'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_18'
+LU0        = '4.2425619e-009+dlu0n_18'
+WU0        = '2.2982969e-009+dwu0n_18'
+PU0        = '-7.6203623e-016+dpu0n_18'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.2504613+da0n_18' LA0        = '-6.9304756e-007+dla0n_18'
+WA0        = '-6.5759503e-008+dwa0n_18'
+PA0        = '8.5829344e-014+dpa0n_18'
+AGS        = '0.85077416+dagsn_18'
+LAGS       = '-4.0775869e-007+dlagsn_18'
+WAGS       = '-7.1367515e-008+dwagsn_18'
+PAGS       = '8.9840061e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.19 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_18+dlmisn_18)'
+LMAX       = '7e-007-(dxln_18+dlmisn_18)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58475731+(dvthn_18+vthmisn_18)'
+LVTH0      = '-4.0187612e-009+dlvthn_18'
+WVTH0      = '-1.6029234e-008+dwvthn_18'
+PVTH0      = '3.9570398e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.059827546+dk2n_18'
+LK2        = '-1.3408216e-009+dlk2n_18'
+WK2        = '4.0040467e-009+dwk2n_18'
+PK2        = '2.7795792e-016+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00035790792+dcitn_18'
+LCIT       = '2.3132079e-010+dlcitn_18'
+WCIT       = '5.2108038e-011+dwcitn_18'
+PCIT       = '-6.2347505e-017+dpcitn_18'
+VOFF       = -0.10692563         LVOFF      = -5.1820416e-009     WVOFF      = -2.7517012e-009
+PVOFF      = -2.6927173e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.023868909+du0n_18'
+LU0        = '4.9987811e-009+dlu0n_18'
+WU0        = '-1.1040002e-010+dwu0n_18'
+PU0        = '8.8792113e-016+dpu0n_18'
+UA         = -1.080391e-009      LUA        = 3.9287131e-017      WUA        = -1.578122e-016
+PUA        = 1.35601e-022        UB         = 2.4785956e-018      LUB        = 1.6217676e-025
+WUB        = 1.4728174e-025      PUB        = -1.0934942e-031     UC         = 6.4726623e-011
+LUC        = 4.0047207e-017      WUC        = -8.0202142e-018     PUC        = -9.2459613e-024
+VSAT       = '84997.656+dvsatn_18'
+LVSAT      = '0.0031800055+dlvsatn_18'
+WVSAT      = '0.0028179027+dwvsatn_18'
+PVSAT      = '-1.9302633e-009+dpvsatn_18'
+A0         = '0.72691983+da0n_18'
+LA0        = '-3.3442168e-007+dla0n_18'
+WA0        = '1.6553422e-007+dwa0n_18'
+PA0        = '-7.2606855e-014+dpa0n_18'
+AGS        = '-3.3021125+dagsn_18'
+LAGS       = '2.4369687e-006+dlagsn_18'
+WAGS       = '6.6394419e-007+dwagsn_18'
+PAGS       = '-4.1384846e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.044413375        LKETA      = 5.5893089e-009
+WKETA      = -9.7275544e-010     PKETA      = 2.9340003e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15038105+dpclmn_18'
+LPCLM      = '6.4813981e-008+dlpclmn_18'
+WPCLM      = '-2.6826433e-008+dwpclmn_18'
+PPCLM      = '1.8376107e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0084649305        LPDIBLC2   = -4.3647724e-009
+WPDIBLC2   = -2.0213626e-009     PPDIBLC2   = 1.553862e-015       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.005244197
+LTVOFF     = -1.9592623e-009     WTVOFF     = -2.117345e-009      PTVOFF     = 1.0645402e-015
+KT1        = -0.34824522         LKT1       = 2.46259e-008        WKT1       = 1.3672618e-008
+PKT1       = 5.0186846e-015      KT1L       = 0                   KT2        = -0.076610106
+LKT2       = 1.3194132e-008      WKT2       = 8.7331822e-009      PKT2       = -4.3237898e-015
+UTE        = -0.6594357          LUTE       = -2.7902399e-007     WUTE       = -9.8221278e-008
+PUTE       = 8.5896718e-014      UA1        = 3.9503485e-009      LUA1       = -9.1136066e-016
+WUA1       = -4.9647199e-016     PUA1       = 3.4262174e-022      UB1        = -3.5230482e-018
+LUB1       = 3.9527663e-025      WUB1       = 2.7499835e-025      PUB1       = -1.7382021e-031
+UC1        = 3.7157106e-011      LUC1       = -2.5993185e-017     WUC1       = -1.4974451e-017
+PUC1       = 1.6764337e-023      PRT        = 0                   AT         = 44822.861
+LAT        = -0.016725344        WAT        = -0.005764348        PAT        = 2.103987e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LETA0      = '0+dleta0n_18'
+PETA0      = '0+dpeta0n_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_18.20 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxln_18+dlmisn_18)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_18+dwmisn_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_18+toxmisn_18)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_18+dlmisn_18)'  XW         = '7e-09+(dxwn_18+dwmisn_18)'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.47864106+(dvthn_18+vthmisn_18)'
+LVTH0      = '3.4713667e-008+dlvthn_18'
+WVTH0      = '-6.4490083e-009+dwvthn_18'
+PVTH0      = '4.6025743e-016+dpvthn_18'
+K1         = 0.71631             K2         = '-0.080568945+dk2n_18'
+LK2        = '6.2297889e-009+dlk2n_18'
+WK2        = '-2.7169986e-008+dwk2n_18'
+PK2        = '1.165648e-014+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010105438+dcitn_18'
+LCIT       = '-6.8913141e-012+dlcitn_18'
+WCIT       = '-1.1492411e-010+dwcitn_18'
+PCIT       = '-1.3807723e-018+dpcitn_18'
+VOFF       = -0.11072071         LVOFF      = -3.7968365e-009     WVOFF      = -1.7694885e-008
+PVOFF      = 2.7615446e-015      NFACTOR    = 0.55                ETA0       = '0.19330368+deta0n_18'
+LETA0      = '1.6583896e-007+dleta0n_18'
+WETA0      = '4.8573951e-008+dweta0n_18'
+PETA0      = '-5.8397463e-014+dpeta0n_18'
+ETAB       = -0.046964442        LETAB      = -1.7188975e-009     WETAB      = -2.0136552e-008
+PETAB      = 6.995913e-016       UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.089825967+du0n_18'
+LU0        = '-1.9075545e-008+dlu0n_18'
+WU0        = '-2.1283271e-008+dwu0n_18'
+PU0        = '8.6160192e-015+dpu0n_18'
+UA         = 3.8588645e-009      LUA        = -1.7635411e-015     WUA        = -1.7899987e-015
+PUA        = 7.3134906e-022      UB         = 1.0327685e-019      LUB        = 1.0291681e-024
+WUB        = 8.5269477e-025      PUB        = -3.6682518e-031     UC         = 4.9553956e-010
+LUC        = -1.1719951e-016     WUC        = -1.5093289e-016     PUC        = 4.2917165e-023
+VSAT       = '120394.58+dvsatn_18'
+LVSAT      = '-0.0097398729+dlvsatn_18'
+WVSAT      = '-0.0075144071+dwvsatn_18'
+PVSAT      = '1.8410297e-009+dpvsatn_18'
+A0         = '0.1352109+da0n_18' LA0        = '-1.1844792e-007+dla0n_18'
+WA0        = '2.4540715e-008+dwa0n_18'
+PA0        = '-2.1144227e-014+dpa0n_18'
+AGS        = '8.2224801+dagsn_18'
+LAGS       = '-1.7695076e-006+dlagsn_18'
+WAGS       = '-1.4292402e-006+dwagsn_18'
+PAGS       = '3.5016386e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.13577392         LKETA      = 3.8935906e-008
+WKETA      = 2.4240139e-008      PKETA      = -6.2687063e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.8732156+dpclmn_18'
+LPCLM      = '-1.9902063e-007+dlpclmn_18'
+WPCLM      = '-1.9604265e-007+dwpclmn_18'
+PPCLM      = '8.0140024e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0083658273       LPDIBLC2   = 1.7784542e-009
+WPDIBLC2   = 4.4997556e-009      PPDIBLC2   = -8.263462e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = -0.0015688388
+LTVOFF     = 5.2749572e-010      WTVOFF     = 2.0854024e-009      PTVOFF     = -4.6946258e-016
+KT1        = -0.2979223          LKT1       = 6.258036e-009       WKT1       = 7.3372524e-008
+PKT1       = -1.6771781e-014     KT1L       = 0                   KT2        = -0.073393373
+LKT2       = 1.2020024e-008      WKT2       = -6.0130697e-009     PKT2       = 1.0585921e-015
+UTE        = -2.8086658          LUTE       = 5.05445e-007        WUTE       = 7.3229441e-007
+PUTE       = -2.1724151e-013     UA1        = 7.3240948e-010      LUA1       = 2.6318709e-016
+WUA1       = 8.2933835e-016      PUA1       = -1.4129903e-022     UB1        = -6.4724218e-018
+LUB1       = 1.471798e-024       WUB1       = 1.3202762e-024      PUB1       = -5.5534662e-031
+UC1        = -1.616876e-010      LUC1       = 4.6585134e-017      WUC1       = 1.0898464e-016
+PUC1       = -2.848073e-023      PRT        = 0                   AT         = -33595.208
+LAT        = 0.011897251         WAT        = -0.0025219585       PAT        = 9.2051487e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_18'
+NOIB       = 'noibnmac_18'
+NOIC       = 'noicnmac_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )

**********************************************************************************************
*                                                                                            *
*                                   1.8V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.ends nch_18_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_18_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwp_18'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_18 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_18  temp2=parp2_18
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_18='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisp_18='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_18='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_18='0.00197184*geo_fac*toxp_18*fac2*mismatchflag' 
.param tnoiax='2.295e6/(l*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(l*scale*1e6)+0.5496'

.param fn_dice='noiseflagp_18_mc*par1fn_mc+noiseflagp_18_mc_mis*par2fp_18_mc'
.param arearatio='sigma_factor_flicker_18*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noiapmac_18='c1fp_18*2.718**((fn_dice+(1-fn_dice)*noiseflagp_18)*arearatio)'
.param noibpmac_18='c2fp_18*2.718**((fn_dice+(1-fn_dice)*noiseflagp_18)*arearatio)'
.param noicpmac_18='c3fp_18*2.718**((fn_dice+(1-fn_dice)*noiseflagp_18)*arearatio)'

.MODEL pch_18.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_18+dlmisp_18)'
+LMAX       = 900.001e-6          WMIN       = '1e-005-(dxwp_18+dwmisp_18)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+(dvthp_18+vthmisp_18)'
+K1         = 0.72417             K2         = '-0.05886+dk2p_18'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_18'
+VOFF       = '-0.08693+dvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_18'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_18'
+A0         = '1.297+da0p_18'     AGS        = '0.2718+dagsp_18'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_18'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'
+LCIT       = '0+dlcitp_18'       WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'
+LU0        = '0+dlu0p_18'        WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+LA0        = '0+dla0p_18'        WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+LPCLM      = '0+dlpclmp_18'      WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+LVOFF      = '0+dlvoffp_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+LK2        = '0+dlk2p_18'        WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_18+dlmisp_18)'
+LMAX       = '1e-005-(dxlp_18+dlmisp_18)'    WMIN       = '1e-005-(dxwp_18+dwmisp_18)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+(dvthp_18+vthmisp_18)'
+LVTH0      = '4.3026273e-009+dlvthp_18'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_18'
+LK2        = '-7.5295977e-010+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_18'
+LCIT       = '2.3222086e-010+dlcitp_18'
+VOFF       = '-0.087552125+dvoffp_18'
+LVOFF      = '6.2119181e-009+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_18'
+LU0        = '9.4119972e-011+dlu0p_18'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_18'  A0         = '1.3227199+da0p_18' LA0        = '-2.5681307e-007+dla0p_18'
+AGS        = '0.25480602+dagsp_18'
+LAGS       = '1.6968486e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_18'
+LPCLM      = '2.5143478e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'
+PAGS       = '0+dpagsp_18'       WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'      WK2        = '0+dwk2p_18'
+PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '1.2e-006-(dxlp_18+dlmisp_18)'  WMIN       = '1e-005-(dxwp_18+dwmisp_18)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+(dvthp_18+vthmisp_18)'
+LVTH0      = '1.3149945e-008+dlvthp_18'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_18'
+LK2        = '4.740474e-009+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_18'
+LCIT       = '2.0991209e-010+dlcitp_18'
+VOFF       = '-0.09229456+dvoffp_18'
+LVOFF      = '1.1831704e-008+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_18' LU0        = '-5.032695e-010+dlu0p_18'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_18'  A0         = '1.5469482+da0p_18' LA0        = '-5.2252362e-007+dla0p_18'
+AGS        = '0.2391074+dagsp_18'
+LAGS       = '1.8828773e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_18'
+LPCLM      = '1.2183992e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'
+PAGS       = '0+dpagsp_18'       WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'      WK2        = '0+dwk2p_18'
+PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.4 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '7e-007-(dxlp_18+dlmisp_18)'    WMIN       = '1e-005-(dxwp_18+dwmisp_18)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63663281+(dvthp_18+vthmisp_18)'
+LVTH0      = '3.5159766e-009+dlvthp_18'
+K1         = 0.72417             K2         = '-0.044249688+dk2p_18'
+LK2        = '-8.3914641e-009+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00023317656+dcitp_18'
+LCIT       = '5.6802555e-011+dlcitp_18'
+VOFF       = '-0.11314283+dvoffp_18'
+LVOFF      = '2.6112767e-008+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58864219+deta0p_18'
+LETA0      = '-2.3439844e-010+dleta0p_18'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01097875+du0p_18'
+LU0        = '5.6255625e-010+dlu0p_18'
+UA         = 6.8244047e-010      LUA        = -2.4986092e-016     UB         = 7.2901719e-019
+LUB        = 4.3105873e-025      UC         = 4.7293438e-011      LUC        = 1.5204645e-017
+VSAT       = '102400.16+dvsatp_18'
+LVSAT      = '0.012055893+dlvsatp_18'
+A0         = '0.75410734+da0p_18'
+LA0        = '2.057237e-008+dla0p_18'
+AGS        = '0.16182344+dagsp_18'
+LAGS       = '2.4122725e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.051643594        LKETA      = 5.7427617e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.43326891+dpclmp_18'
+LPCLM      = '-2.1384951e-008+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0057335625
+LTVOFF     = -1.1032353e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21198906         LKT1       = -4.1175992e-008     KT1L       = 0
+KT2        = -0.071645938        LKT2       = 4.9223672e-009      UTE        = -0.43653125
+LUTE       = -3.8597609e-007     UA1        = 3.7772211e-009      LUA1       = -1.3427515e-015
+UB1        = -3.6822922e-018     LUB1       = 6.0779515e-025      UC1        = 1.0510078e-010
+LUC1       = -5.6732235e-017     PRT        = 0                   AT         = 122856.09
+LAT        = -0.040871274
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      WA0        = '0+dwa0p_18'
+PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      WETA0      = '0+dweta0p_18'
+PETA0      = '0+dpeta0p_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.5 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxlp_18+dlmisp_18)'  WMIN       = '1e-005-(dxwp_18+dwmisp_18)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58085833+(dvthp_18+vthmisp_18)'
+LVTH0      = '-1.6841708e-008+dlvthp_18'
+K1         = 0.72417             K2         = '-0.028775+dk2p_18' LK2        = '-1.4039725e-008+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00037328333+dcitp_18'
+LCIT       = '5.6635833e-012+dlcitp_18'
+VOFF       = '-0.015000125+dvoffp_18'
+LVOFF      = '-9.7093194e-009+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.62434167+deta0p_18'
+LETA0      = '-1.3264708e-008+dleta0p_18'
+ETAB       = -0.027946667        LETAB      = -2.4562067e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010029167+du0p_18'
+LU0        = '9.0915417e-010+dlu0p_18'
+UA         = 2.7778208e-010      LUA        = -1.0216061e-016     UB         = -3.1541667e-019
+LUB        = 8.1227708e-025      UC         = 1.165125e-010       LUC        = -1.0060313e-017
+VSAT       = '166932.92+dvsatp_18'
+LVSAT      = '-0.011498565+dlvsatp_18'
+A0         = '0.91432958+da0p_18'
+LA0        = '-3.7908748e-008+dla0p_18'
+AGS        = '0.034065+dagsp_18' LAGS       = '2.8785908e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14540458         LKETA      = 3.9965523e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.06344125+dpclmp_18'
+LPCLM      = '1.5991426e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0073827417
+LTVOFF     = -1.7051857e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.4099375          LKT1       = 3.1075188e-008      KT1L       = 0
+KT2        = -0.09246            LKT2       = 1.25195e-008        UTE        = -2.4045833
+LUTE       = 3.3236292e-007      UA1        = -4.5311313e-009     LUA1       = 1.6897972e-015
+UB1        = 3.3788208e-018      LUB1       = -1.9695111e-024     UC1        = -1.4464275e-010
+LUC1       = 3.4424154e-017      PRT        = 0                   AT         = 49426.667
+LAT        = -0.014069533
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      WA0        = '0+dwa0p_18'
+PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      WETA0      = '0+dweta0p_18'
+PETA0      = '0+dpeta0p_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_18+dlmisp_18)'
+LMAX       = 900.001e-6          WMIN       = '1e-006-(dxwp_18+dwmisp_18)'    WMAX       = '1e-005-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+(dvthp_18+vthmisp_18)'
+WVTH0      = '-1.5339508e-008+dwvthp_18'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_18'
+WK2        = '-1.0189016e-009+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_18'
+WCIT       = '-1.017782e-011+dwcitp_18'
+VOFF       = '-0.085385933+dvoffp_18'
+WVOFF      = '-1.5451475e-008+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_18'
+WU0        = '-2.0154098e-010+dwu0p_18'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.2936433+da0p_18' WA0        = '3.3590163e-008+dwa0p_18'
+AGS        = '0.27102797+dagsp_18'
+WAGS       = '7.7257376e-009+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'
+PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'       PCIT       = '0+dpcitp_18'
+LU0        = '0+dlu0p_18'        PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'
+PA0        = '0+dpa0p_18'        LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'
+LPCLM      = '0+dlpclmp_18'      WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      PETA0      = '0+dpeta0p_18'      LVOFF      = '0+dlvoffp_18'
+PVOFF      = '0+dpvoffp_18'      LK2        = '0+dlk2p_18'        PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_18+dlmisp_18)'
+LMAX       = '1e-005-(dxlp_18+dlmisp_18)'    WMIN       = '1e-006-(dxwp_18+dwmisp_18)'    WMAX       = '1e-005-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+(dvthp_18+vthmisp_18)'
+LVTH0      = '2.9336e-009+dlvthp_18'
+WVTH0      = '-1.6711552e-008+dwvthp_18'
+PVTH0      = '1.3699856e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_18'
+LK2        = '-5.724287e-010+dlk2p_18'
+WK2        = '-8.3797279e-010+dwk2p_18'
+PK2        = '-1.8065744e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_18'
+LCIT       = '2.5685734e-010+dlcitp_18'
+WCIT       = '1.4512935e-011+dwcitp_18'
+PCIT       = '-2.4653719e-016+dpcitp_18'
+VOFF       = '-0.085808935+dvoffp_18'
+LVOFF      = '4.2236693e-009+dlvoffp_18'
+WVOFF      = '-1.7444105e-008+dwvoffp_18'
+PVOFF      = '1.9896406e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_18'
+LU0        = '6.5535886e-011+dlu0p_18'
+WU0        = '-2.3018805e-010+dwu0p_18'
+PU0        = '2.8604095e-016+dpu0p_18'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.3194838+da0p_18' LA0        = '-2.5801661e-007+dla0p_18'
+WA0        = '3.2383971e-008+dwa0p_18'
+PA0        = '1.2043829e-014+dpa0p_18'
+AGS        = '0.25390291+dagsp_18'
+LAGS       = '1.7099371e-007+dlagsp_18'
+WAGS       = '9.0374716e-009+dwagsp_18'
+PAGS       = '-1.3097665e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_18'
+LPCLM      = '2.479746e-007+dlpclmp_18'
+WPCLM      = '-3.4678027e-009+dwpclmp_18'
+PPCLM      = '3.462601e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.8 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '1.2e-006-(dxlp_18+dlmisp_18)'  WMIN       = '1e-006-(dxwp_18+dwmisp_18)'    WMAX       = '1e-005-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+(dvthp_18+vthmisp_18)'
+LVTH0      = '1.3912858e-008+dlvthp_18'
+WVTH0      = '1.2921016e-009+dwvthp_18'
+PVTH0      = '-7.6344731e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_18'
+LK2        = '5.12738e-009+dlk2p_18'
+WK2        = '9.0480703e-010+dwk2p_18'
+PK2        = '-3.8717685e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_18'
+LCIT       = '2.2066735e-010+dlcitp_18'
+WCIT       = '-1.027101e-010+dwcitp_18'
+PCIT       = '-1.0762789e-016+dpcitp_18'
+VOFF       = '-0.092580246+dvoffp_18'
+LVOFF      = '1.2247673e-008+dlvoffp_18'
+WVOFF      = '2.8588588e-009+dwvoffp_18'
+PVOFF      = '-4.1626056e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_18'
+LU0        = '-5.6139623e-010+dlu0p_18'
+WU0        = '-4.7966753e-010+dwu0p_18'
+PU0        = '5.8167414e-016+dpu0p_18'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.5239739+da0p_18' LA0        = '-5.0033737e-007+dla0p_18'
+WA0        = '2.2990429e-007+dwa0p_18'
+PA0        = '-2.2201775e-013+dpa0p_18'
+AGS        = '0.23113396+dagsp_18'
+LAGS       = '1.9797491e-007+dlagsp_18'
+WAGS       = '7.9790186e-008+dwagsp_18'
+PAGS       = '-9.6939631e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_18'
+LPCLM      = '1.321774e-007+dlpclmp_18'
+WPCLM      = '1.130496e-007+dwpclmp_18'
+PPCLM      = '-1.0344711e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.9 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '7e-007-(dxlp_18+dlmisp_18)'    WMIN       = '1e-006-(dxwp_18+dwmisp_18)'    WMAX       = '1e-005-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthp_18+vthmisp_18)'
+LVTH0      = '2.5718197e-009+dlvthp_18'
+WVTH0      = '-2.3646075e-008+dwvthp_18'
+PVTH0      = '9.4481782e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.042954661+dk2p_18'
+LK2        = '-8.9535871e-009+dlk2p_18'
+WK2        = '-1.295933e-008+dwk2p_18'
+PK2        = '5.6251653e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitp_18'
+LCIT       = '4.6455294e-011+dlcitp_18'
+WCIT       = '-4.1099174e-010+dwcitp_18'
+PCIT       = '1.0354503e-016+dpcitp_18'
+VOFF       = '-0.11299764+dvoffp_18'
+LVOFF      = '2.6233584e-008+dlvoffp_18'
+WVOFF      = '-1.4529495e-009+dwvoffp_18'
+PVOFF      = '-1.2090169e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.56211263+deta0p_18'
+LETA0      = '1.7424833e-008+dleta0p_18'
+WETA0      = '2.6548126e-007+dweta0p_18'
+PETA0      = '-1.7671593e-013+dpeta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0p_18'
+LU0        = '5.5390148e-010+dlu0p_18'
+WU0        = '2.4305632e-010+dwu0p_18'
+PU0        = '8.66083e-017+dpu0p_18'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatp_18'
+LVSAT      = '0.013404813+dlvsatp_18'
+WVSAT      = '0.019706054+dwvsatp_18'
+PVSAT      = '-1.3498647e-008+dpvsatp_18'
+A0         = '0.80514856+da0p_18'
+LA0        = '-7.9420433e-009+dla0p_18'
+WA0        = '-5.107694e-007+dwa0p_18'
+PA0        = '2.8534373e-013+dpa0p_18'
+AGS        = '0.15467694+dagsp_18'
+LAGS       = '2.5034798e-007+dlagsp_18'
+WAGS       = '7.1515032e-008+dwagsp_18'
+PAGS       = '-9.1271151e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmp_18'
+LPCLM      = '-5.4009069e-008+dlpclmp_18'
+WPCLM      = '-5.1456596e-007+dwpclmp_18'
+PPCLM      = '3.2646955e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.10 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxlp_18+dlmisp_18)'  WMIN       = '1e-006-(dxwp_18+dwmisp_18)'    WMAX       = '1e-005-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+(dvthp_18+vthmisp_18)'
+LVTH0      = '-1.614965e-008+dlvthp_18'
+WVTH0      = '2.1213121e-008+dwvthp_18'
+PVTH0      = '-6.9254286e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2p_18'
+LK2        = '-1.4264019e-008+dlk2p_18'
+WK2        = '-3.6972506e-009+dwk2p_18'
+PK2        = '2.2445064e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitp_18'
+LCIT       = '4.9631869e-012+dlcitp_18'
+WCIT       = '-1.465091e-010+dwcitp_18'
+PCIT       = '7.0088675e-018+dpcitp_18'
+VOFF       = '-0.013277558+dvoffp_18'
+LVOFF      = '-1.0164244e-008+dlvoffp_18'
+WVOFF      = '-1.7237725e-008+dwvoffp_18'
+PVOFF      = '4.5524263e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.68737441+deta0p_18'
+LETA0      = '-2.8295717e-008+dleta0p_18'
+WETA0      = '-6.3076868e-007+dweta0p_18'
+PETA0      = '1.504153e-013+dpeta0p_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0p_18'
+LU0        = '8.1401698e-010+dlu0p_18'
+WU0        = '-2.1279835e-009+dwu0p_18'
+PU0        = '9.5203784e-016+dpu0p_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatp_18'
+LVSAT      = '-0.012785126+dlvsatp_18'
+WVSAT      = '-0.052549478+dwvsatp_18'
+PVSAT      = '1.2874622e-008+dpvsatp_18'
+A0         = '0.82373599+da0p_18'
+LA0        = '-1.4726459e-008+dla0p_18'
+WA0        = '9.0657005e-007+dwa0p_18'
+PA0        = '-2.3198517e-013+dpa0p_18'
+AGS        = '0.04584401+dagsp_18'
+LAGS       = '2.9007199e-007+dlagsp_18'
+WAGS       = '-1.1787255e-007+dwagsp_18'
+PAGS       = '-2.2144684e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmp_18'
+LPCLM      = '1.7897004e-007+dlpclmp_18'
+WPCLM      = '9.0231296e-007+dwpclmp_18'
+PPCLM      = '-1.9069126e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_18+dlmisp_18)'
+LMAX       = 900.001e-6          WMIN       = '6e-007-(dxwp_18+dwmisp_18)'    WMAX       = '1e-006-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+(dvthp_18+vthmisp_18)'
+WVTH0      = '-9.168735e-010+dwvthp_18'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_18'
+WK2        = '6.3722708e-009+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.1087682+dvoffp_18'
+WVOFF      = '8.0944649e-009+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_18'
+WU0        = '-4.7371798e-010+dwu0p_18'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.1646275+da0p_18' WA0        = '1.6350911e-007+dwa0p_18'
+AGS        = '0.26549775+dagsp_18'
+WAGS       = '1.3294666e-008+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LU0        = '0+dlu0p_18'
+PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'
+PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'
+PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'       LPCLM      = '0+dlpclmp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      LVOFF      = '0+dlvoffp_18'      PVOFF      = '0+dpvoffp_18'
+LK2        = '0+dlk2p_18'        PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_18+dlmisp_18)'
+LMAX       = '1e-005-(dxlp_18+dlmisp_18)'    WMIN       = '6e-007-(dxwp_18+dwmisp_18)'    WMAX       = '1e-006-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+(dvthp_18+vthmisp_18)'
+LVTH0      = '2.5515924e-008+dlvthp_18'
+WVTH0      = '-1.1460919e-011+dwvthp_18'
+PVTH0      = '-9.0405446e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_18'
+LK2        = '-7.6918538e-009+dlk2p_18'
+WK2        = '5.8351965e-009+dwk2p_18'
+PK2        = '5.3626867e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_18'
+LCIT       = '3.029537e-011+dlcitp_18'
+WCIT       = '1.8416915e-012+dwcitp_18'
+PCIT       = '-1.838929e-017+dpcitp_18'
+VOFF       = '-0.11242711+dvoffp_18'
+LVOFF      = '3.6534227e-008+dlvoffp_18'
+WVOFF      = '9.3603963e-009+dwvoffp_18'
+PVOFF      = '-1.2640325e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_18'
+LU0        = '-2.8293136e-010+dlu0p_18'
+WU0        = '-5.3750841e-010+dwu0p_18'
+PU0        = '6.3694746e-016+dpu0p_18'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_18'  A0         = '1.1751703+da0p_18' LA0        = '-1.0526983e-007+dla0p_18'
+WA0        = '1.7770762e-007+dwa0p_18'
+PA0        = '-1.4177218e-013+dpa0p_18'
+AGS        = '0.25327996+dagsp_18'
+LAGS       = '1.2199468e-007+dlagsp_18'
+WAGS       = '9.6647844e-009+dwagsp_18'
+PAGS       = '3.6244365e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_18'
+LPCLM      = '2.6195605e-007+dlpclmp_18'
+WPCLM      = '-2.0577559e-009+dwpclmp_18'
+PPCLM      = '2.0546692e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.13 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '1.2e-006-(dxlp_18+dlmisp_18)'  WMIN       = '6e-007-(dxwp_18+dwmisp_18)'    WMAX       = '1e-006-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+(dvthp_18+vthmisp_18)'
+LVTH0      = '-7.9573402e-009+dlvthp_18'
+WVTH0      = '-1.9783074e-008+dwvthp_18'
+PVTH0      = '1.4388817e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_18'
+LK2        = '1.295992e-008+dlk2p_18'
+WK2        = '2.0283992e-008+dwk2p_18'
+PK2        = '-1.1759136e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_18'
+LCIT       = '2.8646031e-010+dlcitp_18'
+WCIT       = '1.3305867e-010+dwcitp_18'
+PCIT       = '-1.7388141e-016+dpcitp_18'
+VOFF       = '-0.073036514+dvoffp_18'
+LVOFF      = '-1.0143628e-008+dlvoffp_18'
+WVOFF      = '-1.6821679e-008+dwvoffp_18'
+PVOFF      = '1.8385435e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_18'
+LU0        = '-1.6343677e-009+dlu0p_18'
+WU0        = '-1.4026636e-009+dwu0p_18'
+PU0        = '1.6621564e-015+dpu0p_18'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_18'  A0         = '2.1264181+da0p_18' LA0        = '-1.2324985e-006+dla0p_18'
+WA0        = '-3.7675707e-007+dwa0p_18'
+PA0        = '5.1526849e-013+dpa0p_18'
+AGS        = '0.24152159+dagsp_18'
+LAGS       = '1.3592834e-007+dlagsp_18'
+WAGS       = '6.9329848e-008+dwagsp_18'
+PAGS       = '-3.4458735e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_18'
+LPCLM      = '-2.323312e-007+dlpclmp_18'
+WPCLM      = '-2.0717704e-007+dwpclmp_18'
+PPCLM      = '2.6361305e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.14 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '7e-007-(dxlp_18+dlmisp_18)'    WMIN       = '6e-007-(dxwp_18+dwmisp_18)'    WMAX       = '1e-006-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.69392971+(dvthp_18+vthmisp_18)'
+LVTH0      = '3.5904762e-008+dlvthp_18'
+WVTH0      = '3.6431396e-008+dwvthp_18'
+PVTH0      = '-2.4118095e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.056981+dk2p_18' LK2        = '-4.6954695e-009+dlk2p_18'
+WK2        = '1.1651934e-009+dwk2p_18'
+PK2        = '1.3372409e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.6053841e-005+dcitp_18'
+LCIT       = '1.9867537e-010+dlcitp_18'
+WCIT       = '-4.8168809e-011+dwcitp_18'
+PCIT       = '-4.9740586e-017+dpcitp_18'
+VOFF       = '-0.1585485+dvoffp_18'
+LVOFF      = '4.8432079e-008+dlvoffp_18'
+WVOFF      = '4.4416767e-008+dwvoffp_18'
+PVOFF      = '-2.3562901e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.98182545+deta0p_18'
+LETA0      = '-2.1726296e-007+dleta0p_18'
+WETA0      = '-1.5716955e-007+dweta0p_18'
+PETA0      = '5.9614677e-014+dpeta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013590704+du0p_18'
+LU0        = '-1.6970388e-009+dlu0p_18'
+WU0        = '-2.41164e-009+dwu0p_18'
+PU0        = '2.3533052e-015+dpu0p_18'
+UA         = 1.3822488e-009      LUA        = -9.5202533e-016     WUA        = -1.1215123e-015
+PUA        = 7.6520029e-022      UB         = 4.2523021e-019      LUB        = 7.7972679e-025
+WUB        = 6.4094711e-025      PUB        = -4.4009553e-031     UC         = 2.9244119e-011
+LUC        = 1.5938293e-017      WUC        = -1.2591491e-017     PUC        = 3.1401282e-024
+VSAT       = '120000+dvsatp_18'  A0         = '-0.72475126+da0p_18'
+LA0        = '7.2055254e-007+dla0p_18'
+WA0        = '1.0298397e-006+dwa0p_18'
+PA0        = '-4.4825031e-013+dpa0p_18'
+AGS        = '0.47827608+dagsp_18'
+LAGS       = '-2.6248484e-008+dlagsp_18'
+WAGS       = '-2.5434931e-007+dwagsp_18'
+PAGS       = '1.8726148e-013+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.016556925         LKETA      = -2.0853335e-008
+WKETA      = -2.6719222e-008     PKETA      = 1.5664822e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.500404+dpclmp_18'
+LPCLM      = '4.7410182e-007+dlpclmp_18'
+WPCLM      = '4.774232e-007+dwpclmp_18'
+PPCLM      = '-2.0533812e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00085814023       LPDIBLC2   = -5.8097606e-010
+WPDIBLC2   = -8.5407722e-010     PPDIBLC2   = 5.8504289e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.002836154
+LTVOFF     = -7.3891568e-010     WTVOFF     = 1.7227432e-009      PTVOFF     = -1.8984045e-016
+KT1        = -0.20204794         LKT1       = -5.5033628e-008     WKT1       = -1.696216e-008
+PKT1       = 2.292413e-014       KT1L       = 0                   KT2        = -0.070902278
+LKT2       = 3.3231253e-009      WKT2       = -2.3320582e-009     PKT2       = 2.8535766e-015
+UTE        = -0.91151582         LUTE       = -1.4167628e-007     WUTE       = 1.0302888e-007
+PUTE       = -7.9995661e-014     UA1        = 2.6228981e-009      LUA1       = -9.8687309e-016
+WUA1       = 2.0802761e-016      PUA1       = -5.3728429e-024     UB1        = -4.4978011e-018
+LUB1       = 1.5789137e-024      WUB1       = 9.670389e-025       PUB1       = -7.0324544e-031
+UC1        = 6.8312674e-011      LUC1       = -2.7390649e-017     WUC1       = -1.0991737e-017
+PUC1       = 1.4685771e-024      PRT        = 0                   AT         = -159164.07
+LAT        = 0.079546663         WAT        = 0.093253222         PAT        = -5.9837948e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.15 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxlp_18+dlmisp_18)'  WMIN       = '6e-007-(dxwp_18+dwmisp_18)'    WMAX       = '1e-006-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.5067577+(dvthp_18+vthmisp_18)'
+LVTH0      = '-3.2413023e-008+dlvthp_18'
+WVTH0      = '-5.5540886e-008+dwvthp_18'
+PVTH0      = '9.4517879e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.0081827813+dk2p_18'
+LK2        = '-2.2506819e-008+dlk2p_18'
+WK2        = '-2.4061562e-008+dwk2p_18'
+PK2        = '1.0545007e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070009869+dcitp_18'
+LCIT       = '-8.82703e-011+dlcitp_18'
+WCIT       = '-4.6086901e-010+dwcitp_18'
+PCIT       = '1.0089499e-016+dpcitp_18'
+VOFF       = '0.017174816+dvoffp_18'
+LVOFF      = '-1.5706929e-008+dlvoffp_18'
+WVOFF      = '-4.7903266e-008+dwvoffp_18'
+PVOFF      = '1.0133911e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.01118986+deta0p_18'
+LETA0      = '1.3701903e-007+dleta0p_18'
+WETA0      = '5.014916e-008+dweta0p_18'
+PETA0      = '-1.6056652e-014+dpeta0p_18'
+ETAB       = -0.029119931        LETAB      = -1.7096607e-008     WETAB      = 4.1781416e-009
+PETAB      = -3.1202288e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0030644114+du0p_18'
+LU0        = '2.145058e-009+dlu0p_18'
+WU0        = '5.0996631e-009+dwu0p_18'
+PU0        = '-3.8832044e-016+dpu0p_18'
+UA         = -2.5009653e-009     LUA        = 4.6534778e-016      WUA        = 1.6217792e-015
+PUA        = -2.3610111e-022     UB         = 1.0680103e-018      LUB        = 5.4511207e-025
+WUB        = -5.6666603e-025     PUB        = 6.8326177e-034      UC         = 1.2523854e-010
+LUC        = -1.9099671e-017     WUC        = -4.9445587e-017     PUC        = 1.6591873e-023
+VSAT       = '120000+dvsatp_18'  A0         = '2.493794+da0p_18'  LA0        = '-4.5421648e-007+dla0p_18'
+WA0        = '-7.7517834e-007+dwa0p_18'
+PA0        = '2.1058128e-013+dpa0p_18'
+AGS        = '-0.56632958+dagsp_18'
+LAGS       = '3.5503258e-007+dlagsp_18'
+WAGS       = '4.9858626e-007+dwagsp_18'
+PAGS       = '-8.7559996e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1798753          LKETA      = 5.0844428e-008
+WKETA      = 4.3559769e-008      PKETA      = -9.9870096e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.81372593+dpclmp_18'
+LPCLM      = '-5.5556027e-009+dlpclmp_18'
+WPCLM      = '-7.1793742e-008+dwpclmp_18'
+PPCLM      = '-4.873934e-015+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0043099773       LPDIBLC2   = 1.3053868e-009
+WPDIBLC2   = 3.4153729e-009      PPDIBLC2   = -9.733064e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0025684765
+LTVOFF     = -6.4121339e-010     WTVOFF     = 2.2814996e-009      PTVOFF     = -3.9378654e-016
+KT1        = -0.49760571         LKT1       = 5.2844959e-008      WKT1       = 1.1947371e-007
+PKT1       = -2.6874963e-014     KT1L       = 0                   KT2        = -0.088716077
+LKT2       = 9.825162e-009       WKT2       = 9.3088129e-010      PKT2       = 1.6626037e-015
+UTE        = -1.6168123          LUTE       = 1.1575694e-007      WUTE       = -2.3469415e-007
+PUTE       = 4.3273246e-014      UA1        = -3.673827e-009      LUA1       = 1.3114316e-015
+WUA1       = 4.511145e-017       PUA1       = 5.4091557e-023      UB1        = 7.5163146e-018
+LUB1       = -2.8062385e-024     WUB1       = -1.6210833e-024     PUB1       = 2.4141916e-031
+UC1        = 4.9793198e-012      LUC1       = -4.2739747e-018     WUC1       = 1.259364e-017
+PUC1       = -7.1400855e-024     PRT        = 0                   AT         = 195098.16
+LAT        = -0.049759049        WAT        = -0.21500435         PAT        = 5.2676066e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_18+dlmisp_18)'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+(dvthp_18+vthmisp_18)'
+WVTH0      = '-1.235245e-008+dwvthp_18'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_18'
+WK2        = '1.0981328e-008+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.082272655+dvoffp_18'
+WVOFF      = '-7.9883294e-009+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_18'
+WU0        = '5.0645045e-010+dwu0p_18'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.517435+da0p_18'  WA0        = '-5.0645045e-008+dwa0p_18'
+AGS        = '0.2802775+dagsp_18'
+WAGS       = '4.3233575e-009+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_18'
+WPCLM      = '-1.235245e-008+dwpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LU0        = '0+dlu0p_18'
+PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'
+PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'
+PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'       LPCLM      = '0+dlpclmp_18'
+PPCLM      = '0+dppclmp_18'      LETA0      = '0+dleta0p_18'      PETA0      = '0+dpeta0p_18'
+LVOFF      = '0+dlvoffp_18'      PVOFF      = '0+dpvoffp_18'      LK2        = '0+dlk2p_18'
+PK2        = '0+dpk2p_18'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_18+dlmisp_18)'
+LMAX       = '1e-005-(dxlp_18+dlmisp_18)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+(dvthp_18+vthmisp_18)'
+LVTH0      = '1.3084693e-008+dlvthp_18'
+WVTH0      = '-1.2202747e-008+dwvthp_18'
+PVTH0      = '-1.4947872e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_18'
+LK2        = '1.8463044e-008+dlk2p_18'
+WK2        = '1.2034241e-008+dwk2p_18'
+PK2        = '-1.0513336e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.08299213+dvoffp_18'
+LVOFF      = '7.1839623e-009+dlvoffp_18'
+WVOFF      = '-8.5066354e-009+dwvoffp_18'
+PVOFF      = '5.1752854e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_18'
+LU0        = '8.2354975e-011+dlu0p_18'
+WU0        = '4.6486621e-010+dwu0p_18'
+PU0        = '4.1521866e-016+dpu0p_18'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.5401338+da0p_18' LA0        = '-2.2664761e-007+dla0p_18'
+WA0        = '-4.3825229e-008+dwa0p_18'
+PA0        = '-6.809586e-014+dpa0p_18'
+AGS        = '0.25532754+dagsp_18'
+LAGS       = '2.4912535e-007+dlagsp_18'
+WAGS       = '8.4219004e-009+dwagsp_18'
+PAGS       = '-4.0923951e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_18'
+LPCLM      = '4.3261573e-007+dlpclmp_18'
+WPCLM      = '-4.0356016e-009+dwpclmp_18'
+PPCLM      = '-8.3043732e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.18 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '1.2e-006-(dxlp_18+dlmisp_18)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+(dvthp_18+vthmisp_18)'
+LVTH0      = '1.3104488e-008+dlvthp_18'
+WVTH0      = '-1.4817999e-008+dwvthp_18'
+PVTH0      = '1.6042868e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_18'
+LK2        = '-2.3393752e-008+dlk2p_18'
+WK2        = '-5.536121e-009+dwk2p_18'
+PK2        = '1.0307543e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.10923032+dvoffp_18'
+LVOFF      = '3.8276211e-008+dlvoffp_18'
+WVOFF      = '5.1479577e-009+dwvoffp_18'
+PVOFF      = '-1.1005407e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_18'
+LU0        = '1.9298762e-009+dlu0p_18'
+WU0        = '1.2383331e-009+dwu0p_18'
+PU0        = '-5.0133962e-016+dpu0p_18'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.8892247+da0p_18' LA0        = '-6.4032034e-007+dla0p_18'
+WA0        = '-2.3278069e-007+dwa0p_18'
+PA0        = '1.5581636e-013+dpa0p_18'
+AGS        = '0.50163406+dagsp_18'
+LAGS       = '-4.2747874e-008+dlagsp_18'
+WAGS       = '-8.855842e-008+dwagsp_18'
+PAGS       = '7.3997729e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_18'
+LPCLM      = '3.733935e-009+dlpclmp_18'
+WPCLM      = '-1.7565184e-007+dwpclmp_18'
+PPCLM      = '1.2032151e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.19 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_18+dlmisp_18)'
+LMAX       = '7e-007-(dxlp_18+dlmisp_18)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63703339+(dvthp_18+vthmisp_18)'
+LVTH0      = '1.238952e-008+dlvthp_18'
+WVTH0      = '1.8953291e-009+dwvthp_18'
+PVTH0      = '-9.8443429e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.070684483+dk2p_18'
+LK2        = '-2.5242368e-009+dlk2p_18'
+WK2        = '9.4832075e-009+dwk2p_18'
+PK2        = '1.9302633e-017+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.6494656e-005+dcitp_18'
+LCIT       = '-3.527384e-011+dlcitp_18'
+WCIT       = '-1.3469575e-010+dwcitp_18'
+PCIT       = '9.2266587e-017+dpcitp_18'
+VOFF       = '-0.077660392+dvoffp_18'
+LVOFF      = '1.6650813e-008+dlvoffp_18'
+WVOFF      = '-4.682312e-009+dwvoffp_18'
+PVOFF      = '-4.2716727e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.47744455+deta0p_18'
+LETA0      = '6.2889491e-009+dleta0p_18'
+WETA0      = '1.4898966e-007+dweta0p_18'
+PETA0      = '-7.6081329e-014+dpeta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0078316258+du0p_18'
+LU0        = '2.8318066e-009+dlu0p_18'
+WU0        = '1.0841205e-009+dwu0p_18'
+PU0        = '-3.9570398e-016+dpu0p_18'
+UA         = -9.9789287e-010     LUA        = 6.6674929e-016      WUA        = 3.232337e-016
+PUA        = -2.1739591e-022     UB         = 1.890541e-018       LUB        = -1.2815735e-025
+WUB        = -2.4849655e-025     PUB        = 1.1099014e-031      UC         = -3.3997165e-011
+LUC        = 4.3196624e-017      WUC        = 2.5795969e-017      PUC        = -1.3405679e-023
+VSAT       = '120000+dvsatp_18'  A0         = '-0.15470335+da0p_18'
+LA0        = '7.5977038e-007+dla0p_18'
+WA0        = '6.8382063e-007+dwa0p_18'
+PA0        = '-4.7205555e-013+dpa0p_18'
+AGS        = '0.10781513+dagsp_18'
+LAGS       = '2.2701809e-007+dlagsp_18'
+WAGS       = '-2.9479508e-008+dwagsp_18'
+PAGS       = '3.3528674e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.030607227        LKETA      = 4.9059202e-009
+WKETA      = 1.9094186e-009      PKETA      = 2.895395e-017       DWG        = 0
+DWB        = 0                   PCLM       = '-0.090043958+dpclmp_18'
+LPCLM      = '3.9349411e-007+dlpclmp_18'
+WPCLM      = '2.2833465e-007+dwpclmp_18'
+PPCLM      = '-1.5640924e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00061167969       LPDIBLC2   = -4.1215059e-010
+WPDIBLC2   = -7.0447566e-010     PPDIBLC2   = 4.8256583e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0082648363
+LTVOFF     = -2.2727898e-009     WTVOFF     = -1.5724669e-009     PTVOFF     = 7.4122112e-016
+KT1        = -0.19230335         LKT1       = -5.3678414e-008     WKT1       = -2.2877123e-008
+PKT1       = 2.2101515e-014      KT1L       = 0                   KT2        = -0.076128019
+LKT2       = 3.9538328e-009      WKT2       = 8.399666e-010       PKT2       = 2.4707371e-015
+UTE        = 0.58430742          LUTE       = -1.0382562e-006     WUTE       = -8.0493582e-007
+PUTE       = 4.6422833e-013      UA1        = 7.9580462e-009      LUA1       = -3.9680757e-015
+WUA1       = -3.0304073e-015     PUA1       = 1.8042171e-021      UB1        = -6.5789123e-018
+LUB1       = 2.5859383e-024      WUB1       = 2.2302735e-024      PUB1       = -1.3145093e-030
+UC1        = 1.2043095e-010      LUC1       = -5.3909297e-017     WUC1       = -4.2627533e-017
+PUC1       = 1.7565396e-023      PRT        = 0                   AT         = 121939.93
+LAT        = -0.073315847        WAT        = -0.077376905        PAT        = 3.2949595e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_18.20 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-(dxlp_18+dlmisp_18)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_18+dwmisp_18)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_18+toxmisp_18)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_18+dlmisp_18)'  XW         = '7e-09+(dxwp_18+dwmisp_18)'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.55860975+(dvthp_18+vthmisp_18)'
+LVTH0      = '-1.6235109e-008+dlvthp_18'
+WVTH0      = '-2.406669e-008+dwvthp_18'
+PVTH0      = '-3.6820595e-016+dpvthp_18'
+K1         = 0.72417             K2         = '-0.065028842+dk2p_18'
+LK2        = '-4.5885458e-009+dlk2p_18'
+WK2        = '1.0443997e-008+dwk2p_18'
+PK2        = '-3.3138535e-016+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0013748333+dcitp_18'
+LCIT       = '4.8716087e-010+dlcitp_18'
+WCIT       = '7.9861472e-010+dwcitp_18'
+PCIT       = '-2.4839173e-016+dpcitp_18'
+VOFF       = '-0.050350218+dvoffp_18'
+LVOFF      = '6.6825998e-009+dlvoffp_18'
+WVOFF      = '-6.9155706e-009+dwvoffp_18'
+PVOFF      = '-3.4565333e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.33230907+deta0p_18'
+LETA0      = '5.9263401e-008+dleta0p_18'
+WETA0      = '-1.447702e-007+dweta0p_18'
+PETA0      = '3.1141018e-014+dpeta0p_18'
+ETAB       = -0.031595123        LETAB      = -3.3565264e-008     WETAB      = 5.6805829e-009
+PETAB      = 6.8762461e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.022434483+du0p_18'
+LU0        = '-2.4982364e-009+dlu0p_18'
+WU0        = '-6.6579706e-009+dwu0p_18'
+PU0        = '2.4301593e-015+dpu0p_18'
+UA         = 3.3367804e-009      LUA        = -9.1540647e-016     WUA        = -1.9217324e-015
+PUA        = 6.0201672e-022      UB         = -1.2534117e-018     LUB        = 1.0193854e-024
+WUB        = 8.4243709e-025      PUB        = -2.8720064e-031     UC         = 6.9600342e-011
+LUC        = 5.383534e-018       WUC        = -1.56732e-017       PUC        = 1.730568e-024
+VSAT       = '120000+dvsatp_18'  A0         = '3.7602519+da0p_18' LA0        = '-6.6918829e-007+dla0p_18'
+WA0        = '-1.5439183e-006+dwa0p_18'
+PA0        = '3.4106917e-013+dpa0p_18'
+AGS        = '-0.27523098+dagsp_18'
+LAGS       = '3.6682992e-007+dlagsp_18'
+WAGS       = '3.2188941e-007+dwagsp_18'
+PAGS       = '-9.472098e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1057803          LKETA      = 3.2344091e-008
+WKETA      = -1.4158996e-009     PKETA      = 1.2426951e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.6985672+dpclmp_18'
+LPCLM      = '-2.5934897e-007+dlpclmp_18'
+WPCLM      = '-6.0889241e-007+dwpclmp_18'
+PPCLM      = '1.4917864e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0001163125       LPDIBLC2   = -1.4643344e-010
+WPDIBLC2   = 8.6981835e-010      PPDIBLC2   = -9.2051487e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00038167646
+LTVOFF     = 8.8318738e-010      WTVOFF     = 4.0722425e-009      PTVOFF     = -1.3190978e-015
+KT1        = -0.55188969         LKT1       = 7.7570598e-008      WKT1       = 1.5242409e-007
+PKT1       = -4.1883427e-014     KT1L       = 0                   KT2        = -0.084262275
+LKT2       = 6.9228364e-009      WKT2       = -1.7725766e-009     PKT2       = 3.4243153e-015
+UTE        = -4.413831           LUTE       = 7.8606438e-007      WUTE       = 1.4630962e-006
+PUTE       = -3.6360337e-013     UA1        = -1.2992661e-008     LUA1       = 3.6789326e-015
+WUA1       = 5.7016439e-015      PUA1       = -1.3829815e-021     UB1        = 1.0411731e-017
+LUB1       = -3.6156465e-024     WUB1       = -3.378601e-024      PUB1       = 7.3272984e-031
+UC1        = -8.9982585e-011     LUC1       = 2.2891645e-017      WUC1       = 7.0235516e-017
+PUC1       = -2.3629617e-023     PRT        = 0                   AT         = -223731.43
+LAT        = 0.052854199         WAT        = 0.039225205         PAT        = -9.6101752e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_18'
+NOIB       = 'noibpmac_18'
+NOIC       = 'noicpmac_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_18_mac
.ENDL MAC_18








.LIB MAC_25
**********************************************************************************************
*                                                                                            *
*                                   2.5V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_25_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwn_25'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_25 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_25  temp2=parn2_25
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='l*scale-0.015e-6'
+       wef='w/nf*scale+0.007e-6'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_25='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisn_25='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_25='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_25='0.00275107*geo_fac*toxn_25*fac2*mismatchflag' 
.param tnoiax='6.365e4/(l*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(l*scale*1e6)+0.5356'

.param fn_dice='noiseflagn_25_mc*par1fn_mc+noiseflagn_25_mc_mis*par2fn_25_mc'
.param arearatio='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noianmac_25='c1fn_25*2.718**((fn_dice+(1-fn_dice)*noiseflagn_25)*arearatio)'
.param noibnmac_25='c2fn_25*2.718**((fn_dice+(1-fn_dice)*noiseflagn_25)*arearatio)'
.param noicnmac_25='c3fn_25*2.718**((fn_dice+(1-fn_dice)*noiseflagn_25)*arearatio)'

.MODEL nch_25.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_25+dlmisn_25)'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-(dxwn_25+dwmisn_25)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+(dvthn_25+vthmisn_25)'
+K1         = 0.71631             K2         = '-0.048803+dk2n_25' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_25'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_25'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_25'   A0         = '1.1773+da0n_25'    AGS        = '0.3986+dagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       WVTH0      = '0+dwvthn_25'
+PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       LA0        = '0+dla0n_25'        WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'       WAGS       = '0+dwagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      WETA0      = '0+dweta0n_25'
+PETA0      = '0+dpeta0n_25'      LK2        = '0+dlk2n_25'        WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_25+dlmisn_25)'
+LMAX       = '1e-005-(dxln_25+dlmisn_25)'    WMIN       = '1e-005-(dxwn_25+dwmisn_25)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+(dvthn_25+vthmisn_25)'
+LVTH0      = '1.4790281e-008+dlvthn_25'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_25'
+LK2        = '-1.2153578e-008+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_25'
+LCIT       = '7.5887589e-010+dlcitn_25'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_25'
+LU0        = '2.6891421e-011+dlu0n_25'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.2321467+da0n_25' LA0        = '-5.4764378e-007+dla0n_25'
+AGS        = '0.38027424+dagsn_25'
+LAGS       = '1.8298267e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'        WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'        PA0        = '0+dpa0n_25'
+WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'
+WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_25+dlmisn_25)'
+LMAX       = '1.2e-006-(dxln_25+dlmisn_25)'  WMIN       = '1e-005-(dxwn_25+dwmisn_25)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+(dvthn_25+vthmisn_25)'
+LVTH0      = '3.2469e-010+dlvthn_25'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_25'
+LK2        = '-6.7649162e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_25'
+LCIT       = '5.941827e-011+dlcitn_25'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_25'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_25'
+A0         = '1.3065331+da0n_25' LA0        = '-6.3579172e-007+dla0n_25'
+AGS        = '0.9247153+dagsn_25'
+LAGS       = '-4.6217998e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'
+WCIT       = '0+dwcitn_25'       PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'
+LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'
+LETA0      = '0+dleta0n_25'      WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'
+WK2        = '0+dwk2n_25'        PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.4 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_25+dlmisn_25)'
+LMAX       = '7e-007-(dxln_25+dlmisn_25)'    WMIN       = '1e-005-(dxwn_25+dwmisn_25)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59985+(dvthn_25+vthmisn_25)'
+LVTH0      = '-2.50025e-009+dlvthn_25'
+K1         = 0.71631             K2         = '-0.060148641+dk2n_25'
+LK2        = '-1.2743462e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00063515313+dcitn_25'
+LCIT       = '1.1360511e-010+dlcitn_25'
+VOFF       = -0.14569953         LVOFF      = 1.2165279e-008      NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_25'   UA         = -6.221e-010
+LUA        = -1.650165e-016      UB         = 2.8987125e-018      LUB        = 6.9381938e-026
+UC         = 1.8519984e-010      LUC        = -1.7056393e-017     VSAT       = '89640+dvsatn_25'
+A0         = '1.1521358+da0n_25' LA0        = '-5.3002956e-007+dla0n_25'
+AGS        = '-2.0187031+dagsn_25'
+LAGS       = '1.5540616e-006+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.053365313        LKETA      = 1.4642089e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.268725+dpclmn_25'
+LPCLM      = '-1.6251625e-008+dlpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00478125          LPDIBLC2   = -1.5626563e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0011922813        LTVOFF     = 1.4845234e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29436875         LKT1       = 5.9380938e-009
+KT1L       = 0                   KT2        = -0.055789375        LKT2       = -2.7815281e-009
+UTE        = -1.3999688          LUTE       = 1.1094859e-007      UA1        = 2.5822766e-009
+LUA1       = 2.1799055e-017      UB1        = -3.2810594e-018     LUB1       = 9.4228172e-026
+UC1        = -4.6245625e-011     LUC1       = 4.3535603e-017      PRT        = 0
+AT         = 14157.766           LAT        = -0.0055325845
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'
+WCIT       = '0+dwcitn_25'       PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.5 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxln_25+dlmisn_25)'  WMIN       = '1e-005-(dxwn_25+dwmisn_25)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5771+(dvthn_25+vthmisn_25)'
+LVTH0      = '5.8035e-009+dlvthn_25'
+K1         = 0.71631             K2         = '-0.086854+dk2n_25' LK2        = '8.47311e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00159936+dcitn_25'
+LCIT       = '-2.383304e-010+dlcitn_25'
+VOFF       = -0.094509           LVOFF      = -6.519265e-009      NFACTOR    = 0.55
+ETA0       = '0.3724505+deta0n_25'
+LETA0      = '5.5936068e-008+dleta0n_25'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03148355+du0n_25'
+LU0        = '2.6048043e-009+dlu0n_25'
+UA         = -1.138065e-009      LUA        = 2.3310725e-017      UB         = 2.59272e-018
+LUB        = 1.810692e-025       UC         = 2.917725e-010       LUC        = -5.5955413e-017
+VSAT       = '106268.75+dvsatn_25'
+LVSAT      = '-0.0060694938+dlvsatn_25'
+A0         = '1.025+da0n_25'     LA0        = '-4.83625e-007+dla0n_25'
+AGS        = '4.79731+dagsn_25'  LAGS       = '-9.3378315e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.09492035         LKETA      = 2.9809678e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2926495+dpclmn_25'
+LPCLM      = '-2.4984068e-008+dlpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000394            LPDIBLC2   = 3.869e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0027173           LTVOFF     = -4.081795e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.375355           LKT1       = 3.5498075e-008
+KT1L       = 0                   KT2        = -0.164534           LKT2       = 3.691026e-008
+UTE        = -1.3504             LUTE       = 9.2856e-008         UA1        = 3.44283e-009
+LUA1       = -2.9230295e-016     UB1        = -4.38606e-018       LUB1       = 4.975534e-025
+UC1        = 1.41029e-010        LUC1       = -2.4819635e-017     PRT        = 0
+AT         = -32800              LAT        = 0.011607
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'        WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'        PA0        = '0+dpa0n_25'
+WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'       WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_25+dlmisn_25)'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-(dxwn_25+dwmisn_25)'    WMAX       = '1e-005-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+(dvthn_25+vthmisn_25)'
+WVTH0      = '-1.9034426e-009+dwvthn_25'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_25'
+WK2        = '8.915949e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_25'
+WCIT       = '3.148518e-010+dwcitn_25'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_25'
+WU0        = '-6.4829015e-009+dwu0n_25'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.1644663+da0n_25' WA0        = '1.2842639e-007+dwa0n_25'
+AGS        = '0.4003119+dagsn_25'
+WAGS       = '-1.7130983e-008+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       PCIT       = '0+dpcitn_25'
+LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'
+LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_25+dlmisn_25)'
+LMAX       = '1e-005-(dxln_25+dlmisn_25)'    WMIN       = '1e-006-(dxwn_25+dwmisn_25)'    WMAX       = '1e-005-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+(dvthn_25+vthmisn_25)'
+LVTH0      = '1.6445149e-008+dlvthn_25'
+WVTH0      = '-2.4492827e-010+dwvthn_25'
+PVTH0      = '-1.6560265e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_25'
+LK2        = '-1.2004489e-008+dlk2n_25'
+WK2        = '9.0653661e-009+dwk2n_25'
+PK2        = '-1.4919294e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_25'
+LCIT       = '8.1447946e-010+dlcitn_25'
+WCIT       = '3.7057788e-010+dwcitn_25'
+PCIT       = '-5.5642492e-016+dpcitn_25'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_25'
+LU0        = '1.1847165e-011+dlu0n_25'
+WU0        = '-6.4979789e-009+dwu0n_25'
+PU0        = '1.5054787e-016+dpu0n_25'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_25'   A0         = '1.2162348+da0n_25' LA0        = '-5.1690836e-007+dla0n_25'
+WA0        = '1.5922953e-007+dwa0n_25'
+PA0        = '-3.0756929e-013+dpa0n_25'
+AGS        = '0.38190343+dagsn_25'
+LAGS       = '1.838086e-007+dlagsn_25'
+WAGS       = '-1.6303234e-008+dwagsn_25'
+PAGS       = '-8.2650779e-015+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.8 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_25+dlmisn_25)'
+LMAX       = '1.2e-006-(dxln_25+dlmisn_25)'  WMIN       = '1e-006-(dxwn_25+dwmisn_25)'    WMAX       = '1e-005-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+(dvthn_25+vthmisn_25)'
+LVTH0      = '1.7778581e-009+dlvthn_25'
+WVTH0      = '-1.9482295e-009+dwvthn_25'
+PVTH0      = '-1.4541854e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_25'
+LK2        = '-6.2688409e-009+dlk2n_25'
+WK2        = '1.1995574e-008+dwk2n_25'
+PK2        = '-4.9642252e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_25'
+LCIT       = '6.6229996e-011+dlcitn_25'
+WCIT       = '-4.145586e-011+dwcitn_25'
+PCIT       = '-6.8164938e-017+dpcitn_25'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_25'
+LU0        = '-3.4512743e-011+dlu0n_25'
+WU0        = '-6.662385e-009+dwu0n_25'
+PU0        = '3.4536902e-016+dpu0n_25'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.3201499+da0n_25' LA0        = '-6.4004769e-007+dla0n_25'
+WA0        = '-1.3626309e-007+dwa0n_25'
+PA0        = '4.2589454e-014+dpa0n_25'
+AGS        = '0.94327311+dagsn_25'
+LAGS       = '-4.8141448e-007+dlagsn_25'
+WAGS       = '-1.8570803e-007+dwagsn_25'
+PAGS       = '1.9247961e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.9 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_25+dlmisn_25)'
+LMAX       = '7e-007-(dxln_25+dlmisn_25)'    WMIN       = '1e-006-(dxwn_25+dwmisn_25)'    WMAX       = '1e-005-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+(dvthn_25+vthmisn_25)'
+LVTH0      = '-3.3832116e-009+dlvthn_25'
+WVTH0      = '-3.6076185e-008+dwvthn_25'
+PVTH0      = '8.8357962e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.061138887+dk2n_25'
+LK2        = '-9.2107413e-010+dlk2n_25'
+WK2        = '9.9093956e-009+dwk2n_25'
+PK2        = '-3.5351933e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitn_25'
+LCIT       = '1.1765275e-010+dlcitn_25'
+WCIT       = '-8.1835785e-011+dwcitn_25'
+PCIT       = '-4.050469e-017+dpcitn_25'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0n_25'
+LETA0      = '-3.8911504e-009+dleta0n_25'
+WETA0      = '-7.9238321e-008+dweta0n_25'
+PETA0      = '3.8938742e-014+dpeta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0n_25'
+LU0        = '-6.818911e-010+dlu0n_25'
+WU0        = '-1.6119779e-008+dwu0n_25'
+PU0        = '6.8236842e-015+dpu0n_25'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatn_25'
+LVSAT      = '0.00017484387+dlvsatn_25'
+WVSAT      = '0.002554252+dwvsatn_25'
+PVSAT      = '-1.7496626e-009+dpvsatn_25'
+A0         = '1.1807466+da0n_25' LA0        = '-5.4455646e-007+dla0n_25'
+WA0        = '-2.8630873e-007+dwa0n_25'
+PA0        = '1.4537072e-013+dpa0n_25'
+AGS        = '-2.065376+dagsn_25'
+LAGS       = '1.5795102e-006+dlagsn_25'
+WAGS       = '4.6705548e-007+dwagsn_25'
+PAGS       = '-2.546634e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmn_25'
+LPCLM      = '-2.7249305e-008+dlpclmn_25'
+WPCLM      = '-1.6066245e-007+dwpclmn_25'
+PPCLM      = '1.1005378e-013+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.10 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxln_25+dlmisn_25)'  WMIN       = '1e-006-(dxwn_25+dwmisn_25)'    WMAX       = '1e-005-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58142898+(dvthn_25+vthmisn_25)'
+LVTH0      = '4.65632e-009+dlvthn_25'
+WVTH0      = '-4.3320114e-008+dwvthn_25'
+PVTH0      = '1.147983e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.083157012+dk2n_25'
+LK2        = '7.1155415e-009+dlk2n_25'
+WK2        = '-3.6995758e-008+dwk2n_25'
+PK2        = '1.3585188e-014+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0016696855+dcitn_25'
+LCIT       = '-2.5696666e-010+dlcitn_25'
+WCIT       = '-7.0374751e-010+dwcitn_25'
+PCIT       = '1.8649309e-016+dpcitn_25'
+VOFF       = -0.088709128        LVOFF      = -7.4110351e-009     WVOFF      = -5.8039324e-008
+PVOFF      = 8.9239435e-015      NFACTOR    = 0.55                ETA0       = '0.33936373+deta0n_25'
+LETA0      = '6.7011766e-008+dleta0n_25'
+WETA0      = '3.3109936e-007+dweta0n_25'
+PETA0      = '-1.1083451e-013+dpeta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.030175686+du0n_25'
+LU0        = '2.9882438e-009+dlu0n_25'
+WU0        = '1.3087791e-008+dwu0n_25'
+PU0        = '-3.8370791e-015+dpu0n_25'
+UA         = -1.228116e-009      LUA        = 4.5226192e-017      WUA        = 9.0114011e-016
+PUA        = -2.1930808e-022     UB         = 2.570298e-018       LUB        = 1.9430506e-025
+WUB        = 2.2437669e-025      PUB        = -1.3245125e-031     UC         = 3.0335865e-010
+LUC        = -5.9025742e-017     WUC        = -1.1594261e-016     PUC        = 3.0724791e-023
+VSAT       = '106277.56+dvsatn_25'
+LVSAT      = '-0.005991031+dlvsatn_25'
+WVSAT      = '-8.8174179e-005+dwvsatn_25'
+PVSAT      = '-7.8517707e-010+dpvsatn_25'
+A0         = '0.95451+da0n_25'   LA0        = '-4.6198009e-007+dla0n_25'
+WA0        = '7.0539343e-007+dwa0n_25'
+PA0        = '-2.1660057e-013+dpa0n_25'
+AGS        = '4.7706648+dagsn_25'
+LAGS       = '-9.1564472e-007+dlagsn_25'
+WAGS       = '2.6663872e-007+dwagsn_25'
+PAGS       = '-1.8151128e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.098453102        LKETA      = 3.0884888e-008
+WKETA      = 3.5352247e-008      PKETA      = -1.0759633e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.26948005+dpclmn_25'
+LPCLM      = '-2.1664821e-008+dlpclmn_25'
+WPCLM      = '2.3185666e-007+dwpclmn_25'
+PPCLM      = '-3.3215697e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00043695717       LPDIBLC2   = 4.3021146e-011
+WPDIBLC2   = -4.2987236e-010     PPDIBLC2   = -4.3341774e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0027434372
+LTVOFF     = -4.1510587e-010     WTVOFF     = -2.6155541e-010     PTVOFF     = 6.9312182e-017
+KT1        = -0.39571654         LKT1       = 4.0389824e-008      WKT1       = 2.0375793e-007
+PKT1       = -4.8951729e-014     KT1L       = 0                   KT2        = -0.17137354
+LKT2       = 3.8914578e-008      WKT2       = 6.8443317e-008      PKT2       = -2.0057213e-014
+UTE        = -1.3896059          LUTE       = 1.0324556e-007      WUTE       = 3.9233311e-007
+PUTE       = -1.0396827e-013     UA1        = 3.3235151e-009      LUA1       = -2.5920789e-016
+WUA1       = 1.1939848e-015      PUA1       = -3.3118227e-022     UB1        = -4.1858919e-018
+LUB1       = 4.3688273e-025      WUB1       = -2.0030822e-024     PUB1       = 6.071314e-031
+UC1        = 1.5268558e-010      LUC1       = -2.7611828e-017     WUC1       = -1.1664744e-016
+PUC1       = 2.7941474e-023      PRT        = 0                   AT         = -33393.011
+LAT        = 0.011823449         WAT        = 0.0059342622        PAT        = -2.1660057e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_25+dlmisn_25)'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-(dxwn_25+dwmisn_25)'    WMAX       = '1e-006-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+(dvthn_25+vthmisn_25)'
+WVTH0      = '-3.8203063e-009+dwvthn_25'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_25'
+WK2        = '2.9951201e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_25'
+WCIT       = '-9.5507656e-011+dwcitn_25'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_25'
+WU0        = '-4.3551491e-009+dwu0n_25'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.472886+da0n_25'  WA0        = '-1.821522e-007+dwa0n_25'
+AGS        = '0.4053948+dagsn_25'
+WAGS       = '-2.2249464e-008+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       PCIT       = '0+dpcitn_25'
+LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'
+LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_25+dlmisn_25)'
+LMAX       = '1e-005-(dxln_25+dlmisn_25)'    WMIN       = '6e-007-(dxwn_25+dwmisn_25)'    WMAX       = '1e-006-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+(dvthn_25+vthmisn_25)'
+LVTH0      = '1.4894822e-008+dlvthn_25'
+WVTH0      = '-2.3181445e-009+dwvthn_25'
+PVTH0      = '-1.4999085e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_25'
+LK2        = '-1.6226287e-008+dlk2n_25'
+WK2        = '2.7187635e-009+dwk2n_25'
+PK2        = '2.7594208e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_25'
+LCIT       = '2.1866624e-010+dlcitn_25'
+WCIT       = '-9.9870099e-011+dwcitn_25'
+PCIT       = '4.3558988e-017+dpcitn_25'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_25'
+LU0        = '-2.2871153e-009+dlu0n_25'
+WU0        = '-4.6020798e-009+dwu0n_25'
+PU0        = '2.4656031e-015+dpu0n_25'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.5788249+da0n_25' LA0        = '-1.0578002e-006+dla0n_25'
+WA0        = '-2.0589871e-007+dwa0n_25'
+PA0        = '2.3710883e-013+dpa0n_25'
+AGS        = '0.39080402+dagsn_25'
+LAGS       = '1.4568891e-007+dlagsn_25'
+WAGS       = '-2.5266134e-008+dwagsn_25'
+PAGS       = '3.0121451e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.13 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_25+dlmisn_25)'
+LMAX       = '1.2e-006-(dxln_25+dlmisn_25)'  WMIN       = '6e-007-(dxwn_25+dwmisn_25)'    WMAX       = '1e-006-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+(dvthn_25+vthmisn_25)'
+LVTH0      = '-3.5476441e-009+dlvthn_25'
+WVTH0      = '-7.2295476e-009+dwvthn_25'
+PVTH0      = '-9.1790728e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_25'
+LK2        = '-1.1063061e-008+dlk2n_25'
+WK2        = '5.1625327e-009+dwk2n_25'
+PK2        = '-1.3644568e-016+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_25'
+LCIT       = '4.2051414e-012+dlcitn_25'
+WCIT       = '-5.8296345e-011+dwcitn_25'
+PCIT       = '-5.7059101e-018+dpcitn_25'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_25'
+LU0        = '-3.7564604e-009+dlu0n_25'
+WU0        = '-5.975723e-009+dwu0n_25'
+PU0        = '4.0933703e-015+dpu0n_25'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.2496434+da0n_25' LA0        = '-6.6772012e-007+dla0n_25'
+WA0        = '-6.5263056e-008+dwa0n_25'
+PA0        = '7.0455585e-014+dpa0n_25'
+AGS        = '0.79778898+dagsn_25'
+LAGS       = '-3.3658827e-007+dlagsn_25'
+WAGS       = '-3.9205511e-008+dwagsn_25'
+PAGS       = '4.6639613e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.14 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_25+dlmisn_25)'
+LMAX       = '7e-007-(dxln_25+dlmisn_25)'    WMIN       = '6e-007-(dxwn_25+dwmisn_25)'    WMAX       = '1e-006-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58171161+(dvthn_25+vthmisn_25)'
+LVTH0      = '9.7781262e-009+dlvthn_25'
+WVTH0      = '-1.4180499e-008+dwvthn_25'
+PVTH0      = '-4.4176708e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.048365474+dk2n_25'
+LK2        = '-9.8169855e-009+dlk2n_25'
+WK2        = '-2.953431e-009+dwk2n_25'
+PK2        = '5.4229894e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074160091+dcitn_25'
+LCIT       = '-2.3146846e-013+dlcitn_25'
+WCIT       = '-1.8079361e-010+dwcitn_25'
+PCIT       = '7.8204713e-017+dpcitn_25'
+VOFF       = -0.11884305         LVOFF      = -1.1113064e-008     WVOFF      = 4.4821743e-009
+PVOFF      = 9.0741347e-016      NFACTOR    = 0.55                ETA0       = '0.44101649+deta0n_25'
+LETA0      = '8.7550883e-008+dleta0n_25'
+WETA0      = '1.401169e-008+dweta0n_25'
+PETA0      = '-5.3143386e-014+dpeta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.025036647+du0n_25'
+LU0        = '5.5370966e-009+dlu0n_25'
+WU0        = '-8.1921692e-010+dwu0n_25'
+PU0        = '5.6116359e-016+dpu0n_25'
+UA         = -1.4231724e-009     LUA        = 1.2263258e-016      WUA        = 5.0256129e-017
+PUA        = 8.5010314e-023      UB         = 2.596331e-018       LUB        = 2.9694512e-025
+WUB        = 7.5816365e-026      PUB        = -1.9115381e-031     UC         = 2.1086049e-010
+LUC        = -4.198412e-017      WUC        = -9.6723469e-017     PUC        = 4.0547054e-023
+VSAT       = '95383.047+dvsatn_25'
+LVSAT      = '-0.0039339871+dlvsatn_25'
+WVSAT      = '-0.0034860295+dwvsatn_25'
+PVSAT      = '2.3879302e-009+dpvsatn_25'
+A0         = '0.73982141+da0n_25'
+LA0        = '-3.1849206e-007+dla0n_25'
+WA0        = '1.5770296e-007+dwa0n_25'
+PA0        = '-8.2276134e-014+dpa0n_25'
+AGS        = '-0.68085015+dagsn_25'
+LAGS       = '6.7627954e-007+dlagsn_25'
+WAGS       = '-9.2716206e-007+dwagsn_25'
+PAGS       = '6.5488985e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0862105          LKETA      = 3.3782933e-008
+WKETA      = 2.4398099e-008      PKETA      = -1.4179529e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.15414038+dpclmn_25'
+LPCLM      = '6.223884e-008+dlpclmn_25'
+WPCLM      = '-2.9108346e-008+dwpclmn_25'
+PPCLM      = '1.9939217e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0056516605        LPDIBLC2   = -2.1588875e-009
+WPDIBLC2   = -3.1370779e-010     PPDIBLC2   = 2.1488984e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00060686363
+LTVOFF     = 5.281993e-010       WTVOFF     = 6.9751629e-010      PTVOFF     = -4.4534898e-016
+KT1        = -0.40438432         LKT1       = 7.9708361e-008      WKT1       = 4.7749053e-008
+PKT1       = -2.8416369e-014     KT1L       = 0                   KT2        = -0.063060512
+LKT2       = 1.0747559e-009      WKT2       = 5.0857827e-010      PKT2       = 3.0326713e-015
+UTE        = -2.3760029          LUTE       = 6.1191079e-007      WUTE       = 9.4373503e-007
+PUTE       = -4.549007e-013      UA1        = -1.6665862e-009     LUA1       = 2.0626574e-015
+WUA1       = 2.9130074e-015      PUA1       = -1.4626072e-021     UB1        = -1.9404259e-019
+LUB1       = -1.4505154e-024     WUB1       = -1.745708e-024      PUB1       = 9.4657552e-031
+UC1        = -7.7186558e-011     LUC1       = 5.2991232e-017      WUC1       = 5.4432153e-017
+PUC1       = -3.1179204e-023     PRT        = 0                   AT         = 24063.347
+LAT        = -0.0091481218       WAT        = 0.0068366768        PAT        = -2.495387e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.15 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxln_25+dlmisn_25)'  WMIN       = '6e-007-(dxwn_25+dwmisn_25)'    WMAX       = '1e-006-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.64131926+(dvthn_25+vthmisn_25)'
+LVTH0      = '-1.1978666e-008+dlvthn_25'
+WVTH0      = '-1.0362963e-007+dwvthn_25'
+PVTH0      = '2.8231261e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.11830162+dk2n_25'
+LK2        = '1.5709707e-008+dlk2n_25'
+WK2        = '-1.6051399e-009+dwk2n_25'
+PK2        = '4.9308632e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00095730149+dcitn_25'
+LCIT       = '-7.8962179e-011+dlcitn_25'
+WCIT       = '1.3623212e-011+dwcitn_25'
+PCIT       = '7.2425748e-018+dpcitn_25'
+VOFF       = -0.20469819         LVOFF      = 2.0224061e-008      WVOFF      = 5.8761659e-008
+PVOFF      = -1.8904598e-014     NFACTOR    = 0.55                ETA0       = '0.86582953+deta0n_25'
+LETA0      = '-6.7505877e-008+dleta0n_25'
+WETA0      = '-1.9905171e-007+dweta0n_25'
+PETA0      = '2.4624754e-014+dpeta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.064737693+du0n_25'
+LU0        = '-8.9537849e-009+dlu0n_25'
+WU0        = '-2.1716149e-008+dwu0n_25'
+PU0        = '8.1885437e-015+dpu0n_25'
+UA         = 7.4278131e-010      LUA        = -6.6794053e-016     WUA        = -1.0835535e-015
+PUA        = 4.9885082e-022      UB         = 3.1458048e-018      LUB        = 9.6387188e-026
+WUB        = -3.5515859e-025     PUB        = -3.3847952e-032     UC         = 1.3273841e-010
+LUC        = -1.3469561e-017     WUC        = 5.5871979e-017      PUC        = -1.5150284e-023
+VSAT       = '95257.02+dvsatn_25'
+LVSAT      = '-0.0038879871+dlvsatn_25'
+WVSAT      = '0.011009511+dwvsatn_25'
+PVSAT      = '-2.9029422e-009+dpvsatn_25'
+A0         = '2.7047026+da0n_25' LA0        = '-1.0356737e-006+dla0n_25'
+WA0        = '-1.0570505e-006+dwa0n_25'
+PA0        = '3.6110887e-013+dpa0n_25'
+AGS        = '3.7151795+dagsn_25'
+LAGS       = '-9.2827128e-007+dlagsn_25'
+WAGS       = '1.3295124e-006+dwagsn_25'
+PAGS       = '-1.6879634e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.012901258        LKETA      = 7.0250594e-009
+WKETA      = -5.0798459e-008     PKETA      = 1.3267215e-014      DWG        = 0
+DWB        = 0                   PCLM       = '1.0606992+dpclmn_25'
+LPCLM      = '-2.6865514e-007+dlpclmn_25'
+WPCLM      = '-5.6490105e-007+dwpclmn_25'
+PPCLM      = '2.1550355e-013+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.00025049996      LPDIBLC2   = -4.5988869e-012
+WPDIBLC2   = 2.6239697e-010      PPDIBLC2   = 4.6115986e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0035286809
+LTVOFF     = -5.3826399e-010     WTVOFF     = -1.0522957e-009     PTVOFF     = 1.9333241e-016
+KT1        = -0.1329178          LKT1       = -1.9376919e-008     WKT1       = -6.08804e-008
+PKT1       = 1.1233381e-014      KT1L       = 0                   KT2        = -0.14192015
+LKT2       = 2.9858524e-008      WKT2       = 3.8783749e-008      PKT2       = -1.0937766e-014
+UTE        = 0.09669725          LUTE       = -2.9062477e-007     WUTE       = -1.1043741e-006
+PUTE       = 2.9265915e-013      UA1        = 1.0517893e-008      LUA1       = -2.3846775e-015
+WUA1       = -6.0507539e-015     PUA1       = 1.8091656e-021      UB1        = -1.2366845e-017
+LUB1       = 2.9925574e-024      WUB1       = 6.2351371e-024      PUB1       = -1.966433e-030
+UC1        = 1.2356123e-010      LUC1       = -2.0281709e-017     WUC1       = -8.7319212e-017
+PUC1       = 2.0560044e-023      PRT        = 0                   AT         = -31521.375
+LAT        = 0.011140302         WAT        = 0.0040495246        PAT        = -1.4780765e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_25+dlmisn_25)'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+(dvthn_25+vthmisn_25)'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_25'
+WK2        = '7.0038392e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_25'
+WCIT       = '-1.734284e-010+dwcitn_25'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_25'  WU0        = '2.47049e-010+dwu0n_25'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_25'   A0         = '0.761323+da0n_25'  WA0        = '2.4976654e-007+dwa0n_25'
+AGS        = '0.3716704+dagsn_25'
+WAGS       = '-1.7787528e-009+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'
+PCIT       = '0+dpcitn_25'       LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'
+LAGS       = '0+dlagsn_25'       PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'
+WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+PETA0      = '0+dpeta0n_25'      LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_25+dlmisn_25)'
+LMAX       = '1e-005-(dxln_25+dlmisn_25)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+(dvthn_25+vthmisn_25)'
+LVTH0      = '-2.9748634e-009+dlvthn_25'
+WVTH0      = '4.1584242e-010+dwvthn_25'
+PVTH0      = '-4.1521866e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_25'
+LK2        = '-8.5746992e-009+dlk2n_25'
+WK2        = '7.1926316e-009+dwk2n_25'
+PK2        = '-1.8850927e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_25'
+LCIT       = '2.8299186e-011+dlcitn_25'
+WCIT       = '-1.8936348e-010+dwcitn_25'
+PCIT       = '1.5911179e-016+dpcitn_25'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_25'
+LU0        = '-1.3444366e-009+dlu0n_25'
+WU0        = '5.7424856e-011+dwu0n_25'
+PU0        = '1.8933971e-015+dpu0n_25'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_25'   A0         = '0.77421149+da0n_25'
+LA0        = '-1.2869158e-007+dla0n_25'
+WA0        = '2.8250165e-007+dwa0n_25'
+PA0        = '-3.2686013e-013+dpa0n_25'
+AGS        = '0.35349094+dagsn_25'
+LAGS       = '1.8152193e-007+dlagsn_25'
+WAGS       = '-2.6170911e-009+dwagsn_25'
+PAGS       = '8.3708082e-015+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.18 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_25+dlmisn_25)'
+LMAX       = '1.2e-006-(dxln_25+dlmisn_25)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+(dvthn_25+vthmisn_25)'
+LVTH0      = '4.9190535e-010+dlvthn_25'
+WVTH0      = '6.7271443e-009+dwvthn_25'
+PVTH0      = '-1.1631079e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_25'
+LK2        = '-8.0997573e-009+dlk2n_25'
+WK2        = '7.2348917e-009+dwk2n_25'
+PK2        = '-1.935171e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_25'
+LCIT       = '-4.8473782e-011+dlcitn_25'
+WCIT       = '-7.7260869e-011+dwcitn_25'
+PCIT       = '2.6270196e-017+dpcitn_25'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_25'
+LU0        = '4.2425619e-009+dlu0n_25'
+WU0        = '2.2982969e-009+dwu0n_25'
+PU0        = '-7.6203623e-016+dpu0n_25'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.2504613+da0n_25' LA0        = '-6.9304756e-007+dla0n_25'
+WA0        = '-6.5759503e-008+dwa0n_25'
+PA0        = '8.5829344e-014+dpa0n_25'
+AGS        = '0.85077416+dagsn_25'
+LAGS       = '-4.0775869e-007+dlagsn_25'
+WAGS       = '-7.1367515e-008+dwagsn_25'
+PAGS       = '8.9840061e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.19 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxln_25+dlmisn_25)'
+LMAX       = '7e-007-(dxln_25+dlmisn_25)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58475731+(dvthn_25+vthmisn_25)'
+LVTH0      = '-4.0187612e-009+dlvthn_25'
+WVTH0      = '-1.6029234e-008+dwvthn_25'
+PVTH0      = '3.9570398e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.059827546+dk2n_25'
+LK2        = '-1.3408216e-009+dlk2n_25'
+WK2        = '4.0040467e-009+dwk2n_25'
+PK2        = '2.7795792e-016+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00035790792+dcitn_25'
+LCIT       = '2.3132079e-010+dlcitn_25'
+WCIT       = '5.2108038e-011+dwcitn_25'
+PCIT       = '-6.2347505e-017+dpcitn_25'
+VOFF       = -0.10692563         LVOFF      = -5.1820416e-009     WVOFF      = -2.7517012e-009
+PVOFF      = -2.6927173e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.023868909+du0n_25'
+LU0        = '4.9987811e-009+dlu0n_25'
+WU0        = '-1.1040002e-010+dwu0n_25'
+PU0        = '8.8792113e-016+dpu0n_25'
+UA         = -1.080391e-009      LUA        = 3.9287131e-017      WUA        = -1.578122e-016
+PUA        = 1.35601e-022        UB         = 2.4785956e-018      LUB        = 1.6217676e-025
+WUB        = 1.4728174e-025      PUB        = -1.0934942e-031     UC         = 6.4726623e-011
+LUC        = 4.0047207e-017      WUC        = -8.0202142e-018     PUC        = -9.2459613e-024
+VSAT       = '84997.656+dvsatn_25'
+LVSAT      = '0.0031800055+dlvsatn_25'
+WVSAT      = '0.0028179027+dwvsatn_25'
+PVSAT      = '-1.9302633e-009+dpvsatn_25'
+A0         = '0.72691983+da0n_25'
+LA0        = '-3.3442168e-007+dla0n_25'
+WA0        = '1.6553422e-007+dwa0n_25'
+PA0        = '-7.2606855e-014+dpa0n_25'
+AGS        = '-3.3021125+dagsn_25'
+LAGS       = '2.4369687e-006+dlagsn_25'
+WAGS       = '6.6394419e-007+dwagsn_25'
+PAGS       = '-4.1384846e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.044413375        LKETA      = 5.5893089e-009
+WKETA      = -9.7275544e-010     PKETA      = 2.9340003e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15038105+dpclmn_25'
+LPCLM      = '6.4813981e-008+dlpclmn_25'
+WPCLM      = '-2.6826433e-008+dwpclmn_25'
+PPCLM      = '1.8376107e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0084649305        LPDIBLC2   = -4.3647724e-009
+WPDIBLC2   = -2.0213626e-009     PPDIBLC2   = 1.553862e-015       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.005244197
+LTVOFF     = -1.9592623e-009     WTVOFF     = -2.117345e-009      PTVOFF     = 1.0645402e-015
+KT1        = -0.34824522         LKT1       = 2.46259e-008        WKT1       = 1.3672618e-008
+PKT1       = 5.0186846e-015      KT1L       = 0                   KT2        = -0.076610106
+LKT2       = 1.3194132e-008      WKT2       = 8.7331822e-009      PKT2       = -4.3237898e-015
+UTE        = -0.6594357          LUTE       = -2.7902399e-007     WUTE       = -9.8221278e-008
+PUTE       = 8.5896718e-014      UA1        = 3.9503485e-009      LUA1       = -9.1136066e-016
+WUA1       = -4.9647199e-016     PUA1       = 3.4262174e-022      UB1        = -3.5230482e-018
+LUB1       = 3.9527663e-025      WUB1       = 2.7499835e-025      PUB1       = -1.7382021e-031
+UC1        = 3.7157106e-011      LUC1       = -2.5993185e-017     WUC1       = -1.4974451e-017
+PUC1       = 1.6764337e-023      PRT        = 0                   AT         = 44822.861
+LAT        = -0.016725344        WAT        = -0.005764348        PAT        = 2.103987e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LETA0      = '0+dleta0n_25'
+PETA0      = '0+dpeta0n_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL nch_25.20 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxln_25+dlmisn_25)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_25+dwmisn_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_25+toxmisn_25)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_25+dlmisn_25)'  XW         = '7e-09+(dxwn_25+dwmisn_25)'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.43761783+(dvthn_25+vthmisn_25)'
+LVTH0      = '4.9687149e-008+dlvthn_25'
+WVTH0      = '2.0017145e-008+dwvthn_25'
+PVTH0      = '-9.1998886e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.095507584+dk2n_25'
+LK2        = '1.1682392e-008+dlk2n_25'
+WK2        = '-1.5441118e-008+dwk2n_25'
+PK2        = '7.3754432e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028885852+dcitn_25'
+LCIT       = '-6.9237641e-010+dlcitn_25'
+WCIT       = '-1.158666e-009+dwcitn_25'
+PCIT       = '3.7958501e-016+dpcitn_25'
+VOFF       = -0.033502075        LVOFF      = -3.1981638e-008     WVOFF      = -4.5154381e-008
+PVOFF      = 1.2784261e-014      NFACTOR    = 0.55                ETA0       = '0.87164759+deta0n_25'
+LETA0      = '-8.1756564e-008+dleta0n_25'
+WETA0      = '-2.0258327e-007+dweta0n_25'
+PETA0      = '3.3274922e-014+dpeta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03786259+du0n_25'
+LU0        = '-1.0891235e-010+dlu0n_25'
+WU0        = '-5.4029616e-009+dwu0n_25'
+PU0        = '2.8197061e-015+dpu0n_25'
+UA         = -9.6780348e-010     LUA        = -1.8073066e-018     WUA        = -4.5228496e-017
+PUA        = 9.4507946e-023      UB         = 3.2824026e-018      LUB        = -1.3121278e-025
+WUB        = -4.3807346e-025     PUB        = 1.0430523e-031      UC         = 4.517043e-010
+LUC        = -1.0119964e-016     WUC        = -1.3774032e-016     PUC        = 3.8101876e-023
+VSAT       = '128250.1+dvsatn_25'
+LVSAT      = '-0.012607137+dlvsatn_25'
+WVSAT      = '-0.0090172885+dwvsatn_25'
+PVSAT      = '2.3895815e-009+dpvsatn_25'
+A0         = '1.0561856+da0n_25' LA0        = '-4.5460368e-007+dla0n_25'
+WA0        = '-5.6400669e-008+dwa0n_25'
+PA0        = '8.3993788e-015+dpa0n_25'
+AGS        = '8.4937151+dagsn_25'
+LAGS       = '-1.8685084e-006+dlagsn_25'
+WAGS       = '-1.5710587e-006+dwagsn_25'
+PAGS       = '4.019276e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.071396718        LKETA      = 1.5438229e-008
+WKETA      = -1.5291716e-008     PKETA      = 8.1604207e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15677659+dpclmn_25'
+LPCLM      = '6.2479611e-008+dlpclmn_25'
+WPCLM      = '-1.6220002e-008+dwpclmn_25'
+PPCLM      = '1.4504759e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.011607408        LPDIBLC2   = 2.961631e-009
+WPDIBLC2   = 7.1560399e-009      PPDIBLC2   = -1.7958899e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = -0.0028262422
+LTVOFF     = 9.8644798e-010      WTVOFF     = 2.8051426e-009      PTVOFF     = -7.3216776e-016
+KT1        = -0.5264585          LKT1       = 8.9673748e-008      WKT1       = 1.779988e-007
+PKT1       = -5.4960373e-014     KT1L       = 0                   KT2        = -0.033099305
+LKT2       = -2.6873107e-009     WKT2       = -2.7270504e-008     PKT2       = 8.8175556e-015
+UTE        = -3.221274           LUTE       = 6.5604699e-007      WUTE       = 9.0963442e-007
+PUTE       = -2.8197061e-013     UA1        = -4.1086269e-009     LUA1       = 2.0301654e-015
+WUA1       = 2.8275437e-015      PUA1       = -8.70644e-022       UB1        = 3.9057585e-019
+LUB1       = -1.0331961e-024     WUB1       = -1.5086171e-024     PUB1       = 4.7719942e-031
+UC1        = -3.1633616e-010     LUC1       = 1.0303186e-016      WUC1       = 1.796985e-016
+PUC1       = -5.4291291e-023     PRT        = 0                   AT         = -24850
+LAT        = 0.00870525
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_25'
+NOIB       = 'noibnmac_25'
+NOIC       = 'noicnmac_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0                   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )

**********************************************************************************************
*                                                                                            *
*                                   2.5V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.ends nch_25_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_25_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwp_25'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_25 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_25  temp2=parp2_25
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef = 'l*scale-1.5e-08'
+       wef = 'w/nf*scale+7e-09'
+       geo_fac  = '1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_25='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisp_25 = '0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_25 = '-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_25='0.00197184*geo_fac*toxp_25*fac2*mismatchflag' 
.param tnoiax='2.295e6/(l*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(l*scale*1e6)+0.5496'

.param fn_dice='noiseflagp_25_mc*par1fn_mc+noiseflagp_25_mc_mis*par2fp_25_mc'
.param arearatio='sigma_factor_flicker_25*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noiapmac_25='c1fp_25*2.718**((fn_dice+(1-fn_dice)*noiseflagp_25)*arearatio)'
.param noibpmac_25='c2fp_25*2.718**((fn_dice+(1-fn_dice)*noiseflagp_25)*arearatio)'
.param noicpmac_25='c3fp_25*2.718**((fn_dice+(1-fn_dice)*noiseflagp_25)*arearatio)'

.MODEL pch_25.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_25+dlmisp_25)'
+LMAX       = 900.001e-6          WMIN       = '1e-005-(dxwp_25+dwmisp_25)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+(dvthp_25+vthmisp_25)'
+K1         = 0.72417             K2         = '-0.05886+dk2p_25'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_25'
+VOFF       = '-0.08693+dvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_25'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_25'
+A0         = '1.297+da0p_25'     AGS        = '0.2718+dagsp_25'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_25'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'
+LCIT       = '0+dlcitp_25'       WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'
+LU0        = '0+dlu0p_25'        WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+LA0        = '0+dla0p_25'        WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+LPCLM      = '0+dlpclmp_25'      WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+LVOFF      = '0+dlvoffp_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+LK2        = '0+dlk2p_25'        WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_25+dlmisp_25)'
+LMAX       = '1e-005-(dxlp_25+dlmisp_25)'    WMIN       = '1e-005-(dxwp_25+dwmisp_25)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+(dvthp_25+vthmisp_25)'
+LVTH0      = '4.3026273e-009+dlvthp_25'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_25'
+LK2        = '-7.5295977e-010+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_25'
+LCIT       = '2.3222086e-010+dlcitp_25'
+VOFF       = '-0.087552125+dvoffp_25'
+LVOFF      = '6.2119181e-009+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_25'
+LU0        = '9.4119972e-011+dlu0p_25'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_25'  A0         = '1.3227199+da0p_25' LA0        = '-2.5681307e-007+dla0p_25'
+AGS        = '0.25480602+dagsp_25'
+LAGS       = '1.6968486e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_25'
+LPCLM      = '2.5143478e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'
+PAGS       = '0+dpagsp_25'       WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'      WK2        = '0+dwk2p_25'
+PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '1.2e-006-(dxlp_25+dlmisp_25)'  WMIN       = '1e-005-(dxwp_25+dwmisp_25)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.3149945e-008+dlvthp_25'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_25'
+LK2        = '4.740474e-009+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_25'
+LCIT       = '2.0991209e-010+dlcitp_25'
+VOFF       = '-0.09229456+dvoffp_25'
+LVOFF      = '1.1831704e-008+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_25' LU0        = '-5.032695e-010+dlu0p_25'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_25'  A0         = '1.5469482+da0p_25' LA0        = '-5.2252362e-007+dla0p_25'
+AGS        = '0.2391074+dagsp_25'
+LAGS       = '1.8828773e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_25'
+LPCLM      = '1.2183992e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'
+PAGS       = '0+dpagsp_25'       WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'      WK2        = '0+dwk2p_25'
+PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.4 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '7e-007-(dxlp_25+dlmisp_25)'    WMIN       = '1e-005-(dxwp_25+dwmisp_25)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63663281+(dvthp_25+vthmisp_25)'
+LVTH0      = '3.5159766e-009+dlvthp_25'
+K1         = 0.72417             K2         = '-0.044249688+dk2p_25'
+LK2        = '-8.3914641e-009+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00023317656+dcitp_25'
+LCIT       = '5.6802555e-011+dlcitp_25'
+VOFF       = '-0.11314283+dvoffp_25'
+LVOFF      = '2.6112767e-008+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58864219+deta0p_25'
+LETA0      = '-2.3439844e-010+dleta0p_25'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01097875+du0p_25'
+LU0        = '5.6255625e-010+dlu0p_25'
+UA         = 6.8244047e-010      LUA        = -2.4986092e-016     UB         = 7.2901719e-019
+LUB        = 4.3105873e-025      UC         = 4.7293438e-011      LUC        = 1.5204645e-017
+VSAT       = '102400.16+dvsatp_25'
+LVSAT      = '0.012055893+dlvsatp_25'
+A0         = '0.75410734+da0p_25'
+LA0        = '2.057237e-008+dla0p_25'
+AGS        = '0.16182344+dagsp_25'
+LAGS       = '2.4122725e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.051643594        LKETA      = 5.7427617e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.43326891+dpclmp_25'
+LPCLM      = '-2.1384951e-008+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0057335625
+LTVOFF     = -1.1032353e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21198906         LKT1       = -4.1175992e-008     KT1L       = 0
+KT2        = -0.071645938        LKT2       = 4.9223672e-009      UTE        = -0.43653125
+LUTE       = -3.8597609e-007     UA1        = 3.7772211e-009      LUA1       = -1.3427515e-015
+UB1        = -3.6822922e-018     LUB1       = 6.0779515e-025      UC1        = 1.0510078e-010
+LUC1       = -5.6732235e-017     PRT        = 0                   AT         = 122856.09
+LAT        = -0.040871274
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      WA0        = '0+dwa0p_25'
+PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      WETA0      = '0+dweta0p_25'
+PETA0      = '0+dpeta0p_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.5 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxlp_25+dlmisp_25)'  WMIN       = '1e-005-(dxwp_25+dwmisp_25)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67417+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.721705e-008+dlvthp_25'
+K1         = 0.72417             K2         = '-0.014558+dk2p_25' LK2        = '-1.922893e-008+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00075662+dcitp_25'
+LCIT       = '-1.342543e-010+dlcitp_25'
+VOFF       = '-0.06555965+dvoffp_25'
+LVOFF      = '8.7449073e-009+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.587205+deta0p_25'
+LETA0      = '2.90175e-010+dleta0p_25'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010718+du0p_25'  LU0        = '6.5773e-010+dlu0p_25'
+UA         = 1.007205e-011       LUA        = -4.4464483e-018     UB         = 1.377615e-018
+LUB        = 1.9432053e-025      UC         = 1.79368e-010        LUC        = -3.300257e-017
+VSAT       = '176319.5+dvsatp_25'
+LVSAT      = '-0.014924668+dlvsatp_25'
+A0         = '0.7361905+da0p_25' LA0        = '2.7112018e-008+dla0p_25'
+AGS        = '0.655558+dagsp_25' LAGS       = '6.101413e-008+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1545505          LKETA      = 4.3303783e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.544393+dpclmp_25'
+LPCLM      = '3.3546165e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.008210545
+LTVOFF     = -2.0073339e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.387605           LKT1       = 2.2923825e-008      KT1L       = 0
+KT2        = -0.0916772          LKT2       = 1.2233778e-008      UTE        = -1.99591
+LUTE       = 1.8319715e-007      UA1        = 1.29243e-010        LUA1       = -1.1239445e-017
+UB1        = -3.63625e-018       LUB1       = 5.9098975e-025      UC1        = -1.036215e-010
+LUC1       = 1.9451398e-017      PRT        = 0                   AT         = 82801
+LAT        = -0.026251165
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      WA0        = '0+dwa0p_25'
+PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      WETA0      = '0+dweta0p_25'
+PETA0      = '0+dpeta0p_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_25+dlmisp_25)'
+LMAX       = 900.001e-6          WMIN       = '1e-006-(dxwp_25+dwmisp_25)'    WMAX       = '1e-005-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+(dvthp_25+vthmisp_25)'
+WVTH0      = '-1.5339508e-008+dwvthp_25'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_25'
+WK2        = '-1.0189016e-009+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_25'
+WCIT       = '-1.017782e-011+dwcitp_25'
+VOFF       = '-0.085385933+dvoffp_25'
+WVOFF      = '-1.5451475e-008+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_25'
+WU0        = '-2.0154098e-010+dwu0p_25'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.2936433+da0p_25' WA0        = '3.3590163e-008+dwa0p_25'
+AGS        = '0.27102797+dagsp_25'
+WAGS       = '7.7257376e-009+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'
+PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'       PCIT       = '0+dpcitp_25'
+LU0        = '0+dlu0p_25'        PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'
+PA0        = '0+dpa0p_25'        LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'
+LPCLM      = '0+dlpclmp_25'      WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      PETA0      = '0+dpeta0p_25'      LVOFF      = '0+dlvoffp_25'
+PVOFF      = '0+dpvoffp_25'      LK2        = '0+dlk2p_25'        PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_25+dlmisp_25)'
+LMAX       = '1e-005-(dxlp_25+dlmisp_25)'    WMIN       = '1e-006-(dxwp_25+dwmisp_25)'    WMAX       = '1e-005-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+(dvthp_25+vthmisp_25)'
+LVTH0      = '2.9336e-009+dlvthp_25'
+WVTH0      = '-1.6711552e-008+dwvthp_25'
+PVTH0      = '1.3699856e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_25'
+LK2        = '-5.724287e-010+dlk2p_25'
+WK2        = '-8.3797279e-010+dwk2p_25'
+PK2        = '-1.8065744e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_25'
+LCIT       = '2.5685734e-010+dlcitp_25'
+WCIT       = '1.4512935e-011+dwcitp_25'
+PCIT       = '-2.4653719e-016+dpcitp_25'
+VOFF       = '-0.085808935+dvoffp_25'
+LVOFF      = '4.2236693e-009+dlvoffp_25'
+WVOFF      = '-1.7444105e-008+dwvoffp_25'
+PVOFF      = '1.9896406e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_25'
+LU0        = '6.5535886e-011+dlu0p_25'
+WU0        = '-2.3018805e-010+dwu0p_25'
+PU0        = '2.8604095e-016+dpu0p_25'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.3194838+da0p_25' LA0        = '-2.5801661e-007+dla0p_25'
+WA0        = '3.2383971e-008+dwa0p_25'
+PA0        = '1.2043829e-014+dpa0p_25'
+AGS        = '0.25390291+dagsp_25'
+LAGS       = '1.7099371e-007+dlagsp_25'
+WAGS       = '9.0374716e-009+dwagsp_25'
+PAGS       = '-1.3097665e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_25'
+LPCLM      = '2.479746e-007+dlpclmp_25'
+WPCLM      = '-3.4678027e-009+dwpclmp_25'
+PPCLM      = '3.462601e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.8 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '1.2e-006-(dxlp_25+dlmisp_25)'  WMIN       = '1e-006-(dxwp_25+dwmisp_25)'    WMAX       = '1e-005-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.3912858e-008+dlvthp_25'
+WVTH0      = '1.2921016e-009+dwvthp_25'
+PVTH0      = '-7.6344731e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_25'
+LK2        = '5.12738e-009+dlk2p_25'
+WK2        = '9.0480703e-010+dwk2p_25'
+PK2        = '-3.8717685e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_25'
+LCIT       = '2.2066735e-010+dlcitp_25'
+WCIT       = '-1.027101e-010+dwcitp_25'
+PCIT       = '-1.0762789e-016+dpcitp_25'
+VOFF       = '-0.092580246+dvoffp_25'
+LVOFF      = '1.2247673e-008+dlvoffp_25'
+WVOFF      = '2.8588588e-009+dwvoffp_25'
+PVOFF      = '-4.1626056e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_25'
+LU0        = '-5.6139623e-010+dlu0p_25'
+WU0        = '-4.7966753e-010+dwu0p_25'
+PU0        = '5.8167414e-016+dpu0p_25'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.5239739+da0p_25' LA0        = '-5.0033737e-007+dla0p_25'
+WA0        = '2.2990429e-007+dwa0p_25'
+PA0        = '-2.2201775e-013+dpa0p_25'
+AGS        = '0.23113396+dagsp_25'
+LAGS       = '1.9797491e-007+dlagsp_25'
+WAGS       = '7.9790186e-008+dwagsp_25'
+PAGS       = '-9.6939631e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_25'
+LPCLM      = '1.321774e-007+dlpclmp_25'
+WPCLM      = '1.130496e-007+dwpclmp_25'
+PPCLM      = '-1.0344711e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.9 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '7e-007-(dxlp_25+dlmisp_25)'    WMIN       = '1e-006-(dxwp_25+dwmisp_25)'    WMAX       = '1e-005-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+(dvthp_25+vthmisp_25)'
+LVTH0      = '2.5718197e-009+dlvthp_25'
+WVTH0      = '-2.3646075e-008+dwvthp_25'
+PVTH0      = '9.4481782e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2p_25'
+LK2        = '-8.9535871e-009+dlk2p_25'
+WK2        = '-1.295933e-008+dwk2p_25'
+PK2        = '5.6251653e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitp_25'
+LCIT       = '4.6455294e-011+dlcitp_25'
+WCIT       = '-4.1099174e-010+dwcitp_25'
+PCIT       = '1.0354503e-016+dpcitp_25'
+VOFF       = '-0.11299764+dvoffp_25'
+LVOFF      = '2.6233584e-008+dlvoffp_25'
+WVOFF      = '-1.4529495e-009+dwvoffp_25'
+PVOFF      = '-1.2090169e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.56211263+deta0p_25'
+LETA0      = '1.7424833e-008+dleta0p_25'
+WETA0      = '2.6548126e-007+dweta0p_25'
+PETA0      = '-1.7671593e-013+dpeta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0p_25'
+LU0        = '5.5390148e-010+dlu0p_25'
+WU0        = '2.4305632e-010+dwu0p_25'
+PU0        = '8.66083e-017+dpu0p_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatp_25'
+LVSAT      = '0.013404813+dlvsatp_25'
+WVSAT      = '0.019706054+dwvsatp_25'
+PVSAT      = '-1.3498647e-008+dpvsatp_25'
+A0         = '0.80514856+da0p_25'
+LA0        = '-7.9420433e-009+dla0p_25'
+WA0        = '-5.107694e-007+dwa0p_25'
+PA0        = '2.8534373e-013+dpa0p_25'
+AGS        = '0.15467694+dagsp_25'
+LAGS       = '2.5034798e-007+dlagsp_25'
+WAGS       = '7.1515032e-008+dwagsp_25'
+PAGS       = '-9.1271151e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmp_25'
+LPCLM      = '-5.4009069e-008+dlpclmp_25'
+WPCLM      = '-5.1456596e-007+dwpclmp_25'
+PPCLM      = '3.2646955e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.10 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxlp_25+dlmisp_25)'  WMIN       = '1e-006-(dxwp_25+dwmisp_25)'    WMAX       = '1e-005-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.9165092e-008+dlvthp_25'
+WVTH0      = '5.5647704e-008+dwvthp_25'
+PVTH0      = '-1.9494051e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2p_25'
+LK2        = '-2.0061177e-008+dlk2p_25'
+WK2        = '-2.0365156e-008+dwk2p_25'
+PK2        = '8.3282919e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitp_25'
+LCIT       = '-1.4937327e-010+dlcitp_25'
+WCIT       = '-5.4181493e-010+dwcitp_25'
+PCIT       = '1.512955e-016+dpcitp_25'
+VOFF       = '-0.067282633+dvoffp_25'
+LVOFF      = '9.5476086e-009+dlvoffp_25'
+WVOFF      = '1.7241887e-008+dwvoffp_25'
+PVOFF      = '-8.0326321e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.61679273+deta0p_25'
+LETA0      = '-2.5334029e-009+dleta0p_25'
+WETA0      = '-2.9608441e-007+dweta0p_25'
+PETA0      = '2.8255544e-014+dpeta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0p_25'
+LU0        = '5.7861787e-010+dlu0p_25'
+WU0        = '-1.6886335e-009+dwu0p_25'
+PU0        = '7.9167508e-016+dpu0p_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatp_25'
+LVSAT      = '-0.016594572+dlvsatp_25'
+WVSAT      = '-0.063059374+dwvsatp_25'
+PVSAT      = '1.6710734e-008+dpvsatp_25'
+A0         = '0.51664235+da0p_25'
+LA0        = '9.7362723e-008+dla0p_25'
+WA0        = '2.1970184e-006+dwa0p_25'
+PA0        = '-7.0299881e-013+dpa0p_25'
+AGS        = '0.70207782+dagsp_25'
+LAGS       = '5.0546654e-008+dlagsp_25'
+WAGS       = '-4.6552383e-007+dwagsp_25'
+PAGS       = '1.0474804e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmp_25'
+LPCLM      = '3.4876893e-007+dlpclmp_25'
+WPCLM      = '7.447096e-007+dwpclmp_25'
+PPCLM      = '-1.3316603e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_25+dlmisp_25)'
+LMAX       = 900.001e-6          WMIN       = '6e-007-(dxwp_25+dwmisp_25)'    WMAX       = '1e-006-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+(dvthp_25+vthmisp_25)'
+WVTH0      = '-9.168735e-010+dwvthp_25'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_25'
+WK2        = '6.3722708e-009+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.1087682+dvoffp_25'
+WVOFF      = '8.0944649e-009+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_25'
+WU0        = '-4.7371798e-010+dwu0p_25'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.1646275+da0p_25' WA0        = '1.6350911e-007+dwa0p_25'
+AGS        = '0.26549775+dagsp_25'
+WAGS       = '1.3294666e-008+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LU0        = '0+dlu0p_25'
+PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'
+PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'
+PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'       LPCLM      = '0+dlpclmp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      LVOFF      = '0+dlvoffp_25'      PVOFF      = '0+dpvoffp_25'
+LK2        = '0+dlk2p_25'        PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_25+dlmisp_25)'
+LMAX       = '1e-005-(dxlp_25+dlmisp_25)'    WMIN       = '6e-007-(dxwp_25+dwmisp_25)'    WMAX       = '1e-006-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+(dvthp_25+vthmisp_25)'
+LVTH0      = '2.5515924e-008+dlvthp_25'
+WVTH0      = '-1.1460919e-011+dwvthp_25'
+PVTH0      = '-9.0405446e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_25'
+LK2        = '-7.6918538e-009+dlk2p_25'
+WK2        = '5.8351965e-009+dwk2p_25'
+PK2        = '5.3626867e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_25'
+LCIT       = '3.029537e-011+dlcitp_25'
+WCIT       = '1.8416915e-012+dwcitp_25'
+PCIT       = '-1.838929e-017+dpcitp_25'
+VOFF       = '-0.11242711+dvoffp_25'
+LVOFF      = '3.6534227e-008+dlvoffp_25'
+WVOFF      = '9.3603963e-009+dwvoffp_25'
+PVOFF      = '-1.2640325e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_25'
+LU0        = '-2.8293136e-010+dlu0p_25'
+WU0        = '-5.3750841e-010+dwu0p_25'
+PU0        = '6.3694746e-016+dpu0p_25'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_25'  A0         = '1.1751703+da0p_25' LA0        = '-1.0526983e-007+dla0p_25'
+WA0        = '1.7770762e-007+dwa0p_25'
+PA0        = '-1.4177218e-013+dpa0p_25'
+AGS        = '0.25327996+dagsp_25'
+LAGS       = '1.2199468e-007+dlagsp_25'
+WAGS       = '9.6647844e-009+dwagsp_25'
+PAGS       = '3.6244365e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_25'
+LPCLM      = '2.6195605e-007+dlpclmp_25'
+WPCLM      = '-2.0577559e-009+dwpclmp_25'
+PPCLM      = '2.0546692e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.13 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '1.2e-006-(dxlp_25+dlmisp_25)'  WMIN       = '6e-007-(dxwp_25+dwmisp_25)'    WMAX       = '1e-006-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+(dvthp_25+vthmisp_25)'
+LVTH0      = '-7.9573402e-009+dlvthp_25'
+WVTH0      = '-1.9783074e-008+dwvthp_25'
+PVTH0      = '1.4388817e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_25'
+LK2        = '1.295992e-008+dlk2p_25'
+WK2        = '2.0283992e-008+dwk2p_25'
+PK2        = '-1.1759136e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_25'
+LCIT       = '2.8646031e-010+dlcitp_25'
+WCIT       = '1.3305867e-010+dwcitp_25'
+PCIT       = '-1.7388141e-016+dpcitp_25'
+VOFF       = '-0.073036514+dvoffp_25'
+LVOFF      = '-1.0143628e-008+dlvoffp_25'
+WVOFF      = '-1.6821679e-008+dwvoffp_25'
+PVOFF      = '1.8385435e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_25'
+LU0        = '-1.6343677e-009+dlu0p_25'
+WU0        = '-1.4026636e-009+dwu0p_25'
+PU0        = '1.6621564e-015+dpu0p_25'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_25'  A0         = '2.1264181+da0p_25' LA0        = '-1.2324985e-006+dla0p_25'
+WA0        = '-3.7675707e-007+dwa0p_25'
+PA0        = '5.1526849e-013+dpa0p_25'
+AGS        = '0.24152159+dagsp_25'
+LAGS       = '1.3592834e-007+dlagsp_25'
+WAGS       = '6.9329848e-008+dwagsp_25'
+PAGS       = '-3.4458735e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_25'
+LPCLM      = '-2.323312e-007+dlpclmp_25'
+WPCLM      = '-2.0717704e-007+dwpclmp_25'
+PPCLM      = '2.6361305e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.14 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '7e-007-(dxlp_25+dlmisp_25)'    WMIN       = '6e-007-(dxwp_25+dwmisp_25)'    WMAX       = '1e-006-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.69392971+(dvthp_25+vthmisp_25)'
+LVTH0      = '3.5904762e-008+dlvthp_25'
+WVTH0      = '3.6431396e-008+dwvthp_25'
+PVTH0      = '-2.4118095e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.056981+dk2p_25' LK2        = '-4.6954695e-009+dlk2p_25'
+WK2        = '1.1651934e-009+dwk2p_25'
+PK2        = '1.3372409e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.6053841e-005+dcitp_25'
+LCIT       = '1.9867537e-010+dlcitp_25'
+WCIT       = '-4.8168809e-011+dwcitp_25'
+PCIT       = '-4.9740586e-017+dpcitp_25'
+VOFF       = '-0.1585485+dvoffp_25'
+LVOFF      = '4.8432079e-008+dlvoffp_25'
+WVOFF      = '4.4416767e-008+dwvoffp_25'
+PVOFF      = '-2.3562901e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.98182545+deta0p_25'
+LETA0      = '-2.1726296e-007+dleta0p_25'
+WETA0      = '-1.5716955e-007+dweta0p_25'
+PETA0      = '5.9614677e-014+dpeta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013590704+du0p_25'
+LU0        = '-1.6970388e-009+dlu0p_25'
+WU0        = '-2.41164e-009+dwu0p_25'
+PU0        = '2.3533052e-015+dpu0p_25'
+UA         = 1.3822488e-009      LUA        = -9.5202533e-016     WUA        = -1.1215123e-015
+PUA        = 7.6520029e-022      UB         = 4.2523021e-019      LUB        = 7.7972679e-025
+WUB        = 6.4094711e-025      PUB        = -4.4009553e-031     UC         = 2.9244119e-011
+LUC        = 1.5938293e-017      WUC        = -1.2591491e-017     PUC        = 3.1401282e-024
+VSAT       = '120000+dvsatp_25'  A0         = '-0.72475126+da0p_25'
+LA0        = '7.2055254e-007+dla0p_25'
+WA0        = '1.0298397e-006+dwa0p_25'
+PA0        = '-4.4825031e-013+dpa0p_25'
+AGS        = '0.47827608+dagsp_25'
+LAGS       = '-2.6248484e-008+dlagsp_25'
+WAGS       = '-2.5434931e-007+dwagsp_25'
+PAGS       = '1.8726148e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.016556925         LKETA      = -2.0853335e-008
+WKETA      = -2.6719222e-008     PKETA      = 1.5664822e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.500404+dpclmp_25'
+LPCLM      = '4.7410182e-007+dlpclmp_25'
+WPCLM      = '4.774232e-007+dwpclmp_25'
+PPCLM      = '-2.0533812e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00085814023       LPDIBLC2   = -5.8097606e-010
+WPDIBLC2   = -8.5407722e-010     PPDIBLC2   = 5.8504289e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.002836154
+LTVOFF     = -7.3891568e-010     WTVOFF     = 1.7227432e-009      PTVOFF     = -1.8984045e-016
+KT1        = -0.20204794         LKT1       = -5.5033628e-008     WKT1       = -1.696216e-008
+PKT1       = 2.292413e-014       KT1L       = 0                   KT2        = -0.070902278
+LKT2       = 3.3231253e-009      WKT2       = -2.3320582e-009     PKT2       = 2.8535766e-015
+UTE        = -0.91151582         LUTE       = -1.4167628e-007     WUTE       = 1.0302888e-007
+PUTE       = -7.9995661e-014     UA1        = 2.6228981e-009      LUA1       = -9.8687309e-016
+WUA1       = 2.0802761e-016      PUA1       = -5.3728429e-024     UB1        = -4.4978011e-018
+LUB1       = 1.5789137e-024      WUB1       = 9.670389e-025       PUB1       = -7.0324544e-031
+UC1        = 6.8312674e-011      LUC1       = -2.7390649e-017     WUC1       = -1.0991737e-017
+PUC1       = 1.4685771e-024      PRT        = 0                   AT         = -159164.07
+LAT        = 0.079546663         WAT        = 0.093253222         PAT        = -5.9837948e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.15 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxlp_25+dlmisp_25)'  WMIN       = '6e-007-(dxwp_25+dwmisp_25)'    WMAX       = '1e-006-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.49731109+(dvthp_25+vthmisp_25)'
+LVTH0      = '-3.5861036e-008+dlvthp_25'
+WVTH0      = '-1.2804903e-007+dwvthp_25'
+PVTH0      = '3.5917259e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.015424238+dk2p_25'
+LK2        = '-1.9863688e-008+dlk2p_25'
+WK2        = '-1.7443518e-008+dwk2p_25'
+PK2        = '8.1294207e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074340556+dcitp_25'
+LCIT       = '-1.0407731e-010+dlcitp_25'
+WCIT       = '-4.739854e-010+dwcitp_25'
+PCIT       = '1.0568247e-016+dpcitp_25'
+VOFF       = '0.07906712+dvoffp_25'
+LVOFF      = '-3.8297621e-008+dlvoffp_25'
+WVOFF      = '-1.3013231e-007+dwvoffp_25'
+PVOFF      = '4.0147514e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.53621805+deta0p_25'
+LETA0      = '-5.4616255e-008+dleta0p_25'
+WETA0      = '-2.1494571e-007+dweta0p_25'
+PETA0      = '8.0702976e-014+dpeta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '-0.0032467764+du0p_25'
+LU0        = '4.4486415e-009+dlu0p_25'
+WU0        = '1.2543823e-008+dwu0p_25'
+PU0        = '-3.1054387e-015+dpu0p_25'
+UA         = -4.4555912e-009     LUA        = 1.1787862e-015      WUA        = 3.5616741e-015
+PUA        = -9.4416274e-022     UB         = 3.6830818e-018      LUB        = -4.0938905e-025
+WUB        = -1.8954679e-024     PUB        = 4.8569593e-031      UC         = 1.2501464e-010
+LUC        = -1.9017949e-017     WUC        = -9.5125626e-019     PUC        = -1.1085574e-024
+VSAT       = '120000+dvsatp_25'  A0         = '4.5284548+da0p_25' LA0        = '-1.1968677e-006+dla0p_25'
+WA0        = '-1.8428768e-006+dwa0p_25'
+PA0        = '6.002912e-013+dpa0p_25'
+AGS        = '-0.61902699+dagsp_25'
+LAGS       = '3.7426714e-007+dlagsp_25'
+WAGS       = '8.648287e-007+dwagsp_25'
+PAGS       = '-2.2123849e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.16119939         LKETA      = 4.4027721e-008
+WKETA      = 2.9723511e-008      PKETA      = -4.9367755e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.026314886+dpclmp_25'
+LPCLM      = '3.010593e-007+dlpclmp_25'
+WPCLM      = '1.4806514e-007+dwpclmp_25'
+PPCLM      = '-8.5122425e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.029013451        LPDIBLC2   = 1.0322155e-008
+WPDIBLC2   = 1.067619e-008       PPDIBLC2   = -3.6235045e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0098913079
+LTVOFF     = -3.3140468e-009     WTVOFF     = -1.2517845e-009     PTVOFF     = 8.9586216e-016
+KT1        = -0.53396973         LKT1       = 6.6117825e-008      WKT1       = 1.7461856e-007
+PKT1       = -4.7002832e-014     KT1L       = 0                   KT2        = -0.13690558
+LKT2       = 2.7414329e-008      WKT2       = 3.1876712e-008      PKT2       = -9.6326245e-015
+UTE        = -2.2252494          LUTE       = 3.3783649e-007      WUTE       = 3.0622811e-007
+PUTE       = -1.5416338e-013     UA1        = -7.0184478e-009     LUA1       = 2.5322182e-015
+WUA1       = 4.3136988e-015      PUA1       = -1.5039428e-021     UB1        = 9.7141728e-018
+LUB1       = -3.6084567e-024     WUB1       = -7.1230374e-024     PUB1       = 2.2496324e-030
+UC1        = 8.4798945e-011      LUC1       = -3.3408138e-017     WUC1       = -2.3004356e-017
+PUC1       = 5.8531829e-024      PRT        = 0                   AT         = 258419.48
+LAT        = -0.072871331        WAT        = -0.23293867         PAT        = 5.9222091e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_25+dlmisp_25)'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+(dvthp_25+vthmisp_25)'
+WVTH0      = '-1.235245e-008+dwvthp_25'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_25'
+WK2        = '1.0981328e-008+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.082272655+dvoffp_25'
+WVOFF      = '-7.9883294e-009+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_25'
+WU0        = '5.0645045e-010+dwu0p_25'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.517435+da0p_25'  WA0        = '-5.0645045e-008+dwa0p_25'
+AGS        = '0.2802775+dagsp_25'
+WAGS       = '4.3233575e-009+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_25'
+WPCLM      = '-1.235245e-008+dwpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LU0        = '0+dlu0p_25'
+PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'
+PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'
+PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'       LPCLM      = '0+dlpclmp_25'
+PPCLM      = '0+dppclmp_25'      LETA0      = '0+dleta0p_25'      PETA0      = '0+dpeta0p_25'
+LVOFF      = '0+dlvoffp_25'      PVOFF      = '0+dpvoffp_25'      LK2        = '0+dlk2p_25'
+PK2        = '0+dpk2p_25'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_25+dlmisp_25)'
+LMAX       = '1e-005-(dxlp_25+dlmisp_25)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.3084693e-008+dlvthp_25'
+WVTH0      = '-1.2202747e-008+dwvthp_25'
+PVTH0      = '-1.4947872e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_25'
+LK2        = '1.8463044e-008+dlk2p_25'
+WK2        = '1.2034241e-008+dwk2p_25'
+PK2        = '-1.0513336e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.08299213+dvoffp_25'
+LVOFF      = '7.1839623e-009+dlvoffp_25'
+WVOFF      = '-8.5066354e-009+dwvoffp_25'
+PVOFF      = '5.1752854e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_25'
+LU0        = '8.2354975e-011+dlu0p_25'
+WU0        = '4.6486621e-010+dwu0p_25'
+PU0        = '4.1521866e-016+dpu0p_25'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.5401338+da0p_25' LA0        = '-2.2664761e-007+dla0p_25'
+WA0        = '-4.3825229e-008+dwa0p_25'
+PA0        = '-6.809586e-014+dpa0p_25'
+AGS        = '0.25532754+dagsp_25'
+LAGS       = '2.4912535e-007+dlagsp_25'
+WAGS       = '8.4219004e-009+dwagsp_25'
+PAGS       = '-4.0923951e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_25'
+LPCLM      = '4.3261573e-007+dlpclmp_25'
+WPCLM      = '-4.0356016e-009+dwpclmp_25'
+PPCLM      = '-8.3043732e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.18 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '1.2e-006-(dxlp_25+dlmisp_25)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.3104488e-008+dlvthp_25'
+WVTH0      = '-1.4817999e-008+dwvthp_25'
+PVTH0      = '1.6042868e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_25'
+LK2        = '-2.3393752e-008+dlk2p_25'
+WK2        = '-5.536121e-009+dwk2p_25'
+PK2        = '1.0307543e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.10923032+dvoffp_25'
+LVOFF      = '3.8276211e-008+dlvoffp_25'
+WVOFF      = '5.1479577e-009+dwvoffp_25'
+PVOFF      = '-1.1005407e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_25'
+LU0        = '1.9298762e-009+dlu0p_25'
+WU0        = '1.2383331e-009+dwu0p_25'
+PU0        = '-5.0133962e-016+dpu0p_25'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.8892247+da0p_25' LA0        = '-6.4032034e-007+dla0p_25'
+WA0        = '-2.3278069e-007+dwa0p_25'
+PA0        = '1.5581636e-013+dpa0p_25'
+AGS        = '0.50163406+dagsp_25'
+LAGS       = '-4.2747874e-008+dlagsp_25'
+WAGS       = '-8.855842e-008+dwagsp_25'
+PAGS       = '7.3997729e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_25'
+LPCLM      = '3.733935e-009+dlpclmp_25'
+WPCLM      = '-1.7565184e-007+dwpclmp_25'
+PPCLM      = '1.2032151e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.19 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-(dxlp_25+dlmisp_25)'
+LMAX       = '7e-007-(dxlp_25+dlmisp_25)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63703339+(dvthp_25+vthmisp_25)'
+LVTH0      = '1.238952e-008+dlvthp_25'
+WVTH0      = '1.8953291e-009+dwvthp_25'
+PVTH0      = '-9.8443429e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.070684483+dk2p_25'
+LK2        = '-2.5242368e-009+dlk2p_25'
+WK2        = '9.4832075e-009+dwk2p_25'
+PK2        = '1.9302633e-017+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.6494656e-005+dcitp_25'
+LCIT       = '-3.527384e-011+dlcitp_25'
+WCIT       = '-1.3469575e-010+dwcitp_25'
+PCIT       = '9.2266587e-017+dpcitp_25'
+VOFF       = '-0.077660392+dvoffp_25'
+LVOFF      = '1.6650813e-008+dlvoffp_25'
+WVOFF      = '-4.682312e-009+dwvoffp_25'
+PVOFF      = '-4.2716727e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.47744455+deta0p_25'
+LETA0      = '6.2889491e-009+dleta0p_25'
+WETA0      = '1.4898966e-007+dweta0p_25'
+PETA0      = '-7.6081329e-014+dpeta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0078316258+du0p_25'
+LU0        = '2.8318066e-009+dlu0p_25'
+WU0        = '1.0841205e-009+dwu0p_25'
+PU0        = '-3.9570398e-016+dpu0p_25'
+UA         = -9.9789287e-010     LUA        = 6.6674929e-016      WUA        = 3.232337e-016
+PUA        = -2.1739591e-022     UB         = 1.890541e-018       LUB        = -1.2815735e-025
+WUB        = -2.4849655e-025     PUB        = 1.1099014e-031      UC         = -3.3997165e-011
+LUC        = 4.3196624e-017      WUC        = 2.5795969e-017      PUC        = -1.3405679e-023
+VSAT       = '120000+dvsatp_25'  A0         = '-0.15470335+da0p_25'
+LA0        = '7.5977038e-007+dla0p_25'
+WA0        = '6.8382063e-007+dwa0p_25'
+PA0        = '-4.7205555e-013+dpa0p_25'
+AGS        = '0.10781513+dagsp_25'
+LAGS       = '2.2701809e-007+dlagsp_25'
+WAGS       = '-2.9479508e-008+dwagsp_25'
+PAGS       = '3.3528674e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.030607227        LKETA      = 4.9059202e-009
+WKETA      = 1.9094186e-009      PKETA      = 2.895395e-017       DWG        = 0
+DWB        = 0                   PCLM       = '-0.090043958+dpclmp_25'
+LPCLM      = '3.9349411e-007+dlpclmp_25'
+WPCLM      = '2.2833465e-007+dwpclmp_25'
+PPCLM      = '-1.5640924e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00061167969       LPDIBLC2   = -4.1215059e-010
+WPDIBLC2   = -7.0447566e-010     PPDIBLC2   = 4.8256583e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0082648363
+LTVOFF     = -2.2727898e-009     WTVOFF     = -1.5724669e-009     PTVOFF     = 7.4122112e-016
+KT1        = -0.19230335         LKT1       = -5.3678414e-008     WKT1       = -2.2877123e-008
+PKT1       = 2.2101515e-014      KT1L       = 0                   KT2        = -0.076128019
+LKT2       = 3.9538328e-009      WKT2       = 8.399666e-010       PKT2       = 2.4707371e-015
+UTE        = 0.58430742          LUTE       = -1.0382562e-006     WUTE       = -8.0493582e-007
+PUTE       = 4.6422833e-013      UA1        = 7.9580462e-009      LUA1       = -3.9680757e-015
+WUA1       = -3.0304073e-015     PUA1       = 1.8042171e-021      UB1        = -6.5789123e-018
+LUB1       = 2.5859383e-024      WUB1       = 2.2302735e-024      PUB1       = -1.3145093e-030
+UC1        = 1.2043095e-010      LUC1       = -5.3909297e-017     WUC1       = -4.2627533e-017
+PUC1       = 1.7565396e-023      PRT        = 0                   AT         = 121939.93
+LAT        = -0.073315847        WAT        = -0.077376905        PAT        = 3.2949595e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.MODEL pch_25.20 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-(dxlp_25+dlmisp_25)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_25+dwmisp_25)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_25+toxmisp_25)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_25+dlmisp_25)'  XW         = '7e-09+(dxwp_25+dwmisp_25)'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.68798623+(dvthp_25+vthmisp_25)'
+LVTH0      = '3.0987305e-008+dlvthp_25'
+WVTH0      = '-1.2309216e-008+dwvthp_25'
+PVTH0      = '-4.6596838e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.06622436+dk2p_25'
+LK2        = '-4.1521818e-009+dlk2p_25'
+WK2        = '1.3392156e-008+dwk2p_25'
+PK2        = '-1.4074635e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0010738143+dcitp_25'
+LCIT       = '3.7728892e-010+dlcitp_25'
+WCIT       = '6.2906705e-010+dwcitp_25'
+PCIT       = '-1.8650683e-016+dpcitp_25'
+VOFF       = '-0.12935096+dvoffp_25'
+LVOFF      = '3.551787e-008+dlvoffp_25'
+WVOFF      = '-3.6225413e-009+dwvoffp_25'
+PVOFF      = '-4.658489e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.52223945+deta0p_25'
+LETA0      = '-1.0061189e-008+dleta0p_25'
+WETA0      = '-2.064607e-007+dweta0p_25'
+PETA0      = '5.3658052e-014+dpeta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.019683455+du0p_25'
+LU0        = '-1.4941111e-009+dlu0p_25'
+WU0        = '-1.3748277e-009+dwu0p_25'
+PU0        = '5.0181211e-016+dpu0p_25'
+UA         = 3.0725555e-009      LUA        = -8.1896436e-016     WUA        = -1.0079109e-015
+PUA        = 2.6847187e-022      UB         = -5.0726275e-019     LUB        = 7.4704103e-025
+WUB        = 6.4807129e-025      PUB        = -2.1625712e-031     UC         = 1.4501647e-010
+LUC        = -2.2143351e-017     WUC        = -1.3092362e-017     PUC        = 7.8856188e-025
+VSAT       = '120000+dvsatp_25'  A0         = '3.6857665+da0p_25' LA0        = '-6.4200111e-007+dla0p_25'
+WA0        = '-1.331365e-006+dwa0p_25'
+PA0        = '2.634872e-013+dpa0p_25'
+AGS        = '-1.0058362+dagsp_25'
+LAGS       = '6.3350082e-007+dlagsp_25'
+WAGS       = '1.0996219e-006+dwagsp_25'
+PAGS       = '-3.7859334e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.099167818        LKETA      = 2.9930536e-008
+WKETA      = -7.9296553e-009     PKETA      = 3.6202159e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.7853663+dpclmp_25'
+LPCLM      = '-2.9103063e-007+dlpclmp_25'
+WPCLM      = '-9.5162534e-007+dwpclmp_25'
+PPCLM      = '2.7427616e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.02050574         LPDIBLC2   = 7.2957075e-009
+WPDIBLC2   = 5.5120091e-009      PPDIBLC2   = -1.7864511e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.0012059534
+LTVOFF     = 1.1840485e-009      WTVOFF     = 5.4842531e-009      PTVOFF     = -1.8344817e-015
+KT1        = -0.37469333         LKT1       = 1.2893926e-008      WKT1       = 7.7937783e-008
+PKT1       = -1.4695926e-014     KT1L       = 0                   KT2        = -0.093167253
+LKT2       = 1.0173153e-008      WKT2       = 5.3275499e-009      PKT2       = 8.3276914e-016
+UTE        = -4.8611772          LUTE       = 9.4934572e-007      WUTE       = 1.9062363e-006
+PUTE       = -5.2534948e-013     UA1        = -1.2135077e-008     LUA1       = 3.3659144e-015
+WUA1       = 7.4194929e-015      PUA1       = -2.0099964e-021     UB1        = 7.3080953e-018
+LUB1       = -2.4828195e-024     WUB1       = -5.6625484e-024     PUB1       = 1.5663706e-030
+UC1        = -1.0663781e-010     LUC1       = 2.8970801e-017      WUC1       = 9.3197753e-017
+PUC1       = -3.2010833e-023     PRT        = 0                   AT         = -238957.71
+LAT        = 0.058411792         WAT        = 0.068969287         PAT        = -2.0466765e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_25'
+NOIB       = 'noibpmac_25'
+NOIC       = 'noicpmac_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )



.ends pch_25_mac
.ENDL MAC_25







.LIB MAC_33
**********************************************************************************************
*                                                                                            *
*                                   3.3V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************


**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_33_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwn_33'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_33 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_33  temp2=parn2_33
+fac1='0.267067*temp1*sigma+0.963678*temp2*sigma'
+fac2='0.267067*temp1*sigma-0.963678*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_33='(0.00730940+0.001287615/(lef*1e6)-0.0007615/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisn_33='0.00275107*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_33='-0.00275107*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_33='0.00275107*geo_fac*toxn_33*fac2*mismatchflag' 
.param tnoiax='6.365e4/(l*scale*1e6)+6.113e6'
.param rnoiax='0.01273/(l*scale*1e6)+0.5356'

.param fn_dice='noiseflagn_33_mc*par1fn_mc+noiseflagn_33_mc_mis*par2fn_33_mc'
.param arearatio='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noianmac_33='c1fn_33*2.718**((fn_dice+(1-fn_dice)*noiseflagn_33)*arearatio)'
.param noibnmac_33='c2fn_33*2.718**((fn_dice+(1-fn_dice)*noiseflagn_33)*arearatio)'
.param noicnmac_33='c3fn_33*2.718**((fn_dice+(1-fn_dice)*noiseflagn_33)*arearatio)'

.MODEL nch_33.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_33+dlmisn_33)'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-(dxwn_33+dwmisn_33)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+(dvthn_33+vthmisn_33)'
+K1         = 0.71631             K2         = '-0.048803+dk2n_33' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_33'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_33'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_33'   A0         = '1.1773+da0n_33'    AGS        = '0.3986+dagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       WVTH0      = '0+dwvthn_33'
+PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       WCIT       = '0+dwcitn_33'
+PCIT       = '0+dpcitn_33'       LA0        = '0+dla0n_33'        WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'       WAGS       = '0+dwagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      WETA0      = '0+dweta0n_33'
+PETA0      = '0+dpeta0n_33'      LK2        = '0+dlk2n_33'        WK2        = '0+dwk2n_33'
+PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_33+dlmisn_33)'
+LMAX       = '1e-005-(dxln_33+dlmisn_33)'    WMIN       = '1e-005-(dxwn_33+dwmisn_33)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+(dvthn_33+vthmisn_33)'
+LVTH0      = '1.4790281e-008+dlvthn_33'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_33'
+LK2        = '-1.2153578e-008+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_33'
+LCIT       = '7.5887589e-010+dlcitn_33'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_33'
+LU0        = '2.6891421e-011+dlu0n_33'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.2321467+da0n_33' LA0        = '-5.4764378e-007+dla0n_33'
+AGS        = '0.38027424+dagsn_33'
+LAGS       = '1.8298267e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'        WCIT       = '0+dwcitn_33'
+PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'        PA0        = '0+dpa0n_33'
+WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'
+WETA0      = '0+dweta0n_33'      PETA0      = '0+dpeta0n_33'      WK2        = '0+dwk2n_33'
+PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_33+dlmisn_33)'
+LMAX       = '1.2e-006-(dxln_33+dlmisn_33)'  WMIN       = '1e-005-(dxwn_33+dwmisn_33)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+(dvthn_33+vthmisn_33)'
+LVTH0      = '3.2469e-010+dlvthn_33'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_33'
+LK2        = '-6.7649162e-009+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_33'
+LCIT       = '5.941827e-011+dlcitn_33'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_33'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_33'
+A0         = '1.3065331+da0n_33' LA0        = '-6.3579172e-007+dla0n_33'
+AGS        = '0.9247153+dagsn_33'
+LAGS       = '-4.6217998e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'
+WCIT       = '0+dwcitn_33'       PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'
+LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'
+LETA0      = '0+dleta0n_33'      WETA0      = '0+dweta0n_33'      PETA0      = '0+dpeta0n_33'
+WK2        = '0+dwk2n_33'        PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.4 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-(dxln_33+dlmisn_33)'    WMIN       = '1e-005-(dxwn_33+dwmisn_33)'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.610265+(dvthn_33+vthmisn_33)'
+LVTH0      = '-9.634525e-009+dlvthn_33'
+K1         = 0.71631             K2         = '-0.061443975+dk2n_33'
+LK2        = '-3.8704213e-010+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000563835+dcitn_33'
+LCIT       = '1.6245803e-010+dlcitn_33'
+VOFF       = -0.1374945          LVOFF      = 6.5448325e-009      NFACTOR    = 0.55
+ETA0       = '0.5384555+deta0n_33'
+LETA0      = '-8.7375175e-009+dleta0n_33'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_33'   UA         = -6.3473475e-010     LUA        = -1.563617e-016
+UB         = 2.789025e-018       LUB        = 1.4451788e-025      UC         = 1.588935e-010
+LUC        = 9.634525e-019       VSAT       = '89640+dvsatn_33'   A0         = '0.237041+da0n_33'
+LA0        = '9.6810365e-008+dla0n_33'
+AGS        = '0.85381797+dagsn_33'
+LAGS       = '-4.1361531e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0366945          LKETA      = 3.2225825e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.016415+dpclmn_33'
+LPCLM      = '1.7906928e-007+dlpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.004925            LPDIBLC2   = -1.661125e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0010792           LTVOFF     = 2.25913e-010        WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29831            LKT1       = 8.63785e-009
+KT1L       = 0                   KT2        = -0.0551455          LKT2       = -3.2225825e-009
+UTE        = -1.516875           LUTE       = 1.9102938e-007      UA1        = 2.0056675e-009
+LUA1       = 4.1677626e-016      UB1        = -2.91846e-018       LUB1       = -1.541524e-025
+UC1        = -9.48705e-011       LUC1       = 7.6843643e-017      PRT        = 0
+AT         = 20827.425           LAT        = -0.010101301
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'
+WCIT       = '0+dwcitn_33'       PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      WETA0      = '0+dweta0n_33'
+PETA0      = '0+dpeta0n_33'      WK2        = '0+dwk2n_33'        PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.5 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_33+dlmisn_33)'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-(dxwn_33+dwmisn_33)'    WMAX       = '1e-005-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+(dvthn_33+vthmisn_33)'
+WVTH0      = '-1.9034426e-009+dwvthn_33'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_33'
+WK2        = '8.915949e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_33'
+WCIT       = '3.148518e-010+dwcitn_33'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_33'
+WU0        = '-6.4829015e-009+dwu0n_33'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.1644663+da0n_33' WA0        = '1.2842639e-007+dwa0n_33'
+AGS        = '0.4003119+dagsn_33'
+WAGS       = '-1.7130983e-008+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       PCIT       = '0+dpcitn_33'
+LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'
+LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.6 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_33+dlmisn_33)'
+LMAX       = '1e-005-(dxln_33+dlmisn_33)'    WMIN       = '1e-006-(dxwn_33+dwmisn_33)'    WMAX       = '1e-005-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+(dvthn_33+vthmisn_33)'
+LVTH0      = '1.6445149e-008+dlvthn_33'
+WVTH0      = '-2.4492827e-010+dwvthn_33'
+PVTH0      = '-1.6560265e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_33'
+LK2        = '-1.2004489e-008+dlk2n_33'
+WK2        = '9.0653661e-009+dwk2n_33'
+PK2        = '-1.4919294e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_33'
+LCIT       = '8.1447946e-010+dlcitn_33'
+WCIT       = '3.7057788e-010+dwcitn_33'
+PCIT       = '-5.5642492e-016+dpcitn_33'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_33'
+LU0        = '1.1847165e-011+dlu0n_33'
+WU0        = '-6.4979789e-009+dwu0n_33'
+PU0        = '1.5054787e-016+dpu0n_33'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_33'   A0         = '1.2162348+da0n_33' LA0        = '-5.1690836e-007+dla0n_33'
+WA0        = '1.5922953e-007+dwa0n_33'
+PA0        = '-3.0756929e-013+dpa0n_33'
+AGS        = '0.38190343+dagsn_33'
+LAGS       = '1.838086e-007+dlagsn_33'
+WAGS       = '-1.6303234e-008+dwagsn_33'
+PAGS       = '-8.2650779e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.7 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_33+dlmisn_33)'
+LMAX       = '1.2e-006-(dxln_33+dlmisn_33)'  WMIN       = '1e-006-(dxwn_33+dwmisn_33)'    WMAX       = '1e-005-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+(dvthn_33+vthmisn_33)'
+LVTH0      = '1.7778581e-009+dlvthn_33'
+WVTH0      = '-1.9482295e-009+dwvthn_33'
+PVTH0      = '-1.4541854e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_33'
+LK2        = '-6.2688409e-009+dlk2n_33'
+WK2        = '1.1995574e-008+dwk2n_33'
+PK2        = '-4.9642252e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_33'
+LCIT       = '6.6229996e-011+dlcitn_33'
+WCIT       = '-4.145586e-011+dwcitn_33'
+PCIT       = '-6.8164938e-017+dpcitn_33'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_33'
+LU0        = '-3.4512743e-011+dlu0n_33'
+WU0        = '-6.662385e-009+dwu0n_33'
+PU0        = '3.4536902e-016+dpu0n_33'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.3201499+da0n_33' LA0        = '-6.4004769e-007+dla0n_33'
+WA0        = '-1.3626309e-007+dwa0n_33'
+PA0        = '4.2589454e-014+dpa0n_33'
+AGS        = '0.94327311+dagsn_33'
+LAGS       = '-4.8141448e-007+dlagsn_33'
+WAGS       = '-1.8570803e-007+dwagsn_33'
+PAGS       = '1.9247961e-013+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.8 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-(dxln_33+dlmisn_33)'    WMIN       = '1e-006-(dxwn_33+dwmisn_33)'    WMAX       = '1e-005-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.61260823+(dvthn_33+vthmisn_33)'
+LVTH0      = '-9.6531111e-009+dlvthn_33'
+WVTH0      = '-2.3448733e-008+dwvthn_33'
+PVTH0      = '1.8599153e-016+dpvthn_33'
+K1         = 0.71631             K2         = '-0.061361997+dk2n_33'
+LK2        = '-7.6824392e-010+dlk2n_33'
+WK2        = '-8.2035576e-010+dwk2n_33'
+PK2        = '3.8146864e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00056199471+dcitn_33'
+LCIT       = '1.7336809e-010+dlcitn_33'
+WCIT       = '1.8415807e-011+dwcitn_33'
+PCIT       = '-1.0917703e-016+dpcitn_33'
+VOFF       = -0.13952383         LVOFF      = 8.0391584e-009      WVOFF      = 2.0307493e-008
+PVOFF      = -1.4953719e-014     NFACTOR    = 0.55                ETA0       = '0.54212048+deta0n_33'
+LETA0      = '-9.7151486e-009+dleta0n_33'
+WETA0      = '-3.667542e-008+dweta0n_33'
+PETA0      = '9.7831547e-015+dpeta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039864876+du0n_33'
+LU0        = '-4.3119852e-010+dlu0n_33'
+WU0        = '-1.2457472e-008+dwu0n_33'
+PU0        = '4.3150036e-015+dpu0n_33'
+UA         = -5.7018434e-010     LUA        = -1.846368e-016      WUA        = -6.4595592e-016
+PUA        = 2.8294892e-022      UB         = 2.795246e-018       LUB        = 1.5343922e-025
+WUB        = -6.2253769e-026     PUB        = -8.9275936e-032     UC         = 1.6565338e-010
+LUC        = 1.1841976e-020      WUC        = -6.764611e-017      PUC        = 9.5227665e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.2429578+da0n_33' LA0        = '9.7828886e-008+dla0n_33'
+WA0        = '-5.9209381e-008+dwa0n_33'
+PA0        = '-1.0192336e-014+dpa0n_33'
+AGS        = '0.82120683+dagsn_33'
+LAGS       = '-3.9779908e-007+dlagsn_33'
+WAGS       = '3.2633961e-007+dwagsn_33'
+PAGS       = '-1.5827303e-013+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033517974        LKETA      = 1.1409345e-009
+WKETA      = -3.1787491e-008     PKETA      = 2.0831052e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.018151516+dpclmn_33'
+LPCLM      = '1.8025879e-007+dlpclmn_33'
+WPCLM      = '1.7377311e-008+dwpclmn_33'
+PPCLM      = '-1.1903458e-014+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0049521331        LPDIBLC2   = -1.6797111e-009
+WPDIBLC2   = -2.7152049e-010     PPDIBLC2   = 1.8599153e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00095938099
+LTVOFF     = 3.0676272e-010      WTVOFF     = 1.1990289e-009      PTVOFF     = -8.0906317e-016
+KT1        = -0.29378102         LKT1       = 5.2365858e-009      WKT1       = -4.5321528e-008
+PKT1       = 3.4036451e-014      KT1L       = 0                   KT2        = -0.054709833
+LKT2       = -3.7708737e-009     WKT2       = -4.3597233e-009     PKT2       = 5.4867502e-015
+UTE        = -1.4961476          LUTE       = 1.7430185e-007      WUTE       = -2.0741926e-007
+PUTE       = 1.6739238e-013      UA1        = 2.1614356e-009      LUA1       = 3.4817481e-016
+WUA1       = -1.5587711e-015     PUA1       = 6.8649475e-022      UB1        = -3.0099966e-018
+LUB1       = -1.2751846e-025     WUB1       = 9.1600655e-025      PUB1       = -2.6652587e-031
+UC1        = -1.0154792e-010     LUC1       = 8.2052595e-017      WUC1       = 6.6820968e-017
+PUC1       = -5.2125987e-023     PRT        = 0                   AT         = 17838.697
+LAT        = -0.0086517678       WAT        = 0.029908206         PAT        = -1.450548e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.9 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_33+dlmisn_33)'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-(dxwn_33+dwmisn_33)'    WMAX       = '1e-006-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+(dvthn_33+vthmisn_33)'
+WVTH0      = '-3.8203063e-009+dwvthn_33'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_33'
+WK2        = '2.9951201e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_33'
+WCIT       = '-9.5507656e-011+dwcitn_33'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_33'
+WU0        = '-4.3551491e-009+dwu0n_33'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.472886+da0n_33'  WA0        = '-1.821522e-007+dwa0n_33'
+AGS        = '0.4053948+dagsn_33'
+WAGS       = '-2.2249464e-008+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       PCIT       = '0+dpcitn_33'
+LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'
+LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.10 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_33+dlmisn_33)'
+LMAX       = '1e-005-(dxln_33+dlmisn_33)'    WMIN       = '6e-007-(dxwn_33+dwmisn_33)'    WMAX       = '1e-006-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+(dvthn_33+vthmisn_33)'
+LVTH0      = '1.4894822e-008+dlvthn_33'
+WVTH0      = '-2.3181445e-009+dwvthn_33'
+PVTH0      = '-1.4999085e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_33'
+LK2        = '-1.6226287e-008+dlk2n_33'
+WK2        = '2.7187635e-009+dwk2n_33'
+PK2        = '2.7594208e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_33'
+LCIT       = '2.1866624e-010+dlcitn_33'
+WCIT       = '-9.9870099e-011+dwcitn_33'
+PCIT       = '4.3558988e-017+dpcitn_33'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_33'
+LU0        = '-2.2871153e-009+dlu0n_33'
+WU0        = '-4.6020798e-009+dwu0n_33'
+PU0        = '2.4656031e-015+dpu0n_33'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.5788249+da0n_33' LA0        = '-1.0578002e-006+dla0n_33'
+WA0        = '-2.0589871e-007+dwa0n_33'
+PA0        = '2.3710883e-013+dpa0n_33'
+AGS        = '0.39080402+dagsn_33'
+LAGS       = '1.4568891e-007+dlagsn_33'
+WAGS       = '-2.5266134e-008+dwagsn_33'
+PAGS       = '3.0121451e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.11 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_33+dlmisn_33)'
+LMAX       = '1.2e-006-(dxln_33+dlmisn_33)'  WMIN       = '6e-007-(dxwn_33+dwmisn_33)'    WMAX       = '1e-006-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+(dvthn_33+vthmisn_33)'
+LVTH0      = '-3.5476441e-009+dlvthn_33'
+WVTH0      = '-7.2295476e-009+dwvthn_33'
+PVTH0      = '-9.1790728e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_33'
+LK2        = '-1.1063061e-008+dlk2n_33'
+WK2        = '5.1625327e-009+dwk2n_33'
+PK2        = '-1.3644568e-016+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_33'
+LCIT       = '4.2051414e-012+dlcitn_33'
+WCIT       = '-5.8296345e-011+dwcitn_33'
+PCIT       = '-5.7059101e-018+dpcitn_33'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_33'
+LU0        = '-3.7564604e-009+dlu0n_33'
+WU0        = '-5.975723e-009+dwu0n_33'
+PU0        = '4.0933703e-015+dpu0n_33'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.2496434+da0n_33' LA0        = '-6.6772012e-007+dla0n_33'
+WA0        = '-6.5263056e-008+dwa0n_33'
+PA0        = '7.0455585e-014+dpa0n_33'
+AGS        = '0.79778898+dagsn_33'
+LAGS       = '-3.3658827e-007+dlagsn_33'
+WAGS       = '-3.9205511e-008+dwagsn_33'
+PAGS       = '4.6639613e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.12 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-(dxln_33+dlmisn_33)'    WMIN       = '6e-007-(dxwn_33+dwmisn_33)'    WMAX       = '1e-006-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.62416051+(dvthn_33+vthmisn_33)'
+LVTH0      = '-1.9299366e-008+dlvthn_33'
+WVTH0      = '-3.5081872e-008+dwvthn_33'
+PVTH0      = '9.8997697e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.084614633+dk2n_33'
+LK2        = '1.5013688e-008+dlk2n_33'
+WK2        = '2.2595049e-008+dwk2n_33'
+PK2        = '-1.2077719e-014+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.4407725e-005+dcitn_33'
+LCIT       = '4.7734586e-010+dlcitn_33'
+WCIT       = '5.396259e-010+dwcitn_33'
+PCIT       = '-4.1528265e-016+dpcitn_33'
+VOFF       = -0.14499566         LVOFF      = 6.8014763e-009      WVOFF      = 2.581763e-008
+PVOFF      = -1.3707373e-014     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.027494+du0n_33'  LU0        = '3.85381e-009+dlu0n_33'
+UA         = -1.544506e-009      LUA        = 2.0574611e-016      WUA        = 3.3518603e-016
+PUA        = -1.1016667e-022     UB         = 3.0456506e-018      LUB        = -1.0838841e-026
+WUB        = -3.144112e-025      PUB        = 7.6152075e-032      UC         = 1.3026419e-010
+LUC        = 1.3224341e-017      WUC        = -3.20092e-017       PUC        = -3.7822197e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.071022788+da0n_33'
+LA0        = '1.39635e-007+dla0n_33'
+WA0        = '1.1392917e-007+dwa0n_33'
+PA0        = '-5.2291091e-014+dpa0n_33'
+AGS        = '1.0470243+dagsn_33'
+LAGS       = '-5.0731446e-007+dlagsn_33'
+WAGS       = '9.8941424e-008+dwagsn_33'
+PAGS       = '-4.7991037e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057717038        LKETA      = 1.4264911e-008
+WKETA      = -7.4190347e-009     PKETA      = 7.6152075e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.063135913+dpclmn_33'
+LPCLM      = '1.245769e-007+dlpclmn_33'
+WPCLM      = '-6.4479129e-008+dwpclmn_33'
+PPCLM      = '4.4168203e-014+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0065224688        LPDIBLC2   = -2.7553911e-009
+WPDIBLC2   = -1.8528485e-009     PPDIBLC2   = 1.2692012e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0014579395
+LTVOFF     = -5.478764e-011      WTVOFF     = 6.9698049e-010      PTVOFF     = -4.4498196e-016
+KT1        = -0.41345609         LKT1       = 8.5922521e-008      WKT1       = 7.5191268e-008
+PKT1       = -4.7214286e-014     KT1L       = 0                   KT2        = -0.083150049
+LKT2       = 1.4836089e-008      WKT2       = 2.4279574e-008      PKT2       = -1.3250461e-014
+UTE        = -4.5226643          LUTE       = 2.0823738e-006      WUTE       = 2.8402831e-006
+PUTE       = -1.7540361e-012     UA1        = -8.8292082e-009     LUA1       = 6.9690535e-015
+WUA1       = 9.5088072e-015      PUA1       = -5.9807301e-021     UB1        = 3.5556533e-018
+LUB1       = -4.0190571e-024     WUB1       = -5.6956029e-024     PUB1       = 3.6522535e-030
+UC1        = -9.3333628e-011     LUC1       = 6.4051975e-017      WUC1       = 5.8549173e-017
+PUC1       = -3.3999363e-023     PRT        = 0                   AT         = 36676.356
+LAT        = -0.017788033        WAT        = 0.010938683         PAT        = -5.3052612e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WU0        = '0+dwu0n_33'
+PU0        = '0+dpu0n_33'        LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.13 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_33+dlmisn_33)'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+(dvthn_33+vthmisn_33)'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_33'
+WK2        = '7.0038392e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_33'
+WCIT       = '-1.734284e-010+dwcitn_33'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_33'  WU0        = '2.47049e-010+dwu0n_33'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_33'   A0         = '0.761323+da0n_33'  WA0        = '2.4976654e-007+dwa0n_33'
+AGS        = '0.3716704+dagsn_33'
+WAGS       = '-1.7787528e-009+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'
+PCIT       = '0+dpcitn_33'       LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'
+LAGS       = '0+dlagsn_33'       PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'
+PETA0      = '0+dpeta0n_33'      LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.14 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxln_33+dlmisn_33)'
+LMAX       = '1e-005-(dxln_33+dlmisn_33)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+(dvthn_33+vthmisn_33)'
+LVTH0      = '-2.9748634e-009+dlvthn_33'
+WVTH0      = '4.1584242e-010+dwvthn_33'
+PVTH0      = '-4.1521866e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_33'
+LK2        = '-8.5746992e-009+dlk2n_33'
+WK2        = '7.1926316e-009+dwk2n_33'
+PK2        = '-1.8850927e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_33'
+LCIT       = '2.8299186e-011+dlcitn_33'
+WCIT       = '-1.8936348e-010+dwcitn_33'
+PCIT       = '1.5911179e-016+dpcitn_33'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_33'
+LU0        = '-1.3444366e-009+dlu0n_33'
+WU0        = '5.7424856e-011+dwu0n_33'
+PU0        = '1.8933971e-015+dpu0n_33'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.77421149+da0n_33'
+LA0        = '-1.2869158e-007+dla0n_33'
+WA0        = '2.8250165e-007+dwa0n_33'
+PA0        = '-3.2686013e-013+dpa0n_33'
+AGS        = '0.35349094+dagsn_33'
+LAGS       = '1.8152193e-007+dlagsn_33'
+WAGS       = '-2.6170911e-009+dwagsn_33'
+PAGS       = '8.3708082e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.15 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxln_33+dlmisn_33)'
+LMAX       = '1.2e-006-(dxln_33+dlmisn_33)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+(dvthn_33+vthmisn_33)'
+LVTH0      = '4.9190535e-010+dlvthn_33'
+WVTH0      = '6.7271443e-009+dwvthn_33'
+PVTH0      = '-1.1631079e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_33'
+LK2        = '-8.0997573e-009+dlk2n_33'
+WK2        = '7.2348917e-009+dwk2n_33'
+PK2        = '-1.935171e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_33'
+LCIT       = '-4.8473782e-011+dlcitn_33'
+WCIT       = '-7.7260869e-011+dwcitn_33'
+PCIT       = '2.6270196e-017+dpcitn_33'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_33'
+LU0        = '4.2425619e-009+dlu0n_33'
+WU0        = '2.2982969e-009+dwu0n_33'
+PU0        = '-7.6203623e-016+dpu0n_33'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.2504613+da0n_33' LA0        = '-6.9304756e-007+dla0n_33'
+WA0        = '-6.5759503e-008+dwa0n_33'
+PA0        = '8.5829344e-014+dpa0n_33'
+AGS        = '0.85077416+dagsn_33'
+LAGS       = '-4.0775869e-007+dlagsn_33'
+WAGS       = '-7.1367515e-008+dwagsn_33'
+PAGS       = '8.9840061e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL nch_33.16 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-(dxln_33+dlmisn_33)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwn_33+dwmisn_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxn_33+toxmisn_33)'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxln_33+dlmisn_33)'  XW         = '7e-09+(dxwn_33+dwmisn_33)'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55808764+(dvthn_33+vthmisn_33)'
+LVTH0      = '1.4249961e-008+dlvthn_33'
+WVTH0      = '5.024359e-009+dwvthn_33'
+PVTH0      = '-1.0464671e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.05327862+dk2n_33'
+LK2        = '-5.8268361e-009+dlk2n_33'
+WK2        = '3.5740888e-009+dwk2n_33'
+PK2        = '5.7247908e-016+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0013478911+dcitn_33'
+LCIT       = '-4.4681771e-010+dlcitn_33'
+WCIT       = '-2.5158853e-010+dwcitn_33'
+PCIT       = '1.4568464e-016+dpcitn_33'
+VOFF       = -0.057007723        LVOFF      = -3.9375805e-008     WVOFF      = -2.759105e-008
+PVOFF      = 1.4322237e-014      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.027415653+du0n_33'
+LU0        = '2.569262e-009+dlu0n_33'
+WU0        = '4.7556933e-011+dwu0n_33'
+PU0        = '7.7972061e-016+dpu0n_33'
+UA         = -3.1525033e-010     LUA        = -4.8483422e-016     WUA        = -4.1097219e-016
+PUA        = 3.0901559e-022      UB         = 1.9361005e-018      LUB        = 5.3378591e-025
+WUB        = 3.5908572e-025      PUB        = -2.5443515e-031     UC         = 2.7124189e-010
+LUC        = -1.0141575e-016     WUC        = -1.1758266e-016     PUC        = 6.5804316e-023
+VSAT       = '89640+dvsatn_33'   A0         = '-0.34514734+da0n_33'
+LA0        = '3.9994433e-007+dla0n_33'
+WA0        = '3.6654444e-007+dwa0n_33'
+PA0        = '-2.1029886e-013+dpa0n_33'
+AGS        = '1.1144919+dagsn_33'
+LAGS       = '-5.8840536e-007+dlagsn_33'
+WAGS       = '5.7988577e-008+dwagsn_33'
+PAGS       = '1.2311378e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.15385781         LKETA      = 8.0558749e-008
+WKETA      = 5.0938416e-008      PKETA      = -3.2625152e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.29050755+dpclmn_33'
+LPCLM      = '-3.1172672e-008+dlpclmn_33'
+WPCLM      = '-2.0249371e-007+dwpclmn_33'
+PPCLM      = '1.3870819e-013+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00044751625       LPDIBLC2   = 1.1271564e-009
+WPDIBLC2   = 1.8346476e-009      PPDIBLC2   = -1.0875051e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0081349215
+LTVOFF     = -3.9394086e-009     WTVOFF     = -3.3559476e-009     PTVOFF     = 1.912983e-015
+KT1        = -0.41004433         LKT1       = 6.6958288e-008      WKT1       = 7.3120328e-008
+PKT1       = -3.5702997e-014     KT1L       = 0                   KT2        = 0.0022587488
+LKT2       = -4.0831034e-008     WKT2       = -2.7563566e-008     PKT2       = 2.0539483e-014
+UTE        = 1.8537909           LUTE       = -2.0005842e-006     WUTE       = -1.0302252e-006
+PUTE       = 7.2431941e-013      UA1        = 1.3867563e-008      LUA1       = -7.7046524e-015
+WUA1       = -4.2681328e-015     PUA1       = 2.9262094e-021      UB1        = -1.1144346e-017
+LUB1       = 5.6158658e-024      WUB1       = 3.2272968e-024      PUB1       = -2.1961447e-030
+UC1        = -8.990499e-011      LUC1       = 6.104435e-017       WUC1       = 5.646799e-017
+PUC1       = -3.2173735e-023     PRT        = 0                   AT         = 69891.578
+LAT        = -0.033897415        WAT        = -0.0092229568       PAT        = 4.473134e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noianmac_33'
+NOIB       = 'noibnmac_33'
+NOIC       = 'noicnmac_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LETA0      = '0+dleta0n_33'
+PETA0      = '0+dpeta0n_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )
**********************************************************************************************
*                                                                                            *
*                                   3.3V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.ends nch_33_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_33_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.245e-7' xw='+7e-09+dxwp_33'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_33 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_33  temp2=parp2_33
+fac1='0.918790*temp1*sigma+0.394746*temp2*sigma'
+fac2='0.918790*temp1*sigma-0.394746*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_33='(0.0040365603+0.00063585645603/(lef*1e6)-0.00028565603/(wef*1e6))*geo_fac*fac1*mismatchflag'
+       dlmisp_33='0.00197184*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_33='-0.00197184*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_33='0.00197184*geo_fac*toxp_33*fac2*mismatchflag' 
.param tnoiax='2.295e6/(l*scale*1e6)+3.979e7'
.param rnoiax='0.006365/(l*scale*1e6)+0.5496'

.param fn_dice='noiseflagp_33_mc*par1fn_mc+noiseflagp_33_mc_mis*par2fp_33_mc'
.param arearatio='sigma_factor_flicker_33*(log(3.873)-min(0,0.36*log(((w*scale*l*scale*multi)/(28E-6*1E-6*1))**0.5)))'
.param noiapmac_33='c1fp_33*2.718**((fn_dice+(1-fn_dice)*noiseflagp_33)*arearatio)'
.param noibpmac_33='c2fp_33*2.718**((fn_dice+(1-fn_dice)*noiseflagp_33)*arearatio)'
.param noicpmac_33='c3fp_33*2.718**((fn_dice+(1-fn_dice)*noiseflagp_33)*arearatio)'

.MODEL pch_33.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_33+dlmisp_33)'
+LMAX       = 900.001e-6          WMIN       = '1e-005-(dxwp_33+dwmisp_33)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+(dvthp_33+vthmisp_33)'
+K1         = 0.72417             K2         = '-0.05886+dk2p_33'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_33'
+VOFF       = '-0.08693+dvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_33'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_33'
+A0         = '1.297+da0p_33'     AGS        = '0.2718+dagsp_33'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_33'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'
+LCIT       = '0+dlcitp_33'       WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'
+LU0        = '0+dlu0p_33'        WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+LA0        = '0+dla0p_33'        WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       WAGS       = '0+dwagsp_33'       PAGS       = '0+dpagsp_33'
+LPCLM      = '0+dlpclmp_33'      WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+LVOFF      = '0+dlvoffp_33'      WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'
+LK2        = '0+dlk2p_33'        WK2        = '0+dwk2p_33'        PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_33+dlmisp_33)'
+LMAX       = '1e-005-(dxlp_33+dlmisp_33)'    WMIN       = '1e-005-(dxwp_33+dwmisp_33)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+(dvthp_33+vthmisp_33)'
+LVTH0      = '4.3026273e-009+dlvthp_33'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_33'
+LK2        = '-7.5295977e-010+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_33'
+LCIT       = '2.3222086e-010+dlcitp_33'
+VOFF       = '-0.087552125+dvoffp_33'
+LVOFF      = '6.2119181e-009+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_33'
+LU0        = '9.4119972e-011+dlu0p_33'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_33'  A0         = '1.3227199+da0p_33' LA0        = '-2.5681307e-007+dla0p_33'
+AGS        = '0.25480602+dagsp_33'
+LAGS       = '1.6968486e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_33'
+LPCLM      = '2.5143478e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'
+PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_33+dlmisp_33)'
+LMAX       = '1.2e-006-(dxlp_33+dlmisp_33)'  WMIN       = '1e-005-(dxwp_33+dwmisp_33)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+(dvthp_33+vthmisp_33)'
+LVTH0      = '1.3149945e-008+dlvthp_33'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_33'
+LK2        = '4.740474e-009+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_33'
+LCIT       = '2.0991209e-010+dlcitp_33'
+VOFF       = '-0.09229456+dvoffp_33'
+LVOFF      = '1.1831704e-008+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_33' LU0        = '-5.032695e-010+dlu0p_33'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_33'  A0         = '1.5469482+da0p_33' LA0        = '-5.2252362e-007+dla0p_33'
+AGS        = '0.2391074+dagsp_33'
+LAGS       = '1.8828773e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_33'
+LPCLM      = '1.2183992e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'
+PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.4 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-(dxlp_33+dlmisp_33)'    WMIN       = '1e-005-(dxwp_33+dwmisp_33)'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66820333+(dvthp_33+vthmisp_33)'
+LVTH0      = '2.5141783e-008+dlvthp_33'
+K1         = 0.72417             K2         = '-0.057809+dk2p_33' LK2        = '8.96665e-010+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00019533833+dcitp_33'
+LCIT       = '8.2721742e-011+dlcitp_33'
+VOFF       = '-0.13908857+dvoffp_33'
+LVOFF      = '4.3885598e-008+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.95879833+deta0p_33'
+LETA0      = '-2.5379136e-007+dleta0p_33'
+ETAB       = 0.25185033          LETAB      = -2.3775688e-007     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012313333+du0p_33'
+LU0        = '-3.5163333e-010+dlu0p_33'
+UA         = 7.2328648e-010      LUA        = -2.7784044e-016     UB         = 1.059925e-018
+LUB        = 2.0438688e-025      UC         = 4.4832033e-011      LUC        = 1.6890707e-017
+VSAT       = '120000+dvsatp_33'  A0         = '0.37262633+da0p_33'
+LA0        = '2.8188686e-007+dla0p_33'
+AGS        = '0.30685+dagsp_33'  LAGS       = '1.4188405e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.052654           LKETA      = 6.43489e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.010440833+dpclmp_33'
+LPCLM      = '2.6825228e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0059350667
+LTVOFF     = -1.2412657e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20446833         LKT1       = -4.6327692e-008     KT1L       = 0
+KT2        = -0.072545           LKT2       = 5.538225e-009       UTE        = -0.36603333
+LUTE       = -4.3426717e-007     UA1        = 4.0224725e-009      LUA1       = -1.5107487e-015
+UB1        = -4.1472483e-018     LUB1       = 9.2629011e-025      UC1        = 1.1546283e-010
+LUC1       = -6.3830241e-017     PRT        = 0                   AT         = 130321.17
+LAT        = -0.045984849
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'      WVOFF      = '0+dwvoffp_33'
+PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'        PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.5 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_33+dlmisp_33)'
+LMAX       = 900.001e-6          WMIN       = '1e-006-(dxwp_33+dwmisp_33)'    WMAX       = '1e-005-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+(dvthp_33+vthmisp_33)'
+WVTH0      = '-1.5339508e-008+dwvthp_33'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_33'
+WK2        = '-1.0189016e-009+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_33'
+WCIT       = '-1.017782e-011+dwcitp_33'
+VOFF       = '-0.085385933+dvoffp_33'
+WVOFF      = '-1.5451475e-008+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_33'
+WU0        = '-2.0154098e-010+dwu0p_33'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.2936433+da0p_33' WA0        = '3.3590163e-008+dwa0p_33'
+AGS        = '0.27102797+dagsp_33'
+WAGS       = '7.7257376e-009+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'
+PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'       PCIT       = '0+dpcitp_33'
+LU0        = '0+dlu0p_33'        PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'
+PA0        = '0+dpa0p_33'        LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'
+LPCLM      = '0+dlpclmp_33'      WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      PETA0      = '0+dpeta0p_33'      LVOFF      = '0+dlvoffp_33'
+PVOFF      = '0+dpvoffp_33'      LK2        = '0+dlk2p_33'        PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_33+dlmisp_33)'
+LMAX       = '1e-005-(dxlp_33+dlmisp_33)'    WMIN       = '1e-006-(dxwp_33+dwmisp_33)'    WMAX       = '1e-005-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+(dvthp_33+vthmisp_33)'
+LVTH0      = '2.9336e-009+dlvthp_33'
+WVTH0      = '-1.6711552e-008+dwvthp_33'
+PVTH0      = '1.3699856e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_33'
+LK2        = '-5.724287e-010+dlk2p_33'
+WK2        = '-8.3797279e-010+dwk2p_33'
+PK2        = '-1.8065744e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_33'
+LCIT       = '2.5685734e-010+dlcitp_33'
+WCIT       = '1.4512935e-011+dwcitp_33'
+PCIT       = '-2.4653719e-016+dpcitp_33'
+VOFF       = '-0.085808935+dvoffp_33'
+LVOFF      = '4.2236693e-009+dlvoffp_33'
+WVOFF      = '-1.7444105e-008+dwvoffp_33'
+PVOFF      = '1.9896406e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_33'
+LU0        = '6.5535886e-011+dlu0p_33'
+WU0        = '-2.3018805e-010+dwu0p_33'
+PU0        = '2.8604095e-016+dpu0p_33'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.3194838+da0p_33' LA0        = '-2.5801661e-007+dla0p_33'
+WA0        = '3.2383971e-008+dwa0p_33'
+PA0        = '1.2043829e-014+dpa0p_33'
+AGS        = '0.25390291+dagsp_33'
+LAGS       = '1.7099371e-007+dlagsp_33'
+WAGS       = '9.0374716e-009+dwagsp_33'
+PAGS       = '-1.3097665e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_33'
+LPCLM      = '2.479746e-007+dlpclmp_33'
+WPCLM      = '-3.4678027e-009+dwpclmp_33'
+PPCLM      = '3.462601e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.7 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_33+dlmisp_33)'
+LMAX       = '1.2e-006-(dxlp_33+dlmisp_33)'  WMIN       = '1e-006-(dxwp_33+dwmisp_33)'    WMAX       = '1e-005-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+(dvthp_33+vthmisp_33)'
+LVTH0      = '1.3912858e-008+dlvthp_33'
+WVTH0      = '1.2921016e-009+dwvthp_33'
+PVTH0      = '-7.6344731e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_33'
+LK2        = '5.12738e-009+dlk2p_33'
+WK2        = '9.0480703e-010+dwk2p_33'
+PK2        = '-3.8717685e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_33'
+LCIT       = '2.2066735e-010+dlcitp_33'
+WCIT       = '-1.027101e-010+dwcitp_33'
+PCIT       = '-1.0762789e-016+dpcitp_33'
+VOFF       = '-0.092580246+dvoffp_33'
+LVOFF      = '1.2247673e-008+dlvoffp_33'
+WVOFF      = '2.8588588e-009+dwvoffp_33'
+PVOFF      = '-4.1626056e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_33'
+LU0        = '-5.6139623e-010+dlu0p_33'
+WU0        = '-4.7966753e-010+dwu0p_33'
+PU0        = '5.8167414e-016+dpu0p_33'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.5239739+da0p_33' LA0        = '-5.0033737e-007+dla0p_33'
+WA0        = '2.2990429e-007+dwa0p_33'
+PA0        = '-2.2201775e-013+dpa0p_33'
+AGS        = '0.23113396+dagsp_33'
+LAGS       = '1.9797491e-007+dlagsp_33'
+WAGS       = '7.9790186e-008+dwagsp_33'
+PAGS       = '-9.6939631e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_33'
+LPCLM      = '1.321774e-007+dlpclmp_33'
+WPCLM      = '1.130496e-007+dwpclmp_33'
+PPCLM      = '-1.0344711e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.8 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-(dxlp_33+dlmisp_33)'    WMIN       = '1e-006-(dxwp_33+dwmisp_33)'    WMAX       = '1e-005-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+(dvthp_33+vthmisp_33)'
+LVTH0      = '2.5702433e-008+dlvthp_33'
+WVTH0      = '-1.6627131e-009+dwvthp_33'
+PVTH0      = '-5.610425e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2p_33'
+LK2        = '7.9535455e-010+dlk2p_33'
+WK2        = '-6.2274297e-009+dwk2p_33'
+PK2        = '1.0138136e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitp_33'
+LCIT       = '6.8571721e-011+dlcitp_33'
+WCIT       = '-4.6654535e-010+dwcitp_33'
+PCIT       = '1.4159925e-016+dpcitp_33'
+VOFF       = '-0.14042777+dvoffp_33'
+LVOFF      = '4.5023226e-008+dlvoffp_33'
+WVOFF      = '1.3401393e-008+dwvoffp_33'
+PVOFF      = '-1.1384241e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.93976958+deta0p_33'
+LETA0      = '-2.4127017e-007+dleta0p_33'
+WETA0      = '1.9042077e-007+dweta0p_33'
+PETA0      = '-1.2529949e-013+dpeta0p_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0p_33'
+LU0        = '-4.3228825e-010+dlu0p_33'
+WU0        = '-8.0877649e-010+dwu0p_33'
+PU0        = '8.0711378e-016+dpu0p_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatp_33'  A0         = '0.37683406+da0p_33'
+LA0        = '2.8545338e-007+dla0p_33'
+WA0        = '-4.2106763e-008+dwa0p_33'
+PA0        = '-3.5690177e-014+dpa0p_33'
+AGS        = '0.30127989+dagsp_33'
+LAGS       = '1.4992495e-007+dlagsp_33'
+WAGS       = '5.5740077e-008+dwagsp_33'
+PAGS       = '-8.0465306e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmp_33'
+LPCLM      = '2.5263178e-007+dlpclmp_33'
+WPCLM      = '-2.6616416e-007+dwpclmp_33'
+PPCLM      = '1.5631432e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.9 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_33+dlmisp_33)'
+LMAX       = 900.001e-6          WMIN       = '6e-007-(dxwp_33+dwmisp_33)'    WMAX       = '1e-006-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+(dvthp_33+vthmisp_33)'
+WVTH0      = '-9.168735e-010+dwvthp_33'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_33'
+WK2        = '6.3722708e-009+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.1087682+dvoffp_33'
+WVOFF      = '8.0944649e-009+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_33'
+WU0        = '-4.7371798e-010+dwu0p_33'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.1646275+da0p_33' WA0        = '1.6350911e-007+dwa0p_33'
+AGS        = '0.26549775+dagsp_33'
+WAGS       = '1.3294666e-008+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LU0        = '0+dlu0p_33'
+PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'
+PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'
+PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'       LPCLM      = '0+dlpclmp_33'
+WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      LVOFF      = '0+dlvoffp_33'      PVOFF      = '0+dpvoffp_33'
+LK2        = '0+dlk2p_33'        PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.10 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_33+dlmisp_33)'
+LMAX       = '1e-005-(dxlp_33+dlmisp_33)'    WMIN       = '6e-007-(dxwp_33+dwmisp_33)'    WMAX       = '1e-006-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+(dvthp_33+vthmisp_33)'
+LVTH0      = '2.5515924e-008+dlvthp_33'
+WVTH0      = '-1.1460919e-011+dwvthp_33'
+PVTH0      = '-9.0405446e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_33'
+LK2        = '-7.6918538e-009+dlk2p_33'
+WK2        = '5.8351965e-009+dwk2p_33'
+PK2        = '5.3626867e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_33'
+LCIT       = '3.029537e-011+dlcitp_33'
+WCIT       = '1.8416915e-012+dwcitp_33'
+PCIT       = '-1.838929e-017+dpcitp_33'
+VOFF       = '-0.11242711+dvoffp_33'
+LVOFF      = '3.6534227e-008+dlvoffp_33'
+WVOFF      = '9.3603963e-009+dwvoffp_33'
+PVOFF      = '-1.2640325e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_33'
+LU0        = '-2.8293136e-010+dlu0p_33'
+WU0        = '-5.3750841e-010+dwu0p_33'
+PU0        = '6.3694746e-016+dpu0p_33'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_33'  A0         = '1.1751703+da0p_33' LA0        = '-1.0526983e-007+dla0p_33'
+WA0        = '1.7770762e-007+dwa0p_33'
+PA0        = '-1.4177218e-013+dpa0p_33'
+AGS        = '0.25327996+dagsp_33'
+LAGS       = '1.2199468e-007+dlagsp_33'
+WAGS       = '9.6647844e-009+dwagsp_33'
+PAGS       = '3.6244365e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_33'
+LPCLM      = '2.6195605e-007+dlpclmp_33'
+WPCLM      = '-2.0577559e-009+dwpclmp_33'
+PPCLM      = '2.0546692e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.11 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_33+dlmisp_33)'
+LMAX       = '1.2e-006-(dxlp_33+dlmisp_33)'  WMIN       = '6e-007-(dxwp_33+dwmisp_33)'    WMAX       = '1e-006-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+(dvthp_33+vthmisp_33)'
+LVTH0      = '-7.9573402e-009+dlvthp_33'
+WVTH0      = '-1.9783074e-008+dwvthp_33'
+PVTH0      = '1.4388817e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_33'
+LK2        = '1.295992e-008+dlk2p_33'
+WK2        = '2.0283992e-008+dwk2p_33'
+PK2        = '-1.1759136e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_33'
+LCIT       = '2.8646031e-010+dlcitp_33'
+WCIT       = '1.3305867e-010+dwcitp_33'
+PCIT       = '-1.7388141e-016+dpcitp_33'
+VOFF       = '-0.073036514+dvoffp_33'
+LVOFF      = '-1.0143628e-008+dlvoffp_33'
+WVOFF      = '-1.6821679e-008+dwvoffp_33'
+PVOFF      = '1.8385435e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_33'
+LU0        = '-1.6343677e-009+dlu0p_33'
+WU0        = '-1.4026636e-009+dwu0p_33'
+PU0        = '1.6621564e-015+dpu0p_33'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_33'  A0         = '2.1264181+da0p_33' LA0        = '-1.2324985e-006+dla0p_33'
+WA0        = '-3.7675707e-007+dwa0p_33'
+PA0        = '5.1526849e-013+dpa0p_33'
+AGS        = '0.24152159+dagsp_33'
+LAGS       = '1.3592834e-007+dlagsp_33'
+WAGS       = '6.9329848e-008+dwagsp_33'
+PAGS       = '-3.4458735e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_33'
+LPCLM      = '-2.323312e-007+dlpclmp_33'
+WPCLM      = '-2.0717704e-007+dwpclmp_33'
+PPCLM      = '2.6361305e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.12 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-(dxlp_33+dlmisp_33)'    WMIN       = '6e-007-(dxwp_33+dwmisp_33)'    WMAX       = '1e-006-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.71413591+(dvthp_33+vthmisp_33)'
+LVTH0      = '4.9746007e-008+dlvthp_33'
+WVTH0      = '4.4758708e-008+dwvthp_33'
+PVTH0      = '-2.9822304e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.081500912+dk2p_33'
+LK2        = '1.210067e-008+dlk2p_33'
+WK2        = '1.8256989e-008+dwk2p_33'
+PK2        = '-1.0370639e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00027074978+dcitp_33'
+LCIT       = '3.2519209e-010+dlcitp_33'
+WCIT       = '4.9753631e-011+dwcitp_33'
+PCIT       = '-1.1681746e-016+dpcitp_33'
+VOFF       = '-0.16416909+dvoffp_33'
+LVOFF      = '5.2282189e-008+dlvoffp_33'
+WVOFF      = '3.7308907e-008+dwvoffp_33'
+PVOFF      = '-1.8694017e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '1.6257923+deta0p_33'
+LETA0      = '-6.5838023e-007+dleta0p_33'
+WETA0      = '-5.0040409e-007+dweta0p_33'
+PETA0      = '2.9473034e-013+dpeta0p_33'
+ETAB       = 0.28491024          LETAB      = -2.4719608e-007     WETAB      = -1.0607259e-007
+PETAB      = 6.9665977e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0129307+du0p_33' LU0        = '-1.2449358e-009+dlu0p_33'
+WU0        = '-1.3490775e-009+dwu0p_33'
+PU0        = '1.6254499e-015+dpu0p_33'
+UA         = 6.2049606e-010      LUA        = -4.3022473e-016     WUA        = -6.5221192e-016
+PUA        = 4.4372955e-022      UB         = 1.2460966e-018      LUB        = 2.1743335e-025
+WUB        = 3.6166585e-025      PUB        = -2.4878787e-031     UC         = 8.592997e-011
+LUC        = -2.2891515e-017     WUC        = -4.1761652e-017     PUC        = 2.3121689e-023
+VSAT       = '120000+dvsatp_33'  A0         = '-1.1286012+da0p_33'
+LA0        = '9.9718972e-007+dla0p_33'
+WA0        = '1.4738665e-006+dwa0p_33'
+PA0        = '-7.5240867e-013+dpa0p_33'
+AGS        = '0.33709696+dagsp_33'
+LAGS       = '7.0459211e-008+dlagsp_33'
+WAGS       = '1.9672285e-008+dwagsp_33'
+PAGS       = '-4.4330452e-016+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.01845363         LKETA      = 3.1288949e-009
+WKETA      = -5.7256713e-009     PKETA      = 1.2842398e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.91948422+dpclmp_33'
+LPCLM      = '7.6117178e-007+dlpclmp_33'
+WPCLM      = '6.9705435e-007+dwpclmp_33'
+PPCLM      = '-3.5578546e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00053371608
+LTVOFF     = 8.3825431e-010      WTVOFF     = 3.3007955e-009      PTVOFF     = -1.2708063e-015
+KT1        = -0.22796155         LKT1       = -3.7282803e-008     WKT1       = 3.7683501e-008
+PKT1       = -1.4508148e-014     KT1L       = 0                   KT2        = -0.076177783
+LKT2       = 6.9368466e-009      WKT2       = 4.1870557e-009      PKT2       = -1.6120164e-015
+UTE        = -0.63624871         LUTE       = -3.3023425e-007     WUTE       = -3.1402917e-008
+PUTE       = 1.2090123e-014      UA1        = 2.5730296e-009      LUA1       = -9.5271316e-016
+WUA1       = 4.5708691e-016      PUA1       = -1.7597846e-022     UB1        = -2.4655743e-018
+LUB1       = 1.8683839e-025      WUB1       = -5.3163127e-025     PUB1       = 3.2334363e-031
+UC1        = 1.2926861e-010      LUC1       = -6.9145464e-017     WUC1       = -2.0202544e-017
+PUC1       = 7.7779793e-024      PRT        = 0                   AT         = -112231.74
+LAT        = 0.04739802          WAT        = 0.013468362         PAT        = -5.1853195e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.13 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_33+dlmisp_33)'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+(dvthp_33+vthmisp_33)'
+WVTH0      = '-1.235245e-008+dwvthp_33'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_33'
+WK2        = '1.0981328e-008+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.082272655+dvoffp_33'
+WVOFF      = '-7.9883294e-009+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_33'
+WU0        = '5.0645045e-010+dwu0p_33'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.517435+da0p_33'  WA0        = '-5.0645045e-008+dwa0p_33'
+AGS        = '0.2802775+dagsp_33'
+WAGS       = '4.3233575e-009+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_33'
+WPCLM      = '-1.235245e-008+dwpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LU0        = '0+dlu0p_33'
+PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'
+PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'
+PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'       LPCLM      = '0+dlpclmp_33'
+PPCLM      = '0+dppclmp_33'      LETA0      = '0+dleta0p_33'      PETA0      = '0+dpeta0p_33'
+LVOFF      = '0+dlvoffp_33'      PVOFF      = '0+dpvoffp_33'      LK2        = '0+dlk2p_33'
+PK2        = '0+dpk2p_33'        
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.14 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_33+dlmisp_33)'
+LMAX       = '1e-005-(dxlp_33+dlmisp_33)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+(dvthp_33+vthmisp_33)'
+LVTH0      = '1.3084693e-008+dlvthp_33'
+WVTH0      = '-1.2202747e-008+dwvthp_33'
+PVTH0      = '-1.4947872e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_33'
+LK2        = '1.8463044e-008+dlk2p_33'
+WK2        = '1.2034241e-008+dwk2p_33'
+PK2        = '-1.0513336e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.08299213+dvoffp_33'
+LVOFF      = '7.1839623e-009+dlvoffp_33'
+WVOFF      = '-8.5066354e-009+dwvoffp_33'
+PVOFF      = '5.1752854e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_33'
+LU0        = '8.2354975e-011+dlu0p_33'
+WU0        = '4.6486621e-010+dwu0p_33'
+PU0        = '4.1521866e-016+dpu0p_33'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.5401338+da0p_33' LA0        = '-2.2664761e-007+dla0p_33'
+WA0        = '-4.3825229e-008+dwa0p_33'
+PA0        = '-6.809586e-014+dpa0p_33'
+AGS        = '0.25532754+dagsp_33'
+LAGS       = '2.4912535e-007+dlagsp_33'
+WAGS       = '8.4219004e-009+dwagsp_33'
+PAGS       = '-4.0923951e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_33'
+LPCLM      = '4.3261573e-007+dlpclmp_33'
+WPCLM      = '-4.0356016e-009+dwpclmp_33'
+PPCLM      = '-8.3043732e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.15 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-(dxlp_33+dlmisp_33)'
+LMAX       = '1.2e-006-(dxlp_33+dlmisp_33)'  WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+(dvthp_33+vthmisp_33)'
+LVTH0      = '1.3104488e-008+dlvthp_33'
+WVTH0      = '-1.4817999e-008+dwvthp_33'
+PVTH0      = '1.6042868e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_33'
+LK2        = '-2.3393752e-008+dlk2p_33'
+WK2        = '-5.536121e-009+dwk2p_33'
+PK2        = '1.0307543e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.10923032+dvoffp_33'
+LVOFF      = '3.8276211e-008+dlvoffp_33'
+WVOFF      = '5.1479577e-009+dwvoffp_33'
+PVOFF      = '-1.1005407e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_33'
+LU0        = '1.9298762e-009+dlu0p_33'
+WU0        = '1.2383331e-009+dwu0p_33'
+PU0        = '-5.0133962e-016+dpu0p_33'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.8892247+da0p_33' LA0        = '-6.4032034e-007+dla0p_33'
+WA0        = '-2.3278069e-007+dwa0p_33'
+PA0        = '1.5581636e-013+dpa0p_33'
+AGS        = '0.50163406+dagsp_33'
+LAGS       = '-4.2747874e-008+dlagsp_33'
+WAGS       = '-8.855842e-008+dwagsp_33'
+PAGS       = '7.3997729e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_33'
+LPCLM      = '3.733935e-009+dlpclmp_33'
+WPCLM      = '-1.7565184e-007+dwpclmp_33'
+PPCLM      = '1.2032151e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.MODEL pch_33.16 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-(dxlp_33+dlmisp_33)'    WMIN       = 4e-07               WMAX       = '6e-007-(dxwp_33+dwmisp_33)'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = '(toxp_33+toxmisp_33)'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+(dxlp_33+dlmisp_33)'  XW         = '7e-09+(dxwp_33+dwmisp_33)'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.61514398+(dvthp_33+vthmisp_33)'
+LVTH0      = '-2.6047239e-009+dlvthp_33'
+WVTH0      = '-1.532939e-008+dwvthp_33'
+PVTH0      = '1.9545899e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.058122211+dk2p_33'
+LK2        = '-1.1129393e-008+dlk2p_33'
+WK2        = '4.0661177e-009+dwk2p_33'
+PK2        = '3.7300091e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00023030751+dcitp_33'
+LCIT       = '1.6118564e-010+dlcitp_33'
+WCIT       = '2.5205174e-011+dwcitp_33'
+PCIT       = '-1.7265544e-017+dpcitp_33'
+VOFF       = '-0.076624005+dvoffp_33'
+LVOFF      = '1.5940888e-008+dlvoffp_33'
+WVOFF      = '-1.5830962e-008+dwvoffp_33'
+PVOFF      = '3.3651523e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.64909037+deta0p_33'
+LETA0      = '-1.1128843e-007+dleta0p_33'
+WETA0      = '9.2453971e-008+dweta0p_33'
+PETA0      = '-3.7354385e-014+dpeta0p_33'
+ETAB       = -0.13694024         LETAB      = 9.1690589e-009      WETAB      = 1.4999065e-007
+PETAB      = -8.5947663e-014     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.014444088+du0p_33'
+LU0        = '-1.6977297e-009+dlu0p_33'
+WU0        = '-2.267704e-009+dwu0p_33'
+PU0        = '1.9002958e-015+dpu0p_33'
+UA         = 6.2446178e-010      LUA        = -4.4456365e-016     WUA        = -6.5461912e-016
+PUA        = 4.5243327e-022      UB         = 1.4852981e-018      LUB        = 1.4943406e-025
+WUB        = 2.1647051e-025      PUB        = -2.075123e-031      UC         = 7.8058186e-012
+LUC        = 1.456158e-017       WUC        = 5.6597073e-018      PUC        = 3.8766034e-025
+VSAT       = '120000+dvsatp_33'  A0         = '2.0277567+da0p_33' LA0        = '-7.3521475e-007+dla0p_33'
+WA0        = '-4.4204272e-007+dwa0p_33'
+PA0        = '2.9916085e-013+dpa0p_33'
+AGS        = '0.27898717+dagsp_33'
+LAGS       = '1.0976525e-007+dlagsp_33'
+WAGS       = '5.4944933e-008+dwagsp_33'
+PAGS       = '-2.4302068e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.017067018        LKETA      = -4.3691233e-009
+WKETA      = -6.5673447e-009     PKETA      = 5.8355368e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.38502207+dpclmp_33'
+LPCLM      = '6.8073884e-008+dlpclmp_33'
+WPCLM      = '-9.4780967e-008+dwpclmp_33'
+PPCLM      = '6.4924962e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0078162936
+LTVOFF     = -1.965538e-009      WTVOFF     = -1.119729e-009      PTVOFF     = 4.3109567e-016
+KT1        = -0.20119403         LKT1       = -4.7588297e-008     WKT1       = 2.1435618e-008
+PKT1       = -8.252713e-015      KT1L       = 0                   KT2        = -0.086007533
+LKT2       = 1.07213e-008        WKT2       = 1.0153714e-008      PKT2       = -3.9091799e-015
+UTE        = -0.20938525         LUTE       = -4.9457668e-007     WUTE       = -2.9050904e-007
+PUTE       = 1.1184598e-013      UA1        = 4.8176091e-009      LUA1       = -1.8168763e-015
+WUA1       = -9.0537282e-016     PUA1       = 3.4856854e-022      UB1        = -4.6703481e-018
+LUB1       = 1.2785718e-024      WUB1       = 8.0666645e-025      PUB1       = -3.3933853e-031
+UC1        = 1.5987652e-010      LUC1       = -8.0929511e-017     WUC1       = -3.8781546e-017
+PUC1       = 1.4930895e-023      PRT        = 0                   AT         = 20080.692
+LAT        = -0.0035422663       WAT        = -0.066845283        PAT        = 2.5735434e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiapmac_33'
+NOIB       = 'noibpmac_33'
+NOIC       = 'noicpmac_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      
+RNOIB    = 0
+RNOIA    = rnoiax
+TNOIA    = tnoiax   )


.ends pch_33_mac
.ENDL MAC_33







***************************************************************
*                                                             *
*                     Native DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MAC_na
**********************************************************************************************
*                                                                                            *
*                                  1.2V Native NMOS DEVICE MODELS                            *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_na_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='6.70e-008' xw='+2e-08+dxwn_na'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-007/scale' sb='0e-007/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_na w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_na  temp2=parn2_na
+fac1='0.140524*temp1*sigma+0.990077*temp2*sigma'
+fac2='0.140524*temp1*sigma-0.990077*temp2*sigma'
.param  lef='l*scale-1.00E-09'
+       wef='w/nf*scale+2e-08'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_na='0.00566925*geo_fac*fac1*mismatchflag'
+       dlmisn_na='0.00458676*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_na='-0.00458676*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_na='0.00458676*geo_fac*toxn_na*fac2*mismatchflag' 

.MODEL nch_na.1 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+LMAX       = 20.001e-6           WMIN       = '1e-005-(dxwn_na+dwmisn_na)'    WMAX       = 900.001e-6          
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' 
+XW         = '2e-08+(dxwn_na+dwmisn_na)'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.2215+(dvthn_na+vthmisn_na)'  
+K1         = 0.07                
+K2         = '0.003274+dk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            
+W0         = 0                   DVT0       = 1.2e-006            DVT1       = 0.1                 
+DVT2       = 0.16                DVT0W      = 0                   DVT1W      = 0                   
+DVT2W      = 0                   DSUB       = 0.1693              MINV       = -0.45422941         
+VOFFL      = 0                   DVTP0      = 0.0001              DVTP1      = 2.22e-015           
+LPE0       = 1.114e-006          LPEB       = 6.974e-008          WEB        = 0                   
+WEC        = 0                   SCREF      = 1e-006              KVTH0WE    = 0                   
+LKVTH0WE   = 0                   WKVTH0WE   = 0                   PKVTH0WE   = 0                   
+K2WE       = 0                   LK2WE      = 0                   WK2WE      = 0                   
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 1e+023              
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0                   
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0                   
+CIT        = 0.001465            VOFF       = -0.02904            NFACTOR    = 1                   
+ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                   U0         = 0.0417              UA         = -8.233e-012         
+UB         = 2.608e-18           
+Pub      = 0 
+Wub      = 0 
+Lub      = 0 
+UC         = 5.201e-011          VSAT       = '110000+dvsatn_na'  
+A0         = 12                  
+Pa0      = 0 
+Wa0      = 0 
+La0      = 0 
+AGS        = 0.9672              A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.03098            
+Pketa    = 0 
+Wketa    = 0 
+Lketa    = 0 
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.00784             
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+laigc    = 0 
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+laigsd   = 0 
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.01783             LTVOFF     = 0                   WTVOFF     = 0                   
+PTVOFF     = 0                   KT1        = -0.3204             KT1L       = 0                   
+KT2        = -0.01368            
+Pkt2     = 0 
+Wkt2     = 0 
+Lkt2     = 0 
+UTE        = -1.896              UA1        = 1.097e-009          
+UB1        = -2.747e-018        
+UC1        = 6.4e-11             
+Puc1     = 0 
+Wuc1     = 0 
+Luc1     = 0 
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.2 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-005-(dxwn_na+dwmisn_na)'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.22523998+(dvthn_na+vthmisn_na)' 
+LVTH0      = '3.7287579e-08+dlvthn_na'  
+K1         = 0.07               
+K2         = '0.0044363938+dk2n_na'  
+LK2        = '-1.1589065e-08+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001393201         
+LCIT       = 7.1583604e-010      VOFF       = -0.023729017        LVOFF      = -5.2950498e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                   U0         = 0.041365652         
+LU0        = 3.3334454e-009      UA         = -8.1219795e-012     LUA        = -1.1068748e-018     
+UB         = 2.5680284e-18       
+Pub      = 0 
+Wub      = 0 
+LUB        = 3.9851769e-25      
+UC         = 5.5815668e-11       
+Puc      = 0 
+Wuc      = 0 
+LUC        = -3.7942517e-17      
+VSAT       = '110000+dvsatn_na' 
+A0         = 12.835012           
+Pa0      = 0 
+Wa0      = 0 
+LA0        = -8.3250658e-06      
+AGS        = 0.78933137          LAGS       = 1.7733502e-006      
+A1         = 0                   A2         = 1                   B0         = 0                   
+B1         = 0                  
+KETA       = -0.028856036        
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = -2.1175926e-08      
+DWG        = 0                   DWB        = 0                   PCLM       = 2                   
+PDIBLC1    = 0                   PDIBLC2    = 0.0083560955        LPDIBLC2   = -5.1454722e-009     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.039283729         
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = 1.0684121e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.0192573           
+LTVOFF     = -1.4230179e-008     WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.30997307         LKT1       = -1.0395649e-007     KT1L       = 0                   
+KT2        = -0.012746613        
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -9.305869e-09       
+UTE        = -1.9069306          
+LUTE       = 1.0897802e-007      UA1        = 1.0204858e-009      LUA1       = 7.6284616e-016      
+UB1        = -2.593543e-018      LUB1       = -1.529966e-024     
+UC1        = 6.3503837e-11       
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 4.946747e-18        
+PRT        = 0                   AT         = 93999.975           
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             JSD        = 5.11E-6             
+JSWS       = 5.46E-12            JSWD       = 5.46E-12            JSWGS      = 5.46E-12            
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01                
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01                
+BVS        = 19                BVD        = 19                XJBVS      = 1                   
+XJBVD      = 1                   JSWGD      = 5.46E-12            PBS        = 0.25                
+PBD        = 0.25                CJS        = 'cjn_na'            CJD        = 'cjn_na'            
+MJS        = 0.24                MJD        = 0.24                PBSWS      = 1                   
+PBSWD      = 1                   CJSWS      = 'cjswn_na'          CJSWD      = 'cjswn_na'          
+MJSWS      = 0.01                MJSWD      = 0.01                PBSWGS     = 0.6                 
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         CJSWGD     = 'cjswgn_na'         
+MJSWGS     = 0.5                 MJSWGD     = 0.5                 TPB        = 1.0e-3              
+TCJ        = 1.68e-3             TPBSW      = 1E-03               TCJSW      = 1E-04               
+TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            XTIS       = 3                   
+XTID       = 3                  
+DMCG       = 6.7e-8             
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0                   
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06                  
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50                  
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50                  
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7              
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.3 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-005-(dxwn_na+dwmisn_na)'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.20387473+(dvthn_na+vthmisn_na)' 
+LVTH0      = '1.6670122e-08+dlvthn_na'  
+K1         = 0.07               
+K2         = '-0.0053184497+dk2n_na' 
+LK2        = '-2.1756411e-09+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.002061386         
+LCIT       = 7.1037474e-011      VOFF       = -0.041989322        LVOFF      = -3.5329304e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                  
+U0         = 0.042395668         
+Pu0      = 0 
+Wu0      = 0 
+LU0        = 2.3394906e-09       
+UA         = -1.4913719e-011     LUA        = 5.4471535e-018      
+UB         = 2.9623511e-018      LUB        = 1.799616e-026      
+UC         = 1.023081e-10        
+Puc      = 0 
+Wuc      = 0 
+LUC        = -8.28078e-17        
+VSAT       = '41293.995+dvsatn_na' 
+A0         = 7.5946349           
+LA0        = -3.2681027e-006    
+AGS        = 4.2238601           
+Pags     = 0 
+Wags     = 0 
+LAGS       = -1.541004e-06       
+A1         = 0                   A2         = 1                   B0         = 0                   
+B1         = 0                  
+KETA       = -0.083974999        
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = 3.2014043e-08       
+DWG        = 0                   DWB        = 0                   PCLM       = 2                   
+PDIBLC1    = 0                   PDIBLC2    = -0.017790103        LPDIBLC2   = 2.0085609e-008      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.25796658          
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = -1.0418801e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.005493501         
+LTVOFF     = -9.4811349e-010     WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.41622772         LKT1       = -1.4207495e-009     KT1L       = 0                   
+KT2        = -0.01635363         
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -5.825086e-09       
+UTE        = -1.6801437          
+LUTE       = -1.0987129e-007     UA1        = 3.3062468e-009      LUA1       = -1.4429132e-015     
+UB1        = -5.1929097e-018     LUB1       = 9.7842281e-025     
+UC1        = -2.8413175e-11      
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 9.3646513e-17       
+PRT        = 0                   AT         = 122876.25           
+LAT        = -0.02786561        
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      
+PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.066301464+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.4 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007' 
+LMAX       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-005-(dxwn_na+dwmisn_na)'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.15172282+(dvthn_na+vthmisn_na)' 
+LVTH0      = '-8.2584959e-09+dlvthn_na' 
+K1         = 0.07               
+K2         = '-0.0040961665+dk2n_na' 
+LK2        = '-2.7598923e-09+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0022557772        
+LCIT       = -2.1881503e-011     VOFF       = -0.087843005        LVOFF      = -1.3411244e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                  
+U0         = 0.049593625         
+Pu0      = 0 
+Wu0      = 0 
+LU0        = -1.1011326e-09      
+UA         = -5.597171e-012      LUA        = 9.9384373e-019      
+UB         = 3e-018             
+UC         = -1.2001495e-10      
+Puc      = 0 
+Wuc      = 0 
+LUC        = 2.34626e-17         
+VSAT       = '283367.82+dvsatn_na' 
+A0         = 10.572528           LA0        = -4.6915353e-006     
+AGS        = 2.475217            
+Pags     = 0 
+Wags     = 0 
+LAGS       = -7.05155e-07        
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.04398699          
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = -2.9151779e-08      
+DWG        = 0                   
+DWB        = 0                   PCLM       = 2.9834715           LPCLM      = -4.7009938e-007     
+PDIBLC1    = 0                   PDIBLC2    = 0.048037098         LPDIBLC2   = -1.1379793e-008     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.025233168         
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = 7.058545e-09 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.00010919689       
+LTVOFF     = 1.6255839e-009      WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.66270511         
+Pkt1     = 0 
+Wkt1     = 0 
+LKT1       = 1.1639544e-07       
+KT1L       = 0                   
+KT2        = -0.020034267        
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -4.065741e-09       
+UTE        = -3.114974           
+Pute     = 0 
+Wute     = 0 
+LUTE       = 5.7597756e-07       
+UA1        = -2.7697264e-009     LUA1       = 1.461402e-015       
+UB1        = -2.1403782e-018     LUB1       = -4.806872e-025     
+UC1        = -7.24611e-11        
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 1.147014e-16        
+PRT        = 0                   AT         = 164499.82           
+LAT        = -0.047761673       
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      
+PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.049409815+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.5 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+LMAX       = 20.001e-6           WMIN       = '1e-006-(dxwn_na+dwmisn_na)'    WMAX       = '1e-005-(dxwn_na+dwmisn_na)'    
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' 
+XW         = '2e-08+(dxwn_na+dwmisn_na)'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.215482+(dvthn_na+vthmisn_na)' 
+WVTH0      = '-6.030036e-08+dwvthn_na'  
+K1         = 0.07               
+K2         = '0.0031123866+dk2n_na'  
+WK2        = '1.6193656e-09+dwk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0014504933        
+WCIT       = 1.453568e-010       VOFF       = -0.03273682         WVOFF      = 3.7042136e-008      
+NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.042123867         
+Pu0      = 0 
+Lu0      = 0 
+WU0        = -4.247144e-09       
+UA         = -8.45196e-012       WUA        = 2.1939792e-018     
+UB         = 2.6014266e-18       
+Pub      = 0 
+Lub      = 0 
+WUB        = 6.58648e-26         
+UC         = 5.6513867e-011      WUC        = -4.5128744e-017     
+VSAT       = '110000+dvsatn_na' 
+A0         = 11.66               
+Pa0      = 0 
+Wa0      = 3.4068e-06 
+La0      = 0 
+AGS        = 0.97915667          
+WAGS       = -1.198058e-007      A1         = 0                   A2         = 1                   
+B0         = 0                   B1         = 0                  
+KETA       = -0.032103133        
+Pketa    = 0 
+Lketa    = 0 
+WKETA      = 1.1253796e-08       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.0083970333        
+WPDIBLC2   = -5.581474e-009      PDIBLCB    = 0.22000011          DROUT      = 0.56                
+PVAG       = 1.5                 DELTA      = 0.05                PSCBE1     = 9.264e+008          
+PSCBE2     = 1e-020              FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52                
+RSW        = 16.58               RDW        = 16.58               PRWG       = 0                   
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.2e-008            
+ALPHA1     = 0.01                BETA0      = 11                  AIGBACC    = 0.01302             
+BIGBACC    = 0.005269            CIGBACC    = 0.19351             NIGBACC    = 20.288              
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006               
+EIGBINV    = 1.1                 NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+laigc    = 0 
+WAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084            
+AIGSD      = 0.01016             
+paigsd   = 0 
+laigsd   = 0 
+WAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.019850733         LTVOFF     = 0                   WTVOFF     = -2.0247748e-008     
+PTVOFF     = 0                  
+KT1        = -0.29934267         
+Pkt1     = 0 
+Lkt1     = 0 
+WKT1       = -2.1099448e-07      
+KT1L       = 0                  
+KT2        = -0.0152304          
+Pkt2     = 0 
+Lkt2     = 0 
+WKT2       = 1.5535008e-08       
+UTE        = -1.8615466          
+Pute     = 0 
+Lute     = 0 
+WUTE       = -3.452224e-07       
+UA1        = 1.2236863e-009      
+WUA1       = -1.2693964e-015     UB1        = -3.0583267e-018     WUB1       = 3.1194932e-024      
+UC1        = 9.3919993e-11       
+Puc1     = 0 
+Luc1     = 0 
+WUC1       = -2.997984e-16       
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.6 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-006-(dxwn_na+dwmisn_na)'    WMAX       = '1e-005-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.2187799+(dvthn_na+vthmisn_na)'  
+LVTH0      = '3.2880023e-08+dlvthn_na'  
+WVTH0      = '-6.473002e-08+dwvthn_na'   
+PVTH0      = '4.4163708e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '0.0042329285+dk2n_na'  
+LK2        = '-1.1171801e-08+dlk2n_na'  
+WK2        = '2.0387229e-09+dwk2n_na'  
+PK2        = '-4.1809925e-15+dpk2n_na' 
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0013810505        
+LCIT       = 6.9234522e-010      WCIT       = 1.2174817e-010      PCIT       = 2.35378e-016        
+VOFF       = -0.027734675        LVOFF      = -4.9871385e-008     WVOFF      = 4.0136692e-008      
+PVOFF      = -3.0852717e-014     NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.041828626         
+LU0        = 2.9435463e-09       
+WU0        = -4.6389985e-09      
+PU0        = 3.9067896e-15       
+UA         = -8.3513357e-012     
+LUA        = -1.0032246e-018     WUA        = 2.2981492e-018      PUA        = -1.0385751e-024     
+UB         = 2.5597183e-18       
+LUB        = 4.1583308e-25       
+WUB        = 8.326704e-26        
+PUB        = -1.735003e-31      
+UC         = 6.0664505e-11       
+LUC        = -4.138186e-17       
+WUC        = -4.858534e-17       
+PUC        = 3.446225e-23        
+VSAT       = '110000+dvsatn_na'  
+A0         = 12.440833           
+LA0        = -7.7848987e-06      
+WA0        = 3.9496768e-06       
+PA0        = -5.4124809e-12      
+AGS        = 0.81069442          LAGS       = 1.6795686e-006      
+WAGS       = -2.1405776e-007     PAGS       = 9.3969207e-013      A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.029991314        
+LKETA      = -2.1054839e-08      
+WKETA      = 1.137549e-08        
+PKETA      = -1.213289e-15       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.0089570334        
+LPDIBLC2   = -5.5832006e-009     WPDIBLC2   = -6.0213976e-009     PPDIBLC2   = 4.3860385e-015      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.039283729         
+Ppdits   = 0              
+Wpdits   = 0             
+Lpdits   = 1.0684121e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.021496742         LTVOFF     = -1.6410709e-008     WTVOFF     = -2.2439213e-008     
+PTVOFF     = 2.1848902e-014     
+KT1        = -0.28690572         
+LKT1       = -1.2399633e-07      
+WKT1       = -2.3113483e-07      
+PKT1       = 2.0079927e-13       
+KT1L       = 0                   
+KT2        = -0.014328833        
+LKT2       = -8.988622e-09       
+WKT2       = 1.5853845e-08       
+PKT2       = -3.178812e-15      
+UTE        = -1.8685544          
+LUTE       = 6.986702e-08        
+WUTE       = -3.8452956e-07      
+PUTE       = 3.9189226e-13       
+UA1        = 1.1597887e-009      
+LUA1       = 6.3705889e-016      WUA1       = -1.3958145e-015     PUA1       = 1.2603885e-021      
+UB1        = -2.9333743e-018     LUB1       = -1.2457755e-024     WUB1       = 3.4051089e-024      
+PUB1       = -2.8475885e-030    
+UC1        = 9.7249182e-11       
+LUC1       = -3.3191927e-17      
+WUC1       = -3.3812834e-16      
+PUC1       = 3.8214951e-22       
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      
+WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.7 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-006-(dxwn_na+dwmisn_na)'    WMAX       = '1e-005-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.20106992+(dvthn_na+vthmisn_na)' 
+LVTH0      = '1.578989e-08+dlvthn_na'   
+WVTH0      = '-2.8104333e-08+dwvthn_na'  
+PVTH0      = '8.819929e-15+dpvthn_na'   
+K1         = 0.07               
+K2         = '-0.0052218906+dk2n_na' 
+LK2        = '-2.0478999e-09+dlk2n_na'  
+WK2        = '-9.675219e-10+dwk2n_na'  
+PK2        = '-1.2799665e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020538148        
+LCIT       = 4.312764e-011       WCIT       = 7.5863676e-011      PCIT       = 2.7965654e-016      
+VOFF       = -0.044304802        LVOFF      = -3.3881213e-008     WVOFF      = 2.3201101e-008      
+PVOFF      = -1.4509872e-014     NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.042679304         
+LU0        = 2.122652e-09        
+WU0        = -2.842046e-09       
+PU0        = 2.1727235e-15       
+UA         = -1.5646256e-011     
+LUA        = 6.0363731e-018      WUA        = 7.3400194e-018      PUA        = -5.9039798e-024     
+UB         = 2.9814398e-018      LUB        = 8.8717912e-027      WUB        = -1.9126815e-025     
+PUB        = 9.1426177e-032     
+UC         = 1.0314189e-10       
+LUC        = -8.237264e-17       
+WUC        = -8.35487e-18        
+PUC        = -4.36032e-24        
+VSAT       = '40181.613+dvsatn_na' 
+A0         = 7.9071503           LA0        = -3.4098954e-006     WA0        = -3.1314046e-006     
+PA0        = 1.4207628e-012     
+AGS        = 4.1848595           
+LAGS       = -1.576535e-06       
+WAGS       = 3.90785e-07         
+PAGS       = 3.56021e-13         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.087750154        
+LKETA      = 3.4682632e-08       
+WKETA      = 3.7827079e-08       
+PKETA      = -2.6739261e-14      
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = -0.019028806        
+LPDIBLC2   = 2.1423134e-008      WPDIBLC2   = 1.2411805e-008      PPDIBLC2   = -1.3402002e-014     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.26575327          
+Ppdits   = 7.5291941e-14 
+Wpdits   = -7.8022542e-08 
+Lpdits   = -1.1170218e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.0055207155        LTVOFF     = -9.9384268e-010     WTVOFF     = -2.7268857e-010     
+PTVOFF     = 4.5820649e-016      KT1        = -0.40785341         LKT1       = -7.2818147e-009     
+WKT1       = -8.391058e-008      PKT1       = 5.8727874e-014      KT1L       = 0                   
+KT2        = -0.018440266        
+LKT2       = -5.0210717e-09      
+WKT2       = 2.0908104e-08       
+PKT2       = -8.056216e-15       
+UTE        = -1.6135514          LUTE       = -1.7621082e-007     
+WUTE       = -6.6725478e-007     PUTE       = 6.6472208e-013      UA1        = 3.6370587e-009      
+LUA1       = -1.7535067e-015     WUA1       = -3.3147353e-015     PUA1       = 3.1121471e-021      
+UB1        = -5.4148903e-018     LUB1       = 1.1488875e-024      WUB1       = 2.2242463e-024      
+PUB1       = -1.7080561e-030    
+UC1        = -3.606643e-11       
+LUC1       = 9.545744e-17        
+WUC1       = 7.668546e-17        
+PUC1       = -1.814561e-23       
+PRT        = 0                   
+AT         = 118154.16           LAT        = -0.023308792        WAT        = 0.047315345         
+PAT        = -4.5659308e-008    
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.067374916+dlvsatn_na' 
+WVSAT      = '0.011146077+dwvsatn_na' 
+PVSAT      = '-1.0755991e-08+dpvsatn_na' )


.MODEL nch_na.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007' 
+LMAX       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+WMIN       = '1e-006-(dxwn_na+dwmisn_na)'    WMAX       = '1e-005-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.15122808+(dvthn_na+vthmisn_na)' 
+LVTH0      = '-8.034504e-09+dlvthn_na'  
+WVTH0      = '-4.9572123e-09+dwvthn_na' 
+PVTH0      = '-2.2443959e-15+dpvthn_na' 
+K1         = 0.07               
+K2         = '-0.0034294495+dk2n_na' 
+LK2        = '-2.9046867e-09+dlk2n_na'  
+WK2        = '-6.6805046e-09+dwk2n_na'  
+PK2        = '1.4508391e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020602825        
+LCIT       = 4.0036091e-011      WCIT       = 1.958857e-009       PCIT       = -6.2041429e-016     
+VOFF       = -0.086693876        LVOFF      = -1.3619235e-008     WVOFF      = -1.1514278e-008     
+PVOFF      = 2.084079e-015       NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.04910732          
+LU0        = -9.4993853e-10      
+WU0        = 4.8727838e-09       
+PU0        = -1.5149657e-15      
+UA         = -5.586217e-012      
+LUA        = 1.2276746e-018      WUA        = -1.0975898e-019     PUA        = -2.3429858e-024     
+UB         = 2.9797497e-018      LUB        = 9.6796238e-027      WUB        = 2.029076e-025       
+PUB        = -9.6989831e-032    
+UC         = -1.1125513e-10      
+LUC        = 2.010914e-17        
+WUC        = -8.777345e-17       
+PUC        = 3.3601749e-23       
+VSAT       = '286174.73+dvsatn_na' 
+A0         = 10.203165           LA0        = -4.5073905e-006     WA0        = 3.7010098e-006      
+PA0        = -1.8451313e-012    
+AGS        = 2.3421029           
+LAGS       = -6.95699e-07        
+WAGS       = 1.333811e-06        
+PAGS       = -9.4745e-14         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.05210738          
+LKETA      = -3.2169259e-08      
+WKETA      = -8.136628e-08       
+PKETA      = 3.0235153e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 3.0949316           LPCLM      = -5.2337731e-007     WPCLM      = -1.1168302e-006     
+PPCLM      = 5.3384485e-013      PDIBLC1    = 0                   PDIBLC2    = 0.051189809         
+LPDIBLC2   = -1.2141364e-008     WPDIBLC2   = -3.1590156e-008     PPDIBLC2   = 7.6309355e-015      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.005584814         
+Ppdits   = -5.6109786e-14 
+Wpdits   = 1.968765e-07  
+Lpdits   = 1.2658324e-08 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.00026518598      LTVOFF     = 1.7718182e-009      WTVOFF     = 3.7513163e-009      
+PTVOFF     = -1.4652679e-015    
+KT1        = -0.68108559         
+LKT1       = 1.2332316e-07       
+WKT1       = 1.841725e-07        
+PKT1       = -6.9415831e-14      
+KT1L       = 0                   
+KT2        = -0.022681454        
+LKT2       = -2.993785e-09       
+WKT2       = 2.652482e-08        
+PKT2       = -1.0741004e-14      
+UTE        = -3.2531062          
+LUTE       = 6.0749632e-07       
+WUTE       = 1.3840846e-06       
+PUTE       = -3.1581813e-13      
+UA1        = -3.3895002e-009     
+LUA1       = 1.6051884e-015      WUA1       = 6.2101328e-015      PUA1       = -1.4407399e-021     
+UB1        = -1.8405564e-018     LUB1       = -5.5964413e-025     WUB1       = -3.0042151e-024     
+PUB1       = 7.9114846e-031     
+UC1        = -1.1418203e-10      
+LUC1       = 1.3279669e-16       
+WUC1       = 4.1804357e-16       
+PUC1       = -1.8131477e-22      
+PRT        = 0                   
+AT         = 175592.58           LAT        = -0.050764357        WAT        = -0.1111495          
+PAT        = 3.0086887e-008     
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.050209783+dlvsatn_na' 
+WVSAT      = '-0.02812521+dwvsatn_na' 
+PVSAT      = '8.015684e-09+dpvsatn_na'  )


.MODEL nch_na.9 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+LMAX       = 20.001e-6           WMIN       = 5e-07               WMAX       = '1e-006-(dxwn_na+dwmisn_na)'    
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' 
+XW         = '2e-08+(dxwn_na+dwmisn_na)'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.262536+(dvthn_na+vthmisn_na)' 
+WVTH0      = '-1.230528e-08+dwvthn_na'  
+K1         = 0.07               
+K2         = '0.00669472+dk2n_na' 
+WK2        = '-2.0346144e-09+dwk2n_na' 
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00117492          
+WCIT       = 4.264416e-010       VOFF       = 0.00313076          WVOFF      = 4.572048e-010       
+NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.0381472           
+Pu0      = 0 
+Lu0      = 0 
+WU0        = -1.90944e-10        
+UA         = -7.51988e-012       WUA        = 1.2432576e-018     
+UB         = 2.91456e-18         
+Pub      = 0 
+Lub      = 0 
+WUB        = -2.535312e-25       
+UC         = 1.00444e-011        WUC        = 2.270112e-018       
+VSAT       = '110000+dvsatn_na'  A0         = 15                  AGS        = 0.8981              
+WAGS       = -3.7128e-008        A1         = 0                   A2         = 1                   
+B0         = 0                   B1         = 0                  
+KETA       = -0.035942           
+Pketa    = 0 
+Lketa    = 0 
+WKETA      = 1.516944e-08        
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = -0.0084162          
+WPDIBLC2   = 1.1568024e-008      PDIBLCB    = 0.22000011          DROUT      = 0.56                
+PVAG       = 1.5                 DELTA      = 0.05                PSCBE1     = 9.264e+008          
+PSCBE2     = 1e-020              FPROUT     = 600                
+PDITS      = 0.07392             
+Ppdits   = 0 
+Wpdits   = -2.43984e-08 
+Lpdits   = 0 
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52                
+RSW        = 16.58               RDW        = 16.58               PRWG       = 0                   
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.2e-008            
+ALPHA1     = 0.01                BETA0      = 11                  AIGBACC    = 0.01302             
+BIGBACC    = 0.005269            CIGBACC    = 0.19351             NIGBACC    = 20.288              
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006               
+EIGBINV    = 1.1                 NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+laigc    = 0 
+WAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084            
+AIGSD      = 0.01016             
+paigsd   = 0 
+laigsd   = 0 
+WAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.0743288           LTVOFF     = 0                   WTVOFF     = -7.5815376e-008     
+PTVOFF     = 0                  
+KT1        = -0.586696           
+Pkt1     = 0 
+Lkt1     = 0 
+WKT1       = 8.210592e-08        
+KT1L       = 0                   KT2        = -1.8023768e-017     WKT2       = 1.8030359e-023      
+UTE        = -2.408              
+Pute     = 0 
+Wute     = 2.1216e-07 
+Lute     = 0 
+UA1        = 4.84232e-11         
+Pua1     = 0 
+Lua1     = 0 
+WUA1       = -7.062806e-17       
+UB1        = 3.33067e-034       
+UC1        = -2.77584e-10        
+Puc1     = 0 
+Luc1     = 0 
+WUC1       = 7.913568e-17        
+PRT        = 0                   AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             JSD        = 5.11E-6             JSWS       = 5.46E-12            
+JSWD       = 5.46E-12            JSWGS      = 5.46E-12            NJS        = 1                   
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 19                
+BVD        = 19                XJBVS      = 1                   XJBVD      = 1                   
+JSWGD      = 5.46E-12            PBS        = 0.25                PBD        = 0.25                
+CJS        = 'cjn_na'            CJD        = 'cjn_na'            MJS        = 0.24                
+MJD        = 0.24                PBSWS      = 1                   PBSWD      = 1                   
+CJSWS      = 'cjswn_na'          CJSWD      = 'cjswn_na'          MJSWS      = 0.01                
+MJSWD      = 0.01                PBSWGS     = 0.6                 PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgn_na'         CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 
+MJSWGD     = 0.5                 TPB        = 1.0e-3              TCJ        = 1.68e-3             
+TPBSW      = 1E-03               TCJSW      = 1E-04               TPBSWG     = 5.00E-04            
+TCJSWG     = 1.50E-03            XTIS       = 3                   XTID       = 3                   
+DMCG       = 6.7e-8             
+DMCI       = 7.2e-8              
+DMDG       = 0                   
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0                   
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012              
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50                  
+RBDB       = 50                  RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      
+PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.10 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '1.000489e-005-(dxln_na+dlmisn_na)' 
+WMIN       = 5e-07               WMAX       = '1e-006-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.27377651+(dvthn_na+vthmisn_na)' 
+LVTH0      = '1.1206787e-07+dlvthn_na'  
+WVTH0      = '-8.6334751e-09+dwvthn_na'  
+PVTH0      = '-3.6607898e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '0.0089179387+dk2n_na' 
+LK2        = '-2.216549e-08+dlk2n_na'   
+WK2        = '-2.7399876e-09+dwk2n_na' 
+PK2        = '7.03257e-15+dpk2n_na'    
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011669214        
+LCIT       = 7.9746271e-011      WCIT       = 3.4015986e-010      PCIT       = 8.6022893e-016      
+VOFF       = 0.012363636         LVOFF      = -9.205177e-008      WVOFF      = -7.6358516e-010     
+PVOFF      = 1.2171276e-014      NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.037307302         
+LU0        = 8.3737859e-09       
+WU0        = -2.724741e-11       
+PU0        = -1.632055e-15       
+UA         = -7.4390536e-012     
+LUA        = -8.0583906e-019     WUA        = 1.3676215e-018      PUA        = -1.2399084e-024     
+UB         = 2.9023949e-18       
+LUB        = 1.2128611e-25       
+WUB        = -2.6626316e-25      
+PUB        = 1.2693761e-31      
+UC         = 5.5331115e-12       
+LUC        = 4.4977537e-17       
+WUC        = 7.648683e-18        
+PUC        = -5.3624341e-23      
+VSAT       = '110000+dvsatn_na'  
+A0         = 16.318525           LA0        = -1.3145698e-005     WA0        = -5.5702308e-009     
+PA0        = 5.5535201e-014      AGS        = 0.57560247          LAGS       = 3.2153004e-006      
+WAGS       = 2.5736033e-008      PAGS       = -6.2675441e-013     A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.039830546        
+LKETA      = 3.8768827e-08       
+WKETA      = 2.141151e-08        
+PKETA      = -6.223343e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                  
+PDIBLC2    = -0.0095824258       
+LPDIBLC2   = 1.1627272e-08       
+WPDIBLC2   = 1.2888851e-08       
+PPDIBLC2   = -1.3168643e-14      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.06576706          
+Ppdits   = 2.6067545e-14  
+Wpdits   = -2.7012999e-08 
+Lpdits   = 8.128479e-08  
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.083017641         LTVOFF     = -8.6627742e-008     WTVOFF     = -8.5190529e-008     
+PTVOFF     = 9.3470276e-014     
+KT1        = -0.58531147         
+LKT1       = -1.380387e-08       
+WKT1       = 7.3239023e-08       
+PKT1       = 8.8402969e-14       
+KT1L       = 0                   
+KT2        = -0.0008900086       
+LKT2       = 8.873378e-09        
+WKT2       = 2.146244e-09        
+PKT2       = -2.1398053e-14     
+UTE        = -2.4243445          
+LUTE       = 1.6295422e-07       
+WUTE       = 1.8237632e-07       
+PUTE       = 2.9694331e-13       
+UA1        = -2.7562915e-10      
+LUA1       = 3.2308018e-15       
+WUA1       = 6.831169e-17        
+PUA1       = -1.3852293e-21      
+UB1        = 8.261343e-019       LUB1       = -8.236559e-024      WUB1       = -4.2958984e-025     
+PUB1       = 4.2830107e-030     
+UC1        = -3.1174403e-10      
+LUC1       = 3.4057554e-16       
+WUC1       = 7.9044742e-17       
+PUC1       = 9.0669e-25          
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      
+WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.11 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '9.998918e-007-(dxln_na+dlmisn_na)' 
+WMIN       = 5e-07               WMAX       = '1e-006-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.16928865+(dvthn_na+vthmisn_na)' 
+LVTH0      = '1.1237128e-08+dlvthn_na'  
+WVTH0      = '-6.052123e-08+dwvthn_na'   
+PVTH0      = '1.3463745e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '-0.01029922+dk2n_na' 
+LK2        = '-3.6209357e-09+dlk2n_na'  
+WK2        = '4.2113542e-09+dwk2n_na'  
+PK2        = '3.245302e-16+dpk2n_na'    
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 6.1253963e-005      
+LCIT       = 1.1467153e-009      WCIT       = 2.1082757e-009      PCIT       = -8.460029e-016      
+VOFF       = -0.028959602        LVOFF      = -5.2174846e-008     WVOFF      = 7.548997e-009       
+PVOFF      = 4.1496342e-015      NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.04345602          
+LU0        = 2.4402754e-09       
+WU0        = -3.6342964e-09      
+PU0        = 1.8487474e-15       
+UA         = -8.2913947e-012     
+LUA        = 1.6670127e-020      WUA        = -1.6193864e-019     PUA        = 2.361172e-025       
+UB         = 3.0495164e-018      LUB        = -2.0686113e-026     WUB        = -2.607063e-025      
+PUB        = 1.2157524e-031     
+UC         = 2.0119193e-10       
+LUC        = -1.4383359e-16      
+WUC        = -1.0836587e-16      
+PUC        = 5.832985e-23        
+VSAT       = '51109.136+dvsatn_na' 
+A0         = 4.6215339           LA0        = -1.8581016e-006     WA0        = 2.199241e-007       
+PA0        = -1.6206683e-013    
+AGS        = 5.779722            
+LAGS       = -1.806705e-06       
+WAGS       = -1.235974e-06       
+PAGS       = 5.90795e-13         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.015026988         
+LKETA      = -1.4168771e-08      
+WKETA      = -6.7005605e-08      
+PKETA      = 2.3089167e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                  
+PDIBLC2    = 0.0060641877        
+LPDIBLC2   = -3.4717082e-09      
+WPDIBLC2   = -1.3183049e-08      
+PPDIBLC2   = 1.1990738e-14       
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.087183083         
+Ppdits   = -1.0047513e-13 
+Wpdits   = 1.0411905e-07  
+Lpdits   = 6.0618485e-08  
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.013966012        LTVOFF     = 6.9614831e-009      WTVOFF     = 1.9603774e-008      
+PTVOFF     = -7.6562258e-015     KT1        = -0.72931399         LKT1       = 1.2515856e-007      
+WKT1       = 2.4397921e-007      PKT1       = -7.6361307e-014     KT1L       = 0                   
+KT2        = 0.023254924         
+LKT2       = -1.442648e-08       
+WKT2       = -2.1620989e-08      
+PKT2       = 1.537301e-15        
+UTE        = -3.1534526          LUTE       = 8.6654353e-007      
+WUTE       = 9.0344437e-007      PUTE       = -3.9888735e-013     UA1        = 5.9062311e-010      
+LUA1       = 2.3948684e-015      WUA1       = -2.0737094e-016     PUA1       = -1.1191955e-021     
+UB1        = -6.5978836e-018     LUB1       = -1.0723817e-024     WUB1       = 3.4308995e-024      
+PUB1       = 5.5763849e-031     
+UC1        = 8.625428e-11        
+LUC1       = -4.349334e-17       
+WUC1       = -4.808166e-17       
+PUC1       = 1.2358419e-22       
+PRT        = 0                   
+AT         = 133785.65           LAT        = -0.038393174        WAT        = 0.031371232         
+PAT        = -3.0273239e-008    
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.056829831+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'           
+PVSAT      = '0+dpvsatn_na'             )


.MODEL nch_na.12 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007-(dxln_na+dlmisn_na)' 
+LMAX       = '4.997495e-007-(dxln_na+dlmisn_na)' 
+WMIN       = 5e-07               WMAX       = '1e-006-(dxwn_na+dwmisn_na)'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.098413894+(dvthn_na+vthmisn_na)' 
+LVTH0      = '-2.2641001e-08+dlvthn_na'  
+WVTH0      = '-5.8827684e-08+dwvthn_na'  
+PVTH0      = '1.2654232e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '-0.016401262+dk2n_na' 
+LK2        = '-7.041595e-10+dlk2n_na'  
+WK2        = '6.5507443e-09+dwk2n_na'  
+PK2        = '-7.936985e-16+dpk2n_na'   
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0049850742        
+LCIT       = -1.2068708e-009     WCIT       = -1.0244305e-009     PCIT       = 6.5143068e-016      
+VOFF       = -0.15551324         LVOFF      = 8.3177944e-009      WVOFF      = 5.8681477e-008      
+PVOFF      = -2.0291691e-014     NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.05981412          
+LU0        = -5.3788956e-09      
+WU0        = -6.0481528e-09      
+PU0        = 3.0025707e-15       
+UA         = -7.2924817e-012     
+LUA        = -4.6081033e-019     WUA        = 1.630631e-018       PUA        = -6.2073108e-025     
+UB         = 3.3799592e-018      LUB        = -1.7863776e-025     WUB        = -2.0530602e-025     
+PUB        = 9.5093905e-032     
+UC         = -2.0850659e-10      
+LUC        = 5.2002276e-17       
+WUC        = 1.142306e-17        
+PUC        = 1.070741e-24        
+VSAT       = '289316+dvsatn_na'    
+A0         = 25.046353           
+LA0        = -1.1621166e-05      
+WA0        = -1.1439042e-05      
+PA0        = 5.410919e-12        
+AGS        = 5.365513            
+LAGS       = -1.6087171e-06      
+WAGS       = -1.750066e-06       
+PAGS       = 8.365331e-13        
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.038709988         
+LKETA      = -2.5489243e-08      
+WKETA      = -6.7700945e-08      
+PKETA      = 2.3421536e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 3.5357505           
+Ppclm    = 7.4877045e-13 
+Wpclm    = -1.5664655e-06 
+Lpclm    = -7.3408868e-07 
+PDIBLC1    = 0                  
+PDIBLC2    = -0.01307004         
+LPDIBLC2   = 5.6744528e-09       
+WPDIBLC2   = 3.395489e-08        
+PPDIBLC2   = -1.0541198e-14      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.45617604          
+Ppdits   = 7.4877045e-14 
+Wpdits   = -2.6272655e-07 
+Lpdits   = -1.1576014e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.0024810079       LTVOFF     = 1.471651e-009       WTVOFF     = 6.0114547e-009      
+PTVOFF     = -1.1590974e-015    
+KT1        = -0.62425846         
+LKT1       = 7.4942016e-08       
+WKT1       = 1.2620882e-07       
+PKT1       = -2.0067065e-14      
+KT1L       = 0                   
+KT2        = 0.056643439         
+LKT2       = -3.038619e-08       
+WKT2       = -5.4386579e-08      
+PKT2       = 1.7199249e-14       
+UTE        = -2.0620486          
+LUTE       = 3.4485242e-07       
+WUTE       = 1.6920585e-07       
+PUTE       = -4.792134e-14       
+UA1        = 5.3123939e-009      
+LUA1       = 1.3786194e-016      WUA1       = -2.6657992e-015     PUA1       = 5.5933186e-023      
+UB1        = -9.7631652e-018     LUB1       = 4.4062288e-025      WUB1       = 5.0768459e-024      
+PUB1       = -2.291239e-031     
+UC1        = -1.1999426e-10      
+LUC1       = 5.5093456e-17       
+WUC1       = 4.2397207e-16       
+PUC1       = -1.0205747e-22      
+PRT        = 0                   
+AT         = 144229.87           LAT        = -0.043385514        WAT        = -0.079159534        
+PAT        = 2.2560467e-008     
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.057033044+dlvsatn_na' 
+WVSAT      = '-0.031329311+dwvsatn_na' 
+PVSAT      = '1.4975409e-08+dpvsatn_na' )


.MODEL nch_na.13 NMOS	(	LEVEL      = 54                  LMIN       = 2e-07               
+LMAX       = '2.995932e-007-(dxln_na+dlmisn_na)' 
+WMIN       = 5e-07               WMAX       = '1.01e-006'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = '(toxn_na+toxmisn_na)'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+(dxln_na+dlmisn_na)' XW         = '2e-08+(dxwn_na+dwmisn_na)'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.14018532+(dvthn_na+vthmisn_na)'  
+LVTH0      = '-1.0736146e-08+dlvthn_na' 
+WVTH0      = '-2.5725481e-08+dwvthn_na' 
+PVTH0      = '3.220104e-15+dpvthn_na'   
+K1         = 0.07               
+K2         = '-0.03257056+dk2n_na'   
+LK2        = '3.9040877e-09+dlk2n_na'  
+WK2        = '1.5265834e-08+dwk2n_na'  
+PK2        = '-3.277497e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00085172         
+LCIT       = 4.566156e-010       WCIT       = 3.0688944e-009      PCIT       = -5.1516691e-016     
+VOFF       = -0.068713742        
+LVOFF      = -1.6420061e-08      
+WVOFF      = -4.5987983e-08      
+PVOFF      = 9.5391021e-15       
+NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.035277235         
+LU0        = 1.6141152e-09       
+WU0        = 1.232442e-08        
+PU0        = -2.2336115e-15      
+UA         = -3.1681784e-010     
+LUA        = 8.7753917e-017      WUA        = 1.3959704e-016      PUA        = -3.9941157e-023     
+UB         = 2.87556e-018        LUB        = -3.4884e-026        WUB        = 6.47088e-026        
+PUB        = 1.813968e-032      
+UC         = -8.186544e-11       
+LUC        = 1.5909557e-17       
+WUC        = 5.097627e-17        
+PUC        = -1.0201927e-23      
+VSAT       = '111866.01+dvsatn_na' 
+LVSAT      = '-0.006459814+dlvsatn_na' 
+WVSAT      = '0.030196514+dwvsatn_na'  
+PVSAT      = '-2.5594431e-09+dpvsatn_na' 
+A0         = -27.195624          
+LA0        = 3.267799e-06        
+WA0        = 2.2646677e-05       
+PA0        = -4.3035117e-12      
+AGS        = -0.063126           
+LAGS       = -6.15469e-08        
+WAGS       = 1.5083e-06          
+PAGS       = -9.2107e-14         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.06139791          
+LKETA      = -3.1955324e-08      
+WKETA      = -3.317461e-08       
+PKETA      = 1.3581555e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 1.5052841           
+LPCLM      = -1.5540615e-07      
+WPCLM      = 2.5539941e-06       
+PPCLM      = -4.2556016e-13      
+PDIBLC1    = 0                  
+PDIBLC2    = 0.017114269         
+LPDIBLC2   = -2.928076e-09       
+WPDIBLC2   = -7.6776225e-09      
+PPDIBLC2   = 1.3240692e-15       
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.00651548         LTVOFF     = 2.6214756e-009      WTVOFF     = 8.0482896e-009      
+PTVOFF     = -1.7395953e-015    
+KT1        = -0.79589667         
+LKT1       = 1.2385889e-07       
+WKT1       = 3.3264227e-07       
+PKT1       = -7.8900579e-14      
+KT1L       = 0                   
+KT2        = -0.04538432         
+LKT2       = -1.3083e-09         
+WKT2       = 1.117282e-08        
+PKT2       = -1.485166e-15      
+UTE        = -1.2634695          
+LUTE       = 1.1725738e-07       
+WUTE       = 2.1500415e-07       
+PUTE       = -6.0973837e-14      
+UA1        = 1.207196e-008       
+LUA1       = -1.7886144e-015     WUA1       = -7.5040992e-015     PUA1       = 1.4348487e-021      
+UB1        = -1.790136e-017      LUB1       = 2.7600084e-024      WUB1       = 1.2288307e-023      
+PUB1       = -2.2843904e-030    
+UC1        = -1.7613512e-10      
+LUC1       = 7.1093577e-17       
+WUC1       = 9.175608e-17        
+PUC1       = -7.375925e-24       
+PRT        = 0                   
+AT         = -65995.12           LAT        = 0.016528609         WAT        = 0.025594982         
+PAT        = -7.29457e-009      
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      )

.ends nch_na_mac
.ENDL MAC_na







***************************************************************
*                                                             *
*                     Native IO DEVICE MODELS                 *
*                                                             *
***************************************************************
.LIB MAC_na25
**********************************************************************************************
*                                                                                            *
*                                 Native IO NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_na25_mac n1 n2 n3 n4  l=length w=width multi='1' nf='1' scale='1' sigma='1'
+dmcg='1.135e-007' xw='+7e-09+dxwn_na25'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0e-6/scale' sb='0e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_na25 w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_na25  temp2=parn2_na25
+fac1='0.010101*temp1*sigma+0.999949*temp2*sigma'
+fac2='0.010101*temp1*sigma-0.999949*temp2*sigma'
.param  lef='l*scale-3.859e-8'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_na25='0.00173817*geo_fac*fac1*mismatchflag'
+       dlmisn_na25='0.00174110*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_na25='-0.00174110*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_na25='0.00174110*geo_fac*toxn_na25*fac2*mismatchflag' 
.MODEL nch_na25.1 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = 900.00001e-06       WMIN       = '1e-005-(dxwn_na25+dwmisn_na25)'    WMAX       = 900.00001e-06
+VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'     
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = '(toxn_na25+toxmisn_na25)'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)'
+K1         = 0.083826            K2         = -0.00094810982      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000703125+dcitn_na25'
+VOFF       = -0.12480063         NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021196+deta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062834873+du0n_na25'
+UA         = 1.2235048e-009      UB         = 2.4999846e-018      UC         = -4.7661329e-011
+VSAT       = '78400+dvsatn_na25'   A0         = 3.5135779           AGS        = 1.0683639
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055602815        DWG        = 0
+DWB        = 0                   PCLM       = 0.01                PDIBLC1    = 0
+PDIBLC2    = 0.0001485           PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3e-018             UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                  
+XGL        = -2.11e-008 
+RSHG       = 15.06                  
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'        WU0        = '0+dwu0n_na25'
+PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'
+PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'
+PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'      WETA0      = '0+dweta0n_na25'
+PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'
+PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = '1e-005-(dxwn_na25+dwmisn_na25)'    WMAX       = 900.00001e-06    
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = -4.5976888e-005     LK2        = -8.986516e-009      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00087551455+dcitn_na25'
+LCIT       = '-1.717243e-009+dlcitn_na25'
+VOFF       = -0.12541317         LVOFF      = 6.1017084e-009      NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021196+deta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062126092+du0n_na25'
+LU0        = '7.0604626e-009+dlu0n_na25'
+UA         = 1.0246402e-009      LUA        = 1.9809716e-015      UB         = 2.7182203e-018
+LUB        = -2.1739356e-024     UC         = -1.5214257e-011     LUC        = -3.2321858e-016
+VSAT       = '78400+dvsatn_na25'   A0         = 4.1247439           LA0        = -6.0880748e-006
+AGS        = 0.58809352          LAGS       = 4.7841698e-006      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.049079469        LKETA      = -6.4981729e-008     DWG        = 0
+DWB        = 0                   PCLM       = -0.026664974        LPCLM      = 3.6523484e-007
+PDIBLC1    = 0                   PDIBLC2    = 0.00015511976       LPDIBLC2   = -6.5942131e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25'
+CGDO       = 'cgon_na25'           CGBO       = 0                   CGDL       = 'cgln_na25'
+CGSL       = 'cgln_na25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283             KT1        = -0.25050115         LKT1       = -8.1870746e-008
+KT1L       = 0                   KT2        = -0.015762253        LKT2       = -2.7200338e-008
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -3.0882242e-018
+LUB1       = 8.7883765e-025      UC1        = -1.5421529e-010     LUC1       = 6.9476141e-016
+PRT        = 0                   AT         = 183960.37           LAT        = -0.19162228
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008           
+RSHG       = 15.06                  
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       WU0        = '0+dwu0n_na25'
+PU0        = '0+dpu0n_na25'        WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      WETA0      = '0+dweta0n_na25'      PETA0      = '0+dpeta0n_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.3 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = '1e-005-(dxwn_na25+dwmisn_na25)'    WMAX       = 900.00001e-06    
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = -0.00065388215      LK2        = -7.7941645e-009     K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0+dcitn_na25'
+VOFF       = -0.13332084         LVOFF      = 2.1611887e-008      NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021196+deta0n_na25'
+ETAB       = -0.0015372917       LETAB      = 5.1498547e-009      U0         = '0.062294657+du0n_na25'
+LU0        = '6.729838e-009+dlu0n_na25'
+UA         = 1.2107717e-009      LUA        = 1.6158914e-015      UB         = 2.478809e-018
+LUB        = -1.7043519e-024     UC         = -1.654901e-010      LUC        = -2.8466042e-017
+VSAT       = '78400+dvsatn_na25'   A0         = 2.1609292           LA0        = -2.2362292e-006
+AGS        = -8.613579           LAGS       = 2.2832422e-005      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = '-0.080253643'
+Pketa    = '0'
+Wketa    = '0'
+LKETA      = '-3.8364353e-09'
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33322887          LPCLM      = -3.4066454e-007
+PDIBLC1    = 0                   PDIBLC2    = 0.0001458025        LPDIBLC2   = -4.7667175e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25'
+CGDO       = 'cgon_na25'           CGBO       = 0                   CGDL       = 'cgln_na25'
+CGSL       = 'cgln_na25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283             KT1        = -0.2672704          LKT1       = -4.897936e-008
+KT1L       = 0                   KT2        = -0.02963            UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -2.64016e-018       UC1        = 4.3901206e-011
+LUC1       = 3.0617374e-016      PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                  
+XGL        = -2.11e-008           
+RSHG       = 15.06 
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+WU0        = '0+dwu0n_na25'        PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'
+WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'
+WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'
+WETA0      = '0+dweta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = 900.00001e-06       WMIN       = '1.2e-006-(dxwn_na25+dwmisn_na25)'  WMAX       = '1e-005-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'     
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = '(toxn_na25+toxmisn_na25)'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)'
+K1         = 0.083826            K2         = -0.00082308439      WK2        = -1.2511295e-009
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00079956499+dcitn_na25'
+WCIT       = '-9.6507494e-010+dwcitn_na25'
+VOFF       = -0.12477695         WVOFF      = -2.3700525e-010     NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062945581+du0n_na25'
+WU0        = '-1.1078502e-009+dwu0n_na25'
+UA         = 1.2235048e-009      UB         = 2.4999846e-018      UC         = -5.7780526e-011
+WUC        = 1.0126281e-016      VSAT       = '78400+dvsatn_na25'   A0         = 3.7916851
+WA0        = -2.783019e-006      AGS        = 1.0095994           WAGS       = 5.8805572e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.059213254        WKETA      = 3.6129664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = -0.0085221351
+WPCLM      = 1.8535101e-007      PDIBLC1    = 0                   PDIBLC2    = 0.00015035165
+WPDIBLC2   = -1.8529439e-011     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -2.9809198e-018     WUB1       = -1.9093557e-025
+UC1        = -8.447e-011         PRT        = 0                   AT         = 164723.91
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008           
+RSHG       = 15.06                  
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'
+PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.5 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = '1.2e-006-(dxwn_na25+dwmisn_na25)'  WMAX       = '1e-005-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = 0.00014232922       LK2        = -9.6168808e-009     WK2        = -1.8843792e-009
+PK2        = 6.3080606e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00099559933+dcitn_na25'
+LCIT       = '-1.9527785e-009+dlcitn_na25'
+WCIT       = '-1.2016884e-009+dwcitn_na25'
+PCIT       = '2.3570036e-015+dpcitn_na25'
+VOFF       = -0.12535694         LVOFF      = 5.777557e-009       WVOFF      = -5.6264021e-010
+PVOFF      = 3.2437834e-015      NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062119625+du0n_na25'
+LU0        = '8.2276866e-009+dlu0n_na25'
+WU0        = '6.471586e-011+dwu0n_na25'
+PU0        = '-1.1680411e-014+dpu0n_na25'
+UA         = 1.0066817e-009      LUA        = 2.1598628e-015      WUA        = 1.7970992e-016
+PUA        = -1.7901642e-021     UB         = 2.7288894e-018      LUB        = -2.2802153e-024
+WUB        = -1.0676613e-025     PUB        = 1.0635412e-030      UC         = -2.2362049e-011
+LUC        = -3.5281798e-016     WUC        = 7.1527948e-017      PUC        = 2.9620114e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 4.4672822           LA0        = -6.7298994e-006
+WA0        = -3.427781e-006      PA0        = 6.4227384e-012      AGS        = 0.49648423
+LAGS       = 5.1113508e-006      WAGS       = 9.1673415e-007      PAGS       = -3.2741006e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.05319211         LKETA      = -5.9979091e-008
+WKETA      = 4.1155197e-008      PKETA      = -5.0061403e-014     DWG        = 0
+DWB        = 0                   PCLM       = -0.050216044        LPCLM      = 4.1533012e-007
+WPCLM      = 2.3567555e-007      PPCLM      = -5.0130345e-013     PDIBLC1    = 0
+PDIBLC2    = 0.00015787937       LPDIBLC2   = -7.4986694e-011     WPDIBLC2   = -2.7615395e-011
+PPDIBLC2   = 9.0508939e-017      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25050115
+LKT1       = -8.1870746e-008     KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008     UTE        = -1.48               UA1        = 1.67e-009
+UB1        = -3.064466e-018      LUB1       = 8.3223805e-025      WUB1       = -2.3774844e-025
+PUB1       = 4.6632217e-031      UC1        = -1.6378149e-010     LUC1       = 7.9005425e-016
+WUC1       = 9.5728966e-017      PUC1       = -9.5359548e-022     PRT        = 0
+AT         = 183960.37           LAT        = -0.19162228         JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                  
+XGL        = -2.11e-008 
+RSHG       = 15.06                  
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'
+PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.6 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = '1.2e-006-(dxwn_na25+dwmisn_na25)'  WMAX       = '1e-005-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = -0.0002474582       LK2        = -8.8523478e-009     WK2        = -4.0670845e-009
+PK2        = 1.0589241e-014      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.13409419
+LVOFF      = 2.2914876e-008      WVOFF      = 7.7389381e-009      PVOFF      = -1.3039015e-014
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = -0.0014451533       LETAB      = 4.9691335e-009      WETAB      = -9.2202907e-010
+PETAB      = 1.808477e-015       U0         = '0.062618082+du0n_na25'
+LU0        = '7.2500067e-009+dlu0n_na25'
+WU0        = '-3.2365228e-009+dwu0n_na25'
+PU0        = '-5.2053284e-015+dpu0n_na25'
+UA         = 1.2361917e-009      LUA        = 1.7096996e-015      WUA        = -2.5437827e-016
+PUA        = -9.3873932e-022     UB         = 2.4638385e-018      LUB        = -1.7603418e-024
+WUB        = 1.4980948e-025      PUB        = 5.6029122e-031      UC         = -1.9983058e-010
+LUC        = -4.7294195e-018     WUC        = 3.4364521e-016      PUC        = -2.3753239e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 2.2652791           LA0        = -2.4108685e-006
+WA0        = -1.0442288e-006     PA0        = 1.7476153e-012      AGS        = -9.9452213
+LAGS       = 2.5591817e-005      WAGS       = 1.3325745e-005      PAGS       = -2.7613259e-011
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0
+KETA       = '-0.083185601'
+LKETA      = '-1.1496065e-09'
+WKETA      = '2.9340101e-08'
+PKETA      = '-2.6887095e-14'
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33215077          LPCLM      = -3.3464797e-007
+WPCLM      = 1.0788531e-008      PPCLM      = -6.0207799e-014     PDIBLC1    = 0
+PDIBLC2    = 0.00012335961       LPDIBLC2   = -7.2792913e-012     WPDIBLC2   = 2.2458608e-010
+PPDIBLC2   = -4.0416155e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.2672704
+LKT1       = -4.897936e-008      KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = 6.1508484e-011      LUC1       = 3.4816825e-016      WUC1       = -1.7619603e-016
+PUC1       = -4.2023907e-022     PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                  
+XGL        = -2.11e-008           
+RSHG       = 15.06 
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.7 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = 900.00001e-06       WMIN       = 5e-07               WMAX       = '1.2e-006-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'     
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = '(toxn_na25+toxmisn_na25)'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)'
+K1         = 0.083826            K2         = 0.012003617         WK2        = -1.6732958e-008
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0+dcitn_na25'        VOFF       = -0.12783168         WVOFF      = 3.4500609e-009
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.06106174+du0n_na25'
+WU0        = '1.1659461e-009+dwu0n_na25'
+UA         = 1.2854346e-009      WUA        = -7.4749352e-017     UB         = 2.4999846e-018
+UC         = 2.6115752e-011      VSAT       = '78400+dvsatn_na25'   A0         = 1.4808087
+WA0        = 6.2088783e-009      AGS        = 1.6647716           WAGS       = -2.027371e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.029279813        DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.000135            PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3.13911e-018       UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                  
+XGL        = -2.11e-008 
+RSHG       = 15.06                  
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'        PU0        = '0+dpu0n_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.8 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+LMAX       = '9.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = 5e-07               WMAX       = '1.2e-006-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = 0.012933166         LK2        = -9.2596208e-009     WK2        = -1.7322919e-008
+PK2        = 5.8768479e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.12905814
+LVOFF      = 1.221718e-008       WVOFF      = 3.9046996e-009      PVOFF      = -4.528842e-015
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062004206+du0n_na25'
+LU0        = '-9.3882913e-009+dlu0n_na25'
+WU0        = '2.040266e-010+dwu0n_na25'
+PU0        = '9.5820743e-015+dpu0n_na25'
+UA         = 1.2896963e-009      LUA        = -4.2452701e-017     WUA        = -1.6188868e-016
+PUA        = 8.6803058e-022      UB         = 2.594245e-018       LUB        = -9.389669e-025
+WUB        = 5.5749704e-026      PUB        = -5.5534566e-031     UC         = 3.2781608e-011
+LUC        = -6.6401324e-017     WUC        = 4.9695541e-018      PUC        = -4.9503766e-023
+VSAT       = '78400+dvsatn_na25'   A0         = 1.5569963           LA0        = -7.5893653e-007
+WA0        = 8.4934061e-008      PA0        = -7.8421382e-013     AGS        = 1.5962099
+LAGS       = 6.8297174e-007      WAGS       = -4.1063467e-007     PAGS       = 2.0709529e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.01641015         LKETA      = -1.2819999e-007
+WKETA      = -3.2406274e-009     PKETA      = 3.2281218e-014      DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.000135            PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25050115
+LKT1       = -8.1870746e-008     KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008     UTE        = -1.48               UA1        = 1.67e-009
+UB1        = -3.2614407e-018     LUB1       = 1.2185862e-024      UC1        = -8.447e-011
+PRT        = 0                   AT         = 183960.37           LAT        = -0.19162228
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008           
+RSHG       = 15.06                  
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       LCIT       = '0+dlcitn_na25'
+WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'
+WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'
+PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'
+PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.MODEL nch_na25.9 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-(dxln_na25+dlmisn_na25)'
+WMIN       = 5e-07               WMAX       = '1.2e-006-(dxwn_na25+dwmisn_na25)'
+VERSION    = 4.5 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na25' 
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = '(toxn_na25+toxmisn_na25)'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+(dxln_na25+dlmisn_na25)' XW         = '7e-09+(dxwn_na25+dwmisn_na25)'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+(dvthn_na25+vthmisn_na25)' K1         = 0.083826
+K2         = 0.0070517436        LK2        = 2.2762599e-009      WK2        = -1.2877221e-008
+PK2        = -2.842989e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.12106439
+LVOFF      = -3.4618388e-009     WVOFF      = -7.9880317e-009     PVOFF      = 1.879768e-014
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+LETA0      = '-2.0005323e-016+dleta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+PETA0      = '2.4146429e-022+dpeta0n_na25'
+ETAB       = -0.0045972791       LETAB      = 1.1151745e-008      WETAB      = 2.8825868e-009
+PETAB      = -5.6539345e-015     U0         = '0.061722716+du0n_na25'
+LU0        = '-8.8361755e-009+dlu0n_na25'
+WU0        = '-2.1558162e-009+dwu0n_na25'
+PU0        = '1.4210694e-014+dpu0n_na25'
+UA         = 1.6235236e-009      LUA        = -6.9722491e-016     WUA        = -7.2188788e-016
+PUA        = 1.9664186e-021      UB         = 1.8314711e-018      LUB        = 5.5714547e-025
+WUB        = 9.1307699e-025      PUB        = -2.236916e-030      UC         = 1.6131981e-010
+LUC        = -3.1851744e-016     WUC        = -9.2263315e-017     PUC        = 1.4120976e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 1.8138372           LA0        = -1.2627068e-006
+WA0        = -4.9933847e-007     PA0        = 3.6178416e-013      AGS        = 1.253264
+LAGS       = 1.3556292e-006      WAGS       = -1.9082677e-007     PAGS       = 1.6398195e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.080802003        LKETA      = -1.9011631e-009
+WKETA      = 2.6463098e-008      PKETA      = -2.5979966e-014     DWG        = 0
+DWB        = 0                   PCLM       = 0.53198689          LPCLM      = -7.5895904e-007
+WPCLM      = -2.3041366e-007     PPCLM      = 4.5193566e-013      PDIBLC1    = 0
+PDIBLC2    = 0.00030623536       LPDIBLC2   = -3.3586275e-010     WPDIBLC2   = 3.8550414e-012
+PPDIBLC2   = -7.5613168e-018     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.2672704
+LKT1       = -4.897936e-008      KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = -8.447e-011         PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                  
+XGL        = -2.11e-008           
+RSHG       = 15.06 
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'       
+FNOIMOD  = 1  
+NOIA     = 'noian_na25' 
+NOIB     = 'noibn_na25' 
+NOIC     = 'noicn_na25' 
+EM       = 1.12e+08 
+EF       = 1.00 
+TNOIMOD  = 1  
+KVTH0WE  = 0  
+K2WE     = 0  
+KU0WE    = 0  
+WEC      = 0  
+WEB      = 0  
+SCREF    = 1e-6 
+WPEMOD   = 1  
+UD       = 0 )

.ends nch_na25_mac

.ENDL MAC_na25



.LIB MAC_hv25_snw_spw
**********************************************************************************************
*                                                                                            *
*                                   2.5V HVNMOS DEVICE MODELS                                *
*                                                                                            *
**********************************************************************************************


**********************************
*       Mismatch   model         * 
**********************************
.subckt nch_hv25_snw_mac n1 n2 n3 n4  l=length w=width multi=1 nf='1' scale='1' sigma='1'
+dmcg='1.245e-07' xw='+7e-09+dxwn_hv25_snw'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0.46e-6/scale' sb='0.46e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 nch_hv25_snw w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parn1_hv25_snw_spw  temp2=parn2_hv25_snw_spw
+fac1='0.055060*temp1*sigma+0.998483*temp2*sigma'
+fac2='0.055060*temp1*sigma-0.998483*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisn_hv25_snw='0.0171455*geo_fac*fac1*mismatchflag'
+       dlmisn_hv25_snw='0.00537238*geo_fac*lef*fac2*mismatchflag'
+       dwmisn_hv25_snw='-0.00537238*geo_fac*wef*fac2*mismatchflag'
+       toxmisn_hv25_snw='0.00537238*geo_fac*toxn_hv25_snw*fac2*mismatchflag' 
.MODEL nch_hv25_snw.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = 0.0009000001        WMIN       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.5704+(dvthn_hv25_snw+vthmisn_hv25_snw)'  
+LVTH0      = '1.0886705e-15+dlvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+WVTH0      = '1.0228436e-13+dwvthn_hv25_snw' 
+PVTH0      = '-9.7981255e-19+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.03173+dk2n_hv25_snw'  
+LK2        = '0+dlk2n_hv25_snw' 
+WK2        = '0+dwk2n_hv25_snw'        
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0
+K3B        = 0.52562             W0         = 0                   DVT0       = 46.85
+DVT1       = 0.261               DVT2       = 0.04202             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.1
+MINV       = -0.3                VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20
+DVTP1      = 1.223               LPE0       = 3.507e-07           LPEB       = 1.362e-07
+XJ         = 2.35e-06            NGATE      = 4.282e+20           NDEP       = 5.11e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000537+dcitn_hv25_snw'
+LCIT       = '0+dlcitn_hv25_snw'       WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'
+VOFF       = -0.1052276          NFACTOR    = 0.75                ETA0       = '0.003803+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '0+dweta0n_hv25_snw'      PETA0      = '0+dpeta0n_hv25_snw'
+ETAB       = -0.007951           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.02773+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '0+dwu0n_hv25_snw'        PU0        = '0+dpu0n_hv25_snw'
+UA         = -1.5453e-09        
+UB         = 3.02e-18 
+PUB      = 0 
+WUB      = 0 
+LUB      = 0 
+UC         = '1.2661e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+WUC      = '0+dwucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'      A0         = '1.28792+da0n_hv25_snw'   LA0        = '0+dla0n_hv25_snw'
+WA0        = '0+dwa0n_hv25_snw'        PA0        = '0+dpa0n_hv25_snw'        AGS        = '0.415+dagsn_hv25_snw'
+LAGS       = '0+dlagsn_hv25_snw'       WAGS       = '0+dwagsn_hv25_snw'       PAGS       = '0+dpagsn_hv25_snw'
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.04188+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+WKETA    = '0+dwketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.0005404+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '-1.0886718e-18+dlpdiblc2n_hv25_snw'
+WPDIBLC2   = '-1.0891898e-18+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '9.7981256e-22+dppdiblc2n_hv25_snw'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.399e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = 0 
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.002
+LTVOFF     = 0                   WTVOFF     = 0                   PTVOFF     = 0
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.269706           KT1L       = 0
+KT2        = -0.046              
+PKT2     = 0 
+WKT2     = 0 
+LKT2     = 0 
+UTE        = -1.095              UA1        = 2.8795633e-09
+UB1        = -3.470411e-18       LUB1       = 1.0009006e-30       WUB1       = 1.0446274e-30
+PUB1       = -2.9394377e-35
+UC1        = '-1.1e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+WUC1     = '0+dwuc1n_hv25_snw'
+LUC1     = '0+dluc1n_hv25_snw'
+PRT        = 0
+AT         = 222000              JSS        = 1.399e-07           JSWS       = 5e-14
+JSWGS      = 9e-14              
+NJS        = 1.00               
+NJD        = 1.007 
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   XJBVS      = 1
+XJBVD      = 1                  
+JSD        = 2.299e-6            
+JSWD       = 2.001e-12 
+JSWGD      = 2.001e-12           
+BVD        = 14.5                JTSSWGS    = 1.086e-08
+JTSSWGD    = 1.086e-08           NJTSSWG    = 40                  XTSSWGS    = 0.29766
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   PBS        = 0.7                
+PBD        = 0.62 
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'           MJS        = 0.31
+MJD        = 0.35                
+PBSWS      = 0.48               
+PBSWD      = 0.6 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'         MJSWS      = 0.12
+MJSWD      = 0.27                
+PBSWGS     = 0.6                
+PBSWGD     = 0.6 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'        MJSWGS     = 0.3
+MJSWGD     = 0.32                
+TPB        = 1.95E-03            
+TCJ        = 1.71E-03 
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04            
+TPBSWG     = 1.75E-03 
+TCJSWG     = 1.33E-03            
+XTIS       = 3                   XTID       = 3
+DMCG       = 1.245e-07           DMCI       = 3.05e-07            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-08           RSHG       = 15.06               GBMIN      = 1e-12
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.2 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56815568+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '2.1498986e-08+dlvthn_hv25_snw' 
+WVTH0      = '0+dwvthn_hv25_snw'       
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096 
+K2         = '-0.030971118+dk2n_hv25_snw' 
+LK2        = '-7.2695682e-09+dlk2n_hv25_snw' 
+WK2        = '0+dwk2n_hv25_snw'        
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0
+K3B        = 0.52562             W0         = 0                   DVT0       = 46.85
+DVT1       = 0.261               DVT2       = 0.04202             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.1
+MINV       = -0.3                VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20
+DVTP1      = 1.223               LPE0       = 3.507e-07           LPEB       = 1.362e-07
+XJ         = 2.35e-06            NGATE      = 4.282e+20           NDEP       = 5.11e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0004898836+dcitn_hv25_snw'
+LCIT       = '4.5134213e-10+dlcitn_hv25_snw'
+WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'       VOFF       = -0.10578279
+LVOFF      = 5.3183037e-09       WVOFF      = 6.5135945e-16       PVOFF      = -6.2395688e-21
+NFACTOR    = 0.75                ETA0       = '0.0038497542+deta0n_hv25_snw'
+LETA0      = '-4.4787259e-10+dleta0n_hv25_snw'
+WETA0      = '0+dweta0n_hv25_snw'      PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.007951
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.02636607+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.3065492e-08+dlu0n_hv25_snw'
+WU0        = '6.5135954e-16+dwu0n_hv25_snw'
+PU0        = '-6.2395687e-21+dpu0n_hv25_snw'
+UA         = -1.621774e-09       LUA        = 7.3256777e-16       WUA        = 4.559517e-23
+PUA        = -4.3676981e-28     
+UB         = 3.0339031e-18       
+PUB      = 0 
+WUB      = 0 
+LUB        = -1.3318292e-25 
+UC         = '1.2170204e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+WUC      = '0+dwucn_hv25_snw' 
+LUC        = '4.7014805e-17+dlucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'
+KVSAT    = -0.4 
+LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'
+A0         = '1.4262467+da0n_hv25_snw' 
+LA0        = '-1.3250727e-06+dla0n_hv25_snw' 
+WA0        = '-5.8622361e-14+dwa0n_hv25_snw' 
+PA0        = '5.6156119e-19+dpa0n_hv25_snw' 
+AGS        = '0.38300976+dagsn_hv25_snw' 
+LAGS       = '3.0644404e-07+dlagsn_hv25_snw' 
+WAGS       = '0+dwagsn_hv25_snw'       
+PAGS       = '0+dpagsn_hv25_snw'       
+A1         = 0
+A2         = 0.82037             B0         = 0                   B1         = 0
+KETA       = '-0.039655488+dketan_hv25_snw'
+LKETA      = '-2.1309268e-08+dlketan_hv25_snw'
+WKETA      = '-6.5135948e-16+dwketan_hv25_snw'
+PKETA      = '6.2395686e-21+dpketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                  
+PDIBLC2    = '0.00056810277+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-2.6537314e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '1.0314925e-16+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-1.8718705e-23+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.3996436e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = -6.165876  
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.0020708033
+LTVOFF     = -6.7824639e-10      WTVOFF     = -3.9081577e-17      PTVOFF     = 3.7437412e-22
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.26501213         LKT1       = -4.4964041e-08
+WKT1       = -6.513595e-15       PKT1       = 6.2395686e-20       KT1L       = 0
+KT2        = -0.044283341        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = -1.6444391e-08      
+UTE        = -1.0816761
+LUTE       = -1.2763364e-07      UA1        = 2.8412992e-09       LUA1       = 3.6654358e-16
+UB1        = -3.4778955e-18      LUB1       = 7.1696745e-26       WUB1       = -2.0890393e-30
+PUB1       = 6.2395687e-37
+UC1        = '-1.2523559e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+WUC1     = '0+dwuc1n_hv25_snw'
+LUC1       = '1.4594629e-16+dluc1n_hv25_snw'
+PRT        = 0                   AT         = 237769.83           LAT        = -0.15106396
+WAT        = 1.0421753e-08       PAT        = -9.9833099e-14      JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.3 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.65837596+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-3.0765622e-08+dlvthn_hv25_snw' 
+WVTH0      = '0+dwvthn_hv25_snw'       
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096 
+K2         = '-0.037720435+dk2n_hv25_snw' 
+LK2        = '-3.3596878e-09+dlk2n_hv25_snw' 
+WK2        = '2.8962057e-14+dwk2n_hv25_snw' 
+PK2        = '-1.677772e-20+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0019845+dcitn_hv25_snw'
+LCIT       = '-4.1448915e-10+dlcitn_hv25_snw'
+WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'       VOFF       = -0.11206397
+LVOFF      = 8.9569943e-09       WVOFF      = -2.9974009e-13      PVOFF      = 1.677772e-19
+NFACTOR    = 0.75                ETA0       = '0.0091687573+deta0n_hv25_snw'
+LETA0      = '-3.5291711e-09+dleta0n_hv25_snw'
+WETA0      = '2.0563061e-14+dweta0n_hv25_snw'
+PETA0      = '-1.1912181e-20+dpeta0n_hv25_snw'
+ETAB       = -0.007951           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.015033924+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.9630205e-08+dlu0n_hv25_snw'
+WU0        = '-1.011952e-14+dwu0n_hv25_snw'
+PU0        = '1.9837617e-28+dpu0n_hv25_snw'
+UA         = -2.0646691e-09      LUA        = 9.8913684e-16       WUA        = 3.3463218e-21
+PUA        = -2.3488808e-27     
+UB         = 2.185808e-18        
+PUB      = 0 
+WUB      = 0 
+LUB        = 3.5811862e-25 
+UC         = '3.7054698e-10+ducn_hv25_snw' 
+LUC        = '-9.7141067e-17+dlucn_hv25_snw' 
+WUC        = '-1.8825334e-15+dwucn_hv25_snw' 
+PUC        = '1.0905516e-21+dpucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'
+KVSAT    = -0.4 
+WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '2.8370898+da0n_hv25_snw' 
+LA0        = '-2.1423742e-06+dla0n_hv25_snw' 
+WA0        = '3.5173417e-12+dwa0n_hv25_snw' 
+PA0        = '-1.5099948e-18+dpa0n_hv25_snw' 
+AGS        = '-2.6915442+dagsn_hv25_snw' 
+LAGS       = '2.0875331e-06+dlagsn_hv25_snw' 
+WAGS       = '-2.8962058e-12+dwagsn_hv25_snw' 
+PAGS       = '1.6777721e-18+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.17665855+dketan_hv25_snw' 
+LKETA      = '5.8056604e-08+dlketan_hv25_snw' 
+WKETA      = '3.8884465e-07+dwketan_hv25_snw' 
+PKETA      = '-2.252577e-13+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00010889385+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '6.4659e-13+dlpdiblc2n_hv25_snw'     
+WPDIBLC2   = '2.1564691e-16+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-8.3888599e-23+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.56072e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = -99.477394 
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.00061379989
+LTVOFF     = 1.6579571e-10       WTVOFF     = -5.5131128e-16      PTVOFF     = 6.7110882e-22
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.45116111         LKT1       = 6.2872069e-08
+WKT1       = 3.9081575e-13       PKT1       = -1.677772e-19       KT1L       = 0
+KT2        = -0.10893154         LKT2       = 2.100631e-08        WKT2       = -2.8962057e-14
+PKT2       = 1.6777718e-20       UTE        = -1.324896           LUTE       = 1.3263653e-08
+UA1        = 4.668441e-10        LUA1       = 1.7420654e-15       UB1        = -9.7213076e-19
+LUB1       = -1.3798927e-24      WUB1       = -1.0119517e-30      PUB1       = -3.4730437e-44
+UC1        = '1.4252689e-10+duc1n_hv25_snw' 
+LUC1       = '-9.16852e-18+dluc1n_hv25_snw' 
+WUC1       = '-8.6886172e-22+dwuc1n_hv25_snw' 
+PUC1       = '5.033316e-28+dpuc1n_hv25_snw' 
+PRT        = 0                  
+AT         = 26111.936 
+LAT        = -0.028450543        
+WAT        = -5.3841902e-07      
+PAT        = 2.1811036e-13 
+JSS        = 1.399e-07           JSWS       = 5e-14               JSWGS      = 9e-14
+NJS        = 1.00               
+NJD        = 1.007               
+IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   XJBVS      = 1                   XJBVD      = 1
+JSD        = 2.299e-6            
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12 
+BVD        = 14.5                JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08
+NJTSSWG    = 40                  XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774 
+TNJTSSWG   = 1                   VTSSWGS    = 1                   VTSSWGD    = 1
+PBS        = 0.7                
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'
+CJD        = 'cjdn_hv25_snw'           MJS        = 0.31               
+MJD        = 0.35 
+PBSWS      = 0.48               
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'
+CJSWD      = 'cjswdn_hv25_snw'         MJSWS      = 0.12               
+MJSWD      = 0.27 
+PBSWGS     = 0.6                
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'
+CJSWGD     = 'cjswgdn_hv25_snw'        MJSWGS     = 0.3                
+MJSWGD     = 0.32 
+TPB        = 1.95E-03            
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03 
+TCJSW      = 9.93E-04            
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03 
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.245e-07
+DMCI       = 3.05e-07            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-08
+RSHG       = 15.06               GBMIN      = 1e-12               RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.4 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = 0.0009000001        WMIN       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56899962+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-1.0765758e-13+dlvthn_hv25_snw' 
+WVTH0      = '1.4013749e-08+dwvthn_hv25_snw' 
+PVTH0      = '1.0841118e-19+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.030898666+dk2n_hv25_snw' 
+LK2        = '0+dlk2n_hv25_snw'        
+WK2        = '-8.319164e-09+dwk2n_hv25_snw'  
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0                   K3B        = 0.52562
+W0         = 0                   DVT0       = 46.85               DVT1       = 0.261
+DVT2       = 0.04202             DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.1                 MINV       = -0.3
+VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20         DVTP1      = 1.223
+LPE0       = 3.507e-07           LPEB       = 1.362e-07           XJ         = 2.35e-06
+NGATE      = 4.282e+20           NDEP       = 5.11e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00057329675+dcitn_hv25_snw'
+LCIT       = '1.0833535e-17+dlcitn_hv25_snw'
+WCIT       = '-3.6322162e-10+dwcitn_hv25_snw'
+PCIT       = '-1.0841118e-22+dpcitn_hv25_snw'
+VOFF       = -0.10423309         WVOFF      = -9.9520936e-09      NFACTOR    = 0.75
+ETA0       = '0.0041001769+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '-2.9738491e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0080753085       WETAB      = 1.2439556e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.027320487+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '4.0979999e-09+dwu0n_hv25_snw'
+PU0        = '0+dpu0n_hv25_snw'        UA         = -1.604196e-09       WUA        = 5.8937233e-16
+UB         = 3.0668172e-18       
+LUB        = -1.0833535e-31      
+WUB        = -4.6850015e-25 
+PUB        = 1.0841118e-36 
+UC         = '1.3013561e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+WUC        = '-3.5280869e-17+dwucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.2661706+da0n_hv25_snw' 
+LA0        = '0+dla0n_hv25_snw' 
+WA0        = '2.1764634e-07+dwa0n_hv25_snw' 
+PA0        = '0+dpa0n_hv25_snw'        
+AGS        = '0.41553546+dagsn_hv25_snw'
+LAGS       = '0+dlagsn_hv25_snw'       WAGS       = '-5.3583029e-09+dwagsn_hv25_snw'
+PAGS       = '0+dpagsn_hv25_snw'       A1         = 0                   A2         = 0.82037
+B0         = 0                   B1         = 0
+KETA       = '-0.042854552+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+WKETA      = '9.7523441e-09+dwketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                   PDIBLC2    = '0.00037999609+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '1.0765758e-16+dlpdiblc2n_hv25_snw'
+WPDIBLC2   = '1.6051619e-09+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '-1.0841118e-22+dppdiblc2n_hv25_snw'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4068322e+09 
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -78.377043          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0020559444        LTVOFF     = 0                   WTVOFF     = -5.5983606e-10
+PTVOFF     = 0                   TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26925912
+WKT1       = -4.4719704e-09      KT1L       = 0                  
+KT2        = -0.046223777 
+LKT2       = -1.0833534e-15      
+WKT2       = 2.239343e-09        
+PKT2       = 1.0841118e-20 
+UTE        = -1.1056295          LUTE       = 4.3334138e-14       WUTE       = 1.063689e-07
+PUTE       = -4.3364473e-19      UA1        = 2.8549361e-09       WUA1       = 2.4644465e-16
+UB1        = -3.4579588e-18      LUB1       = -2.0448162e-30      WUB1       = -1.2460853e-25
+PUB1       = 1.0841118e-36
+UC1        = '-1.1186071e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+LUC1     = '0+dluc1n_hv25_snw'
+WUC1       = '1.8620149e-17+dwuc1n_hv25_snw'
+PRT        = 0                   AT         = 222000              JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.5 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56650617+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '2.3885351e-08+dlvthn_hv25_snw' 
+WVTH0      = '1.6506672e-08+dwvthn_hv25_snw' 
+PVTH0      = '-2.3880361e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.03016535+dk2n_hv25_snw'  
+LK2        = '-7.0246556e-09+dlk2n_hv25_snw' 
+WK2        = '-8.0633169e-09+dwk2n_hv25_snw' 
+PK2        = '-2.4508341e-15+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00052439212+dcitn_hv25_snw'
+LCIT       = '4.6847218e-10+dlcitn_hv25_snw'
+WCIT       = '-3.4532676e-10+dwcitn_hv25_snw'
+PCIT       = '-1.7142036e-16+dpcitn_hv25_snw'
+VOFF       = -0.10484164         LVOFF      = 5.8294711e-09       WVOFF      = -9.4181028e-09
+PVOFF      = -5.1152585e-15      NFACTOR    = 0.75                ETA0       = '0.0041521624+deta0n_hv25_snw'
+LETA0      = '-4.9798456e-10+dleta0n_hv25_snw'
+WETA0      = '-3.0261985e-09+dweta0n_hv25_snw'
+PETA0      = '5.0147045e-16+dpeta0n_hv25_snw'
+ETAB       = -0.0080753085       WETAB      = 1.2439556e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.025956845+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.3062732e-08+dlu0n_hv25_snw'
+WU0        = '4.0951171e-09+dwu0n_hv25_snw'
+PU0        = '2.7615038e-17+dpu0n_hv25_snw'
+UA         = -1.6827304e-09      LUA        = 7.5230414e-16       WUA        = 6.0998995e-16
+PUA        = -1.9750235e-22     
+UB         = 3.0821927e-18       
+LUB        = -1.4728613e-25 
+WUB        = -4.8323292e-25      
+PUB        = 1.4113086e-31 
+UC         = '1.2522658e-10+ducn_hv25_snw' 
+LUC        = '4.7025153e-17+dlucn_hv25_snw' 
+WUC        = '-3.5270058e-17+dwucn_hv25_snw' 
+PUC        = '-1.03556e-25+dpucn_hv25_snw'   
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.4021929+da0n_hv25_snw' 
+LA0        = '-1.3029988e-06+dla0n_hv25_snw' 
+WA0        = '2.4070587e-07+dwa0n_hv25_snw' 
+PA0        = '-2.2089408e-13+dpa0n_hv25_snw' 
+AGS        = '0.38241298+dagsn_hv25_snw' 
+LAGS       = '3.1729015e-07+dlagsn_hv25_snw' 
+WAGS       = '5.97207e-09+dwagsn_hv25_snw'  
+PAGS       = '-1.0853704e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.04071521+dketan_hv25_snw'
+LKETA      = '-2.04934e-08+dlketan_hv25_snw'
+WKETA      = '1.0604639e-08+dwketan_hv25_snw'
+PKETA      = '-8.164386e-15+dpketan_hv25_snw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00039833343+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-1.7565876e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '1.698882e-09+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-8.9777177e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4074759e+09 
+PBGIDL   = 0              
+LBGIDL   = -6.1658759 
+WBGIDL     = -78.377048          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0021199845        LTVOFF     = -6.134585e-10       WTVOFF     = -4.9215553e-10
+PTVOFF     = -6.4833206e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26447988
+LKT1       = -4.5781779e-08      WKT1       = -5.3262253e-09      PKT1       = 8.1831642e-15
+KT1L       = 0                  
+KT2        = -0.044466284        
+LKT2       = -1.6835561e-08 
+WKT2       = 1.83071e-09         
+PKT2       = 3.9144316e-15       
+UTE        = -1.0912181
+LUTE       = -1.3805102e-07      WUTE       = 9.5486347e-08       PUTE       = 1.0424677e-13
+UA1        = 2.8216694e-09       LUA1       = 3.1867162e-16       WUA1       = 1.9643528e-16
+PUA1       = 4.790547e-22        UB1        = -3.4672797e-18      LUB1       = 8.928643e-26
+WUB1       = -1.0623345e-25      PUB1       = -1.7601936e-31
+UC1        = '-1.2707275e-10+duc1n_hv25_snw'
+LUC1       = '1.4572069e-16+dluc1n_hv25_snw'
+WUC1       = '1.8384482e-17+dwuc1n_hv25_snw'
+PUC1       = '2.257528e-24+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 237877.86           LAT        = -0.15209881
+WAT        = -0.0010810437       PAT        = 1.0355642e-08       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.6 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'    WMAX       = '1e-005-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.66406201+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-3.2628752e-08+dlvthn_hv25_snw' 
+WVTH0      = '-5.6900341e-08+dwvthn_hv25_snw' 
+PVTH0      = '1.8644319e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.038247886+dk2n_hv25_snw' 
+LK2        = '-2.3424433e-09+dlk2n_hv25_snw' 
+WK2        = '5.2782044e-09+dwk2n_hv25_snw'  
+PK2        = '-1.0179581e-14+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0021558865+dcitn_hv25_snw'
+LCIT       = '-4.7665251e-10+dlcitn_hv25_snw'
+WCIT       = '-1.7150645e-09+dwcitn_hv25_snw'
+PCIT       = '6.2206871e-16+dpcitn_hv25_snw'
+VOFF       = -0.11277103         LVOFF      = 1.0422968e-08       WVOFF      = 7.0752106e-09
+PVOFF      = -1.4669835e-14      NFACTOR    = 0.75                ETA0       = '0.0097310283+deta0n_hv25_snw'
+LETA0      = '-3.7298216e-09+dleta0n_hv25_snw'
+WETA0      = '-5.6266249e-09+dweta0n_hv25_snw'
+PETA0      = '2.0078974e-15+dpeta0n_hv25_snw'
+ETAB       = -0.0080753085       WETAB      = 1.2439556e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.014856902+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.9492929e-08+dlu0n_hv25_snw'
+WU0        = '1.7714492e-09+dwu0n_hv25_snw'
+PU0        = '1.3737159e-15+dpu0n_hv25_snw'
+UA         = -2.0677308e-09      LUA        = 9.7533487e-16       WUA        = 3.0641927e-17
+PUA        = 1.3811397e-22      
+UB         = 2.1380215e-18       
+LUB        = 3.9967218e-25 
+WUB        = 4.7819848e-25       
+PUB        = -4.1582638e-31 
+UC         = '1.7208914e-10+ducn_hv25_snw' 
+LUC        = '1.9877672e-17+dlucn_hv25_snw' 
+WUC        = '1.0343415e-16+dwucn_hv25_snw' 
+PUC        = '-8.0454904e-23+dpucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '2.7883693+da0n_hv25_snw' 
+LA0        = '-2.1060108e-06+dla0n_hv25_snw' 
+WA0        = '4.8754885e-07+dwa0n_hv25_snw'  
+PA0        = '-3.6389021e-13+dpa0n_hv25_snw' 
+AGS        = '-2.709636+dagsn_hv25_snw'  
+LAGS       = '2.1085142e-06+dlagsn_hv25_snw' 
+WAGS       = '1.8104222e-07+dwagsn_hv25_snw'  
+PAGS       = '-2.0995519e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.14077466+dketan_hv25_snw' 
+LKETA      = '3.7471039e-08+dlketan_hv25_snw' 
+WKETA      = '2.9754579e-08+dwketan_hv25_snw' 
+PKETA      = '-1.9257946e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00016492465+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-4.044505e-11+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '-5.6069993e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '4.1120399e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.5813612e+09 
+PBGIDL   = 7.4254705e-05 
+LBGIDL   = -106.89768 
+WBGIDL     = -206.55712          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.00070206902       LTVOFF     = 2.0793992e-10       WTVOFF     = -8.8330974e-10
+PTVOFF     = -4.2173642e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.45776537 
+LKT1       = 6.6188505e-08       
+WKT1       = 6.6089134e-08       
+PKT1       = -3.3187753e-14 
+KT1L       = 0                   KT2        = -0.11375012         LKT2       = 2.3300562e-08
+WKT2       = 4.821945e-08        PKT2       = -2.2958565e-14      UTE        = -1.3588252
+LUTE       = 1.6973791e-08       WUTE       = 3.3952937e-07       PUTE       = -3.7127355e-14
+UA1        = 2.4590441e-10       LUA1       = 1.8108123e-15       WUA1       = 2.2109434e-15
+PUA1       = -6.8794985e-22     
+UB1        = -4.6546741e-19      
+LUB1       = -1.6496635e-24 
+WUB1       = -5.0701811e-24      
+PUB1       = 2.6995956e-30 
+UC1        = '1.897303e-10+duc1n_hv25_snw'  
+LUC1       = '-3.780332e-17+dluc1n_hv25_snw' 
+WUC1       = '-4.7236537e-16+dwuc1n_hv25_snw' 
+PUC1       = '2.8654892e-22+dpuc1n_hv25_snw'  
+PRT        = 0                  
+AT         = 21180.051           
+LAT        = -0.026565769 
+WAT        = 0.049352836         
+PAT        = -1.8860704e-08      
+JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.7 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = 0.0009000001        WMIN       = 6e-07               WMAX       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09             VTH0       = '0.5867339+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '0+dlvthn_hv25_snw'       WVTH0      = '-3.8446798e-09+dwvthn_hv25_snw'
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096             
+K2         = '-0.029554225+dk2n_hv25_snw' 
+LK2        = '0+dlk2n_hv25_snw'        
+WK2        = '-9.673015e-09+dwk2n_hv25_snw'  
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0                   K3B        = 0.52562
+W0         = 0                   DVT0       = 46.85               DVT1       = 0.261
+DVT2       = 0.04202             DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.1                 MINV       = -0.3
+VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20         DVTP1      = 1.223
+LPE0       = 3.507e-07           LPEB       = 1.362e-07           XJ         = 2.35e-06
+NGATE      = 4.282e+20           NDEP       = 5.11e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00017147578+dcitn_hv25_snw'
+LCIT       = '-2.4375453e-16+dlcitn_hv25_snw'
+WCIT       = '4.1412104e-11+dwcitn_hv25_snw'
+PCIT       = '1.47959e-22+dpcitn_hv25_snw'
+VOFF       = -0.10549053         WVOFF      = -8.6858483e-09      NFACTOR    = 0.75
+ETA0       = '-0.002042785+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '3.2121135e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0098021603       WETAB      = 2.9828953e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.032042525+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '-6.5709268e-10+dwu0n_hv25_snw'
+PU0        = '0+dpu0n_hv25_snw'        UA         = -1.1506345e-09      LUA        = 4.4079146e-22
+WUA        = 1.326359e-16        PUA        = -4.4387699e-28     
+UB         = 2.8656853e-18 
+LUB        = 2.4375453e-30       
+WUB        = -2.6596025e-25      
+PUB        = -1.47959e-36 
+UC         = '1.4024866e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+WUC        = '-4.54647e-17+dwucn_hv25_snw'  
+VSAT       = '100000+dvsatn_hv25_snw'
+KVSAT    = -0.4 
+LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'
+A0         = '1.4858003+da0n_hv25_snw' 
+LA0        = '0+dla0n_hv25_snw'        
+WA0        = '-3.52079e-09+dwa0n_hv25_snw'   
+PA0        = '0+dpa0n_hv25_snw'        
+AGS        = '0.43224+dagsn_hv25_snw'  LAGS       = '0+dlagsn_hv25_snw'
+WAGS       = '-2.2179781e-08+dwagsn_hv25_snw'
+PAGS       = '0+dpagsn_hv25_snw'       A1         = 0                   A2         = 0.82037
+B0         = 0                   B1         = 0
+KETA       = '-0.03277545+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+WKETA      = '-3.9731185e-10+dwketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                   PDIBLC2    = '0.00164622+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '0+dlpdiblc2n_hv25_snw'   WPDIBLC2   = '3.3007446e-10+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '0+dppdiblc2n_hv25_snw'   PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.112               DELTA      = 0.00375             PSCBE1     = 2170000
+PSCBE2     = 1.5952e-09          FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = 80                  RDW        = 510                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1e-09
+ALPHA1     = 0.978               BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'
+LAGIDL     = '0+dlagidln_hv25_snw'     WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'
+BGIDL      = 2.404875e+09        
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -76.406125          
+CGIDL      = 70
+EGIDL      = 2.2484              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.054
+CIGC       = 0.075               AIGSD      = 0.43                BIGSD      = 0.054
+CIGSD      = 0.075               NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'
+CGDO       = 'cgdon_hv25_snw'          CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'
+CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                  
+NOFF       = 2.3195 
+VOFFCV     = -0.022791           
+TVOFF      = 0.00188241          LTVOFF     = 0
+WTVOFF     = -3.8508687e-10      PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.27014163         WKT1       = -3.5832792e-09      KT1L       = 0
+KT2        = -0.026943303        
+LKT2       = 2.4375454e-14       
+WKT2       = -1.7176095e-08 
+PKT2       = -1.47959e-20        
+UTE        = -0.9984824          LUTE       = -9.7501813e-13
+WUTE       = -1.5281843e-09      PUTE       = 5.91836e-19         UA1        = 3.4824632e-09
+WUA1       = -3.8547517e-16      UB1        = -4.1272103e-18      LUB1       = -9.6824044e-31
+WUB1       = 5.493278e-25        PUB1       = 2.2398669e-44
+UC1        = '-1.5751471e-10+duc1n_hv25_snw'
+LUC1       = '1.4693049e-23+dluc1n_hv25_snw'
+WUC1       = '6.4593727e-17+dwuc1n_hv25_snw'
+PUC1       = '-1.47959e-29+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 222000              JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.8 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'
+LMAX       = '1e-005-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = 6e-07               WMAX       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.58596616+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '7.354444e-09+dlvthn_hv25_snw'  
+WVTH0      = '-3.0895374e-09+dwvthn_hv25_snw' 
+PVTH0      = '-7.233735e-15+dpvthn_hv25_snw'  
+K1         = 0.72096             
+K2         = '-0.028027666+dk2n_hv25_snw' 
+LK2        = '-1.4623361e-08+dlk2n_hv25_snw' 
+WK2        = '-1.0215964e-08+dwk2n_hv25_snw' 
+PK2        = '5.201063e-15+dpk2n_hv25_snw'   
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00014362352+dcitn_hv25_snw'
+LCIT       = '2.6680484e-10+dlcitn_hv25_snw'
+WCIT       = '3.8107218e-11+dwcitn_hv25_snw'
+PCIT       = '3.1658649e-17+dpcitn_hv25_snw'
+VOFF       = -0.1051917          LVOFF      = -2.8625772e-09      WVOFF      = -9.0655873e-09
+PVOFF      = 3.6376342e-15       NFACTOR    = 0.75                ETA0       = '-0.002042785+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '3.2121135e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0098021603       WETAB      = 2.9828953e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.031079424+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '9.2258309e-09+dlu0n_hv25_snw'
+WU0        = '-1.0633201e-09+dwu0n_hv25_snw'
+PU0        = '3.8913744e-15+dpu0n_hv25_snw'
+UA         = -1.1838355e-09      LUA        = 3.1804303e-16       WUA        = 1.0760286e-16
+PUA        = 2.397986e-22       
+UB         = 2.8519788e-18       
+LUB        = 1.3130201e-25  
+WUB        = -2.5140743e-25      
+PUB        = -1.394074e-31  
+UC         = '1.3517962e-10+ducn_hv25_snw' 
+LUC        = '4.8557871e-17+dlucn_hv25_snw' 
+WUC        = '-4.5292767e-17+dwucn_hv25_snw' 
+PUC        = '-1.647003e-24+dpucn_hv25_snw'  
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.631829+da0n_hv25_snw'  
+LA0        = '-1.3988524e-06+dla0n_hv25_snw' 
+WA0        = '9.46235e-09+dwa0n_hv25_snw'    
+PA0        = '-1.2436942e-13+dpa0n_hv25_snw' 
+AGS        = '0.41461947+dagsn_hv25_snw' 
+LAGS       = '1.687924e-07+dlagsn_hv25_snw'  
+WAGS       = '-2.6459865e-08+dwagsn_hv25_snw' 
+PAGS       = '4.10002e-14+dpagsn_hv25_snw'  
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.031996639+dketan_hv25_snw' 
+LKETA      = '-7.460465e-09+dlketan_hv25_snw' 
+WKETA      = '1.8250375e-09+dwketan_hv25_snw' 
+PKETA      = '-2.1288551e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.0017293789+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-7.9660291e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '3.5851924e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-2.7248101e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4064954e+09 
+PBGIDL   = 9.422214e-06   
+LBGIDL   = -15.522593 
+WBGIDL     = -77.389725          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0020909319        LTVOFF     = -1.9974936e-09      WTVOFF     = -4.6289958e-10
+PTVOFF     = 7.4539129e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26474403
+LKT1       = -5.1705255e-08      WKT1       = -5.0602247e-09      PKT1       = 1.4148105e-14
+KT1L       = 0                  
+KT2        = -0.025648252        
+LKT2       = -1.2405651e-08 
+WKT2       = -1.7119048e-08      
+PKT2       = -5.464875e-16       
+UTE        = -0.99653847
+LUTE       = -1.8622487e-08      WUTE       = 1.4400008e-10       PUTE       = -1.6017764e-14
+UA1        = 3.4032566e-09       LUA1       = 7.5874416e-16       WUA1       = -3.89223e-16
+PUA1       = 3.5901651e-23       UB1        = -4.122698e-18       LUB1       = -4.3225884e-26
+WUB1       = 5.5377274e-25       PUB1       = -4.2579456e-32
+UC1        = '-1.7286994e-10+duc1n_hv25_snw'
+LUC1       = '1.4709236e-16+dluc1n_hv25_snw'
+WUC1       = '6.4502251e-17+dwuc1n_hv25_snw'
+PUC1       = '8.7626402e-25+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 235827.57           LAT        = -0.13245844
+WAT        = 0.00098360183       PAT        = -9.422217e-09       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.9 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-(dxln_hv25_snw+dlmisn_hv25_snw)'    WMIN       = 6e-07               WMAX       = '1e-006-(dxwn_hv25_snw+dwmisn_hv25_snw)'
+XL         = '-1.5e-08+(dxln_hv25_snw+dlmisn_hv25_snw)'  XW         = '7e-09+(dxwn_hv25_snw+dwmisn_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxn_hv25_snw+toxmisn_hv25_snw)'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56718873+(dvthn_hv25_snw+vthmisn_hv25_snw)'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '1.8232216e-08+dlvthn_hv25_snw'  
+WVTH0      = '4.0651078e-08+dwvthn_hv25_snw'  
+PVTH0      = '-3.2572674e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '0.00596423+dk2n_hv25_snw'  
+LK2        = '-3.4314873e-08+dlk2n_hv25_snw' 
+WK2        = '-3.9243397e-08+dwk2n_hv25_snw' 
+PK2        = '2.2016659e-14+dpk2n_hv25_snw'  
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.00030429415+dcitn_hv25_snw'
+LCIT       = '5.2628355e-10+dlcitn_hv25_snw'
+WCIT       = '7.6233741e-10+dwcitn_hv25_snw'
+PCIT       = '-3.878879e-16+dpcitn_hv25_snw'
+VOFF       = -0.01579062         
+LVOFF      = -5.465262e-08       
+WVOFF      = -9.0584057e-08 
+PVOFF      = 5.0861284e-14       
+NFACTOR    = 0.75                ETA0       = '-0.0051352725+deta0n_hv25_snw'
+LETA0      = '1.791478e-09+dleta0n_hv25_snw'
+WETA0      = '9.34374e-09+dweta0n_hv25_snw'
+PETA0      = '-3.5520513e-15+dpeta0n_hv25_snw'
+ETAB       = -0.0098021603       WETAB      = 2.9828953e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '-0.0050681187+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '3.0166103e-08+dlu0n_hv25_snw'
+WU0        = '2.1835945e-08+dwu0n_hv25_snw'
+PU0        = '-9.3741698e-15+dpu0n_hv25_snw'
+UA         = -3.0092683e-09      LUA        = 1.3755162e-15       WUA        = 9.7877017e-16
+PUA        = -2.6486863e-22     
+UB         = 2.1142697e-18       
+LUB        = 5.5865688e-25 
+WUB        = 5.0211681e-25       
+PUB        = -5.7592393e-31 
+UC         = '2.1098788e-10+ducn_hv25_snw'
+LUC        = '4.6421442e-18+dlucn_hv25_snw'
+WUC        = '6.4263119e-17+dwucn_hv25_snw'
+PUC        = '-6.5112728e-23+dpucn_hv25_snw'
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '5.16666+da0n_hv25_snw'   
+LA0        = '-3.44658e-06+dla0n_hv25_snw'   
+WA0        = '-1.9073898e-06+dwa0n_hv25_snw' 
+PA0        = '9.8606318e-13+dpa0n_hv25_snw' 
+AGS        = '-1.8785318+dagsn_hv25_snw' 
+LAGS       = '1.497215e-06+dlagsn_hv25_snw'  
+WAGS       = '-6.5587953e-07+dwagsn_hv25_snw' 
+PAGS       = '4.0562309e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.02132804+dketan_hv25_snw' 
+LKETA      = '-1.3640783e-08+dlketan_hv25_snw' 
+WKETA      = '-9.0528161e-08+dwketan_hv25_snw' 
+PKETA      = '3.2211659e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '-0.0010274321+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '8.0041753e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '6.4000321e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-4.3554467e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.5238016e+09 
+PBGIDL   = 5.0671216e-05  
+LBGIDL   = -83.47812  
+WBGIDL     = -148.59463          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = -0.00044081598      LTVOFF     = -5.3085207e-10      WTVOFF     = 2.6757545e-10
+PTVOFF     = 3.2222711e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.46663637 
+LKT1       = 6.5250985e-08       
+WKT1       = 7.5022238e-08       
+PKT1       = -3.2243665e-14 
+KT1L       = 0                  
+KT2        = 0.023807743         
+LKT2       = -4.1055509e-08 
+WKT2       = -9.0301314e-08      
+PKT2       = 4.1847999e-14       
+UTE        = -1.8064983
+LUTE       = 4.5058726e-07       WUTE       = 7.9033623e-07       PUTE       = -4.7377612e-13
+UA1        = -8.9822497e-10      LUA1       = 3.2505924e-15       WUA1       = 3.3630817e-15
+PUA1       = -2.1378085e-21     
+UB1        = -7.7834337e-18      
+LUB1       = 2.0774383e-24 
+WUB1       = 2.299011e-24        
+PUB1       = -1.053596e-30 
+UC1        = '-1.6101782e-09+duc1n_hv25_snw' 
+LUC1       = '9.7972499e-16+dluc1n_hv25_snw' 
+WUC1       = '1.3401424e-15+dwuc1n_hv25_snw' 
+PUC1       = '-7.3810208e-22+dpuc1n_hv25_snw' 
+PRT        = 0                   AT         = 160587.12           LAT        = -0.088871641
+WAT        = -0.09103008         PAT        = 4.3881309e-08       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


**********************************************************************************************
*                                                                                            *
*                                   2.5V HVPMOS DEVICE MODELS                                *
*                                                                                            *
**********************************************************************************************

.ends nch_hv25_snw_mac

**********************************
*       Mismatch   model         * 
**********************************
.subckt pch_hv25_spw_mac n1 n2 n3 n4  l=length w=width multi=1 nf='1' scale='1' sigma='1'
+dmcg='1.245e-07' xw='+7e-09+dxwp_hv25_spw'
+ad='2*dmcg/scale*(w/nf+xw/scale)' as='2*dmcg/scale*(w/nf+xw/scale)'
+pd='4*dmcg/scale+2*(w/nf+xw/scale)' ps='4*dmcg/scale+2*(w/nf+xw/scale)'
+nrd='dmcg/scale/nf/(w/nf+xw/scale)' nrs='dmcg/scale/nf/(w/nf+xw/scale)'
+sa='0.46e-6/scale' sb='0.46e-6/scale' sd='2*dmcg/scale' sca='0e-6/scale' scb='0e-6/scale' scc='0e-6/scale'
+mismatchflag='1'
MAIN n1 n2 n3 n4 pch_hv25_spw w=w l=l ad=ad as=as pd=pd ps=ps nrd=nrd nrs=nrs m=multi nf=nf sa=sa sb=sb sd=sd sca=sca scb=scb scc=scc
**** mismatch ***
.param
+temp1=parp1_hv25_snw_spw  temp2=parp2_hv25_snw_spw
+fac1='0.955201*temp1*sigma+0.295958*temp2*sigma'
+fac2='0.955201*temp1*sigma-0.295958*temp2*sigma'
.param  lef='l*scale-1.5e-08'
+       wef='w/nf*scale+7e-09'
+       geo_fac ='1/sqrt(multi*nf*lef*wef*1e12)'
+       vthmisp_hv25_snw='0.00726065*geo_fac*fac1*mismatchflag'
+       dlmisp_hv25_snw='0.00238777*geo_fac*lef*fac2*mismatchflag'
+       dwmisp_hv25_snw='-0.00238777*geo_fac*wef*fac2*mismatchflag'
+       toxmisp_hv25_snw='0.00238777*geo_fac*toxp_hv25_spw*fac2*mismatchflag' 
.MODEL pch_hv25_spw.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = 0.000900001         WMIN       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = 0.000900001
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6442+(dvthp_hv25_spw+vthmisp_hv25_snw)' 
+LVTH0      = '0+dlvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.08232165+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '0+dwk2p_hv25_spw'        PK2        = '0+dpk2p_hv25_spw'
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0004148+dcitp_hv25_spw'
+LCIT       = '0+dlcitp_hv25_spw'       WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'
+VOFF       = '-0.0865+dvoffp_hv25_spw' LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '0+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.006848+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'
+ETAB       = -0.02432            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.0116+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '0+dlu0p_hv25_spw'        WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'
+UA         = 8.334e-10           UB         = 7.75794e-19         UC         = -2.033e-12
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'      A0         = '1.1746748+da0p_hv25_spw' LA0        = '0+dla0p_hv25_spw'
+WA0        = '0+dwa0p_hv25_spw'        PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3121+dagsp_hv25_spw' 
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.02279+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = 1e-05               PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.125               DELTA      = 0.005               PSCBE1     = 9.264e+08
+PSCBE2     = 1e-20               FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = 132                 RDW        = 1494                PRWG       = 0
+PRWB       = 0                   WR         = 1                  
+ALPHA0     = 4.408e-9 
+ALPHA1     = 5e-06               BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.836852e+09        
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = 0 
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.00164008         LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.3321398
+KT1L       = 0                  
+KT2        = -0.064              
+PKT2     = 0 
+WKT2     = 0 
+LKT2     = 0 
+UTE        = -1.11
+UA1        = 1.396008e-09        UB1        = -1.9674846e-18      LUB1       = 0
+WUB1       = 0                   PUB1       = 0                   UC1        = -7.169e-11
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'    WMIN       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = 0.000900001
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6464583+(dvthp_hv25_spw+vthmisp_hv25_snw)' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.1758676e-08+dlvthp_hv25_spw' 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.083168541+dk2p_hv25_spw' 
+LK2        = '8.1597909e-09+dlk2p_hv25_spw' 
+WK2        = '0+dwk2p_hv25_spw'        
+PK2        = '0+dpk2p_hv25_spw'        
+K3         = -2.3406
+K3B        = 2.028               W0         = 0                   DVT0       = 1.5477
+DVT1       = 0.15301             DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.22574
+MINV       = 0                   VOFFL      = -1.11e-09           DVTP0      = 0
+DVTP1      = 0                   LPE0       = 0                   LPEB       = 0
+XJ         = 1.6e-06             NGATE      = 1.842e+20           NDEP       = 7.81e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00039357392+dcitp_hv25_spw'
+LCIT       = '2.0451328e-10+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'      
+VOFF       = '-0.085975522+dvoffp_hv25_spw' 
+LVOFF      = '-5.053352e-09+dlvoffp_hv25_spw' 
+WVOFF      = '0+dwvoffp_hv25_spw'      
+PVOFF      = '0+dpvoffp_hv25_spw'      
+NFACTOR    = '0.5+dnfactorp_hv25_spw'
+LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'
+ETA0       = '0.006848+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'
+ETAB       = -0.02432            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.011675347+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '-7.2596536e-10+dlu0p_hv25_spw'
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'        UA         = 8.2448251e-10
+LUA        = 8.5919986e-17      
+UB         = 8.2361677e-19       
+PUB      = 0 
+WUB      = 0 
+LUB        = -4.6077234e-25 
+UC         = -4.9586313e-12      LUC        = 2.8188457e-17       VSAT       = '100090+dvsatp_hv25_spw'
+KVSAT    = 0.0  
+LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'
+A0         = '1.2235104+da0p_hv25_spw' 
+LA0        = '-4.7053122e-07+dla0p_hv25_spw' 
+WA0        = '0+dwa0p_hv25_spw'        
+PA0        = '0+dpa0p_hv25_spw'        
+AGS        = '0.33277669+dagsp_hv25_spw' 
+LAGS       = '-1.9921988e-07+dlagsp_hv25_spw' 
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = '-0.019854216+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA      = '-2.828628e-08+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.098675386+dpclmp_hv25_spw'
+LPCLM      = '1.2762652e-08+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = 9.9990511e-06       LPDIBLC2   = 9.1423011e-15       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8365868e+09       
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL     = 2.55509             
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0017957012       LTVOFF     = 1.4994105e-09
+WTVOFF     = 0                   PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.33251998         LKT1       = 3.6630623e-09       KT1L       = 0
+KT2        = -0.063905113        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = -9.1423e-10         
+UTE        = -1.098329
+LUTE       = -1.124503e-07       UA1        = 1.438989e-09        LUA1       = -4.1412173e-16
+UB1        = -2.0143922e-18      LUB1       = 4.5195495e-25       WUB1       = 0
+PUB1       = 0                   UC1        = -7.7851446e-11      LUC1       = 5.9365532e-17
+PRT        = 0                   AT         = 255674.15           LAT        = -0.22810042
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.3 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'  WMIN       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = 0.000900001
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.61303698+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-6.1481289e-09+dlvthp_hv25_spw' 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.055422101+dk2p_hv25_spw' 
+LK2        = '-1.5008486e-08+dlk2p_hv25_spw' 
+WK2        = '0+dwk2p_hv25_spw'        
+PK2        = '0+dpk2p_hv25_spw'        
+K3         = -2.3406
+K3B        = 2.028               W0         = 0                   DVT0       = 1.5477
+DVT1       = 0.15301             DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.22574
+MINV       = 0                   VOFFL      = -1.11e-09           DVTP0      = 0
+DVTP1      = 0                   LPE0       = 0                   LPEB       = 0
+XJ         = 1.6e-06             NGATE      = 1.842e+20           NDEP       = 7.81e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00068882917+dcitp_hv25_spw'
+LCIT       = '-4.2024854e-11+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'      
+VOFF       = '-0.10750902+dvoffp_hv25_spw' 
+LVOFF      = '1.292712e-08+dlvoffp_hv25_spw' 
+WVOFF      = '0+dwvoffp_hv25_spw'      
+PVOFF      = '0+dpvoffp_hv25_spw'      
+NFACTOR    = '0.5+dnfactorp_hv25_spw'
+LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'
+ETA0       = '0.0023308372+deta0p_hv25_spw'
+LETA0      = '3.7718309e-09+dleta0p_hv25_spw'
+WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02432
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.0099700819+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '6.9793076e-10+dlu0p_hv25_spw'
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'       
+UA         = 3.2122981e-10 
+PUA      = 0 
+WUA      = 0 
+LUA        = 5.0613599e-16       
+UB         = 6.9157942e-19       
+PUB      = 0 
+WUB      = 0 
+LUB        = -3.5052116e-25 
+UC         = 5.4042917e-11       LUC        = -2.1077835e-17     
+VSAT       = '100125.15+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '-2.9351401e-05+dlvsatp_hv25_spw' 
+WVSAT      = '0+dwvsatp_hv25_spw'      
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '0.87352452+da0p_hv25_spw' 
+LA0        = '-1.7829298e-07+dla0p_hv25_spw' 
+WA0        = '0+dwa0p_hv25_spw'        
+PA0        = '0+dpa0p_hv25_spw'        
+AGS        = '-2.4069189+dagsp_hv25_spw' 
+LAGS       = '2.0884259e-06+dlagsp_hv25_spw' 
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = '-0.074408394+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA      = '1.7266459e-08+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.11820286+dpclmp_hv25_spw'
+LPCLM      = '-3.5427858e-09+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = -0.00050816109      
+PPDIBLC2 = 0 
+WPDIBLC2 = 0 
+LPDIBLC2   = 4.3267286e-10       
+PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8385522e+09       
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL     = 0.914016            
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = 0.0009629125        LTVOFF     = -8.0403194e-10
+WTVOFF     = 0                   PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.32316898         
+PKT1     = 0 
+WKT1     = 0 
+LKT1       = -4.1450232e-09      
+KT1L       = 0
+KT2        = -0.068916663        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = 3.2704163e-09       
+UTE        = -1.2067583
+LUTE       = -2.1911792e-08      UA1        = 1.3112044e-09       LUA1       = -3.0742157e-16
+UB1        = -2.3619412e-18      
+PUB1     = 0 
+WUB1     = 0 
+LUB1       = 7.4215833e-25       
+UC1        = -2.9164208e-11
+LUC1       = 1.8711689e-17       PRT        = 0                  
+AT         = -1637.4997 
+LAT        = -0.013245188        
+WAT        = 0                   
+PAT        = 0 
+JSS        = 1.13e-07            JSWS       = 1e-14               JSWGS      = 5e-14
+NJS        = 1.00               
+NJD        = 1.007               
+IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   XJBVS      = 1                   XJBVD      = 1
+JSD        = 3.060E-06           
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12 
+BVD        = 16.8                
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10
+NJTSSWG    = 26.124              XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470 
+TNJTSSWG   = 0.14981             VTSSWGS    = 20                  VTSSWGD    = 20
+PBS        = 0.7                
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'
+MJS        = 0.31                PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'
+MJSWS      = 0.082               PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'
+MJSWGS     = 0.35                CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29 
+PBSWD      = 0.4                 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18 
+PBSWGD     = 0.8                 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62 
+TPB        = 1.35E-03            
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04 
+TCJSW      = 3.00E-04            
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03 
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.245e-07
+DMCI       = 3.05e-07            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.3e-08
+RSHG       = 14.93               GBMIN      = 1e-12               RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1                  
+FNOIMOD    = 1 
+NOIA       = 1.5e+41             
+NOIB       = 0.5e+025            
+NOIC       = 1e7     
+EM         = 1.9e+7              
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.4 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = 0.000900001         WMIN       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.64345035+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '0+dlvthp_hv25_spw'       
+WVTH0      = '-7.5018037e-09+dwvthp_hv25_spw' 
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415             K2         = '-0.082607151+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '2.8570113e-09+dwk2p_hv25_spw'
+PK2        = '0+dpk2p_hv25_spw'        K3         = -2.3406             K3B        = 2.028
+W0         = 0                   DVT0       = 1.5477              DVT1       = 0.15301
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.22574             MINV       = 0
+VOFFL      = -1.11e-09           DVTP0      = 0                   DVTP1      = 0
+LPE0       = 0                   LPEB       = 0                   XJ         = 1.6e-06
+NGATE      = 1.842e+20           NDEP       = 7.81e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00046065207+dcitp_hv25_spw'
+LCIT       = '0+dlcitp_hv25_spw'       WCIT       = '-4.5884163e-10+dwcitp_hv25_spw'
+PCIT       = '0+dpcitp_hv25_spw'       VOFF       = '-0.085646288+dvoffp_hv25_spw'
+LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '-8.5430982e-09+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0066149354+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '2.332277e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.024623219        WETAB      = 3.0343114e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011567552+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '0+dlu0p_hv25_spw'        WU0        = '3.2470491e-10+dwu0p_hv25_spw'
+PU0        = '0+dpu0p_hv25_spw'        UA         = 8.6781702e-10       WUA        = -3.4441114e-16
+UB         = 7.5548315e-19       WUB        = 2.0325072e-25       UC         = -1.4744507e-12
+WUC        = -5.5894032e-18      VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'
+KVSAT    = 0.0  
+WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'      A0         = '1.1735196+da0p_hv25_spw'
+LA0        = '0+dla0p_hv25_spw'        WA0        = '1.1560816e-08+dwa0p_hv25_spw'
+PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3103881+dagsp_hv25_spw'  
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '1.7130983e-08+dwagsp_hv25_spw' 
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0                   A2         = 0.5
+B0         = 0                   B1         = 0
+KETA       = '-0.023852944+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+WKETA      = '1.0636885e-08+dwketap_hv25_spw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'      WPCLM      = '0+dwpclmp_hv25_spw'
+PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0                   PDIBLC2    = 1e-05
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.125
+DELTA      = 0.005               PSCBE1     = 9.264e+08           PSCBE2     = 1e-20
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55               RSW        = 132
+RDW        = 1494                PRWG       = 0                   PRWB       = 0
+WR         = 1                  
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06
+BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8394845e+09       
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -26.343354          
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0014210886       LTVOFF     = 0
+WTVOFF     = -2.1914473e-09      PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.32992071         WKT1       = -2.2206419e-08      KT1L       = 0
+KT2        = -0.064129743        
+PKT2     = 0 
+LKT2     = 0 
+WKT2       = 1.298338e-09        
+UTE        = -1.1084336
+WUTE       = -1.567541e-08       UA1        = 1.3822259e-09       WUA1       = 1.379171e-16
+UB1        = -1.9969204e-18      LUB1       = 0                   WUB1       = 2.9456425e-25
+PUB1       = 0                  
+UC1        = -7.7090318e-11      
+PUC1     = 0 
+LUC1     = 0 
+WUC1       = 5.404097e-17  
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.5 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'    WMIN       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.64575005+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.2157617e-08+dlvthp_hv25_spw' 
+WVTH0      = '-7.0874606e-09+dwvthp_hv25_spw' 
+PVTH0      = '-3.992188e-15+dpvthp_hv25_spw'  
+K1         = 0.77415            
+K2         = '-0.083597915+dk2p_hv25_spw' 
+LK2        = '9.546009e-09+dlk2p_hv25_spw' 
+WK2        = '4.2967504e-09+dwk2p_hv25_spw' 
+PK2        = '-1.3871885e-14+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00044123614+dcitp_hv25_spw'
+LCIT       = '1.8707246e-10+dlcitp_hv25_spw'
+WCIT       = '-4.7695583e-10+dwcitp_hv25_spw'
+PCIT       = '1.7453027e-16+dpcitp_hv25_spw'
+VOFF       = '-0.085078901+dvoffp_hv25_spw' 
+LVOFF      = '-5.4667641e-09+dlvoffp_hv25_spw' 
+WVOFF      = '-8.9724718e-09+dwvoffp_hv25_spw' 
+PVOFF      = '4.137011e-15+dpvoffp_hv25_spw'  
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0066149354+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '2.332277e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.024623219        WETAB      = 3.0343114e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011661877+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '-9.0882215e-10+dlu0p_hv25_spw'
+WU0        = '1.3478816e-10+dwu0p_hv25_spw'
+PU0        = '1.829848e-15+dpu0p_hv25_spw'
+UA         = 8.6340336e-10       
+LUA        = 4.2525664e-17       
+WUA        = -3.8948089e-16 
+PUA        = 4.3424698e-22       
+UB         = 8.0349339e-19       
+LUB        = -4.6257876e-25 
+WUB        = 2.0137456e-25       
+PUB        = 1.8076838e-32       
+UC         = -4.4689633e-12
+LUC        = 2.8852129e-17       WUC        = -4.9001076e-18      PUC        = -6.6413631e-24
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '1.2235888+da0p_hv25_spw' 
+LA0        = '-4.8241738e-07+dla0p_hv25_spw' 
+WA0        = '-7.84261e-10+dwa0p_hv25_spw'  
+PA0        = '1.1894482e-13+dpa0p_hv25_spw' 
+AGS        = '0.33792906+dagsp_hv25_spw' 
+LAGS       = '-2.653572e-07+dlagsp_hv25_spw'  
+WAGS       = '-5.1559855e-08+dwagsp_hv25_spw' 
+PAGS       = '6.618362e-13+dpagsp_hv25_spw'  
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.020950178+dketap_hv25_spw'
+LKETA      = '-2.7968151e-08+dlketap_hv25_spw'
+WKETA      = '1.0967297e-08+dwketap_hv25_spw'
+PKETA      = '-3.1835141e-15+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.098633344+dpclmp_hv25_spw'
+LPCLM      = '1.316773e-08+dlpclmp_hv25_spw'
+WPCLM      = '4.207168e-10+dwpclmp_hv25_spw'
+PPCLM      = '-4.0536063e-15+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = 1.0002555e-05       LPDIBLC2   = -2.4614122e-14
+WPDIBLC2   = -3.5059733e-14      PPDIBLC2   = 3.3780053e-19       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8391677e+09       
+LBGIDL     = 3.051889            
+WBGIDL     = -25.827376 
+PBGIDL     = -4.971461e-06       
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.0015665472       LTVOFF     = 1.4014942e-09       WTVOFF     = -2.2931441e-09
+PTVOFF     = 9.7984913e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.33008289
+LKT1       = 1.562568e-09        WKT1       = -2.4388012e-08      PKT1       = 2.1019646e-14
+KT1L       = 0                  
+KT2        = -0.064096056        
+LKT2       = -3.245759e-10  
+WKT2       = 1.910758e-09        
+PKT2       = -5.900666e-15       
+UTE        = -1.0976437
+LUTE       = -1.0396005e-07      WUTE       = -6.8573555e-09      PUTE       = -8.4961951e-14
+UA1        = 1.4183791e-09       LUA1       = -3.4833558e-16      WUA1       = 2.0624321e-16
+PUA1       = -6.5832208e-22      UB1        = -2.0375734e-18      LUB1       = 3.9169107e-25
+WUB1       = 2.3197362e-25       PUB1       = 6.0306067e-31      
+UC1        = -8.3567717e-11 
+LUC1       = 6.2409748e-17       
+WUC1       = 5.7202725e-17       
+PUC1       = -3.046346e-23  
+PRT        = 0                   AT         = 255562.67           LAT        = -0.22702635
+WAT        = 0.0011155412        PAT        = -1.0748202e-08      JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.6 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'  WMIN       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'    WMAX       = '1e-005-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.61206792+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-5.9669626e-09+dlvthp_hv25_spw' 
+WVTH0      = '-9.6973494e-09+dwvthp_hv25_spw' 
+PVTH0      = '-1.8129302e-15+dpvthp_hv25_spw' 
+K1         = 0.77415            
+K2         = '-0.053177777+dk2p_hv25_spw' 
+LK2        = '-1.5854807e-08+dlk2p_hv25_spw' 
+WK2        = '-2.2458953e-08+dwk2p_hv25_spw' 
+PK2        = '8.4691269e-15+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00071983749+dcitp_hv25_spw'
+LCIT       = '-4.5559673e-11+dlcitp_hv25_spw'
+WCIT       = '-3.1030033e-10+dwcitp_hv25_spw'
+PCIT       = '3.5372933e-17+dpcitp_hv25_spw'
+VOFF       = '-0.10705435+dvoffp_hv25_spw' 
+LVOFF      = '1.2882738e-08+dlvoffp_hv25_spw' 
+WVOFF      = '-4.549857e-09+dwvoffp_hv25_spw' 
+PVOFF      = '4.441281e-16+dpvoffp_hv25_spw'   
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0018533543+deta0p_hv25_spw'
+LETA0      = '3.9759202e-09+dleta0p_hv25_spw'
+WETA0      = '4.778171e-09+dweta0p_hv25_spw'
+PETA0      = '-2.0423215e-15+dpeta0p_hv25_spw'
+ETAB       = -0.024623219        WETAB      = 3.0343114e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.0097261642+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '7.0749829e-10+dlu0p_hv25_spw'
+WU0        = '2.4408843e-09+dwu0p_hv25_spw'
+PU0        = '-9.5742337e-17+dpu0p_hv25_spw'
+UA         = 3.0814582e-10       
+LUA        = 5.061657e-16        
+WUA        = 1.3093138e-16 
+PUA        = -2.97265e-25        
+UB         = 6.5583563e-19       
+LUB        = -3.3928452e-25 
+WUB        = 3.5768821e-25       
+PUB        = -1.1244506e-31      
+UC         = 5.5202067e-11
+LUC        = -2.0973181e-17      WUC        = -1.1599617e-17      PUC        = -1.0472732e-24
+VSAT       = '100125.17+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '-2.93663e-05+dlvsatp_hv25_spw'   
+WVSAT      = '-1.785e-07+dwvsatp_hv25_spw'    
+PVSAT      = '1.492e-13+dpvsatp_hv25_spw'     
+A0         = '0.88566989+da0p_hv25_spw' 
+LA0        = '-2.0025508e-07+dla0p_hv25_spw' 
+WA0        = '-1.2153872e-07+dwa0p_hv25_spw' 
+PA0        = '2.197748e-13+dpa0p_hv25_spw'  
+AGS        = '-2.7332125+dagsp_hv25_spw' 
+LAGS       = '2.299046e-06+dlagsp_hv25_spw'  
+WAGS       = '3.2652199e-06+dwagsp_hv25_spw' 
+PAGS       = '-2.107675e-12+dpagsp_hv25_spw'  
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.075485777+dketap_hv25_spw'
+LKETA      = '1.7569074e-08+dlketap_hv25_spw'
+WKETA      = '1.0781372e-08+dwketap_hv25_spw'
+PKETA      = '-3.0282673e-15+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.11907437+dpclmp_hv25_spw'
+LPCLM      = '-3.9005241e-09+dlpclmp_hv25_spw'
+WPCLM      = '-8.7211918e-09+dwpclmp_hv25_spw'
+PPCLM      = '3.5798873e-15+dppclmp_hv25_spw'
+PDIBLC1    = 0                  
+PDIBLC2    = -0.00049892196      
+LPDIBLC2   = 4.2492736e-10 
+WPDIBLC2   = -9.2455896e-11      
+PPDIBLC2   = 7.7509197e-17       
+PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8413607e+09       
+LBGIDL     = 1.220821            
+WBGIDL     = -28.104337 
+PBGIDL     = -3.070195e-06       
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = 0.00105037          LTVOFF     = -7.8363171e-10      WTVOFF     = -8.7518704e-10
+PTVOFF     = -2.0414503e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.32447187 
+LKT1       = -3.1226367e-09      
+WKT1       = 1.3037938e-08       
+PKT1       = -1.0231022e-14 
+KT1L       = 0                  
+KT2        = -0.068293082        
+LKT2       = 3.1799411e-09 
+WKT2       = -6.24021e-09        
+PKT2       = 9.053923e-16        
+UTE        = -1.1916543
+LUTE       = -2.5461248e-08      WUTE       = -1.511464e-07       PUTE       = 3.5519405e-14
+UA1        = 1.4717343e-09       LUA1       = -3.9288719e-16      WUA1       = -1.6064233e-15
+PUA1       = 8.5525444e-22      
+UB1        = -2.6267678e-18      
+LUB1       = 8.8366834e-25 
+WUB1       = 2.6501189e-24       
+PUB1       = -1.4160907e-30      
+UC1        = -2.8459174e-11 
+LUC1       = 1.6394114e-17       
+WUC1       = -7.05528e-18        
+PUC1       = 2.3191974e-23 
+PRT        = 0                  
+AT         = 260.41626           
+LAT        = -0.013848961 
+WAT        = -0.01899244         
+PAT        = 6.041959e-09        
+JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.7 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = 0.000900001         WMIN       = 6e-07               WMAX       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6505965+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '0+dlvthp_hv25_spw'       
+WVTH0      = '-3.056245e-10+dwvthp_hv25_spw' 
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415             K2         = '-0.08095365+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '1.1919356e-09+dwk2p_hv25_spw'
+PK2        = '0+dpk2p_hv25_spw'        K3         = -2.3406             K3B        = 2.028
+W0         = 0                   DVT0       = 1.5477              DVT1       = 0.15301
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.22574             MINV       = 0
+VOFFL      = -1.11e-09           DVTP0      = 0                   DVTP1      = 0
+LPE0       = 0                   LPEB       = 0                   XJ         = 1.6e-06
+NGATE      = 1.842e+20           NDEP       = 7.81e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '5e-06+dcitp_hv25_spw'    LCIT       = '0+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'       VOFF       = '-0.09840935+dvoffp_hv25_spw'
+LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '4.3093055e-09+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0078338475+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '1.1048326e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02777105         WETAB      = 6.2041774e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.01189+du0p_hv25_spw'   LU0        = '0+dlu0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'        UA         = 7.3142125e-10
+WUA        = -2.070606e-16       UB         = 9.3050526e-19       WUB        = 2.7003453e-26
+UC         = -4.9627175e-12      WUC        = -2.0767185e-18      VSAT       = '100090+dvsatp_hv25_spw'
+KVSAT    = 0.0  
+LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'
+A0         = '1.1243+da0p_hv25_spw'    LA0        = '0+dla0p_hv25_spw'        WA0        = '6.11249e-08+dwa0p_hv25_spw'
+PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3246685+dagsp_hv25_spw' 
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '2.75062e-09+dwagsp_hv25_spw'    
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0                   A2         = 0.5
+B0         = 0                   B1         = 0
+KETA       = '-0.01842522+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+WKETA      = '5.1711665e-09+dwketap_hv25_spw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'      WPCLM      = '0+dwpclmp_hv25_spw'
+PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0                   PDIBLC2    = 1e-05
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.125
+DELTA      = 0.005               PSCBE1     = 9.264e+08           PSCBE2     = 1e-20
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55               RSW        = 132
+RDW        = 1494                PRWG       = 0                   PRWB       = 0
+WR         = 1                  
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06
+BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8487188e+09       
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -35.642327          
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0077185505       LTVOFF     = 0
+WTVOFF     = 4.1500969e-09       PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.43539899         WKT1       = 8.4010209e-08       KT1L       = 0
+KT2        = -0.066840985        
+PKT2     = 0 
+LKT2     = 0 
+WKT2       = 4.028559e-09        
+UTE        = -1.04509
+WUTE       = -7.946237e-08       UA1        = 1.6192357e-09       WUA1       = -1.0075176e-16
+UB1        = -1.2508264e-18      LUB1       = 0                   WUB1       = -4.567525e-25
+PUB1       = 0                  
+UC1        = -4.160162e-11       
+PUC1     = 0 
+LUC1     = 0 
+WUC1       = 1.830385e-17   
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.8 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'
+LMAX       = '1e-005-(dxlp_hv25_spw+dlmisp_hv25_snw)'    WMIN       = 6e-07               WMAX       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.65367204+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.963285e-08+dlvthp_hv25_spw'  
+WVTH0      = '8.8999034e-10+dwvthp_hv25_spw'  
+PVTH0      = '-1.1519749e-14+dpvthp_hv25_spw' 
+K1         = 0.77415             K2         = '-0.080741289+dk2p_hv25_spw'
+LK2        = '-2.0461011e-09+dlk2p_hv25_spw'
+WK2        = '1.4201276e-09+dwk2p_hv25_spw'
+PK2        = '-2.1986302e-15+dpk2p_hv25_spw'
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '-5.6522539e-05+dcitp_hv25_spw'
+LCIT       = '5.9276966e-10+dlcitp_hv25_spw'
+WCIT       = '2.4287163e-11+dwcitp_hv25_spw'
+PCIT       = '-2.3400681e-16+dpcitp_hv25_spw'
+VOFF       = '-0.10051086+dvoffp_hv25_spw'  
+LVOFF      = '2.0248044e-08+dlvoffp_hv25_spw'  
+WVOFF      = '6.5675098e-09+dwvoffp_hv25_spw' 
+PVOFF      = '-2.1757799e-14+dpvoffp_hv25_spw' 
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0078338475+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '1.1048326e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02777105         WETAB      = 6.2041774e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011841299+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '4.6923921e-10+dlu0p_hv25_spw'
+WU0        = '-4.5888963e-11+dwu0p_hv25_spw'
+PU0        = '4.4214016e-16+dpu0p_hv25_spw'
+UA         = 6.9516704e-10       
+LUA        = 3.4930927e-16       
+WUA        = -2.2006692e-16 
+PUA        = 1.2531589e-22       
+UB         = 9.6668554e-19       
+LUB        = -3.4859701e-25 
+WUB        = 3.7040068e-26       
+PUB        = -9.6702792e-32      
+UC         = -1.0203788e-11
+LUC        = 5.0497711e-17       WUC        = 8.7486055e-19       PUC        = -2.8438464e-23
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '1.1487502+da0p_hv25_spw' 
+LA0        = '-2.3557704e-07+dla0p_hv25_spw' 
+WA0        = '7.4578287e-08+dwa0p_hv25_spw' 
+PA0        = '-1.2962338e-13+dpa0p_hv25_spw' 
+AGS        = '0.26893051+dagsp_hv25_spw' 
+LAGS       = '5.370355e-07+dlagsp_hv25_spw'  
+WAGS       = '1.792169e-08+dwagsp_hv25_spw'   
+PAGS       = '-1.4617325e-13+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.013740616+dketap_hv25_spw'
+LKETA      = '-4.5136162e-08+dlketap_hv25_spw'
+WKETA      = '3.7072669e-09+dwketap_hv25_spw'
+PKETA      = '1.4104673e-14+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.097611236+dpclmp_hv25_spw'
+LPCLM      = '2.3015743e-08+dlpclmp_hv25_spw'
+WPCLM      = '1.4499799e-09+dwpclmp_hv25_spw'
+PPCLM      = '-1.3970556e-14+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = 9.918782e-06        LPDIBLC2   = 7.8253527e-13
+WPDIBLC2   = 4.9299316e-14       PPDIBLC2   = -4.7499891e-19      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8498584e+09       
+LBGIDL     = -10.979692          
+WBGIDL     = -36.592851 
+PBGIDL     = 9.158342e-06        
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.008048839        LTVOFF     = 3.1823294e-09       WTVOFF     = 4.2345237e-09
+PTVOFF     = -8.13452e-16        TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.43957731
+LKT1       = 4.0258064e-08       WKT1       = 8.5872868e-08       PKT1       = -1.7946719e-14
+KT1L       = 0                  
+KT2        = -0.066003516        
+LKT2       = -8.069012e-09 
+WKT2       = 3.831571e-09        
+PKT2       = 1.89798e-15         
+UTE        = -1.0203598
+LUTE       = -2.382758e-07       WUTE       = -8.4682298e-08      PUTE       = 5.0294002e-14
+UA1        = 1.7590987e-09       LUA1       = -1.3475799e-15      WUA1       = -1.3686146e-16
+PUA1       = 3.4791691e-22       UB1        = -1.3906555e-18      LUB1       = 1.3472542e-24
+WUB1       = -4.1947264e-25      PUB1       = -3.5919144e-31     
+UC1        = -4.089859e-11 
+LUC1       = -6.77362e-18        
+WUC1       = 1.423492e-17        
+PUC1       = 3.920417e-23  
+PRT        = 0                   AT         = 255662.53           LAT        = -0.22798842
+WAT        = 0.0010149903        PAT        = -9.779388e-09       JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.9 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-(dxlp_hv25_spw+dlmisp_hv25_snw)'  WMIN       = 6e-07               WMAX       = '1e-006-(dxwp_hv25_spw+dwmisp_hv25_snw)'
+XL         = '-1.5e-08+(dxlp_hv25_spw+dlmisp_hv25_snw)'  XW         = '7e-09+(dxwp_hv25_spw+dwmisp_hv25_snw)'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = '(toxp_hv25_spw+toxmisp_hv25_snw)'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.60744212+(dvthp_hv25_spw+vthmisp_hv25_snw)'
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-8.9691367e-09+dlvthp_hv25_spw' 
+WVTH0      = '-1.4355527e-08+dwvthp_hv25_spw' 
+PVTH0      = '1.2102586e-15+dpvthp_hv25_spw'  
+K1         = 0.77415            
+K2         = '-0.071926411+dk2p_hv25_spw' 
+LK2        = '-9.4065238e-09+dlk2p_hv25_spw' 
+WK2        = '-3.5790776e-09+dwk2p_hv25_spw' 
+PK2        = '1.9757061e-15+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00069636579+dcitp_hv25_spw'
+LCIT       = '-3.5892087e-11+dlcitp_hv25_spw'
+WCIT       = '-2.8666432e-10+dwcitp_hv25_spw'
+PCIT       = '2.5637674e-17+dpcitp_hv25_spw'
+VOFF       = '-0.085611855+dvoffp_hv25_spw' 
+LVOFF      = '7.80737e-09+dlvoffp_hv25_spw'   
+WVOFF      = '-2.6142459e-08+dwvoffp_hv25_spw' 
+PVOFF      = '5.5550242e-15+dpvoffp_hv25_spw'  
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0071615325+deta0p_hv25_spw'
+LETA0      = '5.6138303e-10+dleta0p_hv25_spw'
+WETA0      = '-5.6716436e-10+dweta0p_hv25_spw'
+PETA0      = '1.3961174e-15+dpeta0p_hv25_spw'
+ETAB       = -0.02777105         WETAB      = 6.2041774e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.010301257+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '1.755174e-09+dlu0p_hv25_spw'
+WU0        = '1.861766e-09+dwu0p_hv25_spw'
+PU0        = '-1.1507518e-15+dpu0p_hv25_spw'
+UA         = 1.969934e-11        
+LUA        = 9.1332481e-16       
+WUA        = 4.21397e-16  
+PUA        = -4.1030648e-22      
+UB         = 1.2517635e-18       
+LUB        = -5.866371e-25  
+WUB        = -2.4241117e-25      
+PUB        = 1.3663899e-31       
+UC         = 8.1280474e-11
+LUC        = -2.5891648e-17      WUC        = -3.7860572e-17      PUC        = 3.9056223e-24
+VSAT       = '97152.829+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '0.0024525374+dlvsatp_hv25_spw' 
+WVSAT      = '0.0029929677+dwvsatp_hv25_spw' 
+PVSAT      = '-2.499128e-09+dpvsatp_hv25_spw' 
+A0         = '0.62114912+da0p_hv25_spw'  
+LA0        = '2.0496981e-07+dla0p_hv25_spw'  
+WA0        = '1.4483368e-07+dwa0p_hv25_spw'  
+PA0        = '-1.8828667e-13+dpa0p_hv25_spw' 
+AGS        = '0.2741672+dagsp_hv25_spw'   
+LAGS       = '5.3266282e-07+dlagsp_hv25_spw'  
+WAGS       = '2.3678862e-07+dwagsp_hv25_spw'  
+PAGS       = '-3.2892711e-13+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.085108059+dketap_hv25_spw' 
+LKETA      = '1.4455652e-08+dlketap_hv25_spw' 
+WKETA      = '2.047101e-08+dwketap_hv25_spw' 
+PKETA      = '1.069486e-16+dpketap_hv25_spw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.12621674+dpclmp_hv25_spw'
+LPCLM      = '-8.6985116e-10+dlpclmp_hv25_spw'
+WPCLM      = '-1.591356e-08+dwpclmp_hv25_spw'
+PPCLM      = '5.2799965e-16+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = -0.00067619849      LPDIBLC2   = 5.7369046e-10
+WPDIBLC2   = 8.6061567e-11       PPDIBLC2   = -7.2295242e-17      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8388983e+09       
+LBGIDL     = -1.828032           
+WBGIDL     = -25.624782 
+PBGIDL     = 0                   
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.0019375589       LTVOFF     = -1.9205895e-09      WTVOFF     = 2.1336573e-09
+PTVOFF     = 9.4077142e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.36922828
+LKT1       = -1.8483369e-08      WKT1       = 5.8107654e-08       PKT1       = 5.2372351e-15
+KT1L       = 0                   KT2        = -0.081154493        LKT2       = 4.5820536e-09
+WKT2       = 6.7112301e-09       PKT2       = -5.0653522e-16      UTE        = -1.4618981
+LUTE       = 1.3040868e-07       WUTE       = 1.209891e-07        PUTE       = -1.2144161e-13
+UA1        = -1.5936537e-09      LUA1       = 1.4519685e-15       WUA1       = 1.4804225e-15
+PUA1       = -1.0025152e-21     
+UB1        = 2.2580494e-18       
+LUB1       = -1.6994145e-24 
+WUB1       = -2.2688921e-24      
+PUB1       = 1.1850737e-30       
+UC1        = -1.4591413e-10 
+LUC1       = 8.0914363e-17       
+WUC1       = 1.1122185e-16       
+PUC1       = -4.1779916e-23 
+PRT        = 0                  
+AT         = -4411.3745          
+LAT        = -0.010826715 
+WAT        = -0.014287945        
+PAT        = 2.9985581e-09       
+JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.ends pch_hv25_spw_mac

.ENDL MAC_hv25_snw_spw





***************************************************************
*                                                             *
*                     Standard-vt DEVICE MODELS               *
*                                                             *
***************************************************************
.LIB MOS
**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln'
+LMAX       = 2.00001e-05         WMIN       = '1e-005-dxwn'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3971583+dvthn'   K1         = 0.31994
+K2         = '0.022565+dk2n'     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 0.001               VOFF       = -0.1282             NFACTOR    = '0.75+dnfactorn'
+ETA0       = '0.10102+deta0n'    ETAB       = -0.08565            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'      UA         = -1.683e-009
+UB         = 2.412312e-018       UC         = 1.289e-010          VSAT       = '110000+dvsatn'
+A0         = 2.203               AGS        = 0.8591              A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05109            DWG        = 0                   DWB        = 0
+PCLM       = 0.2722              PDIBLC1    = 0                   PDIBLC2    = '0.002415+dpdiblc2n'
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.001375            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2154432
+KT1L       = 0                   KT2        = -0.07264            UTE        = -1.379
+UA1        = 1.6e-009            UB1        = -1.44628e-018       UC1        = 3.03e-013
+PRT        = 0                   AT         = 200000
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'      LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln'
+LMAX       = '1e-005-dxln'       WMIN       = '1e-005-dxwn'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39304444+dvthn'  LVTH0      = '4.099508e-008+dlvthn'
+K1         = 0.31994             K2         = '0.023370867+dk2n'  LK2        = -8.0305518e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00098244461
+LCIT       = '1.7494141e-010+dlcitn'
+VOFF       = -0.1255394          LVOFF      = '-2.65132e-008+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10102+deta0n'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'
+UA         = -1.7047351e-009     LUA        = 2.1659301e-016      UB         = 2.4380817e-018
+LUB        = -2.5679813e-025     UC         = 1.3000452e-010      LUC        = -1.1006611e-017
+VSAT       = '110000+dvsatn'     A0         = 2.2653681           LA0        = '-6.2150487e-007+dla0n'
+AGS        = 0.81477464          LAGS       = 4.4170706e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04934744         LKETA      = -1.7364799e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0025667367+dpdiblc2n'
+LPDIBLC2   = -1.5120733e-009     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0013986988
+LTVOFF     = -2.3616127e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21318399         LKT1       = -2.2513329e-008     KT1L       = 0
+KT2        = -0.071975146        LKT2       = -6.6253388e-009     UTE        = -1.3590544
+LUTE       = -1.9876016e-007     UA1        = 1.662196e-009       LUA1       = -6.1978976e-016
+UB1        = -1.4469534e-018     LUB1       = 6.7108271e-027      UC1        = -3.5356714e-012
+LUC1       = 3.8252783e-017      PRT        = 0                   AT         = 201072.34
+LAT        = -0.01068603
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln'
+LMAX       = '1.000002e-006-dxln'
+WMIN       = '1e-005-dxwn'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43676534+dvthn'  LVTH0      = '-1.2003913e-009+dlvthn'
+K1         = 0.31994             K2         = '0.021314478+dk2n'  LK2        = -6.0459107e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010868883
+LCIT       = '7.4141765e-011+dlcitn'
+VOFF       = -0.15239595         LVOFF      = '-5.9367112e-010+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10102+deta0n'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'
+UA         = -1.5453265e-009     LUA        = 6.2746135e-017      UB         = 2.269578e-018
+LUB        = -9.4173528e-026     UC         = 1.2925162e-010      LUC        = -1.0279988e-017
+VSAT       = '113946.42+dvsatn'  LVSAT      = '-0.0038087297+dlvsatn'
+A0         = 2.2094596           LA0        = '-5.6754699e-007+dla0n'
+AGS        = 0.42887173          LAGS       = 8.1414582e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073052413        LKETA      = 5.5131064e-009      DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0012164964+dpdiblc2n'
+LPDIBLC2   = -2.0894285e-010     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012118355
+LTVOFF     = -5.5817591e-011     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.22714346         LKT1       = -9.0408975e-009     KT1L       = 0
+KT2        = -0.075960598        LKT2       = -2.7789399e-009     UTE        = -1.5971652
+LUTE       = 3.1042938e-008      UA1        = 1.1007222e-009      LUA1       = -7.7905835e-017
+UB1        = -1.5451554e-018     LUB1       = 1.0148653e-025      UC1        = 1.2934884e-011
+LUC1       = 2.2356885e-017      PRT        = 0                   AT         = 234845.69
+LAT        = -0.043281019
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          LU0        = '0+dlu0n'           WU0        = '0+dwu0n'
+PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'         WETA0      = '0+dweta0n'
+PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln'
+LMAX       = '2.399959e-007-dxln'
+WMIN       = '1e-005-dxwn'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44301989+dvthn'  LVTH0      = '-2.6263045e-009+dlvthn'
+K1         = 0.31994             K2         = '0.0060518885+dk2n' LK2        = -2.5663454e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00089174876
+LCIT       = '1.1862968e-010+dlcitn'
+VOFF       = -0.13778537         LVOFF      = '-3.9245908e-009+dlvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.1010175+deta0n'  LETA0      = '5.6985851e-013+dleta0n'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021399889+du0n'  LU0        = '4.7901151e-011+dlu0n'
+UA         = -1.318498e-009      LUA        = 1.1033782e-017      UB         = 1.9551074e-018
+LUB        = -2.2480505e-026     UC         = 8.770291e-011       LUC        = -8.077125e-019
+VSAT       = '101196.2+dvsatn'   LVSAT      = '-0.0009019344+dlvsatn'
+A0         = 0.76497717          LA0        = '-2.3823389e-007+dla0n'
+AGS        = 3.2754786           LAGS       = 1.6517638e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073974665        LKETA      = 5.7233616e-009      DWG        = 0
+DWB        = 0                   PCLM       = -0.03535932         LPCLM      = 7.0117374e-008
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020716496+dpdiblc2n'
+LPDIBLC2   = 1.1562347e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00087063866
+LTVOFF     = 2.1968459e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.25962724         LKT1       = -1.6352462e-009     KT1L       = 0
+KT2        = -0.10603119         LKT2       = 4.0765531e-009      UTE        = -1.5964855
+LUTE       = 3.0887983e-008      UA1        = 8.2927857e-010      LUA1       = -1.6022109e-017
+UB1        = -1.389084e-018      LUB1       = 6.5905376e-026      UC1        = 1.2396893e-010
+LUC1       = -2.9566572e-018     PRT        = 0                   AT         = 54781.038
+LAT        = -0.0022298811
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+WETA0      = '0+dweta0n'         PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln'
+WMIN       = '1e-005-dxwn'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41002329+dvthn'  LVTH0      = '5.3414286e-010+dlvthn'
+K1         = 0.31994             K2         = '-0.00024866313+dk2n'
+LK2        = -1.9628723e-009     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = -6.5754395e-005     LCIT       = '2.1034029e-010+dlcitn'
+VOFF       = -0.13659885         LVOFF      = '-4.0382368e-009+dlvoffn'
+NFACTOR    = '0.75+dnfactorn-0.320672*ss_flag+0.320672*ff_flag'
+ETA0       = '0.00050744458+deta0n'
+LETA0      = '9.6275235e-009+dleta0n'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021162477+du0n'  LU0        = '7.0640674e-011+dlu0n'
+UA         = -1.3961783e-009     LUA        = 1.8474072e-017      UB         = 1.7190372e-018
+LUB        = 1.3053168e-028      UC         = 1.2291211e-010      LUC        = -4.1800851e-018
+VSAT       = '85039.349+dvsatn+962.017*ff_flag'
+LVSAT      = '0.00064558489+dlvsatn-9.21423e-05*ff_flag'
+A0         = 1.4250678           LA0        = '-3.0145803e-007+dla0n'
+AGS        = 3.3966895           LAGS       = 1.5356668e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.13066844         LKETA      = 1.1153548e-008      DWG        = 0
+DWB        = 0                   PCLM       = 0.69140908          LPCLM      = 5.0677006e-010
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn'         RDW        = '65+drdswn'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon'              CGDO       = 'cgon'
+CGBO       = 0                   CGDL       = 'cgln'              CGSL       = 'cgln'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011288596        LTVOFF     = -2.7642003e-012     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.28118927         LKT1       = 4.2998671e-010
+KT1L       = 0                   KT2        = -0.095343813        LKT2       = 3.0529057e-009
+UTE        = -1.7133071          LUTE       = 4.2077271e-008      UA1        = -1.2041553e-010
+LUA1       = 7.4940541e-017      UB1        = 2.8533105e-021      LUB1       = -6.7415774e-026
+UC1        = 1.5113984e-010      LUC1       = -5.5591139e-018     PRT        = 0
+AT         = 31500
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn'          PVTH0      = '0+dpvthn'
+WCIT       = '0+dwcitn'          WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+WETA0      = '0+dweta0n'         PETA0      = '0+dpeta0n'         WVOFF      = '0+dwvoffn'
+PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn+0.0*ff_flag'
+WVSAT      = '0+dwvsatn+0.0*ff_flag'
+LNFACTOR   = '0+dlnfactorn+3.07141e-08*ss_flag-3.07141e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn+0.0*ss_flag+0.0*ff_flag'
+PNFACTOR   = '0+dpnfactorn+0.0*ss_flag+0.0*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln'
+LMAX       = 2.00001e-05         WMIN       = '1e-006-dxwn'       WMAX       = '1e-005-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39547494+dvthn'  WVTH0      = '1.6867314e-008+dwvthn'
+K1         = 0.31994             K2         = '0.022969033+dk2n'  WK2        = -4.048414e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010453333
+WCIT       = '-4.5424e-010+dwcitn'
+VOFF       = -0.12669799         WVOFF      = '-1.5050107e-008+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n'      UA         = -1.7121267e-009
+WUA        = 2.918492e-016       UB         = 2.4287286e-018      WUB        = -1.6449393e-025
+UC         = 1.3399547e-010      WUC        = -5.1056576e-017     VSAT       = '110000+dvsatn'
+A0         = 2.1942733           WA0        = 8.74412e-008        AGS        = 0.85684215
+WAGS       = 2.262365e-008       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.052544067
+WKETA      = 1.4569748e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.265162            WPCLM      = 7.052076e-008       PDIBLC1    = 0
+PDIBLC2    = '0.0024053667+dpdiblc2n'
+WPDIBLC2   = 9.6526e-011         PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00136514
+LTVOFF     = 0                   WTVOFF     = 9.87972e-011        PTVOFF     = 0
+KT1        = -0.21658778         WKT1       = 1.1468652e-008      KT1L       = 0
+KT2        = -0.0729256          WKT2       = 2.861712e-009       UTE        = -1.3799067
+WUTE       = 9.0848e-009         UA1        = 1.6328667e-009      WUA1       = -3.29324e-016
+UB1        = -1.4643317e-018     WUB1       = 1.8087837e-025      UC1        = -3.5953267e-012
+WUC1       = 3.9061233e-017      PRT        = 0                   AT         = 200000
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           WU0        = '0+dwu0n'           PU0        = '0+dpu0n'
+LETA0      = '0+dleta0n'         PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'
+PVOFF      = '0+dpvoffn'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'      LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln'
+LMAX       = '1e-005-dxln'       WMIN       = '1e-006-dxwn'       WMAX       = '1e-005-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3912083+dvthn'   LVTH0      = '4.2517486e-008+dlvthn'
+WVTH0      = '1.8398106e-008+dwvthn'
+PVTH0      = '-1.5254509e-014+dpvthn'
+K1         = 0.31994             K2         = '0.023700073+dk2n'  LK2        = -7.2848877e-009
+WK2        = -3.2986427e-009     PK2        = -7.471554e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0010309425        LCIT       = '1.4340605e-010+dlcitn'
+WCIT       = '-4.8594906e-010+dwcitn'
+PCIT       = 3.1598426e-016      VOFF       = -0.12386568         LVOFF      = '-2.8224355e-008+dlvoffn'
+WVOFF      = '-1.6770688e-008+dwvoffn'
+PVOFF      = '1.7145779e-014+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021608056+du0n'  LU0        = '1.9377335e-011+dlu0n'
+WU0        = '1.948407e-011+dwu0n'
+PU0        = '-1.941609e-016+dpu0n'
+UA         = -1.7350077e-009     LUA        = 2.2801148e-016      WUA        = 3.0333057e-016
+PUA        = -1.1441307e-022     UB         = 2.4549474e-018      LUB        = -2.6127333e-025
+WUB        = -1.6899378e-025     PUB        = 4.4841459e-032      UC         = 1.3493348e-010
+LUC        = -9.347427e-018      WUC        = -4.9388253e-017     PUC        = -1.6625027e-023
+VSAT       = '110000+dvsatn'
+A0         = '2.2627307+0.0048613*ff_flag-0.00364597*ss_flag'
+LA0        = '-6.8218549e-007+dla0n-4.84434e-08*ff_flag+3.63325e-08*ss_flag'
+WA0        = '2.6426333e-008-4.87102e-08*ff_flag+3.65326e-08*ss_flag'
+PA0        = '6.0801986e-013+4.85402e-13*ff_flag-3.64052e-13*ss_flag'
+AGS        = 0.81261905
+LAGS       = 4.4068808e-007      WAGS       = 2.1599056e-008      PAGS       = 1.0210194e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050703795        LKETA      = -1.833851e-008
+WKETA      = 1.3590674e-008      PKETA      = 9.7565851e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0025925301+dpdiblc2n'
+LPDIBLC2   = -1.8651041e-009     WPDIBLC2   = -2.5844939e-010     PPDIBLC2   = 3.5373688e-015
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013867485        LTVOFF     = -2.1533064e-010
+WTVOFF     = 1.1974258e-010      PTVOFF     = -2.0872296e-016     KT1        = -0.21442694
+LKT1       = -2.1532981e-008     WKT1       = 1.2454399e-008      PKT1       = -9.8230852e-015
+KT1L       = 0                   KT2        = -0.072099838        LKT2       = -8.2288133e-009
+WKT2       = 1.2494052e-009      PKT2       = 1.6066814e-014      UTE        = -1.3572144
+LUTE       = -2.2613065e-007     WUTE       = -1.8436448e-008     PUTE       = 2.7425227e-013
+UA1        = 1.7006531e-009      LUA1       = -6.754996e-016      WUA1       = -3.853407e-016
+PUA1       = 5.5821258e-022      UB1        = -1.4668194e-018     LUB1       = 2.4789881e-026
+WUB1       = 1.9905701e-025      PUB1       = -1.8115212e-031     UC1        = -7.765745e-012
+LUC1       = 4.1558677e-017      WUC1       = 4.2385337e-017      PUC1       = -3.3125063e-023
+PRT        = 0                   AT         = 201084.5            LAT        = -0.010807139
+WAT        = -0.00012177544      PAT        = 1.2135056e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln'
+LMAX       = '1.000002e-006-dxln'
+WMIN       = '1e-006-dxwn'       WMAX       = '1e-005-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43644065+dvthn'  LVTH0      = '-1.136705e-009+dlvthn'
+WVTH0      = '3.253333e-009+dwvthn'
+PVTH0      = '-6.3813721e-016+dpvthn'
+K1         = 0.31994             K2         = '0.022589005+dk2n'  LK2        = -6.2125854e-009
+WK2        = -1.2770759e-008     PK2        = 1.6700806e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.001096553         LCIT       = '8.0084763e-011+dlcitn'
+WCIT       = '-9.6839942e-011+dwcitn'
+PCIT       = -5.9548836e-017     VOFF       = -0.15284142         LVOFF      = '-2.5957307e-010+dlvoffn'
+WVOFF      = '4.4636181e-009+dwvoffn'
+PVOFF      = '-3.3476624e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10328893+deta0n' WETA0      = '-2.2734712e-008+dweta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021606051+du0n'  LU0        = '2.1312171e-011+dlu0n'
+WU0        = '3.9571993e-011+dwu0n'
+PU0        = '-2.1354795e-016+dpu0n'
+UA         = -1.5657172e-009     LUA        = 6.4627591e-017      WUA        = 2.0431503e-016
+PUA        = -1.8852183e-023     UB         = 2.2803345e-018      LUB        = -9.2752717e-026
+WUB        = -1.0778004e-025     PUB        = -1.423653e-032      UC         = 1.3678552e-010
+LUC        = -1.1134843e-017     WUC        = -7.5489601e-017     PUC        = 8.5656457e-024
+VSAT       = '114148.32+dvsatn+35.0518*ff_flag-56.0828*ss_flag'
+LVSAT      = '-0.0040035838+dlvsatn-3.38288e-05*ff_flag+5.41261e-05*ss_flag'
+WVSAT      = '-0.0020230217+dwvsatn-0.000351219*ff_flag+0.00056195*ss_flag'
+PVSAT      = '1.9524384e-009+dpvsatn+3.38965e-10*ff_flag-5.42344e-10*ss_flag'
+A0         = '2.1280013-0.0488385*ff_flag+0.0445155*ss_flag'
+LA0        = '-5.5215676e-007+dla0n+3.38286e-09*ff_flag-1.01486e-08*ss_flag'
+WA0        = '8.1621195e-007+4.89361e-07*ff_flag-4.46046e-07*ss_flag'
+PA0        = '-1.5421014e-013-3.38966e-14*ff_flag+1.01689e-13*ss_flag'
+AGS        = 0.42466709
+LAGS       = 8.151044e-007       WAGS       = 4.2130504e-008      PAGS       = -9.6049124e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.076145004        LKETA      = 6.2150549e-009
+WKETA      = 3.0987767e-008      PKETA      = -7.0335238e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00079587727+dpdiblc2n'
+LPDIBLC2   = -1.3113651e-010     WPDIBLC2   = 4.2146038e-009      PPDIBLC2   = -7.7961951e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0012284441        LTVOFF     = -6.254953e-011
+WTVOFF     = -1.6641859e-010     PTVOFF     = 6.7454036e-017      KT1        = -0.22675482
+LKT1       = -9.6352162e-009     WKT1       = -3.8941599e-009     PKT1       = 5.9550728e-015
+KT1L       = 0                   KT2        = -0.07738044         LKT2       = -3.1324513e-009
+WKT2       = 1.4226817e-008      PKT2       = 3.5421843e-015      UTE        = -1.6184239
+LUTE       = 2.5965229e-008      WUTE       = 2.1301242e-007      PUTE       = 5.0878647e-014
+UA1        = 1.0856968e-009      LUA1       = -8.1999125e-017     WUA1       = 1.505545e-016
+PUA1       = 4.1014766e-023      UB1        = -1.5438351e-018     LUB1       = 9.9118509e-026
+WUB1       = -1.3229333e-026     PUB1       = 2.372755e-032       UC1        = 1.0815775e-011
+LUC1       = 2.3625467e-017      WUC1       = 2.1233474e-017      PUC1       = -1.2711188e-023
+PRT        = 0                   AT         = 235012.77           LAT        = -0.04355165
+WAT        = -0.0016741523       PAT        = 2.71172e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln'
+LMAX       = '2.399959e-007-dxln'
+WMIN       = '1e-006-dxwn'       WMAX       = '1e-005-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+dvthn'  LVTH0      = '-2.6209825e-009+dlvthn'
+WVTH0      = '6.8814839e-010+dwvthn'
+PVTH0      = '-5.3326435e-017+dpvthn'
+K1         = 0.31994             K2         = '0.0071010498+dk2n' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitn'
+WCIT       = '-2.634146e-010+dwcitn'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffn'
+WVOFF      = '-2.7301032e-008+dwvoffn'
+PVOFF      = '3.8940424e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10402516+deta0n' LETA0      = '-1.6784547e-010+dleta0n'
+WETA0      = '-3.0136772e-008+dweta0n'
+PETA0      = '1.6875216e-015+dpeta0n'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0n'  LU0        = '6.0443544e-011+dlu0n'
+WU0        = '-3.4587047e-010+dwu0n'
+PU0        = '-1.2567478e-016+dpu0n'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatn-195.445*ff_flag+312.712*ss_flag'
+LVSAT      = '-0.00073522225+dlvsatn+1.87198e-05*ff_flag-2.99517e-05*ss_flag'
+WVSAT      = '0.013868259+dwvsatn+0.00195836*ff_flag-0.00313337*ss_flag'
+PVSAT      = '-1.6704557e-009+dpvsatn-1.87572e-10*ff_flag+3.00116e-10*ss_flag'
+A0         = '0.71811517-0.157167*ff_flag'
+LA0        = '-2.3073092e-007+dla0n+2.80797e-08*ff_flag'
+WA0        = '4.6955716e-007+1.57482e-06*ff_flag'
+PA0        = '-7.5179779e-014-2.81358e-13*ff_flag'
+AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2n'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln'
+WMIN       = '1e-006-dxwn'       WMAX       = '1e-005-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41095635+dvthn'  LVTH0      = '4.4351783e-010+dlvthn'
+WVTH0      = '-9.3492206e-009+dwvthn'
+PVTH0      = '9.0806281e-016+dpvthn'
+K1         = 0.31994             K2         = '0.0013060071+dk2n' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 9.8452363e-005      LCIT       = '1.9928338e-010+dlcitn'
+WCIT       = '-1.6453517e-009+dwcitn'
+PCIT       = 1.1079017e-016      VOFF       = -0.13957401         LVOFF      = '-3.8809298e-009+dlvoffn'
+WVOFF      = '2.9811114e-008+dwvoffn'
+PVOFF      = '-1.576216e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn-0.357015*ss_flag+0.357015*ff_flag'
+ETA0       = '0.00035892377+deta0n-0.00181714*ff_flag'
+LETA0      = '9.7614105e-009+dleta0n+1.74047e-10*ff_flag'
+WETA0      = '1.4881786e-009+dweta0n+1.82078e-08*ff_flag'
+PETA0      = '-1.3415478e-015+dpeta0n-1.74395e-15*ff_flag'
+ETAB       = -0.081412532        LETAB      = -1.9907778e-010     WETAB      = -4.2459433e-008
+PETAB      = 1.9947594e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0n'   LU0        = '4.5926676e-011+dlu0n'
+WU0        = '-4.2433976e-009+dwu0n'
+PU0        = '2.4763426e-016+dpu0n'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024      UB         = 1.7366172e-018      LUB        = 9.8246845e-028
+WUB        = -1.7615195e-025     PUB        = -8.5364064e-033     UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '84649.699+dvsatn+1470.82*ff_flag'
+LVSAT      = '0.00071705169+dlvsatn-0.000140875*ff_flag'
+WVSAT      = '0.0039042958+dwvsatn-0.00509818*ff_flag'
+PVSAT      = '-7.1609734e-010+dpvsatn+4.88305e-10*ff_flag'
+A0         = '1.6696481+0.354057*ff_flag'
+LA0        = '-3.2186969e-007+dla0n-2.08856e-08*ff_flag'
+WA0        = '-2.4506944e-006-3.54765e-06*ff_flag'
+PA0        = '2.0452483e-013+2.09274e-13*ff_flag'
+AGS        = '3.3966895+1.45371*ss_flag'
+Pags     = '0+1.39516e-12*ss_flag'
+Wags     = '0-1.45662e-05*ss_flag'
+LAGS       = '1.5356668e-007-1.39237e-07*ss_flag'
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn'         RDW        = '65+drdswn'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon'              CGDO       = 'cgon'
+CGBO       = 0                   CGDL       = 'cgln'              CGSL       = 'cgln'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.097099973        LKT2       = 3.1797651e-009      WKT2       = 1.7596724e-008
+PKT2       = -1.2711311e-015     UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn+3.4195e-08*ss_flag-3.4195e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn+3.64155e-07*ss_flag-3.64155e-07*ff_flag'
+PNFACTOR   = '0+dpnfactorn-3.48789e-14*ss_flag+3.48789e-14*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln'
+LMAX       = 2.00001e-05         WMIN       = '6e-007-dxwn'       WMAX       = '1e-006-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41234586+dvthn'  WVTH0      = '-3.4102328e-010+dwvthn'
+K1         = 0.31994             K2         = '0.024897369+dk2n'  WK2        = -6.0153161e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00033
+WCIT       = '9.486e-010+dwcitn' VOFF       = -0.13118588         WVOFF      = '-1.047246e-008+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220595+du0n'    WU0        = '-4.5849e-010+dwu0n'
+UA         = -1.5544144e-009     WUA        = 1.3098269e-016      UB         = 2.3962278e-018
+WUB        = -1.3134316e-025     UC         = 1.369035e-010       WUC        = -5.402277e-017
+VSAT       = '110000+dvsatn'     A0         = 2.6356816           WA0        = -3.6279523e-007
+AGS        = 0.93377161          WAGS       = -5.5844398e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05097            WKETA      = 1.29642e-008        DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0041275+dpdiblc2n'
+WPDIBLC2   = -1.66005e-009       PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0015829
+LTVOFF     = 0                   WTVOFF     = -1.23318e-010       PTVOFF     = 0
+KT1        = -0.2248802          WKT1       = 1.9926924e-008      KT1L       = 0
+KT2        = -0.0734525          WKT2       = 3.39915e-009        UTE        = -1.619
+WUTE       = 2.5296e-007         UA1        = 1.155e-009          WUA1       = 1.581e-016
+UB1        = -1.12735e-018       WUB1       = -1.62843e-025       UC1        = -2e-014
+WUC1       = 3.54144e-017        PRT        = 0                   AT         = 200000
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln'
+LMAX       = '1e-005-dxln'       WMIN       = '6e-007-dxwn'       WMAX       = '1e-006-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40885016+dvthn'  LVTH0      = '3.4835029e-008+dlvthn'
+WVTH0      = '4.0341437e-010+dwvthn'
+PVTH0      = '-7.418403e-015+dpvthn'
+K1         = 0.31994             K2         = '0.026722076+dk2n'  LK2        = -1.8183407e-008
+WK2        = -6.3810858e-009     PK2        = 3.6449353e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00046259057      LCIT       = '1.3212796e-009+dlcitn'
+WCIT       = '1.0374547e-009+dwcitn'
+PCIT       = -8.8544672e-016     VOFF       = -0.12858922         LVOFF      = '-2.5875987e-008+dlvoffn'
+WVOFF      = '-1.1952669e-008+dwvoffn'
+PVOFF      = '1.4750443e-014+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021971943+du0n'  LU0        = '8.7251438e-010+dlu0n'
+WU0        = '-3.5168128e-010+dwu0n'
+PU0        = '-1.0643607e-015+dpu0n'
+UA         = -1.5717657e-009     LUA        = 1.7290734e-016      WUA        = 1.3682375e-016
+PUA        = -5.8206845e-023     UB         = 2.4217449e-018      LUB        = -2.542805e-025
+WUB        = -1.3512724e-025     PUB        = 3.7708778e-032      UC         = 1.4062234e-010
+LUC        = -3.7058619e-017     WUC        = -5.5190885e-017     PUC        = 1.1640389e-023
+VSAT       = '110000+dvsatn'
+A0         = '2.5755871-0.109379*ff_flag+0.0820344*ss_flag'
+LA0        = '5.9884843e-007+dla0n+1.08998e-06*ff_flag-8.17482e-07*ss_flag'
+WA0        = '-2.9268715e-007+6.78151e-08*ff_flag-5.08613e-08*ss_flag'
+PA0        = '-6.9863474e-013-6.75785e-13*ff_flag+5.06839e-13*ss_flag'
+AGS        = 0.87470677
+LAGS       = 5.8858761e-007      WAGS       = -4.1730422e-008     PAGS       = -1.4064732e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050917348        LKETA      = -5.2468409e-010
+WKETA      = 1.3808498e-008      PKETA      = -8.4135178e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.003974959+dpdiblc2n'
+LPDIBLC2   = 1.5200878e-009      WPDIBLC2   = -1.6685269e-009     PPDIBLC2   = 8.447307e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016380078        LTVOFF     = -5.491551e-010
+WTVOFF     = -1.3654194e-010     PTVOFF     = 1.3177799e-016      KT1        = -0.22424568
+LKT1       = -6.3230738e-009     WKT1       = 2.2469514e-008      PKT1       = -2.5337191e-014
+KT1L       = 0                   KT2        = -0.074820758        LKT2       = 1.363484e-008
+WKT2       = 4.024744e-009       PKT2       = -6.2341126e-015     UTE        = -1.6586596
+LUTE       = 3.9521215e-007      WUTE       = 2.8903761e-007      PUTE       = -3.5951739e-013
+UA1        = 1.1037098e-009      LUA1       = 5.1111283e-016      WUA1       = 2.2354154e-016
+PUA1       = -6.521321e-022      UB1        = -1.0463944e-018     LUB1       = -8.0673118e-025
+WUB1       = -2.2977647e-025     PUB1       = 6.6699936e-031      UC1        = -1.9453945e-012
+LUC1       = 1.9186768e-017      WUC1       = 3.644858e-017       PUC1       = -1.0305715e-023
+PRT        = 0                   AT         = 200798.9            LAT        = -0.0079610926
+WAT        = 0.00016953766       PAT        = -1.6894614e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln'
+LMAX       = '1.000002e-006-dxln'
+WMIN       = '6e-007-dxwn'       WMAX       = '1e-006-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44786427+dvthn'  LVTH0      = '-2.817881e-009+dlvthn'
+WVTH0      = '-8.3987589e-009+dwvthn'
+PVTH0      = '1.0766624e-015+dpvthn'
+K1         = 0.31994             K2         = '0.014852277+dk2n'  LK2        = -6.7277449e-009
+WK2        = -4.8792964e-009     PK2        = 2.1955433e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00094891812       LCIT       = '-4.0981585e-011+dlcitn'
+WCIT       = '5.3747588e-011+dwcitn'
+PCIT       = 6.3938839e-017      VOFF       = -0.15657613         LVOFF      = '1.1344586e-009+dlvoffn'
+WVOFF      = '8.2730227e-009+dwvoffn'
+PVOFF      = '-4.7695748e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.06074615+deta0n' WETA0      = '2.0658927e-008+dweta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220162+du0n'    LU0        = '8.2980161e-010+dlu0n'
+WU0        = '-3.7878026e-010+dwu0n'
+PU0        = '-1.0382072e-015+dpu0n'
+UA         = -1.5168324e-009     LUA        = 1.1989066e-016      WUA        = 1.5445249e-016
+PUA        = -7.5220517e-023     UB         = 2.285951e-018       LUB        = -1.2322447e-025
+WUB        = -1.1350885e-025     PUB        = 1.6844661e-032      UC         = 1.0610996e-010
+LUC        = -3.750375e-018      WUC        = -4.420053e-017      PUC        = 1.0334881e-024
+VSAT       = '112500.53+dvsatn-788.665*ff_flag+1261.86*ss_flag'
+LVSAT      = '-0.0024132899+dlvsatn+0.000761148*ff_flag-0.00121784*ss_flag'
+WVSAT      = '-0.00034228083+dwvsatn+0.000488972*ff_flag-0.000782355*ss_flag'
+PVSAT      = '3.3033865e-010+dpvsatn-4.71912e-10*ff_flag+7.55059e-10*ss_flag'
+A0         = '4.506443+1.09887*ff_flag-1.0016*ss_flag'
+LA0        = '-1.26464e-006+dla0n-7.61145e-08*ff_flag+2.28345e-07*ss_flag'
+WA0        = '-1.6097986e-006-6.81297e-07*ff_flag+6.20992e-07*ss_flag'
+PA0        = '5.7252272e-013+4.71914e-14*ff_flag-1.41574e-13*ss_flag'
+AGS        = -0.80346274
+LAGS       = 2.2082058e-006      WAGS       = 1.2948229e-006      PAGS       = -1.4305683e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055175769        LKETA      = 3.5851609e-009
+WKETA      = 9.5991475e-009      PKETA      = -4.3510319e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0069572267+dpdiblc2n'
+LPDIBLC2   = -1.3581285e-009     WPDIBLC2   = -2.0699726e-009     PPDIBLC2   = 4.7191236e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0010163914        LTVOFF     = 5.0773113e-011
+WTVOFF     = 4.9875206e-011      PTVOFF     = -4.813506e-017      KT1        = -0.22821446
+LKT1       = -2.4927658e-009     WKT1       = -2.4053332e-009     PKT1       = -1.3302266e-015
+KT1L       = 0                   KT2        = -0.057541276        LKT2       = -3.0417602e-009
+WKT2       = -6.0091298e-009     PKT2       = 3.4496793e-015      UTE        = -1.265572
+LUTE       = 1.5839361e-008      WUTE       = -1.4689655e-007     PUTE       = 6.1207033e-014
+UA1        = 1.9047865e-009      LUA1       = -2.6201434e-016     WUA1       = -6.8491696e-016
+PUA1       = 2.2463028e-022      UB1        = -2.1825365e-018     LUB1       = 2.897709e-025
+WUB1       = 6.3824609e-025      PUB1       = -1.7073789e-031     UC1        = 2.4369497e-012
+LUC1       = 1.4957323e-017      WUC1       = 2.9779875e-017      PUC1       = -3.8696813e-024
+PRT        = 0                   AT         = 224902.3            LAT        = -0.031223524
+WAT        = 0.0086385276        PAT        = -9.8629682e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln'
+LMAX       = '2.399959e-007-dxln'
+WMIN       = '6e-007-dxwn'       WMAX       = '1e-006-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+dvthn'  LVTH0      = '-2.4452732e-009+dlvthn'
+WVTH0      = '-2.656096e-009+dwvthn'
+PVTH0      = '-2.3254991e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0077298678+dk2n'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitn'
+WCIT       = '4.0796102e-010+dwcitn'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffn'
+WVOFF      = '-1.6424805e-008+dwvoffn'
+PVOFF      = '8.6103596e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.044118879+deta0n'
+LETA0      = '3.7906852e-009+dleta0n'
+WETA0      = '3.0967637e-008+dweta0n'
+PETA0      = '-2.3501797e-015+dpeta0n'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0n'  LU0        = '-6.7466293e-010+dlu0n'
+WU0        = '-7.6703892e-009+dwu0n'
+PU0        = '6.2413382e-016+dpu0n'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatn+4397.51*ff_flag-7036.02*ss_flag'
+LVSAT      = '-0.0010680136+dlvsatn-0.000421195*ff_flag+0.000673912*ss_flag'
+WVSAT      = '0.0069449685+dwvsatn-0.00272646*ff_flag+0.00436233*ss_flag'
+PVSAT      = '-1.3310085e-009+dpvsatn+2.61141e-10*ff_flag-4.17826e-10*ss_flag'
+A0         = '2.0693451+3.53626*ff_flag'
+LA0        = '-7.0903035e-007+dla0n-6.31793e-07*ff_flag'
+WA0        = '-9.0869732e-007-2.19248e-06*ff_flag'
+PA0        = '4.1268564e-013+3.91711e-13*ff_flag'
+AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln'
+WMIN       = '6e-007-dxwn'       WMAX       = '1e-006-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.4204795+dvthn-0.00994084*ff_flag'
+LVTH0      = '2.1124771e-011+dlvthn+9.52137e-10*ff_flag'
+WVTH0      = '-1.9062833e-008+dwvthn+1.01397e-08*ff_flag'
+PVTH0      = '1.3389037e-015+dpvthn-9.7118e-16*ff_flag'
+K1         = 0.31994             K2         = '-0.014947392+dk2n' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitn'
+WCIT       = '-4.2348127e-010+dwcitn'
+PCIT       = 6.2821635e-017      VOFF       = -0.10368237         LVOFF      = '-5.3664414e-009+dlvoffn'
+WVOFF      = '-6.7983641e-009+dwvoffn'
+PVOFF      = '-6.0994162e-017+dpvoffn'
+NFACTOR    = '0.75+dnfactorn-0.745563*ss_flag'
+ETA0       = '-0.051871703+deta0n+0.0408857*ff_flag'
+LETA0      = '1.2984759e-008+dleta0n-3.91605e-09*ff_flag'
+WETA0      = '5.4763418e-008+dweta0n-2.53491e-08*ff_flag'
+PETA0      = '-4.6293634e-015+dpeta0n+2.42795e-15*ff_flag'
+ETAB       = -0.16081204         LETAB      = 4.4792501e-009      WETAB      = 3.8528064e-008
+PETAB      = -2.7771351e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0n'  LU0        = '1.4350807e-010+dlu0n'
+WU0        = '-2.7003787e-009+dwu0n'
+PU0        = '1.4810125e-016+dpu0n'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023      UB         = 9.4237903e-019      LUB        = 5.867745e-026
+WUB        = 6.3397101e-025      PUB        = -6.7385287e-032     UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatn-11977.1*ff_flag'
+LVSAT      = '-0.00026235326+dlvsatn+0.00114717*ff_flag'
+WVSAT      = '-0.0099049722+dwvsatn+0.00861872*ff_flag'
+PVSAT      = '2.8289571e-010+dpvsatn-8.25503e-10*ff_flag'
+A0         = '-8.937762-7.96629*ff_flag'
+LA0        = '3.4524137e-007+dla0n+4.69926e-07*ff_flag'
+WA0        = '8.3688639e-006+4.9391e-06*ff_flag'
+PA0        = '-4.7592845e-013-2.91354e-13*ff_flag'
+AGS        = '6.4966895-32.7086*ss_flag'
+LAGS       = '1.5356668e-007+3.13284e-06*ss_flag'
+WAGS       = '-3.162e-006+2.02793e-05*ss_flag'
+PAGS       = '-1.6753592e-027-1.94236e-12*ss_flag'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0                   KT2        = -0.10354588
+LKT2       = 3.8169646e-009      WKT2       = 2.4171549e-008      PKT2       = -1.9210747e-015
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn'               CJD        = 'cjn'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn'             CJSWD      = 'cjswn'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn+7.14103e-08*ss_flag'
+WNFACTOR   = '0+dwnfactorn+7.60474e-07*ss_flag'
+PNFACTOR   = '0+dpnfactorn-7.28385e-14*ss_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln'
+LMAX       = 2.00001e-05         WMIN       = '3e-007-dxwn'       WMAX       = '6e-007-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4276847+dvthn'   WVTH0      = '-9.851103e-009+dwvthn'
+K1         = 0.31994             K2         = '0.016999242+dk2n'  WK2        = -1.1184774e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00184
+WCIT       = '-3.968e-010+dwcitn'
+VOFF       = -0.15391902         WVOFF      = '3.6220876e-009+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022642667+du0n'  WU0        = '-8.2005333e-010+dwu0n'
+UA         = -1.3081355e-009     WUA        = -2.1710251e-017     UB         = 2.1698603e-018
+WUB        = 9.0047147e-027      UC         = 7.1487333e-011      WUC        = -1.3464747e-017
+VSAT       = '110000+dvsatn'     A0         = 1.7876245           WA0        = 1.6300015e-007
+AGS        = 0.82793509          WAGS       = 9.7742421e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.024641333        WKETA      = -3.3595733e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00032208424+dpdiblc2n'
+WPDIBLC2   = 6.9930778e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012677333
+LTVOFF     = 0                   WTVOFF     = 7.2085333e-011      PTVOFF     = 0
+KT1        = -0.20249189         WKT1       = 6.0461739e-009      KT1L       = 0
+KT2        = -0.070540667        WKT2       = 1.5938133e-009      UTE        = -1.3784667
+WUTE       = 1.0382933e-007      UA1        = 1.282e-009          WUA1       = 7.936e-017
+UB1        = -1.3882293e-018     WUB1       = -1.0978133e-027     UC1        = 5.4326667e-011
+WUC1       = 1.7194667e-018      PRT        = 0                   AT         = 200000
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln'
+LMAX       = '1e-005-dxln'       WMIN       = '3e-007-dxwn'       WMAX       = '6e-007-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42605581+dvthn'  LVTH0      = '1.6232044e-008+dlvthn'
+WVTH0      = '-1.0264089e-008+dwvthn'
+PVTH0      = '4.1154478e-015+dpvthn'
+K1         = 0.31994             K2         = '0.018007345+dk2n'  LK2        = -1.0045864e-008
+WK2        = -9.7795291e-010     PK2        = -1.4003415e-015     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0018878992        LCIT       = '-4.7732075e-010+dlcitn'
+WCIT       = '-4.1984897e-010+dwcitn'
+PCIT       = 2.2968548e-016      VOFF       = -0.15467558         LVOFF      = '7.5391143e-009+dlvoffn'
+WVOFF      = '4.2208688e-009+dwvoffn'
+PVOFF      = '-5.9669201e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02272967+du0n'   LU0        = '-8.6699326e-010+dlu0n'
+WU0        = '-8.2147169e-010+dwu0n'
+PU0        = '1.4134056e-017+dpu0n'
+UA         = -1.314581e-009      LUA        = 6.423085e-017       WUA        = -2.263072e-017
+PUA        = 9.1725784e-024      UB         = 2.1840169e-018      LUB        = -1.410727e-025
+WUB        = 1.2264093e-026      PUB        = -3.2480061e-032     UC         = 7.141683e-011
+LUC        = 7.0257088e-019      WUC        = -1.228347e-017      PUC        = -1.1771549e-023
+VSAT       = '110000+dvsatn'     A0         = 1.8035366           LA0        = '-1.5856545e-007+dla0n'
+WA0        = 1.8598415e-007      PA0        = -2.2903814e-013     AGS        = 0.77479681
+LAGS       = 5.2952879e-007      WAGS       = 2.0213751e-008      PAGS       = -1.0403086e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022723624        LKETA      = -1.9110184e-008
+WKETA      = -3.6716113e-009     PKETA      = 3.1094924e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '9.2111129e-005+dpdiblc2n'
+LPDIBLC2   = 2.2917073e-009      WPDIBLC2   = 7.388388e-010       PPDIBLC2   = -3.9393101e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013017628        LTVOFF     = -3.3910735e-010
+WTVOFF     = 7.1929953e-011      PTVOFF     = 1.5483859e-018      KT1        = -0.20000319
+LKT1       = -2.4800253e-008     WKT1       = 7.4391679e-009      PKT1       = -1.3881339e-014
+KT1L       = 0                   KT2        = -0.07226453         LKT2       = 1.7178492e-008
+WKT2       = 2.4398829e-009      PKT2       = -8.4311765e-015     UTE        = -1.3598451
+LUTE       = -1.8556648e-007     WUTE       = 1.037726e-007       PUTE       = 5.6536225e-016
+UA1        = 1.3460976e-009      LUA1       = -6.3873965e-016     WUA1       = 7.3261077e-017
+PUA1       = 6.0776441e-023      UB1        = -1.4247522e-018     LUB1       = 3.639548e-025
+WUB1       = 4.8053771e-027      PUB1       = -5.8825942e-032     UC1        = 8.1281117e-011
+LUC1       = -2.6860406e-016     WUC1       = -1.5151857e-017     PUC1       = 1.681246e-022
+PRT        = 0                   AT         = 202216.18           LAT        = -0.022084463
+WAT        = -0.00070917713      PAT        = 7.0670281e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'
+LVSAT      = '0+dlvsatn'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln'
+LMAX       = '1.000002e-006-dxln'
+WMIN       = '3e-007-dxwn'       WMAX       = '6e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44379242+dvthn'  LVTH0      = '-8.8573346e-010+dlvthn'
+WVTH0      = '-5.8742089e-009+dwvthn'
+PVTH0      = '-1.2126911e-016+dpvthn'
+K1         = 0.31994             K2         = '0.011976931+dk2n'  LK2        = -4.2258503e-009
+WK2        = -3.096582e-009      PK2        = 6.4436865e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0011530249        LCIT       = '2.3191383e-010+dlcitn'
+WCIT       = '-7.279858e-011+dwcitn'
+PCIT       = -1.0525632e-016     VOFF       = -0.13612071         LVOFF      = '-1.0368368e-008+dlvoffn'
+WVOFF      = '-4.4093367e-009+dwvoffn'
+PVOFF      = '2.3621775e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.10373847+deta0n' WETA0      = '-5.9963093e-009+dweta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02296062+du0n'   LU0        = '-1.0898857e-009+dlu0n'
+WU0        = '-9.6432059e-010+dwu0n'
+PU0        = '1.5199896e-016+dpu0n'
+UA         = -1.2231707e-009     LUA        = -2.3990174e-017     WUA        = -2.7617741e-017
+PUA        = 1.3985602e-023      UB         = 2.1388512e-018      LUB        = -9.748279e-026
+WUB        = -2.230697e-026      PUB        = 8.8481753e-034      UC         = 7.9956073e-011
+LUC        = -7.5387377e-018     WUC        = -2.7985123e-017     PUC        = 3.382273e-024
+VSAT       = '114026.83+dvsatn'  LVSAT      = '-0.0038863371+dlvsatn'
+WVSAT      = '-0.0012885866+dwvsatn'
+PVSAT      = '1.2436279e-009+dpvsatn'
+A0         = 2.1012026           LA0        = '-4.4584588e-007+dla0n'
+WA0        = -1.1854956e-007     PA0        = 6.4870393e-014      AGS        = 1.8492877
+LAGS       = -5.0747307e-007     WAGS       = -3.4988232e-007     PAGS       = 2.5315256e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.036180291        LKETA      = -6.1230205e-009
+WKETA      = -2.1780491e-009     PKETA      = 1.6680405e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0029202782+dpdiblc2n'
+LPDIBLC2   = -4.3778502e-010     WPDIBLC2   = 4.3293545e-010      PPDIBLC2   = -9.8700623e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00097124062       LTVOFF     = -2.0117097e-011
+WTVOFF     = 7.786867e-011       PTVOFF     = -4.1831298e-018     KT1        = -0.20791948
+LKT1       = -1.7160154e-008     WKT1       = -1.4988217e-008     PKT1       = 7.7635542e-015
+KT1L       = 0                   KT2        = -0.05401687         LKT2       = -4.3250772e-010
+WKT2       = -8.1942617e-009     PKT2       = 1.8319428e-015      UTE        = -1.7274986
+LUTE       = 1.6925963e-007      WUTE       = 1.3949795e-007      PUTE       = -3.3913534e-014
+UA1        = 3.3391362e-010      LUA1       = 3.3812923e-016      WUA1       = 2.8902423e-016
+PUA1       = -1.4745873e-022     UB1        = -8.5309426e-019     LUB1       = -1.8775804e-025
+WUB1       = -1.860081e-025      PUB1       = 1.2533005e-031      UC1        = -2.9157422e-010
+LUC1       = 9.1242359e-017      WUC1       = 2.120668e-016       PUC1       = -5.1166403e-023
+PRT        = 0                   AT         = 224176.96           LAT        = -0.043279029
+WAT        = 0.0090882378        PAT        = -2.3885551e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln'
+LMAX       = '2.399959e-007-dxln'
+WMIN       = '3e-007-dxwn'       WMAX       = '6e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45421094+dvthn'  LVTH0      = '-3.2609491e-009+dlvthn'
+WVTH0      = '-7.6043531e-009+dwvthn'
+PVTH0      = '2.7316917e-016+dpvthn'
+K1         = 0.31994             K2         = '0.0033553434+dk2n' LK2        = -2.2603008e-009
+WK2        = -2.2578918e-009     PK2        = 4.5316404e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0024283835        LCIT       = '-5.8842434e-011+dlcitn'
+WCIT       = '-9.3654447e-010+dwcitn'
+PCIT       = 9.166047e-017       VOFF       = -0.18990686         LVOFF      = '1.8937985e-009+dlvoffn'
+WVOFF      = '1.0968765e-008+dwvoffn'
+PVOFF      = '-1.143722e-015+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.12614967+deta0n' LETA0      = '-5.1093057e-009+dleta0n'
+WETA0      = '-1.9891452e-008+dweta0n'
+PETA0      = '3.1678146e-015+dpeta0n'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014783927+du0n'  LU0        = '7.7423676e-010+dlu0n'
+WU0        = '9.0506683e-010+dwu0n'
+PU0        = '-2.7418398e-016+dpu0n'
+UA         = -1.660424e-009      LUA        = 7.569483e-017       WUA        = 1.2189162e-016
+PUA        = -2.0099543e-023     UB         = 1.8854943e-018      LUB        = -3.9722495e-026
+WUB        = -1.9210541e-026     PUB        = 1.7889358e-034      UC         = 5.728725e-011
+LUC        = -2.3706995e-018     WUC        = -1.9686336e-017     PUC        = 1.4903156e-024
+VSAT       = '108347.65+dvsatn'  LVSAT      = '-0.0025915958+dlvsatn'
+WVSAT      = '0.0058612307+dwvsatn'
+PVSAT      = '-3.863875e-010+dpvsatn'
+A0         = -0.98300577         LA0        = '2.5729195e-007+dla0n'
+WA0        = 9.8376019e-007      PA0        = -1.8643419e-013     AGS        = -2.8231338
+LAGS       = 5.5774558e-007      WAGS       = 1.311556e-006       PAGS       = -1.2562214e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041656409        LKETA      = -4.8745752e-009
+WKETA      = -7.736204e-009      PKETA      = 2.9351887e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.22629814          LPCLM      = 8.9111726e-008
+WPCLM      = -2.8028223e-008     PPCLM      = -6.2145624e-015     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00094709599
+LTVOFF     = -1.4612604e-011     WTVOFF     = 2.7416941e-011      PTVOFF     = 7.3188553e-018
+KT1        = -0.277058           LKT1       = -1.397956e-009      WKT1       = 2.8183098e-008
+PKT1       = -2.0786423e-015     KT1L       = 0                   KT2        = -0.046538569
+LKT2       = -2.1374107e-009     WKT2       = -5.5723834e-009     PKT2       = 1.234207e-015
+UTE        = -0.65956337         LUTE       = -7.4208242e-008     WUTE       = -1.1179679e-007
+PUTE       = 2.3376642e-014      UA1        = 2.5612467e-009      LUA1       = -1.6965817e-016
+WUA1       = -5.4560818e-016     PUA1       = 4.2820766e-023      UB1        = -2.0582479e-018
+LUB1       = 8.6992894e-026      WUB1       = 4.4039735e-025      PUB1       = -1.7477864e-032
+UC1        = 1.6622197e-010      LUC1       = -1.3126016e-017     WUC1       = -2.8658038e-017
+PUC1       = 3.714046e-024       PRT        = 0                   AT         = 44971.144
+LAT        = -0.0024236881       WAT        = -0.0047907659       PAT        = 7.7558019e-010
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln'
+WMIN       = '3e-007-dxwn'       WMAX       = '6e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.42266826+dvthn+0.0132545*ff_flag'
+LVTH0      = '-2.3975895e-010+dlvthn-1.26952e-09*ff_flag'
+WVTH0      = '-2.0419864e-008+dwvthn-4.24143e-09*ff_flag'
+PVTH0      = '1.5006516e-015+dpvthn+4.06245e-16*ff_flag'
+K1         = 0.31994             K2         = '-0.013299183+dk2n' LK2        = -6.6511353e-010
+WK2        = -2.1217758e-011     PK2        = 2.3893317e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0036006898       LCIT       = '5.1862823e-010+dlcitn'
+WCIT       = '1.1272813e-009+dwcitn'
+PCIT       = -1.0601483e-016     VOFF       = -0.10535026         LVOFF      = '-6.2051173e-009+dlvoffn'
+WVOFF      = '-5.7642711e-009+dwvoffn'
+PVOFF      = '4.5898489e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn+0.652034*ss_flag+0.171025*ff_flag'
+ETA0       = '-0.024024221+deta0n'
+LETA0      = '9.2744996e-009+dleta0n'
+WETA0      = '3.7497979e-008+dweta0n'
+PETA0      = '-2.3290025e-015+dpeta0n'
+ETAB       = -0.051005772        LETAB      = -2.9378167e-009     WETAB      = -2.9551821e-008
+PETAB      = 1.8214463e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022141568+du0n'  LU0        = '6.9514519e-011+dlu0n'
+WU0        = '-3.982763e-009+dwu0n'
+PU0        = '1.9397724e-016+dpu0n'
+UA         = -8.2122219e-010     LUA        = -4.684758e-018      WUA        = -5.3101284e-016
+PUA        = 4.24363e-023        UB         = 1.5660551e-018      LUB        = -9.1262856e-027
+WUB        = 2.4729184e-025      PUB        = -2.5346971e-032     UC         = -1.4219741e-011
+LUC        = 4.4783116e-018      WUC        = 2.9941448e-017      PUC        = -3.2630832e-024
+VSAT       = '77105.7+dvsatn+3976.34*ff_flag'
+LVSAT      = '0.00040078898+dlvsatn-0.000380855*ff_flag'
+WVSAT      = '0.0031661761+dwvsatn-0.00127243*ff_flag'
+PVSAT      = '-1.2825247e-010+dpvsatn+1.21874e-10*ff_flag'
+A0         = 8.073381            LA0        = '-6.1013784e-007+dla0n'
+WA0        = -2.1780448e-006     PA0        = 1.1640666e-013      AGS        = 1.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.36913643
+LKETA      = 2.6491789e-008      WKETA      = 8.6846044e-008      PKETA      = -6.1239936e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 1.2610378
+LPCLM      = -9.9966741e-009     WPCLM      = -3.0393451e-007     PPCLM      = 2.0212018e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0013591416+dpdiblc2n'
+LPDIBLC2   = -3.4398937e-011     WPDIBLC2   = -2.2266776e-010     PPDIBLC2   = 2.1327341e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = -0.00086115198      LTVOFF     = 1.585832e-010
+WTVOFF     = 8.4605521e-010      PTVOFF     = -7.1091137e-017     KT1        = -0.34419326
+LKT1       = 5.032327e-009       WKT1       = 3.0784511e-008      PKT1       = -2.3278082e-015
+KT1L       = 0                   KT2        = -0.086391456        LKT2       = 1.6797387e-009
+WKT2       = 1.3535807e-008      PKT2       = -5.9599457e-016     UTE        = -0.52365297
+LUTE       = -8.7225876e-008     WUTE       = -1.699253e-007      PUTE       = 2.8944249e-014
+UA1        = 4.9577924e-009      LUA1       = -3.9920171e-016     WUA1       = -1.6816004e-015
+PUA1       = 1.5162724e-022      UB1        = -5.0063038e-018     LUB1       = 3.6936063e-025
+WUB1       = 1.9058735e-024      PUB1       = -1.5784264e-031     UC1        = -2.9832515e-011
+LUC1       = 5.6522777e-018      WUC1       = 6.8152816e-019      PUC1       = 9.0387302e-025
+PRT        = 0                   AT         = 19666.667           WAT        = 0.0033066667
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn-6.2452e-08*ss_flag-1.63809e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn-1.06036e-07*ss_flag-1.06036e-07*ff_flag'
+PNFACTOR   = '0+dpnfactorn+1.01561e-14*ss_flag+1.01561e-14*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln'
+LMAX       = 2.00001e-05         WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40171155+dvthn'  WVTH0      = '-1.5396969e-009+dwvthn'
+K1         = 0.31994             K2         = '0.0081248889+dk2n' WK2        = 1.7213156e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0001
+WCIT       = '2.24e-010+dwcitn'  VOFF       = -0.14674927         WVOFF      = '1.3277655e-009+dwvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019737031+du0n'  WU0        = '1.0975004e-010+dwu0n'
+UA         = -1.3876311e-009     WUA        = 3.7283556e-018      UB         = 2.1326667e-018
+WUB        = 2.0906667e-026      UC         = 3.6184444e-011      WUC        = -2.1678222e-018
+VSAT       = '110000+dvsatn'     A0         = 2.4502222           WA0        = -4.9031111e-008
+AGS        = 0.79150093          WAGS       = 2.1433174e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.019631111        WKETA      = -4.9628444e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0021243041+dpdiblc2n'
+WPDIBLC2   = 1.2259743e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn'         RDW        = '65+drdswn'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon'              CGDO       = 'cgon'              CGBO       = 0
+CGDL       = 'cgln'              CGSL       = 'cgln'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0016550111
+LTVOFF     = 0                   WTVOFF     = -5.1843556e-011     PTVOFF     = 0
+KT1        = -0.17096587         WKT1       = -4.0421547e-009     KT1L       = 0
+KT2        = -0.074963333        WKT2       = 3.0090667e-009      UTE        = -0.94635556
+WUTE       = -3.4446222e-008     UA1        = 1.6e-009            WUA1       = -2.24e-017
+UB1        = -1.3369511e-018     WUB1       = -1.7506844e-026     UC1        = 7.9455556e-011
+WUC1       = -6.3217778e-018     PRT        = 0                   AT         = 200000
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn'          PVTH0      = '0+dpvthn'          LCIT       = '0+dlcitn'
+LU0        = '0+dlu0n'           PU0        = '0+dpu0n'           LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LVOFF      = '0+dlvoffn'         PVOFF      = '0+dpvoffn'
+PVSAT      = '0+dpvsatn'         WVSAT      = '0+dwvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+LA0        = '0+dla0n'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln'
+LMAX       = '1e-005-dxln'       WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'
+DLC        = '1.694588E-08+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39757681+dvthn'  LVTH0      = '4.120314e-008+dlvthn'
+WVTH0      = '-1.1508097e-009+dwvthn'
+PVTH0      = '-3.875303e-015+dpvthn'
+K1         = 0.31994             K2         = '0.0095210115+dk2n' LK2        = -1.3912516e-008
+WK2        = 1.7376739e-009      PK2        = -1.6301281e-016     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00022358126      LCIT       = '1.2315009e-009+dlcitn'
+WCIT       = '2.5582478e-010+dwcitn'
+PCIT       = -3.1713744e-016     VOFF       = -0.14555693         LVOFF      = '-1.188177e-008+dlvoffn'
+WVOFF      = '1.3029025e-009+dwvoffn'
+PVOFF      = '2.4776275e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019787828+du0n'  LU0        = '-5.0619488e-010+dlu0n'
+WU0        = '1.1991766e-010+dwu0n'
+PU0        = '-1.0132143e-016+dpu0n'
+UA         = -1.4160953e-009     LUA        = 2.8364855e-016      WUA        = 9.8538358e-018
+PUA        = -6.1041084e-023     UB         = 2.1751911e-018      LUB        = -4.2376047e-025
+WUB        = 1.5088364e-026      PUB        = 5.7980026e-032      UC         = 4.1488701e-011
+LUC        = -5.2857499e-017     WUC        = -2.7064689e-018     PUC        = 5.3676738e-024
+VSAT       = '109991.66+dvsatn'  LVSAT      = '8.3113569e-005+dlvsatn'
+WVSAT      = '2.6689462e-006+dwvsatn'
+PVSAT      = '-2.6596342e-011+dpvsatn'
+A0         = 2.5602871           LA0        = '-1.0968083e-006+dla0n'
+WA0        = -5.6175997e-008     PA0        = 7.1199573e-014      AGS        = 0.78787773
+LAGS       = 3.6105576e-008      WAGS       = 1.6027857e-008      PAGS       = 5.3864572e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020217326        LKETA      = 5.8416966e-009
+WKETA      = -4.4736266e-009     PKETA      = -4.8751095e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0018516752+dpdiblc2n'
+LPDIBLC2   = 2.7167764e-009      WPDIBLC2   = 1.7577829e-010      PPDIBLC2   = -5.2995312e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016612908        LTVOFF     = -6.2577869e-011
+WTVOFF     = -4.3119011e-011     PTVOFF     = -8.6941049e-017     KT1        = -0.16216021
+LKT1       = -8.7749359e-008     WKT1       = -4.6705847e-009     PKT1       = 6.2623747e-015
+KT1L       = 0                   KT2        = -0.073651203        LKT2       = -1.3075522e-008
+WKT2       = 2.8836182e-009      PKT2       = 1.2501079e-015      UTE        = -0.91695187
+LUTE       = -2.9301095e-007     WUTE       = -3.7953218e-008     PUTE       = 3.4947594e-014
+UA1        = 1.6683918e-009      LUA1       = -6.8153127e-016     WUA1       = -2.9873049e-017
+PUA1       = 7.4469758e-023      UB1        = -1.3894768e-018     LUB1       = 5.2342433e-025
+WUB1       = -6.4827623e-027     PUB1       = -1.0985619e-031     UC1        = 3.4504068e-011
+LUC1       = 4.4794652e-016      WUC1       = -1.8320158e-019     PUC1       = -6.1171587e-023
+PRT        = 0                   AT         = 199165.95           LAT        = 0.0083113569
+WAT        = 0.00026689462       PAT        = -2.6596342e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'
+PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln'
+LMAX       = '1.000002e-006-dxln'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44102656+dvthn'  LVTH0      = '-7.3064059e-010+dlvthn'
+WVTH0      = '-4.989133e-009+dwvthn'
+PVTH0      = '-1.7089884e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0030841439+dk2n'
+LK2        = -1.7471541e-009     WK2        = 1.722962e-009       PK2        = -1.4881416e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011992438
+LCIT       = '-1.4168183e-010+dlcitn'
+WCIT       = '-8.7588649e-011+dwcitn'
+PCIT       = 1.4294291e-017      VOFF       = -0.15305248         LVOFF      = '-4.6477361e-009+dlvoffn'
+WVOFF      = '1.0088296e-009+dwvoffn'
+PVOFF      = '5.3157543e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.090996667+deta0n'
+WETA0      = '-1.9189333e-009+dweta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019886018+du0n'  LU0        = '-6.0095944e-010+dlu0n'
+WU0        = '1.9551924e-011+dwu0n'
+PU0        = '-4.4574475e-018+dpu0n'
+UA         = -1.1110295e-009     LUA        = -1.0773486e-017     WUA        = -6.3502928e-017
+PUA        = 9.756262e-024       UB         = 1.7905694e-018      LUB        = -5.2558224e-026
+WUB        = 8.9143207e-026      PUB        = -1.3491044e-032     UC         = -2.0787412e-011
+LUC        = 7.2457998e-018      WUC        = 4.2527925e-018      PUC        = -1.348779e-024
+VSAT       = '110077.78+dvsatn'  WVSAT      = '-2.4888889e-005+dwvsatn'
+A0         = 1.4387986           LA0        = '-1.4448542e-008+dla0n'
+WA0        = 9.3419726e-008      PA0        = -7.3176755e-014     AGS        = 0.48121726
+LAGS       = 3.3206667e-007      WAGS       = 8.7900211e-008      PAGS       = -1.5500155e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.006990853        LKETA      = -6.9233048e-009
+WKETA      = -1.1518669e-008     PKETA      = 1.9241315e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.25972553          LPCLM      = -1.0447143e-012
+WPCLM      = 5.9095831e-008      PPCLM      = 3.3430856e-019      PDIBLC1    = 0
+PDIBLC2    = '0.0056323094+dpdiblc2n'
+LPDIBLC2   = -9.3195145e-010     WPDIBLC2   = -4.3491454e-010     PPDIBLC2   = 5.9432633e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016763501        LTVOFF     = -7.7111719e-011
+WTVOFF     = -1.4776636e-010     PTVOFF     = 1.4055149e-017      KT1        = -0.27465483
+LKT1       = 2.0820326e-008      WKT1       = 6.3670941e-009      PKT1       = -4.3901995e-015
+KT1L       = 0                   KT2        = -0.096034015        LKT2       = 8.5263542e-009
+WKT2       = 5.2512249e-009      PKT2       = -1.034893e-015      UTE        = -1.3450582
+LUTE       = 1.2015872e-007      WUTE       = 1.7117021e-008      PUTE       = -1.8201244e-014
+UA1        = 9.9167261e-010      LUA1       = -2.8422861e-017     WUA1       = 7.8541349e-017
+PUA1       = -3.0162062e-023     UB1        = -9.5222251e-019     LUB1       = 1.0142584e-025
+WUB1       = -1.5428706e-025     PUB1       = 3.2791213e-032      UC1        = 6.2488934e-010
+LUC1       = -1.2184022e-016     WUC1       = -8.1201539e-017     PUC1       = 1.702002e-023
+PRT        = 0                   AT         = 272864.16           LAT        = -0.062815518
+WAT        = -0.006491667        PAT        = 3.8631212e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n'
+PETA0      = '0+dpeta0n'         PVSAT      = '0+dpvsatn'         LVSAT      = '0+dlvsatn'
+LNFACTOR   = '0+dlnfactorn'      WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln'
+LMAX       = '2.399959e-007-dxln'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45945038+dvthn'  LVTH0      = '-4.9309045e-009+dlvthn'
+WVTH0      = '-9.2809733e-009+dwvthn'
+PVTH0      = '8.0755491e-016+dpvthn'
+K1         = 0.31994             K2         = '-0.0051767884+dk2n'
+LK2        = -1.270073e-009      WK2        = 4.7239043e-010      PK2        = 1.3629114e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00052078982
+LCIT       = '2.5045144e-010+dlcitn'
+WCIT       = '7.1909851e-012+dwcitn'
+PCIT       = -7.3135697e-018     VOFF       = -0.16902629         LVOFF      = '-1.0060278e-009+dlvoffn'
+WVOFF      = '4.2869811e-009+dwvoffn'
+PVOFF      = '-2.1577756e-016+dpvoffn'
+NFACTOR    = '0.75+dnfactorn'    ETA0       = '0.053643565+deta0n'
+LETA0      = '8.5157601e-009+dleta0n'
+WETA0      = '3.3105009e-009+dweta0n'
+PETA0      = '-1.1922064e-015+dpeta0n'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018716753+du0n'  LU0        = '-3.3439041e-010+dlu0n'
+WU0        = '-3.5343762e-010+dwu0n'
+PU0        = '8.0576709e-017+dpu0n'
+UA         = -1.0699161e-009     LUA        = -2.0146527e-017     WUA        = -6.7070912e-017
+PUA        = 1.0569691e-023      UB         = 1.6471084e-018      LUB        = -1.9851994e-026
+WUB        = 5.7072951e-026      PUB        = -6.1796667e-033     UC         = -4.4895282e-012
+LUC        = 3.5302083e-018      WUC        = 8.223327e-020       PUC        = -3.9797494e-025
+VSAT       = '127361.64+dvsatn'  LVSAT      = '-0.0039403743+dlvsatn'
+WVSAT      = '-0.00022324674+dwvsatn'
+PVSAT      = '4.5221623e-011+dpvsatn'
+A0         = 2.9007007           LA0        = '-3.4773299e-007+dla0n'
+WA0        = -2.5902588e-007     PA0        = 7.1737938e-015      AGS        = 1.1681751
+LAGS       = 1.7545402e-007      WAGS       = 3.4337137e-008      PAGS       = -3.2888453e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.091684306        LKETA      = 1.2385109e-008
+WKETA      = 8.2727232e-009      PKETA      = -2.5879101e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.10444213         LPCLM      = 8.3021898e-008
+WPCLM      = 7.7808664e-008      PPCLM      = -4.2658173e-015     PDIBLC1    = 0
+PDIBLC2    = '0.0019389061+dpdiblc2n'
+LPDIBLC2   = -8.9929363e-011     WPDIBLC2   = -3.0044995e-010     PPDIBLC2   = 2.8777396e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0014974253        LTVOFF     = -3.6320451e-011
+WTVOFF     = -1.4868844e-010     PTVOFF     = 1.4265366e-017      KT1        = -0.11754841
+LKT1       = -1.4996797e-008     WKT1       = -2.2859971e-008     PKT1       = 2.2729868e-015
+KT1L       = 0                   KT2        = -0.070200221        LKT2       = 2.6367656e-009
+WKT2       = 1.999345e-009       PKT2       = -2.9352944e-016     UTE        = -0.85631913
+LUTE       = 8.7359953e-009      WUTE       = -4.8834951e-008     PUTE       = -3.1655136e-015
+UA1        = 8.5127789e-010      LUA1       = 3.5843275e-018      WUA1       = 1.58184e-018
+PUA1       = -1.2616833e-023     UB1        = -5.9081832e-019     LUB1       = 1.9032907e-026
+WUB1       = -2.9180118e-026     PUB1       = 4.2693323e-033      UC1        = 8.9570029e-011
+LUC1       = 2.0188224e-019      WUC1       = -4.1294185e-018     PUC1       = -5.5088158e-025
+PRT        = 0                   AT         = -24643.815          LAT        = 0.0050103502
+WAT        = 0.017486021         PAT        = -1.6033121e-009
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn'               CJD        = 'cjn'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn'             CJSWD      = 'cjswn'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'            CJSWGD     = 'cjswgn'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn'
+WNFACTOR   = '0+dwnfactorn'      PNFACTOR   = '0+dpnfactorn'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln'       XW         = '2.0e-08+dxwn'      DLC        = '-5.415E-09+ddlcn'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.36071788+dvthn'  LVTH0      = '4.5257928e-009+dlvthn'
+WVTH0      = '-5.95745e-010+dwvthn'
+PVTH0      = '-2.4324941e-017+dpvthn'
+K1         = 0.31994             K2         = '-0.017993665+dk2n' LK2        = -4.245975e-011
+WK2        = 1.4810162e-009      PK2        = 3.9683957e-017      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -5.9211109e-005     LCIT       = '2.0624097e-010+dlcitn'
+WCIT       = '-5.9918863e-012+dwcitn'
+PCIT       = -6.0509011e-018     VOFF       = -0.13155585         LVOFF      = '-4.5949844e-009+dlvoffn'
+WVOFF      = '2.6215158e-009+dwvoffn'
+PVOFF      = '-5.6257627e-017+dpvoffn'
+NFACTOR    = '0.75+dnfactorn+0.69479*ss_flag-0.285042*ff_flag'
+ETA0       = '0.10887736+deta0n' LETA0      = '3.2254122e-009+dleta0n'
+WETA0      = '-5.030526e-009+dweta0n'
+PETA0      = '-3.9329451e-016+dpeta0n'
+ETAB       = -0.2088503          LETAB      = 6.034125e-009       WETAB      = 2.0958427e-008
+PETAB      = -1.049575e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0038987013+du0n' LU0        = '1.0848974e-009+dlu0n'
+WU0        = '1.8549544e-009+dwu0n'
+PU0        = '-1.3094529e-016+dpu0n'
+UA         = -2.711597e-009      LUA        = 1.3709532e-016      WUA        = 7.3907108e-017
+PUA        = -2.9333248e-024     UB         = 2.065192e-018       LUB        = -5.9896453e-026
+WUB        = 8.7568051e-026      PUB        = -9.1005179e-033     UC         = 8.4822175e-011
+LUC        = -5.0241559e-018     WUC        = -1.7519653e-018     PUC        = -2.2229358e-025
+VSAT       = '86222.222+dvsatn+1247.06*ss_flag'
+WVSAT      = '0.00024888889+dwvsatn-0.000399059*ss_flag'
+A0         = -0.45808519         LA0        = '-2.6025116e-008+dla0n'
+WA0        = 5.5202439e-007      PA0        = -7.0509412e-014     AGS        = 1.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.087025563
+LKETA      = -4.7319014e-009     WKETA      = -5.9125793e-008     PKETA      = 3.8675872e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.089655853
+LPCLM      = 8.1605653e-008      WPCLM      = 1.2828746e-007      PPCLM      = -9.1007273e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.00040143075+dpdiblc2n'
+LPDIBLC2   = 5.7331562e-011      WPDIBLC2   = 8.3799696e-011      PPDIBLC2   = -8.0264186e-018
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn'
+RDW        = '65+drdswn'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon'
+CGDO       = 'cgon'              CGBO       = 0                   CGDL       = 'cgln'
+CGSL       = 'cgln'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0015650114        LTVOFF     = -4.2793916e-011
+WTVOFF     = 6.9682922e-011      PTVOFF     = -6.6504612e-018     KT1        = -0.27336375
+LKT1       = -7.2647279e-011     WKT1       = 8.1190665e-009      PKT1       = -6.9421642e-016
+KT1L       = 0                   KT2        = -0.046973328        LKT2       = 4.120706e-010
+WKT2       = 9.2200548e-010      PKT2       = -1.9034079e-016     UTE        = -0.38851129
+LUTE       = -3.6071108e-008     WUTE       = -2.1317063e-007     PUTE       = 1.2574723e-014
+UA1        = 9.3863422e-010      LUA1       = -4.782749e-018      WUA1       = -3.954698e-016
+PUA1       = 2.541317e-023       UB1        = 4.7400456e-019      LUB1       = -8.2956893e-026
+WUB1       = 1.5217483e-025      PUB1       = -1.3101026e-032     UC1        = 5.5175742e-011
+LUC1       = 3.4962015e-018      WUC1       = -2.6521114e-017     PUC1       = 1.5938174e-024
+PRT        = 0                   AT         = 27666.667           WAT        = 0.00074666667
+NOIA       = 'noian'
+NOIB       = 'noibn'
+NOIC       = 'noicn'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn'
+CJD        = 'cjn'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn'
+CJSWD      = 'cjswn'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn'
+CJSWGD     = 'cjswgn'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+PVSAT      = '0+dpvsatn+3.8222e-11*ss_flag'
+LVSAT      = '0+dlvsatn-0.000119444*ss_flag'
+LNFACTOR   = '0+dlnfactorn-6.65473e-08*ss_flag+2.73014e-08*ff_flag'
+WNFACTOR   = '0+dwnfactorn-1.19718e-07*ss_flag+3.99059e-08*ff_flag'
+PNFACTOR   = '0+dpnfactorn+1.14666e-14*ss_flag-3.8222e-15*ff_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )

**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************



.MODEL pch.1 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp'
+LMAX       = 2.000001e-05        WMIN       = '1e-005-dxwp'       WMAX       = 0.00090000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40478507+dvthp' K1         = 0.23752
+K2         = '0.01799+dk2p'      K3         = -2.4570454          K3B        = 2.1204211
+W0         = 0                   DVT0       = 10.498235           DVT1       = 1.3326361
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.4494              MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1e-010              DVTP1      = 0.3712
+LPE0       = 1.4959847e-007      LPEB       = 3.4167544e-008      WEB        = -210
+WEC        = -3510               SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020
+NDEP       = 6.3687e+017         NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 3.295e-005          VOFF       = -0.090520243        NFACTOR    = '0.7+dnfactorp'
+ETA0       = '0.15257+deta0p'    ETAB       = -0.1161             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p'      UA         = 2.125e-009
+UB         = 1.1188572e-018      UC         = 5.989e-011          VSAT       = '110000+dvsatp'
+A0         = 4.1738374           AGS        = 1.0392952           A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04364            DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2p'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.002061            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2107
+KT1L       = 0                   KT2        = -0.04721            UTE        = -1.871
+UA1        = -4.98e-010          UB1        = -2e-018             UC1        = 2.97e-011
+PRT        = 0
+AT         = '190000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'
+WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'
+WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp'
+LMAX       = '1.000249e-005-dxlp'
+WMIN       = '1e-005-dxwp'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40465395+dvthp' LVTH0      = '-1.3068431e-009+dlvthp'
+K1         = 0.23752             K2         = '0.01701623+dk2p'   LK2        = '9.7051776e-009+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -1.7211113e-005
+LCIT       = '4.9993574e-010+dlcitp'
+VOFF       = -0.090095029        LVOFF      = '-4.2379431e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15257+deta0p'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p'
+LU0        = '1.4985763e-010+dlu0p'
+UA         = 2.1364918e-009      LUA        = -1.1453404e-016     UB         = 1.120458e-018
+LUB        = -1.5954699e-026     UC         = 5.655953e-011       LUC        = 3.3193464e-017
+VSAT       = '110000+dvsatp'     A0         = 4.2339233           LA0        = -5.9885154e-007
+AGS        = 1.0187726           LAGS       = 2.045409e-007       A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.039535177        LKETA      = -4.0911132e-008     DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035560074+dpdiblc2p'
+LPDIBLC2   = 6.4224697e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021063228
+LTVOFF     = -4.517137e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2088205          LKT1       = -1.8732203e-008     KT1L       = 0
+KT2        = -0.047125154        LKT2       = -8.4562518e-010     UTE        = -1.8654152
+LUTE       = -5.5661404e-008     UA1        = -5.2291677e-010     LUA1       = 2.4833549e-016
+UB1        = -1.9183761e-018     LUB1       = -8.1351283e-025     UC1        = 6.2424743e-011
+LUC1       = -3.2615442e-016     PRT        = 0
+AT         = '191611+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.016056174+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'
+PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'         WETA0      = '0+dweta0p'
+PETA0      = '0+dpeta0p'         WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp'
+LMAX       = '1.002493e-006-dxlp'
+WMIN       = '1e-005-dxwp'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40092504+dvthp' LVTH0      = '-4.9112115e-009+dlvthp'
+K1         = 0.23752             K2         = '0.026125594+dk2p'  LK2        = '9.0007509e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00023972529
+LCIT       = '2.5158128e-010+dlcitp'
+VOFF       = -0.086981097        LVOFF      = '-7.247866e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15257+deta0p'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p'
+UA         = 2.0886074e-009      LUA        = -6.8249074e-017     UB         = 1.0708166e-018
+LUB        = 3.2028626e-026      UC         = 6.8468081e-011      LUC        = 2.168267e-017
+VSAT       = '110000+dvsatp'     A0         = 4.0877297           LA0        = -4.5754098e-007
+AGS        = 0.54098468          LAGS       = 6.6637023e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.066038936        LKETA      = -1.5292624e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.007+dpdiblc2p'    PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 2.1                 DELTA      = 0.036
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55                  RSW        = '75+drdswp'         RDW        = '75+drdswp'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.945e-007          ALPHA1     = 0.23                BETA0      = 17.8
+AGIDL      = 1e-008              BGIDL      = 2.317e+009          CGIDL      = 4.6
+EGIDL      = 0.008744            AIGBACC    = 0.012459            BIGBACC    = 0.0046798592
+CIGBACC    = 0.245               NIGBACC    = 8.2582031           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.006941            BIGC       = 0.0013212138
+CIGC       = 0.1525875           AIGSD      = 0.00629             BIGSD      = 0.00033134367
+CIGSD      = 0.01328125          NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.84                NTOX       = 'ntoxp'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop'              CGDO       = 'cgop'
+CGBO       = 0                   CGDL       = 'cglp'              CGSL       = 'cglp'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 6.8381              NOFF       = 2.3364              VOFFCV     = -0.069707
+TVOFF      = 0.0013759405        LTVOFF     = 2.542731e-010       WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2366354          LKT1       = 8.1536504e-009
+KT1L       = 0                   KT2        = -0.046125466        LKT2       = -1.8119223e-009
+UTE        = -2.0398459          LUTE       = 1.1294316e-007      UA1        = -3.6894314e-010
+LUA1       = 9.9504733e-017      UB1        = -2.8318571e-018     LUB1       = 6.9457022e-026
+UC1        = -3.7734954e-010     LUC1       = 9.8930958e-017      PRT        = 0
+AT         = '209960.05+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.033792351+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'
+PVTH0      = '0+dpvthp'          WK2        = '0+dwk2p'           PK2        = '0+dpk2p'
+WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'         WVOFF      = '0+dwvoffp'
+PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'           WU0        = '0+dwu0p'
+PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp'
+LMAX       = '2.399996e-007-dxlp'
+WMIN       = '1e-005-dxwp'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43586814+dvthp' LVTH0      = '3.1291616e-009+dlvthp'
+K1         = 0.23752             K2         = '0.026688227+dk2p'  LK2        = '7.7061392e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00050750804
+LCIT       = '1.8996473e-010+dlcitp'
+VOFF       = -0.10209394         LVOFF      = '-3.7704156e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.1525715+deta0p'  LETA0      = '-3.4445173e-013+dleta0p'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p'      UA         = 1.9776245e-009      LUA        = -4.2712014e-017
+UB         = 8.7504948e-019      LUB        = 7.707445e-026       UC         = 1.1382387e-010
+LUC        = 1.1246349e-017      VSAT       = '102515.14+dvsatp'  LVSAT      = '0.0017222586+dlvsatp'
+A0         = 2.8553267           LA0        = -1.7396628e-007     AGS        = 2.3173399
+LAGS       = 2.5763267e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.15948292
+LKETA      = 6.2087424e-009      DWG        = 0                   DWB        = 0
+PCLM       = 2.1496972           LPCLM      = '-3.4445173e-008+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.009366305+dpdiblc2p'
+LPDIBLC2   = -5.4448442e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0024847424
+LTVOFF     = -8.6112932e-013     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.19244272         LKT1       = -2.0150426e-009     KT1L       = 0
+KT2        = -0.043364015        LKT2       = -2.4473295e-009     UTE        = -1.5257969
+LUTE       = -5.3390018e-009     UA1        = -4.5404703e-011     LUA1       = 2.5058863e-017
+UB1        = -2.6722123e-018     LUB1       = 3.2722914e-026      UC1        = 1.9891165e-011
+LUC1       = 7.5262703e-018      PRT        = 0
+AT         = '207632.63+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.033256814+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'
+WK2        = '0+dwk2p'           PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'
+PCIT       = '0+dpcitp'          WETA0      = '0+dweta0p'         PETA0      = '0+dpeta0p'
+WVOFF      = '0+dwvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp'
+WMIN       = '1e-005-dxwp'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.37118957+dvthp' LVTH0      = '-3.2416772e-009+dlvthp'
+K1         = 0.23752             K2         = '0.032369455+dk2p'  LK2        = '2.1101295e-010+dlk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0025451145
+LCIT       = '4.9064805e-010+dlcitp'
+VOFF       = -0.069838389        LVOFF      = '-6.9475876e-009+dlvoffp'
+NFACTOR    = '0.7+dnfactorp+0.679147*ff_flag-0.594253*ss_flag+0.339573*sf_flag-0.543317*fs_flag'
+ETA0       = '0.14371879+deta0p-0.0339573*ss_flag'
+LETA0      = '8.716477e-010+dleta0p+3.34479e-09*ss_flag'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018269064+du0p-0.000339573*ss_flag'
+LU0        = '5.0171587e-012+dlu0p+3.34479e-11*ss_flag'
+UA         = 2.8260496e-009      LUA        = -1.2628188e-016     UB         = 1.8598275e-019
+LUB        = 1.4494752e-025      UC         = 2.5109082e-010      LUC        = -2.2744453e-018
+VSAT       = '116757.1+dvsatp+5093.6*ff_flag-8489.33*ss_flag+4074.88*sf_flag-4074.88*fs_flag'
+LVSAT      = '0.00031942577+dlvsatp-0.000501718*ff_flag+0.000836197*ss_flag-0.000401374*sf_flag+0.000401374*fs_flag'
+A0         = -2.4686737          LA0        = 3.5044776e-007      AGS        = 5.584986
+LAGS       = -6.4230468e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.27139688
+LKETA      = 1.7232268e-008      DWG        = 0                   DWB        = 0
+PCLM       = '1.7679439+0.50936*ff_flag-0.50936*ss_flag+0.407488*sf_flag-0.407488*fs_flag'
+Wpclm    = '0+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+LPCLM      = '3.1575288e-009+dlpclmp-5.01718e-08*ff_flag+5.01718e-08*ss_flag-4.01374e-08*sf_flag+4.01374e-08*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035644164+dpdiblc2p'
+LPDIBLC2   = 2.7001609e-011      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0038291897
+LTVOFF     = -1.3328918e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20152438         LKT1       = -1.1204988e-009     KT1L       = 0
+KT2        = -0.07256623         LKT2       = 4.2908867e-010      WKT2       = -3.4270439e-007
+PKT2       = 3.3756383e-014      UTE        = -2.5647553          LUTE       = 9.6998401e-008
+UA1        = -4.88626e-009       LUA1       = 5.0188311e-016      UB1        = 4.1052355e-019
+LUB1       = -2.7092657e-025     UC1        = -2.6143785e-010     LUC1       = 3.5237178e-017
+PRT        = 0
+AT         = '-191122.75+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '0.0060205904+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp'          PVTH0      = '0+dpvthp'          WK2        = '0+dwk2p'
+PK2        = '0+dpk2p'           WCIT       = '0+dwcitp'          PCIT       = '0+dpcitp'
+WETA0      = '0+dweta0p+0.0*ss_flag'
+PETA0      = '0+dpeta0p+0.0*ss_flag'
+WVOFF      = '0+dwvoffp'
+PVOFF      = '0+dpvoffp'
+WU0        = '0+dwu0p+0.0*ss_flag'
+PU0        = '0+dpu0p+0.0*ss_flag'
+LNFACTOR   = '0+dlnfactorp-6.68957e-08*ff_flag+5.85338e-08*ss_flag-3.34479e-08*sf_flag+5.35166e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PNFACTOR   = '0+dpnfactorp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PVSAT      = '0+dpvsatp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+WVSAT      = '0+dwvsatp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+PPCLM      = '0+dppclmp+0.0*ff_flag+0.0*ss_flag+0.0*sf_flag+0.0*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp'
+LMAX       = 2.000001e-05        WMIN       = '1e-006-dxwp'       WMAX       = '1e-005-dxwp'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40568103+dvthp' WVTH0      = '8.9774574e-009+dwvthp'
+K1         = 0.23752             K2         = '0.018667733+dk2p'  WK2        = '-6.790888e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.2646354e-005
+WCIT       = '8.5767547e-010+dwcitp'
+VOFF       = -0.090248724        WVOFF      = '-2.7206214e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p'      UA         = 2.17566e-009
+WUA        = -5.076132e-016      UB         = 1.1405421e-018      WUB        = -2.1728252e-025
+UC         = 6.2729e-011         WUC        = -2.844678e-017      VSAT       = '110000+dvsatp'
+A0         = 4.0329858           WA0        = 1.4113335e-006      AGS        = 1.0486742
+WAGS       = -9.3977301e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.045544
+WKETA      = 1.907808e-008       DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.00097393333+dpdiblc2p'
+WPDIBLC2   = 2.61188e-010        PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0020859333
+LTVOFF     = 0                   WTVOFF     = -2.49832e-010       PTVOFF     = 0
+KT1        = -0.210632           WKT1       = -6.8136e-010        KT1L       = 0
+KT2        = -0.047049067        WKT2       = -1.612552e-009      UTE        = -1.86964
+WUTE       = -1.36272e-008       UA1        = -5.46178e-010       WUA1       = 4.8274356e-016
+UB1        = -2.017e-018         WUB1       = 1.7034e-025         UC1        = 3.0346e-011
+WUC1       = -6.47292e-018       PRT        = 0
+AT         = '189433.33+datp'
+PAT      = '0+dpatp'
+LAT      = '0+dlatp'
+WAT        = '0.005678+dwatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp'               CJD        = 'cjp'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp'             CJSWD      = 'cjswp'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'          PVTH0      = '0+dpvthp'
+LK2        = '0+dlk2p'           PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'
+PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'
+LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'
+WU0        = '0+dwu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp'
+LMAX       = '1.000249e-005-dxlp'
+WMIN       = '1e-006-dxwp'       WMAX       = '1e-005-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40577219+dvthp' LVTH0      = '9.0853098e-010+dlvthp'
+WVTH0      = '1.1204701e-008+dwvthp'
+PVTH0      = '-2.2198048e-014+dpvthp'
+K1         = 0.23752             K2         = '0.017700018+dk2p'  LK2        = '9.6448336e-009+dlk2p'
+WK2        = '-6.8515553e-009+dwk2p'
+PK2        = '6.046471e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00010956611
+LCIT       = '5.6729641e-010+dlcitp'
+WCIT       = '9.2539704e-010+dwcitp'
+PCIT       = '-6.7495389e-016+dpcitp'
+VOFF       = -0.089885889        LVOFF      = '-3.6162331e-009+dlvoffp'
+WVOFF      = '-2.0955804e-009+dwvoffp'
+PVOFF      = '-6.2295337e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p'  LU0        = '1.4985763e-010+dlu0p'
+UA         = 2.185679e-009       LUA        = -9.9855131e-017     WUA        = -4.9285564e-016
+PUA        = -1.4708269e-022     UB         = 1.1467823e-018      LUB        = -6.2193658e-026
+WUB        = -2.6376923e-025     PUB        = 4.6331437e-031      UC         = 5.9336696e-011
+LUC        = 3.3809736e-017      WUC        = -2.7827206e-017     PUC        = -6.1750419e-024
+VSAT       = '110000+dvsatp'     A0         = 4.082638            LA0        = -4.9486334e-007
+WA0        = 1.5158789e-006      PA0        = -1.0419617e-012     AGS        = 1.02975
+LAGS       = 1.8860985e-007      WAGS       = -1.0999371e-007     PAGS       = 1.5962908e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041373691        LKETA      = -4.1563798e-008
+WKETA      = 1.8421917e-008      PKETA      = 6.5397097e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035107849+dpdiblc2p'
+LPDIBLC2   = 6.2077451e-009      WPDIBLC2   = 4.5312959e-011      PPDIBLC2   = 2.1515402e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0021301728        LTVOFF     = -4.4091682e-010
+WTVOFF     = -2.3897727e-010     PTVOFF     = -1.0818479e-016     KT1        = -0.20872938
+LKT1       = -1.8962699e-008     WKT1       = -9.1309027e-010     PKT1       = 2.3095629e-015
+KT1L       = 0                   KT2        = -0.046972985        LKT2       = -7.5827959e-010
+WKT2       = -1.5247384e-009     PKT2       = -8.7520279e-016     UTE        = -1.8648342
+LUTE       = -4.7897352e-008     WUTE       = -5.8215488e-009     PUTE       = -7.7795803e-014
+UA1        = -5.7456501e-010     LUA1       = 2.8292192e-016      WUA1       = 5.175153e-016
+PUA1       = -3.4655599e-022     UB1        = -1.9361064e-018     LUB1       = -8.0623403e-025
+WUB1       = 1.776578e-025       PUB1       = -7.2933566e-032     UC1        = 6.6506529e-011
+LUC1       = -3.6039753e-016     WUC1       = -4.0899501e-017     PUC1       = 3.4311596e-022
+PRT        = 0
+AT         = '191166.05+datp'
+LAT        = '-0.017269307+dlatp'
+WAT        = '0.004458367+dwatp'
+PAT        = '1.2155594e-08+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp'
+LMAX       = '1.002493e-006-dxlp'
+WMIN       = '1e-006-dxwp'       WMAX       = '1e-005-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.3990933+dvthp'  LVTH0      = '-5.5472718e-009+dlvthp'
+WVTH0      = '-1.8353959e-008+dwvthp'
+PVTH0      = '6.3733239e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0267055+dk2p'    LK2        = '9.4014377e-010+dlk2p'
+WK2        = '-5.8106529e-009+dwk2p'
+PK2        = '-4.0148817e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00019073515
+LCIT       = '2.7702552e-010+dlcitp'
+WCIT       = '4.9088123e-010+dwcitp'
+PCIT       = '-2.5495134e-016+dpcitp'
+VOFF       = -0.085868797        LVOFF      = '-7.4991505e-009+dlvoffp'
+WVOFF      = '-1.1145253e-008+dwvoffp'
+PVOFF      = '2.5178708e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15305847+deta0p' WETA0      = '-4.894436e-009+dweta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018320708+du0p'  LU0        = '-6.8450398e-013+dlu0p'
+WU0        = '-7.0957345e-012+dwu0p'
+PU0        = '6.8587299e-018+dpu0p'
+UA         = 2.1571943e-009      LUA        = -7.2321872e-017     WUA        = -6.8724042e-016
+PUA        = 4.0809443e-023      UB         = 1.0503811e-018      LUB        = 3.0987619e-026
+WUB        = 2.0476372e-025      PUB        = 1.0430894e-032      UC         = 7.0564226e-011
+LUC        = 2.2957217e-017      WUC        = -2.100337e-017      PUC        = -1.2770955e-023
+VSAT       = '110000+dvsatp'     A0         = 3.9990876           LA0        = -4.1410363e-007
+WA0        = 8.881941e-007       PA0        = -4.3524225e-013     AGS        = 0.51343683
+LAGS       = 6.8767767e-007      WAGS       = 2.7602949e-007      PAGS       = -2.1350055e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.068491768        LKETA      = -1.5351492e-008
+WKETA      = 2.4577375e-008      PKETA      = 5.8985077e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0067025176+dpdiblc2p'
+LPDIBLC2   = 6.8450398e-011      WPDIBLC2   = 2.9807735e-009      PPDIBLC2   = -6.8587299e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001417086         LTVOFF     = 2.4835214e-010
+WTVOFF     = -4.122785e-010      PTVOFF     = 5.9328014e-017      KT1        = -0.23702705
+LKT1       = 8.3898043e-009      WKT1       = 3.9243084e-009      PKT1       = -2.3662618e-015
+KT1L       = 0                   KT2        = -0.046499384        LKT2       = -1.2160616e-009
+WKT2       = 3.7466529e-009      PKT2       = -5.9705244e-015     UTE        = -2.0256028
+LUTE       = 1.0750135e-007      WUTE       = -1.4271669e-007     PUTE       = 5.4526903e-014
+UA1        = -3.2474037e-010     LUA1       = 4.1441683e-017      WUA1       = -4.4291168e-016
+PUA1       = 5.8179177e-022      UB1        = -2.8877333e-018     LUB1       = 1.1360753e-025
+WUB1       = 5.5987888e-025      PUB1       = -4.4238808e-031     UC1        = -4.1188686e-010
+LUC1       = 1.0201704e-016      WUC1       = 3.4606401e-016      PUC1       = -3.0922584e-023
+PRT        = 0
+AT         = '202541.68+datp'
+LAT        = '-0.028264981+dlatp'
+WAT        = '0.074332056+dwatp'
+PAT        = '-5.5384244e-08+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp'
+LMAX       = '2.399996e-007-dxlp'
+WMIN       = '1e-006-dxwp'       WMAX       = '1e-005-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+dvthp' LVTH0      = '3.2178643e-009+dlvthp'
+WVTH0      = '1.3206912e-008+dwvthp'
+PVTH0      = '-8.8880115e-016+dpvthp'
+K1         = 0.23752             K2         = '0.027489247+dk2p'  LK2        = '7.5980421e-010+dlk2p'
+WK2        = '-8.0262273e-009+dwk2p'
+PK2        = '1.0831329e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitp'
+WCIT       = '-9.439202e-010+dwcitp'
+PCIT       = '7.5195034e-017+dpcitp'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffp'
+WVOFF      = '-5.7821145e-009+dwvoffp'
+PVOFF      = '1.283818e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15306049+deta0p' LETA0      = '-4.6449316e-013+dleta0p'
+WETA0      = '-4.8996634e-009+dweta0p'
+PETA0      = '1.2028151e-018+dpeta0p'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0p'  LU0        = '1.3663252e-012+dlu0p'
+WU0        = '8.2210644e-011+dwu0p'
+PU0        = '-1.3690578e-017+dpu0p'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatp'  LVSAT      = '0.0017671522+dlvsatp'
+WVSAT      = '0.0019549554+dwvsatp'
+PVSAT      = '-4.4983329e-010+dpvsatp'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmp'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2p'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datp'
+LAT        = '-0.036846346+dlatp'
+WAT        = '-0.32267684+dwatp'
+PAT        = '3.5967105e-08+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp'
+WMIN       = '1e-006-dxwp'       WMAX       = '1e-005-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36983935+dvthp' LVTH0      = '-3.4158001e-009+dlvthp'
+WVTH0      = '-1.3529255e-008+dwvthp'
+PVTH0      = '1.7447113e-015+dpvthp'
+K1         = 0.23752             K2         = '0.03417205+dk2p'   LK2        = '1.0154813e-010+dlk2p'
+WK2        = '-1.8062006e-008+dwk2p'
+PK2        = '1.0968375e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0024472326
+LCIT       = '4.8278125e-010+dlcitp'
+WCIT       = '-9.8077622e-010+dwcitp'
+PCIT       = '7.8825353e-017+dpcitp'
+VOFF       = -0.068061807        LVOFF      = '-7.1938663e-009+dlvoffp'
+WVOFF      = '-1.7801351e-008+dwvoffp'
+PVOFF      = '2.4677127e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.756116*ff_flag-0.661602*ss_flag+0.378058*sf_flag-0.604893*fs_flag'
+ETA0       = '0.14447861+deta0p-0.0378058*ss_flag'
+LETA0      = '8.4485e-010+dleta0p+3.72386e-09*ss_flag'
+WETA0      = '-7.6134723e-009+dweta0p+3.85619e-08*ss_flag'
+PETA0      = '2.6851299e-016+dpeta0p-3.79834e-15*ss_flag'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0p-1.92425e-05*ff_flag-0.000320331*ss_flag+0.0*sf_flag+1.5394e-05*fs_flag'
+LU0        = '4.0694732e-012+dlu0p+1.89538e-12*ff_flag+3.15525e-11*ss_flag+0.0*sf_flag-1.5163e-12*fs_flag'
+WU0        = '-1.5318415e-010+dwu0p+1.9281e-10*ff_flag-1.9281e-10*ss_flag+0.0*sf_flag-1.54248e-10*fs_flag'
+PU0        = '9.495809e-018+dpu0p-1.89917e-17*ff_flag+1.89917e-17*ss_flag+0.0*sf_flag+1.51934e-17*fs_flag'
+UA         = 2.9435284e-009      LUA        = -1.3230537e-016     WUA        = -1.177138e-015
+PUA        = 6.0355362e-023      UB         = 7.9012478e-020      LUB        = 1.5372039e-025
+WUB        = 1.0718421e-024      PUB        = -8.7904172e-032     UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '116650.24+dvsatp+5670.87*ff_flag-8489.34*ss_flag+4536.7*sf_flag-4536.7*fs_flag'
+LVSAT      = '0.00035562736+dlvsatp-0.000558579*ff_flag+0.000836197*ss_flag-0.000446864*sf_flag+0.000446864*fs_flag'
+WVSAT      = '0.0010707586+dwvsatp-0.00578429*ff_flag-4.8e-09*ss_flag-0.00462743*sf_flag+0.00462743*fs_flag'
+PVSAT      = '-3.6273991e-010+dpvsatp+5.69751e-10*ff_flag-2e-17*ss_flag+4.55801e-10*sf_flag-4.55801e-10*fs_flag'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.8381261+0.563239*ff_flag-0.547845*ss_flag+0.45367*sf_flag-0.450591*fs_flag'
+LPCLM      = '3.5007467e-009+dlpclmp-5.54788e-08*ff_flag+5.39625e-08*ss_flag-4.46864e-08*sf_flag+4.43831e-08*fs_flag'
+WPCLM      = '-7.0322585e-007-5.39867e-07*ff_flag+3.85619e-07*ss_flag-4.62743e-07*sf_flag+4.31893e-07*fs_flag'
+PPCLM      = '-3.439044e-015+dppclmp+5.31768e-14*ff_flag-3.79834e-14*ss_flag+4.55801e-14*sf_flag-4.25414e-14*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2p'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datp'
+LAT        = '0.0065683527+dlatp'
+WAT        = '0.09819304+dwatp'
+PAT        = '-5.4885776e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp-7.44773e-08*ff_flag+6.51676e-08*ss_flag-3.72386e-08*sf_flag+5.95818e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-7.71239e-07*ff_flag+6.74834e-07*ss_flag-3.85619e-07*sf_flag+6.16991e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp+7.59668e-14*ff_flag-6.64709e-14*ss_flag+3.79834e-14*sf_flag-6.07734e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.11 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp'
+LMAX       = 2.000001e-05        WMIN       = '6e-007-dxwp'       WMAX       = '1e-006-dxwp'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39498798+dvthp' WVTH0      = '-1.9294524e-009+dwvthp'
+K1         = 0.23752             K2         = '0.01549285+dk2p'   WK2        = '-3.552507e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001967827
+WCIT       = '-1.2032073e-009+dwcitp'
+VOFF       = -0.09144815         WVOFF      = '-1.497207e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0182575+du0p'    WU0        = '-7.905e-011+dwu0p'
+UA         = 1.99885e-009        WUA        = -3.27267e-016       UB         = 8.73301e-019
+WUB        = 5.530338e-026       UC         = 5.0433e-011         WUC        = -1.590486e-017
+VSAT       = '110000+dvsatp'     A0         = 5.6976187           WA0        = -2.8659209e-007
+AGS        = 0.9868853           WAGS       = -3.0952611e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0371165          WKETA      = 1.048203e-008       DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00265352+dpdiblc2p'
+WPDIBLC2   = -1.4519904e-009     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.001624
+LTVOFF     = 0                   WTVOFF     = 2.2134e-010         PTVOFF     = 0
+KT1        = -0.23085728         WKT1       = 1.9948426e-008      KT1L       = 0
+KT2        = -0.0375475          WKT2       = -1.130415e-008      UTE        = -1.70165
+WUTE       = -1.84977e-007       UA1        = 5.98405e-010        WUA1       = -6.847311e-016
+UB1        = -2.3925e-018        WUB1       = 5.5335e-025         UC1        = -5.605e-012
+WUC1       = 3.01971e-017        PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'          PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'
+PK2        = '0+dpk2p'           LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'
+PVOFF      = '0+dpvoffp'          LU0        = '0+dlu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp'
+LMAX       = '1.000249e-005-dxlp'
+WMIN       = '6e-007-dxwp'       WMAX       = '1e-006-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39111725+dvthp' LVTH0      = '-3.8578036e-008+dlvthp'
+WVTH0      = '-3.7433358e-009+dwvthp'
+PVTH0      = '1.807825e-014+dpvthp'
+K1         = 0.23752             K2         = '0.014568275+dk2p'  LK2        = '9.2148693e-009+dlk2p'
+WK2        = '-3.6571777e-009+dwk2p'
+PK2        = '1.0432107e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020873444
+LCIT       = '-1.1911829e-009+dlcitp'
+WCIT       = '-1.3154517e-009+dwcitp'
+PCIT       = '1.118695e-015+dpcitp'
+VOFF       = -0.089940125        LVOFF      = '-1.5029884e-008+dlvoffp'
+WVOFF      = '-2.0402598e-009+dwvoffp'
+PVOFF      = '5.4123897e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018250788+du0p'  LU0        = '6.6900726e-011+dlu0p'
+WU0        = '-8.753996e-011+dwu0p'
+PU0        = '8.4616038e-017+dpu0p'
+UA         = 2.0283313e-009      LUA        = -2.9382799e-016     WUA        = -3.3236098e-016
+PUA        = 5.0769623e-023      UB         = 8.391319e-019       LUB        = 3.4054974e-025
+WUB        = 5.0034171e-026      PUB        = 5.2516098e-032      UC         = 5.0128521e-011
+LUC        = 3.0346169e-018      WUC        = -1.8434868e-017     PUC        = 2.5215579e-023
+VSAT       = '110000+dvsatp'     A0         = 5.8948522           LA0        = -1.9657469e-006
+WA0        = -3.3257964e-007     PA0        = 4.5833947e-013      AGS        = 0.95157211
+LAGS       = 3.5195244e-007      WAGS       = -3.0252237e-008     PAGS       = -6.980351e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033294837        LKETA      = -3.8088992e-008
+WKETA      = 1.0181485e-008      PKETA      = 2.9954078e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.001805439+dpdiblc2p'
+LPDIBLC2   = 8.4524839e-009      WPDIBLC2   = -1.4381348e-009     PPDIBLC2   = -1.3809337e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001669892         LTVOFF     = -4.5738688e-010
+WTVOFF     = 2.3050916e-010      PTVOFF     = -9.1385321e-017     KT1        = -0.23024672
+LKT1       = -6.0852472e-009     WKT1       = 2.1034597e-008      PKT1       = -1.0825437e-014
+KT1L       = 0                   KT2        = -0.035304454        LKT2       = -2.2355547e-008
+WKT2       = -1.342664e-008      PKT2       = 2.115401e-014       UTE        = -1.6698811
+LUTE       = -3.1662776e-007     WUTE       = -2.0467371e-007     PUTE       = 1.9630921e-013
+UA1        = 6.3625325e-010      LUA1       = -3.7721841e-016     WUA1       = -7.1751933e-016
+PUA1       = 3.2678714e-022      UB1        = -2.2894498e-018     LUB1       = -1.0270599e-024
+WUB1       = 5.3806807e-025      PUB1       = 1.5230887e-031      UC1        = -1.1364694e-011
+LUC1       = 5.7404569e-017      WUC1       = 3.8529147e-017      PUC1       = -8.304218e-023
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp'
+LMAX       = '1.002493e-006-dxlp'
+WMIN       = '6e-007-dxwp'       WMAX       = '1e-006-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43560449+dvthp' LVTH0      = '4.4232917e-009+dlvthp'
+WVTH0      = '1.8887457e-008+dwvthp'
+PVTH0      = '-3.7966508e-015+dpvthp'
+K1         = 0.23752             K2         = '0.023882732+dk2p'  LK2        = '2.115241e-010+dlk2p'
+WK2        = '-2.9314302e-009+dwk2p'
+PK2        = '3.417039e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001104327
+LCIT       = '-2.4099921e-010+dlcitp'
+WCIT       = '-4.4098244e-010+dwcitp'
+PCIT       = '2.7343389e-016+dpcitp'
+VOFF       = -0.10137833         LVOFF      = '-3.9737264e-009+dlvoffp'
+WVOFF      = '4.6744705e-009+dwvoffp'
+PVOFF      = '-1.0780618e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14671+deta0p'    WETA0      = '1.581e-009+dweta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018313752+du0p'  LU0        = '6.039741e-012+dlu0p'
+UA         = 1.7761809e-009      LUA        = -5.0099652e-017     WUA        = -2.9860671e-016
+PUA        = 1.8142778e-023      UB         = 1.0785501e-018      LUB        = 1.0912836e-025
+WUB        = 1.7603136e-025      PUB        = -6.927266e-032      UC         = 3.4403006e-011
+LUC        = 1.8234884e-017      WUC        = 1.5881074e-017      PUC        = -7.9541759e-024
+VSAT       = '110000+dvsatp'     A0         = 4.9641532           LA0        = -1.0661342e-006
+WA0        = -9.6172823e-008     PA0        = 2.2982888e-013      AGS        = 0.67053007
+LAGS       = 6.2360739e-007      WAGS       = 1.1579439e-007      PAGS       = -1.4814887e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057803706        LKETA      = -1.4398743e-008
+WKETA      = 1.3675552e-008      PKETA      = -3.8195322e-016     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.012869735+dpdiblc2p'
+LPDIBLC2   = -2.2422539e-009     WPDIBLC2   = -3.3097886e-009     PPDIBLC2   = 1.6710454e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00085005187       LTVOFF     = 3.3506973e-010
+WTVOFF     = 1.6609632e-010      PTVOFF     = -2.9123933e-017     KT1        = -0.24612493
+LKT1       = 9.2626193e-009      WKT1       = 1.3204148e-008      PKT1       = -3.2565332e-015
+KT1L       = 0                   KT2        = -0.052092046        LKT2       = -6.1286762e-009
+WKT2       = 9.4511686e-009      PKT2       = -9.5965747e-016     UTE        = -2.2598535
+LUTE       = 2.5363892e-007      WUTE       = 9.6219042e-008      PUTE       = -9.4533423e-014
+UA1        = -7.5839073e-010     LUA1       = 9.7084307e-016      WUA1       = -5.8832305e-019
+PUA1       = -3.6619765e-022     UB1        = -2.7883902e-018     LUB1       = -5.4478464e-025
+WUB1       = 4.5854899e-025      PUB1       = 2.2917193e-031      UC1        = -4.0697082e-011
+LUC1       = 8.5757226e-017      WUC1       = -3.2549564e-017     PUC1       = -1.4337569e-023
+PRT        = 0
+AT         = '253818.5+datp'
+LAT        = '-0.061686895+dlatp'
+WAT        = '0.022029706+dwatp'
+PAT        = '-2.1293892e-08+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp'
+LMAX       = '2.399996e-007-dxlp'
+WMIN       = '6e-007-dxwp'       WMAX       = '1e-006-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+dvthp' LVTH0      = '1.8657789e-009+dlvthp'
+WVTH0      = '2.5644645e-010+dwvthp'
+PVTH0      = '4.9032594e-016+dpvthp'
+K1         = 0.23752             K2         = '0.021012137+dk2p'  LK2        = '8.7204533e-010+dlk2p'
+WK2        = '-1.4195742e-009+dwk2p'
+PK2        = '-6.1726576e-018+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitp'
+WCIT       = '1.6122937e-009+dwcitp'
+PCIT       = '-1.9902291e-016+dpcitp'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffp'
+WVOFF      = '-2.10792e-009+dwvoffp'
+PVOFF      = '4.8255944e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.14756059+deta0p' LETA0      = '-1.9572049e-010+dleta0p'
+WETA0      = '7.102273e-010+dweta0p'
+PETA0      = '2.0036393e-016+dpeta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0p'  LU0        = '-1.2055811e-011+dlu0p'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatp'  LVSAT      = '0.0033816548+dlvsatp'
+WVSAT      = '0.0091118432+dwvsatp'
+PVSAT      = '-2.096626e-009+dpvsatp'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmp'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2p'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datp'
+LAT        = '-0.010714171+dlatp'
+WAT        = '-0.11098338+dwatp'
+PAT        = '9.3122869e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p'
+PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp'
+WMIN       = '6e-007-dxwp'       WMAX       = '1e-006-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4183589+dvthp'  LVTH0      = '1.2618987e-009+dlvthp'
+WVTH0      = '3.5960684e-008+dwvthp'
+PVTH0      = '-3.0265415e-015+dpvthp'
+K1         = 0.23752             K2         = '0.022738541+dk2p'  LK2        = '7.0199448e-010+dlk2p'
+WK2        = '-6.399827e-009+dwk2p'
+PK2        = '4.8438224e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.003713364
+LCIT       = '6.2948623e-010+dlcitp'
+WCIT       = '3.1067772e-010+dwcitp'
+PCIT       = '-7.0813731e-017+dpcitp'
+VOFF       = -0.10614675         LVOFF      = '-3.0117636e-009+dlvoffp'
+WVOFF      = '2.1045293e-008+dwvoffp'
+PVOFF      = '-1.798032e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.394754*ff_flag+0.394754*ss_flag+0.315803*sf_flag-0.315803*fs_flag'
+ETA0       = '0.11688678+deta0p' LETA0      = '2.82565e-009+dleta0p'
+WETA0      = '2.0530196e-008+dweta0p'
+PETA0      = '-1.751903e-015+dpeta0p'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0p+0.000432956*ff_flag-0.00129887*ss_flag+0.0*sf_flag-0.000346365*fs_flag'
+LU0        = '1.337909e-011+dlu0p-4.2646e-11*ff_flag+1.27938e-10*ss_flag+0.0*sf_flag+3.41168e-11*fs_flag'
+UA         = 1.3899922e-009      LUA        = -1.4990434e-017     WUA        = 4.0746901e-016
+PUA        = -5.9305876e-023     UB         = 3.3204841e-018      LUB        = -1.0111129e-025
+WUB        = -2.234459e-024      PUB        = 1.7202414e-031      UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '132266.67+dvsatp+2631.69*ff_flag-21647.8*ss_flag+2105.35*sf_flag-2105.35*fs_flag'
+LVSAT      = '-0.00025921987+dlvsatp-0.000259221*ff_flag+0.0021323*ss_flag-0.000207377*sf_flag+0.000207377*fs_flag'
+WVSAT      = '-0.014858007+dwvsatp-0.00268433*ff_flag+0.0134216*ss_flag-0.00214746*sf_flag+0.00214746*fs_flag'
+PVSAT      = '2.6440426e-010+dpvsatp+2.64405e-10*ff_flag-1.32203e-09*ss_flag+2.11524e-10*sf_flag-2.11524e-10*fs_flag'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = '1.3863246+0.0865912*ff_flag-0.432956*ss_flag+0.0*sf_flag-0.0692729*fs_flag'
+LPCLM      = '-7.7061899e-009+dlpclmp-8.52921e-09*ff_flag+4.2646e-08*ss_flag+0.0*sf_flag+6.82337e-09*fs_flag'
+WPCLM      = '-2.4238831e-007-5.36865e-08*ff_flag+2.68433e-07*ss_flag+0.0*sf_flag+4.29492e-08*fs_flag'
+PPCLM      = '7.9920313e-015+dppclmp+5.28811e-15*ff_flag-2.64405e-14*ss_flag+0.0*sf_flag-4.23049e-15*fs_flag'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2p'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datp'
+LAT        = '-0.0064077479+dlatp'
+WAT        = '-0.095092602+dwatp'
+PAT        = '7.7470449e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p-2.68433e-10*ff_flag+8.05298e-10*ss_flag+0.0*sf_flag+2.14746e-10*fs_flag'
+PU0        = '0+dpu0p+2.64405e-17*ff_flag-7.93216e-17*ss_flag+0.0*sf_flag-2.11524e-17*fs_flag'
+LNFACTOR   = '0+dlnfactorp-3.88831e-08*ff_flag-3.88831e-08*ss_flag-3.11065e-08*sf_flag+3.11065e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-4.02649e-07*ff_flag-4.02649e-07*ss_flag-3.22119e-07*sf_flag+3.22119e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp+3.96608e-14*ff_flag+3.96608e-14*ss_flag+3.17286e-14*sf_flag-3.17286e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.16 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp'
+LMAX       = 2.000001e-05        WMIN       = '3e-007-dxwp'       WMAX       = '6e-007-dxwp'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39586+dvthp'    WVTH0      = '-1.3888e-009+dwvthp'
+K1         = 0.23752             K2         = '0.0081982+dk2p'    WK2        = '9.70176e-010+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 2.2391333e-005
+WCIT       = '2.9627733e-012+dwcitp'
+VOFF       = -0.091604867        WVOFF      = '-1.4000427e-009+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01813+du0p'      UA         = 1.8358e-009
+WUA        = -2.26176e-016       UB         = 9.8152549e-019      WUB        = -1.1795806e-026
+UC         = 1.2716e-011         WUC        = 7.47968e-018        VSAT       = '110000+dvsatp'
+A0         = 4.9147812           WA0        = 1.9876721e-007      AGS        = 0.91700495
+WAGS       = 1.2373205e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.024978
+WKETA      = 2.95616e-009        DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '-0.0010155488+dpdiblc2p'
+WPDIBLC2   = 8.2283226e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021580667
+LTVOFF     = 0                   WTVOFF     = -1.0978133e-010     PTVOFF     = 0
+KT1        = -0.20282363         WKT1       = 2.5675605e-009      KT1L       = 0
+KT2        = -0.068142667        WKT2       = 7.6648533e-009      UTE        = -2
+UA1        = -6.0133333e-011     WUA1       = -2.7643733e-016     UB1        = -2.9933333e-018
+WUB1       = 9.2586667e-025      UC1        = 1.2064667e-010      WUC1       = -4.8078933e-017
+PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'           PK2        = '0+dpk2p'
+LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'
+LU0        = '0+dlu0p'           WU0        = '0+dwu0p'           PU0        = '0+dpu0p'
+LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'
+LPCLM      = '0+dlpclmp'          PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp'
+LMAX       = '1.000249e-005-dxlp'
+WMIN       = '3e-007-dxwp'       WMAX       = '6e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39511135+dvthp' LVTH0      = '-7.4615193e-009+dlvthp'
+WVTH0      = '-1.2669942e-009+dwvthp'
+PVTH0      = '-1.21399e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0067699412+dk2p' LK2        = '1.4234884e-008+dlk2p'
+WK2        = '1.1777893e-009+dwk2p'
+PK2        = '-2.0691983e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -2.2145724e-005
+LCIT       = '4.4388304e-010+dlcitp'
+WCIT       = '-7.5678113e-012+dwcitp'
+PCIT       = '1.0495413e-016+dpcitp'
+VOFF       = -0.090810617        LVOFF      = '-7.9159727e-009+dlvoffp'
+WVOFF      = '-1.5005549e-009+dwvoffp'
+PVOFF      = '1.001765e-015+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018093556+du0p'  LU0        = '3.6322634e-010+dlu0p'
+WU0        = '9.9437966e-012+dwu0p'
+PU0        = '-9.9105843e-017+dpu0p'
+UA         = 1.8814664e-009      LUA        = -4.5513902e-016     WUA        = -2.4130478e-016
+PUA        = 1.5078246e-022      UB         = 8.9943727e-019      LUB        = 8.1814046e-025
+WUB        = 1.2644841e-026      PUB        = -2.4359015e-031     UC         = 5.3614712e-012
+LUC        = 7.3299647e-017      WUC        = 9.3207029e-018      PUC        = -1.8348739e-023
+VSAT       = '110000+dvsatp'     A0         = 4.9358235           LA0        = -2.0972081e-007
+WA0        = 2.6201814e-007      PA0        = -6.3039668e-013     AGS        = 0.88551891
+LAGS       = 3.1380883e-007      WAGS       = 1.070075e-008       PAGS       = 1.6668688e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021109528        LKETA      = -3.8555513e-008
+WKETA      = 2.6265942e-009      PKETA      = 3.2846508e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '-0.0022129374+dpdiblc2p'
+LPDIBLC2   = 1.1933893e-008      WPDIBLC2   = 1.0532586e-009      PPDIBLC2   = -2.296567e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0022502516        LTVOFF     = -9.1876997e-010
+WTVOFF     = -1.2931379e-010     PTVOFF     = 1.9467219e-016      KT1        = -0.20007204
+LKT1       = -2.7424003e-008     WKT1       = 2.3262956e-009      PKT1       = 2.4045909e-015
+KT1L       = 0                   KT2        = -0.071334663        LKT2       = 3.1813347e-008
+WKT2       = 8.9120895e-009      PKT2       = -1.2430704e-014     UTE        = -2
+UA1        = -2.1898977e-011     LUA1       = -3.8106653e-016     WUA1       = -3.0946494e-016
+PUA1       = 3.2917298e-022      UB1        = -3.0398017e-018     LUB1       = 4.6313143e-025
+WUB1       = 1.0032862e-024      PUB1       = -7.7160978e-031     UC1        = 1.3668863e-010
+LUC1       = -1.5988382e-016     WUC1       = -5.3263913e-017     PUC1       = 5.1676618e-023
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp'
+LMAX       = '1.002493e-006-dxlp'
+WMIN       = '3e-007-dxwp'       WMAX       = '6e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4015281+dvthp'  LVTH0      = '-1.25909e-009+dlvthp'
+WVTH0      = '-2.2399062e-009+dwvthp'
+PVTH0      = '-2.7357417e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020322269+dk2p'  LK2        = '1.135217e-009+dlk2p'
+WK2        = '-7.2394308e-010+dwk2p'
+PK2        = '-2.309857e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00012950653
+LCIT       = '2.9729612e-010+dlcitp'
+WCIT       = '1.6340624e-010+dwcitp'
+PCIT       = '-6.0309219e-017+dpcitp'
+VOFF       = -0.094380138        LVOFF      = '-4.4656764e-009+dlvoffp'
+WVOFF      = '3.3559208e-010+dwvoffp'
+PVOFF      = '-7.7305283e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15749467+deta0p' WETA0      = '-5.1054933e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018516405+du0p'  LU0        = '-4.5499382e-011+dlu0p'
+WU0        = '-1.2564511e-010+dwu0p'
+PU0        = '3.1954257e-017+dpu0p'
+UA         = 1.3874016e-009      LUA        = 2.2423545e-017      WUA        = -5.7563571e-017
+PUA        = -2.6821604e-023     UB         = 1.8599319e-018      LUB        = -1.1027271e-025
+WUB        = -3.0842538e-025     PUB        = 6.6756003e-032      UC         = 6.9923054e-011
+LUC        = 1.0894485e-017      WUC        = -6.141356e-018      PUC        = -3.4031283e-024
+VSAT       = '110000+dvsatp'     A0         = 5.5679137           LA0        = -8.2069853e-007
+WA0        = -4.7050432e-007     PA0        = 7.7658793e-014      AGS        = 0.81346956
+LAGS       = 3.8345165e-007      WAGS       = 2.7171899e-008      PAGS       = 7.4769166e-016
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.040814855        LKETA      = -1.9508364e-008
+WKETA      = 3.1424638e-009      PKETA      = 2.7860117e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0094980747+dpdiblc2p'
+LPDIBLC2   = 6.1404034e-010      WPDIBLC2   = -1.219359e-009      PPDIBLC2   = -9.9857052e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00090537312       LTVOFF     = 3.8118819e-010
+WTVOFF     = 1.3179714e-010      PTVOFF     = -5.7717376e-017     KT1        = -0.23415174
+LKT1       = 5.5174081e-009      WKT1       = 5.7807717e-009      PKT1       = -9.3450223e-016
+KT1L       = 0                   KT2        = -0.030743494        LKT2       = -7.4220364e-009
+WKT2       = -3.7849339e-009     PKT2       = -1.5777414e-016     UTE        = -2.1773101
+LUTE       = 1.7138772e-007      WUTE       = 4.5042127e-008      PUTE       = -4.3537675e-014
+UA1        = -1.1220652e-009     LUA1       = 6.8235303e-016      WUA1       = 2.2488985e-016
+PUA1       = -1.8733383e-022     UB1        = -2.1861765e-018     LUB1       = -3.6198181e-025
+WUB1       = 8.5176483e-026      PUB1       = 1.1583418e-031      UC1        = -9.4282854e-011
+LUC1       = 6.3372989e-017      WUC1       = 6.736151e-019       PUC1       = -4.5934244e-025
+PRT        = 0
+AT         = '274020.76+datp'
+LAT        = '-0.081214384+dlatp'
+WAT        = '0.0095043019+dwatp'
+PAT        = '-9.1868488e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'         PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp'
+LMAX       = '2.399996e-007-dxlp'
+WMIN       = '3e-007-dxwp'       WMAX       = '6e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.41517553+dvthp' LVTH0      = '1.8811701e-009+dlvthp'
+WVTH0      = '-5.5183106e-009+dwvthp'
+PVTH0      = '4.807834e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020374292+dk2p'  LK2        = '1.1232467e-009+dlk2p'
+WK2        = '-1.0241103e-009+dwk2p'
+PK2        = '-1.6191751e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00085869844
+LCIT       = '1.2950979e-010+dlcitp'
+WCIT       = '-1.0081518e-010+dwcitp'
+PCIT       = '4.878646e-019+dpcitp'
+VOFF       = -0.10161713         LVOFF      = '-2.8004515e-009+dlvoffp'
+WVOFF      = '-4.2791006e-009+dwvoffp'
+PVOFF      = '2.8878333e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.15634998+deta0p' LETA0      = '2.6339076e-010+dleta0p'
+WETA0      = '-4.7391943e-009+dweta0p'
+PETA0      = '-8.4285042e-017+dpeta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.017556708+du0p'  LU0        = '1.7532593e-010+dlu0p'
+WU0        = '5.1812534e-010+dwu0p'
+PU0        = '-1.1617668e-016+dpu0p'
+UA         = 1.7606824e-009      LUA        = -6.3467987e-017     WUA        = -2.1515951e-016
+PUA        = 9.4410636e-024      UB         = 1.070533e-018       LUB        = 7.1367198e-026
+WUB        = 1.0174729e-025      PUB        = -2.7624318e-032     UC         = 1.2252387e-010
+LUC        = -1.2089108e-018     WUC        = -2.7979981e-017     PUC        = 1.6219176e-024
+VSAT       = '107365.33+dvsatp'  LVSAT      = '0.00060623504+dlvsatp'
+WVSAT      = '0.0016334957+dwvsatp'
+PVSAT      = '-3.7586573e-010+dpvsatp'
+A0         = 2.4886762           LA0        = -1.1216906e-007     WA0        = -1.7134175e-007
+PA0        = 8.821785e-015       AGS        = 4.7607057           LAGS       = -5.2480344e-007
+WAGS       = -2.1052918e-007     PAGS       = 5.5442473e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.12603645         LKETA      = 1.0103917e-010      WKETA      = 1.2478354e-008
+PKETA      = 6.3783275e-016      DWG        = 0                   DWB        = 0
+PCLM       = 2.6591518           LPCLM      = '-1.5167017e-007+dlpclmp'
+WPCLM      = 3.3108978e-008      PPCLM      = '-7.6183427e-015+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.018189484+dpdiblc2p'
+LPDIBLC2   = -1.3858441e-009     WPDIBLC2   = -2.7423305e-009     PPDIBLC2   = 2.5057715e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0028034616        LTVOFF     = -5.5560064e-011
+WTVOFF     = -2.6970243e-011     PTVOFF     = -2.1185159e-017     KT1        = -0.21668017
+LKT1       = 1.4972169e-009      WKT1       = 9.2746875e-010      PKT1       = 1.8223793e-016
+KT1L       = 0                   KT2        = -0.053089879        LKT2       = -2.2801556e-009
+WKT2       = -6.6189077e-009     PKT2       = 4.9432038e-016      UTE        = -1.3070703
+LUTE       = -2.8853573e-008     WUTE       = -2.817803e-007      PUTE       = 3.166384e-014
+UA1        = 3.5137962e-009      LUA1       = -3.8435405e-016     WUA1       = -1.2145568e-015
+PUA1       = 1.438814e-022       UB1        = -5.6340411e-018     LUB1       = 4.3136838e-025
+WUB1       = 1.0687354e-024      PUB1       = -1.1048174e-031     UC1        = 9.1514618e-011
+LUC1       = 2.0621177e-017      WUC1       = 1.897228e-017       PUC1       = -4.6698469e-024
+PRT        = 0
+AT         = '-52217.376+datp'
+LAT        = '-0.0061473152+dlatp'
+WAT        = '-0.058586759+dwatp'
+PAT        = '6.4808363e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp'
+WMIN       = '3e-007-dxwp'       WMAX       = '6e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.36316023+dvthp' LVTH0      = '-3.2423373e-009+dlvthp'
+WVTH0      = '1.7375122e-009+dwvthp'
+PVTH0      = '-2.3391514e-016+dpvthp'
+K1         = 0.23752             K2         = '0.020043122+dk2p'  LK2        = '1.1558669e-009+dlk2p'
+WK2        = '-4.7286672e-009+dwk2p'
+PK2        = '2.0298134e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0040898917
+LCIT       = '6.1694592e-010+dlcitp'
+WCIT       = '5.4412491e-010+dwcitp'
+PCIT       = '-6.3038734e-017+dpcitp'
+VOFF       = -0.064317116        LVOFF      = '-6.474503e-009+dlvoffp'
+WVOFF      = '-4.8890811e-009+dwvoffp'
+PVOFF      = '3.4886642e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp-0.707445*ff_flag-0.345233*ss_flag-0.565956*sf_flag+0.565956*fs_flag'
+ETA0       = '0.159024+deta0p'   WETA0      = '-5.59488e-009+dweta0p'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.019574783+du0p'  LU0        = '-2.3454436e-011+dlu0p'
+WU0        = '-8.9317888e-010+dwu0p'
+PU0        = '2.2836786e-017+dpu0p'
+UA         = 2.5413757e-009      LUA        = -1.4036628e-016     WUA        = -3.0638876e-016
+PUA        = 1.8427145e-023      UB         = -3.1570734e-019     LUB        = 2.0791187e-025
+WUB        = 1.9979745e-026      PUB        = -1.9570215e-032     UC         = -1.5114415e-010
+LUC        = 2.574739e-017       WUC        = 4.4193923e-018      PUC        = -1.5694208e-024
+VSAT       = '115987.55+dvsatp+113.195*ff_flag+90.5518*sf_flag-90.5518*fs_flag'
+LVSAT      = '-0.00024305347+dlvsatp-1.11493e-05*ff_flag-8.91981e-06*sf_flag+8.91981e-06*fs_flag'
+WVSAT      = '-0.0047649492+dwvsatp-0.00112285*ff_flag-0.000898285*sf_flag+0.000898285*fs_flag'
+PVSAT      = '2.543811e-010+dpvsatp+1.10601e-10*ff_flag+8.84807e-11*sf_flag-8.84807e-11*fs_flag'
+A0         = -3.5451926          LA0        = 4.8216702e-007      WA0        = -6.7893192e-008
+PA0        = -1.3678978e-015     AGS        = -1.544912           LAGS       = 9.62999e-008
+WAGS       = 9.5467378e-007      PAGS       = -5.9330019e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.28207926         LKETA      = 1.5471256e-008      WKETA      = 1.8752824e-008
+PKETA      = 1.9797485e-017      DWG        = 0                   DWB        = 0
+PCLM       = 1.4321929           LPCLM      = '-3.0814716e-008+dlpclmp'
+WPCLM      = -2.7082666e-007     PPCLM      = '2.2319318e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0057499399+dpdiblc2p'
+LPDIBLC2   = -1.6054908e-010     WPDIBLC2   = -1.2089627e-009     PPDIBLC2   = 9.9540429e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.003039542         LTVOFF     = -7.8813989e-011
+WTVOFF     = -8.0234889e-010     PTVOFF     = 5.5189638e-017      KT1        = -0.24843132
+LKT1       = 4.6247054e-009      WKT1       = 3.7361302e-008      PKT1       = -3.4064947e-015
+KT1L       = 0                   KT2        = -0.092007203        LKT2       = 1.5532008e-009
+WKT2       = -7.877144e-009      PKT2       = 6.1825666e-016      UTE        = -2.9967679
+LUTE       = 1.3758164e-007      WUTE       = 4.2144814e-007      PUTE       = -3.7604162e-014
+UA1        = -4.748832e-009      LUA1       = 4.2951483e-016      WUA1       = 6.6412562e-016
+PUA1       = -4.1168815e-023     UB1        = -7.634209e-019      LUB1       = -4.8387708e-026
+WUB1       = 8.0045741e-025      PUB1       = -8.4056362e-032     UC1        = 2.3476355e-010
+LUC1       = 6.5111571e-018      WUC1       = 2.0967956e-017      PUC1       = -4.866421e-024
+PRT        = 0
+AT         = '-240720.63+datp'
+LAT        = '0.012420255+dlatp'
+WAT        = '0.047069619+dwatp'
+PAT        = '-3.9263169e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'
+LNFACTOR   = '0+dlnfactorp+6.96831e-08*ff_flag+3.40053e-08*ss_flag+5.57465e-08*sf_flag-5.57465e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp+2.80714e-07*ff_flag+5.61424e-08*ss_flag+2.24571e-07*sf_flag-2.24571e-07*fs_flag'
+PNFACTOR   = '0+dpnfactorp-2.76502e-14*ff_flag-5.53001e-15*ss_flag-2.21202e-14*sf_flag+2.21202e-14*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.21 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp'
+LMAX       = 2.000001e-05        WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'
+DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39886347+dvthp' WVTH0      = '-4.2769067e-010+dwvthp'
+K1         = 0.23752             K2         = '0.0042611111+dk2p' WK2        = '2.2300444e-009+dwk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 3.3905556e-005
+WCIT       = '-7.2177778e-013+dwcitp'
+VOFF       = -0.094192791        WVOFF      = '-5.7190684e-010+dwvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018635556+du0p'  WU0        = '-1.6177778e-010+dwu0p'
+UA         = 1.7390889e-009      WUA        = -1.9522844e-016     UB         = 9.0724751e-019
+WUB        = 1.1973148e-026      UC         = 2.7868889e-011      WUC        = 2.6307556e-018
+VSAT       = '110000+dvsatp'     A0         = 4.9424518           WA0        = 1.8991262e-007
+AGS        = 0.96980191          WAGS       = -4.5218203e-009     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.025255333        WKETA      = 3.0449067e-009      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.0012224845+dpdiblc2p'
+WPDIBLC2   = 1.0666159e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp'         RDW        = '75+drdswp'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop'              CGDO       = 'cgop'              CGBO       = 0
+CGDL       = 'cglp'              CGSL       = 'cglp'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0019168889
+LTVOFF     = 0                   WTVOFF     = -3.2604444e-011     PTVOFF     = 0
+KT1        = -0.18476667         WKT1       = -3.2106667e-009     KT1L       = 0
+KT2        = -0.046056667        WKT2       = 5.9733333e-010      UTE        = -2
+UA1        = -1.4863333e-009     WUA1       = 1.7994667e-016      UB1        = 1.9633333e-019
+WUB1       = -9.4826667e-026     UC1        = -8.8333333e-012     WUC1       = -6.6453333e-018
+PRT        = 0
+AT         = '195000+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT      = '0+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp'
+PVTH0      = '0+dpvthp'          LK2        = '0+dlk2p'           PK2        = '0+dpk2p'
+LCIT       = '0+dlcitp'          PCIT       = '0+dpcitp'          LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LVOFF      = '0+dlvoffp'          PVOFF      = '0+dpvoffp'
+LU0        = '0+dlu0p'           PU0        = '0+dpu0p'           LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp'
+LMAX       = '1.000249e-005-dxlp'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '1.894715e-08+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39822143+dvthp' LVTH0      = '-6.3989092e-009+dlvthp'
+WVTH0      = '-2.7176737e-010+dwvthp'
+PVTH0      = '-1.5540252e-015+dpvthp'
+K1         = 0.23752             K2         = '0.0031573454+dk2p' LK2        = '1.1000792e-008+dlk2p'
+WK2        = '2.3338199e-009+dwk2p'
+PK2        = '-1.0342889e-015+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.0119082e-005
+LCIT       = '8.3743995e-010+dlcitp'
+WCIT       = '1.3836631e-012+dwcitp'
+PCIT       = '-2.0984087e-017+dpcitp'
+VOFF       = -0.093830612        LVOFF      = '-3.6096908e-009+dlvoffp'
+WVOFF      = '-5.3415624e-010+dwvoffp'
+PVOFF      = '-3.7624521e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018684482+du0p'  LU0        = '-4.8763196e-010+dlu0p'
+WU0        = '-1.7915269e-010+dwu0p'
+PU0        = '1.7316881e-016+dpu0p'
+UA         = 1.7479112e-009      LUA        = -8.7928367e-017     WUA        = -1.985671e-016
+PUA        = 3.3275053e-023      UB         = 9.0136967e-019      LUB        = 5.8582143e-026
+WUB        = 1.2026475e-026      PUB        = -5.3148705e-034     UC         = 2.5555018e-011
+LUC        = 2.3061424e-017      WUC        = 2.8587679e-018      PUC        = -2.2725076e-024
+VSAT       = '110000+dvsatp'     A0         = 5.1522506           LA0        = -2.0909813e-006
+WA0        = 1.9276147e-007      PA0        = -2.8393315e-014     AGS        = 0.94067619
+LAGS       = 2.9028438e-007      WAGS       = -6.94958e-009       PAGS       = 2.419651e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022063743        LKETA      = -3.1809303e-008
+WKETA      = 2.931943e-009       PKETA      = 1.1258637e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00073443994+dpdiblc2p'
+LPDIBLC2   = 4.8641453e-009      WPDIBLC2   = 1.1009784e-010      PPDIBLC2   = -3.4247737e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0019628202        LTVOFF     = -4.5777937e-010
+WTVOFF     = -3.7335767e-011     PTVOFF     = 4.71552e-017        KT1        = -0.18211747
+LKT1       = -2.6403487e-008     WKT1       = -3.4191656e-009     PKT1       = 2.0780258e-015
+KT1L       = 0                   KT2        = -0.045396993        LKT2       = -6.574706e-009
+WKT2       = 6.1203518e-010      PKT2       = -1.4652746e-016     UTE        = -2
+UA1        = -1.5686016e-009     LUA1       = 8.199353e-016       WUA1       = 1.8547991e-016
+PUA1       = -5.5147606e-023     UB1        = 4.3030993e-019      LUB1       = -2.3319512e-024
+WUB1       = -1.0714949e-025     PUB1       = 1.2281665e-031      UC1        = -8.5684136e-012
+LUC1       = -2.6403487e-018     WUC1       = -6.7816596e-018     PUC1       = 1.3587091e-024
+PRT        = 0
+AT         = '195537+datp'
+PAT      = '0+dpatp'
+WAT      = '0+dwatp'
+LAT        = '-0.0053520581+dlatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp'
+CJD        = 'cjp'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp'
+CJSWD      = 'cjswp'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp'
+CJSWGD     = 'cjswgp'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'         PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'
+WNFACTOR   = '0+dwnfactorp'      PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'
+LVSAT      = '0+dlvsatp'         WVSAT      = '0+dwvsatp'         LPCLM      = '0+dlpclmp'
+PPCLM      = '0+dppclmp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp'
+LMAX       = '1.002493e-006-dxlp'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-7.573426e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40428089+dvthp' LVTH0      = '-5.4184208e-010+dlvthp'
+WVTH0      = '-1.3590142e-009+dwvthp'
+PVTH0      = '-5.0309352e-016+dpvthp'
+K1         = 0.23752             K2         = '0.013617963+dk2p'  LK2        = '8.8956963e-010+dlk2p'
+WK2        = '1.421435e-009+dwk2p'
+PK2        = '-1.5237854e-016+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00066489035
+LCIT       = '1.4631255e-010+dlcitp'
+WCIT       = '-7.916586e-012+dwcitp'
+PCIT       = '-1.1994475e-017+dpcitp'
+VOFF       = -0.09086501         LVOFF      = '-6.476239e-009+dlvoffp'
+WVOFF      = '-7.89249e-010+dwvoffp'
+PVOFF      = '-1.296728e-016+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018126194+du0p'  LU0        = '5.2008881e-011+dlu0p'
+WU0        = '-7.7758431e-013+dwu0p'
+PU0        = '7.5161222e-019+dpu0p'
+UA         = 1.7085045e-009      LUA        = -4.983793e-017      WUA        = -1.6031651e-016
+PUA        = -3.6979321e-024     UB         = 8.8465665e-019      LUB        = 7.4736926e-026
+WUB        = 3.6627113e-027      PUB        = 7.5529189e-033      UC         = 5.2502842e-011
+LUC        = -2.9863164e-018     WUC        = -5.6688818e-019     PUC        = 1.0387281e-024
+VSAT       = '110000+dvsatp'     A0         = 3.324562            LA0        = -3.2433938e-007
+WA0        = 2.4736821e-007      PA0        = -8.1176135e-014     AGS        = 0.63607723
+LAGS       = 5.8470942e-007      WAGS       = 8.3937444e-008      PAGS       = -6.3654797e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.039544464        LKETA      = -1.4912456e-008
+WKETA      = 2.7359386e-009      PKETA      = 1.3153214e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.63897871          LPCLM      = '3.4896282e-007+dlpclmp'
+WPCLM      = 1.5551686e-008      PPCLM      = '-1.5032244e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.0048953557+dpdiblc2p'
+LPDIBLC2   = 8.4220833e-010      WPDIBLC2   = 2.5351106e-010      PPDIBLC2   = -1.7287081e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0014875213        LTVOFF     = 1.6441517e-012
+WTVOFF     = -5.4490261e-011     PTVOFF     = 6.3736716e-017      KT1        = -0.19632548
+LKT1       = -1.2670035e-008     WKT1       = -6.3236314e-009     PKT1       = 4.8854794e-015
+KT1L       = 0                   KT2        = -0.040190418        LKT2       = -1.1607376e-008
+WKT2       = -7.6191809e-010     PKT2       = 1.1815344e-015      UTE        = -1.9417853
+LUTE       = -5.6270254e-008     WUTE       = -3.0325788e-008     PUTE       = 2.9312876e-014
+UA1        = -7.5913757e-010     LUA1       = 3.7508134e-017      WUA1       = 1.0875301e-016
+PUA1       = 1.9016541e-023      UB1        = -1.8971739e-018     LUB1       = -8.2207586e-026
+WUB1       = -7.3043398e-027     PUB1       = 2.6306428e-032      UC1        = -8.4465824e-011
+LUC1       = 7.0722012e-017      WUC1       = -2.4678347e-018     PUC1       = -2.8110297e-024
+PRT        = 0
+AT         = '310768.56+datp'
+LAT        = '-0.11673477+dlatp'
+WAT        = '-0.0022549945+dwatp'
+PAT        = '2.1796754e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'      PVSAT      = '0+dpvsatp'         LVSAT      = '0+dlvsatp'
+WVSAT      = '0+dwvsatp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp'
+LMAX       = '2.399996e-007-dxlp'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42302095+dvthp' LVTH0      = '3.7702272e-009+dlvthp'
+WVTH0      = '-3.0077769e-009+dwvthp'
+PVTH0      = '-1.2371486e-016+dpvthp'
+K1         = 0.23752             K2         = '0.015925729+dk2p'  LK2        = '3.5855486e-010+dlk2p'
+WK2        = '3.9942964e-010+dwk2p'
+PK2        = '8.2783879e-017+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00087740207
+LCIT       = '9.7413814e-011+dlcitp'
+WCIT       = '-1.0680034e-010+dwcitp'
+PCIT       = '1.0758577e-017+dpcitp'
+VOFF       = -0.11205689         LVOFF      = '-1.6000077e-009+dlvoffp'
+WVOFF      = '-9.3837657e-010+dwvoffp'
+PVOFF      = '-9.5358696e-017+dpvoffp'
+NFACTOR    = '0.7+dnfactorp'     ETA0       = '0.17773778+deta0p' WETA0      = '-1.1583289e-008+dweta0p'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018941031+du0p'  LU0        = '-1.3548435e-010+dlu0p'
+WU0        = '7.5141923e-011+dwu0p'
+PU0        = '-1.6717391e-017+dpu0p'
+UA         = 1.6454109e-009      LUA        = -3.5320138e-017     WUA        = -1.7827262e-016
+PUA        = 4.3375199e-025      UB         = 1.4480642e-018      LUB        = -5.4902581e-026
+WUB        = -1.9062694e-026     PUB        = 1.2782012e-032      UC         = 3.5249758e-011
+LUC        = 9.8360105e-019      WUC        = -5.2264908e-020     PUC        = 9.2031378e-025
+VSAT       = '114391.12+dvsatp'  LVSAT      = '-0.0010103917+dlvsatp'
+WVSAT      = '-0.00061475644+dwvsatp'
+PVSAT      = '1.4145484e-010+dpvsatp'
+A0         = 2.7585035           LA0        = -1.9408989e-007     WA0        = -2.576865e-007
+PA0        = 3.5036449e-014      AGS        = 4.8481565           LAGS       = -3.844858e-007
+WAGS       = -2.3851344e-007     PAGS       = 1.0540829e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.081442179        LKETA      = -5.2718337e-009     WKETA      = -1.7918112e-009
+PKETA      = 2.3571521e-015      DWG        = 0                   DWB        = 0
+PCLM       = 3.228392            LPCLM      = '-2.468586e-007+dlpclmp'
+WPCLM      = -1.490479e-007      PPCLM      = '2.2841957e-014+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '0.013031169+dpdiblc2p'
+LPDIBLC2   = -1.0298341e-009     WPDIBLC2   = -1.0916698e-009     PPDIBLC2   = 1.3665395e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0016914353        LTVOFF     = -4.5276266e-011
+WTVOFF     = 3.2887816e-010      PTVOFF     = -2.4475974e-017     KT1        = -0.29006066
+LKT1       = 8.8983363e-009      WKT1       = 2.4409226e-008      PKT1       = -2.1861203e-015
+KT1L       = 0                   KT2        = -0.081513175        LKT2       = -2.0990506e-009
+WKT2       = 2.4765473e-009      PKT2       = 4.3636676e-016      UTE        = -2.4467233
+LUTE       = 5.9915465e-008      WUTE       = 8.290864e-008       PUTE       = 3.2577479e-015
+UA1        = -2.3362551e-010     LUA1       = -8.3411665e-017     WUA1       = -1.5381806e-017
+PUA1       = 4.7579837e-023      UB1        = -3.3796683e-018     LUB1       = 2.5891288e-025
+WUB1       = 3.4733611e-025      PUB1       = -5.5295984e-032     UC1        = 1.9960266e-010
+LUC1       = 5.358138e-018       WUC1       = -1.5615894e-017     PUC1       = 2.1432552e-025
+PRT        = 0
+AT         = '-253490.39+datp'
+LAT        = '0.013100647+dlatp'
+WAT        = '0.005820604+dwatp'
+PAT        = '3.2148828e-10+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p'
+PETA0      = '0+dpeta0p'         LNFACTOR   = '0+dlnfactorp'      WNFACTOR   = '0+dwnfactorp'
+PNFACTOR   = '0+dpnfactorp'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp'        XW         = '2.0e-08+dxwp'      DLC        = '-6.55e-09+ddlcp'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.34168801+dvthp' LVTH0      = '-4.2410674e-009+dlvthp'
+WVTH0      = '-5.1335978e-009+dwvthp'
+PVTH0      = '8.5678502e-017+dpvthp'
+K1         = 0.23752             K2         = '-9.6172764e-005+dk2p'
+LK2        = '1.9367122e-009+dlk2p'
+WK2        = '1.7159072e-009+dwk2p'
+PK2        = '-4.6889159e-017+dpk2p'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0031308002
+LCIT       = '4.9222174e-010+dlcitp'
+WCIT       = '2.3721565e-010+dwcitp'
+PCIT       = '-2.3126998e-017+dpcitp'
+VOFF       = -0.071895358        LVOFF      = '-5.555919e-009+dlvoffp'
+WVOFF      = '-2.4640438e-009+dwvoffp'
+PVOFF      = '5.4919529e-017+dpvoffp'
+NFACTOR    = '0.7+dnfactorp+0.222609*ff_flag-0.288637*ss_flag+0.178087*sf_flag-0.178087*fs_flag'
+ETA0       = '0.18434054+deta0p' LETA0      = '-6.5037242e-010+dleta0p'
+WETA0      = '-1.3696174e-008+dweta0p'
+PETA0      = '2.0811918e-016+dpeta0p'
+ETAB       = 0.017265187         LETAB      = -4.8777932e-009     WETAB      = -3.058086e-008
+PETAB      = 1.5608938e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.016700842+du0p'  LU0        = '8.5174259e-011+dlu0p'
+WU0        = '2.6482083e-011+dwu0p'
+PU0        = '-1.1924396e-017+dpu0p'
+UA         = 2.1146812e-009      LUA        = -8.1543267e-017     WUA        = -1.6984654e-016
+PUA        = -3.9621729e-025     UB         = -6.9986034e-019     LUB        = 1.5666798e-025
+WUB        = 1.429087e-025       PUB        = -3.1721708e-033     UC         = -3.0466952e-010
+LUC        = 3.446565e-017       WUC        = 5.3547512e-017      PUC        = -4.3592643e-024
+VSAT       = '94172.59+dvsatp-13960.2*ff_flag-11168.2*sf_flag+11168.2*fs_flag'
+LVSAT      = '0.00098113326+dlvsatp+0.00137508*ff_flag+0.00110006*sf_flag-0.00110006*fs_flag'
+WVSAT      = '0.0022158375+dwvsatp+0.00338064*ff_flag+0.00270451*sf_flag-0.00270451*fs_flag'
+PVSAT      = '-1.3735866e-010+dpvsatp-3.32992e-10*ff_flag-2.66394e-10*sf_flag+2.66394e-10*fs_flag'
+A0         = -3.9507937          LA0        = 4.6677589e-007      WA0        = 6.1899155e-008
+PA0        = 3.557262e-015       AGS        = 3.8863976           LAGS       = -2.8975255e-007
+WAGS       = -7.8334526e-007     PAGS       = 6.4206764e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.29827237         LKETA      = 1.608594e-008       WKETA      = 2.3934619e-008
+PKETA      = -1.769013e-016      DWG        = 0                   DWB        = 0
+PCLM       = 0.10668465          LPCLM      = '6.0629576e-008+dlpclmp'
+WPCLM      = 1.5333598e-007      PPCLM      = '-6.9428557e-015+dppclmp'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00014056647+dpdiblc2p'
+LPDIBLC2   = 2.675818e-010       WPDIBLC2   = 6.7599931e-010      PPDIBLC2   = -3.7461452e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp'
+RDW        = '75+drdswp'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop'
+CGDO       = 'cgop'              CGBO       = 0                   CGDL       = 'cglp'
+CGSL       = 'cglp'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 4.9882714e-005      LTVOFF     = 1.1641666e-010
+WTVOFF     = 1.5434209e-010      PTVOFF     = -7.2841711e-018     KT1        = -0.1018881
+LKT1       = -9.6366611e-009     WKT1       = -9.5325297e-009     PKT1       = 1.1571426e-015
+KT1L       = 0
+KT2        = '-0.097480753-0.079233761'
+LKT2       = '-5.262442e-010+7.8045026e-09'
+WKT2       = '-6.1256082e-009+2.5354803e-08'
+PKT2       = '1.2836791e-015-2.4974408e-15'
+UTE        = -2.1874478
+LUTE       = 3.4376828e-008      WUTE       = 1.6246569e-007      PUTE       = -4.5786219e-015
+UA1        = -6.1936262e-009     LUA1       = 5.0364841e-016      WUA1       = 1.1264598e-015
+PUA1       = -6.4891559e-023     UB1        = 4.2688773e-018      LUB1       = -4.9446886e-025
+WUB1       = -8.0987802e-025     PUB1       = 5.8689608e-032      UC1        = 4.6642041e-010
+LUC1       = -2.092341e-017      WUC1       = -5.3162239e-017     PUC1       = 3.9126405e-024
+PRT        = 0
+AT         = '-88342.852+datp'
+LAT        = '-0.0031663846+dlatp'
+WAT        = '-0.0016912692+dwatp'
+PAT        = '1.0614078e-09+dpatp'
+NOIA       = 'noiap'
+NOIB       = 'noibp'
+NOIC       = 'noicp'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp'               CJD        = 'cjp'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp'             CJSWD      = 'cjswp'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp'            CJSWGD     = 'cjswgp'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -4.5e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp-2.19269e-08*ff_flag+2.84306e-08*ss_flag-1.75416e-08*sf_flag+1.75416e-08*fs_flag'
+WNFACTOR   = '0+dwnfactorp-1.69032e-08*ff_flag+3.80322e-08*ss_flag-1.35226e-08*sf_flag+1.35226e-08*fs_flag'
+PNFACTOR   = '0+dpnfactorp+1.66496e-15*ff_flag-3.74616e-15*ss_flag+1.33197e-15*sf_flag-1.33197e-15*fs_flag'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.ENDL MOS








***************************************************************
*                                                             *
*                     High-vt DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_hvt
**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT NMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************

.MODEL nch_hvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hvt'
+LMAX       = 2.001e-05           WMIN       = '1e-005-dxwn_hvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48907152+dvthn_hvt'
+K1         = 0.48686             K2         = '-0.0095062275+dk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0006173+dcitn_hvt'
+VOFF       = '-0.13532+dvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.01078+du0n_hvt'  UA         = -2.072e-009         UB         = 1.982334e-018
+UC         = 3.335e-011          VSAT       = '85000+dvsatn_hvt'  A0         = '2.5+da0n_hvt'
+AGS        = 0.7622              A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.02183
+DWG        = 0                   DWB        = 0                   PCLM       = '0.05608+dpclmn_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '1.037e-005+dpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01371
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01205             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.01095
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.001653            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2369144
+KT1L       = 0                   KT2        = -0.08116            UTE        = -1
+UA1        = 7.57716e-010        UB1        = -4.33e-019          UC1        = 7.68e-011
+PRT        = 0                   AT         = '180000+datn_hvt'   NOIA       = 'noian_hvt'
+NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'               EM         = 2e+06
+EF         = 1.00                   JSS        = 1.99e-07            JSD        = 1.99e-07
+JSWS       = 5.1e-13             JSWD       = 5.1e-13             JSWGS      = 5.1e-13
+JSWGD      = 5.1e-13             NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 8.85                BVD        = 8.85
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1.02
+PBD        = 1.02                CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'
+MJS        = 0.5                 MJD        = 0.5                 PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'
+MJSWS      = 0.05                MJSWD      = 0.05                PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'
+MJSWGS     = 0.445               MJSWGD     = 0.445               TPB        = 0.0015
+TCJ        = 0.000773            TPBSW      = 0.0018              TCJSW      = 0.0005
+TPBSWG     = 0.00198             TCJSWG     = 0.00104             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010
+NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045
+TNJTSSWG   = 1                   VTSSWGS    = 24.384              VTSSWGD    = 24.384
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'
+WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'
+WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'
+WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-dxln_hvt'
+LMAX       = '1e-005-dxln_hvt'   WMIN       = '1e-005-dxwn_hvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48903673+dvthn_hvt'
+LVTH0      = '3.4673952e-010+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.009315043+dk2n_hvt'
+LK2        = '-1.9051743e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00059199273+dcitn_hvt'
+LCIT       = '2.5218974e-010+dlcitn_hvt'
+VOFF       = '-0.13344662+dvoffn_hvt'
+LVOFF      = '-1.8668452e-008+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010796085+du0n_hvt'
+LU0        = '-1.6029009e-010+dlu0n_hvt'
+UA         = -2.0930179e-009     LUA        = 2.0944571e-016      UB         = 2.0091892e-018
+LUB        = -2.6761545e-025     UC         = 3.094152e-011       LUC        = 2.4000769e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5647695+da0n_hvt'
+LA0        = '-6.4543475e-007+dla0n_hvt'
+AGS        = 0.73187417          LAGS       = 3.0220025e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.027071608         LKETA      = -5.2233197e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.044936222+dpclmn_hvt'
+LPCLM      = 1.1104897e-007      PDIBLC1    = 0                   PDIBLC2    = '-6.7292224e-005+dpdiblc2n_hvt'
+LPDIBLC2   = '7.739126e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.013682119
+LAIGBACC   = 2.7783615e-010      BIGBACC    = 0.005651            CIGBACC    = 0.17808
+NIGBACC    = 10                  AIGBINV    = 0.012070375         LAIGBINV   = -2.0303411e-010
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010974664         LAIGSD     = -2.4577813e-010
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016943924        LTVOFF     = -4.1247983e-010
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2306225
+LKT1       = -6.2699498e-008     KT1L       = 0                   KT2        = -0.079945037
+LKT2       = -1.2107245e-008     UTE        = -1                  UA1        = 7.5516683e-010
+LUA1       = 2.5402773e-017      UB1        = -4.1723657e-019     LUB1       = -1.5708429e-025
+UC1        = 7.4655316e-011      LUC1       = 2.1372012e-017      PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     WETA0      = '0+dweta0n_hvt'
+PETA0      = '0+dpeta0n_hvt'     WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-dxln_hvt'
+LMAX       = '9.999998e-007-dxln_hvt'
+WMIN       = '1e-005-dxwn_hvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48729786+dvthn_hvt'
+LVTH0      = '2.0249303e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.0098625756+dk2n_hvt'
+LK2        = '-1.3767462e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00078875148+dcitn_hvt'
+LCIT       = '6.229629e-011+dlcitn_hvt'
+VOFF       = '-0.15153322+dvoffn_hvt'
+LVOFF      = '-1.21293e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787+deta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010595978+du0n_hvt'
+LU0        = '3.2834652e-011+dlu0n_hvt'
+UA         = -1.9245583e-009     LUA        = 4.6864003e-017      UB         = 1.7876818e-018
+LUB        = -5.3836875e-026     UC         = 5.6805909e-011      LUC        = -9.6115981e-019
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.2604038+da0n_hvt'
+LA0        = '-3.5168897e-007+dla0n_hvt'
+AGS        = 0.71746344          LAGS       = 3.1610815e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.012457767        LKETA      = -1.4083081e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.1133964+dpclmn_hvt'
+LPCLM      = 4.4977503e-008      PDIBLC1    = 0                   PDIBLC2    = '0.00095871047+dpdiblc2n_hvt'
+LPDIBLC2   = '-2.1629081e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010704536
+LAIGSD     = 1.4924842e-011      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0013851482
+LTVOFF     = -1.1402579e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.28148673         LKT1       = -1.3610023e-008     KT1L       = 0
+KT2        = -0.095734437        LKT2       = 3.1312318e-009      UTE        = -1
+UA1        = 7.9493834e-010      LUA1       = -1.298103e-017      UB1        = -5.6793775e-019
+LUB1       = -1.1641377e-026     UC1        = 9.0243083e-011      LUC1       = 6.3281329e-018
+PRT        = 0                   AT         = '153475+datn_hvt'   LAT        = -0.02265591
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      WK2        = '0+dwk2n_hvt'
+PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'
+PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-dxln_hvt'
+LMAX       = '2.4e-007-dxln_hvt' WMIN       = '1e-005-dxwn_hvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.5104748+dvthn_hvt'
+LVTH0      = '-3.2590414e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.0088279616+dk2n_hvt'
+LK2        = '-1.6126217e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049761697+dcitn_hvt'
+LCIT       = '1.286703e-010+dlcitn_hvt'
+VOFF       = '-0.14489542+dvoffn_hvt'
+LVOFF      = '-2.7262414e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.053787235+deta0n_hvt'
+LETA0      = '-5.3516274e-014+dleta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010674795+du0n_hvt'
+LU0        = '1.4865632e-011+dlu0n_hvt'
+UA         = -1.7371124e-009     LUA        = 4.1293422e-018      UB         = 1.5411949e-018
+LUB        = 2.358193e-027       UC         = 4.809812e-011       LUC        = 1.0240769e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.3726002+da0n_hvt'
+LA0        = '-1.4928398e-007+dla0n_hvt'
+AGS        = 2.7589451           LAGS       = -1.4931701e-007     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.045344311        LKETA      = -6.5854749e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.012856326+dpclmn_hvt'
+LPCLM      = 6.7899033e-008      PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2n_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.01074102
+LAIGSD     = 6.6069475e-012      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0014691618
+LTVOFF     = -1.3317954e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.29118213         LKT1       = -1.1399627e-008     KT1L       = 0
+KT2        = -0.082470923        LKT2       = 1.073629e-010       UTE        = -1
+UA1        = 5.5687579e-010      LUA1       = 4.1293422e-017      UB1        = -4.7482513e-019
+LUB1       = -3.2869564e-026     UC1        = 1.4400944e-010      LUC1       = -5.9297353e-018
+PRT        = 0                   AT         = '63373.56+datn_hvt' LAT        = -0.0021142232
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      WK2        = '0+dwk2n_hvt'
+PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     WU0        = '0+dwu0n_hvt'
+PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'
+PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'       PA0        = '0+dpa0n_hvt'
+WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-dxln_hvt'
+WMIN       = '1e-005-dxwn_hvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46352798+dvthn_hvt'
+LVTH0      = '1.2375625e-009+dlvthn_hvt'
+K1         = 0.48686             K2         = '-0.010711104+dk2n_hvt'
+LK2        = '-1.4322528e-009+dlk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.4878744e-005+dcitn_hvt'
+LCIT       = '1.7107612e-010+dlcitn_hvt'
+VOFF       = '-0.13095522+dvoffn_hvt'
+LVOFF      = '-4.0614453e-009+dlvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.0030442456+deta0n_hvt'
+LETA0      = '5.4433111e-009+dleta0n_hvt'
+ETAB       = -0.04771            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.010717766+du0n_hvt'
+LU0        = '1.0749846e-011+dlu0n_hvt'
+UA         = -1.8778919e-009     LUA        = 1.7613311e-017      UB         = 1.6074375e-018
+LUB        = -3.9865789e-027     UC         = 7.3636933e-011      LUC        = -1.4220511e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '3.1457415+da0n_hvt'
+LA0        = '-3.1911686e-007+dla0n_hvt'
+AGS        = -1.8335201          LAGS       = 2.9055298e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.21515855         LKETA      = 9.6794686e-009      DWG        = 0
+DWB        = 0                   PCLM       = '0.70882167+dpclmn_hvt'
+LPCLM      = 1.2389152e-009      PDIBLC1    = 0
+PDIBLC2    = '-0.00060334045+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+Ppdiblc2 = '0+0.0*ff_flag_hvt'
+Wpdiblc2 = '0+0.0*ff_flag_hvt'
+LPDIBLC2   = '1.5356923e-010+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.0107619
+LAIGSD     = 4.6070769e-012      BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = -0.001042516
+LTVOFF     = 1.0739096e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.49186518         LKT1       = 7.8219566e-009      KT1L       = 0
+KT2        = -0.097046703        LKT2       = 1.5034428e-009      UTE        = -1
+UA1        = 2.1520252e-009      LUA1       = -1.1149126e-016     UB1        = -1.7094573e-018
+LUB1       = 8.5384492e-026      UC1        = 8.883403e-011       LUC1       = -6.4499077e-019
+PRT        = 0                   AT         = '54607.726+datn_hvt'
+LAT        = -0.0012746246       NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+WK2        = '0+dwk2n_hvt'       PK2        = '0+dpk2n_hvt'       WCIT       = '0+dwcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  WETA0      = '0+dweta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     WA0        = '0+dwa0n_hvt'
+PA0        = '0+dpa0n_hvt'       WVOFF      = '0+dwvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hvt'
+LMAX       = 2.001e-05           WMIN       = '1e-006-dxwn_hvt'   WMAX       = '1e-005-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48720312+dvthn_hvt'
+WVTH0      = '1.872136e-008+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.0090150096+dk2n_hvt'
+WK2        = '-4.9220037e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00067671727+dcitn_hvt'
+WCIT       = '-5.9536101e-010+dwcitn_hvt'
+VOFF       = '-0.13380079+dvoffn_hvt'
+WVOFF      = '-1.5222491e-008+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010791333+du0n_hvt'
+WU0        = '-1.1356e-010+dwu0n_hvt'
+UA         = -2.0880933e-009     WUA        = 1.612552e-016       UB         = 1.9952467e-018
+WUB        = -1.2938586e-025     UC         = 3.5864867e-011      WUC        = -2.5198964e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5020782+da0n_hvt'
+WA0        = '-2.0823565e-008+dwa0n_hvt'
+AGS        = 0.76721602          WAGS       = -5.0260498e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.021492267         WKETA      = 3.384088e-009       DWG        = 0
+DWB        = 0                   PCLM       = '0.050807733+dpclmn_hvt'
+WPCLM      = 5.2828112e-008      PDIBLC1    = 0                   PDIBLC2    = '-9.9880667e-006+dpdiblc2n_hvt'
+WPDIBLC2   = 2.0398783e-010      PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = 6.5276e-009
+BGIDL      = 1.7187e+009         CGIDL      = 64.8                EGIDL      = -0.075922
+AIGBACC    = 0.013680533         WAIGBACC   = 2.95256e-010        BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.012071533
+WAIGBINV   = -2.15764e-010       BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010981733
+WAIGSD     = -3.17968e-010       BIGSD      = 0.0005681           CIGSD      = 0.001732
+NIGC       = 2.211               POXEDGE    = 1                   PIGCD      = 3.146
+NTOX       = 'ntoxn_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'          CGBO       = 0
+CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.4376              VOFFCV     = -0.1183             TVOFF      = 0.0018936067
+LTVOFF     = 0                   WTVOFF     = -2.4108788e-009     PTVOFF     = 0
+KT1        = -0.22891783         WKT1       = -8.0125665e-008     KT1L       = 0
+KT2        = -0.082194733        WKT2       = 1.0368028e-008      UTE        = -1
+UA1        = 7.4419715e-010      WUA1       = 1.3545891e-016      UB1        = -4.4240667e-019
+WUB1       = 9.42548e-026        UC1        = 8.1197333e-011      WUC1       = -4.406128e-017
+PRT        = 0                   AT         = '180000+datn_hvt'   NOIA       = 'noian_hvt'
+NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'               EM         = 2e+06
+EF         = 1.00                   JSS        = 1.99e-07            JSD        = 1.99e-07
+JSWS       = 5.1e-13             JSWD       = 5.1e-13             JSWGS      = 5.1e-13
+JSWGD      = 5.1e-13             NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 8.85                BVD        = 8.85
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1.02
+PBD        = 1.02                CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'
+MJS        = 0.5                 MJD        = 0.5                 PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'
+MJSWS      = 0.05                MJSWD      = 0.05                PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'
+MJSWGS     = 0.445               MJSWGD     = 0.445               TPB        = 0.0015
+TCJ        = 0.000773            TPBSW      = 0.0018              TCJSW      = 0.0005
+TPBSWG     = 0.00198             TCJSWG     = 0.00104             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010
+NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045
+TNJTSSWG   = 1                   VTSSWGS    = 24.384              VTSSWGD    = 24.384
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'
+PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'
+LCIT       = '0+dlcitn_hvt'      PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'
+WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'
+PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-dxln_hvt'
+LMAX       = '1e-005-dxln_hvt'   WMIN       = '1e-006-dxwn_hvt'   WMAX       = '1e-005-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4870433+dvthn_hvt'
+LVTH0      = '1.5926236e-009+dlvthn_hvt'
+WVTH0      = '1.9974106e-008+dwvthn_hvt'
+PVTH0      = '-1.2483759e-014+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0088515496+dk2n_hvt'
+LK2        = '-1.6288964e-009+dlk2n_hvt'
+WK2        = '-4.644204e-009+dwk2n_hvt'
+PK2        = '-2.7683047e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00065956444+dcitn_hvt'
+LCIT       = '1.7092986e-010+dlcitn_hvt'
+WCIT       = '-6.7706849e-010+dwcitn_hvt'
+PCIT       = '8.1422399e-016+dpcitn_hvt'
+VOFF       = '-0.13192345+dvoffn_hvt'
+LVOFF      = '-1.8707891e-008+dlvoffn_hvt'
+WVOFF      = '-1.5262147e-008+dwvoffn_hvt'
+PVOFF      = '3.9517719e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010809241+du0n_hvt'
+LU0        = '-1.784563e-010+dlu0n_hvt'
+WU0        = '-1.3182627e-010+dwu0n_hvt'
+PU0        = '1.8202542e-016+dpu0n_hvt'
+UA         = -2.1093908e-009     LUA        = 2.122312e-016       WUA        = 1.6405603e-016
+PUA        = -2.7910565e-023     UB         = 2.0225716e-018      LUB        = -2.7229571e-025
+WUB        = -1.3409191e-025     PUB        = 4.6896278e-032      UC         = 3.3104478e-011
+LUC        = 2.7507574e-017      WUC        = -2.1672843e-017     PUC        = -3.5138188e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5666992+da0n_hvt'
+LA0        = '-6.4395506e-007+dla0n_hvt'
+WA0        = '-1.9335724e-008+dwa0n_hvt'
+PA0        = '-1.4826505e-014+dpa0n_hvt'
+AGS        = 0.73609148          LAGS       = 3.1015948e-007      WAGS       = -4.2257426e-008
+PAGS       = -7.975149e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.027044741
+LKETA      = -5.533102e-008      WKETA      = 2.6920129e-010      PKETA      = 3.1040189e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.039694095+dpclmn_hvt'
+LPCLM      = 1.1074863e-007      WPCLM      = 5.252611e-008       PPCLM      = 3.009487e-015
+PDIBLC1    = 0                   PDIBLC2    = '-8.6607909e-005+dpdiblc2n_hvt'
+LPDIBLC2   = '7.6352516e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.9354317e-010      PPDIBLC2   = 1.0408214e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.013649493         LAIGBACC   = 3.0932425e-010
+WAIGBACC   = 3.2691754e-010      PAIGBACC   = -3.1551073e-016     BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.012094217
+LAIGBINV   = -2.2604464e-010     WAIGBINV   = -2.3890128e-010     PAIGBINV   = 2.3056554e-016
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.011008828         LAIGSD     = -2.6999975e-010
+WAIGSD     = -3.4232303e-010     PAIGSD     = 2.4270056e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0019525118        LTVOFF     = -5.8699655e-010     WTVOFF     = -2.5863568e-009
+PTVOFF     = 1.7486576e-015      KT1        = -0.22197516         LKT1       = -6.9184447e-008
+WKT1       = -8.6646335e-008     PKT1       = 6.4979193e-014      KT1L       = 0
+KT2        = -0.080921921        LKT2       = -1.2683719e-008     WKT2       = 9.7883783e-009
+PKT2       = 5.7762734e-015      UTE        = -1                  UA1        = 7.399493e-010
+LUA1       = 4.233029e-017       WUA1       = 1.5247967e-016      PUA1       = -1.6961372e-022
+UB1        = -4.2755473e-019     LUB1       = -1.4800118e-025     WUB1       = 1.0338794e-025
+PUB1       = -9.1012712e-032     UC1        = 7.9141368e-011      LUC1       = 2.0487923e-017
+WUC1       = -4.4950239e-017     PUC1       = 8.8585706e-024      PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-dxln_hvt'
+LMAX       = '9.999998e-007-dxln_hvt'
+WMIN       = '1e-006-dxwn_hvt'   WMAX       = '1e-005-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4867008+dvthn_hvt'
+LVTH0      = '1.9231706e-009+dlvthn_hvt'
+WVTH0      = '5.9825209e-009+dwvthn_hvt'
+PVTH0      = '1.0196325e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0092646587+dk2n_hvt'
+LK2        = '-1.2302016e-009+dlk2n_hvt'
+WK2        = '-5.9911282e-009+dwk2n_hvt'
+PK2        = '-1.4683773e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076480999+dcitn_hvt'
+LCIT       = '6.9356536e-011+dlcitn_hvt'
+WCIT       = '2.3989382e-010+dwcitn_hvt'
+PCIT       = '-7.0743667e-017+dpcitn_hvt'
+VOFF       = '-0.15028908+dvoffn_hvt'
+LVOFF      = '-9.8307814e-010+dlvoffn_hvt'
+WVOFF      = '-1.2466302e-008+dwvoffn_hvt'
+PVOFF      = '-2.3031152e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322047+deta0n_hvt'
+WETA0      = '-5.3611676e-009+dweta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010588559+du0n_hvt'
+LU0        = '3.4526134e-011+dlu0n_hvt'
+WU0        = '7.4341403e-011+dwu0n_hvt'
+PU0        = '-1.694865e-017+dpu0n_hvt'
+UA         = -1.9374491e-009     LUA        = 4.62889e-017        WUA        = 1.2916552e-016
+PUA        = 5.7625411e-024      UB         = 1.7937358e-018      LUB        = -5.1444368e-026
+WUB        = -6.0660547e-026     PUB        = -2.3972914e-032     UC         = 6.1830105e-011
+LUC        = -2.1575749e-019     WUC        = -5.0342439e-017     PUC        = -7.4689313e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.2665477+da0n_hvt'
+LA0        = '-3.5427643e-007+dla0n_hvt'
+WA0        = '-6.1561936e-008+dwa0n_hvt'
+PA0        = '2.5926351e-014+dpa0n_hvt'
+AGS        = 0.68632144          LAGS       = 3.5819293e-007      WAGS       = 3.1204285e-007
+PAGS       = -4.2168952e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.014745192
+LKETA      = -1.4999221e-008     WKETA      = 2.2919993e-008      PKETA      = 9.179728e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.10751264+dpclmn_hvt'
+LPCLM      = 4.5296405e-008      WPCLM      = 5.8955317e-008      PPCLM      = -3.1953928e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.00091932882+dpdiblc2n_hvt'
+LPDIBLC2   = '-2.0731242e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 3.9460417e-010      PPDIBLC2   = -8.9963436e-017     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010711499         LAIGSD     = 1.695462e-011
+WAIGSD     = -6.9774317e-011     PAIGSD     = -2.0338381e-017     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0014648952        LTVOFF     = -1.1639387e-010     WTVOFF     = -7.9906516e-010
+PTVOFF     = 2.3728111e-017      KT1        = -0.27891208         LKT1       = -1.4234166e-008
+WKT1       = -2.5797936e-008     PKT1       = 6.2539164e-015      KT1L       = 0
+KT2        = -0.097891213        LKT2       = 3.6934805e-009      WKT2       = 2.1610894e-008
+PKT2       = -5.6337314e-015     UTE        = -1                  UA1        = 7.9464426e-010
+LUA1       = -1.0456257e-017     WUA1       = 2.9466796e-018      PUA1       = -2.5298234e-023
+UB1        = -5.6747736e-019     LUB1       = -1.2960733e-026     WUB1       = -4.6130942e-027
+PUB1       = 1.3219947e-032      UC1        = 9.416361e-011       LUC1       = 5.9898365e-018
+WUC1       = -3.9283681e-017     PUC1       = 3.3897301e-024      PRT        = 0
+AT         = '153257.67+datn_hvt'
+LAT        = -0.022446166        WAT        = 0.002177614         PAT        = -2.1016327e-009
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-dxln_hvt'
+LMAX       = '2.4e-007-dxln_hvt' WMIN       = '1e-006-dxwn_hvt'   WMAX       = '1e-005-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51029903+dvthn_hvt'
+LVTH0      = '-3.4568481e-009+dlvthn_hvt'
+WVTH0      = '1.7612109e-009+dwvthn_hvt'
+PVTH0      = '1.9820236e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0068379101+dk2n_hvt'
+LK2        = '-1.7834614e-009+dlk2n_hvt'
+WK2        = '-1.9940316e-008+dwk2n_hvt'
+PK2        = '1.7118143e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00049520102+dcitn_hvt'
+LCIT       = '1.3082307e-010+dlcitn_hvt'
+WCIT       = '2.420774e-011+dwcitn_hvt'
+PCIT       = '-2.1570692e-017+dpcitn_hvt'
+VOFF       = '-0.14181909+dvoffn_hvt'
+LVOFF      = '-2.9141003e-009+dlvoffn_hvt'
+WVOFF      = '-3.0824876e-008+dwvoffn_hvt'
+PVOFF      = '1.882346e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.054322285+deta0n_hvt'
+LETA0      = '-5.43961e-014+dleta0n_hvt'
+WETA0      = '-5.3612063e-009+dweta0n_hvt'
+PETA0      = '8.8158482e-021+dpeta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010674795+du0n_hvt'
+LU0        = '1.4865632e-011+dlu0n_hvt'
+UA         = -1.7554817e-009     LUA        = 4.8032508e-018      WUA        = 1.8406019e-016
+PUA        = -6.7525646e-024     UB         = 1.5597693e-018      LUB        = 1.8962419e-027
+WUB        = -1.8611524e-025     PUB        = 4.6287498e-033      UC         = 6.0350359e-011
+LUC        = 1.2160087e-019      WUC        = -1.2276744e-016     PUC        = 9.0428094e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.405171+da0n_hvt' LA0        = '-1.5789634e-007+dla0n_hvt'
+WA0        = '-3.2635924e-007+dwa0n_hvt'
+PA0        = '8.62959e-014+dpa0n_hvt'
+AGS        = 3.0235749           LAGS       = -1.7466347e-007     WAGS       = -2.6515905e-006
+PAGS       = 2.5397146e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.053375301
+LKETA      = -6.1921743e-009     WKETA      = 8.0470522e-008      PKETA      = -3.9408717e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.012039198+dpclmn_hvt'
+LPCLM      = 6.7062822e-008      WPCLM      = 8.1876225e-009      PPCLM      = 8.3788294e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00070725187+dpdiblc2n_hvt'
+LPDIBLC2   = '1.6352195e-010+dlpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 6.5276e-009         BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010745391
+LAIGSD     = 9.2277033e-012      WAIGSD     = -4.3800595e-011     PAIGSD     = -2.6259973e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.0016164685        LTVOFF     = -1.5095014e-010
+WTVOFF     = -1.476013e-009      PTVOFF     = 1.7806138e-016      KT1        = -0.2886127
+LKT1       = -1.2022581e-008     WKT1       = -2.5745648e-008     PKT1       = 6.2419957e-015
+KT1L       = 0                   KT2        = -0.081503825        LKT2       = -4.2581776e-011
+WKT2       = -9.6903242e-009     PKT2       = 1.5024456e-015      UTE        = -1
+UA1        = 5.5431357e-010      LUA1       = 4.4335296e-017      WUA1       = 2.5673461e-017
+PUA1       = -3.0479576e-023     UB1        = -4.7522522e-019     LUB1       = -3.3992745e-026
+WUB1       = 4.0088836e-027      PUB1       = 1.1254274e-032      UC1        = 1.4667601e-010
+LUC1       = -5.9821505e-018     WUC1       = -2.6719068e-017     PUC1       = 5.2519947e-025
+PRT        = 0                   AT         = '63846.319+datn_hvt'
+LAT        = -0.0020618081       WAT        = -0.0047370519       PAT        = -5.2519947e-010
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-dxln_hvt'
+WMIN       = '1e-006-dxwn_hvt'   WMAX       = '1e-005-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.46122686+dvthn_hvt'
+LVTH0      = '1.2433235e-009+dlvthn_hvt'
+WVTH0      = '2.3057213e-008+dwvthn_hvt'
+PVTH0      = '-5.7724504e-017+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0089135286+dk2n_hvt'
+LK2        = '-1.584657e-009+dlk2n_hvt'
+WK2        = '-1.8011708e-008+dwk2n_hvt'
+PK2        = '1.5270907e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.2775734e-005+dcitn_hvt'
+LCIT       = '1.7415672e-010+dlcitn_hvt'
+WCIT       = '1.2127215e-010+dwcitn_hvt'
+PCIT       = '-3.08676e-017+dpcitn_hvt'
+VOFF       = '-0.12918363+dvoffn_hvt'
+LVOFF      = '-4.1243344e-009+dlvoffn_hvt'
+WVOFF      = '-1.7751302e-008+dwvoffn_hvt'
+PVOFF      = '6.3014862e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.0038339129+deta0n_hvt'
+LETA0      = '5.5701928e-009+dleta0n_hvt'
+WETA0      = '7.9124665e-009+dweta0n_hvt'
+PETA0      = '-1.2713542e-015+dpeta0n_hvt'
+ETAB       = -0.0480806          WETAB      = 3.713412e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010717766+du0n_hvt'
+LU0        = '1.0749846e-011+dlu0n_hvt'
+UA         = -1.8691811e-009     LUA        = 1.5693471e-017      WUA        = -8.7281901e-017
+PUA        = 1.9236798e-023      UB         = 1.5879251e-018      LUB        = -8.0054308e-028
+WUB        = 1.9551478e-025      PUB        = -3.1924079e-032     UC         = 7.2032623e-011
+LUC        = -9.9733571e-019     WUC        = 1.6075185e-017      PUC        = -4.255648e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '3.1625332+da0n_hvt'
+LA0        = '-3.262179e-007+dla0n_hvt'
+WA0        = '-1.6825379e-007+dwa0n_hvt'
+PA0        = '7.1152433e-014+dpa0n_hvt'
+AGS        = -1.0966783          LAGS       = 2.1997769e-007      WAGS       = -7.3831551e-006
+PAGS       = 7.071645e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.22825247
+LKETA      = 1.05577e-008        WKETA      = 1.3120105e-007      PKETA      = -8.7998818e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.71125481+dpclmn_hvt'
+LPCLM      = 9.1391598e-011      WPCLM      = -2.438004e-008      PPCLM      = 1.1498186e-014
+PDIBLC1    = 0
+PDIBLC2    = '-0.00078408711+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '1.7088129e-010+dlpdiblc2n_hvt+3.07143e-10*ff_flag_hvt'
+WPDIBLC2   = '1.8110816e-009-4.5e-15*ff_flag_hvt'
+PPDIBLC2   = '-1.7346684e-016-4.2e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 8.9756956e-009      LAGIDL     = -2.3448056e-016     WAGIDL     = -2.4529918e-014
+PAGIDL     = 2.3494952e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010802719         LAIGSD     = 3.7368513e-012
+WAIGSD     = -4.0900567e-010     PAIGSD     = 8.7196609e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0011725623       LTVOFF     = 1.1618546e-010      WTVOFF     = 1.3030646e-009
+PTVOFF     = -8.8120893e-017     KT1        = -0.50365453         LKT1       = 8.574298e-009
+WKT1       = 1.1812929e-007      PKT1       = -7.5384608e-015     KT1L       = 0
+KT2        = -0.0972308          LKT2       = 1.4637605e-009      WKT2       = 1.8446502e-009
+PKT2       = 3.9761654e-016      UTE        = -1                  UA1        = 2.2638308e-009
+LUA1       = -1.1940363e-016     WUA1       = -1.1202924e-015     PUA1       = 7.9281947e-023
+UB1        = -1.7844563e-018     LUB1       = 9.1406454e-026      WUB1       = 7.5148988e-025
+PUB1       = -6.0340054e-032     UC1        = 9.2788654e-011      LUC1       = -8.2077635e-019
+WUC1       = -3.9625329e-017     PUC1       = 1.7613715e-024      PRT        = 0
+AT         = '56281.889+datn_hvt'
+LAT        = -0.0013372809       WAT        = -0.016775112        PAT        = 6.2781559e-010
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hvt'
+LMAX       = 2.001e-05           WMIN       = '6e-007-dxwn_hvt'   WMAX       = '1e-006-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50870165+dvthn_hvt'
+WVTH0      = '-3.2071391e-009+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.013455713+dk2n_hvt'
+WK2        = '-3.924861e-010+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002187195+dcitn_hvt'
+WCIT       = '-1.2820329e-010+dwcitn_hvt'
+VOFF       = '-0.14654054+dvoffn_hvt'
+WVOFF      = '-2.2279452e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.01255705+du0n_hvt'
+WU0        = '-1.914591e-009+dwu0n_hvt'
+UA         = -1.8649e-009        WUA        = -6.6402e-017        UB         = 1.8935558e-018
+WUB        = -2.5661085e-026     UC         = 2.8458e-011         WUC        = -1.764396e-017
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.3943405+da0n_hvt'
+WA0        = '8.9068892e-008+dwa0n_hvt'
+AGS        = 0.7006446           WAGS       = 1.7642347e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.028716            WKETA      = -3.98412e-009       DWG        = 0
+DWB        = 0                   PCLM       = '0.12089+dpclmn_hvt'
+WPCLM      = -1.86558e-008       PDIBLC1    = 0                   PDIBLC2    = '0.0001745+dpdiblc2n_hvt'
+WPDIBLC2   = 1.581e-011          PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = -3.50462e-009
+WAGIDL     = 1.0232864e-014      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010732            WAIGSD     = -6.324e-011
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -0.0006746          LTVOFF     = 0
+WTVOFF     = 2.08692e-010        PTVOFF     = 0                   KT1        = -0.33479425
+WKT1       = 2.7868287e-008      KT1L       = 0                   KT2        = -0.0657215
+WKT2       = -6.43467e-009       UTE        = -1                  UA1        = 9.824e-010
+WUA1       = -1.07508e-016       UB1        = -1.95e-019          WUB1       = -1.581e-025
+UC1        = 4.699e-011          WUC1       = -9.1698e-018        PRT        = 0
+AT         = '180000+datn_hvt'   NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LU0        = '0+dlu0n_hvt'       PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'
+PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'
+LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-dxln_hvt'
+LMAX       = '1e-005-dxln_hvt'   WMIN       = '6e-007-dxwn_hvt'   WMAX       = '1e-006-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.5110559+dvthn_hvt'
+LVTH0      = '-2.3460394e-008+dlvthn_hvt'
+WVTH0      = '-4.5187473e-009+dwvthn_hvt'
+PVTH0      = '1.3070319e-014+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.014045764+dk2n_hvt'
+LK2        = '5.8799205e-009+dlk2n_hvt'
+WK2        = '6.5389451e-010+dwk2n_hvt'
+PK2        = '-1.0427298e-014+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-2.4513613e-005+dcitn_hvt'
+LCIT       = '2.4238447e-009+dlcitn_hvt'
+WCIT       = '2.069112e-011+dwcitn_hvt'
+PCIT       = '-1.4837492e-015+dpcitn_hvt'
+VOFF       = '-0.14564436+dvoffn_hvt'
+LVOFF      = '-8.9305867e-009+dlvoffn_hvt'
+WVOFF      = '-1.2668245e-009+dwvoffn_hvt'
+PVOFF      = '-9.5776732e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.012656944+du0n_hvt'
+LU0        = '-9.9545487e-010+dlu0n_hvt'
+WU0        = '-2.0164829e-009+dwu0n_hvt'
+PU0        = '1.015364e-015+dpu0n_hvt'
+UA         = -1.8756395e-009     LUA        = 1.0702035e-016      WUA        = -7.4370252e-017
+PUA        = 7.9404504e-023      UB         = 1.9143814e-018      LUB        = -2.0752927e-025
+WUB        = -2.3737825e-026     PUB        = -1.9165493e-032     UC         = 2.643967e-011
+LUC        = 2.011288e-017       WUC        = -1.4874738e-017     PUC        = -2.7595599e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4989486+da0n_hvt'
+LA0        = '-1.0424316e-006+dla0n_hvt'
+WA0        = '4.9769824e-008+dwa0n_hvt'
+PA0        = '3.9161953e-013+dpa0n_hvt'
+AGS        = 0.69822263          LAGS       = 2.4135222e-008      WAGS       = -3.6312008e-009
+PAGS       = 2.1199325e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.035331927
+LKETA      = -6.5928435e-008     WKETA      = -8.1837277e-009     PKETA      = 4.1849552e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.10163503+dpclmn_hvt'
+LPCLM      = 1.9187792e-007      WPCLM      = -1.0653641e-008     PPCLM      = -7.9742395e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.00055802311+dpdiblc2n_hvt'
+LPDIBLC2   = '-3.82185e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = -4.6398047e-010     PPDIBLC2   = 4.7811648e-015      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -5.3329631e-009     LAGIDL     = 1.821964e-014       WAGIDL     = 1.2097774e-014
+PAGIDL     = -1.8584033e-020     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010673718         LAIGSD     = 5.8078442e-010
+WAIGSD     = -5.1121097e-013     PAIGSD     = -6.2509928e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0008685116       LTVOFF     = 1.9323504e-009      WTVOFF     = 2.9108711e-010
+PTVOFF     = -8.2107636e-016     KT1        = -0.33583509         LKT1       = 1.0372115e-008
+WKT1       = 2.9490798e-008      PKT1       = -1.61685e-014       KT1L       = 0
+KT2        = -0.063489474        LKT2       = -2.2242387e-008     WKT2       = -7.9927175e-009
+PKT2       = 1.5526115e-014      UTE        = -1                  UA1        = 1.0008468e-009
+LUA1       = -1.8382409e-016     WUA1       = -1.1363576e-016     PUA1       = 6.1063753e-023
+UB1        = -1.5440649e-019     LUB1       = -4.0451875e-025     WUB1       = -1.7522326e-025
+PUB1       = 1.7063521e-031      UC1        = 4.2151057e-011      LUC1       = 4.8220601e-017
+WUC1       = -7.2201214e-018     PUC1       = -1.9428762e-023     PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-dxln_hvt'
+LMAX       = '9.999998e-007-dxln_hvt'
+WMIN       = '6e-007-dxwn_hvt'   WMAX       = '1e-006-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48558584+dvthn_hvt'
+LVTH0      = '1.1209657e-009+dlvthn_hvt'
+WVTH0      = '7.119782e-009+dwvthn_hvt'
+PVTH0      = '1.8378815e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0053868824+dk2n_hvt'
+LK2        = '-2.4768353e-009+dlk2n_hvt'
+WK2        = '-9.94646e-009+dwk2n_hvt'
+PK2        = '-1.9681093e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.002506147+dcitn_hvt'
+LCIT       = '-1.8516057e-011+dlcitn_hvt'
+WCIT       = '-1.5362699e-009+dwcitn_hvt'
+PCIT       = '1.8886378e-017+dpcitn_hvt'
+VOFF       = '-0.15441346+dvoffn_hvt'
+LVOFF      = '-4.6745788e-010+dlvoffn_hvt'
+WVOFF      = '-8.2594361e-009+dwvoffn_hvt'
+PVOFF      = '-2.8290478e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.0136144+deta0n_hvt'
+WETA0      = '3.6160632e-008+dweta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011582973+du0n_hvt'
+LU0        = '4.1043315e-011+dlu0n_hvt'
+WU0        = '-9.3996074e-010+dwu0n_hvt'
+PU0        = '-2.3596175e-017+dpu0n_hvt'
+UA         = -1.7768587e-009     LUA        = 1.1686151e-017      WUA        = -3.463671e-017
+PUA        = 4.1057344e-023      UB         = 1.7305426e-018      LUB        = -3.0105021e-026
+WUB        = 3.7964552e-027      PUB        = -4.5739047e-032     UC         = 5.9157679e-011
+LUC        = -1.1463532e-017     WUC        = -4.7616564e-017     PUC        = 4.003799e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.6053222+da0n_hvt'
+LA0        = '-1.7998555e-007+dla0n_hvt'
+WA0        = '6.1288803e-007+dwa0n_hvt'
+PA0        = '-1.5185035e-013+dpa0n_hvt'
+AGS        = 1.325703            LAGS       = -5.8145107e-007     WAGS       = -3.401263e-007
+PAGS       = 5.3674736e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.033557198
+LKETA      = 5.5701002e-010      WKETA      = 4.210824e-008       PKETA      = -6.6876279e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.29773631+dpclmn_hvt'
+LPCLM      = 2.6190056e-009      WPCLM      = -1.3507283e-007     PPCLM      = 4.0335554e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.003503292+dpdiblc2n_hvt'
+LPDIBLC2   = '9.7757714e-011+dlpdiblc2n_hvt'
+WPDIBLC2   = 4.9056774e-009      PPDIBLC2   = -4.0113497e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.1215736e-008      LAGIDL     = -7.4027216e-015     WAGIDL     = -1.4981898e-014
+PAGIDL     = 7.550776e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.011537467         LAIGSD     = -2.5282682e-010
+WAIGSD     = -9.1226199e-010     PAIGSD     = 2.5483869e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0013812082        LTVOFF     = -2.3887209e-010     WTVOFF     = -7.1370433e-010
+PTVOFF     = 1.486559e-016       KT1        = -0.30478929         LKT1       = -1.9590434e-008
+WKT1       = 5.9681959e-010      PKT1       = 1.1717309e-014      KT1L       = 0
+KT2        = -0.083000523        LKT2       = -3.4121173e-009     WKT2       = 6.4223907e-009
+PKT2       = 1.6139784e-015      UTE        = -1                  UA1        = 7.6350827e-010
+LUA1       = 4.5233196e-017      WUA1       = 3.4705392e-017      PUA1       = -8.2101475e-023
+UB1        = -4.8486151e-019     LUB1       = -8.5593968e-026     WUB1       = -8.8881256e-026
+PUB1       = 8.7305847e-032      UC1        = 8.4574546e-011      LUC1       = 7.2773529e-018
+WUC1       = -2.9502835e-017     PUC1       = 2.0764634e-024      PRT        = 0
+AT         = '156495.2+datn_hvt' LAT        = -0.025570732        WAT        = -0.0011246659
+PAT        = 1.0854241e-009      NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-dxln_hvt'
+LMAX       = '2.4e-007-dxln_hvt' WMIN       = '6e-007-dxwn_hvt'   WMAX       = '1e-006-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.48556798+dvthn_hvt'
+LVTH0      = '1.1250376e-009+dlvthn_hvt'
+WVTH0      = '2.6986884e-008+dwvthn_hvt'
+PVTH0      = '-2.6914998e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.014789467+dk2n_hvt'
+LK2        = '-3.3319642e-010+dlk2n_hvt'
+WK2        = '-1.1829728e-008+dwk2n_hvt'
+PK2        = '2.3254395e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028841387+dcitn_hvt'
+LCIT       = '-1.0469212e-010+dlcitn_hvt'
+WCIT       = '-2.4125087e-009+dwcitn_hvt'
+PCIT       = '2.186548e-016+dpcitn_hvt'
+VOFF       = '-0.13884306+dvoffn_hvt'
+LVOFF      = '-4.0172593e-009+dlvoffn_hvt'
+WVOFF      = '-3.3860426e-008+dwvoffn_hvt'
+PVOFF      = '3.0075683e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.013614777+deta0n_hvt'
+LETA0      = '-8.5871322e-014+dleta0n_hvt'
+WETA0      = '3.6160453e-008+dweta0n_hvt'
+PETA0      = '4.0920575e-020+dpeta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011933619+du0n_hvt'
+LU0        = '-3.8898403e-011+dlu0n_hvt'
+WU0        = '-1.2840002e-009+dwu0n_hvt'
+PU0        = '5.4839316e-017+dpu0n_hvt'
+UA         = -1.6143173e-009     LUA        = -2.5370678e-017     WUA        = 4.0072486e-017
+PUA        = 2.4024843e-023      UB         = 1.427875e-018       LUB        = 3.8898349e-026
+WUB        = -5.158308e-026      PUB        = -3.3113399e-032     UC         = -9.4317845e-011
+LUC        = 2.3526431e-017      WUC        = 3.4994131e-017      PUC        = -1.4830118e-023
+VSAT       = '85000+dvsatn_hvt'  A0         = '1.4060353+da0n_hvt'
+LA0        = '-1.3455132e-007+dla0n_hvt'
+WA0        = '-3.2724079e-007+dwa0n_hvt'
+PA0        = '6.2483975e-014+dpa0n_hvt'
+AGS        = -4.3278073          LAGS       = 7.0745881e-007      WAGS       = 4.8468194e-006
+PAGS       = -6.4579327e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.06923171
+LKETA      = -2.2877216e-008     WKETA      = -4.4588629e-008     PKETA      = 1.3077871e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.18340503+dpclmn_hvt'
+LPCLM      = 1.1231153e-007      WPCLM      = 2.0754074e-007      PPCLM      = -3.7774855e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.0060264624+dpdiblc2n_hvt'
+LPDIBLC2   = '6.7300019e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 5.4255947e-009      PPDIBLC2   = -5.196678e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.125462e-008      WAGIDL     = 1.8137864e-014      BGIDL      = 1.7187e+009
+CGIDL      = 64.8                EGIDL      = -0.075922           AIGBACC    = 0.01397
+BIGBACC    = 0.005651            CIGBACC    = 0.17808             NIGBACC    = 10
+AIGBINV    = 0.01186             BIGBINV    = 0.002321            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3.056               AIGC       = 0.00986
+BIGC       = 0.002797            CIGC       = 0.40778504          AIGSD      = 0.010725544
+LAIGSD     = -6.7721212e-011     WAIGSD     = -2.3555899e-011     PAIGSD     = 5.222792e-017
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = -2.3944289e-005     LTVOFF     = 8.148018e-011
+WTVOFF     = 1.9720807e-010      PTVOFF     = -5.9017549e-017     KT1        = -0.3895338
+LKT1       = -2.7004246e-010     WKT1       = 7.7193873e-008      PKT1       = -5.7455934e-015
+KT1L       = 0                   KT2        = -0.11399975         LKT2       = 3.6552111e-009
+WKT2       = 2.3455522e-008      PKT2       = -2.2693031e-015     UTE        = -1
+UA1        = 7.384309e-010       LUA1       = 5.0950433e-017      WUA1       = -1.6212622e-016
+PUA1       = -3.7227017e-023     UB1        = -5.5970626e-019     LUB1       = -6.8530563e-026
+WUB1       = 9.017955e-026       PUB1       = 4.6482849e-032      UC1        = 1.8326101e-010
+LUC1       = -1.5221581e-017     WUC1       = -6.4035764e-017     PUC1       = 9.9494187e-024
+PRT        = 0                   AT         = '50471.488+datn_hvt'
+LAT        = -0.0013990211       WAT        = 0.0089052757        PAT        = -1.2012422e-009
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-dxln_hvt'
+WMIN       = '6e-007-dxwn_hvt'   WMAX       = '1e-006-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.52889853+dvthn_hvt'
+LVTH0      = '-3.0251973e-009+dlvthn_hvt'
+WVTH0      = '-4.5967889e-008+dwvthn_hvt'
+PVTH0      = '4.2961667e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.0034807992+dk2n_hvt'
+LK2        = '-1.4163497e-009+dlk2n_hvt'
+WK2        = '-2.3553092e-008+dwk2n_hvt'
+PK2        = '1.3554172e-015+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0022436261+dcitn_hvt+0.00149113*ff_flag_hvt'
+LCIT       = '3.8644929e-010+dlcitn_hvt-1.42821e-10*ff_flag_hvt'
+WCIT       = '2.453402e-009+dwcitn_hvt-1.52096e-09*ff_flag_hvt'
+PCIT       = '-2.4740602e-016+dpcitn_hvt+1.45678e-16*ff_flag_hvt'
+VOFF       = '-0.15526103+dvoffn_hvt'
+LVOFF      = '-2.4447333e-009+dlvoffn_hvt'
+WVOFF      = '8.8476402e-009+dwvoffn_hvt'
+PVOFF      = '-1.0830445e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '-0.098943963+deta0n_hvt'
+LETA0      = '1.078088e-008+dleta0n_hvt'
+WETA0      = '1.0492472e-007+dweta0n_hvt'
+PETA0      = '-6.5862555e-015+dpeta0n_hvt'
+ETAB       = -0.046734           WETAB      = 2.33988e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011390414+du0n_hvt'
+LU0        = '1.3130169e-011+dlu0n_hvt'
+WU0        = '-6.8610119e-010+dwu0n_hvt'
+PU0        = '-2.4279295e-018+dpu0n_hvt'
+UA         = -2.6549763e-009     LUA        = 7.4304472e-017      WUA        = 7.1422917e-016
+PUA        = -4.0546423e-023     UB         = 2.8034532e-018      LUB        = -9.2855625e-026
+WUB        = -1.0443238e-024     PUB        = 6.1972105e-032      UC         = 3.5201396e-010
+LUC        = -1.9223586e-017     WUC        = -2.6950578e-016     PUC        = 1.4335127e-023
+VSAT       = '75059.289+dvsatn_hvt'
+LVSAT      = '0.00095212923+dlvsatn_hvt'
+WVSAT      = '0.010139525+dwvsatn_hvt'
+PVSAT      = '-9.7117181e-010+dpvsatn_hvt'
+A0         = '3.6588742+da0n_hvt'
+LA0        = '-3.5033003e-007+dla0n_hvt'
+WA0        = '-6.7452153e-007+dwa0n_hvt'
+PA0        = '9.5746803e-014+dpa0n_hvt'
+AGS        = -12.31189           LAGS       = 1.4721806e-006      WAGS       = 4.0563604e-006
+PAGS       = -5.7008247e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.30170439
+LKETA      = 1.265134e-008       WKETA      = 2.0612201e-007      PKETA      = -1.0935395e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '1.4612224+dpclmn_hvt'
+LPCLM      = -4.5212201e-008     WPCLM      = -7.8934701e-007     PPCLM      = 5.770785e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0020245416+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '-9.8131414e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-1.0537197e-009+3.3e-15*ff_flag_hvt'
+PPDIBLC2   = '1.0092612e-016-3.3e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 7.6302591e-010      LAGIDL     = -1.1510597e-015     WAGIDL     = -1.6152995e-014
+PAGIDL     = 3.284406e-021       BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0084736815        LAIGSD     = 1.4796395e-010
+WAIGSD     = 1.9666123e-009      PAIGSD     = -1.3839198e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00087605272       LTVOFF     = -4.7222538e-012     WTVOFF     = -7.8652278e-010
+PTVOFF     = 3.5204978e-017      KT1        = -0.38345064         LKT1       = -8.5269239e-010
+WKT1       = -4.478684e-009      PKT1       = 2.0770694e-015      KT1L       = 0
+KT2        = -0.10972811         LKT2       = 3.2460696e-009      WKT2       = 1.4591905e-008
+PKT2       = -1.4203388e-015     UTE        = -1                  UA1        = 2.7399852e-009
+LUA1       = -1.4076004e-016     WUA1       = -1.6059698e-015     PUA1       = 1.0106548e-022
+UB1        = -2.8047868e-018     LUB1       = 1.4650505e-025      WUB1       = 1.792227e-024
+PUB1       = -1.1654062e-031     UC1        = -5.9952012e-012     LUC1       = 2.9055298e-018
+WUC1       = 6.1134203e-017      PUC1       = -2.0394608e-024     PRT        = 0
+AT         = '30229.258+datn_hvt'
+LAT        = 0.00053979585       WAT        = 0.0097985706        PAT        = -1.2868027e-009
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hvt'
+LMAX       = 2.001e-05           WMIN       = '3e-007-dxwn_hvt'   WMAX       = '6e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50469668+dvthn_hvt'
+WVTH0      = '-7.2405683e-010+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.018663811+dk2n_hvt'
+WK2        = '2.8365349e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.6815733e-005+dcitn_hvt'
+WCIT       = '-3.0229547e-012+dwcitn_hvt'
+VOFF       = '-0.1479146+dvoffn_hvt'
+WVOFF      = '-1.3760297e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0097100667+du0n_hvt'
+WU0        = '-1.4946133e-010+dwu0n_hvt'
+UA         = -2.0093333e-009     WUA        = 2.3146667e-017      UB         = 1.8696767e-018
+WUB        = -1.0856031e-026     UC         = 6.7605333e-012      WUC        = -4.1915307e-018
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4846667+da0n_hvt'
+WA0        = '3.3066667e-008+dwa0n_hvt'
+AGS        = 0.70916528          WAGS       = 1.2359526e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.03349             WKETA      = -6.944e-009         DWG        = 0
+DWB        = 0                   PCLM       = '0.086064+dpclmn_hvt'
+WPCLM      = 2.93632e-009        PDIBLC1    = 0                   PDIBLC2    = '0.0002+dpdiblc2n_hvt'
+PDIBLCB    = 0.36                DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '52.68+drdswn_hvt'
+RDW        = '52.68+drdswn_hvt'  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.628e-007          ALPHA1     = 0.74177
+BETA0      = 14.347              AGIDL      = 1.9903893e-008      WAGIDL     = -4.2804139e-015
+BGIDL      = 1.7187e+009         CGIDL      = 64.8                EGIDL      = -0.075922
+AIGBACC    = 0.01397             BIGBACC    = 0.005651            CIGBACC    = 0.17808
+NIGBACC    = 10                  AIGBINV    = 0.01186             BIGBINV    = 0.002321
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3.056
+AIGC       = 0.00986             BIGC       = 0.002797            CIGC       = 0.40778504
+AIGSD      = 0.010811333         WAIGSD     = -1.1242667e-010     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00080189333      LTVOFF     = 0                   WTVOFF     = 2.8761387e-010
+PTVOFF     = 0                   KT1        = -0.30268081         WKT1       = 7.9579563e-009
+KT1L       = 0                   KT2        = -0.087758667        WKT2       = 7.2283733e-009
+UTE        = -1                  UA1        = 9.1015413e-010      WUA1       = -6.2715563e-017
+UB1        = -4.8333333e-019     WUB1       = 2.0666667e-026      UC1        = 6.6546667e-011
+WUC1       = -2.1294933e-017     PRT        = 0                   AT         = '180000+datn_hvt'
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'      LK2        = '0+dlk2n_hvt'
+PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'      PCIT       = '0+dpcitn_hvt'
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LU0        = '0+dlu0n_hvt'
+PU0        = '0+dpu0n_hvt'       LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'
+PVSAT      = '0+dpvsatn_hvt'     LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'
+LVOFF      = '0+dlvoffn_hvt'     PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-dxln_hvt'
+LMAX       = '1e-005-dxln_hvt'   WMIN       = '3e-007-dxwn_hvt'   WMAX       = '6e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50415216+dvthn_hvt'
+LVTH0      = '5.4262158e-009+dlvthn_hvt'
+WVTH0      = '-2.3842459e-010+dwvthn_hvt'
+PVTH0      = '-4.8393788e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.017442304+dk2n_hvt'
+LK2        = '-1.2172452e-008+dlk2n_hvt'
+WK2        = '2.7597496e-009+dwk2n_hvt'
+PK2        = '7.6517329e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.0177693e-005+dcitn_hvt'
+LCIT       = '6.6148798e-011+dlcitn_hvt'
+WCIT       = '-8.1748978e-013+dwcitn_hvt'
+PCIT       = '-2.19777e-017+dpcitn_hvt'
+VOFF       = '-0.14440888+dvoffn_hvt'
+LVOFF      = '-3.4934865e-008+dlvoffn_hvt'
+WVOFF      = '-2.0328191e-009+dwvoffn_hvt'
+PVOFF      = '6.5449795e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0096095882+du0n_hvt'
+LU0        = '1.0012788e-009+dlu0n_hvt'
+WU0        = '-1.2712231e-010+dwu0n_hvt'
+PU0        = '-2.2261087e-016+dpu0n_hvt'
+UA         = -2.0329249e-009     LUA        = 2.3509213e-016      WUA        = 2.3146667e-017
+PUA        = -7.7459245e-038     UB         = 1.8882828e-018      LUB        = -1.8541258e-025
+WUB        = -7.5567356e-027     PUB        = -3.2877845e-032     UC         = 1.0353437e-011
+LUC        = -3.5803676e-017     WUC        = -4.9012735e-018     PUC        = 7.0726655e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.51877+da0n_hvt'  LA0        = '-3.3984348e-007+dla0n_hvt'
+WA0        = '3.7480575e-008+dwa0n_hvt'
+PA0        = '-4.3985082e-014+dpa0n_hvt'
+AGS        = 0.64577863          LAGS       = 6.3165497e-007      WAGS       = 2.888408e-008
+PAGS       = -1.6466899e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.032417644
+LKETA      = 1.0686148e-008      WKETA      = -6.3768724e-009     PKETA      = -5.6514894e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.098718676+dpclmn_hvt'
+LPCLM      = -1.2610524e-007     WPCLM      = -8.8455033e-009     PPCLM      = 1.1740717e-013
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020706102+dpdiblc2n_hvt'
+LPDIBLC2   = '4.0564078e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.0371692e-011      PPDIBLC2   = -1.0335505e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.2738868e-008      LAGIDL     = -2.8250836e-014     WAGIDL     = -5.306761e-015
+PAGIDL     = 1.0227662e-020      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010911419         LAIGSD     = -9.9736054e-010
+WAIGSD     = -1.4788544e-010     PAIGSD     = 3.5335059e-016      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00093907733      LTVOFF     = 1.3670536e-009      WTVOFF     = 3.3483786e-010
+PTVOFF     = -4.7059232e-016     KT1        = -0.30301138         LKT1       = 3.294083e-009
+WKT1       = 9.1400928e-009      PKT1       = -1.1780121e-014     KT1L       = 0
+KT2        = -0.088205476        LKT2       = 4.4525024e-009      WKT2       = 7.3312038e-009
+PKT2       = -1.0247167e-015     UTE        = -1                  UA1        = 9.1845297e-010
+LUA1       = -8.2698857e-017     WUA1       = -6.2551601e-017     PUA1       = -1.6338931e-024
+UB1        = -4.635236e-019      LUB1       = -1.9740615e-025     WUB1       = 1.6429343e-026
+PUB1       = 4.2225396e-032      UC1        = 6.3683371e-011      LUC1       = 2.853306e-017
+WUC1       = -2.0570156e-017     PUC1       = -7.2224861e-024     PRT        = 0
+AT         = '185361.71+datn_hvt'
+LAT        = -0.053430029        NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-dxln_hvt'
+LMAX       = '9.999998e-007-dxln_hvt'
+WMIN       = '3e-007-dxwn_hvt'   WMAX       = '6e-007-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50581834+dvthn_hvt'
+LVTH0      = '3.8181642e-009+dlvthn_hvt'
+WVTH0      = '-5.4243698e-009+dwvthn_hvt'
+PVTH0      = '1.6561842e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.027975813+dk2n_hvt'
+LK2        = '-2.0064785e-009+dlk2n_hvt'
+WK2        = '4.0586773e-009+dwk2n_hvt'
+PK2        = '-4.8843216e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.3137364e-005+dcitn_hvt'
+LCIT       = '2.4688076e-011+dlcitn_hvt'
+WCIT       = '-1.5403957e-011+dwcitn_hvt'
+PCIT       = '-7.9001844e-018+dpcitn_hvt'
+VOFF       = '-0.17703749+dvoffn_hvt'
+LVOFF      = '-3.4447304e-009+dlvoffn_hvt'
+WVOFF      = '5.7674668e-009+dwvoffn_hvt'
+PVOFF      = '-9.8313887e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394+deta0n_hvt'
+WETA0      = '3.3728e-010+dweta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.010777257+du0n_hvt'
+LU0        = '-1.2564727e-010+dlu0n_hvt'
+WU0        = '-4.4041663e-010+dwu0n_hvt'
+PU0        = '7.9751987e-017+dpu0n_hvt'
+UA         = -1.8624698e-009     LUA        = 7.0584552e-017      WUA        = 1.8442182e-017
+PUA        = 4.5403359e-024      UB         = 1.8138374e-018      LUB        = -1.1356466e-025
+WUB        = -4.7846291e-026     PUB        = 6.0059267e-033      UC         = -2.3484559e-011
+LUC        = -3.1463557e-018     WUC        = 3.6216234e-018      PUC        = -1.1528505e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.7847738+da0n_hvt'
+LA0        = '-5.9656583e-007+dla0n_hvt'
+WA0        = '-1.1837193e-007+dwa0n_hvt'
+PA0        = '1.0642942e-013+dpa0n_hvt'
+AGS        = 0.99230228          LAGS       = 2.9722222e-007      WAGS       = -1.3341787e-007
+PAGS       = -8.0300815e-015     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.062487913
+LKETA      = -1.833491e-008      WKETA      = -1.7439729e-008     PKETA      = 5.0253622e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.11357953+dpclmn_hvt'
+LPCLM      = 7.8785457e-008      WPCLM      = 1.19943e-007        PPCLM      = -6.8876455e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.0039568235+dpdiblc2n_hvt'
+LPDIBLC2   = '3.7809599e-011+dlpdiblc2n_hvt'
+WPDIBLC2   = 2.8040582e-010      PPDIBLC2   = -3.6396714e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -1.6100659e-008     LAGIDL     = 9.2335022e-015      WAGIDL     = 8.1542661e-015
+PAGIDL     = -2.7636827e-021     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.0095557214        LAIGSD     = 3.110337e-010
+WAIGSD     = 3.1642055e-010      PAIGSD     = -9.4754836e-017     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00054146397       LTVOFF     = -6.1828645e-011     WTVOFF     = -1.9306294e-010
+PTVOFF     = 3.8888964e-017      KT1        = -0.29802416         LKT1       = -1.5191142e-009
+WKT1       = -3.5975613e-009     PKT1       = 5.1309112e-016      KT1L       = 0
+KT2        = -0.082955072        LKT2       = -6.1470449e-010     WKT2       = 6.3942111e-009
+PKT2       = -1.204176e-016      UTE        = -1                  UA1        = 9.5675293e-010
+LUA1       = -1.1966245e-016     WUA1       = -8.5106296e-017     PUA1       = 2.0133823e-023
+UB1        = -7.6916278e-019     LUB1       = 9.7568666e-026      WUB1       = 8.7385528e-026
+PUB1       = -2.6254986e-032     UC1        = 8.6004875e-011      LUC1       = 6.9903979e-018
+WUC1       = -3.0389639e-017     PUC1       = 2.2543755e-024      PRT        = 0
+AT         = '155308.05+datn_hvt'
+LAT        = -0.024425001        WAT        = -0.00038863135      PAT        = 3.7507123e-010
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-dxln_hvt'
+LMAX       = '2.4e-007-dxln_hvt' WMIN       = '3e-007-dxwn_hvt'   WMAX       = '6e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.54957039+dvthn_hvt'
+LVTH0      = '-6.1566027e-009+dlvthn_hvt'
+WVTH0      = '-1.2694612e-008+dwvthn_hvt'
+PVTH0      = '1.8231172e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.035957904+dk2n_hvt'
+LK2        = '-1.866895e-010+dlk2n_hvt'
+WK2        = '1.2947034e-009+dwk2n_hvt'
+PK2        = '1.4170966e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0011513917+dcitn_hvt'
+LCIT       = '2.9930144e-010+dlcitn_hvt'
+WCIT       = '8.9520178e-011+dwcitn_hvt'
+PCIT       = '-3.1821208e-017+dpcitn_hvt'
+VOFF       = '-0.20682982+dvoffn_hvt'
+LVOFF      = '3.3474436e-009+dlvoffn_hvt'
+WVOFF      = '8.2913661e-009+dwvoffn_hvt'
+PVOFF      = '-1.5585475e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.071394461+deta0n_hvt'
+LETA0      = '-1.0512644e-013+dleta0n_hvt'
+WETA0      = '3.3704815e-010+dweta0n_hvt'
+PETA0      = '5.2858751e-020+dpeta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0098673625+du0n_hvt'
+LU0        = '8.179401e-011+dlu0n_hvt'
+WU0        = '-2.9211617e-012+dwu0n_hvt'
+PU0        = '-1.998998e-017+dpu0n_hvt'
+UA         = -1.5798663e-009     LUA        = 6.1554727e-018      WUA        = 1.8712843e-017
+PUA        = 4.4786295e-024      UB         = 1.3403576e-018      LUB        = -5.6188355e-027
+WUB        = 2.6777448e-027      PUB        = -5.512745e-033      UC         = -1.6318395e-011
+LUC        = -4.7801265e-018     WUC        = -1.3365528e-017     PUC        = 2.7199481e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '-0.21513096+da0n_hvt'
+LA0        = '8.7364448e-008+dla0n_hvt'
+WA0        = '6.7788229e-007+dwa0n_hvt'
+PA0        = '-7.5103801e-014+dpa0n_hvt'
+AGS        = 4.0738385           LAGS       = -4.0531873e-007     WAGS       = -3.62201e-007
+PAGS       = 4.412881e-014       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.041036755
+LKETA      = 5.2670585e-009      WKETA      = 2.3777819e-008      PKETA      = -4.3715793e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.037239891+dpclmn_hvt'
+LPCLM      = 6.1381241e-008      WPCLM      = 1.1691835e-007      PPCLM      = -6.1980744e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.0063850288+dpdiblc2n_hvt'
+LPDIBLC2   = '-5.1578237e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = -2.2695298e-009     PPDIBLC2   = 2.1737738e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.5172797e-008      LAGIDL     = -1.7618527e-016     WAGIDL     = -4.4471339e-015
+PAGIDL     = 1.0923487e-022      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010855278         LAIGSD     = 1.4755516e-011
+WAIGSD     = -1.0399134e-010     PAIGSD     = 1.0923487e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00034199185       LTVOFF     = -1.6352195e-011     WTVOFF     = -2.9672342e-011
+PTVOFF     = 1.638523e-018       KT1        = -0.2610052          LKT1       = -9.9588457e-009
+WKT1       = -2.4938587e-009     PKT1       = 2.6146457e-016      KT1L       = 0
+KT2        = -0.08304073         LKT2       = -5.9517585e-010     WKT2       = 4.2609281e-009
+PKT2       = 3.659368e-016       UTE        = -1                  UA1        = 5.3903002e-010
+LUA1       = -2.4428307e-017     WUA1       = -3.8497671e-017     PUA1       = 9.5078026e-024
+UB1        = -4.6064538e-019     LUB1       = 2.7231635e-026      WUB1       = 2.8761801e-026
+PUB1       = -1.2889714e-032     UC1        = 8.9319326e-011      LUC1       = 6.2347561e-018
+WUC1       = -5.7919224e-018     PUC1       = -3.3535103e-024     PRT        = 0
+AT         = '62885.449+datn_hvt'
+LAT        = -0.003354127        WAT        = 0.0012086199        PAT        = 1.0923487e-011
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-dxln_hvt'
+WMIN       = '3e-007-dxwn_hvt'   WMAX       = '6e-007-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42852522+dvthn_hvt'
+LVTH0      = '5.4372004e-009+dlvthn_hvt'
+WVTH0      = '1.6263563e-008+dwvthn_hvt'
+PVTH0      = '-9.505199e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.042921137+dk2n_hvt'
+LK2        = '4.8025448e-010+dlk2n_hvt'
+WK2        = '8.9991682e-010+dwk2n_hvt'
+PK2        = '1.7952263e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0029497941+dcitn_hvt-0.00198818*ff_flag_hvt'
+LCIT       = '-9.3513424e-011+dlcitn_hvt+1.90428e-10*ff_flag_hvt'
+WCIT       = '-7.6651852e-010+dwcitn_hvt+6.36217e-10*ff_flag_hvt'
+PCIT       = '5.0170863e-017+dpcitn_hvt-6.0937e-17*ff_flag_hvt'
+VOFF       = '-0.11162465+dvoffn_hvt'
+LVOFF      = '-5.7713837e-009+dlvoffn_hvt'
+WVOFF      = '-1.8206912e-008+dwvoffn_hvt'
+PVOFF      = '9.7947875e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.081002552+deta0n_hvt'
+LETA0      = '-9.2037575e-010+dleta0n_hvt'
+WETA0      = '-6.6421214e-009+dweta0n_hvt'
+PETA0      = '6.6852331e-016+dpeta0n_hvt'
+ETAB       = -0.043984           WETAB      = 6.3488e-010         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0084941866+du0n_hvt'
+LU0        = '2.133179e-010+dlu0n_hvt'
+WU0        = '1.1095601e-009+dwu0n_hvt'
+PU0        = '-1.2654432e-016+dpu0n_hvt'
+UA         = -1.5470255e-009     LUA        = 3.0099569e-018      WUA        = 2.7299671e-017
+PUA        = 3.6561762e-024      UB         = 8.6403595e-019      LUB        = 4.0003629e-026
+WUB        = 1.5811482e-025      PUB        = -2.0400633e-032     UC         = -1.7596009e-010
+LUC        = 1.0510483e-017      WUC        = 5.7838133e-017      PUC        = -4.0999954e-024
+VSAT       = '91413.362+dvsatn_hvt'
+LVSAT      = '-0.00061427692+dlvsatn_hvt'
+A0         = '1.9053792+da0n_hvt'
+LA0        = '-1.1573971e-007+dla0n_hvt'
+WA0        = '4.1264533e-007+dwa0n_hvt'
+PA0        = '-4.9699193e-014+dpa0n_hvt'
+AGS        = -4.8405472          LAGS       = 4.4850827e-007      WAGS       = -5.7587186e-007
+PAGS       = 6.4594377e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.096747294
+LKETA      = -7.9300079e-009     WKETA      = -4.0918034e-008     PKETA      = 1.8250413e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.34167982+dpclmn_hvt'
+LPCLM      = 9.0540741e-008      WPCLM      = 3.2845239e-007      PPCLM      = -2.6458974e-014
+PDIBLC1    = 0
+PDIBLC2    = '0.0013152167+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '-3.0191711e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-6.139383e-010-4.4e-15*ff_flag_hvt'
+PPDIBLC2   = '5.8803501e-017+3.1e-22*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -7.7202355e-008     LAGIDL     = 9.6293887e-015      WAGIDL     = 3.2185541e-014
+PAGIDL     = -3.399472e-021      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.012273835         LAIGSD     = -1.2111493e-010
+WAIGSD     = -3.8948256e-010     PAIGSD     = 2.8436926e-017      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 3.1348491e-005      LTVOFF     = 1.3401475e-011      WTVOFF     = -2.6280616e-010
+PTVOFF     = 2.3968267e-017      KT1        = -0.3821311          LKT1       = 1.6426901e-009
+WKT1       = -5.2967973e-009     PKT1       = 5.2993228e-016      KT1L       = 0
+KT2        = -0.12696737         LKT2       = 3.6121531e-009      WKT2       = 2.5280248e-008
+PKT2       = -1.6473105e-015     UTE        = -1                  UA1        = -3.8008776e-010
+LUA1       = 6.3605529e-017      WUA1       = 3.2847538e-016      PUA1       = -2.564117e-023
+UB1        = 5.7809179e-019      LUB1       = -7.2259442e-026     WUB1       = -3.0515772e-025
+PUB1       = 1.9093365e-032      UC1        = 2.7796675e-010      LUC1       = -1.1834045e-017
+WUC1       = -1.1492221e-016     PUC1       = 7.0990755e-024      PRT        = 0
+AT         = '54161.45+datn_hvt' LAT        = -0.0025185354       WAT        = -0.0050393882
+PAT        = 6.0936271e-010      NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hvt'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51228418+dvthn_hvt'
+WVTH0      = '-3.1520563e-009+dwvthn_hvt'
+K1         = 0.48686             K2         = '-0.027700402+dk2n_hvt'
+WK2        = '5.7282437e-009+dwk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.2115556e-006+dcitn_hvt'
+WCIT       = '-5.8961778e-013+dwcitn_hvt'
+VOFF       = '-0.16804363+dvoffn_hvt'
+WVOFF      = '5.0652597e-009+dwvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.009243+du0n_hvt' UA         = -1.9128889e-009
+WUA        = -7.7155556e-018     UB         = 1.7494485e-018      WUB        = 2.7616975e-026
+UC         = -1.1097778e-012     WUC        = -1.6730311e-018     VSAT       = '85000+dvsatn_hvt'
+A0         = '2.4627778+da0n_hvt'
+WA0        = '4.0071111e-008+dwa0n_hvt'
+AGS        = 0.70174031          WAGS       = 1.4735516e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.023713333         WKETA      = -3.8154667e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.10196778+dpclmn_hvt'
+WPCLM      = -2.1528889e-009     PDIBLC1    = 0                   PDIBLC2    = '0.00016111111+dpdiblc2n_hvt'
+WPDIBLC2   = 1.2444444e-011      PDIBLCB    = 0.36                DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.628e-007
+ALPHA1     = 0.74177             BETA0      = 14.347              AGIDL      = -3.9509333e-009
+WAGIDL     = 3.3531307e-015      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010226667         WAIGSD     = 7.4666667e-011
+BIGSD      = 0.0005681           CIGSD      = 0.001732            NIGC       = 2.211
+POXEDGE    = 1                   PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_hvt'
+CGDO       = 'cgon_hvt'          CGBO       = 0                   CGDL       = 'cgln_hvt'
+CGSL       = 'cgln_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                   NOFF       = 2.4376
+VOFFCV     = -0.1183             TVOFF      = 0.00057671111       LTVOFF     = 0
+WTVOFF     = -1.5353956e-010     PTVOFF     = 0                   KT1        = -0.25007282
+WKT1       = -8.8766023e-009     KT1L       = 0                   KT2        = -0.078571111
+WKT2       = 4.2883556e-009      UTE        = -1                  UA1        = 6.9660797e-010
+WUA1       = 5.6192102e-018      UB1        = -5.3755556e-019     WUB1       = 3.8017778e-026
+UC1        = -2.2012222e-027     WUC1       = 2.5959111e-034      PRT        = 0
+AT         = '180000+datn_hvt'   NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'
+NOIC       = 'noicn_hvt'               EM         = 2e+06               EF         = 1.00
+JSS        = 1.99e-07            JSD        = 1.99e-07            JSWS       = 5.1e-13
+JSWD       = 5.1e-13             JSWGS      = 5.1e-13             JSWGD      = 5.1e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 8.85                BVD        = 8.85                XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjn_hvt'           CJD        = 'cjn_hvt'           MJS        = 0.5
+MJD        = 0.5                 PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_hvt'         CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05
+MJSWD      = 0.05                PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_hvt'        CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445
+MJSWGD     = 0.445               TPB        = 0.0015              TCJ        = 0.000773
+TPBSW      = 0.0018              TCJSW      = 0.0005              TPBSWG     = 0.00198
+TCJSWG     = 0.00104             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.0773e-010         JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267
+XTSSWGS    = 0.1489045           XTSSWGD    = 0.1489045           TNJTSSWG   = 1
+VTSSWGS    = 24.384              VTSSWGD    = 24.384              DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_hvt'      PVTH0      = '0+dpvthn_hvt'
+LK2        = '0+dlk2n_hvt'       PK2        = '0+dpk2n_hvt'       LCIT       = '0+dlcitn_hvt'
+PCIT       = '0+dpcitn_hvt'      LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'
+PNFACTOR   = '0+dpnfactorn_hvt'  LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'
+LU0        = '0+dlu0n_hvt'       WU0        = '0+dwu0n_hvt'       PU0        = '0+dpu0n_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+LA0        = '0+dla0n_hvt'       PA0        = '0+dpa0n_hvt'       LVOFF      = '0+dlvoffn_hvt'
+PVOFF      = '0+dpvoffn_hvt'     LPDIBLC2   = '0+dlpdiblc2n_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '9.999998e-007-dxln_hvt'
+LMAX       = '1e-005-dxln_hvt'   WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '1.694588E-08+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.51234878+dvthn_hvt'
+LVTH0      = '-6.4382948e-010+dlvthn_hvt'
+WVTH0      = '-2.8613456e-009+dwvthn_hvt'
+PVTH0      = '-2.8969643e-015+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.026542885+dk2n_hvt'
+LK2        = '-1.1534782e-008+dlk2n_hvt'
+WK2        = '5.6719354e-009+dwk2n_hvt'
+PK2        = '5.6111864e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.8095546e-005+dcitn_hvt'
+LCIT       = '-1.8818104e-010+dlcitn_hvt'
+WCIT       = '-6.5512025e-012+dwcitn_hvt'
+PCIT       = '5.9407847e-017+dpcitn_hvt'
+VOFF       = '-0.16583617+dvoffn_hvt'
+LVOFF      = '-2.1997539e-008+dlvoffn_hvt'
+WVOFF      = '4.8239142e-009+dwvoffn_hvt'
+PVOFF      = '2.405035e-015+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.009196234+du0n_hvt'
+LU0        = '4.6602859e-010+dlu0n_hvt'
+WU0        = '5.1510543e-012+dwu0n_hvt'
+PU0        = '-5.1330823e-017+dpu0n_hvt'
+UA         = -1.9494081e-009     LUA        = 3.6391787e-016      WUA        = -3.5786985e-018
+PUA        = -4.1224236e-023     UB         = 1.7949578e-018      LUB        = -4.535054e-025
+WUB        = 2.2307263e-026      PUB        = 5.291186e-032       UC         = 2.4818506e-012
+LUC        = -3.5790972e-017     WUC        = -2.382366e-018      PUC        = 7.0686e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.4767003+da0n_hvt'
+LA0        = '-1.387395e-007+dla0n_hvt'
+WA0        = '5.0942878e-008+dwa0n_hvt'
+PA0        = '-1.0833836e-013+dpa0n_hvt'
+AGS        = 0.69695355          LAGS       = 4.7700611e-008      WAGS       = 1.2508105e-008
+PAGS       = 2.21964e-014        A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.021443805
+LKETA      = 2.26161e-008        WKETA      = -2.8652439e-009     PKETA      = -9.469074e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.078433349+dpclmn_hvt'
+LPCLM      = 2.3452317e-007      WPCLM      = -2.3541986e-009     PPCLM      = 2.0060734e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.00033562153+dpdiblc2n_hvt'
+LPDIBLC2   = '4.9499954e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = 5.1511054e-011      PPDIBLC2   = -3.8930307e-016     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = -5.7365638e-009     LAGIDL     = 1.7794005e-014      WAGIDL     = 3.8053772e-015
+PAGIDL     = -4.5066867e-021     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010177577         LAIGSD     = 4.891816e-010
+WAIGSD     = 8.6943791e-011      PAIGSD     = -1.2234289e-016     BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.0006678292        LTVOFF     = -9.0800179e-010     WTVOFF     = -1.7937223e-010
+PTVOFF     = 2.5742541e-016      KT1        = -0.24668894         LKT1       = -3.3720694e-008
+WKT1       = -8.8830857e-009     PKT1       = 6.4607686e-017      KT1L       = 0
+KT2        = -0.079299589        LKT2       = 7.25936e-009        WKT2       = 4.4813199e-009
+PKT2       = -1.9229111e-015     UTE        = -1                  UA1        = 7.1237702e-010
+LUA1       = -1.5714029e-016     WUA1       = 3.3927053e-018      PUA1       = 2.2187367e-023
+UB1        = -5.5056664e-019     LUB1       = 1.2965687e-025      WUB1       = 4.4283115e-026
+PUB1       = -6.243477e-032      UC1        = -4.5276662e-015     LUC1       = 4.5118691e-020
+WUC1       = -1.9002853e-019     PUC1       = 1.8936552e-024      PRT        = 0
+AT         = '186195.75+datn_hvt'
+LAT        = -0.061741367        WAT        = -0.00026689401      PAT        = 2.6596281e-009
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.4e-007-dxln_hvt'
+LMAX       = '9.999998e-007-dxln_hvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.50579229+dvthn_hvt'
+LVTH0      = '5.6838921e-009+dlvthn_hvt'
+WVTH0      = '-5.4160336e-009+dwvthn_hvt'
+PVTH0      = '-4.3141451e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.033880681+dk2n_hvt'
+LK2        = '-4.4530155e-009+dlk2n_hvt'
+WK2        = '5.948235e-009+dwk2n_hvt'
+PK2        = '2.9445968e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.1708385e-005+dcitn_hvt'
+LCIT       = '-1.8201674e-010+dlcitn_hvt'
+WCIT       = '-5.3466832e-012+dwcitn_hvt'
+PCIT       = '5.8245356e-017+dpcitn_hvt'
+VOFF       = '-0.18317423+dvoffn_hvt'
+LVOFF      = '-5.2644364e-009+dlvoffn_hvt'
+WVOFF      = '7.7312239e-009+dwvoffn_hvt'
+PVOFF      = '-4.0083295e-016+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049378+deta0n_hvt'
+WETA0      = '-1.2174649e-008+dweta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.0092676886+du0n_hvt'
+LU0        = '3.9706713e-010+dlu0n_hvt'
+WU0        = '4.2645093e-011+dwu0n_hvt'
+PU0        = '-8.7516619e-017+dpu0n_hvt'
+UA         = -1.6998633e-009     LUA        = 1.230802e-016       WUA        = -3.3591884e-017
+PUA        = -1.225827e-023      UB         = 1.4354528e-018      LUB        = -1.0654419e-025
+WUB        = 7.3236778e-026      PUB        = 3.7593782e-033      UC         = -2.1093222e-011
+LUC        = -1.3038481e-017     WUC        = 2.8563953e-018      PUC        = 2.0126297e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.5873486+da0n_hvt'
+LA0        = '-2.4552705e-007+dla0n_hvt'
+WA0        = '-5.5195882e-008+dwa0n_hvt'
+PA0        = '-5.9029885e-015+dpa0n_hvt'
+AGS        = 0.5431558           LAGS       = 1.9613205e-007      WAGS       = 1.0308999e-008
+PAGS       = 2.4318775e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.042376717
+LKETA      = 2.4135791e-009      WKETA      = -1.1004146e-008     PKETA      = -1.6141542e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.32342178+dpclmn_hvt'
+LPCLM      = -1.917125e-009      WPCLM      = -1.9897424e-008     PPCLM      = 1.8937181e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0063906368+dpdiblc2n_hvt'
+LPDIBLC2   = '-1.5415703e-009+dlpdiblc2n_hvt'
+WPDIBLC2   = -4.9841445e-010     PPDIBLC2   = 1.4143444e-016      PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 1.1601063e-008      LAGIDL     = 1.0613221e-015      WAGIDL     = -7.1028482e-016
+PAGIDL     = -1.4858509e-022     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010724308         LAIGSD     = -3.8472926e-011
+WAIGSD     = -5.7527272e-011     PAIGSD     = 1.7087286e-017      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.00037839866      LTVOFF     = 1.0172109e-010      WTVOFF     = 1.0129311e-010
+PTVOFF     = -1.3446951e-017     KT1        = -0.28676733         LKT1       = 4.9592795e-009
+WKT1       = -7.1997481e-009     PKT1       = -1.5599949e-015     KT1L       = 0
+KT2        = -0.071167105        LKT2       = -5.8936542e-010     WKT2       = 2.6220617e-009
+PKT2       = -1.2852611e-016     UTE        = -1                  UA1        = 6.1336742e-010
+LUA1       = -6.1585337e-017     WUA1       = 2.4777067e-017      PUA1       = 1.5491482e-024
+UB1        = -4.4649813e-019     LUB1       = 2.9219524e-026      WUB1       = -1.5867159e-026
+PUB1       = -4.3832602e-033     UC1        = -2.6148331e-011     LUC1       = 2.5276712e-017
+WUC1       = 5.4993869e-018      PUC1       = -3.5972451e-024     PRT        = 0
+AT         = '145546.01+datn_hvt'
+LAT        = -0.022509978        WAT        = 0.00273522          PAT        = -2.3773615e-010
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LETA0      = '0+dleta0n_hvt'     PETA0      = '0+dpeta0n_hvt'     LVSAT      = '0+dlvsatn_hvt'
+WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999926e-008-dxln_hvt'
+LMAX       = '2.4e-007-dxln_hvt' WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_hvt'          TOXM       = 2.6e-009            DTOX       = 3.3157e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'
+DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.54277891+dvthn_hvt'
+LVTH0      = '-2.7484641e-009+dlvthn_hvt'
+WVTH0      = '-1.0521336e-008+dwvthn_hvt'
+PVTH0      = '7.3251285e-016+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.057011061+dk2n_hvt'
+LK2        = '8.2034108e-010+dlk2n_hvt'
+WK2        = '8.0317137e-009+dwk2n_hvt'
+PK2        = '-1.8054013e-016+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0024251868+dcitn_hvt'
+LCIT       = '3.7583621e-010+dlcitn_hvt'
+WCIT       = '4.9713459e-010+dwcitn_hvt'
+PCIT       = '-5.6312335e-017+dpcitn_hvt'
+VOFF       = '-0.19831769+dvoffn_hvt'
+LVOFF      = '-1.8119706e-009+dlvoffn_hvt'
+WVOFF      = '5.5674846e-009+dwvoffn_hvt'
+PVOFF      = '9.2464993e-017+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.11049331+deta0n_hvt'
+LETA0      = '1.0676827e-013+dleta0n_hvt'
+WETA0      = '-1.2174583e-008+dweta0n_hvt'
+PETA0      = '-1.4947558e-020+dpeta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0                   U0         = '0.011644154+du0n_hvt'
+LU0        = '-1.4472886e-010+dlu0n_hvt'
+WU0        = '-5.714943e-010+dwu0n_hvt'
+PU0        = '5.2497336e-017+dpu0n_hvt'
+UA         = -1.0911728e-009     LUA        = -1.56915e-017       WUA        = -1.3766906e-016
+PUA        = 1.1469661e-023      UB         = 9.6663712e-019      LUB        = 3.3827571e-028
+WUB        = 1.2226828e-025      PUB        = -7.4190206e-033     UC         = -1.1464114e-010
+LUC        = 8.2889478e-018      WUC        = 1.8097751e-017      PUC        = -1.4621557e-024
+VSAT       = '85000+dvsatn_hvt'  A0         = '2.1662588+da0n_hvt'
+LA0        = '-1.4952532e-007+dla0n_hvt'
+WA0        = '-8.4162443e-008+dwa0n_hvt'
+PA0        = '7.0092372e-016+dpa0n_hvt'
+AGS        = 2.9032334           LAGS       = -3.4192788e-007     WAGS       = 1.2392635e-008
+PAGS       = 2.3843739e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.094645246
+LKETA      = -9.5028092e-009     WKETA      = -1.9640422e-008     PKETA      = 3.547784e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.1577434+dpclmn_hvt'
+LPCLM      = 3.5854896e-008      WPCLM      = 5.4523696e-008      PPCLM      = 1.970356e-015
+PDIBLC1    = 0                   PDIBLC2    = '-0.001258821+dpdiblc2n_hvt'
+LPDIBLC2   = '2.0238365e-010+dlpdiblc2n_hvt'
+WPDIBLC2   = 1.7650212e-010      PPDIBLC2   = -1.2435743e-017     PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 2.2559981e-008      LAGIDL     = -1.4371359e-015     WAGIDL     = -3.6110329e-015
+PAGIDL     = 5.1273906e-022      BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010515306         LAIGSD     = 9.1763159e-012
+WAIGSD     = 4.7998774e-012      PAIGSD     = 2.8776927e-018      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = 0.00019311573       LTVOFF     = -2.8575048e-011     WTVOFF     = 1.7968017e-011
+PTVOFF     = 5.5498359e-018      KT1        = -0.1993459          LKT1       = -1.4971409e-008
+WKT1       = -2.2224836e-008     PKT1       = 1.8654848e-015      KT1L       = 0
+KT2        = -0.078321382        LKT2       = 1.0416954e-009      WKT2       = 2.7507369e-009
+PKT2       = -1.57862e-016       UTE        = -1                  UA1        = 3.8300931e-010
+LUA1       = -9.0673747e-018     WUA1       = 1.1428955e-017      PUA1       = 4.5923042e-024
+UB1        = -3.6816262e-019     LUB1       = 1.1360279e-026      WUB1       = -8.3268299e-028
+PUB1       = -7.8108801e-033     UC1        = 1.2007767e-010      LUC1       = -8.0604759e-018
+WUC1       = -1.5634592e-017     PUC1       = 1.2209639e-024      PRT        = 0
+AT         = '60359.202+datn_hvt'
+LAT        = -0.0030887479       WAT        = 0.002017019         PAT        = -7.3997812e-011
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+LVSAT      = '0+dlvsatn_hvt'     WVSAT      = '0+dwvsatn_hvt'     PVSAT      = '0+dpvsatn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_hvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999926e-008-dxln_hvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_hvt'
+TOXM       = 2.6e-009            DTOX       = 3.3157e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_hvt'   XW         = '2e-08+dxwn_hvt'    DLC        = '-5.415E-09+ddlcn_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4884551+dvthn_hvt'
+LVTH0      = '2.4547135e-009+dlvthn_hvt'
+WVTH0      = '-2.9139982e-009+dwvthn_hvt'
+PVTH0      = '3.8759072e-018+dpvthn_hvt'
+K1         = 0.48686             K2         = '-0.059489688+dk2n_hvt'
+LK2        = '1.057746e-009+dlk2n_hvt'
+WK2        = '6.2018534e-009+dwk2n_hvt'
+PK2        = '-5.2746416e-018+dpk2n_hvt'
+K3         = -4.051853           K3B        = 3.7250013           W0         = 0
+DVT0       = 2.535               DVT1       = 0.845               DVT2       = 2.22e-016
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.405               MINV       = -0.1596             VOFFL      = 0
+DVTP0      = 9.206e-006          DVTP1      = 0.2616              LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 5.328e+020          NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0020076336+dcitn_hvt'
+LCIT       = '-4.8742874e-011+dlcitn_hvt'
+WCIT       = '-4.6502715e-010+dwcitn_hvt'
+PCIT       = '3.5844287e-017+dpcitn_hvt'
+VOFF       = '-0.19091382+dvoffn_hvt'
+LVOFF      = '-2.5211195e-009+dlvoffn_hvt'
+WVOFF      = '7.1656209e-009+dwvoffn_hvt'
+PVOFF      = '-6.0605779e-017+dpvoffn_hvt'
+NFACTOR    = '1+dnfactorn_hvt'   ETA0       = '0.12787478+deta0n_hvt'
+LETA0      = '-1.6647044e-009+dleta0n_hvt'
+WETA0      = '-2.1641235e-008+dweta0n_hvt'
+PETA0      = '9.0670848e-016+dpeta0n_hvt'
+ETAB       = -0.040047778        WETAB      = -6.2471111e-010     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = 0.001
+LKU0WE     = -0.7e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0
+U0         = '0.012025944+du0n_hvt-0.000773181*ss_flag_hvt'
+LU0        = '-1.8129701e-010+dlu0n_hvt+7.40554e-11*ss_flag_hvt'
+WU0        = '-2.060218e-011+dwu0n_hvt+2.47418e-10*ss_flag_hvt'
+PU0        = '-2.6755173e-019+dpu0n_hvt-2.36977e-17*ss_flag_hvt'
+UA         = -1.4443723e-009     LUA        = 1.8138233e-017      WUA        = -5.5493377e-018
+PUA        = -1.1848719e-024     UB         = 1.2479661e-018      LUB        = -2.6607642e-026
+WUB        = 3.5257163e-026      PUB        = 9.1497416e-034      UC         = -1.8256357e-011
+LUC        = -9.4286389e-019     WUC        = 7.3729378e-018      PUC        = -4.3492444e-025
+VSAT       = '88919.277+dvsatn_hvt'
+LVSAT      = '-0.00037539145+dlvsatn_hvt'
+WVSAT      = '0.00079810724+dwvsatn_hvt'
+PVSAT      = '-7.644335e-011+dpvsatn_hvt'
+A0         = '3.3212421+da0n_hvt'
+LA0        = '-2.6015054e-007+dla0n_hvt'
+WA0        = '-4.0430801e-008+dwa0n_hvt'
+PA0        = '-3.4877279e-015+dpa0n_hvt'
+AGS        = -9.2463195          LAGS       = 8.2176602e-007      WAGS       = 8.3397528e-007
+PAGS       = -5.4848104e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.16625457
+LKETA      = -1.6361607e-008     WKETA      = -6.3160361e-008     PKETA      = 4.523153e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.4610665+dpclmn_hvt'
+LPCLM      = 6.8023664e-009      WPCLM      = 7.1573562e-008      PPCLM      = 3.3730625e-016
+PDIBLC1    = 0
+PDIBLC2    = '0.00026404831+dpdiblc2n_hvt-0.00320674*ff_flag_hvt'
+LPDIBLC2   = '5.6522009e-011+dlpdiblc2n_hvt+3.07142e-10*ff_flag_hvt'
+WPDIBLC2   = '-2.775644e-010-7e-17*ff_flag_hvt'
+PPDIBLC2   = '3.1055111e-017-4.2e-23*ff_flag_hvt'
+PDIBLCB    = 0.36
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 600
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '52.68+drdswn_hvt'  RDW        = '52.68+drdswn_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.628e-007          ALPHA1     = 0.74177             BETA0      = 14.347
+AGIDL      = 9.2037183e-009      LAGIDL     = -1.5786234e-016     WAGIDL     = 4.5355976e-015
+PAGIDL     = -2.6755173e-022     BGIDL      = 1.7187e+009         CGIDL      = 64.8
+EGIDL      = -0.075922           AIGBACC    = 0.01397             BIGBACC    = 0.005651
+CIGBACC    = 0.17808             NIGBACC    = 10                  AIGBINV    = 0.01186
+BIGBINV    = 0.002321            CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3.056               AIGC       = 0.00986             BIGC       = 0.002797
+CIGC       = 0.40778504          AIGSD      = 0.010947813         LAIGSD     = -3.2249538e-011
+WAIGSD     = 3.4844444e-011      PAIGSD     = 9.7315253e-031      BIGSD      = 0.0005681
+CIGSD      = 0.001732            NIGC       = 2.211               POXEDGE    = 1
+PIGCD      = 3.146               NTOX       = 'ntoxn_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_hvt'          CGDO       = 'cgon_hvt'
+CGBO       = 0                   CGDL       = 'cgln_hvt'          CGSL       = 'cgln_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                   NOFF       = 2.4376              VOFFCV     = -0.1183
+TVOFF      = -0.0010982244       LTVOFF     = 9.5110543e-011      WTVOFF     = 9.8657168e-011
+PTVOFF     = -2.1786355e-018     KT1        = -0.3903388          LKT1       = 3.3220437e-009
+WKT1       = -2.6703358e-009     PKT1       = -7.460871e-018      KT1L       = 0
+KT2        = -0.028142337        LKT2       = -3.7644937e-009     WKT2       = -6.3437628e-009
+PKT2       = 7.1321646e-016      UTE        = -1                  UA1        = 2.20354e-010
+LUA1       = 6.5118814e-018      WUA1       = 1.3633402e-016      PUA1       = -7.3712029e-024
+UB1        = 3.2461847e-019      LUB1       = -5.4994848e-026     WUB1       = -2.2404626e-025
+PUB1       = 1.3568695e-032      UC1        = -1.2102699e-010     LUC1       = 1.5032721e-017
+WUC1       = 1.2755791e-017      PUC1       = -1.4982897e-024     PRT        = 0
+AT         = '27042.218+datn_hvt'
+LAT        = 0.00010237949       WAT        = 0.0036387662        PAT        = -2.2933005e-010
+NOIA       = 'noian_hvt'             NOIB       = 'noibn_hvt'          NOIC       = 'noicn_hvt'
+EM         = 2e+06               EF         = 1.00                   JSS        = 1.99e-07
+JSD        = 1.99e-07            JSWS       = 5.1e-13             JSWD       = 5.1e-13
+JSWGS      = 5.1e-13             JSWGD      = 5.1e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 8.85
+BVD        = 8.85                XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjn_hvt'
+CJD        = 'cjn_hvt'           MJS        = 0.5                 MJD        = 0.5
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_hvt'
+CJSWD      = 'cjswn_hvt'         MJSWS      = 0.05                MJSWD      = 0.05
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_hvt'
+CJSWGD     = 'cjswgn_hvt'        MJSWGS     = 0.445               MJSWGD     = 0.445
+TPB        = 0.0015              TCJ        = 0.000773            TPBSW      = 0.0018
+TCJSW      = 0.0005              TPBSWG     = 0.00198             TCJSWG     = 0.00104
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.0773e-010
+JTSSWGD    = 1.0773e-010         NJTSSWG    = 6.8267              XTSSWGS    = 0.1489045
+XTSSWGD    = 0.1489045           TNJTSSWG   = 1                   VTSSWGS    = 24.384
+VTSSWGD    = 24.384              DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = -1e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.7e-008
+PKU0     = 8e-14
+LKU0       = 20e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.1
+STETA0     = -3.0e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_hvt'  WNFACTOR   = '0+dwnfactorn_hvt'  PNFACTOR   = '0+dpnfactorn_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )

**********************************************************************************************
*                                                                                            *
*                                1.2V HI-VT PMOS DEVICE MODELS                                 *
*                                                                                            *
**********************************************************************************************



.MODEL pch_hvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hvt'
+LMAX       = 2.001e-05           WMIN       = '1e-005-dxwp_hvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.6126+dvthp_hvt' K1         = 0.45227
+K2         = '0.00875238+dk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.998e-006+dcitp_hvt'
+VOFF       = '-0.1169336+dvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.0155+du0p_hvt'
+UA         = 2.182e-009          UB         = '2.35199e-020+dubp_hvt'
+UC         = -1.587e-010         VSAT       = '80000+dvsatp_hvt'  A0         = '1.9367211+da0p_hvt'
+AGS        = 0.6941              A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.005274
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0007+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01331             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.006741            BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006354            BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.000826
+LTVOFF     = 0                   WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2284             KT1L       = 0                   KT2        = -0.062
+UTE        = -1                  UA1        = 3.2470362e-009      UB1        = -3.44e-018
+UC1        = 1.5e-010            PRT        = 0                   AT         = '160000+datp_hvt'
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LA0        = '0+dla0p_hvt'       WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'
+LVOFF      = '0+dlvoffp_hvt'     WVOFF      = '0+dwvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-dxlp_hvt'
+LMAX       = '1e-005-dxlp_hvt'   WMIN       = '1e-005-dxwp_hvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61212866+dvthp_hvt'
+LVTH0      = '-4.6965102e-009+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0086881253+dk2p_hvt'
+LK2        = '6.4024108e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-6.9962746e-006+dcitp_hvt'
+LCIT       = '1.2947638e-010+dlcitp_hvt'
+VOFF       = '-0.1162912+dvoffp_hvt'
+LVOFF      = '-6.4009164e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015481789+du0p_hvt'
+LU0        = '1.8145608e-010+dlu0p_hvt'
+UA         = 2.1793219e-009      LUA        = 2.6684717e-017      UB         = '2.3131224e-020+dubp_hvt'
+LUB        = '3.8728063e-027+dlubp_hvt'
+UC         = -1.6405617e-010     LUC        = 5.3369434e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9439756+da0p_hvt'
+LA0        = '-7.2284714e-008+dla0p_hvt'
+AGS        = 0.67174336          LAGS       = 2.2276402e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0080574927        LKETA      = -2.7735027e-008     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00067199796+dpdiblc2p_hvt'
+LPDIBLC2   = 2.790154e-010       PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.013307858         LAIGBACC   = 2.1347774e-011
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.006740143
+LAIGC      = 8.5391094e-012      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063562496        LAIGSD     = -2.2415162e-011     BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00077115285       LTVOFF     = 5.46503e-010        WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2291634          LKT1       = 7.6066387e-009
+KT1L       = 0                   KT2        = -0.061571507        LKT2       = -4.2695547e-009
+UTE        = -1                  UA1        = 3.3091074e-009      LUA1       = -6.1848365e-016
+UB1        = -3.4560685e-018     LUB1       = 1.601083e-025       UC1        = 1.7142467e-010
+LUC1       = -2.1347774e-016     PRT        = 0                   AT         = '163213.7+datp_hvt'
+LAT        = -0.03202166         NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'
+PPCLM      = '0+dppclmp_hvt'     WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-dxlp_hvt'
+LMAX       = '1.000004e-006-dxlp_hvt'
+WMIN       = '1e-005-dxwp_hvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61593416+dvthp_hvt'
+LVTH0      = '-1.0275907e-009+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0089735747+dk2p_hvt'
+LK2        = '3.6503647e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-5.5398165e-005+dcitp_hvt'
+LCIT       = '1.7614113e-010+dlcitp_hvt'
+VOFF       = '-0.12126605+dvoffp_hvt'
+LVOFF      = '-1.604613e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015729562+du0p_hvt'
+LU0        = '-5.7424184e-011+dlu0p_hvt'
+UA         = 2.2430506e-009      LUA        = -3.4756743e-017     UB         = '3.148352e-020+dubp_hvt'
+LUB        = '-4.179725e-027+dlubp_hvt'
+UC         = -1.1646812e-010     LUC        = 7.4893225e-018      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.8505045+da0p_hvt'
+LA0        = '1.783172e-008+dla0p_hvt'
+AGS        = 0.54473918          LAGS       = 3.4521001e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0081330433       LKETA      = -1.212557e-008      DWG        = 0
+DWB        = 0                   PCLM       = '0.48798566+dpclmp_hvt'
+LPCLM      = '6.779076e-008+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0011060413+dpdiblc2p_hvt'
+LPDIBLC2   = -1.394501e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 6.0595496e-009      LAGIDL     = 9.0669764e-016      BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067486865
+LAIGC      = 3.0223255e-013      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006324536         LAIGSD     = 8.1602787e-012      BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.0014439574        LTVOFF     = -1.021546e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2170348          LKT1       = -4.0866676e-009
+KT1L       = 0                   KT2        = -0.066153607        LKT2       = 1.4809395e-010
+UTE        = -0.99028201         LUTE       = -9.3692089e-009     UA1        = 3.5037294e-009
+LUA1       = -8.0612069e-016     UB1        = -4.3840573e-018     LUB1       = 1.0547916e-024
+UC1        = -5e-011             PRT        = 0                   AT         = '131880.9+datp_hvt'
+LAT        = -0.0018133953       NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_hvt'
+LMAX       = '2.400007e-007-dxlp_hvt'
+WMIN       = '1e-005-dxwp_hvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61781514+dvthp_hvt'
+LVTH0      = '-5.9477527e-010+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.0081498936+dk2p_hvt'
+LK2        = '5.5456548e-010+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.2678647e-005+dcitp_hvt'
+LCIT       = '1.4206865e-010+dlcitp_hvt'
+VOFF       = '-0.12004674+dvoffp_hvt'
+LVOFF      = '-1.8851782e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.005+deta0p_hvt'  ETAB       = -0.002981
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.014783015+du0p_hvt'
+LU0        = '1.603762e-010+dlu0p_hvt'
+UA         = 1.9999369e-009      LUA        = 2.1183712e-017      UB         = '1.4122343e-020+dubp_hvt'
+LUB        = '-1.8491831e-028+dlubp_hvt'
+UC         = -1.8034671e-010     LUC        = 2.2187786e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '1.7431254+da0p_hvt'
+LA0        = '4.253965e-008+dla0p_hvt'
+AGS        = -1.2093921          LAGS       = 7.4883562e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.031512029        LKETA      = -6.7460652e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.76508556+dpclmp_hvt'
+LPCLM      = '4.0300721e-009+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.2515198e-009
+LAGIDL     = 1.722253e-016       BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067911664        LAIGC      = -9.4723917e-012
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0062694339
+LAIGSD     = 2.0839262e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0011848746
+LTVOFF     = -4.253965e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20254588         LKT1       = -7.4205683e-009     KT1L       = 0
+KT2        = -0.066872234        LKT2       = 3.1345005e-010      UTE        = -1.0542029
+LUTE       = 5.3389844e-009      UA1        = -1.1145711e-009     LUA1       = 2.5655026e-016
+UB1        = 1.52481e-018        LUB1       = -3.0483879e-025     UC1        = 1.3712006e-010
+LUC1       = -4.3056326e-017     PRT        = 0                   AT         = '164417.93+datp_hvt'
+LAT        = -0.0093001664       NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     WETA0      = '0+dweta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+WA0        = '0+dwa0p_hvt'       PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+WUB        = '0+dwubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_hvt'
+WMIN       = '1e-005-dxwp_hvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62049874+dvthp_hvt'
+LVTH0      = '-3.3044111e-010+dlvthp_hvt'
+K1         = 0.45227             K2         = '0.036036684+dk2p_hvt'
+LK2        = '-2.1922834e-009+dlk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0013071458+dcitp_hvt'
+LCIT       = '2.7995136e-010+dlcitp_hvt'
+VOFF       = '-0.097292557+dvoffp_hvt'
+LVOFF      = '-4.1264647e-009+dlvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0012648024+deta0p_hvt'
+LETA0      = '3.6791697e-010+dleta0p_hvt'
+ETAB       = -0.002981           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020077263+du0p_hvt'
+LU0        = '-3.6110716e-010+dlu0p_hvt'
+UA         = 3.1589863e-009      LUA        = -9.2982651e-017     UB         = '5.1450685e-021+dubp_hvt'
+LUB        = '6.9934326e-028+dlubp_hvt'
+UC         = 3.1029579e-010      LUC        = -2.61405e-017       VSAT       = '80000+dvsatp_hvt'
+A0         = '2.8116814+da0p_hvt'
+LA0        = '-6.2713119e-008+dla0p_hvt'
+AGS        = 0.15077171          LAGS       = 6.1485949e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10276744         LKETA      = 2.7259302e-010      DWG        = 0
+DWB        = 0                   PCLM       = '0.69003909+dpclmp_hvt'
+LPCLM      = '1.1422149e-008+dlpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0014100442+dpdiblc2p_hvt'
+LPDIBLC2   = 1.8813936e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 1.7791268e-008      LAGIDL     = -6.6893994e-016     BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067595171
+LAIGC      = -6.3549294e-012     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063672463        LAIGSD     = 1.1204744e-011      BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00061717463       LTVOFF     = 1.3378799e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.26051769         LKT1       = -1.7103456e-009
+KT1L       = 0                   KT2        = -0.062569441        LKT2       = -1.1037509e-010
+UTE        = -1                  UA1        = 3.5443587e-009      LUA1       = -2.0235433e-016
+UB1        = -4.2355728e-018     LUB1       = 2.6255893e-025      UC1        = -7.2445427e-010
+LUC1       = 4.1808746e-017      PRT        = 0                   AT         = '138591.81+datp_hvt'
+LAT        = -0.0067562934       NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+WK2        = '0+dwk2p_hvt'       PK2        = '0+dpk2p_hvt'       WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  WETA0      = '0+dweta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+WU0        = '0+dwu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     WA0        = '0+dwa0p_hvt'
+PA0        = '0+dpa0p_hvt'       WVOFF      = '0+dwvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'     WUB        = '0+dwubp_hvt'
+PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hvt'
+LMAX       = 2.001e-05           WMIN       = '1e-006-dxwp_hvt'   WMAX       = '1e-005-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61229953+dvthp_hvt'
+WVTH0      = '-3.0107027e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '0.010141663+dk2p_hvt'
+WK2        = '-1.3920616e-008+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '6.1111067e-006+dcitp_hvt'
+WCIT       = '-1.1333288e-012+dwcitp_hvt'
+VOFF       = '-0.11533828+dvoffp_hvt'
+WVOFF      = '-1.598516e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01548252+du0p_hvt'
+WU0        = '1.7515494e-010+dwu0p_hvt'
+UA         = 2.2249533e-009      WUA        = -4.303924e-016      UB         = '2.2806161e-020+dubp_hvt'
+WUB        = '7.1516681e-027+dwubp_hvt'
+UC         = -1.4579133e-010     WUC        = -1.2934484e-016     VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9316529+da0p_hvt'
+WA0        = '5.0782806e-008+dwa0p_hvt'
+AGS        = 0.69754533          WAGS       = -3.452224e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0027765867        WKETA      = 2.5024082e-008      DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00069773333+dpdiblc2p_hvt'
+WPDIBLC2   = 2.2712e-011         PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.013307733         WAIGBACC   = 2.2712e-011
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0067383933
+WAIGC      = 2.61188e-011        BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063455           WAIGSD     = 8.517e-011          BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 0.00080628          LTVOFF     = 0                   WTVOFF     = 1.975944e-010
+PTVOFF     = 0                   KT1        = -0.23137449         WKT1       = 2.9804351e-008
+KT1L       = 0                   KT2        = -0.062              UTE        = -0.99988667
+WUTE       = -1.1356e-009        UA1        = 3.3109785e-009      WUA1       = -6.4070122e-016
+UB1        = -3.5034667e-018     WUB1       = 6.35936e-025        UC1        = 1.5566667e-010
+WUC1       = -5.678e-017         PRT        = 0                   AT         = '158866.67+datp_hvt'
+WAT        = 0.011356            NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'
+PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-dxlp_hvt'
+LMAX       = '1e-005-dxlp_hvt'   WMIN       = '1e-006-dxwp_hvt'   WMAX       = '1e-005-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61180329+dvthp_hvt'
+LVTH0      = '-4.9446453e-009+dlvthp_hvt'
+WVTH0      = '-3.2602297e-009+dwvthp_hvt'
+PVTH0      = '2.486314e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.010100557+dk2p_hvt'
+LK2        = '4.0958863e-010+dlk2p_hvt'
+WK2        = '-1.4152563e-008+dwk2p_hvt'
+PK2        = '2.3111375e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.3558524e-006+dcitp_hvt'
+LCIT       = '1.4415037e-010+dlcitp_hvt'
+WCIT       = '1.3622969e-011+dwcitp_hvt'
+PCIT       = '-1.4703338e-016+dpcitp_hvt'
+VOFF       = '-0.11472162+dvoffp_hvt'
+LVOFF      = '-6.1444404e-009+dlvoffp_hvt'
+WVOFF      = '-1.5727245e-008+dwvoffp_hvt'
+PVOFF      = '-2.5698902e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015462922+du0p_hvt'
+LU0        = '1.9527577e-010+dlu0p_hvt'
+WU0        = '1.8905216e-010+dwu0p_hvt'
+PU0        = '-1.3847334e-016+dpu0p_hvt'
+UA         = 2.2229673e-009      LUA        = 1.9789386e-017      WUA        = -4.3732641e-016
+PUA        = 6.9091215e-023      UB         = '2.2282248e-020+dubp_hvt'
+LUB        = '5.2203233e-027+dlubp_hvt'
+WUB        = '8.5067435e-027+dwubp_hvt'
+PUB        = '-1.350212e-032+dpubp_hvt'
+UC         = -1.5148622e-010     LUC        = 5.6744517e-017      WUC        = -1.2595083e-016
+PUC        = -3.3818332e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.937358+da0p_hvt'
+LA0        = '-5.6845594e-008+dla0p_hvt'
+WA0        = '6.6308526e-008+dwa0p_hvt'
+PA0        = '-1.5469998e-013+dpa0p_hvt'
+AGS        = 0.67532224          LAGS       = 2.2143334e-007      WAGS       = -3.5860382e-008
+PAGS       = 1.3333392e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.0055851012
+LKETA      = -2.7984348e-008     WKETA      = 2.4773363e-008      PKETA      = 2.4981929e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00067845556+dpdiblc2p_hvt'
+LPDIBLC2   = 1.9208584e-010      WPDIBLC2   = -6.4705156e-011     PPDIBLC2   = 8.7103416e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.013305348         LAIGBACC   = 2.3767188e-011      WAIGBACC   = 2.5144985e-011
+PAIGBACC   = -2.4242532e-017     BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067373785        LAIGC      = 1.0111729e-011      WAIGC      = 2.770024e-011
+PAIGC      = -1.5757646e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063484416        LAIGSD     = -2.9310493e-011     WAIGSD     = 7.8235992e-011
+PAIGSD     = 6.9091215e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00072432279
+LTVOFF     = 8.1663061e-010      WTVOFF     = 4.6923719e-010      PTVOFF     = -2.7066787e-015
+KT1        = -0.23287197         LKT1       = 1.4921105e-008      WKT1       = 3.7159845e-008
+PKT1       = -7.329095e-014      KT1L       = 0                   KT2        = -0.061498663
+LKT2       = -4.995379e-009      WKT2       = -7.2989554e-010     PKT2       = 7.2727595e-015
+UTE        = -0.99987453         LUTE       = -1.2097072e-010     WUTE       = -1.2572493e-009
+PUTE       = 1.2121266e-015      UA1        = 3.3871642e-009      LUA1       = -7.591229e-016
+WUA1       = -7.8212933e-016     PUA1       = 1.4092052e-021      UB1        = -3.5249985e-018
+LUB1       = 2.1454512e-025      WUB1       = 6.9067817e-025      PUB1       = -5.4545696e-031
+UC1        = 1.7769837e-010      LUC1       = -2.1952627e-016     WUC1       = -6.2862463e-017
+PUC1       = 6.0606329e-023      PRT        = 0                   AT         = '162323.18+datp_hvt'
+LAT        = -0.034441075        WAT        = 0.0089230149        PAT        = 2.4242532e-008
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-dxlp_hvt'
+LMAX       = '1.000004e-006-dxlp_hvt'
+WMIN       = '1e-006-dxwp_hvt'   WMAX       = '1e-005-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61596443+dvthp_hvt'
+LVTH0      = '-9.3284166e-010+dlvthp_hvt'
+WVTH0      = '3.0336679e-010+dwvthp_hvt'
+PVTH0      = '-9.4938494e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.010146379+dk2p_hvt'
+LK2        = '3.6541093e-010+dlk2p_hvt'
+WK2        = '-1.1751499e-008+dwk2p_hvt'
+PK2        = '-3.7520902e-018+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-5.1890394e-005+dcitp_hvt'
+LCIT       = '1.8612246e-010+dlcitp_hvt'
+WCIT       = '-3.5147862e-011+dwcitp_hvt'
+PCIT       = '-1.0001293e-016+dpcitp_hvt'
+VOFF       = '-0.11940365+dvoffp_hvt'
+LVOFF      = '-1.630445e-009+dlvoffp_hvt'
+WVOFF      = '-1.8661273e-008+dwvoffp_hvt'
+PVOFF      = '2.588358e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015731779+du0p_hvt'
+LU0        = '-6.3932258e-011+dlu0p_hvt'
+WU0        = '-2.2214447e-011+dwu0p_hvt'
+PU0        = '6.5210903e-017+dpu0p_hvt'
+UA         = 2.2824572e-009      LUA        = -3.7565491e-017     WUA        = -3.9485453e-016
+PUA        = 2.8143653e-023      UB         = '3.2122294e-020+dubp_hvt'
+LUB        = '-4.2665633e-027+dlubp_hvt'
+WUB        = '-6.4005179e-027+dwubp_hvt'
+PUB        = '8.7011938e-034+dpubp_hvt'
+UC         = -9.9178128e-011     LUC        = 6.3137588e-018      WUC        = -1.7324572e-016
+PUC        = 1.1779148e-023      VSAT       = '80000+dvsatp_hvt'  A0         = '1.8541774+da0p_hvt'
+LA0        = '2.3349608e-008+dla0p_hvt'
+WA0        = '-3.680289e-008+dwa0p_hvt'
+PA0        = '-5.5289236e-014+dpa0p_hvt'
+AGS        = 0.54517566          LAGS       = 3.4690896e-007      WAGS       = -4.3734454e-009
+PAGS       = -1.7023478e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.010393893
+LKETA      = -1.257884e-008      WKETA      = 2.2653713e-008      PKETA      = 4.5417678e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.48952403+dpclmp_hvt'
+LPCLM      = '6.6307604e-008+dlpclmp_hvt'
+WPCLM      = '-1.5414446e-008+dwpclmp_hvt'
+PPCLM      = '1.4861222e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0009960922+dpdiblc2p_hvt'
+LPDIBLC2   = -1.1415082e-010     WPDIBLC2   = 1.1016897e-009      PPDIBLC2   = -2.5349881e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 5.9529652e-009
+LAGIDL     = 1.0094567e-015      WAGIDL     = 1.0679755e-015      PAGIDL     = -1.0296458e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067463808        LAIGC      = 1.4325823e-012      WAIGC      = 2.310373e-011
+PAIGC      = -1.1326104e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063062363        LAIGSD     = 1.1380063e-011      WAIGSD     = 1.8336243e-010
+PAIGSD     = -3.2262236e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0017455958
+LTVOFF     = -1.6798891e-010     WTVOFF     = -3.0224167e-009     PTVOFF     = 6.5965977e-016
+KT1        = -0.2115147          LKT1       = -5.6696539e-009     WKT1       = -5.5311421e-008
+PKT1       = 1.5861523e-014      KT1L       = 0                   KT2        = -0.066914966
+LKT2       = 2.2653337e-010      WKT2       = 7.6288213e-009      PKT2       = -7.8596299e-016
+UTE        = -0.99518489         LUTE       = -4.6422919e-009     WUTE       = 4.9126872e-008
+PUTE       = -4.7363709e-014     UA1        = 3.4120518e-009      LUA1       = -7.8311729e-016
+WUA1       = 9.1860953e-016      PUA1       = -2.304941e-022      UB1        = -4.4075377e-018
+LUB1       = 1.06541e-024        WUB1       = 2.3527347e-025      PUB1       = -1.0639674e-031
+UC1        = -4.4670781e-011     LUC1       = -5.1379533e-018     WUC1       = -5.3398774e-017
+PUC1       = 5.1482292e-023      PRT        = 0                   AT         = '126846.61+datp_hvt'
+LAT        = -0.00023775627      WAT        = 0.050443624         PAT        = -1.5787903e-008
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_hvt'
+LMAX       = '2.400007e-007-dxlp_hvt'
+WMIN       = '1e-006-dxwp_hvt'   WMAX       = '1e-005-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61684664+dvthp_hvt'
+LVTH0      = '-7.2984626e-010+dlvthp_hvt'
+WVTH0      = '-9.7044399e-009+dwvthp_hvt'
+PVTH0      = '1.3534114e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0091657792+dk2p_hvt'
+LK2        = '5.9104693e-010+dlk2p_hvt'
+WK2        = '-1.0179173e-008+dwk2p_hvt'
+PK2        = '-3.6554416e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00013928472+dcitp_hvt'
+LCIT       = '1.4213307e-010+dlcitp_hvt'
+WCIT       = '-4.6699281e-010+dwcitp_hvt'
+PCIT       = '-6.4541088e-019+dpcitp_hvt'
+VOFF       = '-0.11759164+dvoffp_hvt'
+LVOFF      = '-2.0473878e-009+dlvoffp_hvt'
+WVOFF      = '-2.4600015e-008+dwvoffp_hvt'
+PVOFF      = '1.6253402e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0052266667+deta0p_hvt'
+WETA0      = '-2.2712e-009+dweta0p_hvt'
+ETAB       = -0.0026116467       WETAB      = -3.7009204e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01468135+du0p_hvt'
+LU0        = '1.7777142e-010+dlu0p_hvt'
+WU0        = '1.018685e-009+dwu0p_hvt'
+PU0        = '-1.7430005e-016+dpu0p_hvt'
+UA         = 2.0115286e-009      LUA        = 2.4775184e-017      WUA        = -1.1614875e-016
+PUA        = -3.5986546e-023     UB         = '1.393665e-020+dubp_hvt'
+LUB        = '-8.2046654e-029+dlubp_hvt'
+WUB        = '1.8606441e-027+dwubp_hvt'
+PUB        = '-1.030774e-033+dpubp_hvt'
+UC         = -1.7637103e-010     LUC        = 2.4075846e-017      WUC        = -3.9836287e-017
+PUC        = -1.8918362e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.8037767+da0p_hvt'
+LA0        = '3.4946811e-008+dla0p_hvt'
+WA0        = '-6.0772635e-007+dwa0p_hvt'
+PA0        = '7.6080253e-014+dpa0p_hvt'
+AGS        = -1.2558619          LAGS       = 7.613277e-007       WAGS       = 4.6562707e-007
+PAGS       = -1.251706e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.030250419
+LKETA      = -8.0098533e-009     WKETA      = -1.2641329e-008     PKETA      = 1.2663157e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.7633423+dpclmp_hvt'
+LPCLM      = '3.3020183e-009+dlpclmp_hvt'
+WPCLM      = '1.7467444e-008+dwpclmp_hvt'
+PPCLM      = '7.2950988e-015+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 9.506692e-009
+LAGIDL     = 1.9174417e-016      WAGIDL     = -2.5568258e-015     PAGIDL     = -1.9557906e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067980145        LAIGC      = -1.0448335e-011     WAIGC      = -6.8617508e-011
+PAIGC      = 9.7789528e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0062559658        LAIGSD     = 2.29473e-011        WAIGSD     = 1.3495001e-010
+PAIGSD     = -2.1122538e-017     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0012435786
+LTVOFF     = -5.2474754e-011     WTVOFF     = -5.8821405e-010     PTVOFF     = 9.9549739e-017
+KT1        = -0.20169025         LKT1       = -7.9302606e-009     WKT1       = -8.5734562e-009
+PKT1       = 5.1071168e-015      KT1L       = 0                   KT2        = -0.066955086
+LKT2       = 2.3576496e-010      WKT2       = 8.3017883e-010      PKT2       = 7.7840464e-016
+UTE        = -1.0322856          LUTE       = 3.8945882e-009      WUTE       = -2.1961089e-007
+PUTE       = 1.447285e-014       UA1        = -1.2154355e-009     LUA1       = 2.8166753e-016
+WUA1       = 1.0106606e-015      PUA1       = -2.5167504e-022     UB1        = 1.6976218e-018
+LUB1       = -3.3938718e-025     WUB1       = -1.7315743e-024     PUB1       = 3.4617493e-031
+UC1        = 1.4980978e-010      LUC1       = -4.988793e-017      WUC1       = -1.2715096e-016
+PUC1       = 6.8452669e-023      PRT        = 0                   AT         = '164704.37+datp_hvt'
+LAT        = -0.0089488268       WAT        = -0.0028700651       PAT        = -3.520423e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_hvt'
+WMIN       = '1e-006-dxwp_hvt'   WMAX       = '1e-005-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62112712+dvthp_hvt'
+LVTH0      = '-3.0821854e-010+dlvthp_hvt'
+WVTH0      = '6.2963879e-009+dwvthp_hvt'
+PVTH0      = '-2.2267017e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.039312509+dk2p_hvt'
+LK2        = '-2.378406e-009+dlk2p_hvt'
+WK2        = '-3.2823766e-008+dwk2p_hvt'
+PK2        = '1.8649482e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.001255845+dcitp_hvt'
+LCIT       = '2.7955334e-010+dlcitp_hvt'
+WCIT       = '-5.1403406e-010+dwcitp_hvt'
+PCIT       = '3.988153e-018+dpcitp_hvt'
+VOFF       = '-0.094349901+dvoffp_hvt'
+LVOFF      = '-4.3366994e-009+dlvoffp_hvt'
+WVOFF      = '-2.9485413e-008+dwvoffp_hvt'
+PVOFF      = '2.1065519e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0016702266+deta0p_hvt'
+LETA0      = '3.5030935e-010+dleta0p_hvt'
+WETA0      = '-4.0623502e-009+dweta0p_hvt'
+PETA0      = '1.7642829e-016+dpeta0p_hvt'
+ETAB       = -0.0024435492       LETAB      = -1.6557601e-011     WETAB      = -5.3852571e-009
+PETAB      = 1.6590717e-016      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020247538+du0p_hvt'
+LU0        = '-3.7049814e-010+dlu0p_hvt'
+WU0        = '-1.7061645e-009+dwu0p_hvt'
+PU0        = '9.4097621e-017+dpu0p_hvt'
+UA         = 3.2378267e-009      LUA        = -9.6015179e-017     WUA        = -7.8998098e-016
+PUA        = 3.0385928e-023      UB         = '6.6310195e-021+dubp_hvt'
+LUB        = '6.3755797e-028+dlubp_hvt'
+WUB        = '-1.488923e-026+dwubp_hvt'
+PUB        = '6.1908859e-034+dpubp_hvt'
+UC         = 3.6736503e-010      LUC        = -2.9482156e-017     WUC        = -5.718338e-016
+PUC        = 3.3483393e-023
+VSAT       = '80000+dvsatp_hvt+384.85*ff_flag_hvt'
+A0         = '2.8058311+da0p_hvt'
+LA0        = '-6.375555e-008+dla0p_hvt'
+WA0        = '5.861974e-008+dwa0p_hvt'
+PA0        = '1.0445163e-014+dpa0p_hvt'
+AGS        = 0.42342501          LAGS       = 5.9591794e-007      WAGS       = -2.7319861e-006
+PAGS       = 1.897943e-013       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.11819552
+LKETA      = 6.5273933e-010      WKETA      = 1.5458936e-007      PKETA      = -3.8090659e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.64548004+dpclmp_hvt'
+LPCLM      = '1.4911452e-008+dlpclmp_hvt'
+WPCLM      = '4.4648173e-007+dwpclmp_hvt'
+PPCLM      = '-3.4962808e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0011650945+dpdiblc2p_hvt'
+LPDIBLC2   = 1.6401181e-010      WPDIBLC2   = -2.4543963e-009     PPDIBLC2   = 2.4175804e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.9014279e-008
+LAGIDL     = -7.4475313e-016     WAGIDL     = -1.2254564e-014     PAGIDL     = 7.5964819e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067626145        LAIGC      = -6.9614349e-012     WAIGC      = -3.1036115e-011
+PAIGC      = 6.0771855e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063792204        LAIGSD     = 1.0806725e-011      WAIGSD     = -1.1998086e-010
+PAIGSD     = 3.988153e-018       BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00041665357
+LTVOFF     = 2.8977363e-011      WTVOFF     = 2.009221e-009       PTVOFF     = -1.5629762e-016
+KT1        = -0.27399067         LKT1       = -8.08669e-010       WKT1       = 1.349993e-007
+PKT1       = -9.0347998e-015     KT1L       = 0                   KT2        = -0.06440307
+LKT2       = -1.5608599e-011     WKT2       = 1.837297e-008       PKT2       = -9.4956024e-016
+UTE        = -0.98043183         LUTE       = -1.2130111e-009     WUTE       = -1.9607303e-007
+PUTE       = 1.2154371e-014      UA1        = 4.0217564e-009      LUA1       = -2.3419587e-016
+WUA1       = -4.783525e-015      PUA1       = 3.1905224e-022      UB1        = -4.7898783e-018
+LUB1       = 2.9963158e-025      WUB1       = 5.5541404e-024      PUB1       = -3.7146797e-031
+UC1        = -8.3846188e-010     LUC1       = 4.7456829e-017      WUC1       = 1.1423563e-015
+PUC1       = -5.659379e-023      PRT        = 0                   AT         = '149449.21+datp_hvt'
+LAT        = -0.0074461934       WAT        = -0.1087911          PAT        = 6.9127985e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt-3.79076e-05*ff_flag_hvt'
+WVSAT      = '0+dwvsatp_hvt-0.00385619*ff_flag_hvt'
+PVSAT      = '0+dpvsatp_hvt+3.79834e-10*ff_flag_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hvt'
+LMAX       = 2.001e-05           WMIN       = '6e-007-dxwp_hvt'   WMAX       = '1e-006-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61125883+dvthp_hvt'
+WVTH0      = '-4.0722196e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.0002448+dk2p_hvt'
+WK2        = '-3.326424e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.11496425+dvoffp_hvt'
+WVOFF      = '-1.636667e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.01565424+du0p_hvt'
+UA         = 2.06805e-009        WUA        = -2.70351e-016       UB         = '2.375152e-020+dubp_hvt'
+WUB        = '6.1874016e-027+dwubp_hvt'
+UC         = -2.77715e-010       WUC        = 5.2173e-018         VSAT       = '80000+dvsatp_hvt'
+A0         = '2.0352044+da0p_hvt'
+WA0        = '-5.4839704e-008+dwa0p_hvt'
+AGS        = 0.65564             WAGS       = 8.2212e-009         A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.0231715           WKETA      = 4.22127e-009        DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.001061+dpdiblc2p_hvt'
+WPDIBLC2   = -3.4782e-010        PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067268           WAIGC      = 3.7944e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0064972
+WAIGSD     = -6.9564e-011        BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0004854
+LTVOFF     = 0                   WTVOFF     = 5.24892e-010        PTVOFF     = 0
+KT1        = -0.23359227         WKT1       = 3.206649e-008       KT1L       = 0
+KT2        = -0.0837             WKT2       = 2.2134e-008         UTE        = -1.00255
+WUTE       = 1.581e-009          UA1        = 2.548672e-009       WUA1       = 1.3685136e-016
+UB1        = -2.7095e-018        WUB1       = -1.7391e-025        UC1        = -5.5e-011
+WUC1       = 1.581e-016          PRT        = 0                   AT         = '201000+datp_hvt'
+WAT        = -0.03162            NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'
+WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     LU0        = '0+dlu0p_hvt'       WU0        = '0+dwu0p_hvt'
+PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'
+PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'       PA0        = '0+dpa0p_hvt'
+LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'     LUB        = '0+dlubp_hvt'
+PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-dxlp_hvt'
+LMAX       = '1e-005-dxlp_hvt'   WMIN       = '6e-007-dxwp_hvt'   WMAX       = '1e-006-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61062935+dvthp_hvt'
+LVTH0      = '-6.2721597e-009+dlvthp_hvt'
+WVTH0      = '-4.4576408e-009+dwvthp_hvt'
+PVTH0      = '3.8403787e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.00076317335+dk2p_hvt'
+LK2        = '5.165129e-009+dlk2p_hvt'
+WK2        = '-3.0715579e-009+dwk2p_hvt'
+PK2        = '-2.5395137e-015+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.11307253+dvoffp_hvt'
+LVOFF      = '-1.8849246e-008+dlvoffp_hvt'
+WVOFF      = '-1.7409313e-008+dwvoffp_hvt'
+PVOFF      = '1.0389012e-014+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015658701+du0p_hvt'
+LU0        = '-4.4448199e-011+dlu0p_hvt'
+WU0        = '-1.0642708e-011+dwu0p_hvt'
+PU0        = '1.0604511e-016+dpu0p_hvt'
+UA         = 2.0622546e-009      LUA        = 5.7745727e-017      WUA        = -2.7339952e-016
+PUA        = 3.0375747e-023      UB         = '2.3581866e-020+dubp_hvt'
+LUB        = '1.6904501e-027+dlubp_hvt'
+WUB        = '7.1811331e-027+dwubp_hvt'
+PUB        = '-9.9016497e-033+dpubp_hvt'
+UC         = -2.8634218e-010     LUC        = 8.5962147e-017      WUC        = 1.1602247e-017
+PUC        = -6.3620315e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '2.1050058+da0p_hvt'
+LA0        = '-6.9550813e-007+dla0p_hvt'
+WA0        = '-1.0469221e-007+dwa0p_hvt'
+PA0        = '4.9673581e-013+dpa0p_hvt'
+AGS        = 0.63185714          LAGS       = 2.3697506e-007      WAGS       = 8.4740236e-009
+PAGS       = -2.519162e-015      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.027363574
+LKETA      = -4.1770281e-008     WKETA      = 2.5593208e-009      PKETA      = 1.6559845e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0011621759+dpdiblc2p_hvt'
+LPDIBLC2   = -1.0081273e-009     WPDIBLC2   = -5.5809985e-010     PPDIBLC2   = 2.0952515e-015
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7.1660412e-009
+LAGIDL     = -1.6544525e-015     WAGIDL     = -1.6936199e-016     PAGIDL     = 1.6875415e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067238488        LAIGC      = 2.9406558e-011      WAIGC      = 4.1500602e-011
+PAIGC      = -3.5438372e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0065014796        LAIGSD     = -4.2642178e-011     WAIGSD     = -7.7862738e-011
+PAIGSD     = 8.2689533e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00073434927
+LTVOFF     = -2.4805579e-009     WTVOFF     = 4.5901019e-010      PTVOFF     = 6.5645364e-016
+KT1        = -0.22642694         LKT1       = -7.139614e-008      WKT1       = 3.0585913e-008
+PKT1       = 1.475264e-014       KT1L       = 0                   KT2        = -0.086238823
+LKT2       = 2.5297112e-008      WKT2       = 2.4505068e-008      PKT2       = -2.3625581e-014
+UTE        = -1.0028232          LUTE       = 2.7218411e-009      WUTE       = 1.750362e-009
+PUTE       = -1.6875415e-015     UA1        = 2.4093999e-009      LUA1       = 1.3877227e-015
+WUA1       = 2.1519025e-016      PUA1       = -7.8057732e-022     UB1        = -2.6242298e-018
+LUB1       = -8.4964139e-025     WUB1       = -2.2810584e-025     PUB1       = 5.4001328e-031
+UC1        = -5.5535617e-011     LUC1       = 5.3369434e-018      WUC1       = 1.750362e-016
+PUC1       = -1.6875415e-022     PRT        = 0                   AT         = '203731.65+datp_hvt'
+LAT        = -0.027218411        WAT        = -0.03331362         PAT        = 1.6875415e-008
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-dxlp_hvt'
+LMAX       = '1.000004e-006-dxlp_hvt'
+WMIN       = '6e-007-dxwp_hvt'   WMAX       = '1e-006-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61554806+dvthp_hvt'
+LVTH0      = '-1.5299835e-009+dlvthp_hvt'
+WVTH0      = '-1.2133172e-010+dwvthp_hvt'
+PVTH0      = '-3.4030025e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0039528553+dk2p_hvt'
+LK2        = '6.1835871e-010+dlk2p_hvt'
+WK2        = '-5.4341046e-009+dwk2p_hvt'
+PK2        = '-2.6175882e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00016326695+dcitp_hvt'
+LCIT       = '1.6222785e-010+dlcitp_hvt'
+WCIT       = '7.8456228e-011+dwcitp_hvt'
+PCIT       = '-7.5640434e-017+dpcitp_hvt'
+VOFF       = '-0.13509166+dvoffp_hvt'
+LVOFF      = '2.3796189e-009+dlvoffp_hvt'
+WVOFF      = '-2.6595015e-009+dwvoffp_hvt'
+PVOFF      = '-3.8314293e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015786336+du0p_hvt'
+LU0        = '-1.6750272e-010+dlu0p_hvt'
+WU0        = '-7.7862904e-011+dwu0p_hvt'
+PU0        = '1.7085277e-016+dpu0p_hvt'
+UA         = 2.1436706e-009      LUA        = -2.0748264e-017     WUA        = -2.532922e-016
+PUA        = 1.0990082e-023      UB         = '3.5198781e-020+dubp_hvt'
+LUB        = '-9.509534e-027+dlubp_hvt'
+WUB        = '-9.5385351e-027+dwubp_hvt'
+PUB        = '6.2179495e-033+dpubp_hvt'
+UC         = -2.2887475e-010     LUC        = 3.0557222e-017      WUC        = -4.095517e-017
+PUC        = -1.2949184e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '1.3900194+da0p_hvt'
+LA0        = '-6.1826503e-009+dla0p_hvt'
+WA0        = '4.3663828e-007+dwa0p_hvt'
+PA0        = '-2.5166332e-014+dpa0p_hvt'
+AGS        = 0.43032981          LAGS       = 4.3126957e-007      WAGS       = 1.1276932e-007
+PAGS       = -1.030713e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.0068503314
+LKETA      = -8.7843134e-009     WKETA      = 1.9039281e-008      PKETA      = 6.7135067e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.60978339+dpclmp_hvt'
+LPCLM      = '-4.9635651e-008+dlpclmp_hvt'
+WPCLM      = '-1.38079e-007+dwpclmp_hvt'
+PPCLM      = '1.3312334e-013+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-3.6946401e-006+dpdiblc2p_hvt'
+LPDIBLC2   = 1.1590014e-010      WPDIBLC2   = 2.1214723e-009      PPDIBLC2   = -4.8815078e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 5.9358994e-009
+LAGIDL     = -4.6846045e-016     WAGIDL     = 1.0853826e-015      PAGIDL     = 4.7782966e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068008239        LAIGC      = -4.4805975e-011     WAIGC      = -3.2428302e-011
+PAIGC      = 3.5837224e-017      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063732991        LAIGSD     = 8.0937876e-011      WAIGSD     = 1.1495835e-010
+PAIGSD     = -1.0321121e-016     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0022457023
+LTVOFF     = 3.9253963e-010      WTVOFF     = 1.0487074e-009      PTVOFF     = 8.7920657e-017
+KT1        = -0.30383985         LKT1       = 3.2384172e-009      WKT1       = 3.8860227e-008
+PKT1       = 6.77529e-015        KT1L       = 0                   KT2        = -0.056881843
+LKT2       = -3.0062467e-009     WKT2       = -2.6049649e-009     PKT2       = 2.5114727e-015
+UTE        = -0.95965468         LUTE       = -3.8897329e-008     WUTE       = 1.2886051e-008
+PUTE       = -1.2423571e-014     UA1        = 5.0021852e-009      LUA1       = -1.1120075e-015
+WUA1       = -7.0332653e-016     PUA1       = 1.049739e-022       UB1        = -4.5013337e-018
+LUB1       = 9.6009324e-025      WUB1       = 3.3094541e-025      PUB1       = 1.0263781e-033
+UC1        = -9.702252e-011      LUC1       = 4.5334882e-017      PRT        = 0
+AT         = '168477.97+datp_hvt'
+LAT        = 0.006770009         WAT        = 0.0079796334        PAT        = -2.2935823e-008
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_hvt'
+LMAX       = '2.400007e-007-dxlp_hvt'
+WMIN       = '6e-007-dxwp_hvt'   WMAX       = '1e-006-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62836357+dvthp_hvt'
+LVTH0      = '1.4188652e-009+dlvthp_hvt'
+WVTH0      = '2.0428322e-009+dwvthp_hvt'
+PVTH0      = '-8.3827437e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0091980071+dk2p_hvt'
+LK2        = '-5.8855075e-010+dlk2p_hvt'
+WK2        = '-1.0212046e-008+dwk2p_hvt'
+PK2        = '8.3764547e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.0190528e-005+dcitp_hvt'
+LCIT       = '1.2700497e-010+dlcitp_hvt'
+WCIT       = '-3.1452806e-010+dwcitp_hvt'
+PCIT       = '1.478525e-017+dpcitp_hvt'
+VOFF       = '-0.1071063+dvoffp_hvt'
+LVOFF      = '-4.0598137e-009+dlvoffp_hvt'
+WVOFF      = '-3.5295068e-008+dwvoffp_hvt'
+PVOFF      = '3.6780146e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.00269+deta0p_hvt'
+WETA0      = '3.162e-010+dweta0p_hvt'
+ETAB       = -0.00568975         WETAB      = -5.61255e-010       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013809825+du0p_hvt'
+LU0        = '2.8729247e-010+dlu0p_hvt'
+WU0        = '1.9076404e-009+dwu0p_hvt'
+PU0        = '-2.8601153e-016+dpu0p_hvt'
+UA         = 1.9228154e-009      LUA        = 3.0070538e-017      WUA        = -2.5661216e-017
+PUA        = -4.1387807e-023     UB         = '-1.4415186e-020+dubp_hvt'
+LUB        = '1.9066399e-027+dlubp_hvt'
+WUB        = '3.0779517e-026+dwubp_hvt'
+PUB        = '-3.0592342e-033+dpubp_hvt'
+UC         = -1.0652753e-010     LUC        = 2.4051264e-018      WUC        = -1.1107666e-016
+PUC        = 3.185772e-024       VSAT       = '80000+dvsatp_hvt'  A0         = '-0.4400886+da0p_hvt'
+LA0        = '4.149252e-007+dla0p_hvt'
+WA0        = '1.6810163e-006+dwa0p_hvt'
+PA0        = '-3.1149771e-013+dpa0p_hvt'
+AGS        = -2.2782697          LAGS       = 1.0545183e-006      WAGS       = 1.508483e-006
+PAGS       = -4.2422502e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.10544242
+LKETA      = 1.3901725e-008      WKETA      = 6.4054507e-008      PKETA      = -9.6866529e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.13734723+dpclmp_hvt'
+LPCLM      = '1.2227911e-007+dlpclmp_hvt'
+WPCLM      = '9.3617077e-007+dwpclmp_hvt'
+PPCLM      = '-1.1406153e-013+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.5797113e-009
+LAGIDL     = 5.3389844e-016      WAGIDL     = 5.5286945e-015      PAGIDL     = -5.4457641e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0066295649        LAIGC      = -5.3992633e-012     WAIGC      = 1.032011e-010
+PAIGC      = 4.6288995e-018      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0069032632        LAIGSD     = -4.1006845e-011     WAIGSD     = -5.2529326e-010
+PAIGSD     = 4.4110689e-017      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0025143532
+LTVOFF     = 4.5435619e-010      WTVOFF     = 3.2448764e-009      PTVOFF     = -4.1741782e-016
+KT1        = -0.34369484         LKT1       = 1.2409052e-008      WKT1       = 1.3627123e-007
+PKT1       = -1.5638982e-014     KT1L       = 0                   KT2        = -0.084399804
+LKT2       = 3.3256362e-009      WKT2       = 1.8623791e-008      PKT2       = -2.373264e-015
+UTE        = -1.1330412          LUTE       = 9.9890676e-010      WUTE       = -1.1684023e-007
+PUTE       = 1.7426445e-014      UA1        = 5.1778284e-010      LUA1       = -8.0146509e-017
+WUA1       = -7.5722213e-016     PUA1       = 1.1737528e-022      UB1        = -5.7495171e-019
+LUB1       = 5.6632743e-026      WUB1       = 5.8645074e-025      PUB1       = -5.7765398e-032
+UC1        = -4.9691299e-010     LUC1       = 1.3734968e-016      WUC1       = 5.3250627e-016
+PUC1       = -1.2252969e-022     PRT        = 0                   AT         = '319078.95+datp_hvt'
+LAT        = -0.027883277        WAT        = -0.16033214         PAT        = 1.5792716e-008
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_hvt'
+WMIN       = '6e-007-dxwp_hvt'   WMAX       = '1e-006-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60114279+dvthp_hvt'
+LVTH0      = '-1.262382e-009+dlvthp_hvt'
+WVTH0      = '-1.4087635e-008+dwvthp_hvt'
+PVTH0      = '7.505766e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.014181486+dk2p_hvt'
+LK2        = '-1.0794234e-009+dlk2p_hvt'
+WK2        = '-7.190122e-009+dwk2p_hvt'
+PK2        = '5.3998597e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0002837953+dcitp_hvt'
+LCIT       = '9.8047363e-011+dlcitp_hvt'
+WCIT       = '-2.0844672e-009+dwcitp_hvt'
+PCIT       = '1.8912425e-016+dpcitp_hvt'
+VOFF       = '-0.12945599+dvoffp_hvt'
+LVOFF      = '-1.8583687e-009+dlvoffp_hvt'
+WVOFF      = '6.3228005e-009+dwvoffp_hvt'
+PVOFF      = '-4.2134547e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '-0.0055935647+deta0p_hvt'
+LETA0      = '8.1593113e-010+dleta0p_hvt'
+WETA0      = '3.3467169e-009+dweta0p_hvt'
+PETA0      = '-2.9850592e-016+dpeta0p_hvt'
+ETAB       = -0.0066902219       LETAB      = 9.8546484e-011      WETAB      = -1.0536509e-009
+PETAB      = 4.8500998e-017      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.023134011+du0p_hvt'
+LU0        = '-6.3113981e-010+dlu0p_hvt'
+WU0        = '-4.6503664e-009+dwu0p_hvt'
+PU0        = '3.5995213e-016+dpu0p_hvt'
+UA         = 3.7951852e-009      LUA        = -1.5435789e-016     WUA        = -1.3584866e-015
+PUA        = 8.9895493e-023      UB         = '4.2012971e-021+dubp_hvt'
+LUB        = '7.2916293e-029+dlubp_hvt'
+WUB        = '-1.2410913e-026+dwubp_hvt'
+PUB        = '1.1950231e-033+dpubp_hvt'
+UC         = 4.2620133e-011      LUC        = -1.2285918e-017     WUC        = -2.40594e-016
+PUC        = 1.594323e-023
+VSAT       = '80000+dvsatp_hvt-8659.12*ff_flag_hvt'
+A0         = '6.2698767+da0p_hvt'
+LA0        = '-2.4600638e-007+dla0p_hvt'
+WA0        = '-3.4747068e-006+dwa0p_hvt'
+PA0        = '1.9634101e-013+dpa0p_hvt'
+AGS        = -3.5589189          LAGS       = 1.1806623e-006      WAGS       = 1.3300047e-006
+PAGS       = -4.0664491e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.17005268
+LKETA      = -1.3234542e-008     WKETA      = -1.3942381e-007     PKETA      = 1.0355961e-014
+DWG        = 0                   DWB        = 0                   PCLM       = '2.168053+dpclmp_hvt'
+LPCLM      = '-1.0480282e-007+dlpclmp_hvt'
+WPCLM      = '-1.1065427e-006+dwpclmp_hvt'
+PPCLM      = '8.7145749e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0033029405+dpdiblc2p_hvt'
+LPDIBLC2   = 3.7458964e-010      WPDIBLC2   = -2.7379338e-010     PPDIBLC2   = 2.6968648e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0062691429        LAIGC      = 3.0102297e-011      WAIGC      = 4.7230486e-010
+PAIGC      = -3.1727821e-017     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0063691215        LAIGSD     = 1.1606108e-011      WAIGSD     = -1.0967999e-010
+PAIGSD     = 3.1727821e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0054941191
+LTVOFF     = -3.3447833e-010     WTVOFF     = -3.1697938e-009     PTVOFF     = 2.1442719e-016
+KT1        = -0.060547012        LKT1       = -1.5481009e-008     WKT1       = -8.2713229e-008
+PKT1       = 5.9309874e-015      KT1L       = 0                   KT2        = -0.0055268487
+LKT2       = -4.4433499e-009     WKT2       = -4.1680777e-008     PKT2       = 3.5667359e-015
+UTE        = -1.3315617          LUTE       = 2.055318e-008       WUTE       = 1.6207946e-007
+PUTE       = -1.0047143e-014     UA1        = -1.5116726e-009     LUA1       = 1.1975485e-016
+WUA1       = 8.605725e-016       PUA1       = -4.1977494e-023     UB1        = 3.6061635e-019
+LUB1       = -3.5520711e-026     WUB1       = 3.0063587e-025      PUB1       = -2.9612633e-032
+UC1        = 1.6316361e-009      LUC1       = -7.2312407e-017     WUC1       = -1.3771437e-015
+PUC1       = 6.557083e-023       PRT        = 0                   AT         = '-4577.8286+datp_hvt'
+LAT        = 0.0039969161        WAT        = 0.048316479         PAT        = -4.7591732e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt+0.000852921*ff_flag_hvt'
+WVSAT      = '0+dwvsatp_hvt+0.00536865*ff_flag_hvt'
+PVSAT      = '0+dpvsatp_hvt-5.28811e-10*ff_flag_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hvt'
+LMAX       = 2.001e-05           WMIN       = '3e-007-dxwp_hvt'   WMAX       = '6e-007-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60946352+dvthp_hvt'
+WVTH0      = '-5.185311e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.0078104336+dk2p_hvt'
+WK2        = '1.3642688e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.1239429+dvoffp_hvt'
+WVOFF      = '-1.0799904e-008+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015256672+du0p_hvt'
+WU0        = '2.4649216e-010+dwu0p_hvt'
+UA         = 1.9008e-009         WUA        = -1.66656e-016       UB         = '6.2627968e-020+dubp_hvt'
+WUB        = '-1.7915996e-026+dwubp_hvt'
+UC         = -3.4706e-010        WUC        = 4.82112e-017        VSAT       = '80000+dvsatp_hvt'
+A0         = '1.9467547+da0p_hvt'
+WA0        = '-8.4650667e-013+dwa0p_hvt'
+AGS        = 0.66356667          WAGS       = 3.3066667e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.032593333         WKETA      = -1.6202667e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00018+dpdiblc2p_hvt'
+WPDIBLC2   = 1.984e-010          PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.0067954667        WAIGC      = -4.6293333e-012
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0062346
+WAIGSD     = 9.3248e-011         BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0022290667
+LTVOFF     = 0                   WTVOFF     = -5.5618133e-010     PTVOFF     = 0
+KT1        = -0.18142866         WKT1       = -2.7494801e-010     KT1L       = 0
+KT2        = -0.043733333        WKT2       = -2.6453333e-009     UTE        = -0.8688
+WUTE       = -8.1344e-008        UA1        = 3.0774107e-009      WUA1       = -1.9096661e-016
+UB1        = -3.2566667e-018     WUB1       = 1.6533333e-025      UC1        = 3.1221333e-010
+WUC1       = -6.9572267e-017     PRT        = 0                   AT         = '150000+datp_hvt'
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'      LK2        = '0+dlk2p_hvt'
+PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'       LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LA0        = '0+dla0p_hvt'
+PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'     PVOFF      = '0+dpvoffp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-dxlp_hvt'
+LMAX       = '1e-005-dxlp_hvt'   WMIN       = '3e-007-dxwp_hvt'   WMAX       = '6e-007-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60953143+dvthp_hvt'
+LVTH0      = '6.7664387e-010+dlvthp_hvt'
+WVTH0      = '-5.1383545e-009+dwvthp_hvt'
+PVTH0      = '-4.6787951e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.0078994556+dk2p_hvt'
+LK2        = '8.8702447e-010+dlk2p_hvt'
+WK2        = '1.3529371e-009+dwk2p_hvt'
+PK2        = '1.1291113e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.12326781+dvoffp_hvt'
+LVOFF      = '-6.7266941e-009+dlvoffp_hvt'
+WVOFF      = '-1.1088242e-008+dwvoffp_hvt'
+PVOFF      = '2.8730295e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015215739+du0p_hvt'
+LU0        = '4.0785918e-010+dlu0p_hvt'
+WU0        = '2.6399352e-010+dwu0p_hvt'
+PU0        = '-1.7438547e-016+dpu0p_hvt'
+UA         = 1.8840316e-009      LUA        = 1.6708191e-016      WUA        = -1.6290126e-016
+PUA        = -3.7412685e-023     UB         = '6.9551697e-020+dubp_hvt'
+LUB        = '-6.8988797e-026+dlubp_hvt'
+WUB        = '-2.1320162e-026+dwubp_hvt'
+PUB        = '3.3919484e-032+dpubp_hvt'
+UC         = -3.4529746e-010     LUC        = -1.7562102e-017     WUC        = 4.8154525e-017
+PUC        = 5.6471977e-025      VSAT       = '80000+dvsatp_hvt'  A0         = '1.9042621+da0p_hvt'
+LA0        = '4.2340038e-007+dla0p_hvt'
+WA0        = '1.9768854e-008+dwa0p_hvt'
+PA0        = '-1.9698747e-013+dpa0p_hvt'
+AGS        = 0.64171048          LAGS       = 2.1777741e-007      WAGS       = 2.3649485e-009
+PAGS       = 9.3833837e-015      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.034535622
+LKETA      = -1.935318e-008      WKETA      = -1.8873494e-009     PKETA      = 2.6612419e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00022138005+dpdiblc2p_hvt'
+LPDIBLC2   = 3.999395e-009       WPDIBLC2   = 2.9970481e-010      PPDIBLC2   = -1.0094123e-015
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 6.7786118e-009
+LAGIDL     = 2.2059366e-015      WAGIDL     = 7.0844231e-017      PAGIDL     = -7.0589971e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067298072        LAIGC      = 6.542381e-010       WAIGC      = 3.7806361e-011
+PAIGC      = -4.2283393e-016     BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006204127         LAIGSD     = 3.036365e-010       WAIGSD     = 1.0649587e-010
+PAIGSD     = -1.3200325e-016     BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0024678517
+LTVOFF     = -2.3792805e-009     WTVOFF     = -6.1576133e-010     PTVOFF     = 5.9366166e-016
+KT1        = -0.17487517         LKT1       = -6.5299718e-008     WKT1       = -1.3761862e-009
+PKT1       = 1.0972858e-014      KT1L       = 0                   KT2        = -0.041746715
+LKT2       = -1.9794885e-008     WKT2       = -3.0800392e-009     PKT2       = 4.3314571e-015
+UTE        = -0.86697176         LUTE       = -1.8216767e-008     WUTE       = -8.2477508e-008
+PUTE       = 1.1294395e-014      UA1        = 3.0689205e-009      LUA1       = 8.4596957e-017
+WUA1       = -1.9371254e-016     PUA1       = 2.7360673e-023      UB1        = -3.2828048e-018
+LUB1       = 2.6044284e-025      WUB1       = 1.8021062e-025      PUB1       = -1.4823894e-031
+UC1        = 3.5101483e-010      LUC1       = -3.8662241e-016     WUC1       = -7.702508e-017
+PUC1       = 7.426065e-023       PRT        = 0                   AT         = '150000+datp_hvt'
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'     LPCLM      = '0+dlpclmp_hvt'
+WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-dxlp_hvt'
+LMAX       = '1.000004e-006-dxlp_hvt'
+WMIN       = '3e-007-dxwp_hvt'   WMAX       = '6e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60497167+dvthp_hvt'
+LVTH0      = '-3.7194647e-009+dlvthp_hvt'
+WVTH0      = '-6.6786949e-009+dwvthp_hvt'
+PVTH0      = '1.0171781e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.0071439048+dk2p_hvt'
+LK2        = '1.5859044e-010+dlk2p_hvt'
+WK2        = '1.4458866e-009+dwk2p_hvt'
+PK2        = '2.32975e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-7.9441997e-005+dcitp_hvt'
+LCIT       = '8.1411373e-011+dlcitp_hvt'
+WCIT       = '2.6484755e-011+dwcitp_hvt'
+PCIT       = '-2.5534217e-017+dpcitp_hvt'
+VOFF       = '-0.12333821+dvoffp_hvt'
+LVOFF      = '-6.6588147e-009+dlvoffp_hvt'
+WVOFF      = '-9.9466397e-009+dwvoffp_hvt'
+PVOFF      = '1.7723995e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015302442+du0p_hvt'
+LU0        = '3.2426812e-010+dlu0p_hvt'
+WU0        = '2.2215149e-010+dwu0p_hvt'
+PU0        = '-1.3404515e-016+dpu0p_hvt'
+UA         = 2.0644808e-009      LUA        = -6.8909021e-018     WUA        = -2.0419447e-016
+PUA        = 2.3985175e-024      UB         = '-1.9042134e-020+dubp_hvt'
+LUB        = '1.6425402e-026+dlubp_hvt'
+WUB        = '2.4090833e-026+dwubp_hvt'
+PUB        = '-9.8617105e-033+dpubp_hvt'
+UC         = -3.8641853e-010     LUC        = 2.2083125e-017      WUC        = 5.6721974e-017
+PUC        = -7.6952436e-024     VSAT       = '80000+dvsatp_hvt'  A0         = '2.466526+da0p_hvt'
+LA0        = '-1.186839e-007+dla0p_hvt'
+WA0        = '-2.3079583e-007+dwa0p_hvt'
+PA0        = '4.4584443e-014+dpa0p_hvt'
+AGS        = 0.62045294          LAGS       = 2.3827202e-007      WAGS       = -5.1070245e-009
+PAGS       = 1.6587188e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.023873986
+LKETA      = -9.0741897e-009     WKETA      = -9.7960693e-012     PKETA      = 8.5107395e-016
+DWG        = 0                   DWB        = 0                   PCLM       = '0.29963434+dpclmp_hvt'
+LPCLM      = '2.4938215e-007+dlpclmp_hvt'
+WPCLM      = '5.4213413e-008+dwpclmp_hvt'
+PPCLM      = '-5.2267694e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.005001172+dpdiblc2p_hvt'
+LPDIBLC2   = -1.0357197e-009     WPDIBLC2   = -9.8154501e-010     PPDIBLC2   = 2.2585351e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 8.4188008e-009
+LAGIDL     = 6.2461393e-016      WAGIDL     = -4.5401627e-016     PAGIDL     = -1.9987646e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0075985591        LAIGC      = -1.8333426e-010     WAIGC      = -5.2702409e-010
+PAIGC      = 1.2172476e-016      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.006620489         LAIGSD     = -9.7782303e-011     WAIGSD     = -3.8299382e-011
+PAIGSD     = 7.5953054e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = -0.0011137942
+LTVOFF     = 1.0738202e-009      WTVOFF     = 3.4692438e-010      PTVOFF     = -3.3447326e-016
+KT1        = -0.27645852         LKT1       = 3.2637808e-008      WKT1       = 2.1883805e-008
+PKT1       = -1.1452332e-014     KT1L       = 0                   KT2        = -0.066569307
+LKT2       = 4.1368237e-009      WKT2       = 3.4012628e-009      PKT2       = -1.917231e-015
+UTE        = -0.72375392         LUTE       = -1.5629452e-007     WUTE       = -1.3337242e-007
+PUTE       = 6.036269e-014       UA1        = 5.1540208e-009      LUA1       = -1.9256691e-015
+WUA1       = -7.9746463e-016     PUA1       = 6.0944411e-022      UB1        = -5.0007075e-018
+LUB1       = 1.9166901e-024      WUB1       = 6.4055717e-025      PUB1       = -5.9206365e-031
+UC1        = -1.4717988e-010     LUC1       = 9.3692089e-017      WUC1       = 3.109756e-017
+PUC1       = -2.9981469e-023     PRT        = 0                   AT         = '181716.17+datp_hvt'
+LAT        = -0.030577874        WAT        = -0.00022804877      PAT        = 2.198641e-010
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_hvt'
+LMAX       = '2.400007e-007-dxlp_hvt'
+WMIN       = '3e-007-dxwp_hvt'   WMAX       = '6e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62344662+dvthp_hvt'
+LVTH0      = '5.3162157e-010+dlvthp_hvt'
+WVTH0      = '-1.0056772e-009+dwvthp_hvt'
+PVTH0      = '-2.8818329e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.010828147+dk2p_hvt'
+LK2        = '1.0063345e-009+dlk2p_hvt'
+WK2        = '2.2041694e-009+dwk2p_hvt'
+PK2        = '-1.5118335e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00036434146+dcitp_hvt'
+LCIT       = '1.4696674e-010+dlcitp_hvt'
+WCIT       = '-9.4954476e-011+dwcitp_hvt'
+PCIT       = '2.4089498e-018+dpcitp_hvt'
+VOFF       = '-0.16938362+dvoffp_hvt'
+LVOFF      = '3.9362323e-009+dlvoffp_hvt'
+WVOFF      = '3.3168691e-009+dwvoffp_hvt'
+PVOFF      = '-1.2795339e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0023466667+deta0p_hvt'
+WETA0      = '5.2906667e-010+dweta0p_hvt'
+ETAB       = -0.0076403333       WETAB      = 6.4810667e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.018908997+du0p_hvt'
+LU0        = '-5.0560022e-010+dlu0p_hvt'
+WU0        = '-1.2538463e-009+dwu0p_hvt'
+PU0        = '2.0558194e-016+dpu0p_hvt'
+UA         = 2.4318766e-009      LUA        = -9.1428673e-017     WUA        = -3.4127916e-016
+PUA        = 3.3941704e-023      UB         = '1.0514043e-019+dubp_hvt'
+LUB        = '-1.2149006e-026+dlubp_hvt'
+WUB        = '-4.3344965e-026+dwubp_hvt'
+PUB        = '5.6552664e-033+dpubp_hvt'
+UC         = -2.8434905e-010     LUC        = -1.4030621e-018     WUC        = -8.2731996e-019
+PUC        = 5.5468489e-024      VSAT       = '80000+dvsatp_hvt'  A0         = '2.2721747+da0p_hvt'
+LA0        = '-7.3963649e-008+dla0p_hvt'
+WA0        = '-5.8695218e-010+dwa0p_hvt'
+PA0        = '-8.3866191e-015+dpa0p_hvt'
+AGS        = -0.062865982        LAGS       = 3.955037e-007       WAGS       = 1.3493275e-007
+PAGS       = -1.5635963e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.015770614
+LKETA      = -7.2096038e-009     WKETA      = -1.1097571e-008     PKETA      = 3.402371e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '1.8738875+dpclmp_hvt'
+LPCLM      = '-1.128535e-007+dlpclmp_hvt'
+WPCLM      = '-3.1079476e-007+dwpclmp_hvt'
+PPCLM      = '3.1720686e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.4227052e-008
+LAGIDL     = -7.1186459e-016     WAGIDL     = -2.3126565e-015     PAGIDL     = 2.2779667e-022
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0067904231        LAIGC      = 2.6178246e-012      WAIGC      = 3.4689848e-012
+PAIGC      = -3.41695e-019       BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0060709363        LAIGSD     = 2.8669772e-011      WAIGSD     = -9.2506261e-012
+PAIGSD     = 9.1118668e-019      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.0059536555
+LTVOFF     = -5.5240003e-010     WTVOFF     = -2.005289e-009      PTVOFF     = 2.0677104e-016
+KT1        = -0.036864169        LKT1       = -2.2492852e-008     WKT1       = -5.3963786e-008
+PKT1       = 6.0001987e-015      KT1L       = 0                   KT2        = -0.040088397
+LKT2       = -1.9564335e-009     WKT2       = -8.8492812e-009     PKT2       = 9.0161922e-016
+UTE        = -1.6644192          LUTE       = 6.0152558e-008      WUTE       = 2.1261414e-007
+PUTE       = -1.9248819e-014     UA1        = -4.6503985e-009     LUA1       = 3.3032779e-016
+WUA1       = 2.4470503e-015      PUA1       = -1.3711879e-022     UB1        = 4.3837938e-018
+LUB1       = -2.4268369e-025     WUB1       = -2.4879715e-024     PUB1       = 1.2781079e-031
+UC1        = 6.8164387e-010      LUC1       = -9.7020255e-017     WUC1       = -1.9819899e-016
+PUC1       = 2.2779667e-023      PRT        = 0                   AT         = '23298.501+datp_hvt'
+LAT        = 0.005874031         WAT        = 0.023051738         PAT        = -5.1368149e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_hvt'
+WMIN       = '3e-007-dxwp_hvt'   WMAX       = '6e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.62909134+dvthp_hvt'
+LVTH0      = '1.0876261e-009+dlvthp_hvt'
+WVTH0      = '3.2404668e-009+dwvthp_hvt'
+PVTH0      = '-7.0642847e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '0.0034488545+dk2p_hvt'
+LK2        = '-3.9995015e-010+dlk2p_hvt'
+WK2        = '-5.3589046e-010+dwk2p_hvt'
+PK2        = '1.1871254e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0029965967+dcitp_hvt'
+LCIT       = '4.0624388e-010+dlcitp_hvt'
+WCIT       = '-5.0624166e-011+dwcitp_hvt'
+PCIT       = '-1.9575858e-018+dpcitp_hvt'
+VOFF       = '-0.083323642+dvoffp_hvt'
+LVOFF      = '-4.5406751e-009+dlvoffp_hvt'
+WVOFF      = '-2.2279257e-008+dwvoffp_hvt'
+PVOFF      = '1.2416845e-015+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '-0.0037654749+deta0p_hvt'
+LETA0      = '6.0204594e-010+dleta0p_hvt'
+WETA0      = '2.2133012e-009+dweta0p_hvt'
+PETA0      = '-1.658971e-016+dpeta0p_hvt'
+ETAB       = -0.011349295        LETAB      = 3.6533273e-010      WETAB      = 1.8349744e-009
+PETAB      = -1.1690647e-016     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.012677915+du0p_hvt'
+LU0        = '1.0816134e-010+dlu0p_hvt'
+WU0        = '1.8324129e-009+dwu0p_hvt'
+PU0        = '-9.8414586e-017+dpu0p_hvt'
+UA         = 1.5154382e-009      LUA        = -1.1594959e-018     WUA        = 5.4956527e-017
+PUA        = -5.0875112e-024     UB         = '-1.1729084e-019+dubp_hvt'
+LUB        = '9.760474e-027+dlubp_hvt'
+WUB        = '6.2914214e-026+dwubp_hvt'
+PUB        = '-4.8112627e-033+dpubp_hvt'
+UC         = -6.5804385e-010     LUC        = 3.5405876e-017      WUC        = 1.9381767e-016
+PUC        = -1.3625682e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '-0.81406652+da0p_hvt'
+LA0        = '2.3003111e-007+dla0p_hvt'
+WA0        = '9.1733806e-007+dwa0p_hvt'
+PA0        = '-9.8802232e-014+dpa0p_hvt'
+AGS        = -5.0263359          LAGS       = 8.8440549e-007      WAGS       = 2.2398033e-006
+PAGS       = -2.2296571e-013     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.20075656
+LKETA      = 1.4118323e-008      WKETA      = 9.0477925e-008      PKETA      = -6.6028153e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14323689+dpclmp_hvt'
+LPCLM      = '5.7615583e-008+dlpclmp_hvt'
+WPCLM      = '1.4884328e-007+dwpclmp_hvt'
+PPCLM      = '-1.3553661e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0037445427+dpdiblc2p_hvt'
+LPDIBLC2   = 4.1808746e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.007030925         LAIGC      = -2.1071608e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0061922183
+LAIGSD     = 1.6723498e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00034779709
+LTVOFF     = -2.2297998e-013     WTVOFF     = 2.0925836e-011      PTVOFF     = 7.1888745e-018
+KT1        = -0.16638377         LKT1       = -9.7351721e-009     WKT1       = -1.7094442e-008
+PKT1       = 2.3685683e-015      KT1L       = 0                   KT2        = -0.087134982
+LKT2       = 2.6776551e-009      WKT2       = 8.9162661e-009      PKT2       = -8.4828719e-016
+UTE        = -1.1449627          LUTE       = 8.9860931e-009      WUTE       = 4.6388066e-008
+PUTE       = -2.8755498e-015     UA1        = -4.7140308e-009     LUA1       = 3.3659557e-016
+WUA1       = 2.8460346e-015      PUA1       = -1.7641874e-022     UB1        = 6.3241376e-018
+LUB1       = -4.3380755e-025     WUB1       = -3.3967473e-024     PUB1       = 2.1732521e-031
+UC1        = -7.33447e-010       LUC1       = 4.2366196e-017      WUC1       = 8.9207819e-017
+PUC1       = -5.5299035e-024     PRT        = 0                   AT         = '160127.42+datp_hvt'
+LAT        = -0.0076036173       WAT        = -0.053800774        PAT        = 2.4331575e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hvt'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60269827+dvthp_hvt'
+WVTH0      = '-7.3501919e-009+dwvthp_hvt'
+K1         = 0.45227             K2         = '-0.024832611+dk2p_hvt'
+WK2        = '6.8113655e-009+dwk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.1579187+dvoffp_hvt'
+WVOFF      = '7.2352e-011+dwvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015495489+du0p_hvt'
+WU0        = '1.7007076e-010+dwu0p_hvt'
+UA         = 1.8133e-009         WUA        = -1.38656e-016       UB         = '-9.9141467e-021+dubp_hvt'
+WUB        = '5.2974805e-027+dwubp_hvt'
+UC         = -2.8331667e-010     WUC        = 2.7813333e-017      VSAT       = '80000+dvsatp_hvt'
+A0         = '2.1848858+da0p_hvt'
+WA0        = '-7.6202819e-008+dwa0p_hvt'
+AGS        = 0.8260856           WAGS       = -4.8699392e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = 0.038138889         WKETA      = -3.3948444e-009     DWG        = 0
+DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt' PDIBLC1    = 0
+PDIBLC2    = '0.00072222222+dpdiblc2p_hvt'
+WPDIBLC2   = 2.4888889e-011      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 1.1666667e-008      WAGIDL     = -1.4933333e-015     BGIDL      = 4.4632e+009
+CGIDL      = 18                  EGIDL      = -2.0284             AIGBACC    = 0.01333
+BIGBACC    = 0.003785            CIGBACC    = 0.034287            NIGBACC    = 10
+AIGBINV    = 0.012               BIGBINV    = 0.005386            CIGBINV    = 0.5
+EIGBINV    = 0.009906            NIGBINV    = 1                   AIGC       = 0.0066993333
+WAIGC      = 2.6133333e-011      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0071              WAIGSD     = -1.8368e-010        BIGSD      = 0.0002969
+CIGSD      = 0                   NIGC       = 2.605               POXEDGE    = 1
+PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'
+CGBO       = 0                   CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_hvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.05
+MOIN       = 9.6576              NOFF       = 2.0069              VOFFCV     = -0.068319
+TVOFF      = 9.5111111e-005      LTVOFF     = 0                   WTVOFF     = 1.2668444e-010
+PTVOFF     = 0                   KT1        = -0.19143704         WKT1       = 2.927733e-009
+KT1L       = 0                   KT2        = -0.045046667        WKT2       = -2.2250667e-009
+UTE        = -0.86477778         WUTE       = -8.2631111e-008     UA1        = 3.6091411e-009
+WUA1       = -3.6112036e-016     UB1        = -3.7822222e-018     WUB1       = 3.3351111e-025
+UC1        = 9.6044444e-011      WUC1       = -3.9822222e-019     PRT        = 0
+AT         = '165555.56+datp_hvt'
+WAT        = -0.0049777778       NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_hvt'      PVTH0      = '0+dpvthp_hvt'
+LK2        = '0+dlk2p_hvt'       PK2        = '0+dpk2p_hvt'       LCIT       = '0+dlcitp_hvt'
+WCIT       = '0+dwcitp_hvt'      PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'
+WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'
+PETA0      = '0+dpeta0p_hvt'     LU0        = '0+dlu0p_hvt'       PU0        = '0+dpu0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LA0        = '0+dla0p_hvt'       PA0        = '0+dpa0p_hvt'       LVOFF      = '0+dlvoffp_hvt'
+PVOFF      = '0+dpvoffp_hvt'     LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'
+PPCLM      = '0+dppclmp_hvt'     LUB        = '0+dlubp_hvt'       PUB        = '0+dpubp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.000004e-006-dxlp_hvt'
+LMAX       = '1e-005-dxlp_hvt'   WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_hvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_hvt'          TOXM       = 2.8e-009            DTOX       = 3.5028e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'
+DLC        = '1.894715e-08+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60230381+dvthp_hvt'
+LVTH0      = '-3.9303708e-009+dlvthp_hvt'
+WVTH0      = '-7.4511909e-009+dwvthp_hvt'
+PVTH0      = '1.0063652e-015+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.025238793+dk2p_hvt'
+LK2        = '4.0472409e-009+dlk2p_hvt'
+WK2        = '6.9015249e-009+dwk2p_hvt'
+PK2        = '-8.9835813e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_hvt'
+VOFF       = '-0.15841107+dvoffp_hvt'
+LVOFF      = '4.9060386e-009+dlvoffp_hvt'
+WVOFF      = '1.5760246e-010+dwvoffp_hvt'
+PVOFF      = '-8.4944499e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015515143+du0p_hvt'
+LU0        = '-1.9583973e-010+dlu0p_hvt'
+WU0        = '1.6818417e-010+dwu0p_hvt'
+PU0        = '1.8798185e-017+dpu0p_hvt'
+UA         = 1.8181384e-009      LUA        = -4.8210389e-017     WUA        = -1.4181542e-016
+PUA        = 3.148085e-023       UB         = '-2.4318365e-020+dubp_hvt'
+LUB        = '1.4352521e-025+dlubp_hvt'
+WUB        = '8.7182576e-027+dwubp_hvt'
+PUB        = '-3.4084999e-032+dpubp_hvt'
+UC         = -2.9171692e-010     LUC        = 8.3701062e-017      WUC        = 3.1008751e-017
+PUC        = -3.1839493e-023     VSAT       = '80000+dvsatp_hvt'  A0         = '2.2293021+da0p_hvt'
+LA0        = '-4.4256898e-007+dla0p_hvt'
+WA0        = '-8.4243951e-008+dwa0p_hvt'
+PA0        = '8.0122724e-014+dpa0p_hvt'
+AGS        = 0.81265962          LAGS       = 1.3377797e-007      WAGS       = -5.2338774e-008
+PAGS       = 3.6263203e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.041993544
+LKETA      = -3.8408203e-008     WKETA      = -4.2738842e-009     PKETA      = 8.7588492e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.5583+dpclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00053813492+dpdiblc2p_hvt'
+LPDIBLC2   = 1.8342661e-009      WPDIBLC2   = 5.6660018e-011      PPDIBLC2   = -3.1657102e-016
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 1.2166576e-008
+LAGIDL     = -4.9811472e-015     WAGIDL     = -1.6533042e-015     PAGIDL     = 1.5939671e-021
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068113605        LAIGC      = -1.1162514e-009     WAIGC      = 1.1709296e-011
+PAIGC      = 1.437227e-016       BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0071657499        LAIGSD     = -6.5513945e-010     WAIGSD     = -2.0122347e-010
+PAIGSD     = 1.7480506e-016      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00010529973
+LTVOFF     = -1.0152052e-010     WTVOFF     = 1.402553e-010       PTVOFF     = -1.3522154e-016
+KT1        = -0.18899726         LKT1       = -2.4310255e-008     WKT1       = 3.1428822e-009
+PKT1       = -2.1437702e-015     KT1L       = 0                   KT2        = -0.044164557
+LKT2       = -8.7894382e-009     WKT2       = -2.3063297e-009     PKT2       = 8.0971403e-016
+UTE        = -0.85566039         LUTE       = -9.0846636e-008     WUTE       = -8.6097146e-008
+PUTE       = 3.4535954e-014      UA1        = 3.6524298e-009      LUA1       = -4.3133295e-016
+WUA1       = -3.804355e-016      PUA1       = 1.9245824e-022      UB1        = -3.8185251e-018
+LUB1       = 3.6172616e-025      WUB1       = 3.5164114e-025      PUB1       = -1.806496e-031
+UC1        = 1.267698e-010       LUC1       = -3.0615079e-016     WUC1       = -5.2666683e-018
+PUC1       = 4.8509732e-023      PRT        = 0                   AT         = '165555.56+datp_hvt'
+WAT        = -0.0049777778       NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'
+NOIC       = 'noicp_hvt'          EM         = 1.00000e+07         EF         = 1.1
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 2.13e-13
+JSWD       = 2.13e-13            JSWGS      = 2.13e-13            JSWGD      = 2.13e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 1.02                PBD        = 1.02
+CJS        = 'cjp_hvt'           CJD        = 'cjp_hvt'           MJS        = 0.42
+MJD        = 0.42                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswp_hvt'         CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04
+MJSWD      = 0.04                PBSWGS     = 1.22                PBSWGD     = 1.22
+CJSWGS     = 'cjswgp_hvt'        CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92
+MJSWGD     = 0.92                TPB        = 0.0023              TCJ        = 0.000877
+TPBSW      = 0.0016              TCJSW      = 0.000204            TPBSWG     = 0.0003
+TCJSWG     = 0.0008              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1e-008              JTSSWGD    = 1e-008              NJTSSWG    = 7.3495
+XTSSWGS    = 0.27805             XTSSWGD    = 0.27805             TNJTSSWG   = 1
+VTSSWGS    = 9.45                VTSSWGD    = 9.45                DMCG       = 6.10e-008
+DMCI       = 6.60e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.30e-008
+RSHG       = 14.93               GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LCIT       = '0+dlcitp_hvt'      WCIT       = '0+dwcitp_hvt'
+PCIT       = '0+dpcitp_hvt'      LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'
+PNFACTOR   = '0+dpnfactorp_hvt'  LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'
+LVSAT      = '0+dlvsatp_hvt'     WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+LPCLM      = '0+dlpclmp_hvt'     WPCLM      = '0+dwpclmp_hvt'     PPCLM      = '0+dppclmp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.400007e-007-dxlp_hvt'
+LMAX       = '1.000004e-006-dxlp_hvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-7.573426e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60606174+dvthp_hvt'
+LVTH0      = '-3.0731472e-010+dlvthp_hvt'
+WVTH0      = '-6.3298716e-009+dwvthp_hvt'
+PVTH0      = '-7.4709908e-017+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.021004313+dk2p_hvt'
+LK2        = '-3.5263419e-011+dlk2p_hvt'
+WK2        = '5.8812172e-009+dwk2p_hvt'
+PK2        = '8.5330736e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '2.0184239e-006+dcitp_hvt'
+LCIT       = '2.8745673e-012+dlcitp_hvt'
+WCIT       = '4.1742065e-013+dwcitp_hvt'
+PCIT       = '-4.0243943e-019+dpcitp_hvt'
+VOFF       = '-0.15171065+dvoffp_hvt'
+LVOFF      = '-1.5539e-009+dlvoffp_hvt'
+WVOFF      = '-8.6745876e-010+dwvoffp_hvt'
+PVOFF      = '1.3882678e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.015271181+du0p_hvt'
+LU0        = '3.9366797e-011+dlu0p_hvt'
+WU0        = '2.3215499e-010+dwu0p_hvt'
+PU0        = '-4.2876724e-017+dpu0p_hvt'
+UA         = 1.7360291e-009      LUA        = 3.0951971e-017      WUA        = -9.9089955e-017
+PUA        = -9.7112018e-024     UB         = '1.628309e-019+dubp_hvt'
+LUB        = '-3.6907268e-026+dlubp_hvt'
+WUB        = '-3.4108539e-026+dwubp_hvt'
+PUB        = '7.2047437e-033+dpubp_hvt'
+UC         = -1.8530728e-010     LUC        = -1.8889534e-017     WUC        = -7.6336237e-018
+PUC        = 5.4160072e-024      VSAT       = '80000+dvsatp_hvt'  A0         = '1.5490252+da0p_hvt'
+LA0        = '2.1329282e-007+dla0p_hvt'
+WA0        = '6.2804447e-008+dwa0p_hvt'
+PA0        = '-6.1648106e-014+dpa0p_hvt'
+AGS        = 0.47861947          LAGS       = 4.5582942e-007      WAGS       = 4.0279688e-008
+PAGS       = -5.3031182e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.0040958789
+LKETA      = -1.8706851e-009     WKETA      = 6.3191982e-009      PKETA      = -1.4540475e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.39987939+dpclmp_hvt'
+LPCLM      = '1.527349e-007+dlpclmp_hvt'
+WPCLM      = '2.2134998e-008+dwpclmp_hvt'
+PPCLM      = '-2.1340573e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0030490557+dpdiblc2p_hvt'
+LPDIBLC2   = -5.8653772e-010     WPDIBLC2   = -3.568678e-010      PPDIBLC2   = 8.211528e-017
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0052916563        LAIGC      = 3.4891068e-010      WAIGC      = 2.1118479e-010
+PAIGC      = -4.859362e-017      BIGC       = 0.001375            CIGC       = 0.1952244
+AIGSD      = 0.0065825313        LAIGSD     = -9.2852554e-011     WAIGSD     = -2.6152915e-011
+PAIGSD     = 6.0177858e-018      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 4.9927467e-005
+LTVOFF     = -4.813557e-011      WTVOFF     = -2.5466561e-011     PTVOFF     = 2.4552566e-017
+KT1        = -0.20981498         LKT1       = -4.23968e-009       WKT1       = 5.5787206e-010
+PKT1       = 3.4846395e-016      KT1L       = 0                   KT2        = -0.049387055
+LKT2       = -3.7543757e-009     WKT2       = -2.0970578e-009     PKT2       = 6.0795283e-016
+UTE        = -1.008789           LUTE       = 5.6786137e-008      WUTE       = -4.216121e-008
+PUTE       = -7.8231215e-015     UA1        = 3.1502487e-009      LUA1       = 5.2824876e-017
+WUA1       = -1.5625754e-016     PUA1       = -2.3673969e-023     UB1        = -3.4708502e-018
+LUB1       = 2.6529301e-026      WUB1       = 1.5100283e-025      PUB1       = 1.2787795e-032
+UC1        = -2.0272498e-010     LUC1       = 1.1518418e-017      WUC1       = 4.8871994e-017
+PUC1       = -3.6858938e-024     PRT        = 0                   AT         = '194340.3+datp_hvt'
+LAT        = -0.027751664        WAT        = -0.0042677726       PAT        = -6.8452314e-010
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_hvt'
+LMAX       = '2.400007e-007-dxlp_hvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.60369893+dvthp_hvt'
+LVTH0      = '-8.509968e-010+dlvthp_hvt'
+WVTH0      = '-7.3249368e-009+dwvthp_hvt'
+PVTH0      = '1.5425459e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.025922797+dk2p_hvt'
+LK2        = '1.0964798e-009+dlk2p_hvt'
+WK2        = '7.0344576e-009+dwk2p_hvt'
+PK2        = '-1.8002987e-016+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0011791319+dcitp_hvt'
+LCIT       = '2.7465726e-010+dlcitp_hvt'
+WCIT       = '1.6577847e-010+dwcitp_hvt'
+PCIT       = '-3.8452016e-017+dpcitp_hvt'
+VOFF       = '-0.16813777+dvoffp_hvt'
+LVOFF      = '2.2259785e-009+dlvoffp_hvt'
+WVOFF      = '2.9181973e-009+dwvoffp_hvt'
+PVOFF      = '-7.3225267e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0063333333+deta0p_hvt'
+WETA0      = '-7.4666667e-010+dweta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.013440681+du0p_hvt'
+LU0        = '4.6056491e-010+dlu0p_hvt'
+WU0        = '4.9601496e-010+dwu0p_hvt'
+PU0        = '-1.035909e-016+dpu0p_hvt'
+UA         = 1.6835658e-009      LUA        = 4.3023795e-017      WUA        = -1.0181971e-016
+PUA        = -9.083086e-024      UB         = '-3.1571517e-020+dubp_hvt'
+LUB        = '7.8247287e-027+dlubp_hvt'
+WUB        = '4.0285811e-028+dwubp_hvt'
+PUB        = '-7.3632879e-034+dpubp_hvt'
+UC         = -4.2168673e-010     LUC        = 3.5501376e-017      WUC        = 4.3120738e-017
+PUC        = -6.2625713e-024     VSAT       = '80000+dvsatp_hvt'  A0         = '3.5672722+da0p_hvt'
+LA0        = '-2.5110582e-007+dla0p_hvt'
+WA0        = '-4.1501816e-007+dwa0p_hvt'
+PA0        = '4.8298875e-014+dpa0p_hvt'
+AGS        = 0.37783775          LAGS       = 4.7901929e-007      WAGS       = -6.0924509e-009
+PAGS       = -4.2360953e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.0031038886
+LKETA      = -2.1401864e-010     WKETA      = -5.0577305e-009     PKETA      = 1.1637838e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '1.5263677+dpclmp_hvt'
+LPCLM      = '-1.0647007e-007+dlpclmp_hvt'
+WPCLM      = '-1.9958843e-007+dwpclmp_hvt'
+PPCLM      = '2.9677987e-014+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0005+dpdiblc2p_hvt'
+PDIBLCB    = 0                   DROUT      = 0                   PVAG       = 2.5
+DELTA      = 0.01                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 16                  PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RDSW       = 200
+RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.158e-007
+ALPHA1     = 0.0563              BETA0      = 16.7                AGIDL      = 7e-009
+BGIDL      = 4.4632e+009         CGIDL      = 18                  EGIDL      = -2.0284
+AIGBACC    = 0.01333             BIGBACC    = 0.003785            CIGBACC    = 0.034287
+NIGBACC    = 10                  AIGBINV    = 0.012               BIGBINV    = 0.005386
+CIGBINV    = 0.5                 EIGBINV    = 0.009906            NIGBINV    = 1
+AIGC       = 0.0068012637        LAIGC      = 1.5500277e-012      BIGC       = 0.001375
+CIGC       = 0.1952244           AIGSD      = 0.0060420281        LAIGSD     = 3.1517231e-011
+BIGSD      = 0.0002969           CIGSD      = 0                   NIGC       = 2.605
+POXEDGE    = 1                   PIGCD      = 3.05                NTOX       = 'ntoxp_hvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_hvt'
+CGDO       = 'cgop_hvt'          CGBO       = 0                   CGDL       = 'cglp_hvt'
+CGSL       = 'cglp_hvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_hvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.05                MOIN       = 9.6576              NOFF       = 2.0069
+VOFFCV     = -0.068319           TVOFF      = -0.00071076354      LTVOFF     = 1.2689943e-010
+WTVOFF     = 1.2732509e-010      PTVOFF     = -1.0604792e-017     KT1        = -0.19325598
+LKT1       = -8.0499058e-009     WKT1       = -3.9184069e-009     PKT1       = 1.3784557e-015
+KT1L       = 0                   KT2        = -0.070678731        LKT2       = 1.144839e-009
+WKT2       = 9.3962553e-010      PKT2       = -9.0787995e-017     UTE        = -0.62752305
+LUTE       = -3.0943146e-008     WUTE       = -1.1919262e-007     PUTE       = 9.9018068e-015
+UA1        = 4.0586439e-009      LUA1       = -1.5619687e-016     WUA1       = -3.3984325e-016
+PUA1       = 1.8569103e-023      UB1        = -4.3859634e-018     LUB1       = 2.3709684e-025
+WUB1       = 3.1835083e-025      PUB1       = -2.5718979e-032     UC1        = 7.0214117e-011
+LUC1       = -5.1284868e-017     WUC1       = -2.5414657e-018     PUC1       = 8.1443433e-024
+PRT        = 0                   AT         = '134909.12+datp_hvt'
+LAT        = -0.014076548        WAT        = -0.01266366         PAT        = 1.2473705e-009
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+LETA0      = '0+dleta0p_hvt'     PETA0      = '0+dpeta0p_hvt'     LVSAT      = '0+dlvsatp_hvt'
+WVSAT      = '0+dwvsatp_hvt'     PVSAT      = '0+dpvsatp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_hvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_hvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_hvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_hvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_hvt'
+TOXM       = 2.8e-009            DTOX       = 3.5028e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_hvt'    XW         = '2e-08+dxwp_hvt'    DLC        = '-6.55e-09+ddlcp_hvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.61122051+dvthp_hvt'
+LVTH0      = '-1.1012175e-010+dlvthp_hvt'
+WVTH0      = '-2.4781984e-009+dwvthp_hvt'
+PVTH0      = '-3.2314914e-016+dpvthp_hvt'
+K1         = 0.45227             K2         = '-0.013137726+dk2p_hvt'
+LK2        = '-1.6284971e-010+dlk2p_hvt'
+WK2        = '4.7718152e-009+dwk2p_hvt'
+PK2        = '4.28404e-017+dpk2p_hvt'
+K3         = -4.6257419          K3B        = 3.6653727           W0         = 0
+DVT0       = 4.189               DVT1       = 1.908               DVT2       = 0.03
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1029              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.415e-007          DVTP1      = 2.5                 LPE0       = 4.44089e-021
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.4006e+020         NDEP       = 8.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0022823135+dcitp_hvt'
+LCIT       = '3.8332065e-010+dlcitp_hvt'
+WCIT       = '-2.7919479e-010+dwcitp_hvt'
+PCIT       = '5.377849e-018+dpcitp_hvt'
+VOFF       = '-0.11498327+dvoffp_hvt'
+LVOFF      = '-3.0097392e-009+dlvoffp_hvt'
+WVOFF      = '-1.2148175e-008+dwvoffp_hvt'
+PVOFF      = '7.5178503e-016+dpvoffp_hvt'
+NFACTOR    = '1+dnfactorp_hvt'   ETA0       = '0.0087857358+deta0p_hvt'
+LETA0      = '-2.4156164e-010+dleta0p_hvt'
+WETA0      = '-1.8030862e-009+dweta0p_hvt'
+PETA0      = '1.0405732e-016+dpeta0p_hvt'
+ETAB       = -0.0064316667       WETAB      = 2.6133333e-010      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 9.0e-10
+PKU0WE     = -8.6e-17
+U0         = '0.020704853+du0p_hvt'
+LU0        = '-2.5495605e-010+dlu0p_hvt'
+WU0        = '-7.3620721e-010+dwu0p_hvt'
+PU0        = '1.778298e-017+dpu0p_hvt'
+UA         = 2.3445051e-009      LUA        = -2.2078734e-017     WUA        = -2.103449e-016
+PUA        = 1.6066451e-024      UB         = '1.4386965e-019+dubp_hvt'
+LUB        = '-9.4562264e-027+dlubp_hvt'
+WUB        = '-2.0657144e-026+dwubp_hvt'
+PUB        = '1.3380815e-033+dpubp_hvt'
+UC         = 2.4429891e-010      LUC        = -3.0098209e-017     WUC        = -9.4932018e-017
+PUC        = 7.3356251e-024
+VSAT       = '66794.756+dvsatp_hvt+5942.53*ff_flag_hvt-2641.13*ss_flag_hvt'
+LVSAT      = '0.0013007165+dlvsatp_hvt-0.000585338*ff_flag_hvt+0.00026015*ss_flag_hvt'
+WVSAT      = '0.0042256781+dwvsatp_hvt-0.00190161*ff_flag_hvt+0.00084516*ss_flag_hvt'
+PVSAT      = '-4.1622929e-010+dpvsatp_hvt+1.87308e-10*ff_flag_hvt-8.3248e-11*ss_flag_hvt'
+A0         = '0.7142333+da0p_hvt'
+LA0        = '2.9918511e-008+dla0p_hvt'
+WA0        = '4.2828211e-007+dwa0p_hvt'
+PA0        = '-3.4766202e-014+dpa0p_hvt'
+AGS        = 18.855358           LAGS       = -1.3410165e-006     WAGS       = -5.4023388e-006
+PAGS       = 4.8916932e-013      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.022865595
+LKETA      = -2.7720128e-009     WKETA      = 1.8918835e-008      PKETA      = -1.1979079e-015
+DWG        = 0                   DWB        = 0                   PCLM       = '0.0021081653+dpclmp_hvt'
+LPCLM      = '4.3669499e-008+dlpclmp_hvt'
+WPCLM      = '1.9400448e-007+dwpclmp_hvt'
+PPCLM      = '-9.090914e-015+dppclmp_hvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.0037445427+dpdiblc2p_hvt'
+LPDIBLC2   = 4.1808746e-010      PDIBLCB    = 0                   DROUT      = 0
+PVAG       = 2.5                 DELTA      = 0.01                PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 16                  PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RDSW       = 200                 RSW        = '92.68+drdswp_hvt'  RDW        = '92.68+drdswp_hvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.158e-007          ALPHA1     = 0.0563              BETA0      = 16.7
+AGIDL      = 7e-009              BGIDL      = 4.4632e+009         CGIDL      = 18
+EGIDL      = -2.0284             AIGBACC    = 0.01333             BIGBACC    = 0.003785
+CIGBACC    = 0.034287            NIGBACC    = 10                  AIGBINV    = 0.012
+BIGBINV    = 0.005386            CIGBINV    = 0.5                 EIGBINV    = 0.009906
+NIGBINV    = 1                   AIGC       = 0.007030925         LAIGC      = -2.1071608e-011
+BIGC       = 0.001375            CIGC       = 0.1952244           AIGSD      = 0.0061922183
+LAIGSD     = 1.6723498e-011      BIGSD      = 0.0002969           CIGSD      = 0
+NIGC       = 2.605               POXEDGE    = 1                   PIGCD      = 3.05
+NTOX       = 'ntoxp_hvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_hvt'          CGDO       = 'cgop_hvt'          CGBO       = 0
+CGDL       = 'cglp_hvt'          CGSL       = 'cglp_hvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_hvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.05                MOIN       = 9.6576
+NOFF       = 2.0069              VOFFCV     = -0.068319           TVOFF      = 0.00067923594
+LTVOFF     = -1.0015517e-011     WTVOFF     = -8.5134595e-011     PTVOFF     = 1.0322487e-017
+KT1        = -0.2827156          LKT1       = 7.6186684e-010      WKT1       = 2.0131745e-008
+PKT1       = -9.904842e-016      KT1L       = 0                   KT2        = -0.039628068
+LKT2       = -1.9136513e-009     WKT2       = -6.2859466e-009     PKT2       = 6.2093086e-016
+UTE        = -0.84262734         LUTE       = -9.7553741e-009     WUTE       = -5.0359253e-008
+PUTE       = 3.1217197e-015      UA1        = 5.3683084e-009      LUA1       = -2.8519883e-016
+WUA1       = -3.8031394e-016     PUA1       = 2.2555465e-023      UB1        = -4.5646643e-018
+LUB1       = 2.5469888e-025      WUB1       = 8.7669327e-026      PUB1       = -2.9968509e-033
+UC1        = -9.0187515e-010     LUC1       = 4.4465924e-017      WUC1       = 1.4310483e-016
+PUC1       = -6.2018165e-024     PRT        = 0                   AT         = '-8000+datp_hvt'
+NOIA       = 'noiap_hvt'        NOIB       = 'noibp_hvt'        NOIC       = 'noicp_hvt'
+EM         = 1.00000e+07         EF         = 1.1         JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 2.13e-13            JSWD       = 2.13e-13
+JSWGS      = 2.13e-13            JSWGD      = 2.13e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 1.02                PBD        = 1.02                CJS        = 'cjp_hvt'
+CJD        = 'cjp_hvt'           MJS        = 0.42                MJD        = 0.42
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswp_hvt'
+CJSWD      = 'cjswp_hvt'         MJSWS      = 0.04                MJSWD      = 0.04
+PBSWGS     = 1.22                PBSWGD     = 1.22                CJSWGS     = 'cjswgp_hvt'
+CJSWGD     = 'cjswgp_hvt'        MJSWGS     = 0.92                MJSWGD     = 0.92
+TPB        = 0.0023              TCJ        = 0.000877            TPBSW      = 0.0016
+TCJSW      = 0.000204            TPBSWG     = 0.0003              TCJSWG     = 0.0008
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-008
+JTSSWGD    = 1e-008              NJTSSWG    = 7.3495              XTSSWGS    = 0.27805
+XTSSWGD    = 0.27805             TNJTSSWG   = 1                   VTSSWGS    = 9.45
+VTSSWGD    = 9.45                DMCG       = 6.10e-008           DMCI       = 6.60e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.30e-008           RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.6e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -2e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_hvt'  WNFACTOR   = '0+dwnfactorp_hvt'  PNFACTOR   = '0+dpnfactorp_hvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.ENDL MOS_hvt








***************************************************************
*                                                             *
*                     mLow-vt DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_mlvt
**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_mlvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_mlvt'
+LMAX       = 2.00001e-05         WMIN       = '1e-005-dxwn_mlvt'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3971583+dvthn_mlvt'   K1         = 0.31994
+K2         = '0.022565+dk2n_mlvt'     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 0.001               VOFF       = -0.1282             NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'      UA         = -1.683e-009
+UB         = 2.412312e-018       UC         = 1.289e-010          VSAT       = '110000+dvsatn_mlvt'
+A0         = 2.203               AGS        = 0.8591              A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05109            DWG        = 0                   DWB        = 0
+PCLM       = 0.2722              PDIBLC1    = 0                   PDIBLC2    = '0.002415+dpdiblc2n_mlvt'
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.001375            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2154432
+KT1L       = 0                   KT2        = -0.07264            UTE        = -1.379
+UA1        = 1.6e-009            UB1        = -1.44628e-018       UC1        = 3.03e-013
+PRT        = 0                   AT         = 200000
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          WVOFF      = '0+dwvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'      LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_mlvt'
+LMAX       = '1e-005-dxln_mlvt'       WMIN       = '1e-005-dxwn_mlvt'       WMAX       = 0.0009000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39304444+dvthn_mlvt'  LVTH0      = '4.099508e-008+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.023370867+dk2n_mlvt'  LK2        = -8.0305518e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00098244461
+LCIT       = '1.7494141e-010+dlcitn_mlvt'
+VOFF       = -0.1255394          LVOFF      = '-2.65132e-008+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'
+UA         = -1.7047351e-009     LUA        = 2.1659301e-016      UB         = 2.4380817e-018
+LUB        = -2.5679813e-025     UC         = 1.3000452e-010      LUC        = -1.1006611e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.2653681           LA0        = '-6.2150487e-007+dla0n_mlvt'
+AGS        = 0.81477464          LAGS       = 4.4170706e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04934744         LKETA      = -1.7364799e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0025667367+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.5120733e-009     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0013986988
+LTVOFF     = -2.3616127e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21318399         LKT1       = -2.2513329e-008     KT1L       = 0
+KT2        = -0.071975146        LKT2       = -6.6253388e-009     UTE        = -1.3590544
+LUTE       = -1.9876016e-007     UA1        = 1.662196e-009       LUA1       = -6.1978976e-016
+UB1        = -1.4469534e-018     LUB1       = 6.7108271e-027      UC1        = -3.5356714e-012
+LUC1       = 3.8252783e-017      PRT        = 0                   AT         = 201072.34
+LAT        = -0.01068603
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_mlvt'
+LMAX       = '1.000002e-006-dxln_mlvt'
+WMIN       = '1e-005-dxwn_mlvt'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43676534+dvthn_mlvt'  LVTH0      = '-1.2003913e-009+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.021314478+dk2n_mlvt'  LK2        = -6.0459107e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010868883
+LCIT       = '7.4141765e-011+dlcitn_mlvt'
+VOFF       = -0.15239595         LVOFF      = '-5.9367112e-010+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10102+deta0n_mlvt'    ETAB       = -0.08565
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'
+UA         = -1.5453265e-009     LUA        = 6.2746135e-017      UB         = 2.269578e-018
+LUB        = -9.4173528e-026     UC         = 1.2925162e-010      LUC        = -1.0279988e-017
+VSAT       = '113946.42+dvsatn_mlvt'  LVSAT      = '-0.0038087297+dlvsatn_mlvt'
+A0         = 2.2094596           LA0        = '-5.6754699e-007+dla0n_mlvt'
+AGS        = 0.42887173          LAGS       = 8.1414582e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073052413        LKETA      = 5.5131064e-009      DWG        = 0
+DWB        = 0                   PCLM       = 0.2722              PDIBLC1    = 0
+PDIBLC2    = '0.0012164964+dpdiblc2n_mlvt'
+LPDIBLC2   = -2.0894285e-010     PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012118355
+LTVOFF     = -5.5817591e-011     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.22714346         LKT1       = -9.0408975e-009     KT1L       = 0
+KT2        = -0.075960598        LKT2       = -2.7789399e-009     UTE        = -1.5971652
+LUTE       = 3.1042938e-008      UA1        = 1.1007222e-009      LUA1       = -7.7905835e-017
+UB1        = -1.5451554e-018     LUB1       = 1.0148653e-025      UC1        = 1.2934884e-011
+LUC1       = 2.2356885e-017      PRT        = 0                   AT         = 234845.69
+LAT        = -0.043281019
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'
+PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'         WETA0      = '0+dweta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln_mlvt'
+LMAX       = '2.399959e-007-dxln_mlvt'
+WMIN       = '1e-005-dxwn_mlvt'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44301989+dvthn_mlvt'  LVTH0      = '-2.6263045e-009+dlvthn_mlvt'
+K1         = 0.31994             K2         = '0.0060518885+dk2n_mlvt' LK2        = -2.5663454e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00089174876
+LCIT       = '1.1862968e-010+dlcitn_mlvt'
+VOFF       = -0.13778537         LVOFF      = '-3.9245908e-009+dlvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.1010175+deta0n_mlvt'  LETA0      = '5.6985851e-013+dleta0n_mlvt'
+ETAB       = -0.08565            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021399889+du0n_mlvt'  LU0        = '4.7901151e-011+dlu0n_mlvt'
+UA         = -1.318498e-009      LUA        = 1.1033782e-017      UB         = 1.9551074e-018
+LUB        = -2.2480505e-026     UC         = 8.770291e-011       LUC        = -8.077125e-019
+VSAT       = '101196.2+dvsatn_mlvt'   LVSAT      = '-0.0009019344+dlvsatn_mlvt'
+A0         = 0.76497717          LA0        = '-2.3823389e-007+dla0n_mlvt'
+AGS        = 3.2754786           LAGS       = 1.6517638e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.073974665        LKETA      = 5.7233616e-009      DWG        = 0
+DWB        = 0                   PCLM       = -0.03535932         LPCLM      = 7.0117374e-008
+PDIBLC1    = 0                   PDIBLC2    = '-0.00020716496+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.1562347e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00087063866
+LTVOFF     = 2.1968459e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.25962724         LKT1       = -1.6352462e-009     KT1L       = 0
+KT2        = -0.10603119         LKT2       = 4.0765531e-009      UTE        = -1.5964855
+LUTE       = 3.0887983e-008      UA1        = 8.2927857e-010      LUA1       = -1.6022109e-017
+UB1        = -1.389084e-018      LUB1       = 6.5905376e-026      UC1        = 1.2396893e-010
+LUC1       = -2.9566572e-018     PRT        = 0                   AT         = 54781.038
+LAT        = -0.0022298811
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'
+WCIT       = '0+dwcitn_mlvt'          WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+WETA0      = '0+dweta0n_mlvt'         PETA0      = '0+dpeta0n_mlvt'         WVOFF      = '0+dwvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln_mlvt'
+WMIN       = '1e-005-dxwn_mlvt'       WMAX       = 0.0009000001        VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.40966629+dvthn_mlvt'
+LVTH0      = '5.6833647e-10+dlvthn_mlvt'
+K1         = 0.31994             K2         = '-0.00024866313+dk2n_mlvt'
+LK2        = -1.9628723e-009     K3         = -2.5                K3B        = 2.32848
+W0         = 0                   DVT0       = 5.6761764           DVT1       = 1.2875382
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.5                 MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1.0230918e-006      DVTP1      = 1
+LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 3.5825e+020
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = -4.4334382e-05
+Pcit     = 1.8464961e-15
+LCIT       = '2.0828867e-10+dlcitn_mlvt'
+VOFF       = -0.13637037
+LVOFF      = '-4.0601207e-09+dlvoffn_mlvt'
+NFACTOR    = '0.751428+dnfactorn_mlvt-0.00210174*ss_flag_mlvt'
+ETA0       = '0.00065024466+deta0n_mlvt-7.14e-05*ff_flag_mlvt-0.0001428*ss_flag_mlvt'
+LETA0      = '9.6138461e-09+dleta0n_mlvt+6.83872e-12*ff_flag_mlvt+1.36774e-11*ss_flag_mlvt'
+ETAB       = -0.12377292
+Petab    = -6.154987e-15
+Wetab    = 6.426147e-08
+Letab    = 3.6514274e-09
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021162477+du0n_mlvt'  LU0        = '7.0640674e-011+dlu0n_mlvt'
+UA         = -1.3961783e-009     LUA        = 1.8474072e-017      UB         = 1.7190372e-018
+LUB        = 1.3053168e-028      UC         = 1.2291211e-010      LUC        = -4.1800851e-018
+VSAT       = '84982.229+dvsatn_mlvt'
+LVSAT      = '0.00065105587+dlvsatn_mlvt'
+A0         = 1.4250678           LA0        = '-3.0145803e-007+dla0n_mlvt'
+AGS        = 3.3966895           LAGS       = 1.5356668e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.13066844         LKETA      = 1.1153548e-008      DWG        = 0
+DWB        = 0                   PCLM       = 0.69140908          LPCLM      = 5.0677006e-010
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'
+CGBO       = 0                   CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011288596        LTVOFF     = -2.7642003e-012     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.28118927         LKT1       = 4.2998671e-010
+KT1L       = 0
+KT2        = -0.12709626
+Pkt2     = -3.692993e-15
+Wkt2     = 3.855689e-08
+LKT2       = 6.0941662e-09
+UTE        = -1.7133071          LUTE       = 4.2077271e-008      UA1        = -1.2041553e-010
+LUA1       = 7.4940541e-017      UB1        = 2.8533105e-021      LUB1       = -6.7415774e-026
+UC1        = 1.5113984e-010      LUC1       = -5.5591139e-018     PRT        = 0
+AT         = 31500
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+WVTH0      = '3.2130737e-07+dwvthn_mlvt'
+PVTH0      = '-3.0774936e-14+dpvthn_mlvt'
+WCIT       = '-1.9278442e-08+dwcitn_mlvt'
+WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+WETA0      = '-1.2852295e-07+dweta0n_mlvt+6.42615e-08*ff_flag_mlvt+1.28523e-07*ss_flag_mlvt'
+PETA0      = '1.2309974e-14+dpeta0n_mlvt-6.15499e-15*ff_flag_mlvt-1.231e-14*ss_flag_mlvt'
+WVOFF      = '-2.0563671e-07+dwvoffn_mlvt'
+PVOFF      = '1.9695959e-14+dpvoffn_mlvt'
+PVSAT      = '-4.9239897e-09+dpvsatn_mlvt'
+WVSAT      = '0.051409179+dwvsatn_mlvt'
+LNFACTOR   = '-1.3677444e-10+dlnfactorn_mlvt+2.01306e-10*ss_flag_mlvt'
+WNFACTOR   = '-1.2852295e-06+dwnfactorn_mlvt+1.89161e-06*ss_flag_mlvt'
+PNFACTOR   = '1.2309974e-13+dpnfactorn_mlvt-1.81179e-13*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_mlvt'
+LMAX       = 2.00001e-05         WMIN       = '1e-006-dxwn_mlvt'       WMAX       = '1e-005-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39547494+dvthn_mlvt'  WVTH0      = '1.6867314e-008+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.022969033+dk2n_mlvt'  WK2        = -4.048414e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0010453333
+WCIT       = '-4.5424e-010+dwcitn_mlvt'
+VOFF       = -0.12669799         WVOFF      = '-1.5050107e-008+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02161+du0n_mlvt'      UA         = -1.7121267e-009
+WUA        = 2.918492e-016       UB         = 2.4287286e-018      WUB        = -1.6449393e-025
+UC         = 1.3399547e-010      WUC        = -5.1056576e-017     VSAT       = '110000+dvsatn_mlvt'
+A0         = 2.1942733           WA0        = 8.74412e-008        AGS        = 0.85684215
+WAGS       = 2.262365e-008       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.052544067
+WKETA      = 1.4569748e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.265162            WPCLM      = 7.052076e-008       PDIBLC1    = 0
+PDIBLC2    = '0.0024053667+dpdiblc2n_mlvt'
+WPDIBLC2   = 9.6526e-011         PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00136514
+LTVOFF     = 0                   WTVOFF     = 9.87972e-011        PTVOFF     = 0
+KT1        = -0.21658778         WKT1       = 1.1468652e-008      KT1L       = 0
+KT2        = -0.0729256          WKT2       = 2.861712e-009       UTE        = -1.3799067
+WUTE       = 9.0848e-009         UA1        = 1.6328667e-009      WUA1       = -3.29324e-016
+UB1        = -1.4643317e-018     WUB1       = 1.8087837e-025      UC1        = -3.5953267e-012
+WUC1       = 3.9061233e-017      PRT        = 0                   AT         = 200000
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           WU0        = '0+dwu0n_mlvt'           PU0        = '0+dpu0n_mlvt'
+LETA0      = '0+dleta0n_mlvt'         PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'
+PVOFF      = '0+dpvoffn_mlvt'          PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'      LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_mlvt'
+LMAX       = '1e-005-dxln_mlvt'       WMIN       = '1e-006-dxwn_mlvt'       WMAX       = '1e-005-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.3912083+dvthn_mlvt'   LVTH0      = '4.2517486e-008+dlvthn_mlvt'
+WVTH0      = '1.8398106e-008+dwvthn_mlvt'
+PVTH0      = '-1.5254509e-014+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.023700073+dk2n_mlvt'  LK2        = -7.2848877e-009
+WK2        = -3.2986427e-009     PK2        = -7.471554e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0010309425        LCIT       = '1.4340605e-010+dlcitn_mlvt'
+WCIT       = '-4.8594906e-010+dwcitn_mlvt'
+PCIT       = 3.1598426e-016      VOFF       = -0.12386568         LVOFF      = '-2.8224355e-008+dlvoffn_mlvt'
+WVOFF      = '-1.6770688e-008+dwvoffn_mlvt'
+PVOFF      = '1.7145779e-014+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021608056+du0n_mlvt'  LU0        = '1.9377335e-011+dlu0n_mlvt'
+WU0        = '1.948407e-011+dwu0n_mlvt'
+PU0        = '-1.941609e-016+dpu0n_mlvt'
+UA         = -1.7350077e-009     LUA        = 2.2801148e-016      WUA        = 3.0333057e-016
+PUA        = -1.1441307e-022     UB         = 2.4549474e-018      LUB        = -2.6127333e-025
+WUB        = -1.6899378e-025     PUB        = 4.4841459e-032      UC         = 1.3493348e-010
+LUC        = -9.347427e-018      WUC        = -4.9388253e-017     PUC        = -1.6625027e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.2627307           LA0        = '-6.8218549e-007+dla0n_mlvt'
+WA0        = 2.6426333e-008      PA0        = 6.0801986e-013      AGS        = 0.81261905
+LAGS       = 4.4068808e-007      WAGS       = 2.1599056e-008      PAGS       = 1.0210194e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050703795        LKETA      = -1.833851e-008
+WKETA      = 1.3590674e-008      PKETA      = 9.7565851e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0025925301+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.8651041e-009     WPDIBLC2   = -2.5844939e-010     PPDIBLC2   = 3.5373688e-015
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013867485        LTVOFF     = -2.1533064e-010
+WTVOFF     = 1.1974258e-010      PTVOFF     = -2.0872296e-016     KT1        = -0.21442694
+LKT1       = -2.1532981e-008     WKT1       = 1.2454399e-008      PKT1       = -9.8230852e-015
+KT1L       = 0                   KT2        = -0.072099838        LKT2       = -8.2288133e-009
+WKT2       = 1.2494052e-009      PKT2       = 1.6066814e-014      UTE        = -1.3572144
+LUTE       = -2.2613065e-007     WUTE       = -1.8436448e-008     PUTE       = 2.7425227e-013
+UA1        = 1.7006531e-009      LUA1       = -6.754996e-016      WUA1       = -3.853407e-016
+PUA1       = 5.5821258e-022      UB1        = -1.4668194e-018     LUB1       = 2.4789881e-026
+WUB1       = 1.9905701e-025      PUB1       = -1.8115212e-031     UC1        = -7.765745e-012
+LUC1       = 4.1558677e-017      WUC1       = 4.2385337e-017      PUC1       = -3.3125063e-023
+PRT        = 0                   AT         = 201084.5            LAT        = -0.010807139
+WAT        = -0.00012177544      PAT        = 1.2135056e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_mlvt'
+LMAX       = '1.000002e-006-dxln_mlvt'
+WMIN       = '1e-006-dxwn_mlvt'       WMAX       = '1e-005-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.43644065+dvthn_mlvt'  LVTH0      = '-1.136705e-009+dlvthn_mlvt'
+WVTH0      = '3.253333e-009+dwvthn_mlvt'
+PVTH0      = '-6.3813721e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.022589005+dk2n_mlvt'  LK2        = -6.2125854e-009
+WK2        = -1.2770759e-008     PK2        = 1.6700806e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.001096553         LCIT       = '8.0084763e-011+dlcitn_mlvt'
+WCIT       = '-9.6839942e-011+dwcitn_mlvt'
+PCIT       = -5.9548836e-017     VOFF       = -0.15284142         LVOFF      = '-2.5957307e-010+dlvoffn_mlvt'
+WVOFF      = '4.4636181e-009+dwvoffn_mlvt'
+PVOFF      = '-3.3476624e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10328893+deta0n_mlvt' WETA0      = '-2.2734712e-008+dweta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021606051+du0n_mlvt'  LU0        = '2.1312171e-011+dlu0n_mlvt'
+WU0        = '3.9571993e-011+dwu0n_mlvt'
+PU0        = '-2.1354795e-016+dpu0n_mlvt'
+UA         = -1.5657172e-009     LUA        = 6.4627591e-017      WUA        = 2.0431503e-016
+PUA        = -1.8852183e-023     UB         = 2.2803345e-018      LUB        = -9.2752717e-026
+WUB        = -1.0778004e-025     PUB        = -1.423653e-032      UC         = 1.3678552e-010
+LUC        = -1.1134843e-017     WUC        = -7.5489601e-017     PUC        = 8.5656457e-024
+VSAT       = '114148.32+dvsatn_mlvt'  LVSAT      = '-0.0040035838+dlvsatn_mlvt'
+WVSAT      = '-0.0020230217+dwvsatn_mlvt'
+PVSAT      = '1.9524384e-009+dpvsatn_mlvt'
+A0         = 2.1280013           LA0        = '-5.5215676e-007+dla0n_mlvt'
+WA0        = 8.1621195e-007      PA0        = -1.5421014e-013     AGS        = 0.42466709
+LAGS       = 8.151044e-007       WAGS       = 4.2130504e-008      PAGS       = -9.6049124e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.076145004        LKETA      = 6.2150549e-009
+WKETA      = 3.0987767e-008      PKETA      = -7.0335238e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.265162            WPCLM      = 7.052076e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00079587727+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.3113651e-010     WPDIBLC2   = 4.2146038e-009      PPDIBLC2   = -7.7961951e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0012284441        LTVOFF     = -6.254953e-011
+WTVOFF     = -1.6641859e-010     PTVOFF     = 6.7454036e-017      KT1        = -0.22675482
+LKT1       = -9.6352162e-009     WKT1       = -3.8941599e-009     PKT1       = 5.9550728e-015
+KT1L       = 0                   KT2        = -0.07738044         LKT2       = -3.1324513e-009
+WKT2       = 1.4226817e-008      PKT2       = 3.5421843e-015      UTE        = -1.6184239
+LUTE       = 2.5965229e-008      WUTE       = 2.1301242e-007      PUTE       = 5.0878647e-014
+UA1        = 1.0856968e-009      LUA1       = -8.1999125e-017     WUA1       = 1.505545e-016
+PUA1       = 4.1014766e-023      UB1        = -1.5438351e-018     LUB1       = 9.9118509e-026
+WUB1       = -1.3229333e-026     PUB1       = 2.372755e-032       UC1        = 1.0815775e-011
+LUC1       = 2.3625467e-017      WUC1       = 2.1233474e-017      PUC1       = -1.2711188e-023
+PRT        = 0                   AT         = 235012.77           LAT        = -0.04355165
+WAT        = -0.0016741523       PAT        = 2.71172e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln_mlvt'
+LMAX       = '2.399959e-007-dxln_mlvt'
+WMIN       = '1e-006-dxwn_mlvt'       WMAX       = '1e-005-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44295121+dvthn_mlvt'  LVTH0      = '-2.6209825e-009+dlvthn_mlvt'
+WVTH0      = '6.8814839e-010+dwvthn_mlvt'
+PVTH0      = '-5.3326435e-017+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0071010498+dk2n_mlvt' LK2        = -2.6816413e-009
+WK2        = -1.0512597e-008     PK2        = 1.1552647e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00091803764       LCIT       = '1.2078269e-010+dlcitn_mlvt'
+WCIT       = '-2.634146e-010+dwcitn_mlvt'
+PCIT       = -2.1573145e-017     VOFF       = -0.13506072         LVOFF      = '-4.3132178e-009+dlvoffn_mlvt'
+WVOFF      = '-2.7301032e-008+dwvoffn_mlvt'
+PVOFF      = '3.8940424e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10402516+deta0n_mlvt' LETA0      = '-1.6784547e-010+dleta0n_mlvt'
+WETA0      = '-3.0136772e-008+dweta0n_mlvt'
+PETA0      = '1.6875216e-015+dpeta0n_mlvt'
+ETAB       = -0.083491           WETAB      = -2.163318e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021434407+du0n_mlvt'  LU0        = '6.0443544e-011+dlu0n_mlvt'
+WU0        = '-3.4587047e-010+dwu0n_mlvt'
+PU0        = '-1.2567478e-016+dpu0n_mlvt'
+UA         = -1.3266782e-009     LUA        = 1.0131479e-017      WUA        = 8.1965417e-017
+PUA        = 9.0410812e-024      UB         = 1.9652232e-018      LUB        = -2.0913642e-026
+WUB        = -1.0136089e-025     PUB        = -1.5699969e-032     UC         = 8.9870316e-011
+LUC        = -4.391159e-019      WUC        = -2.1717412e-017     PUC        = -3.6933379e-024
+VSAT       = '99812.142+dvsatn_mlvt'  LVSAT      = '-0.00073522225+dlvsatn_mlvt'
+WVSAT      = '0.013868259+dwvsatn_mlvt'
+PVSAT      = '-1.6704557e-009+dpvsatn_mlvt'
+A0         = 0.71811517          LA0        = '-2.3073092e-007+dla0n_mlvt'
+WA0        = 4.6955716e-007      PA0        = -7.5179779e-014     AGS        = 3.2754786
+LAGS       = 1.6517638e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.075402241
+LKETA      = 6.0457198e-009      WKETA      = 1.4304311e-008      PKETA      = -3.2300294e-015
+DWG        = 0                   DWB        = 0                   PCLM       = -0.026264397
+LPCLM      = 6.643939e-008       WPCLM      = -9.1131129e-008     PPCLM      = 3.6853398e-014
+PDIBLC1    = 0                   PDIBLC2    = '-0.00034397698+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.2872746e-010      WPDIBLC2   = 1.3708565e-009      PPDIBLC2   = -1.3130201e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00084753672       LTVOFF     = 2.4289737e-011
+WTVOFF     = 2.3148144e-010      PTVOFF     = -2.3259213e-017     KT1        = -0.26276292
+LKT1       = -1.4260915e-009     WKT1       = 3.1419477e-008      PKT1       = -2.0957301e-015
+KT1L       = 0                   KT2        = -0.11084105         LKT2       = 4.4958996e-009
+WKT2       = 4.8194868e-008      PKT2       = -4.2018519e-015     UTE        = -1.666301
+LUTE       = 3.6880252e-008      WUTE       = 6.9955151e-007      PUTE       = -6.0042533e-014
+UA1        = 7.6386417e-010      LUA1       = -8.627713e-018      WUA1       = 6.5545235e-016
+PUA1       = -7.4091848e-023     UB1        = -1.3948662e-018     LUB1       = 6.5156576e-026
+WUB1       = 5.7937342e-026      PUB1       = 7.5029719e-033      UC1        = 1.3121607e-010
+LUC1       = -3.8233928e-018     WUC1       = -7.2616327e-017     PUC1       = 8.68469e-024
+PRT        = 0                   AT         = 52816.746           LAT        = -0.0020146013
+WAT        = 0.019682214         PAT        = -2.1571044e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln_mlvt'
+WMIN       = '1e-006-dxwn_mlvt'       WMAX       = '1e-005-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44338471+dvthn_mlvt'
+LVTH0      = '-2.6624817e-09+dlvthn_mlvt'
+WVTH0      = '-1.6551106e-08+dwvthn_mlvt'
+PVTH0      = '1.597862e-15+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0013060071+dk2n_mlvt' LK2        = -2.1265863e-009
+WK2        = -1.5577795e-008     PK2        = 1.6404145e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0020197491
+LCIT       = '4.0216548e-10+dlcitn_mlvt'
+WCIT       = '5.152138e-10+dwcitn_mlvt'
+PCIT       = -9.614958e-17
+VOFF       = -0.16044316
+LVOFF      = '-1.8820754e-09+dlvoffn_mlvt'
+WVOFF      = '3.5572622e-08+dwvoffn_mlvt'
+PVOFF      = '-2.1280553e-15+dpvoffn_mlvt'
+NFACTOR    = '0.60878657+dnfactorn_mlvt+0.207839*ss_flag_mlvt'
+ETA0       = '-0.013762419+deta0n_mlvt+0.00706067*ff_flag_mlvt+0.0141213*ss_flag_mlvt'
+LETA0      = '1.1113958e-08+dleta0n_mlvt-6.76274e-10*ff_flag_mlvt-1.35255e-09*ss_flag_mlvt'
+WETA0      = '1.5891949e-08+dweta0n_mlvt-7.20189e-09*ff_flag_mlvt-1.44038e-08*ss_flag_mlvt'
+PETA0      = '-2.7211461e-15+dpeta0n_mlvt+6.89799e-16*ff_flag_mlvt+1.3796e-15*ss_flag_mlvt'
+ETAB       = -0.11384089
+LETAB      = 2.9069217e-09
+WETAB      = -3.5257548e-08
+PETAB      = 1.3049602e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02158597+du0n_mlvt'   LU0        = '4.5926676e-011+dlu0n_mlvt'
+WU0        = '-4.2433976e-009+dwu0n_mlvt'
+PU0        = '2.4763426e-016+dpu0n_mlvt'
+UA         = -1.4077898e-009     LUA        = 1.7900429e-017      WUA        = 1.1634777e-016
+PUA        = 5.7479051e-024
+UB         = 1.7538672e-18
+LUB        = -6.6974505e-28
+WUB        = -3.4899719e-25
+PUB        = 8.0187736e-33
+UC         = 1.3481702e-010
+LUC        = -4.744156e-018      WUC        = -1.1928716e-016     PUC        = 5.6519905e-024
+VSAT       = '90298.236+dvsatn_mlvt+72.6857*ff_flag_mlvt'
+LVSAT      = '0.00017603274+dlvsatn_mlvt-6.96186e-06*ff_flag_mlvt'
+WVSAT      = '-0.0018572123+dwvsatn_mlvt-0.000728311*ff_flag_mlvt'
+PVSAT      = '-1.6425802e-10+dpvsatn_mlvt+6.97579e-11*ff_flag_mlvt'
+A0         = 1.6696481           LA0        = '-3.2186969e-007+dla0n_mlvt'
+WA0        = -2.4506944e-006     PA0        = 2.0452483e-013      AGS        = 3.3966895
+LAGS       = 1.5356668e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.1268643
+LKETA      = 1.0974807e-008      WKETA      = -3.8117548e-008     PKETA      = 1.7909886e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.66549591
+LPCLM      = 1.8189585e-010      WPCLM      = 2.596499e-007       PPCLM      = 3.2552396e-015
+PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999
+DROUT      = 0.56                PVAG       = 1.2                 DELTA      = 0.007595625
+PSCBE1     = 1e+009              PSCBE2     = 1e-020              FPROUT     = 687.13435
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.71e-007           ALPHA1     = 2.371               BETA0      = 15.26
+AGIDL      = 1e-008              BGIDL      = 1.9e+009            CGIDL      = 0.808
+EGIDL      = 0.307               AIGBACC    = 0.01396             BIGBACC    = 0.0079101083
+CIGBACC    = 0.32874864          NIGBACC    = 23.684847           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.01141             BIGC       = 0.0015058812
+CIGC       = 0.000625            AIGSD      = 0.01089             BIGSD      = 0.0010507083
+CIGSD      = 0.069864936         NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'
+CGBO       = 0                   CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.4939              NOFF       = 2.5494              VOFFCV     = -0.1348
+TVOFF      = 0.0011047354        LTVOFF     = -3.4501315e-013     WTVOFF     = 2.41724e-010
+PTVOFF     = -2.4240255e-017     KT1        = -0.28839204         LKT1       = 1.028692e-009
+WKT1       = 7.2171788e-008      PKT1       = -5.9990272e-015     KT1L       = 0
+KT2        = -0.12701693
+LKT2       = 6.0452217e-09
+WKT2       = 3.7762002e-08
+PKT2       = -3.2025688e-15
+UTE        = -1.7723473          LUTE       = 4.7037475e-008
+WUTE       = 5.9158343e-007      PUTE       = -4.9701243e-014     UA1        = -1.7713297e-010
+LUA1       = 8.1501934e-017      WUA1       = 5.6830882e-016      PUA1       = -6.5745153e-023
+UB1        = 2.8502352e-020      LUB1       = -7.1175086e-026     WUB1       = -2.5700339e-025
+PUB1       = 3.766831e-032       UC1        = 1.4673941e-010      LUC1       = -5.3102335e-018
+WUC1       = 4.4092328e-017      PUC1       = -2.4937817e-024     PRT        = 0
+AT         = 31783.333           WAT        = -0.002839
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '1.3525474e-08+dlnfactorn_mlvt-1.99069e-08*ss_flag_mlvt'
+WNFACTOR   = '1.440377e-07+dwnfactorn_mlvt-2.11996e-07*ss_flag_mlvt'
+PNFACTOR   = '-1.3795983e-14+dpnfactorn_mlvt+2.0305e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_mlvt'
+LMAX       = 2.00001e-05         WMIN       = '6e-007-dxwn_mlvt'       WMAX       = '1e-006-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.41234586+dvthn_mlvt'  WVTH0      = '-3.4102328e-010+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.024897369+dk2n_mlvt'  WK2        = -6.0153161e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00033
+WCIT       = '9.486e-010+dwcitn_mlvt' VOFF       = -0.13118588         WVOFF      = '-1.047246e-008+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220595+du0n_mlvt'    WU0        = '-4.5849e-010+dwu0n_mlvt'
+UA         = -1.5544144e-009     WUA        = 1.3098269e-016      UB         = 2.3962278e-018
+WUB        = -1.3134316e-025     UC         = 1.369035e-010       WUC        = -5.402277e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.6356816           WA0        = -3.6279523e-007
+AGS        = 0.93377161          WAGS       = -5.5844398e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.05097            WKETA      = 1.29642e-008        DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0041275+dpdiblc2n_mlvt'
+WPDIBLC2   = -1.66005e-009       PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0015829
+LTVOFF     = 0                   WTVOFF     = -1.23318e-010       PTVOFF     = 0
+KT1        = -0.2248802          WKT1       = 1.9926924e-008      KT1L       = 0
+KT2        = -0.0734525          WKT2       = 3.39915e-009        UTE        = -1.619
+WUTE       = 2.5296e-007         UA1        = 1.155e-009          WUA1       = 1.581e-016
+UB1        = -1.12735e-018       WUB1       = -1.62843e-025       UC1        = -2e-014
+WUC1       = 3.54144e-017        PRT        = 0                   AT         = 200000
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_mlvt'
+LMAX       = '1e-005-dxln_mlvt'       WMIN       = '6e-007-dxwn_mlvt'       WMAX       = '1e-006-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40885016+dvthn_mlvt'  LVTH0      = '3.4835029e-008+dlvthn_mlvt'
+WVTH0      = '4.0341437e-010+dwvthn_mlvt'
+PVTH0      = '-7.418403e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.026722076+dk2n_mlvt'  LK2        = -1.8183407e-008
+WK2        = -6.3810858e-009     PK2        = 3.6449353e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00046259057      LCIT       = '1.3212796e-009+dlcitn_mlvt'
+WCIT       = '1.0374547e-009+dwcitn_mlvt'
+PCIT       = -8.8544672e-016     VOFF       = -0.12858922         LVOFF      = '-2.5875987e-008+dlvoffn_mlvt'
+WVOFF      = '-1.1952669e-008+dwvoffn_mlvt'
+PVOFF      = '1.4750443e-014+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.021971943+du0n_mlvt'  LU0        = '8.7251438e-010+dlu0n_mlvt'
+WU0        = '-3.5168128e-010+dwu0n_mlvt'
+PU0        = '-1.0643607e-015+dpu0n_mlvt'
+UA         = -1.5717657e-009     LUA        = 1.7290734e-016      WUA        = 1.3682375e-016
+PUA        = -5.8206845e-023     UB         = 2.4217449e-018      LUB        = -2.542805e-025
+WUB        = -1.3512724e-025     PUB        = 3.7708778e-032      UC         = 1.4062234e-010
+LUC        = -3.7058619e-017     WUC        = -5.5190885e-017     PUC        = 1.1640389e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.5755871           LA0        = '5.9884843e-007+dla0n_mlvt'
+WA0        = -2.9268715e-007     PA0        = -6.9863474e-013     AGS        = 0.87470677
+LAGS       = 5.8858761e-007      WAGS       = -4.1730422e-008     PAGS       = -1.4064732e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.050917348        LKETA      = -5.2468409e-010
+WKETA      = 1.3808498e-008      PKETA      = -8.4135178e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.003974959+dpdiblc2n_mlvt'
+LPDIBLC2   = 1.5200878e-009      WPDIBLC2   = -1.6685269e-009     PPDIBLC2   = 8.447307e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016380078        LTVOFF     = -5.491551e-010
+WTVOFF     = -1.3654194e-010     PTVOFF     = 1.3177799e-016      KT1        = -0.22424568
+LKT1       = -6.3230738e-009     WKT1       = 2.2469514e-008      PKT1       = -2.5337191e-014
+KT1L       = 0                   KT2        = -0.074820758        LKT2       = 1.363484e-008
+WKT2       = 4.024744e-009       PKT2       = -6.2341126e-015     UTE        = -1.6586596
+LUTE       = 3.9521215e-007      WUTE       = 2.8903761e-007      PUTE       = -3.5951739e-013
+UA1        = 1.1037098e-009      LUA1       = 5.1111283e-016      WUA1       = 2.2354154e-016
+PUA1       = -6.521321e-022      UB1        = -1.0463944e-018     LUB1       = -8.0673118e-025
+WUB1       = -2.2977647e-025     PUB1       = 6.6699936e-031      UC1        = -1.9453945e-012
+LUC1       = 1.9186768e-017      WUC1       = 3.644858e-017       PUC1       = -1.0305715e-023
+PRT        = 0                   AT         = 200798.9            LAT        = -0.0079610926
+WAT        = 0.00016953766       PAT        = -1.6894614e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_mlvt'
+LMAX       = '1.000002e-006-dxln_mlvt'
+WMIN       = '6e-007-dxwn_mlvt'       WMAX       = '1e-006-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44786427+dvthn_mlvt'  LVTH0      = '-2.817881e-009+dlvthn_mlvt'
+WVTH0      = '-8.3987589e-009+dwvthn_mlvt'
+PVTH0      = '1.0766624e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.014852277+dk2n_mlvt'  LK2        = -6.7277449e-009
+WK2        = -4.8792964e-009     PK2        = 2.1955433e-015      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.00094891812       LCIT       = '-4.0981585e-011+dlcitn_mlvt'
+WCIT       = '5.3747588e-011+dwcitn_mlvt'
+PCIT       = 6.3938839e-017      VOFF       = -0.15657613         LVOFF      = '1.1344586e-009+dlvoffn_mlvt'
+WVOFF      = '8.2730227e-009+dwvoffn_mlvt'
+PVOFF      = '-4.7695748e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.06074615+deta0n_mlvt' WETA0      = '2.0658927e-008+dweta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0220162+du0n_mlvt'    LU0        = '8.2980161e-010+dlu0n_mlvt'
+WU0        = '-3.7878026e-010+dwu0n_mlvt'
+PU0        = '-1.0382072e-015+dpu0n_mlvt'
+UA         = -1.5168324e-009     LUA        = 1.1989066e-016      WUA        = 1.5445249e-016
+PUA        = -7.5220517e-023     UB         = 2.285951e-018       LUB        = -1.2322447e-025
+WUB        = -1.1350885e-025     PUB        = 1.6844661e-032      UC         = 1.0610996e-010
+LUC        = -3.750375e-018      WUC        = -4.420053e-017      PUC        = 1.0334881e-024
+VSAT       = '112500.53+dvsatn_mlvt'  LVSAT      = '-0.0024132899+dlvsatn_mlvt'
+WVSAT      = '-0.00034228083+dwvsatn_mlvt'
+PVSAT      = '3.3033865e-010+dpvsatn_mlvt'
+A0         = 4.506443            LA0        = '-1.26464e-006+dla0n_mlvt'
+WA0        = -1.6097986e-006     PA0        = 5.7252272e-013      AGS        = -0.80346274
+LAGS       = 2.2082058e-006      WAGS       = 1.2948229e-006      PAGS       = -1.4305683e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055175769        LKETA      = 3.5851609e-009
+WKETA      = 9.5991475e-009      PKETA      = -4.3510319e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.034065            WPCLM      = 3.062397e-007
+PDIBLC1    = 0                   PDIBLC2    = '0.0069572267+dpdiblc2n_mlvt'
+LPDIBLC2   = -1.3581285e-009     WPDIBLC2   = -2.0699726e-009     PPDIBLC2   = 4.7191236e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0010163914        LTVOFF     = 5.0773113e-011
+WTVOFF     = 4.9875206e-011      PTVOFF     = -4.813506e-017      KT1        = -0.22821446
+LKT1       = -2.4927658e-009     WKT1       = -2.4053332e-009     PKT1       = -1.3302266e-015
+KT1L       = 0                   KT2        = -0.057541276        LKT2       = -3.0417602e-009
+WKT2       = -6.0091298e-009     PKT2       = 3.4496793e-015      UTE        = -1.265572
+LUTE       = 1.5839361e-008      WUTE       = -1.4689655e-007     PUTE       = 6.1207033e-014
+UA1        = 1.9047865e-009      LUA1       = -2.6201434e-016     WUA1       = -6.8491696e-016
+PUA1       = 2.2463028e-022      UB1        = -2.1825365e-018     LUB1       = 2.897709e-025
+WUB1       = 6.3824609e-025      PUB1       = -1.7073789e-031     UC1        = 2.4369497e-012
+LUC1       = 1.4957323e-017      WUC1       = 2.9779875e-017      PUC1       = -3.8696813e-024
+PRT        = 0                   AT         = 224902.3            LAT        = -0.031223524
+WAT        = 0.0086385276        PAT        = -9.8629682e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln_mlvt'
+LMAX       = '2.399959e-007-dxln_mlvt'
+WMIN       = '6e-007-dxwn_mlvt'       WMAX       = '1e-006-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44622988+dvthn_mlvt'  LVTH0      = '-2.4452732e-009+dlvthn_mlvt'
+WVTH0      = '-2.656096e-009+dwvthn_mlvt'
+PVTH0      = '-2.3254991e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0077298678+dk2n_mlvt'
+LK2        = -1.5794676e-009     WK2        = 4.6149392e-009      PK2        = 3.1047474e-017
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00025982624
+LCIT       = '1.1611758e-010+dlcitn_mlvt'
+WCIT       = '4.0796102e-010+dwcitn_mlvt'
+PCIT       = -1.681474e-017      VOFF       = -0.14572369         LVOFF      = '-1.339682e-009+dlvoffn_mlvt'
+WVOFF      = '-1.6424805e-008+dwvoffn_mlvt'
+PVOFF      = '8.6103596e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.044118879+deta0n_mlvt'
+LETA0      = '3.7906852e-009+dleta0n_mlvt'
+WETA0      = '3.0967637e-008+dweta0n_mlvt'
+PETA0      = '-2.3501797e-015+dpeta0n_mlvt'
+ETAB       = -0.1140465          WETAB      = 9.53343e-009        UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.028615308+du0n_mlvt'  LU0        = '-6.7466293e-010+dlu0n_mlvt'
+WU0        = '-7.6703892e-009+dwu0n_mlvt'
+PU0        = '6.2413382e-016+dpu0n_mlvt'
+UA         = -9.0918776e-010     LUA        = -1.8640155e-017     WUA        = -3.4387484e-016
+PUA        = 3.8388147e-023      UB         = 1.8834271e-018      LUB        = -3.1457077e-026
+WUB        = -1.7928862e-026     PUB        = -4.9456651e-033     UC         = 1.3529638e-010
+LUC        = -1.0404295e-017     WUC        = -6.8051994e-017     PUC        = 6.4711448e-024
+VSAT       = '106599.68+dvsatn_mlvt'  LVSAT      = '-0.0010680136+dlvsatn_mlvt'
+WVSAT      = '0.0069449685+dwvsatn_mlvt'
+PVSAT      = '-1.3310085e-009+dpvsatn_mlvt'
+A0         = 2.0693451           LA0        = '-7.0903035e-007+dla0n_mlvt'
+WA0        = -9.0869732e-007     PA0        = 4.1268564e-013      AGS        = 9.449438
+LAGS       = -1.2925052e-007     WAGS       = -6.2974385e-006     PAGS       = 3.0031544e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.072606996        LKETA      = 7.5591319e-009
+WKETA      = 1.145316e-008       PKETA      = -4.7737097e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.5754936          LPCLM      = 1.3896717e-007
+WPCLM      = 4.6908266e-007      PPCLM      = -3.7124937e-014     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012033811
+LTVOFF     = 8.1431956e-012      WTVOFF     = -1.3147983e-010     PTVOFF     = -6.7897403e-018
+KT1        = -0.23251459         LKT1       = -1.512421e-009      WKT1       = 5.6618813e-010
+PKT1       = -2.007674e-015      KT1L       = 0                   KT2        = -0.076091779
+LKT2       = 1.1873834e-009      WKT2       = 1.2750606e-008      PKT2       = -8.2716534e-016
+UTE        = -1.1983736          LUTE       = 5.1947972e-010      WUTE       = 2.2226556e-007
+PUTE       = -2.2954545e-014     UA1        = 9.8057256e-010      LUA1       = -5.1312043e-017
+WUA1       = 4.3440979e-016      PUA1       = -3.0553831e-023     UB1        = -1.3227746e-018
+LUB1       = 9.3762373e-026      WUB1       = -1.5596133e-026     PUB1       = -2.167494e-032
+UC1        = -3.2938788e-011     LUC1       = 2.3022284e-017      WUC1       = 9.4821629e-017
+PUC1       = -1.86979e-023       PRT        = 0                   AT         = 126159.88
+LAT        = -0.0087122282       WAT        = -0.055127782        PAT        = 4.6744751e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln_mlvt'
+WMIN       = '6e-007-dxwn_mlvt'       WMAX       = '1e-006-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44977917+dvthn_mlvt-0.00994084*ff_flag_mlvt'
+LVTH0      = '-2.7852085e-09+dlvthn_mlvt+9.52137e-10*ff_flag_mlvt'
+WVTH0      = '-2.3073464e-08+dwvthn_mlvt+1.01397e-08*ff_flag_mlvt'
+PVTH0      = '1.7230434e-15+dpvthn_mlvt-9.7118e-16*ff_flag_mlvt'
+K1         = 0.31994             K2         = '-0.014947392+dk2n_mlvt' LK2        = -8.8816592e-010
+WK2        = 1.0006715e-009      PK2        = 3.7722565e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.0010994598       LCIT       = '2.4631136e-010+dlcitn_mlvt'
+WCIT       = '-4.2348127e-010+dwcitn_mlvt'
+PCIT       = 6.2821635e-017
+VOFF       = -0.11890298
+LVOFF      = '-3.9086059e-09+dlvoffn_mlvt'
+WVOFF      = '-6.798364e-09+dwvoffn_mlvt'
+PVOFF      = '-6.09942e-17+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt+0.745563*ff_flag_mlvt-0.745563*ss_flag_mlvt'
+ETA0       = '-0.051871703+deta0n_mlvt+0.0294899*ff_flag_mlvt-0.0393199*ss_flag_mlvt'
+LETA0      = '1.2984759e-008+dleta0n_mlvt-2.82456e-09*ff_flag_mlvt+3.76608e-09*ss_flag_mlvt'
+WETA0      = '5.4763418e-008+dweta0n_mlvt-3.00797e-08*ff_flag_mlvt+4.01063e-08*ss_flag_mlvt'
+PETA0      = '-4.6293634e-015+dpeta0n_mlvt+2.88105e-15*ff_flag_mlvt-3.8414e-15*ss_flag_mlvt'
+ETAB       = -0.18617972
+LETAB      = 6.908976e-09
+WETAB      = 3.8528064e-08
+PETAB      = -2.7771351e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020073206+du0n_mlvt'  LU0        = '1.4350807e-010+dlu0n_mlvt'
+WU0        = '-2.7003787e-009+dwu0n_mlvt'
+PU0        = '1.4810125e-016+dpu0n_mlvt'
+UA         = -6.9856808e-010     LUA        = -3.8813519e-017     WUA        = -6.0705839e-016
+PUA        = 6.3596131e-023
+UB         = 6.5255326e-19
+LUB        = 8.6437068e-26
+WUB        = 7.7434308e-25
+PUB        = -8.0830175e-32
+UC         = -7.2475337e-012
+LUC        = 3.2487032e-018      WUC        = 2.5618679e-017      PUC        = -2.5007259e-024
+VSAT       = '98188.197+dvsatn_mlvt-5278.06*ff_flag_mlvt+3931.99*ss_flag_mlvt'
+LVSAT      = '-0.00026235326+dlvsatn_mlvt+0.000505535*ff_flag_mlvt-0.000376608*ss_flag_mlvt'
+WVSAT      = '-0.0099049722+dwvsatn_mlvt+0.00472945*ff_flag_mlvt-0.00401063*ss_flag_mlvt'
+PVSAT      = '2.8289571e-010+dpvsatn_mlvt-4.52989e-10*ff_flag_mlvt+3.8414e-10*ss_flag_mlvt'
+A0         = -8.937762           LA0        = '3.4524137e-007+dla0n_mlvt'
+WA0        = 8.3688639e-006      PA0        = -4.7592845e-013     AGS        = 6.4966895
+LAGS       = 1.5356668e-007      WAGS       = -3.162e-006         PAGS       = -1.6753592e-027
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.063751471        LKETA      = 6.7109408e-009
+WKETA      = -1.0249263e-007     PKETA      = 6.1401319e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1.151367            LPCLM      = -2.6433266e-008
+WPCLM      = -2.359386e-007      PPCLM      = 3.0402704e-014      PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0026410329
+LTVOFF     = -1.2955653e-010     WTVOFF     = -1.3252994e-009     PTVOFF     = 1.0755549e-016
+KT1        = -0.098431959        LKT1       = -1.435499e-008      WKT1       = -1.215875e-007
+PKT1       = 9.6923282e-015      KT1L       = 0
+KT2        = -0.080271035
+LKT2       = 1.5876912e-09
+WKT2       = -9.918812e-09
+PKT2       = 1.3441123e-15
+UTE        = -1.8040518          LUTE       = 5.8531941e-008      WUTE       = 6.2392198e-007
+PUTE       = -6.1425598e-014     UA1        = -2.5114942e-009     LUA1       = 2.8316161e-016
+WUA1       = 2.9493573e-015      PUA1       = -2.7143802e-022     UB1        = 2.4252596e-018
+LUB1       = -2.6522809e-025     WUB1       = -2.7016958e-024     PUB1       = 2.3560237e-031
+UC1        = 5.2895289e-010      LUC1       = -3.0796263e-017     WUC1       = -3.4576542e-016
+PUC1       = 2.3501968e-023      PRT        = 0                   AT         = 35200
+WAT        = -0.006324
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07            JSWS       = 4.17e-13
+JSWD       = 4.17e-13            JSWGS      = 4.17e-13            JSWGD      = 4.17e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.1                   BVD        = 9.1                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005
+MJSWD      = 0.005               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 0.002               TCJ        = 0.0007
+TPBSW      = 0.0004              TCJSW      = 0.0005              TPBSWG     = 2.4e-05
+TCJSWG     = 0.0015              XTIS       = 3                   XTID       = 3
+JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573
+VTSSWGS    = 3.593               VTSSWGD    = 3.593               DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt-7.14103e-08*ff_flag_mlvt+7.14103e-08*ss_flag_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt-7.60474e-07*ff_flag_mlvt+7.60474e-07*ss_flag_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt+7.28385e-14*ff_flag_mlvt-7.28385e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_mlvt'
+LMAX       = 2.00001e-05         WMIN       = '3e-007-dxwn_mlvt'       WMAX       = '6e-007-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.4276847+dvthn_mlvt'   WVTH0      = '-9.851103e-009+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.016999242+dk2n_mlvt'  WK2        = -1.1184774e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00184
+WCIT       = '-3.968e-010+dwcitn_mlvt'
+VOFF       = -0.15391902         WVOFF      = '3.6220876e-009+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022642667+du0n_mlvt'  WU0        = '-8.2005333e-010+dwu0n_mlvt'
+UA         = -1.3081355e-009     WUA        = -2.1710251e-017     UB         = 2.1698603e-018
+WUB        = 9.0047147e-027      UC         = 7.1487333e-011      WUC        = -1.3464747e-017
+VSAT       = '110000+dvsatn_mlvt'     A0         = 1.7876245           WA0        = 1.6300015e-007
+AGS        = 0.82793509          WAGS       = 9.7742421e-009      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.024641333        WKETA      = -3.3595733e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.00032208424+dpdiblc2n_mlvt'
+WPDIBLC2   = 6.9930778e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0012677333
+LTVOFF     = 0                   WTVOFF     = 7.2085333e-011      PTVOFF     = 0
+KT1        = -0.20249189         WKT1       = 6.0461739e-009      KT1L       = 0
+KT2        = -0.070540667        WKT2       = 1.5938133e-009      UTE        = -1.3784667
+WUTE       = 1.0382933e-007      UA1        = 1.282e-009          WUA1       = 7.936e-017
+UB1        = -1.3882293e-018     WUB1       = -1.0978133e-027     UC1        = 5.4326667e-011
+WUC1       = 1.7194667e-018      PRT        = 0                   AT         = 200000
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_mlvt'
+LMAX       = '1e-005-dxln_mlvt'       WMIN       = '3e-007-dxwn_mlvt'       WMAX       = '6e-007-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.42605581+dvthn_mlvt'  LVTH0      = '1.6232044e-008+dlvthn_mlvt'
+WVTH0      = '-1.0264089e-008+dwvthn_mlvt'
+PVTH0      = '4.1154478e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.018007345+dk2n_mlvt'  LK2        = -1.0045864e-008
+WK2        = -9.7795291e-010     PK2        = -1.4003415e-015     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0018878992        LCIT       = '-4.7732075e-010+dlcitn_mlvt'
+WCIT       = '-4.1984897e-010+dwcitn_mlvt'
+PCIT       = 2.2968548e-016      VOFF       = -0.15467558         LVOFF      = '7.5391143e-009+dlvoffn_mlvt'
+WVOFF      = '4.2208688e-009+dwvoffn_mlvt'
+PVOFF      = '-5.9669201e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02272967+du0n_mlvt'   LU0        = '-8.6699326e-010+dlu0n_mlvt'
+WU0        = '-8.2147169e-010+dwu0n_mlvt'
+PU0        = '1.4134056e-017+dpu0n_mlvt'
+UA         = -1.314581e-009      LUA        = 6.423085e-017       WUA        = -2.263072e-017
+PUA        = 9.1725784e-024      UB         = 2.1840169e-018      LUB        = -1.410727e-025
+WUB        = 1.2264093e-026      PUB        = -3.2480061e-032     UC         = 7.141683e-011
+LUC        = 7.0257088e-019      WUC        = -1.228347e-017      PUC        = -1.1771549e-023
+VSAT       = '110000+dvsatn_mlvt'     A0         = 1.8035366           LA0        = '-1.5856545e-007+dla0n_mlvt'
+WA0        = 1.8598415e-007      PA0        = -2.2903814e-013     AGS        = 0.77479681
+LAGS       = 5.2952879e-007      WAGS       = 2.0213751e-008      PAGS       = -1.0403086e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022723624        LKETA      = -1.9110184e-008
+WKETA      = -3.6716113e-009     PKETA      = 3.1094924e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '9.2111129e-005+dpdiblc2n_mlvt'
+LPDIBLC2   = 2.2917073e-009      WPDIBLC2   = 7.388388e-010       PPDIBLC2   = -3.9393101e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0013017628        LTVOFF     = -3.3910735e-010
+WTVOFF     = 7.1929953e-011      PTVOFF     = 1.5483859e-018      KT1        = -0.20000319
+LKT1       = -2.4800253e-008     WKT1       = 7.4391679e-009      PKT1       = -1.3881339e-014
+KT1L       = 0                   KT2        = -0.07226453         LKT2       = 1.7178492e-008
+WKT2       = 2.4398829e-009      PKT2       = -8.4311765e-015     UTE        = -1.3598451
+LUTE       = -1.8556648e-007     WUTE       = 1.037726e-007       PUTE       = 5.6536225e-016
+UA1        = 1.3460976e-009      LUA1       = -6.3873965e-016     WUA1       = 7.3261077e-017
+PUA1       = 6.0776441e-023      UB1        = -1.4247522e-018     LUB1       = 3.639548e-025
+WUB1       = 4.8053771e-027      PUB1       = -5.8825942e-032     UC1        = 8.1281117e-011
+LUC1       = -2.6860406e-016     WUC1       = -1.5151857e-017     PUC1       = 1.681246e-022
+PRT        = 0                   AT         = 202216.18           LAT        = -0.022084463
+WAT        = -0.00070917713      PAT        = 7.0670281e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'
+LVSAT      = '0+dlvsatn_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_mlvt'
+LMAX       = '1.000002e-006-dxln_mlvt'
+WMIN       = '3e-007-dxwn_mlvt'       WMAX       = '6e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44379242+dvthn_mlvt'  LVTH0      = '-8.8573346e-010+dlvthn_mlvt'
+WVTH0      = '-5.8742089e-009+dwvthn_mlvt'
+PVTH0      = '-1.2126911e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.011976931+dk2n_mlvt'  LK2        = -4.2258503e-009
+WK2        = -3.096582e-009      PK2        = 6.4436865e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0011530249        LCIT       = '2.3191383e-010+dlcitn_mlvt'
+WCIT       = '-7.279858e-011+dwcitn_mlvt'
+PCIT       = -1.0525632e-016     VOFF       = -0.13612071         LVOFF      = '-1.0368368e-008+dlvoffn_mlvt'
+WVOFF      = '-4.4093367e-009+dwvoffn_mlvt'
+PVOFF      = '2.3621775e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.10373847+deta0n_mlvt' WETA0      = '-5.9963093e-009+dweta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02296062+du0n_mlvt'   LU0        = '-1.0898857e-009+dlu0n_mlvt'
+WU0        = '-9.6432059e-010+dwu0n_mlvt'
+PU0        = '1.5199896e-016+dpu0n_mlvt'
+UA         = -1.2231707e-009     LUA        = -2.3990174e-017     WUA        = -2.7617741e-017
+PUA        = 1.3985602e-023      UB         = 2.1388512e-018      LUB        = -9.748279e-026
+WUB        = -2.230697e-026      PUB        = 8.8481753e-034      UC         = 7.9956073e-011
+LUC        = -7.5387377e-018     WUC        = -2.7985123e-017     PUC        = 3.382273e-024
+VSAT       = '114026.83+dvsatn_mlvt'  LVSAT      = '-0.0038863371+dlvsatn_mlvt'
+WVSAT      = '-0.0012885866+dwvsatn_mlvt'
+PVSAT      = '1.2436279e-009+dpvsatn_mlvt'
+A0         = 2.1012026           LA0        = '-4.4584588e-007+dla0n_mlvt'
+WA0        = -1.1854956e-007     PA0        = 6.4870393e-014      AGS        = 1.8492877
+LAGS       = -5.0747307e-007     WAGS       = -3.4988232e-007     PAGS       = 2.5315256e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.036180291        LKETA      = -6.1230205e-009
+WKETA      = -2.1780491e-009     PKETA      = 1.6680405e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.61717333          WPCLM      = -5.5287467e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0029202782+dpdiblc2n_mlvt'
+LPDIBLC2   = -4.3778502e-010     WPDIBLC2   = 4.3293545e-010      PPDIBLC2   = -9.8700623e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.00097124062       LTVOFF     = -2.0117097e-011
+WTVOFF     = 7.786867e-011       PTVOFF     = -4.1831298e-018     KT1        = -0.20791948
+LKT1       = -1.7160154e-008     WKT1       = -1.4988217e-008     PKT1       = 7.7635542e-015
+KT1L       = 0                   KT2        = -0.05401687         LKT2       = -4.3250772e-010
+WKT2       = -8.1942617e-009     PKT2       = 1.8319428e-015      UTE        = -1.7274986
+LUTE       = 1.6925963e-007      WUTE       = 1.3949795e-007      PUTE       = -3.3913534e-014
+UA1        = 3.3391362e-010      LUA1       = 3.3812923e-016      WUA1       = 2.8902423e-016
+PUA1       = -1.4745873e-022     UB1        = -8.5309426e-019     LUB1       = -1.8775804e-025
+WUB1       = -1.860081e-025      PUB1       = 1.2533005e-031      UC1        = -2.9157422e-010
+LUC1       = 9.1242359e-017      WUC1       = 2.120668e-016       PUC1       = -5.1166403e-023
+PRT        = 0                   AT         = 224176.96           LAT        = -0.043279029
+WAT        = 0.0090882378        PAT        = -2.3885551e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln_mlvt'
+LMAX       = '2.399959e-007-dxln_mlvt'
+WMIN       = '3e-007-dxwn_mlvt'       WMAX       = '6e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45421094+dvthn_mlvt'  LVTH0      = '-3.2609491e-009+dlvthn_mlvt'
+WVTH0      = '-7.6043531e-009+dwvthn_mlvt'
+PVTH0      = '2.7316917e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0033553434+dk2n_mlvt' LK2        = -2.2603008e-009
+WK2        = -2.2578918e-009     PK2        = 4.5316404e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = 0.0024283835        LCIT       = '-5.8842434e-011+dlcitn_mlvt'
+WCIT       = '-9.3654447e-010+dwcitn_mlvt'
+PCIT       = 9.166047e-017       VOFF       = -0.18990686         LVOFF      = '1.8937985e-009+dlvoffn_mlvt'
+WVOFF      = '1.0968765e-008+dwvoffn_mlvt'
+PVOFF      = '-1.143722e-015+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.10296523+deta0n_mlvt'
+LETA0      = '1.762797e-10+dleta0n_mlvt'
+WETA0      = '-5.5171e-09+dweta0n_mlvt'
+PETA0      = '-1.092484e-16+dpeta0n_mlvt'
+ETAB       = -0.081678           WETAB      = -1.053504e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014783927+du0n_mlvt'  LU0        = '7.7423676e-010+dlu0n_mlvt'
+WU0        = '9.0506683e-010+dwu0n_mlvt'
+PU0        = '-2.7418398e-016+dpu0n_mlvt'
+UA         = -1.660424e-009      LUA        = 7.569483e-017       WUA        = 1.2189162e-016
+PUA        = -2.0099543e-023     UB         = 1.8854943e-018      LUB        = -3.9722495e-026
+WUB        = -1.9210541e-026     PUB        = 1.7889358e-034      UC         = 5.728725e-011
+LUC        = -2.3706995e-018     WUC        = -1.9686336e-017     PUC        = 1.4903156e-024
+VSAT       = '108347.65+dvsatn_mlvt'  LVSAT      = '-0.0025915958+dlvsatn_mlvt'
+WVSAT      = '0.0058612307+dwvsatn_mlvt'
+PVSAT      = '-3.863875e-010+dpvsatn_mlvt'
+A0         = -0.98300577         LA0        = '2.5729195e-007+dla0n_mlvt'
+WA0        = 9.8376019e-007      PA0        = -1.8643419e-013     AGS        = -2.8231338
+LAGS       = 5.5774558e-007      WAGS       = 1.311556e-006       PAGS       = -1.2562214e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041656409        LKETA      = -4.8745752e-009
+WKETA      = -7.736204e-009      PKETA      = 2.9351887e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.22629814          LPCLM      = 8.9111726e-008
+WPCLM      = -2.8028223e-008     PPCLM      = -6.2145624e-015     PDIBLC1    = 0
+PDIBLC2    = '0.001+dpdiblc2n_mlvt'   PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.00094709599
+LTVOFF     = -1.4612604e-011     WTVOFF     = 2.7416941e-011      PTVOFF     = 7.3188553e-018
+KT1        = -0.277058           LKT1       = -1.397956e-009      WKT1       = 2.8183098e-008
+PKT1       = -2.0786423e-015     KT1L       = 0                   KT2        = -0.046538569
+LKT2       = -2.1374107e-009     WKT2       = -5.5723834e-009     PKT2       = 1.234207e-015
+UTE        = -0.65956337         LUTE       = -7.4208242e-008     WUTE       = -1.1179679e-007
+PUTE       = 2.3376642e-014      UA1        = 2.5612467e-009      LUA1       = -1.6965817e-016
+WUA1       = -5.4560818e-016     PUA1       = 4.2820766e-023      UB1        = -2.0582479e-018
+LUB1       = 8.6992894e-026      WUB1       = 4.4039735e-025      PUB1       = -1.7477864e-032
+UC1        = 1.6622197e-010      LUC1       = -1.3126016e-017     WUC1       = -2.8658038e-017
+PUC1       = 3.714046e-024       PRT        = 0                   AT         = 44971.144
+LAT        = -0.0024236881       WAT        = -0.0047907659       PAT        = 7.7558019e-010
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln_mlvt'
+WMIN       = '3e-007-dxwn_mlvt'       WMAX       = '6e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.44820506+dvthn_mlvt+0.0132545*ff_flag_mlvt'
+LVTH0      = '-2.685683e-09+dlvthn_mlvt-1.26952e-09*ff_flag_mlvt'
+WVTH0      = '-2.2097514e-08+dwvthn_mlvt-4.24143e-09*ff_flag_mlvt'
+PVTH0      = '1.6613375e-15+dpvthn_mlvt+4.06245e-16*ff_flag_mlvt'
+K1         = 0.31994             K2         = '-0.013299183+dk2n_mlvt' LK2        = -6.6511353e-010
+WK2        = -2.1217758e-011     PK2        = 2.3893317e-016      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -0.0036006898
+LCIT       = '5.1862823e-10+dlcitn_mlvt'
+WCIT       = '1.1272813e-09+dwcitn_mlvt'
+PCIT       = -1.0601483e-16
+VOFF       = -0.15236504
+LVOFF      = '-1.7020255e-09+dlvoffn_mlvt'
+WVOFF      = '1.3948109e-08+dwvoffn_mlvt'
+PVOFF      = '-1.4290741e-15+dpvoffn_mlvt'
+NFACTOR    = '0.88529431+dnfactorn_mlvt-0.823059*ff_flag_mlvt+0.652034*ss_flag_mlvt'
+ETA0       = '-0.019083082+deta0n_mlvt-0.0325552*ff_flag_mlvt+0.0524265*ss_flag_mlvt'
+LETA0      = '1.1866207e-08+dleta0n_mlvt+3.11815e-09*ff_flag_mlvt-5.02143e-09*ss_flag_mlvt'
+WETA0      = '3.4434473e-08+dweta0n_mlvt+8.38828e-09*ff_flag_mlvt-1.67765e-08*ss_flag_mlvt'
+PETA0      = '-3.9358612e-15+dpeta0n_mlvt-8.03425e-16*ff_flag_mlvt+1.60686e-15*ss_flag_mlvt'
+ETAB       = -0.076373459
+LETAB      = -5.080909e-10
+WETAB      = -2.9551821e-08
+PETAB      = 1.8214463e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.024170983+du0n_mlvt'
+LU0        = '-1.2486354e-10+dlu0n_mlvt'
+WU0        = '-5.2410001e-09+dwu0n_mlvt'
+PU0        = '3.1449164e-16+dpu0n_mlvt'
+UA         = -8.2122219e-010     LUA        = -4.684758e-018      WUA        = -5.3101284e-016
+PUA        = 4.24363e-023
+UB         = 1.6379302e-18
+LUB        = -1.6010509e-26
+WUB        = 1.6340937e-25
+PUB        = -1.7312678e-32
+UC         = -1.4219741e-011
+LUC        = 4.4783116e-018      WUC        = 2.9941448e-017      PUC        = -3.2630832e-024
+VSAT       = '73723.342+dvsatn_mlvt+4856.85*ff_flag_mlvt-5242.65*ss_flag_mlvt'
+LVSAT      = '0.00072475242+dlvsatn_mlvt-0.00046519*ff_flag_mlvt+0.000502143*ss_flag_mlvt'
+WVSAT      = '0.0052632379+dwvsatn_mlvt-0.00155419*ff_flag_mlvt+0.00167765*ss_flag_mlvt'
+PVSAT      = '-3.291098e-10+dpvsatn_mlvt+1.48861e-10*ff_flag_mlvt-1.60686e-10*ss_flag_mlvt'
+A0         = 4.0145518
+LA0        = '-2.2138171e-07+dla0n_mlvt'
+WA0        = 3.384293e-07
+PA0        = -1.2462214e-13
+AGS        = 2.7496326
+Pags     = 8.0342933e-14
+Wags     = -8.388247e-07
+LAGS       = 2.39813e-08
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.36913643
+LKETA      = 2.6491789e-008      WKETA      = 8.6846044e-008      PKETA      = -6.1239936e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 1.2610378
+LPCLM      = -9.9966741e-009     WPCLM      = -3.0393451e-007     PPCLM      = 2.0212018e-014
+PDIBLC1    = 0                   PDIBLC2    = '0.0013591416+dpdiblc2n_mlvt'
+LPDIBLC2   = -3.4398937e-011     WPDIBLC2   = -2.2266776e-010     PPDIBLC2   = 2.1327341e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = -0.00086115198      LTVOFF     = 1.585832e-010
+WTVOFF     = 8.4605521e-010      PTVOFF     = -7.1091137e-017     KT1        = -0.34419326
+LKT1       = 5.032327e-009       WKT1       = 3.0784511e-008      PKT1       = -2.3278082e-015
+KT1L       = 0
+KT2        = -0.13839521
+LKT2       = 6.6606766e-09
+WKT2       = 2.6118178e-08
+PKT2       = -1.8011386e-15
+UTE        = -0.52365297
+LUTE       = -8.7225876e-008     WUTE       = -1.699253e-007      PUTE       = 2.8944249e-014
+UA1        = 4.9577924e-009      LUA1       = -3.9920171e-016     WUA1       = -1.6816004e-015
+PUA1       = 1.5162724e-022      UB1        = -5.0063038e-018     LUB1       = 3.6936063e-025
+WUB1       = 1.9058735e-024      PUB1       = -1.5784264e-031     UC1        = -2.9832515e-011
+LUC1       = 5.6522777e-018      WUC1       = 6.8152816e-019      PUC1       = 9.0387302e-025
+PRT        = 0                   AT         = 19666.667           WAT        = 0.0033066667
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '-1.2958538e-08+dlnfactorn_mlvt+7.88328e-08*ff_flag_mlvt-6.2452e-08*ss_flag_mlvt'
+WNFACTOR   = '-8.388247e-08+dwnfactorn_mlvt+2.12071e-07*ff_flag_mlvt-1.06036e-07*ss_flag_mlvt'
+PNFACTOR   = '8.0342933e-15+dpnfactorn_mlvt-2.03123e-14*ff_flag_mlvt+1.01561e-14*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_mlvt'
+LMAX       = 2.00001e-05         WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.40171155+dvthn_mlvt'  WVTH0      = '-1.5396969e-009+dwvthn_mlvt'
+K1         = 0.31994             K2         = '0.0081248889+dk2n_mlvt' WK2        = 1.7213156e-009
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0001
+WCIT       = '2.24e-010+dwcitn_mlvt'  VOFF       = -0.14674927         WVOFF      = '1.3277655e-009+dwvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019737031+du0n_mlvt'  WU0        = '1.0975004e-010+dwu0n_mlvt'
+UA         = -1.3876311e-009     WUA        = 3.7283556e-018      UB         = 2.1326667e-018
+WUB        = 2.0906667e-026      UC         = 3.6184444e-011      WUC        = -2.1678222e-018
+VSAT       = '110000+dvsatn_mlvt'     A0         = 2.4502222           WA0        = -4.9031111e-008
+AGS        = 0.79150093          WAGS       = 2.1433174e-008      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.019631111        WKETA      = -4.9628444e-009     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0021243041+dpdiblc2n_mlvt'
+WPDIBLC2   = 1.2259743e-010      PDIBLCB    = 0.059999999         DROUT      = 0.56
+PVAG       = 1.2                 DELTA      = 0.007595625         PSCBE1     = 1e+009
+PSCBE2     = 1e-020              FPROUT     = 687.13435           PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_mlvt'         RDW        = '65+drdswn_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 4.71e-007
+ALPHA1     = 2.371               BETA0      = 15.26               AGIDL      = 1e-008
+BGIDL      = 1.9e+009            CGIDL      = 0.808               EGIDL      = 0.307
+AIGBACC    = 0.01396             BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864
+NIGBACC    = 23.684847           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.01141             BIGC       = 0.0015058812        CIGC       = 0.000625
+AIGSD      = 0.01089             BIGSD      = 0.0010507083        CIGSD      = 0.069864936
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.565
+NTOX       = 'ntoxn_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_mlvt'              CGDO       = 'cgon_mlvt'              CGBO       = 0
+CGDL       = 'cgln_mlvt'              CGSL       = 'cgln_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5.4939
+NOFF       = 2.5494              VOFFCV     = -0.1348             TVOFF      = 0.0016550111
+LTVOFF     = 0                   WTVOFF     = -5.1843556e-011     PTVOFF     = 0
+KT1        = -0.17096587         WKT1       = -4.0421547e-009     KT1L       = 0
+KT2        = -0.074963333        WKT2       = 3.0090667e-009      UTE        = -0.94635556
+WUTE       = -3.4446222e-008     UA1        = 1.6e-009            WUA1       = -2.24e-017
+UB1        = -1.3369511e-018     WUB1       = -1.7506844e-026     UC1        = 7.9455556e-011
+WUC1       = -6.3217778e-018     PRT        = 0                   AT         = 200000
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_mlvt'          PVTH0      = '0+dpvthn_mlvt'          LCIT       = '0+dlcitn_mlvt'
+LU0        = '0+dlu0n_mlvt'           PU0        = '0+dpu0n_mlvt'           LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LVOFF      = '0+dlvoffn_mlvt'          PVOFF      = '0+dpvoffn_mlvt'
+PVSAT      = '0+dpvsatn_mlvt'         WVSAT      = '0+dwvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+LA0        = '0+dla0n_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_mlvt'
+LMAX       = '1e-005-dxln_mlvt'       WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_mlvt'              TOXM       = 2.6e-009            DTOX       = 2.86e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'
+DLC        = '1.694588E-08+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.39757681+dvthn_mlvt'  LVTH0      = '4.120314e-008+dlvthn_mlvt'
+WVTH0      = '-1.1508097e-009+dwvthn_mlvt'
+PVTH0      = '-3.875303e-015+dpvthn_mlvt'
+K1         = 0.31994             K2         = '0.0095210115+dk2n_mlvt' LK2        = -1.3912516e-008
+WK2        = 1.7376739e-009      PK2        = -1.6301281e-016     K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = -0.00022358126      LCIT       = '1.2315009e-009+dlcitn_mlvt'
+WCIT       = '2.5582478e-010+dwcitn_mlvt'
+PCIT       = -3.1713744e-016     VOFF       = -0.14555693         LVOFF      = '-1.188177e-008+dlvoffn_mlvt'
+WVOFF      = '1.3029025e-009+dwvoffn_mlvt'
+PVOFF      = '2.4776275e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019787828+du0n_mlvt'  LU0        = '-5.0619488e-010+dlu0n_mlvt'
+WU0        = '1.1991766e-010+dwu0n_mlvt'
+PU0        = '-1.0132143e-016+dpu0n_mlvt'
+UA         = -1.4160953e-009     LUA        = 2.8364855e-016      WUA        = 9.8538358e-018
+PUA        = -6.1041084e-023     UB         = 2.1751911e-018      LUB        = -4.2376047e-025
+WUB        = 1.5088364e-026      PUB        = 5.7980026e-032      UC         = 4.1488701e-011
+LUC        = -5.2857499e-017     WUC        = -2.7064689e-018     PUC        = 5.3676738e-024
+VSAT       = '109991.66+dvsatn_mlvt'  LVSAT      = '8.3113569e-005+dlvsatn_mlvt'
+WVSAT      = '2.6689462e-006+dwvsatn_mlvt'
+PVSAT      = '-2.6596342e-011+dpvsatn_mlvt'
+A0         = 2.5602871           LA0        = '-1.0968083e-006+dla0n_mlvt'
+WA0        = -5.6175997e-008     PA0        = 7.1199573e-014      AGS        = 0.78787773
+LAGS       = 3.6105576e-008      WAGS       = 1.6027857e-008      PAGS       = 5.3864572e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020217326        LKETA      = 5.8416966e-009
+WKETA      = -4.4736266e-009     PKETA      = -4.8751095e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.25972444          WPCLM      = 5.9096178e-008
+PDIBLC1    = 0                   PDIBLC2    = '0.0018516752+dpdiblc2n_mlvt'
+LPDIBLC2   = 2.7167764e-009      WPDIBLC2   = 1.7577829e-010      PPDIBLC2   = -5.2995312e-016
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016612908        LTVOFF     = -6.2577869e-011
+WTVOFF     = -4.3119011e-011     PTVOFF     = -8.6941049e-017     KT1        = -0.16216021
+LKT1       = -8.7749359e-008     WKT1       = -4.6705847e-009     PKT1       = 6.2623747e-015
+KT1L       = 0                   KT2        = -0.073651203        LKT2       = -1.3075522e-008
+WKT2       = 2.8836182e-009      PKT2       = 1.2501079e-015      UTE        = -0.91695187
+LUTE       = -2.9301095e-007     WUTE       = -3.7953218e-008     PUTE       = 3.4947594e-014
+UA1        = 1.6683918e-009      LUA1       = -6.8153127e-016     WUA1       = -2.9873049e-017
+PUA1       = 7.4469758e-023      UB1        = -1.3894768e-018     LUB1       = 5.2342433e-025
+WUB1       = -6.4827623e-027     PUB1       = -1.0985619e-031     UC1        = 3.4504068e-011
+LUC1       = 4.4794652e-016      WUC1       = -1.8320158e-019     PUC1       = -6.1171587e-023
+PRT        = 0                   AT         = 199165.95           LAT        = 0.0083113569
+WAT        = 0.00026689462       PAT        = -2.6596342e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'
+PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_mlvt'
+LMAX       = '1.000002e-006-dxln_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.44102656+dvthn_mlvt'  LVTH0      = '-7.3064059e-010+dlvthn_mlvt'
+WVTH0      = '-4.989133e-009+dwvthn_mlvt'
+PVTH0      = '-1.7089884e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0030841439+dk2n_mlvt'
+LK2        = -1.7471541e-009     WK2        = 1.722962e-009       PK2        = -1.4881416e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011992438
+LCIT       = '-1.4168183e-010+dlcitn_mlvt'
+WCIT       = '-8.7588649e-011+dwcitn_mlvt'
+PCIT       = 1.4294291e-017      VOFF       = -0.15305248         LVOFF      = '-4.6477361e-009+dlvoffn_mlvt'
+WVOFF      = '1.0088296e-009+dwvoffn_mlvt'
+PVOFF      = '5.3157543e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'    ETA0       = '0.090996667+deta0n_mlvt'
+WETA0      = '-1.9189333e-009+dweta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019886018+du0n_mlvt'  LU0        = '-6.0095944e-010+dlu0n_mlvt'
+WU0        = '1.9551924e-011+dwu0n_mlvt'
+PU0        = '-4.4574475e-018+dpu0n_mlvt'
+UA         = -1.1110295e-009     LUA        = -1.0773486e-017     WUA        = -6.3502928e-017
+PUA        = 9.756262e-024       UB         = 1.7905694e-018      LUB        = -5.2558224e-026
+WUB        = 8.9143207e-026      PUB        = -1.3491044e-032     UC         = -2.0787412e-011
+LUC        = 7.2457998e-018      WUC        = 4.2527925e-018      PUC        = -1.348779e-024
+VSAT       = '110077.78+dvsatn_mlvt'  WVSAT      = '-2.4888889e-005+dwvsatn_mlvt'
+A0         = 1.4387986           LA0        = '-1.4448542e-008+dla0n_mlvt'
+WA0        = 9.3419726e-008      PA0        = -7.3176755e-014     AGS        = 0.48121726
+LAGS       = 3.3206667e-007      WAGS       = 8.7900211e-008      PAGS       = -1.5500155e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.006990853        LKETA      = -6.9233048e-009
+WKETA      = -1.1518669e-008     PKETA      = 1.9241315e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.25972553          LPCLM      = -1.0447143e-012
+WPCLM      = 5.9095831e-008      PPCLM      = 3.3430856e-019      PDIBLC1    = 0
+PDIBLC2    = '0.0056323094+dpdiblc2n_mlvt'
+LPDIBLC2   = -9.3195145e-010     WPDIBLC2   = -4.3491454e-010     PPDIBLC2   = 5.9432633e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0016763501        LTVOFF     = -7.7111719e-011
+WTVOFF     = -1.4776636e-010     PTVOFF     = 1.4055149e-017      KT1        = -0.27465483
+LKT1       = 2.0820326e-008      WKT1       = 6.3670941e-009      PKT1       = -4.3901995e-015
+KT1L       = 0                   KT2        = -0.096034015        LKT2       = 8.5263542e-009
+WKT2       = 5.2512249e-009      PKT2       = -1.034893e-015      UTE        = -1.3450582
+LUTE       = 1.2015872e-007      WUTE       = 1.7117021e-008      PUTE       = -1.8201244e-014
+UA1        = 9.9167261e-010      LUA1       = -2.8422861e-017     WUA1       = 7.8541349e-017
+PUA1       = -3.0162062e-023     UB1        = -9.5222251e-019     LUB1       = 1.0142584e-025
+WUB1       = -1.5428706e-025     PUB1       = 3.2791213e-032      UC1        = 6.2488934e-010
+LUC1       = -1.2184022e-016     WUC1       = -8.1201539e-017     PUC1       = 1.702002e-023
+PRT        = 0                   AT         = 272864.16           LAT        = -0.062815518
+WAT        = -0.006491667        PAT        = 3.8631212e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LETA0      = '0+dleta0n_mlvt'
+PETA0      = '0+dpeta0n_mlvt'         PVSAT      = '0+dpvsatn_mlvt'         LVSAT      = '0+dlvsatn_mlvt'
+LNFACTOR   = '0+dlnfactorn_mlvt'      WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.999948e-008-dxln_mlvt'
+LMAX       = '2.399959e-007-dxln_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.45945038+dvthn_mlvt'  LVTH0      = '-4.9309045e-009+dlvthn_mlvt'
+WVTH0      = '-9.2809733e-009+dwvthn_mlvt'
+PVTH0      = '8.0755491e-016+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.0051767884+dk2n_mlvt'
+LK2        = -1.270073e-009      WK2        = 4.7239043e-010      PK2        = 1.3629114e-016
+K3         = -2.5                K3B        = 2.32848             W0         = 0
+DVT0       = 5.6761764           DVT1       = 1.2875382           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.5                 MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1.0230918e-006      DVTP1      = 1                   LPE0       = 2.3791893e-008
+LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 3.5825e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00052078982
+LCIT       = '2.5045144e-010+dlcitn_mlvt'
+WCIT       = '7.1909851e-012+dwcitn_mlvt'
+PCIT       = -7.3135697e-018     VOFF       = -0.16902629         LVOFF      = '-1.0060278e-009+dlvoffn_mlvt'
+WVOFF      = '4.2869811e-009+dwvoffn_mlvt'
+PVOFF      = '-2.1577756e-016+dpvoffn_mlvt'
+NFACTOR    = '0.75+dnfactorn_mlvt'
+ETA0       = '0.092284295+deta0n_mlvt'
+LETA0      = '-2.93549e-10+dleta0n_mlvt'
+WETA0      = '-2.0992013e-09+dweta0n_mlvt'
+PETA0      = '4.10969e-17+dpeta0n_mlvt'
+ETAB       = -0.14585111         WETAB      = 1.0000356e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018716753+du0n_mlvt'  LU0        = '-3.3439041e-010+dlu0n_mlvt'
+WU0        = '-3.5343762e-010+dwu0n_mlvt'
+PU0        = '8.0576709e-017+dpu0n_mlvt'
+UA         = -1.0699161e-009     LUA        = -2.0146527e-017     WUA        = -6.7070912e-017
+PUA        = 1.0569691e-023      UB         = 1.6471084e-018      LUB        = -1.9851994e-026
+WUB        = 5.7072951e-026      PUB        = -6.1796667e-033     UC         = -4.4895282e-012
+LUC        = 3.5302083e-018      WUC        = 8.223327e-020       PUC        = -3.9797494e-025
+VSAT       = '127361.64+dvsatn_mlvt'  LVSAT      = '-0.0039403743+dlvsatn_mlvt'
+WVSAT      = '-0.00022324674+dwvsatn_mlvt'
+PVSAT      = '4.5221623e-011+dpvsatn_mlvt'
+A0         = 2.9007007           LA0        = '-3.4773299e-007+dla0n_mlvt'
+WA0        = -2.5902588e-007     PA0        = 7.1737938e-015      AGS        = 1.1681751
+LAGS       = 1.7545402e-007      WAGS       = 3.4337137e-008      PAGS       = -3.2888453e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.091684306        LKETA      = 1.2385109e-008
+WKETA      = 8.2727232e-009      PKETA      = -2.5879101e-015     DWG        = 0
+DWB        = 0                   PCLM       = -0.10444213         LPCLM      = 8.3021898e-008
+WPCLM      = 7.7808664e-008      PPCLM      = -4.2658173e-015     PDIBLC1    = 0
+PDIBLC2    = '0.0019389061+dpdiblc2n_mlvt'
+LPDIBLC2   = -8.9929363e-011     WPDIBLC2   = -3.0044995e-010     PPDIBLC2   = 2.8777396e-017
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0014974253        LTVOFF     = -3.6320451e-011
+WTVOFF     = -1.4868844e-010     PTVOFF     = 1.4265366e-017      KT1        = -0.11754841
+LKT1       = -1.4996797e-008     WKT1       = -2.2859971e-008     PKT1       = 2.2729868e-015
+KT1L       = 0                   KT2        = -0.070200221        LKT2       = 2.6367656e-009
+WKT2       = 1.999345e-009       PKT2       = -2.9352944e-016     UTE        = -0.85631913
+LUTE       = 8.7359953e-009      WUTE       = -4.8834951e-008     PUTE       = -3.1655136e-015
+UA1        = 8.5127789e-010      LUA1       = 3.5843275e-018      WUA1       = 1.58184e-018
+PUA1       = -1.2616833e-023     UB1        = -5.9081832e-019     LUB1       = 1.9032907e-026
+WUB1       = -2.9180118e-026     PUB1       = 4.2693323e-033      UC1        = 8.9570029e-011
+LUC1       = 2.0188224e-019      WUC1       = -4.1294185e-018     PUC1       = -5.5088158e-025
+PRT        = 0                   AT         = -24643.815          LAT        = 0.0050103502
+WAT        = 0.017486021         PAT        = -1.6033121e-009
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07            JSD        = 2.01e-07
+JSWS       = 4.17e-13            JSWD       = 4.17e-13            JSWGS      = 4.17e-13
+JSWGD      = 4.17e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.1                   BVD        = 9.1
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_mlvt'               CJD        = 'cjn_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'             CJSWD      = 'cjswn_mlvt'
+MJSWS      = 0.005               MJSWD      = 0.005               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'            CJSWGD     = 'cjswgn_mlvt'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 0.002
+TCJ        = 0.0007              TPBSW      = 0.0004              TCJSW      = 0.0005
+TPBSWG     = 2.4e-05             TCJSWG     = 0.0015              XTIS       = 3
+XTID       = 3                   JTSSWGS    = 6.6e-012            JTSSWGD    = 6.6e-012
+NJTSSWG    = 4.573               VTSSWGS    = 3.593               VTSSWGD    = 3.593
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_mlvt'
+WNFACTOR   = '0+dwnfactorn_mlvt'      PNFACTOR   = '0+dpnfactorn_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_mlvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999948e-008-dxln_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0                   RGATEMOD   = '1*rgflag_mlvt'                   PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_mlvt'
+TOXM       = 2.6e-009            DTOX       = 2.86e-010           EPSROX     = 3.9
+WINT       = 0                   LINT       = -5.415E-09          LL         = 2.2652e-05
+WL         = 0                   LLN        = -0.5009             WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 2.2652e-05          WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-1e-09+dxln_mlvt'       XW         = '2.0e-08+dxwn_mlvt'      DLC        = '-5.415E-09+ddlcn_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.36917377+dvthn_mlvt'
+LVTH0      = '3.7158842e-09+dlvthn_mlvt'
+WVTH0      = '3.1924955e-09+dwvthn_mlvt'
+PVTH0      = '-3.87164e-16+dpvthn_mlvt'
+K1         = 0.31994             K2         = '-0.017993665+dk2n_mlvt' LK2        = -4.245975e-011
+WK2        = 1.4810162e-009      PK2        = 3.9683957e-017      K3         = -2.5
+K3B        = 2.32848             W0         = 0                   DVT0       = 5.6761764
+DVT1       = 1.2875382           DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.5
+MINV       = -0.335              VOFFL      = 0                   DVTP0      = 1.0230918e-006
+DVTP1      = 1                   LPE0       = 2.3791893e-008      LPEB       = 0
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0                   XJ         = 8.6e-008
+NGATE      = 3.5825e+020         NDEP       = 6.5e+017            NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0
+CIT        = -5.92111e-05
+LCIT       = '2.0624097e-10+dlcitn_mlvt'
+WCIT       = '-5.99189e-12+dwcitn_mlvt'
+PCIT       = -6.050901e-18
+VOFF       = -0.07602881
+LVOFF      = '-9.9133842e-09+dlvoffn_mlvt'
+WVOFF      = '-1.0479483e-08+dwvoffn_mlvt'
+PVOFF      = '1.1985608e-15+dpvoffn_mlvt'
+NFACTOR    = '0.52450949+dnfactorn_mlvt+0.69479*ss_flag_mlvt-0.285042*ff_flag_mlvt'
+ETA0       = '0.14010297+deta0n_mlvt-0.0112745*ff_flag_mlvt'
+LETA0      = '-4.8736735e-09+dleta0n_mlvt+1.07988e-09*ff_flag_mlvt'
+WETA0      = '-1.6505063e-08+dweta0n_mlvt+1.57843e-09*ff_flag_mlvt'
+PETA0      = '1.4209008e-15+dpeta0n_mlvt-1.51183e-16*ff_flag_mlvt'
+ETAB       = -0.22928538
+LETAB      = 7.9914046e-09
+WETAB      = 1.9379993e-08
+PETAB      = -8.9839211e-16
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -1.2e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0005163436+du0n_mlvt'
+LU0        = '1.4088608e-09+dlu0n_mlvt'
+WU0        = '2.3284845e-09+dwu0n_mlvt'
+PU0        = '-1.7630017e-16+dpu0n_mlvt'
+UA         = -2.711597e-009      LUA        = 1.3709532e-016      WUA        = 7.3907108e-017
+PUA        = -2.9333248e-024
+UB         = 1.717091e-18
+LUB        = -2.6555216e-26
+WUB        = 1.3807793e-25
+PUB        = -1.3938372e-32
+UC         = 8.4822175e-011
+LUC        = -5.0241559e-018     WUC        = -1.7519653e-018     PUC        = -2.2229358e-025
+VSAT       = '86926.88+dvsatn_mlvt+986.521*ff_flag_mlvt'
+WVSAT      = '0.0010381057+dwvsatn_mlvt-0.000315687*ff_flag_mlvt'
+A0         = 7.8850637
+LA0        = '-8.2513494e-07+dla0n_mlvt'
+WA0        = -9.0013451e-07
+PA0        = 6.8578891e-14
+AGS        = -0.8582156
+Pags     = -3.0236588e-14
+Wags     = 3.1568672e-07
+LAGS       = 3.6954231e-07
+A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = 0.087025563
+LKETA      = -4.7319014e-009     WKETA      = -5.9125793e-008     PKETA      = 3.8675872e-015
+DWG        = 0                   DWB        = 0
+PCLM       = -0.18830795
+LPCLM      = 9.1054587e-08
+WPCLM      = 1.5985613e-07
+PPCLM      = -1.2124386e-14
+PDIBLC1    = 0                   PDIBLC2    = '0.00040143075+dpdiblc2n_mlvt'
+LPDIBLC2   = 5.7331562e-011      WPDIBLC2   = 8.3799696e-011      PPDIBLC2   = -8.0264186e-018
+PDIBLCB    = 0.059999999         DROUT      = 0.56                PVAG       = 1.2
+DELTA      = 0.007595625         PSCBE1     = 1e+009              PSCBE2     = 1e-020
+FPROUT     = 687.13435           PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_mlvt'
+RDW        = '65+drdswn_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 4.71e-007           ALPHA1     = 2.371
+BETA0      = 15.26               AGIDL      = 1e-008              BGIDL      = 1.9e+009
+CGIDL      = 0.808               EGIDL      = 0.307               AIGBACC    = 0.01396
+BIGBACC    = 0.0079101083        CIGBACC    = 0.32874864          NIGBACC    = 23.684847
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.01141
+BIGC       = 0.0015058812        CIGC       = 0.000625            AIGSD      = 0.01089
+BIGSD      = 0.0010507083        CIGSD      = 0.069864936         NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.565               NTOX       = 'ntoxn_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_mlvt'
+CGDO       = 'cgon_mlvt'              CGBO       = 0                   CGDL       = 'cgln_mlvt'
+CGSL       = 'cgln_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.4939              NOFF       = 2.5494
+VOFFCV     = -0.1348             TVOFF      = 0.0015650114        LTVOFF     = -4.2793916e-011
+WTVOFF     = 6.9682922e-011      PTVOFF     = -6.6504612e-018     KT1        = -0.27336375
+LKT1       = -7.2647279e-011     WKT1       = 8.1190665e-009      PKT1       = -6.9421642e-016
+KT1L       = 0
+KT2        = -0.033021102
+LKT2       = -9.242786e-10
+WKT2       = -7.6015353e-09
+PKT2       = 6.2604703e-16
+UTE        = -0.38851129
+LUTE       = -3.6071108e-008     WUTE       = -2.1317063e-007     PUTE       = 1.2574723e-014
+UA1        = 9.3863422e-010      LUA1       = -4.782749e-018      WUA1       = -3.954698e-016
+PUA1       = 2.541317e-023       UB1        = 4.7400456e-019      LUB1       = -8.2956893e-026
+WUB1       = 1.5217483e-025      PUB1       = -1.3101026e-032     UC1        = 5.5175742e-011
+LUC1       = 3.4962015e-018      WUC1       = -2.6521114e-017     PUC1       = 1.5938174e-024
+PRT        = 0                   AT         = 27666.667           WAT        = 0.00074666667
+NOIA       = 'noian_mlvt'
+NOIB       = 'noibn_mlvt'
+NOIC       = 'noicn_mlvt'
+EM         = 2.000e+06
+EF         = 1.00
+JSS        = 2.01e-07
+JSD        = 2.01e-07            JSWS       = 4.17e-13            JSWD       = 4.17e-13
+JSWGS      = 4.17e-13            JSWGD      = 4.17e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.1
+BVD        = 9.1                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_mlvt'
+CJD        = 'cjn_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_mlvt'
+CJSWD      = 'cjswn_mlvt'             MJSWS      = 0.005               MJSWD      = 0.005
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_mlvt'
+CJSWGD     = 'cjswgn_mlvt'            MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 0.002               TCJ        = 0.0007              TPBSW      = 0.0004
+TCJSW      = 0.0005              TPBSWG     = 2.4e-05             TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 6.6e-012
+JTSSWGD    = 6.6e-012            NJTSSWG    = 4.573               VTSSWGS    = 3.593
+VTSSWGD    = 3.593               DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 3.0e-009
+LKVTH0     = -2.6e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.5e-008
+PKU0     = 8e-14
+LKU0       = 11e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = -4.3e-09
+TKU0       = 0
+PVSAT      = '-7.5591471e-11+dpvsatn_mlvt+3.02366e-11*ff_flag_mlvt'
+LVSAT      = '-6.749239e-05+dlvsatn_mlvt-9.44893e-05*ff_flag_mlvt'
+LNFACTOR   = '2.1597563e-08+dlnfactorn_mlvt-6.65473e-08*ss_flag_mlvt+2.73014e-08*ff_flag_mlvt'
+WNFACTOR   = '3.1568672e-08+dwnfactorn_mlvt-1.19718e-07*ss_flag_mlvt+3.99059e-08*ff_flag_mlvt'
+PNFACTOR   = '-3.0236588e-15+dpnfactorn_mlvt+1.14666e-14*ss_flag_mlvt-3.8222e-15*ff_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )

**********************************************************************************************
*                                                                                            *
*                               1.2V STD-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************



.MODEL pch_mlvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp_mlvt'
+LMAX       = 2.000001e-05        WMIN       = '1e-005-dxwp_mlvt'       WMAX       = 0.00090000001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_mlvt'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40478507+dvthp_mlvt' K1         = 0.23752
+K2         = '0.01799+dk2p_mlvt'      K3         = -2.4570454          K3B        = 2.1204211
+W0         = 0                   DVT0       = 10.498235           DVT1       = 1.3326361
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.4494              MINV       = -0.335
+VOFFL      = 0                   DVTP0      = 1e-010              DVTP1      = 0.3712
+LPE0       = 1.4959847e-007      LPEB       = 3.4167544e-008      WEB        = -210
+WEC        = -3510               SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020
+NDEP       = 6.3687e+017         NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = 3.295e-005          VOFF       = -0.090520243        NFACTOR    = '0.7+dnfactorp_mlvt'
+ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p_mlvt'      UA         = 2.125e-009
+UB         = 1.1188572e-018      UC         = 5.989e-011          VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.1738374           AGS        = 1.0392952           A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.04364            DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.001+dpdiblc2p_mlvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.002061            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2107
+KT1L       = 0                   KT2        = -0.04721            UTE        = -1.871
+UA1        = -4.98e-010          UB1        = -2e-018             UC1        = 2.97e-011
+PRT        = 0
+AT         = '190000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'
+WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'
+WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp_mlvt'
+LMAX       = '1.000249e-005-dxlp_mlvt'
+WMIN       = '1e-005-dxwp_mlvt'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40465395+dvthp_mlvt' LVTH0      = '-1.3068431e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.01701623+dk2p_mlvt'   LK2        = '9.7051776e-009+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -1.7211113e-005
+LCIT       = '4.9993574e-010+dlcitp_mlvt'
+VOFF       = -0.090095029        LVOFF      = '-4.2379431e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p_mlvt'
+LU0        = '1.4985763e-010+dlu0p_mlvt'
+UA         = 2.1364918e-009      LUA        = -1.1453404e-016     UB         = 1.120458e-018
+LUB        = -1.5954699e-026     UC         = 5.655953e-011       LUC        = 3.3193464e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.2339233           LA0        = -5.9885154e-007
+AGS        = 1.0187726           LAGS       = 2.045409e-007       A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.039535177        LKETA      = -4.0911132e-008     DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035560074+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.4224697e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021063228
+LTVOFF     = -4.517137e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.2088205          LKT1       = -1.8732203e-008     KT1L       = 0
+KT2        = -0.047125154        LKT2       = -8.4562518e-010     UTE        = -1.8654152
+LUTE       = -5.5661404e-008     UA1        = -5.2291677e-010     LUA1       = 2.4833549e-016
+UB1        = -1.9183761e-018     LUB1       = -8.1351283e-025     UC1        = 6.2424743e-011
+LUC1       = -3.2615442e-016     PRT        = 0
+AT         = '191611+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.016056174+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'         WETA0      = '0+dweta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp_mlvt'
+LMAX       = '1.002493e-006-dxlp_mlvt'
+WMIN       = '1e-005-dxwp_mlvt'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40092504+dvthp_mlvt' LVTH0      = '-4.9112115e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.026125594+dk2p_mlvt'  LK2        = '9.0007509e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00023972529
+LCIT       = '2.5158128e-010+dlcitp_mlvt'
+VOFF       = -0.086981097        LVOFF      = '-7.247866e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15257+deta0p_mlvt'    ETAB       = -0.1161
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p_mlvt'
+UA         = 2.0886074e-009      LUA        = -6.8249074e-017     UB         = 1.0708166e-018
+LUB        = 3.2028626e-026      UC         = 6.8468081e-011      LUC        = 2.168267e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.0877297           LA0        = -4.5754098e-007
+AGS        = 0.54098468          LAGS       = 6.6637023e-007      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.066038936        LKETA      = -1.5292624e-008     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.007+dpdiblc2p_mlvt'    PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 2.1                 DELTA      = 0.036
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55                  RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 1.945e-007          ALPHA1     = 0.23                BETA0      = 17.8
+AGIDL      = 1e-008              BGIDL      = 2.317e+009          CGIDL      = 4.6
+EGIDL      = 0.008744            AIGBACC    = 0.012459            BIGBACC    = 0.0046798592
+CIGBACC    = 0.245               NIGBACC    = 8.2582031           AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1                   AIGC       = 0.006941            BIGC       = 0.0013212138
+CIGC       = 0.1525875           AIGSD      = 0.00629             BIGSD      = 0.00033134367
+CIGSD      = 0.01328125          NIGC       = 2                   POXEDGE    = 1
+PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'
+CGBO       = 0                   CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_mlvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 6.8381              NOFF       = 2.3364              VOFFCV     = -0.069707
+TVOFF      = 0.0013759405        LTVOFF     = 2.542731e-010       WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2366354          LKT1       = 8.1536504e-009
+KT1L       = 0                   KT2        = -0.046125466        LKT2       = -1.8119223e-009
+UTE        = -2.0398459          LUTE       = 1.1294316e-007      UA1        = -3.6894314e-010
+LUA1       = 9.9504733e-017      UB1        = -2.8318571e-018     LUB1       = 6.9457022e-026
+UC1        = -3.7734954e-010     LUC1       = 9.8930958e-017      PRT        = 0
+AT         = '209960.05+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.033792351+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         WVOFF      = '0+dwvoffp_mlvt'
+PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'           WU0        = '0+dwu0p_mlvt'
+PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_mlvt'
+LMAX       = '2.399996e-007-dxlp_mlvt'
+WMIN       = '1e-005-dxwp_mlvt'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43586814+dvthp_mlvt' LVTH0      = '3.1291616e-009+dlvthp_mlvt'
+K1         = 0.23752             K2         = '0.026688227+dk2p_mlvt'  LK2        = '7.7061392e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00050750804
+LCIT       = '1.8996473e-010+dlcitp_mlvt'
+VOFF       = -0.10209394         LVOFF      = '-3.7704156e-009+dlvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.1525715+deta0p_mlvt'  LETA0      = '-3.4445173e-013+dleta0p_mlvt'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01832+du0p_mlvt'      UA         = 1.9776245e-009      LUA        = -4.2712014e-017
+UB         = 8.7504948e-019      LUB        = 7.707445e-026       UC         = 1.1382387e-010
+LUC        = 1.1246349e-017      VSAT       = '102515.14+dvsatp_mlvt'  LVSAT      = '0.0017222586+dlvsatp_mlvt'
+A0         = 2.8553267           LA0        = -1.7396628e-007     AGS        = 2.3173399
+LAGS       = 2.5763267e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.15948292
+LKETA      = 6.2087424e-009      DWG        = 0                   DWB        = 0
+PCLM       = 2.1496972           LPCLM      = '-3.4445173e-008+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009366305+dpdiblc2p_mlvt'
+LPDIBLC2   = -5.4448442e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0024847424
+LTVOFF     = -8.6112932e-013     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.19244272         LKT1       = -2.0150426e-009     KT1L       = 0
+KT2        = -0.043364015        LKT2       = -2.4473295e-009     UTE        = -1.5257969
+LUTE       = -5.3390018e-009     UA1        = -4.5404703e-011     LUA1       = 2.5058863e-017
+UB1        = -2.6722123e-018     LUB1       = 3.2722914e-026      UC1        = 1.9891165e-011
+LUC1       = 7.5262703e-018      PRT        = 0
+AT         = '207632.63+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.033256814+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+WK2        = '0+dwk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          WETA0      = '0+dweta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'
+WVOFF      = '0+dwvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_mlvt'
+WMIN       = '1e-005-dxwp_mlvt'       WMAX       = 0.00090000001       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37794575+dvthp_mlvt-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVTH0      = '-2.5761951e-09+dlvthp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.032369455+dk2p_mlvt'  LK2        = '2.1101295e-010+dlk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0025451145
+LCIT       = '4.9064805e-010+dlcitp_mlvt'
+VOFF       = '-0.091458175-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVOFF      = '-4.8180449e-09+dlvoffp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.337809*ff_flag_mlvt+0.270247*sf_flag_mlvt-0.270247*fs_flag_mlvt'
+ETA0       = '0.13696261+deta0p_mlvt'
+LETA0      = '1.5371298e-09+dleta0p_mlvt'
+ETAB       = -0.1161             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018269064+du0p_mlvt-0.000310784*ss_flag_mlvt'
+LU0        = '5.0171587e-012+dlu0p_mlvt+3.06122e-11*ss_flag_mlvt'
+UA         = 2.7936199e-09
+Pua      = 0
+Wua      = 0
+LUA        = -1.2308757e-16
+UB         = -1.3831404e-19
+Pub      = 0
+Wub      = 0
+LUB        = 1.7689066e-25
+UC         = 2.5109082e-010      LUC        = -2.2744453e-018
+VSAT       = '130269.47+dvsatp_mlvt'
+LVSAT      = '-0.0010115384+dlvsatp_mlvt'
+A0         = -2.4686737          LA0        = 3.5044776e-007      AGS        = 5.584986
+LAGS       = -6.4230468e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.27139688
+LKETA      = 1.7232268e-008      DWG        = 0                   DWB        = 0
+PCLM       = '1.9030676-0.405371*ss_flag_mlvt'
+Wpclm    = '0+0.0*ss_flag_mlvt'
+LPCLM      = '-1.0152113e-08+dlpclmp_mlvt+3.99289e-08*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035644164+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.7001609e-011      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0038291897
+LTVOFF     = -1.3328918e-010     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20152438         LKT1       = -1.1204988e-009     KT1L       = 0
+KT2        = -0.07256623         LKT2       = 4.2908867e-010      WKT2       = -3.4270439e-007
+PKT2       = 3.3756383e-014      UTE        = -2.5647553          LUTE       = 9.6998401e-008
+UA1        = -4.88626e-009       LUA1       = 5.0188311e-016      UB1        = 4.1052355e-019
+LUB1       = -2.7092657e-025     UC1        = -2.6143785e-010     LUC1       = 3.5237178e-017
+PRT        = 0
+AT         = '-191122.75+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '0.0060205904+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVTH0      = '0+dpvthp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WK2        = '0+dwk2p_mlvt'
+PK2        = '0+dpk2p_mlvt'           WCIT       = '0+dwcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'
+WETA0      = '0+dweta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'
+WVOFF      = '0+dwvoffp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVOFF      = '0+dpvoffp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WU0        = '0+dwu0p_mlvt+0.0*ss_flag_mlvt'
+PU0        = '0+dpu0p_mlvt+0.0*ss_flag_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt-3.32741e-08*ff_flag_mlvt-2.66193e-08*sf_flag_mlvt+2.66193e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+0.0*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'
+PPCLM      = '0+dppclmp_mlvt+0.0*ss_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp_mlvt'
+LMAX       = 2.000001e-05        WMIN       = '1e-006-dxwp_mlvt'       WMAX       = '1e-005-dxwp_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_mlvt'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40568103+dvthp_mlvt' WVTH0      = '8.9774574e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.018667733+dk2p_mlvt'  WK2        = '-6.790888e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.2646354e-005
+WCIT       = '8.5767547e-010+dwcitp_mlvt'
+VOFF       = -0.090248724        WVOFF      = '-2.7206214e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01818+du0p_mlvt'      UA         = 2.17566e-009
+WUA        = -5.076132e-016      UB         = 1.1405421e-018      WUB        = -2.1728252e-025
+UC         = 6.2729e-011         WUC        = -2.844678e-017      VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.0329858           WA0        = 1.4113335e-006      AGS        = 1.0486742
+WAGS       = -9.3977301e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.045544
+WKETA      = 1.907808e-008       DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '0.00097393333+dpdiblc2p_mlvt'
+WPDIBLC2   = 2.61188e-010        PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0020859333
+LTVOFF     = 0                   WTVOFF     = -2.49832e-010       PTVOFF     = 0
+KT1        = -0.210632           WKT1       = -6.8136e-010        KT1L       = 0
+KT2        = -0.047049067        WKT2       = -1.612552e-009      UTE        = -1.86964
+WUTE       = -1.36272e-008       UA1        = -5.46178e-010       WUA1       = 4.8274356e-016
+UB1        = -2.017e-018         WUB1       = 1.7034e-025         UC1        = 3.0346e-011
+WUC1       = -6.47292e-018       PRT        = 0
+AT         = '189433.33+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+WAT        = '0.005678+dwatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07            JSWS       = 2.71e-13
+JSWD       = 2.71e-13            JSWGS      = 2.71e-13            JSWGD      = 2.71e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                  BVD        = 9.4                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'               MJS        = 0.4
+MJD        = 0.4                 PBSWS      = 1                   PBSWD      = 1
+CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062
+MJSWD      = 0.062               PBSWGS     = 0.75                PBSWGD     = 0.75
+CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95
+MJSWGD     = 0.95                TPB        = 0.003               TCJ        = 0.00105
+TPBSW      = 0.002               TCJSW      = 0.0002              TPBSWG     = 0.0005
+TCJSWG     = 0.00132             XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7
+VTSSWGS    = 0.1                 VTSSWGD    = 0.1                 DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'
+LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'
+PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'
+LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'
+WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp_mlvt'
+LMAX       = '1.000249e-005-dxlp_mlvt'
+WMIN       = '1e-006-dxwp_mlvt'       WMAX       = '1e-005-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40577219+dvthp_mlvt' LVTH0      = '9.0853098e-010+dlvthp_mlvt'
+WVTH0      = '1.1204701e-008+dwvthp_mlvt'
+PVTH0      = '-2.2198048e-014+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.017700018+dk2p_mlvt'  LK2        = '9.6448336e-009+dlk2p_mlvt'
+WK2        = '-6.8515553e-009+dwk2p_mlvt'
+PK2        = '6.046471e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00010956611
+LCIT       = '5.6729641e-010+dlcitp_mlvt'
+WCIT       = '9.2539704e-010+dwcitp_mlvt'
+PCIT       = '-6.7495389e-016+dpcitp_mlvt'
+VOFF       = -0.089885889        LVOFF      = '-3.6162331e-009+dlvoffp_mlvt'
+WVOFF      = '-2.0955804e-009+dwvoffp_mlvt'
+PVOFF      = '-6.2295337e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018164964+du0p_mlvt'  LU0        = '1.4985763e-010+dlu0p_mlvt'
+UA         = 2.185679e-009       LUA        = -9.9855131e-017     WUA        = -4.9285564e-016
+PUA        = -1.4708269e-022     UB         = 1.1467823e-018      LUB        = -6.2193658e-026
+WUB        = -2.6376923e-025     PUB        = 4.6331437e-031      UC         = 5.9336696e-011
+LUC        = 3.3809736e-017      WUC        = -2.7827206e-017     PUC        = -6.1750419e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.082638            LA0        = -4.9486334e-007
+WA0        = 1.5158789e-006      PA0        = -1.0419617e-012     AGS        = 1.02975
+LAGS       = 1.8860985e-007      WAGS       = -1.0999371e-007     PAGS       = 1.5962908e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.041373691        LKETA      = -4.1563798e-008
+WKETA      = 1.8421917e-008      PKETA      = 6.5397097e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00035107849+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.2077451e-009      WPDIBLC2   = 4.5312959e-011      PPDIBLC2   = 2.1515402e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0021301728        LTVOFF     = -4.4091682e-010
+WTVOFF     = -2.3897727e-010     PTVOFF     = -1.0818479e-016     KT1        = -0.20872938
+LKT1       = -1.8962699e-008     WKT1       = -9.1309027e-010     PKT1       = 2.3095629e-015
+KT1L       = 0                   KT2        = -0.046972985        LKT2       = -7.5827959e-010
+WKT2       = -1.5247384e-009     PKT2       = -8.7520279e-016     UTE        = -1.8648342
+LUTE       = -4.7897352e-008     WUTE       = -5.8215488e-009     PUTE       = -7.7795803e-014
+UA1        = -5.7456501e-010     LUA1       = 2.8292192e-016      WUA1       = 5.175153e-016
+PUA1       = -3.4655599e-022     UB1        = -1.9361064e-018     LUB1       = -8.0623403e-025
+WUB1       = 1.776578e-025       PUB1       = -7.2933566e-032     UC1        = 6.6506529e-011
+LUC1       = -3.6039753e-016     WUC1       = -4.0899501e-017     PUC1       = 3.4311596e-022
+PRT        = 0
+AT         = '191166.05+datp_mlvt'
+LAT        = '-0.017269307+dlatp_mlvt'
+WAT        = '0.004458367+dwatp_mlvt'
+PAT        = '1.2155594e-08+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp_mlvt'
+LMAX       = '1.002493e-006-dxlp_mlvt'
+WMIN       = '1e-006-dxwp_mlvt'       WMAX       = '1e-005-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.3990933+dvthp_mlvt'  LVTH0      = '-5.5472718e-009+dlvthp_mlvt'
+WVTH0      = '-1.8353959e-008+dwvthp_mlvt'
+PVTH0      = '6.3733239e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0267055+dk2p_mlvt'    LK2        = '9.4014377e-010+dlk2p_mlvt'
+WK2        = '-5.8106529e-009+dwk2p_mlvt'
+PK2        = '-4.0148817e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00019073515
+LCIT       = '2.7702552e-010+dlcitp_mlvt'
+WCIT       = '4.9088123e-010+dwcitp_mlvt'
+PCIT       = '-2.5495134e-016+dpcitp_mlvt'
+VOFF       = -0.085868797        LVOFF      = '-7.4991505e-009+dlvoffp_mlvt'
+WVOFF      = '-1.1145253e-008+dwvoffp_mlvt'
+PVOFF      = '2.5178708e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15305847+deta0p_mlvt' WETA0      = '-4.894436e-009+dweta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018320708+du0p_mlvt'  LU0        = '-6.8450398e-013+dlu0p_mlvt'
+WU0        = '-7.0957345e-012+dwu0p_mlvt'
+PU0        = '6.8587299e-018+dpu0p_mlvt'
+UA         = 2.1571943e-009      LUA        = -7.2321872e-017     WUA        = -6.8724042e-016
+PUA        = 4.0809443e-023      UB         = 1.0503811e-018      LUB        = 3.0987619e-026
+WUB        = 2.0476372e-025      PUB        = 1.0430894e-032      UC         = 7.0564226e-011
+LUC        = 2.2957217e-017      WUC        = -2.100337e-017      PUC        = -1.2770955e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 3.9990876           LA0        = -4.1410363e-007
+WA0        = 8.881941e-007       PA0        = -4.3524225e-013     AGS        = 0.51343683
+LAGS       = 6.8767767e-007      WAGS       = 2.7602949e-007      PAGS       = -2.1350055e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.068491768        LKETA      = -1.5351492e-008
+WKETA      = 2.4577375e-008      PKETA      = 5.8985077e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0067025176+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.8450398e-011      WPDIBLC2   = 2.9807735e-009      PPDIBLC2   = -6.8587299e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001417086         LTVOFF     = 2.4835214e-010
+WTVOFF     = -4.122785e-010      PTVOFF     = 5.9328014e-017      KT1        = -0.23702705
+LKT1       = 8.3898043e-009      WKT1       = 3.9243084e-009      PKT1       = -2.3662618e-015
+KT1L       = 0                   KT2        = -0.046499384        LKT2       = -1.2160616e-009
+WKT2       = 3.7466529e-009      PKT2       = -5.9705244e-015     UTE        = -2.0256028
+LUTE       = 1.0750135e-007      WUTE       = -1.4271669e-007     PUTE       = 5.4526903e-014
+UA1        = -3.2474037e-010     LUA1       = 4.1441683e-017      WUA1       = -4.4291168e-016
+PUA1       = 5.8179177e-022      UB1        = -2.8877333e-018     LUB1       = 1.1360753e-025
+WUB1       = 5.5987888e-025      PUB1       = -4.4238808e-031     UC1        = -4.1188686e-010
+LUC1       = 1.0201704e-016      WUC1       = 3.4606401e-016      PUC1       = -3.0922584e-023
+PRT        = 0
+AT         = '202541.68+datp_mlvt'
+LAT        = '-0.028264981+dlatp_mlvt'
+WAT        = '0.074332056+dwatp_mlvt'
+PAT        = '-5.5384244e-08+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_mlvt'
+LMAX       = '2.399996e-007-dxlp_mlvt'
+WMIN       = '1e-006-dxwp_mlvt'       WMAX       = '1e-005-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43718619+dvthp_mlvt' LVTH0      = '3.2178643e-009+dlvthp_mlvt'
+WVTH0      = '1.3206912e-008+dwvthp_mlvt'
+PVTH0      = '-8.8880115e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.027489247+dk2p_mlvt'  LK2        = '7.5980421e-010+dlk2p_mlvt'
+WK2        = '-8.0262273e-009+dwk2p_mlvt'
+PK2        = '1.0831329e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00060171165
+LCIT       = '1.8246024e-010+dlcitp_mlvt'
+WCIT       = '-9.439202e-010+dwcitp_mlvt'
+PCIT       = '7.5195034e-017+dpcitp_mlvt'
+VOFF       = -0.10151688         LVOFF      = '-3.8985412e-009+dlvoffp_mlvt'
+WVOFF      = '-5.7821145e-009+dwvoffp_mlvt'
+PVOFF      = '1.283818e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15306049+deta0p_mlvt' LETA0      = '-4.6449316e-013+dleta0p_mlvt'
+WETA0      = '-4.8996634e-009+dweta0p_mlvt'
+PETA0      = '1.2028151e-018+dpeta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018311795+du0p_mlvt'  LU0        = '1.3663252e-012+dlu0p_mlvt'
+WU0        = '8.2210644e-011+dwu0p_mlvt'
+PU0        = '-1.3690578e-017+dpu0p_mlvt'
+UA         = 2.0244394e-009      LUA        = -4.1775106e-017     WUA        = -4.6908533e-016
+PUA        = -9.3878252e-024     UB         = 8.4480992e-019      LUB        = 7.8289346e-026
+WUB        = 3.0300036e-025      PUB        = -1.2173259e-032     UC         = 1.2061679e-010
+LUC        = 1.1440172e-017      WUC        = -6.8065064e-017     PUC        = -1.9421063e-024
+VSAT       = '102320.04+dvsatp_mlvt'  LVSAT      = '0.0017671522+dlvsatp_mlvt'
+WVSAT      = '0.0019549554+dwvsatp_mlvt'
+PVSAT      = '-4.4983329e-010+dpvsatp_mlvt'
+A0         = 3.0733024           LA0        = -2.0108138e-007     WA0        = -2.1841166e-006
+PA0        = 2.7169336e-013      AGS        = 2.4249007           LAGS       = 2.4785173e-007
+WAGS       = -1.0777597e-006     PAGS       = 9.8004983e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.16539386         LKETA      = 6.9455821e-009      WKETA      = 5.9227609e-008
+PKETA      = -7.3831334e-015     DWG        = 0                   DWB        = 0
+PCLM       = 2.0945587           LPCLM      = '-2.1757868e-008+dlpclmp_mlvt'
+WPCLM      = 5.5248741e-007      PPCLM      = '-1.271268e-013+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.009380001+dpdiblc2p_mlvt'
+LPDIBLC2   = -5.4763586e-010     WPDIBLC2   = -1.3723411e-010     PPDIBLC2   = 3.1577433e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0025263677        LTVOFF     = -6.8924791e-012
+WTVOFF     = -4.1708561e-010     PTVOFF     = 6.0434125e-017      KT1        = -0.18961099
+LKT1       = -2.5205829e-009     WKT1       = -2.8373858e-008     PKT1       = 5.065514e-015
+KT1L       = 0                   KT2        = -0.040612586        LKT2       = -2.570608e-009
+WKT2       = -2.7569322e-008     PKT2       = 1.23525e-015        UTE        = -1.4930439
+LUTE       = -1.5039911e-008     WUTE       = -3.2818557e-007     PUTE       = 9.7203107e-014
+UA1        = -1.7087609e-010     LUA1       = 6.0376647e-018      WUA1       = 1.2572233e-015
+PUA1       = 1.9059241e-022      UB1        = -2.54724e-018       LUB1       = 3.5260375e-026
+WUB1       = -1.2522225e-024     PUB1       = -2.542536e-032      UC1        = 8.7162035e-012
+LUC1       = 5.2366996e-018      WUC1       = 1.1197311e-016      PUC1       = 2.2941498e-023
+PRT        = 0
+AT         = '239835.91+datp_mlvt'
+LAT        = '-0.036846346+dlatp_mlvt'
+WAT        = '-0.32267684+dwatp_mlvt'
+PAT        = '3.5967105e-08+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_mlvt'
+WMIN       = '1e-006-dxwp_mlvt'       WMAX       = '1e-005-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37659553+dvthp_mlvt-0.00675618*ff_flag_mlvt-0.00540495*sf_flag_mlvt+0.00540495*fs_flag_mlvt'
+LVTH0      = '-2.750318e-09+dlvthp_mlvt+6.65482e-10*ff_flag_mlvt+5.32386e-10*sf_flag_mlvt-5.32386e-10*fs_flag_mlvt'
+WVTH0      = '-1.3529255e-08+dwvthp_mlvt-1.6e-15*ff_flag_mlvt+2.7e-15*sf_flag_mlvt-2.7e-15*fs_flag_mlvt'
+PVTH0      = '1.7447113e-15+dpvthp_mlvt+4.7e-22*ff_flag_mlvt+1.7e-22*sf_flag_mlvt-1.7e-22*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.03417205+dk2p_mlvt'   LK2        = '1.0154813e-010+dlk2p_mlvt'
+WK2        = '-1.8062006e-008+dwk2p_mlvt'
+PK2        = '1.0968375e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0025544307
+LCIT       = '4.9334023e-10+dlcitp_mlvt'
+WCIT       = '9.334878e-11+dwcitp_mlvt'
+PCIT       = '-2.6975657e-17+dpcitp_mlvt'
+VOFF       = '-0.089834733-0.00752188*ff_flag_mlvt-0.00601751*sf_flag_mlvt+0.00601751*fs_flag_mlvt'
+LVOFF      = '-5.0492393e-09+dlvoffp_mlvt+7.40903e-10*ff_flag_mlvt+5.92723e-10*sf_flag_mlvt-5.92723e-10*fs_flag_mlvt'
+WVOFF      = '-1.6266887e-08+dwvoffp_mlvt+7.67232e-09*ff_flag_mlvt+6.13786e-09*sf_flag_mlvt-6.13786e-09*fs_flag_mlvt'
+PVOFF      = '2.3165684e-15+dpvoffp_mlvt-7.55721e-16*ff_flag_mlvt-6.04577e-16*sf_flag_mlvt+6.04577e-16*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.36078*ff_flag_mlvt+0.288624*sf_flag_mlvt-0.288624*fs_flag_mlvt'
+ETA0       = '0.14001953+deta0p_mlvt'
+LETA0      = '1.2840682e-09+dleta0p_mlvt'
+WETA0      = '-3.0630437e-08+dweta0p_mlvt'
+PETA0      = '2.5356774e-15+dpeta0p_mlvt'
+ETAB       = -0.1210028          WETAB      = 4.9126056e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018284352+du0p_mlvt-0.000346007*ss_flag_mlvt'
+LU0        = '4.0694732e-012+dlu0p_mlvt+3.40816e-11*ss_flag_mlvt'
+WU0        = '-1.5318415e-010+dwu0p_mlvt+3.52927e-10*ss_flag_mlvt'
+PU0        = '9.495809e-018+dpu0p_mlvt-3.47632e-17*ss_flag_mlvt'
+UA         = 2.9074234e-09
+LUA        = -1.2874903e-16
+WUA        = -1.1403109e-15
+PUA        = 5.6727899e-23
+UB         = -1.9015386e-19
+LUB        = 1.8023319e-25
+WUB        = 5.1943491e-25
+PUB        = -3.3492224e-32
+UC         = 2.7661157e-010
+LUC        = -3.9253135e-018     WUC        = -2.5571791e-016     PUC        = 1.6541699e-023
+VSAT       = '131081.45+dvsatp_mlvt'
+LVSAT      = '-0.0010658424+dlvsatp_mlvt'
+WVSAT      = '-0.0081360267+dwvsatp_mlvt'
+PVSAT      = '5.4412583e-10+dpvsatp_mlvt'
+A0         = -2.1580065          LA0        = 3.1420254e-007      WA0        = -3.1128856e-006
+PA0        = 3.6317711e-013      AGS        = 5.7498547           LAGS       = -7.9656226e-008
+WAGS       = -1.6519842e-006     PAGS       = 1.5456609e-013      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.27065848         LKETA      = 1.7314148e-008      WKETA      = -7.3987412e-009
+PKETA      = -8.204379e-016      DWG        = 0                   DWB        = 0
+PCLM       = '1.9579358-0.451313*ss_flag_mlvt'
+LPCLM      = '-8.3004688e-09+dlpclmp_mlvt+4.44542e-08*ss_flag_mlvt'
+WPCLM      = '-5.4977942e-07+4.60339e-07*ss_flag_mlvt'
+PPCLM      = '-1.8553474e-14+dppclmp_mlvt-4.53433e-14*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035150503+dpdiblc2p_mlvt'
+LPDIBLC2   = 3.0061791e-011      WPDIBLC2   = 4.9464872e-010      PPDIBLC2   = -3.0663027e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0038565343        LTVOFF     = -1.3791389e-010
+WTVOFF     = -2.7399346e-010     PTVOFF     = 4.6339548e-017      KT1        = -0.20913593
+LKT1       = -5.9737636e-010     WKT1       = 7.6267772e-008      PKT1       = -5.2416866e-015
+KT1L       = 0                   KT2        = -0.10710269         LKT2       = 3.9786677e-009
+WKT2       = 3.350971e-009       PKT2       = -1.8103988e-015     UTE        = -2.7646078
+LUTE       = 1.1020914e-007      WUTE       = 2.0025219e-006      PUTE       = -1.3237158e-013
+UA1        = -5.759212e-009      LUA1       = 5.5648875e-016      WUA1       = 8.7469789e-015
+PUA1       = -5.4714852e-022     UB1        = 8.0563467e-019      LUB1       = -2.9499778e-025
+WUB1       = -3.9590135e-024     PUB1       = 2.4119355e-031      UC1        = -3.6641886e-010
+LUC1       = 4.2187504e-017      WUC1       = 1.0519098e-015      PUC1       = -6.9642263e-023
+PRT        = 0
+AT         = '-200922.45+datp_mlvt'
+LAT        = '0.0065683527+dlatp_mlvt'
+WAT        = '0.09819304+dwatp_mlvt'
+PAT        = '-5.4885776e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt-3.55368e-08*ff_flag_mlvt-2.84294e-08*sf_flag_mlvt+2.84294e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-2.3017e-07*ff_flag_mlvt-1.84136e-07*sf_flag_mlvt+1.84136e-07*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+2.26717e-14*ff_flag_mlvt+1.81374e-14*sf_flag_mlvt-1.81374e-14*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp_mlvt'
+LMAX       = 2.000001e-05        WMIN       = '6e-007-dxwp_mlvt'       WMAX       = '1e-006-dxwp_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_mlvt'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39498798+dvthp_mlvt' WVTH0      = '-1.9294524e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.01549285+dk2p_mlvt'   WK2        = '-3.552507e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001967827
+WCIT       = '-1.2032073e-009+dwcitp_mlvt'
+VOFF       = -0.09144815         WVOFF      = '-1.497207e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0182575+du0p_mlvt'    WU0        = '-7.905e-011+dwu0p_mlvt'
+UA         = 1.99885e-009        WUA        = -3.27267e-016       UB         = 8.73301e-019
+WUB        = 5.530338e-026       UC         = 5.0433e-011         WUC        = -1.590486e-017
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.6976187           WA0        = -2.8659209e-007
+AGS        = 0.9868853           WAGS       = -3.0952611e-008     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.0371165          WKETA      = 1.048203e-008       DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00265352+dpdiblc2p_mlvt'
+WPDIBLC2   = -1.4519904e-009     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.001624
+LTVOFF     = 0                   WTVOFF     = 2.2134e-010         PTVOFF     = 0
+KT1        = -0.23085728         WKT1       = 1.9948426e-008      KT1L       = 0
+KT2        = -0.0375475          WKT2       = -1.130415e-008      UTE        = -1.70165
+WUTE       = -1.84977e-007       UA1        = 5.98405e-010        WUA1       = -6.847311e-016
+UB1        = -2.3925e-018        WUB1       = 5.5335e-025         UC1        = -5.605e-012
+WUC1       = 3.01971e-017        PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'          PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'
+PK2        = '0+dpk2p_mlvt'           LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'
+PVOFF      = '0+dpvoffp_mlvt'          LU0        = '0+dlu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp_mlvt'
+LMAX       = '1.000249e-005-dxlp_mlvt'
+WMIN       = '6e-007-dxwp_mlvt'       WMAX       = '1e-006-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39111725+dvthp_mlvt' LVTH0      = '-3.8578036e-008+dlvthp_mlvt'
+WVTH0      = '-3.7433358e-009+dwvthp_mlvt'
+PVTH0      = '1.807825e-014+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.014568275+dk2p_mlvt'  LK2        = '9.2148693e-009+dlk2p_mlvt'
+WK2        = '-3.6571777e-009+dwk2p_mlvt'
+PK2        = '1.0432107e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020873444
+LCIT       = '-1.1911829e-009+dlcitp_mlvt'
+WCIT       = '-1.3154517e-009+dwcitp_mlvt'
+PCIT       = '1.118695e-015+dpcitp_mlvt'
+VOFF       = -0.089940125        LVOFF      = '-1.5029884e-008+dlvoffp_mlvt'
+WVOFF      = '-2.0402598e-009+dwvoffp_mlvt'
+PVOFF      = '5.4123897e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018250788+du0p_mlvt'  LU0        = '6.6900726e-011+dlu0p_mlvt'
+WU0        = '-8.753996e-011+dwu0p_mlvt'
+PU0        = '8.4616038e-017+dpu0p_mlvt'
+UA         = 2.0283313e-009      LUA        = -2.9382799e-016     WUA        = -3.3236098e-016
+PUA        = 5.0769623e-023      UB         = 8.391319e-019       LUB        = 3.4054974e-025
+WUB        = 5.0034171e-026      PUB        = 5.2516098e-032      UC         = 5.0128521e-011
+LUC        = 3.0346169e-018      WUC        = -1.8434868e-017     PUC        = 2.5215579e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.8948522           LA0        = -1.9657469e-006
+WA0        = -3.3257964e-007     PA0        = 4.5833947e-013      AGS        = 0.95157211
+LAGS       = 3.5195244e-007      WAGS       = -3.0252237e-008     PAGS       = -6.980351e-015
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033294837        LKETA      = -3.8088992e-008
+WKETA      = 1.0181485e-008      PKETA      = 2.9954078e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.001805439+dpdiblc2p_mlvt'
+LPDIBLC2   = 8.4524839e-009      WPDIBLC2   = -1.4381348e-009     PPDIBLC2   = -1.3809337e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.001669892         LTVOFF     = -4.5738688e-010
+WTVOFF     = 2.3050916e-010      PTVOFF     = -9.1385321e-017     KT1        = -0.23024672
+LKT1       = -6.0852472e-009     WKT1       = 2.1034597e-008      PKT1       = -1.0825437e-014
+KT1L       = 0                   KT2        = -0.035304454        LKT2       = -2.2355547e-008
+WKT2       = -1.342664e-008      PKT2       = 2.115401e-014       UTE        = -1.6698811
+LUTE       = -3.1662776e-007     WUTE       = -2.0467371e-007     PUTE       = 1.9630921e-013
+UA1        = 6.3625325e-010      LUA1       = -3.7721841e-016     WUA1       = -7.1751933e-016
+PUA1       = 3.2678714e-022      UB1        = -2.2894498e-018     LUB1       = -1.0270599e-024
+WUB1       = 5.3806807e-025      PUB1       = 1.5230887e-031      UC1        = -1.1364694e-011
+LUC1       = 5.7404569e-017      WUC1       = 3.8529147e-017      PUC1       = -8.304218e-023
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp_mlvt'
+LMAX       = '1.002493e-006-dxlp_mlvt'
+WMIN       = '6e-007-dxwp_mlvt'       WMAX       = '1e-006-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.43560449+dvthp_mlvt' LVTH0      = '4.4232917e-009+dlvthp_mlvt'
+WVTH0      = '1.8887457e-008+dwvthp_mlvt'
+PVTH0      = '-3.7966508e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.023882732+dk2p_mlvt'  LK2        = '2.115241e-010+dlk2p_mlvt'
+WK2        = '-2.9314302e-009+dwk2p_mlvt'
+PK2        = '3.417039e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001104327
+LCIT       = '-2.4099921e-010+dlcitp_mlvt'
+WCIT       = '-4.4098244e-010+dwcitp_mlvt'
+PCIT       = '2.7343389e-016+dpcitp_mlvt'
+VOFF       = -0.10137833         LVOFF      = '-3.9737264e-009+dlvoffp_mlvt'
+WVOFF      = '4.6744705e-009+dwvoffp_mlvt'
+PVOFF      = '-1.0780618e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14671+deta0p_mlvt'    WETA0      = '1.581e-009+dweta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018313752+du0p_mlvt'  LU0        = '6.039741e-012+dlu0p_mlvt'
+UA         = 1.7761809e-009      LUA        = -5.0099652e-017     WUA        = -2.9860671e-016
+PUA        = 1.8142778e-023      UB         = 1.0785501e-018      LUB        = 1.0912836e-025
+WUB        = 1.7603136e-025      PUB        = -6.927266e-032      UC         = 3.4403006e-011
+LUC        = 1.8234884e-017      WUC        = 1.5881074e-017      PUC        = -7.9541759e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9641532           LA0        = -1.0661342e-006
+WA0        = -9.6172823e-008     PA0        = 2.2982888e-013      AGS        = 0.67053007
+LAGS       = 6.2360739e-007      WAGS       = 1.1579439e-007      PAGS       = -1.4814887e-013
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057803706        LKETA      = -1.4398743e-008
+WKETA      = 1.3675552e-008      PKETA      = -3.8195322e-016     DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.012869735+dpdiblc2p_mlvt'
+LPDIBLC2   = -2.2422539e-009     WPDIBLC2   = -3.3097886e-009     PPDIBLC2   = 1.6710454e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00085005187       LTVOFF     = 3.3506973e-010
+WTVOFF     = 1.6609632e-010      PTVOFF     = -2.9123933e-017     KT1        = -0.24612493
+LKT1       = 9.2626193e-009      WKT1       = 1.3204148e-008      PKT1       = -3.2565332e-015
+KT1L       = 0                   KT2        = -0.052092046        LKT2       = -6.1286762e-009
+WKT2       = 9.4511686e-009      PKT2       = -9.5965747e-016     UTE        = -2.2598535
+LUTE       = 2.5363892e-007      WUTE       = 9.6219042e-008      PUTE       = -9.4533423e-014
+UA1        = -7.5839073e-010     LUA1       = 9.7084307e-016      WUA1       = -5.8832305e-019
+PUA1       = -3.6619765e-022     UB1        = -2.7883902e-018     LUB1       = -5.4478464e-025
+WUB1       = 4.5854899e-025      PUB1       = 2.2917193e-031      UC1        = -4.0697082e-011
+LUC1       = 8.5757226e-017      WUC1       = -3.2549564e-017     PUC1       = -1.4337569e-023
+PRT        = 0
+AT         = '253818.5+datp_mlvt'
+LAT        = '-0.061686895+dlatp_mlvt'
+WAT        = '0.022029706+dwatp_mlvt'
+PAT        = '-2.1293892e-08+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_mlvt'
+LMAX       = '2.399996e-007-dxlp_mlvt'
+WMIN       = '6e-007-dxwp_mlvt'       WMAX       = '1e-006-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42448966+dvthp_mlvt' LVTH0      = '1.8657789e-009+dlvthp_mlvt'
+WVTH0      = '2.5644645e-010+dwvthp_mlvt'
+PVTH0      = '4.9032594e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.021012137+dk2p_mlvt'  LK2        = '8.7204533e-010+dlk2p_mlvt'
+WK2        = '-1.4195742e-009+dwk2p_mlvt'
+PK2        = '-6.1726576e-018+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.0019043804
+LCIT       = '4.5130136e-010+dlcitp_mlvt'
+WCIT       = '1.6122937e-009+dwcitp_mlvt'
+PCIT       = '-1.9902291e-016+dpcitp_mlvt'
+VOFF       = -0.10511904         LVOFF      = '-3.1129936e-009+dlvoffp_mlvt'
+WVOFF      = '-2.10792e-009+dwvoffp_mlvt'
+PVOFF      = '4.8255944e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.14756059+deta0p_mlvt' LETA0      = '-1.9572049e-010+dleta0p_mlvt'
+WETA0      = '7.102273e-010+dweta0p_mlvt'
+PETA0      = '2.0036393e-016+dpeta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018392394+du0p_mlvt'  LU0        = '-1.2055811e-011+dlu0p_mlvt'
+UA         = 1.7984483e-009      LUA        = -5.5223362e-017     WUA        = -2.3857436e-016
+PUA        = 4.3293966e-024      UB         = 9.9807185e-019      LUB        = 1.2764632e-025
+WUB        = 1.4667319e-025      PUB        = -6.2517374e-032     UC         = 1.7448103e-011
+LUC        = 2.213619e-017       WUC        = 3.7166995e-017      PUC        = -1.2852045e-023
+VSAT       = '95303.479+dvsatp_mlvt'  LVSAT      = '0.0033816548+dlvsatp_mlvt'
+WVSAT      = '0.0091118432+dwvsatp_mlvt'
+PVSAT      = '-2.096626e-009+dpvsatp_mlvt'
+A0         = -1.052464           LA0        = 3.1828344e-007      WA0        = 2.0241652e-006
+PA0        = -2.5805877e-013     AGS        = -3.3636732          LAGS       = 1.5518735e-006
+WAGS       = 4.8265857e-006      PAGS       = -1.2320973e-012     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.10952471         LKETA      = -2.4977917e-009     WKETA      = 2.2410773e-009
+PKETA      = 2.2491079e-015      DWG        = 0                   DWB        = 0
+PCLM       = 2.5178855           LPCLM      = '-1.1916494e-007+dlpclmp_mlvt'
+WPCLM      = 1.2069406e-007      PPCLM      = '-2.7771581e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0022380442+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.0408765e-010      WPDIBLC2   = 7.1475619e-009      PPDIBLC2   = -7.3518055e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0011215839        LTVOFF     = 2.7259049e-010
+WTVOFF     = 1.0157939e-009      PTVOFF     = -2.246385e-016      KT1        = -0.22090708
+LKT1       = 3.4600176e-009      WKT1       = 3.5481538e-009      PKT1       = -1.0346986e-015
+KT1L       = 0                   KT2        = -0.073648816        LKT2       = -1.168485e-009
+WKT2       = 6.1276337e-009      PKT2       = -1.9491542e-016     UTE        = -1.8973161
+LUTE       = 1.7021943e-007      WUTE       = 8.4172058e-008      PUTE       = -9.1761424e-014
+UA1        = 2.9733192e-010      LUA1       = 7.2792235e-016      WUA1       = 7.7965111e-016
+PUA1       = -5.4572997e-022     UB1        = -3.5650932e-018     LUB1       = -3.6606607e-025
+WUB1       = -2.1401232e-025     PUB1       = 3.8392762e-031      UC1        = 1.1288074e-010
+LUC1       = 5.0419122e-017      WUC1       = 5.7252818e-018      PUC1       = -2.3144573e-023
+PRT        = 0
+AT         = '32293.31+datp_mlvt'
+LAT        = '-0.010714171+dlatp_mlvt'
+WAT        = '-0.11098338+dwatp_mlvt'
+PAT        = '9.3122869e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p_mlvt'
+PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_mlvt'
+WMIN       = '6e-007-dxwp_mlvt'       WMAX       = '1e-006-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.43558717+dvthp_mlvt-0.0172283*ff_flag_mlvt-0.0137826*sf_flag_mlvt+0.0137826*fs_flag_mlvt'
+LVTH0      = '2.958878e-09+dlvthp_mlvt+1.69698e-09*ff_flag_mlvt+1.35758e-09*sf_flag_mlvt-1.35758e-09*fs_flag_mlvt'
+WVTH0      = '4.664221e-08+dwvthp_mlvt+1.06815e-08*ff_flag_mlvt+8.54522e-09*sf_flag_mlvt-8.54522e-09*fs_flag_mlvt'
+PVTH0      = '-4.0786687e-15+dpvthp_mlvt-1.05213e-15*ff_flag_mlvt-8.41702e-16*sf_flag_mlvt+8.41702e-16*fs_flag_mlvt'
+K1         = 0.23752             K2         = '0.022738541+dk2p_mlvt'  LK2        = '7.0199448e-010+dlk2p_mlvt'
+WK2        = '-6.399827e-009+dwk2p_mlvt'
+PK2        = '4.8438224e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0033958234
+LCIT       = '5.9820857e-10+dlcitp_mlvt'
+WCIT       = '9.515692e-10+dwcitp_mlvt'
+PCIT       = '-1.3394136e-16+dpcitp_mlvt'
+VOFF       = '-0.14735947-0.0146609*ff_flag_mlvt-0.0117287*sf_flag_mlvt+0.0117287*fs_flag_mlvt'
+LVOFF      = '1.0476772e-09+dlvoffp_mlvt+1.4441e-09*ff_flag_mlvt+1.15528e-09*sf_flag_mlvt-1.15528e-09*fs_flag_mlvt'
+WVOFF      = '4.2408344e-08+dwvoffp_mlvt+1.49541e-08*ff_flag_mlvt+1.19633e-08*sf_flag_mlvt-1.19633e-08*fs_flag_mlvt'
+PVOFF      = '-3.9022864e-15+dpvoffp_mlvt-1.47298e-15*ff_flag_mlvt-1.17838e-15*sf_flag_mlvt+1.17838e-15*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt+0.97289*ff_flag_mlvt+0.275652*sf_flag_mlvt-0.275652*fs_flag_mlvt'
+ETA0       = '0.07520113+deta0p_mlvt'
+LETA0      = '6.9316746e-09+dleta0p_mlvt'
+WETA0      = '3.5484332e-08+dweta0p_mlvt'
+PETA0      = '-3.2248811e-15+dpeta0p_mlvt'
+ETAB       = -0.0592775          WETAB      = -1.383375e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018134172+du0p_mlvt+0.000837767*ff_flag_mlvt+0.000670213*sf_flag_mlvt-0.000670213*fs_flag_mlvt'
+LU0        = '1.337909e-011+dlu0p_mlvt-8.25198e-11*ff_flag_mlvt-6.60158e-11*sf_flag_mlvt+6.60158e-11*fs_flag_mlvt'
+UA         = 1.494713e-09
+LUA        = -2.5305406e-17
+WUA        = 3.0065375e-16
+PUA        = -4.8784604e-23
+UB         = 1.5253663e-18
+LUB        = 7.5707302e-26
+WUB        = -1.2303956e-24
+PUB        = 7.3124187e-32
+UC         = 2.8928966e-010
+LUC        = -4.6402028e-018     WUC        = -2.6864957e-016     PUC        = 1.7270887e-023
+VSAT       = '152332.53+dvsatp_mlvt-4188.83*ff_flag_mlvt-3351.07*sf_flag_mlvt+3351.07*fs_flag_mlvt'
+LVSAT      = '-0.0022357018+dlvsatp_mlvt+0.000412599*ff_flag_mlvt+0.000330079*sf_flag_mlvt-0.000330079*fs_flag_mlvt'
+WVSAT      = '-0.029812142+dwvsatp_mlvt+0.00427261*ff_flag_mlvt+0.00341809*sf_flag_mlvt-0.00341809*fs_flag_mlvt'
+PVSAT      = '1.7373823e-09+dpvsatp_mlvt-4.20851e-10*ff_flag_mlvt-3.36681e-10*sf_flag_mlvt+3.36681e-10*fs_flag_mlvt'
+A0         = -7.6203489          LA0        = 9.6522011e-007      WA0        = 2.4587037e-006
+PA0        = -3.0086082e-013     AGS        = 10.540098           LAGS       = 1.8235206e-007
+WAGS       = -6.5380324e-006     PAGS       = -1.1268236e-013     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.3183352          LKETA      = 1.8070041e-008      WKETA      = 4.1231505e-008
+PKETA      = -1.5914493e-015     DWG        = 0                   DWB        = 0
+PCLM       = 1.8660136
+LPCLM      = '-5.4955419e-08+dlpclmp_mlvt'
+WPCLM      = -4.5601882e-07
+PPCLM      = '2.9034575e-14+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.00431+dpdiblc2p_mlvt'  WPDIBLC2   = -3.162e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.006443761         LTVOFF     = -2.5164396e-010
+WTVOFF     = -2.9129647e-009     PTVOFF     = 1.6234422e-016      KT1        = -0.0509619
+LKT1       = -1.3279583e-008     WKT1       = -8.5069741e-008     PKT1       = 7.6941641e-015
+KT1L       = 0                   KT2        = -0.10243042         LKT2       = 1.6665026e-009
+WKT2       = -1.4147519e-009     PKT2       = 5.4800956e-016      UTE        = 1.5479247
+LUTE       = -1.6913678e-007     WUTE       = -2.3962613e-006     PUTE       = 1.5256126e-013
+UA1        = 1.2881832e-008      LUA1       = -5.1165093e-016     WUA1       = -1.0266886e-014
+PUA1       = 5.4235396e-022      UB1        = -8.6610064e-018     LUB1       = 1.3588138e-025
+WUB1       = 5.6969604e-024      PUB1       = -1.983032e-031      UC1        = 1.279103e-009
+LUC1       = -6.4453765e-017     WUC1       = -6.2652247e-016     PUC1       = 3.9131831e-023
+PRT        = 0
+AT         = '-11426.722+datp_mlvt'
+LAT        = '-0.0064077479+dlatp_mlvt'
+WAT        = '-0.095092602+dwatp_mlvt'
+PAT        = '7.7470449e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+WU0        = '0+dwu0p_mlvt-8.54522e-10*ff_flag_mlvt-6.83618e-10*sf_flag_mlvt+6.83618e-10*fs_flag_mlvt'
+PU0        = '0+dpu0p_mlvt+8.41702e-17*ff_flag_mlvt+6.73361e-17*sf_flag_mlvt-6.73361e-17*fs_flag_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt-9.58294e-08*ff_flag_mlvt-2.71517e-08*sf_flag_mlvt+2.71517e-08*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-8.54523e-07*ff_flag_mlvt-1.70904e-07*sf_flag_mlvt+1.70904e-07*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+8.41701e-14*ff_flag_mlvt+1.6834e-14*sf_flag_mlvt-1.6834e-14*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp_mlvt'
+LMAX       = 2.000001e-05        WMIN       = '3e-007-dxwp_mlvt'       WMAX       = '6e-007-dxwp_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_mlvt'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39586+dvthp_mlvt'    WVTH0      = '-1.3888e-009+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.0081982+dk2p_mlvt'    WK2        = '9.70176e-010+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 2.2391333e-005
+WCIT       = '2.9627733e-012+dwcitp_mlvt'
+VOFF       = -0.091604867        WVOFF      = '-1.4000427e-009+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01813+du0p_mlvt'      UA         = 1.8358e-009
+WUA        = -2.26176e-016       UB         = 9.8152549e-019      WUB        = -1.1795806e-026
+UC         = 1.2716e-011         WUC        = 7.47968e-018        VSAT       = '110000+dvsatp_mlvt'
+A0         = 4.9147812           WA0        = 1.9876721e-007      AGS        = 0.91700495
+WAGS       = 1.2373205e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.024978
+WKETA      = 2.95616e-009        DWG        = 0                   DWB        = 0
+PCLM       = 1                   PDIBLC1    = 0                   PDIBLC2    = '-0.0010155488+dpdiblc2p_mlvt'
+WPDIBLC2   = 8.2283226e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0021580667
+LTVOFF     = 0                   WTVOFF     = -1.0978133e-010     PTVOFF     = 0
+KT1        = -0.20282363         WKT1       = 2.5675605e-009      KT1L       = 0
+KT2        = -0.068142667        WKT2       = 7.6648533e-009      UTE        = -2
+UA1        = -6.0133333e-011     WUA1       = -2.7643733e-016     UB1        = -2.9933333e-018
+WUB1       = 9.2586667e-025      UC1        = 1.2064667e-010      WUC1       = -4.8078933e-017
+PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+LU0        = '0+dlu0p_mlvt'           WU0        = '0+dwu0p_mlvt'           PU0        = '0+dpu0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'
+LPCLM      = '0+dlpclmp_mlvt'          PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp_mlvt'
+LMAX       = '1.000249e-005-dxlp_mlvt'
+WMIN       = '3e-007-dxwp_mlvt'       WMAX       = '6e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39511135+dvthp_mlvt' LVTH0      = '-7.4615193e-009+dlvthp_mlvt'
+WVTH0      = '-1.2669942e-009+dwvthp_mlvt'
+PVTH0      = '-1.21399e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0067699412+dk2p_mlvt' LK2        = '1.4234884e-008+dlk2p_mlvt'
+WK2        = '1.1777893e-009+dwk2p_mlvt'
+PK2        = '-2.0691983e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -2.2145724e-005
+LCIT       = '4.4388304e-010+dlcitp_mlvt'
+WCIT       = '-7.5678113e-012+dwcitp_mlvt'
+PCIT       = '1.0495413e-016+dpcitp_mlvt'
+VOFF       = -0.090810617        LVOFF      = '-7.9159727e-009+dlvoffp_mlvt'
+WVOFF      = '-1.5005549e-009+dwvoffp_mlvt'
+PVOFF      = '1.001765e-015+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018093556+du0p_mlvt'  LU0        = '3.6322634e-010+dlu0p_mlvt'
+WU0        = '9.9437966e-012+dwu0p_mlvt'
+PU0        = '-9.9105843e-017+dpu0p_mlvt'
+UA         = 1.8814664e-009      LUA        = -4.5513902e-016     WUA        = -2.4130478e-016
+PUA        = 1.5078246e-022      UB         = 8.9943727e-019      LUB        = 8.1814046e-025
+WUB        = 1.2644841e-026      PUB        = -2.4359015e-031     UC         = 5.3614712e-012
+LUC        = 7.3299647e-017      WUC        = 9.3207029e-018      PUC        = -1.8348739e-023
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9358235           LA0        = -2.0972081e-007
+WA0        = 2.6201814e-007      PA0        = -6.3039668e-013     AGS        = 0.88551891
+LAGS       = 3.1380883e-007      WAGS       = 1.070075e-008       PAGS       = 1.6668688e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021109528        LKETA      = -3.8555513e-008
+WKETA      = 2.6265942e-009      PKETA      = 3.2846508e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '-0.0022129374+dpdiblc2p_mlvt'
+LPDIBLC2   = 1.1933893e-008      WPDIBLC2   = 1.0532586e-009      PPDIBLC2   = -2.296567e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0022502516        LTVOFF     = -9.1876997e-010
+WTVOFF     = -1.2931379e-010     PTVOFF     = 1.9467219e-016      KT1        = -0.20007204
+LKT1       = -2.7424003e-008     WKT1       = 2.3262956e-009      PKT1       = 2.4045909e-015
+KT1L       = 0                   KT2        = -0.071334663        LKT2       = 3.1813347e-008
+WKT2       = 8.9120895e-009      PKT2       = -1.2430704e-014     UTE        = -2
+UA1        = -2.1898977e-011     LUA1       = -3.8106653e-016     WUA1       = -3.0946494e-016
+PUA1       = 3.2917298e-022      UB1        = -3.0398017e-018     LUB1       = 4.6313143e-025
+WUB1       = 1.0032862e-024      PUB1       = -7.7160978e-031     UC1        = 1.3668863e-010
+LUC1       = -1.5988382e-016     WUC1       = -5.3263913e-017     PUC1       = 5.1676618e-023
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp_mlvt'
+LMAX       = '1.002493e-006-dxlp_mlvt'
+WMIN       = '3e-007-dxwp_mlvt'       WMAX       = '6e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.4015281+dvthp_mlvt'  LVTH0      = '-1.25909e-009+dlvthp_mlvt'
+WVTH0      = '-2.2399062e-009+dwvthp_mlvt'
+PVTH0      = '-2.7357417e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020322269+dk2p_mlvt'  LK2        = '1.135217e-009+dlk2p_mlvt'
+WK2        = '-7.2394308e-010+dwk2p_mlvt'
+PK2        = '-2.309857e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00012950653
+LCIT       = '2.9729612e-010+dlcitp_mlvt'
+WCIT       = '1.6340624e-010+dwcitp_mlvt'
+PCIT       = '-6.0309219e-017+dpcitp_mlvt'
+VOFF       = -0.094380138        LVOFF      = '-4.4656764e-009+dlvoffp_mlvt'
+WVOFF      = '3.3559208e-010+dwvoffp_mlvt'
+PVOFF      = '-7.7305283e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15749467+deta0p_mlvt' WETA0      = '-5.1054933e-009+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018516405+du0p_mlvt'  LU0        = '-4.5499382e-011+dlu0p_mlvt'
+WU0        = '-1.2564511e-010+dwu0p_mlvt'
+PU0        = '3.1954257e-017+dpu0p_mlvt'
+UA         = 1.3874016e-009      LUA        = 2.2423545e-017      WUA        = -5.7563571e-017
+PUA        = -2.6821604e-023     UB         = 1.8599319e-018      LUB        = -1.1027271e-025
+WUB        = -3.0842538e-025     PUB        = 6.6756003e-032      UC         = 6.9923054e-011
+LUC        = 1.0894485e-017      WUC        = -6.141356e-018      PUC        = -3.4031283e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.5679137           LA0        = -8.2069853e-007
+WA0        = -4.7050432e-007     PA0        = 7.7658793e-014      AGS        = 0.81346956
+LAGS       = 3.8345165e-007      WAGS       = 2.7171899e-008      PAGS       = 7.4769166e-016
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.040814855        LKETA      = -1.9508364e-008
+WKETA      = 3.1424638e-009      PKETA      = 2.7860117e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.68757773          LPCLM      = '3.0198705e-007+dlpclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0094980747+dpdiblc2p_mlvt'
+LPDIBLC2   = 6.1404034e-010      WPDIBLC2   = -1.219359e-009      PPDIBLC2   = -9.9857052e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.00090537312       LTVOFF     = 3.8118819e-010
+WTVOFF     = 1.3179714e-010      PTVOFF     = -5.7717376e-017     KT1        = -0.23415174
+LKT1       = 5.5174081e-009      WKT1       = 5.7807717e-009      PKT1       = -9.3450223e-016
+KT1L       = 0                   KT2        = -0.030743494        LKT2       = -7.4220364e-009
+WKT2       = -3.7849339e-009     PKT2       = -1.5777414e-016     UTE        = -2.1773101
+LUTE       = 1.7138772e-007      WUTE       = 4.5042127e-008      PUTE       = -4.3537675e-014
+UA1        = -1.1220652e-009     LUA1       = 6.8235303e-016      WUA1       = 2.2488985e-016
+PUA1       = -1.8733383e-022     UB1        = -2.1861765e-018     LUB1       = -3.6198181e-025
+WUB1       = 8.5176483e-026      PUB1       = 1.1583418e-031      UC1        = -9.4282854e-011
+LUC1       = 6.3372989e-017      WUC1       = 6.736151e-019       PUC1       = -4.5934244e-025
+PRT        = 0
+AT         = '274020.76+datp_mlvt'
+LAT        = '-0.081214384+dlatp_mlvt'
+WAT        = '0.0095043019+dwatp_mlvt'
+PAT        = '-9.1868488e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'         PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_mlvt'
+LMAX       = '2.399996e-007-dxlp_mlvt'
+WMIN       = '3e-007-dxwp_mlvt'       WMAX       = '6e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.41517553+dvthp_mlvt' LVTH0      = '1.8811701e-009+dlvthp_mlvt'
+WVTH0      = '-5.5183106e-009+dwvthp_mlvt'
+PVTH0      = '4.807834e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020374292+dk2p_mlvt'  LK2        = '1.1232467e-009+dlk2p_mlvt'
+WK2        = '-1.0241103e-009+dwk2p_mlvt'
+PK2        = '-1.6191751e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00085869844
+LCIT       = '1.2950979e-010+dlcitp_mlvt'
+WCIT       = '-1.0081518e-010+dwcitp_mlvt'
+PCIT       = '4.878646e-019+dpcitp_mlvt'
+VOFF       = -0.10161713         LVOFF      = '-2.8004515e-009+dlvoffp_mlvt'
+WVOFF      = '-4.2791006e-009+dwvoffp_mlvt'
+PVOFF      = '2.8878333e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.15634998+deta0p_mlvt' LETA0      = '2.6339076e-010+dleta0p_mlvt'
+WETA0      = '-4.7391943e-009+dweta0p_mlvt'
+PETA0      = '-8.4285042e-017+dpeta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.017556708+du0p_mlvt'  LU0        = '1.7532593e-010+dlu0p_mlvt'
+WU0        = '5.1812534e-010+dwu0p_mlvt'
+PU0        = '-1.1617668e-016+dpu0p_mlvt'
+UA         = 1.7606824e-009      LUA        = -6.3467987e-017     WUA        = -2.1515951e-016
+PUA        = 9.4410636e-024      UB         = 1.070533e-018       LUB        = 7.1367198e-026
+WUB        = 1.0174729e-025      PUB        = -2.7624318e-032     UC         = 1.2252387e-010
+LUC        = -1.2089108e-018     WUC        = -2.7979981e-017     PUC        = 1.6219176e-024
+VSAT       = '107365.33+dvsatp_mlvt'  LVSAT      = '0.00060623504+dlvsatp_mlvt'
+WVSAT      = '0.0016334957+dwvsatp_mlvt'
+PVSAT      = '-3.7586573e-010+dpvsatp_mlvt'
+A0         = 2.4886762           LA0        = -1.1216906e-007     WA0        = -1.7134175e-007
+PA0        = 8.821785e-015       AGS        = 4.7607057           LAGS       = -5.2480344e-007
+WAGS       = -2.1052918e-007     PAGS       = 5.5442473e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.12603645         LKETA      = 1.0103917e-010      WKETA      = 1.2478354e-008
+PKETA      = 6.3783275e-016      DWG        = 0                   DWB        = 0
+PCLM       = 2.6591518           LPCLM      = '-1.5167017e-007+dlpclmp_mlvt'
+WPCLM      = 3.3108978e-008      PPCLM      = '-7.6183427e-015+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.018189484+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.3858441e-009     WPDIBLC2   = -2.7423305e-009     PPDIBLC2   = 2.5057715e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0028034616        LTVOFF     = -5.5560064e-011
+WTVOFF     = -2.6970243e-011     PTVOFF     = -2.1185159e-017     KT1        = -0.21668017
+LKT1       = 1.4972169e-009      WKT1       = 9.2746875e-010      PKT1       = 1.8223793e-016
+KT1L       = 0                   KT2        = -0.053089879        LKT2       = -2.2801556e-009
+WKT2       = -6.6189077e-009     PKT2       = 4.9432038e-016      UTE        = -1.3070703
+LUTE       = -2.8853573e-008     WUTE       = -2.817803e-007      PUTE       = 3.166384e-014
+UA1        = 3.5137962e-009      LUA1       = -3.8435405e-016     WUA1       = -1.2145568e-015
+PUA1       = 1.438814e-022       UB1        = -5.6340411e-018     LUB1       = 4.3136838e-025
+WUB1       = 1.0687354e-024      PUB1       = -1.1048174e-031     UC1        = 9.1514618e-011
+LUC1       = 2.0621177e-017      WUC1       = 1.897228e-017       PUC1       = -4.6698469e-024
+PRT        = 0
+AT         = '-52217.376+datp_mlvt'
+LAT        = '-0.0061473152+dlatp_mlvt'
+WAT        = '-0.058586759+dwatp_mlvt'
+PAT        = '6.4808363e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_mlvt'
+WMIN       = '3e-007-dxwp_mlvt'       WMAX       = '6e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.37757342+dvthp_mlvt'
+LVTH0      = '-1.8226422e-09+dlvthp_mlvt'
+WVTH0      = '1.067369e-08+dwvthp_mlvt'
+PVTH0      = '-1.1141261e-15+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.020043122+dk2p_mlvt'  LK2        = '1.1558669e-009+dlk2p_mlvt'
+WK2        = '-4.7286672e-009+dwk2p_mlvt'
+PK2        = '2.0298134e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.00057667646
+LCIT       = '2.7089523e-10+dlcitp_mlvt'
+WCIT       = '-7.9630182e-10+dwcitp_mlvt'
+PCIT       = '6.8992913e-17+dpcitp_mlvt'
+VOFF       = '-0.078279894+0.00945867*ff_flag_mlvt+0.00756691*sf_flag_mlvt-0.00756691*fs_flag_mlvt'
+LVOFF      = '-5.0991733e-09+dlvoffp_mlvt-9.31673e-10*ff_flag_mlvt-7.45341e-10*sf_flag_mlvt+7.45341e-10*fs_flag_mlvt'
+WVOFF      = '-4.20992e-10+dwvoffp_mlvt+4.8e-15*ff_flag_mlvt-2e-16*sf_flag_mlvt+2e-16*fs_flag_mlvt'
+PVOFF      = '-9.123907e-17+dpvoffp_mlvt+3.1e-22*ff_flag_mlvt-1.5e-22*sf_flag_mlvt+1.5e-22*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt-0.261239*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+ETA0       = '0.12992738+deta0p_mlvt'
+WETA0      = '1.5540629e-09+dweta0p_mlvt'
+ETAB       = -0.085099333        WETAB      = 2.1757867e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.019574783+du0p_mlvt-0.00111702*ff_flag_mlvt-0.000288264*ss_flag_mlvt-0.000893618*sf_flag_mlvt+0.000893618*fs_flag_mlvt'
+LU0        = '-2.3454436e-011+dlu0p_mlvt+1.10026e-10*ff_flag_mlvt+2.83939e-11*ss_flag_mlvt+8.80211e-11*sf_flag_mlvt-8.80211e-11*fs_flag_mlvt'
+WU0        = '-8.9317888e-010+dwu0p_mlvt+3.57447e-10*ff_flag_mlvt+1.78724e-10*ss_flag_mlvt+2.85958e-10*sf_flag_mlvt-2.85958e-10*fs_flag_mlvt'
+PU0        = '2.2836786e-017+dpu0p_mlvt-3.52084e-17*ff_flag_mlvt-1.76042e-17*ss_flag_mlvt-2.81668e-17*sf_flag_mlvt+2.81668e-17*fs_flag_mlvt'
+UA         = 2.4017479e-09
+LUA        = -1.2661298e-16
+WUA        = -2.6170787e-16
+PUA        = 1.402609e-23
+UB         = -3.9047577e-19
+LUB        = 2.1527654e-25
+WUB        = -4.257349e-26
+PUB        = -1.3408738e-32
+UC         = -1.5114415e-010
+LUC        = 2.574739e-017       WUC        = 4.4193923e-018      PUC        = -1.5694208e-024
+VSAT       = '107609.88+dvsatp_mlvt+5585.11*ff_flag_mlvt+4468.09*sf_flag_mlvt-4468.09*fs_flag_mlvt'
+LVSAT      = '0.00058214433+dlvsatp_mlvt-0.000550132*ff_flag_mlvt-0.000440105*sf_flag_mlvt+0.000440105*fs_flag_mlvt'
+WVSAT      = '-0.0020840957+dwvsatp_mlvt-0.00178724*ff_flag_mlvt-0.00142979*sf_flag_mlvt+0.00142979*fs_flag_mlvt'
+PVSAT      = '-9.68219e-12+dpvsatp_mlvt+1.76042e-10*ff_flag_mlvt+1.40834e-10*sf_flag_mlvt-1.40834e-10*fs_flag_mlvt'
+A0         = -3.5451926          LA0        = 4.8216702e-007      WA0        = -6.7893192e-008
+PA0        = -1.3678978e-015     AGS        = -1.544912           LAGS       = 9.62999e-008
+WAGS       = 9.5467378e-007      PAGS       = -5.9330019e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.28207926         LKETA      = 1.5471256e-008      WKETA      = 1.8752824e-008
+PKETA      = 1.9797485e-017      DWG        = 0                   DWB        = 0
+PCLM       = '1.5673166-0.288264*ss_flag_mlvt'
+LPCLM      = '-4.4124358e-08+dlpclmp_mlvt+2.83939e-08*ss_flag_mlvt'
+WPCLM      = '-2.7082666e-07+1.78724e-07*ss_flag_mlvt'
+PPCLM      = '2.2319318e-14+dppclmp_mlvt-1.76042e-14*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0057499399+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.6054908e-010     WPDIBLC2   = -1.2089627e-009     PPDIBLC2   = 9.9540429e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.003039542         LTVOFF     = -7.8813989e-011
+WTVOFF     = -8.0234889e-010     PTVOFF     = 5.5189638e-017
+KT1        = -0.22681153
+LKT1       = 2.4951627e-09
+WKT1       = 2.3957035e-08
+PKT1       = -2.0861782e-15
+KT1L       = 0                   KT2        = -0.092007203        LKT2       = 1.5532008e-009
+WKT2       = -7.877144e-009      PKT2       = 6.1825666e-016      UTE        = -2.9967679
+LUTE       = 1.3758164e-007      WUTE       = 4.2144814e-007      PUTE       = -3.7604162e-014
+UA1        = -4.748832e-009      LUA1       = 4.2951483e-016      WUA1       = 6.6412562e-016
+PUA1       = -4.1168815e-023     UB1        = -7.634209e-019      LUB1       = -4.8387708e-026
+WUB1       = 8.0045741e-025      PUB1       = -8.4056362e-032     UC1        = 2.3476355e-010
+LUC1       = 6.5111571e-018      WUC1       = 2.0967956e-017      PUC1       = -4.866421e-024
+PRT        = 0
+AT         = '-240720.63+datp_mlvt'
+LAT        = '0.012420255+dlatp_mlvt'
+WAT        = '0.047069619+dwatp_mlvt'
+PAT        = '-3.9263169e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '2.8660095e-09+dleta0p_mlvt'
+PETA0      = '-7.0416881e-16+dpeta0p_mlvt'
+LNFACTOR   = '0+dlnfactorp_mlvt+2.5732e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt-8.93621e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt+8.80214e-15*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '1.000249e-005-dxlp_mlvt'
+LMAX       = 2.000001e-05        WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_mlvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_mlvt'              TOXM       = 2.8e-009            DTOX       = 4.216e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'
+DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39886347+dvthp_mlvt' WVTH0      = '-4.2769067e-010+dwvthp_mlvt'
+K1         = 0.23752             K2         = '0.0042611111+dk2p_mlvt' WK2        = '2.2300444e-009+dwk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 3.3905556e-005
+WCIT       = '-7.2177778e-013+dwcitp_mlvt'
+VOFF       = -0.094192791        WVOFF      = '-5.7190684e-010+dwvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018635556+du0p_mlvt'  WU0        = '-1.6177778e-010+dwu0p_mlvt'
+UA         = 1.7390889e-009      WUA        = -1.9522844e-016     UB         = 9.0724751e-019
+WUB        = 1.1973148e-026      UC         = 2.7868889e-011      WUC        = 2.6307556e-018
+VSAT       = '110000+dvsatp_mlvt'     A0         = 4.9424518           WA0        = 1.8991262e-007
+AGS        = 0.96980191          WAGS       = -4.5218203e-009     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.025255333        WKETA      = 3.0449067e-009      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.0012224845+dpdiblc2p_mlvt'
+WPDIBLC2   = 1.0666159e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 2.1                 DELTA      = 0.036               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = '75+drdswp_mlvt'         RDW        = '75+drdswp_mlvt'         PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.945e-007
+ALPHA1     = 0.23                BETA0      = 17.8                AGIDL      = 1e-008
+BGIDL      = 2.317e+009          CGIDL      = 4.6                 EGIDL      = 0.008744
+AIGBACC    = 0.012459            BIGBACC    = 0.0046798592        CIGBACC    = 0.245
+NIGBACC    = 8.2582031           AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1
+AIGC       = 0.006941            BIGC       = 0.0013212138        CIGC       = 0.1525875
+AIGSD      = 0.00629             BIGSD      = 0.00033134367       CIGSD      = 0.01328125
+NIGC       = 2                   POXEDGE    = 1                   PIGCD      = 2.84
+NTOX       = 'ntoxp_mlvt'             XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgop_mlvt'              CGDO       = 'cgop_mlvt'              CGBO       = 0
+CGDL       = 'cglp_mlvt'              CGSL       = 'cglp_mlvt'              CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_mlvt'               CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 6.8381
+NOFF       = 2.3364              VOFFCV     = -0.069707           TVOFF      = 0.0019168889
+LTVOFF     = 0                   WTVOFF     = -3.2604444e-011     PTVOFF     = 0
+KT1        = -0.18476667         WKT1       = -3.2106667e-009     KT1L       = 0
+KT2        = -0.046056667        WKT2       = 5.9733333e-010      UTE        = -2
+UA1        = -1.4863333e-009     WUA1       = 1.7994667e-016      UB1        = 1.9633333e-019
+WUB1       = -9.4826667e-026     UC1        = -8.8333333e-012     WUC1       = -6.6453333e-018
+PRT        = 0
+AT         = '195000+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT      = '0+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_mlvt'
+PVTH0      = '0+dpvthp_mlvt'          LK2        = '0+dlk2p_mlvt'           PK2        = '0+dpk2p_mlvt'
+LCIT       = '0+dlcitp_mlvt'          PCIT       = '0+dpcitp_mlvt'          LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LVOFF      = '0+dlvoffp_mlvt'          PVOFF      = '0+dpvoffp_mlvt'
+LU0        = '0+dlu0p_mlvt'           PU0        = '0+dpu0p_mlvt'           LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '1.002493e-006-dxlp_mlvt'
+LMAX       = '1.000249e-005-dxlp_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '1.894715e-08+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.39822143+dvthp_mlvt' LVTH0      = '-6.3989092e-009+dlvthp_mlvt'
+WVTH0      = '-2.7176737e-010+dwvthp_mlvt'
+PVTH0      = '-1.5540252e-015+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.0031573454+dk2p_mlvt' LK2        = '1.1000792e-008+dlk2p_mlvt'
+WK2        = '2.3338199e-009+dwk2p_mlvt'
+PK2        = '-1.0342889e-015+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -5.0119082e-005
+LCIT       = '8.3743995e-010+dlcitp_mlvt'
+WCIT       = '1.3836631e-012+dwcitp_mlvt'
+PCIT       = '-2.0984087e-017+dpcitp_mlvt'
+VOFF       = -0.093830612        LVOFF      = '-3.6096908e-009+dlvoffp_mlvt'
+WVOFF      = '-5.3415624e-010+dwvoffp_mlvt'
+PVOFF      = '-3.7624521e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018684482+du0p_mlvt'  LU0        = '-4.8763196e-010+dlu0p_mlvt'
+WU0        = '-1.7915269e-010+dwu0p_mlvt'
+PU0        = '1.7316881e-016+dpu0p_mlvt'
+UA         = 1.7479112e-009      LUA        = -8.7928367e-017     WUA        = -1.985671e-016
+PUA        = 3.3275053e-023      UB         = 9.0136967e-019      LUB        = 5.8582143e-026
+WUB        = 1.2026475e-026      PUB        = -5.3148705e-034     UC         = 2.5555018e-011
+LUC        = 2.3061424e-017      WUC        = 2.8587679e-018      PUC        = -2.2725076e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 5.1522506           LA0        = -2.0909813e-006
+WA0        = 1.9276147e-007      PA0        = -2.8393315e-014     AGS        = 0.94067619
+LAGS       = 2.9028438e-007      WAGS       = -6.94958e-009       PAGS       = 2.419651e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022063743        LKETA      = -3.1809303e-008
+WKETA      = 2.931943e-009       PKETA      = 1.1258637e-015      DWG        = 0
+DWB        = 0                   PCLM       = 1                   PDIBLC1    = 0
+PDIBLC2    = '0.00073443994+dpdiblc2p_mlvt'
+LPDIBLC2   = 4.8641453e-009      WPDIBLC2   = 1.1009784e-010      PPDIBLC2   = -3.4247737e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0019628202        LTVOFF     = -4.5777937e-010
+WTVOFF     = -3.7335767e-011     PTVOFF     = 4.71552e-017        KT1        = -0.18211747
+LKT1       = -2.6403487e-008     WKT1       = -3.4191656e-009     PKT1       = 2.0780258e-015
+KT1L       = 0                   KT2        = -0.045396993        LKT2       = -6.574706e-009
+WKT2       = 6.1203518e-010      PKT2       = -1.4652746e-016     UTE        = -2
+UA1        = -1.5686016e-009     LUA1       = 8.199353e-016       WUA1       = 1.8547991e-016
+PUA1       = -5.5147606e-023     UB1        = 4.3030993e-019      LUB1       = -2.3319512e-024
+WUB1       = -1.0714949e-025     PUB1       = 1.2281665e-031      UC1        = -8.5684136e-012
+LUC1       = -2.6403487e-018     WUC1       = -6.7816596e-018     PUC1       = 1.3587091e-024
+PRT        = 0
+AT         = '195537+datp_mlvt'
+PAT      = '0+dpatp_mlvt'
+WAT      = '0+dwatp_mlvt'
+LAT        = '-0.0053520581+dlatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07
+JSD        = 1.82e-07            JSWS       = 2.71e-13            JSWD       = 2.71e-13
+JSWGS      = 2.71e-13            JSWGD      = 2.71e-13            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjp_mlvt'
+CJD        = 'cjp_mlvt'               MJS        = 0.4                 MJD        = 0.4
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'
+CJSWD      = 'cjswp_mlvt'             MJSWS      = 0.062               MJSWD      = 0.062
+PBSWGS     = 0.75                PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'
+CJSWGD     = 'cjswgp_mlvt'            MJSWGS     = 0.95                MJSWGD     = 0.95
+TPB        = 0.003               TCJ        = 0.00105             TPBSW      = 0.002
+TCJSW      = 0.0002              TPBSWG     = 0.0005              TCJSWG     = 0.00132
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.033e-007
+JTSSWGD    = 1.033e-007          NJTSSWG    = 5.7                 VTSSWGS    = 0.1
+VTSSWGD    = 0.1                 DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'         PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt'      PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'
+LVSAT      = '0+dlvsatp_mlvt'         WVSAT      = '0+dwvsatp_mlvt'         LPCLM      = '0+dlpclmp_mlvt'
+PPCLM      = '0+dppclmp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399996e-007-dxlp_mlvt'
+LMAX       = '1.002493e-006-dxlp_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-7.573426e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.40428089+dvthp_mlvt' LVTH0      = '-5.4184208e-010+dlvthp_mlvt'
+WVTH0      = '-1.3590142e-009+dwvthp_mlvt'
+PVTH0      = '-5.0309352e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.013617963+dk2p_mlvt'  LK2        = '8.8956963e-010+dlk2p_mlvt'
+WK2        = '1.421435e-009+dwk2p_mlvt'
+PK2        = '-1.5237854e-016+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00066489035
+LCIT       = '1.4631255e-010+dlcitp_mlvt'
+WCIT       = '-7.916586e-012+dwcitp_mlvt'
+PCIT       = '-1.1994475e-017+dpcitp_mlvt'
+VOFF       = -0.09086501         LVOFF      = '-6.476239e-009+dlvoffp_mlvt'
+WVOFF      = '-7.89249e-010+dwvoffp_mlvt'
+PVOFF      = '-1.296728e-016+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018126194+du0p_mlvt'  LU0        = '5.2008881e-011+dlu0p_mlvt'
+WU0        = '-7.7758431e-013+dwu0p_mlvt'
+PU0        = '7.5161222e-019+dpu0p_mlvt'
+UA         = 1.7085045e-009      LUA        = -4.983793e-017      WUA        = -1.6031651e-016
+PUA        = -3.6979321e-024     UB         = 8.8465665e-019      LUB        = 7.4736926e-026
+WUB        = 3.6627113e-027      PUB        = 7.5529189e-033      UC         = 5.2502842e-011
+LUC        = -2.9863164e-018     WUC        = -5.6688818e-019     PUC        = 1.0387281e-024
+VSAT       = '110000+dvsatp_mlvt'     A0         = 3.324562            LA0        = -3.2433938e-007
+WA0        = 2.4736821e-007      PA0        = -8.1176135e-014     AGS        = 0.63607723
+LAGS       = 5.8470942e-007      WAGS       = 8.3937444e-008      PAGS       = -6.3654797e-014
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.039544464        LKETA      = -1.4912456e-008
+WKETA      = 2.7359386e-009      PKETA      = 1.3153214e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.63897871          LPCLM      = '3.4896282e-007+dlpclmp_mlvt'
+WPCLM      = 1.5551686e-008      PPCLM      = '-1.5032244e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0048953557+dpdiblc2p_mlvt'
+LPDIBLC2   = 8.4220833e-010      WPDIBLC2   = 2.5351106e-010      PPDIBLC2   = -1.7287081e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0014875213        LTVOFF     = 1.6441517e-012
+WTVOFF     = -5.4490261e-011     PTVOFF     = 6.3736716e-017      KT1        = -0.19632548
+LKT1       = -1.2670035e-008     WKT1       = -6.3236314e-009     PKT1       = 4.8854794e-015
+KT1L       = 0                   KT2        = -0.040190418        LKT2       = -1.1607376e-008
+WKT2       = -7.6191809e-010     PKT2       = 1.1815344e-015      UTE        = -1.9417853
+LUTE       = -5.6270254e-008     WUTE       = -3.0325788e-008     PUTE       = 2.9312876e-014
+UA1        = -7.5913757e-010     LUA1       = 3.7508134e-017      WUA1       = 1.0875301e-016
+PUA1       = 1.9016541e-023      UB1        = -1.8971739e-018     LUB1       = -8.2207586e-026
+WUB1       = -7.3043398e-027     PUB1       = 2.6306428e-032      UC1        = -8.4465824e-011
+LUC1       = 7.0722012e-017      WUC1       = -2.4678347e-018     PUC1       = -2.8110297e-024
+PRT        = 0
+AT         = '310768.56+datp_mlvt'
+LAT        = '-0.11673477+dlatp_mlvt'
+WAT        = '-0.0022549945+dwatp_mlvt'
+PAT        = '2.1796754e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'      PVSAT      = '0+dpvsatp_mlvt'         LVSAT      = '0+dlvsatp_mlvt'
+WVSAT      = '0+dwvsatp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_mlvt'
+LMAX       = '2.399996e-007-dxlp_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.42302095+dvthp_mlvt' LVTH0      = '3.7702272e-009+dlvthp_mlvt'
+WVTH0      = '-3.0077769e-009+dwvthp_mlvt'
+PVTH0      = '-1.2371486e-016+dpvthp_mlvt'
+K1         = 0.23752             K2         = '0.015925729+dk2p_mlvt'  LK2        = '3.5855486e-010+dlk2p_mlvt'
+WK2        = '3.9942964e-010+dwk2p_mlvt'
+PK2        = '8.2783879e-017+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00087740207
+LCIT       = '9.7413814e-011+dlcitp_mlvt'
+WCIT       = '-1.0680034e-010+dwcitp_mlvt'
+PCIT       = '1.0758577e-017+dpcitp_mlvt'
+VOFF       = -0.11205689         LVOFF      = '-1.6000077e-009+dlvoffp_mlvt'
+WVOFF      = '-9.3837657e-010+dwvoffp_mlvt'
+PVOFF      = '-9.5358696e-017+dpvoffp_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt'     ETA0       = '0.17773778+deta0p_mlvt' WETA0      = '-1.1583289e-008+dweta0p_mlvt'
+ETAB       = -0.032255556        WETAB      = -1.4734222e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.018941031+du0p_mlvt'  LU0        = '-1.3548435e-010+dlu0p_mlvt'
+WU0        = '7.5141923e-011+dwu0p_mlvt'
+PU0        = '-1.6717391e-017+dpu0p_mlvt'
+UA         = 1.6454109e-009      LUA        = -3.5320138e-017     WUA        = -1.7827262e-016
+PUA        = 4.3375199e-025      UB         = 1.4480642e-018      LUB        = -5.4902581e-026
+WUB        = -1.9062694e-026     PUB        = 1.2782012e-032      UC         = 3.5249758e-011
+LUC        = 9.8360105e-019      WUC        = -5.2264908e-020     PUC        = 9.2031378e-025
+VSAT       = '114391.12+dvsatp_mlvt'  LVSAT      = '-0.0010103917+dlvsatp_mlvt'
+WVSAT      = '-0.00061475644+dwvsatp_mlvt'
+PVSAT      = '1.4145484e-010+dpvsatp_mlvt'
+A0         = 2.7585035           LA0        = -1.9408989e-007     WA0        = -2.576865e-007
+PA0        = 3.5036449e-014      AGS        = 4.8481565           LAGS       = -3.844858e-007
+WAGS       = -2.3851344e-007     PAGS       = 1.0540829e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.081442179        LKETA      = -5.2718337e-009     WKETA      = -1.7918112e-009
+PKETA      = 2.3571521e-015      DWG        = 0                   DWB        = 0
+PCLM       = 3.228392            LPCLM      = '-2.468586e-007+dlpclmp_mlvt'
+WPCLM      = -1.490479e-007      PPCLM      = '2.2841957e-014+dppclmp_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.013031169+dpdiblc2p_mlvt'
+LPDIBLC2   = -1.0298341e-009     WPDIBLC2   = -1.0916698e-009     PPDIBLC2   = 1.3665395e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 0.0016914353        LTVOFF     = -4.5276266e-011
+WTVOFF     = 3.2887816e-010      PTVOFF     = -2.4475974e-017     KT1        = -0.29006066
+LKT1       = 8.8983363e-009      WKT1       = 2.4409226e-008      PKT1       = -2.1861203e-015
+KT1L       = 0                   KT2        = -0.081513175        LKT2       = -2.0990506e-009
+WKT2       = 2.4765473e-009      PKT2       = 4.3636676e-016      UTE        = -2.4467233
+LUTE       = 5.9915465e-008      WUTE       = 8.290864e-008       PUTE       = 3.2577479e-015
+UA1        = -2.3362551e-010     LUA1       = -8.3411665e-017     WUA1       = -1.5381806e-017
+PUA1       = 4.7579837e-023      UB1        = -3.3796683e-018     LUB1       = 2.5891288e-025
+WUB1       = 3.4733611e-025      PUB1       = -5.5295984e-032     UC1        = 1.9960266e-010
+LUC1       = 5.358138e-018       WUC1       = -1.5615894e-017     PUC1       = 2.1432552e-025
+PRT        = 0
+AT         = '-253490.39+datp_mlvt'
+LAT        = '0.013100647+dlatp_mlvt'
+WAT        = '0.005820604+dwatp_mlvt'
+PAT        = '3.2148828e-10+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_mlvt'
+PETA0      = '0+dpeta0p_mlvt'         LNFACTOR   = '0+dlnfactorp_mlvt'      WNFACTOR   = '0+dwnfactorp_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_mlvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_mlvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_mlvt'       VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_mlvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_mlvt'
+TOXM       = 2.8e-009            DTOX       = 4.216e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_mlvt'        XW         = '2.0e-08+dxwp_mlvt'      DLC        = '-6.55e-09+ddlcp_mlvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.32081892+dvthp_mlvt-0.00525481*ff_flag_mlvt-0.00420385*sf_flag_mlvt+0.00420385*fs_flag_mlvt'
+LVTH0      = '-6.2966677e-09+dlvthp_mlvt+5.17597e-10*ff_flag_mlvt+4.14078e-10*sf_flag_mlvt-4.14078e-10*fs_flag_mlvt'
+WVTH0      = '-7.4877523e-09+dwvthp_mlvt+1.68154e-09*ff_flag_mlvt+1.34523e-09*sf_flag_mlvt-1.34523e-09*fs_flag_mlvt'
+PVTH0      = '3.1756204e-16+dpvthp_mlvt-1.65631e-16*ff_flag_mlvt-1.32505e-16*sf_flag_mlvt+1.32505e-16*fs_flag_mlvt'
+K1         = 0.23752             K2         = '-9.6172764e-005+dk2p_mlvt'
+LK2        = '1.9367122e-009+dlk2p_mlvt'
+WK2        = '1.7159072e-009+dwk2p_mlvt'
+PK2        = '-4.6889159e-017+dpk2p_mlvt'
+K3         = -2.4570454          K3B        = 2.1204211           W0         = 0
+DVT0       = 10.498235           DVT1       = 1.3326361           DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.4494              MINV       = -0.335              VOFFL      = 0
+DVTP0      = 1e-010              DVTP1      = 0.3712              LPE0       = 1.4959847e-007
+LPEB       = 3.4167544e-008      WEB        = -210                WEC        = -3510
+SCREF      = 1e-006
+KVTH0WE    = -0.0038
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0005
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.13e+020           NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = -0.0037013223
+LCIT       = '5.4841801e-10+dlcitp_mlvt'
+WCIT       = '2.0358487e-10+dwcitp_mlvt'
+PCIT       = '-1.9814376e-17+dpcitp_mlvt'
+VOFF       = '-0.050876122+0.0168154*ff_flag_mlvt+0.0134523*sf_flag_mlvt-0.0134523*fs_flag_mlvt'
+LVOFF      = '-7.6263077e-09+dlvoffp_mlvt-1.65631e-09*ff_flag_mlvt-1.32505e-09*sf_flag_mlvt+1.32505e-09*fs_flag_mlvt'
+WVOFF      = '-9.1901995e-09+dwvoffp_mlvt-2.35415e-09*ff_flag_mlvt-1.88332e-09*sf_flag_mlvt+1.88332e-09*fs_flag_mlvt'
+PVOFF      = '7.1744393e-16+dpvoffp_mlvt+2.31884e-16*ff_flag_mlvt+1.85507e-16*sf_flag_mlvt-1.85507e-16*fs_flag_mlvt'
+NFACTOR    = '0.7+dnfactorp_mlvt-0.960879*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+ETA0       = '0.18967042+deta0p_mlvt'
+LETA0      = '-1.1753638e-09+dleta0p_mlvt'
+WETA0      = '-1.7563713e-08+dweta0p_mlvt'
+PETA0      = '5.8907071e-16+dpeta0p_mlvt'
+ETAB       = 0.017265187         LETAB      = -4.8777932e-009     WETAB      = -3.058086e-008
+PETAB      = 1.5608938e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0115
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.016385553+du0p_mlvt+0.00048044*ss_flag_mlvt'
+LU0        = '1.1623009e-10+dlu0p_mlvt-4.73232e-11*ss_flag_mlvt'
+WU0        = '1.2737441e-10+dwu0p_mlvt-6.72616e-11*ss_flag_mlvt'
+PU0        = '-2.1862262e-17+dpu0p_mlvt+6.62524e-18*ss_flag_mlvt'
+UA         = 2.1146812e-009      LUA        = -8.1543267e-017     WUA        = -1.6984654e-016
+PUA        = -3.9621729e-025
+UB         = -8.6501145e-19
+LUB        = 1.7293532e-25
+WUB        = 1.0927793e-25
+PUB        = 1.404511e-34
+UC         = -3.0466952e-010
+LUC        = 3.446565e-017       WUC        = 5.3547512e-017      PUC        = -4.3592643e-024
+VSAT       = '102580.28+dvsatp_mlvt-6305.77*ff_flag_mlvt-5044.62*sf_flag_mlvt+5044.62*fs_flag_mlvt'
+LVSAT      = '0.00015297777+dlvsatp_mlvt+0.000621117*ff_flag_mlvt+0.000496893*sf_flag_mlvt-0.000496893*fs_flag_mlvt'
+WVSAT      = '-0.0004746248+dwvsatp_mlvt+0.00201785*ff_flag_mlvt+0.00161428*sf_flag_mlvt-0.00161428*fs_flag_mlvt'
+PVSAT      = '1.276511e-10+dpvsatp_mlvt-1.98757e-10*ff_flag_mlvt-1.59006e-10*sf_flag_mlvt+1.59006e-10*fs_flag_mlvt'
+A0         = -3.9507937          LA0        = 4.6677589e-007      WA0        = 6.1899155e-008
+PA0        = 3.557262e-015       AGS        = 3.8863976           LAGS       = -2.8975255e-007
+WAGS       = -7.8334526e-007     PAGS       = 6.4206764e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.29827237         LKETA      = 1.608594e-008       WKETA      = 2.3934619e-008
+PKETA      = -1.769013e-016      DWG        = 0                   DWB        = 0
+PCLM       = '-0.15755717+0.48044*ss_flag_mlvt'
+LPCLM      = '8.665732e-08+dlpclmp_mlvt-4.73232e-08*ss_flag_mlvt'
+WPCLM      = '2.8113294e-07-6.72616e-08*ss_flag_mlvt'
+PPCLM      = '-1.9530819e-14+dppclmp_mlvt+6.62524e-15*ss_flag_mlvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00014056647+dpdiblc2p_mlvt'
+LPDIBLC2   = 2.675818e-010       WPDIBLC2   = 6.7599931e-010      PPDIBLC2   = -3.7461452e-017
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 2.1
+DELTA      = 0.036               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55                  RSW        = '75+drdswp_mlvt'
+RDW        = '75+drdswp_mlvt'         PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1.945e-007          ALPHA1     = 0.23
+BETA0      = 17.8                AGIDL      = 1e-008              BGIDL      = 2.317e+009
+CGIDL      = 4.6                 EGIDL      = 0.008744            AIGBACC    = 0.012459
+BIGBACC    = 0.0046798592        CIGBACC    = 0.245               NIGBACC    = 8.2582031
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1                   AIGC       = 0.006941
+BIGC       = 0.0013212138        CIGC       = 0.1525875           AIGSD      = 0.00629
+BIGSD      = 0.00033134367       CIGSD      = 0.01328125          NIGC       = 2
+POXEDGE    = 1                   PIGCD      = 2.84                NTOX       = 'ntoxp_mlvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_mlvt'
+CGDO       = 'cgop_mlvt'              CGBO       = 0                   CGDL       = 'cglp_mlvt'
+CGSL       = 'cglp_mlvt'              CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_mlvt'               CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 6.8381              NOFF       = 2.3364
+VOFFCV     = -0.069707           TVOFF      = 4.9882714e-005      LTVOFF     = 1.1641666e-010
+WTVOFF     = 1.5434209e-010      PTVOFF     = -7.2841711e-018
+KT1        = -0.13792108
+LKT1       = -6.0874233e-09
+WKT1       = -4.487913e-09
+PKT1       = 6.602493e-16
+KT1L       = 0
+KT2        = -0.16053846
+LKT2       = 5.684922e-09
+WKT2       = 1.4052859e-08
+PKT2       = -7.038941e-16
+UTE        = -2.1874478
+LUTE       = 3.4376828e-008      WUTE       = 1.6246569e-007      PUTE       = -4.5786219e-015
+UA1        = -6.1936262e-009     LUA1       = 5.0364841e-016      WUA1       = 1.1264598e-015
+PUA1       = -6.4891559e-023     UB1        = 4.2688773e-018      LUB1       = -4.9446886e-025
+WUB1       = -8.0987802e-025     PUB1       = 5.8689608e-032      UC1        = 4.6642041e-010
+LUC1       = -2.092341e-017      WUC1       = -5.3162239e-017     PUC1       = 3.9126405e-024
+PRT        = 0
+AT         = '-88342.852+datp_mlvt'
+LAT        = '-0.0031663846+dlatp_mlvt'
+WAT        = '-0.0016912692+dwatp_mlvt'
+PAT        = '1.0614078e-09+dpatp_mlvt'
+NOIA       = 'noiap_mlvt'
+NOIB       = 'noibp_mlvt'
+NOIC       = 'noicp_mlvt'
+EM         = 5e+07
+EF         = 1.1
+JSS        = 1.82e-07            JSD        = 1.82e-07
+JSWS       = 2.71e-13            JSWD       = 2.71e-13            JSWGS      = 2.71e-13
+JSWGD      = 2.71e-13            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9.4                  BVD        = 9.4
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjp_mlvt'               CJD        = 'cjp_mlvt'
+MJS        = 0.4                 MJD        = 0.4                 PBSWS      = 1
+PBSWD      = 1                   CJSWS      = 'cjswp_mlvt'             CJSWD      = 'cjswp_mlvt'
+MJSWS      = 0.062               MJSWD      = 0.062               PBSWGS     = 0.75
+PBSWGD     = 0.75                CJSWGS     = 'cjswgp_mlvt'            CJSWGD     = 'cjswgp_mlvt'
+MJSWGS     = 0.95                MJSWGD     = 0.95                TPB        = 0.003
+TCJ        = 0.00105             TPBSW      = 0.002               TCJSW      = 0.0002
+TPBSWG     = 0.0005              TCJSWG     = 0.00132             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.033e-007          JTSSWGD    = 1.033e-007
+NJTSSWG    = 5.7                 VTSSWGS    = 0.1                 VTSSWGD    = 0.1
+DMCG       = 6.1e-008            DMCI       = 6.6e-008            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-09
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = '-4.5e-008*0.9'
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.2
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_mlvt+9.46463e-08*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+WNFACTOR   = '0+dwnfactorp_mlvt+1.34523e-07*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+PNFACTOR   = '0+dpnfactorp_mlvt-1.32505e-14*ff_flag_mlvt+0.0*sf_flag_mlvt+0.0*fs_flag_mlvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.ENDL MOS_mlvt







***************************************************************
*                                                             *
*                     Low-vt DEVICE MODELS                    *
*                                                             *
***************************************************************
.LIB MOS_lvt
**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_lvt.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_lvt'
+LMAX       = 2.001e-05           WMIN       = '1e-005-dxwn_lvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24337292+dvthn_lvt'
+K1         = 0.217               K2         = '0.04171545+dk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.093354003+dvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.02039+du0n_lvt'
+UA         = '-1.859e-009+duan_lvt'
+UB         = '2.749548e-018+dubn_lvt'
+UC         = 1.1e-010            VSAT       = '100000+dvsatn_lvt' A0         = 3.632
+AGS        = 0.90740823          A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.05681
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.004               PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0007635           LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.2450448+dkt1n_lvt'
+KT1L       = 0                   KT2        = -0.0668             UTE        = -1.31
+UA1        = '1.928e-009+dua1n_lvt'
+UB1        = '-1.661e-018+dub1n_lvt'
+UC1        = 9.447e-012          PRT        = 0                   AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'
+LU0        = '0+dlu0n_lvt'       WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+LUB        = '0+dlubn_lvt'       WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'
+LUA1       = '0+dlua1n_lvt'      WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+LKT1       = '0+dlkt1n_lvt'      WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+LVOFF      = '0+dlvoffn_lvt'     WVOFF      = '0+dwvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_lvt'
+LMAX       = '1e-005-dxln_lvt'   WMIN       = '1e-005-dxwn_lvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24049678+dvthn_lvt'
+LVTH0      = '2.8661084e-008+dlvthn_lvt'
+K1         = 0.217               K2         = '0.043164517+dk2n_lvt'
+LK2        = '-1.444011e-008+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.091965081+dvoffn_lvt'
+LVOFF      = '-1.3840758e-008+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020675244+du0n_lvt'
+LU0        = '-2.8424841e-009+dlu0n_lvt'
+UA         = '-1.8593217e-009+duan_lvt'
+LUA        = '3.2058091e-018+dluan_lvt'
+UB         = '2.7766269e-018+dubn_lvt'
+LUB        = '-2.6984417e-025+dlubn_lvt'
+UC         = 1.1257899e-010      LUC        = -2.5699903e-017     VSAT       = '100000+dvsatn_lvt'
+A0         = 3.7051339           LA0        = -7.2878727e-007     AGS        = 0.8707789
+LAGS       = 3.6501531e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.055983222
+LKETA      = -8.2389294e-009     DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0036782967
+LPDIBLC2   = 3.2058091e-009      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00075734474
+LTVOFF     = 6.1337814e-011      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = '-0.24469058+dkt1n_lvt'
+LKT1       = '-3.5298095e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066867558        LKT2       = 6.7321991e-010
+UTE        = -1.3197583          LUTE       = 9.7242876e-008      UA1        = '1.957275e-009+dua1n_lvt'
+LUA1       = '-2.9172863e-016+dlua1n_lvt'
+UB1        = '-1.6246475e-018+dub1n_lvt'
+LUB1       = '-3.6225643e-025+dlub1n_lvt'
+UC1        = 7.5883054e-012      LUC1       = 1.8522096e-017      PRT        = 0
+AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'
+PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'
+PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.3 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_lvt'
+LMAX       = '1.000002e-006-dxln_lvt'
+WMIN       = '1e-005-dxwn_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27177817+dvthn_lvt'
+LVTH0      = '-1.5288943e-009+dlvthn_lvt'
+K1         = 0.217               K2         = '0.033801092+dk2n_lvt'
+LK2        = '-5.4033748e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '3.8143882e-005+dcitn_lvt'
+LCIT       = '5.9697958e-011+dlcitn_lvt'
+VOFF       = '-0.10018652+dvoffn_lvt'
+LVOFF      = '-5.9061631e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.4567+deta0n_lvt' ETAB       = -0.005528
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018444438+du0n_lvt'
+LU0        = '-6.8951141e-010+dlu0n_lvt'
+UA         = '-1.8411545e-009+duan_lvt'
+LUA        = '-1.432751e-017+dluan_lvt'
+UB         = '2.5673703e-018+dubn_lvt'
+LUB        = '-6.7888553e-026+dlubn_lvt'
+UC         = 9.6276879e-011      LUC        = -9.966574e-018      VSAT       = '100000+dvsatn_lvt'
+A0         = 3.4293849           LA0        = -4.6265917e-007     AGS        = 1.2332136
+LAGS       = 1.5225964e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.076554108
+LKETA      = 1.1614238e-008      DWG        = 0                   DWB        = 0
+PCLM       = 0.81271454          LPCLM      = -1.4297661e-008     PDIBLC1    = 0
+PDIBLC2    = 0.0063814388        LPDIBLC2   = 5.9697958e-010      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00076844601       LTVOFF     = 5.0623868e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.25006822+dkt1n_lvt'
+LKT1       = '1.6602002e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066689591        LKT2       = 5.0146285e-010
+UTE        = -1.2731241          LUTE       = 5.2235713e-008      UA1        = '1.7750009e-009+dua1n_lvt'
+LUA1       = '-1.1581404e-016+dlua1n_lvt'
+UB1        = '-2.3399606e-018+dub1n_lvt'
+LUB1       = '3.2809938e-025+dlub1n_lvt'
+UC1        = 1.0394314e-011      LUC1       = 1.5813989e-017      PRT        = 0
+AT         = 232497.29           LAT        = -0.050665657
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3
+XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1                   VTSSWGS    = 10
+VTSSWGD    = 10                  DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'
+PVTH0      = '0+dpvthn_lvt'      WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'
+WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'
+PUA        = '0+dpuan_lvt'       WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'
+WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'
+PUB1       = '0+dpub1n_lvt'      WKT1       = '0+dwkt1n_lvt'      PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-dxln_lvt'
+LMAX       = '2.399959e-007-dxln_lvt'
+WMIN       = '1e-005-dxwn_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28699282+dvthn_lvt'
+LVTH0      = '-4.9975315e-009+dlvthn_lvt'
+K1         = 0.217               K2         = '0.027201124+dk2n_lvt'
+LK2        = '-3.8987143e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '8.2647504e-005+dcitn_lvt'
+LCIT       = '4.9552022e-011+dlcitn_lvt'
+VOFF       = '-0.11213032+dvoffn_lvt'
+LVOFF      = '-3.1832158e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.45669658+deta0n_lvt'
+LETA0      = '7.8060952e-013+dleta0n_lvt'
+ETAB       = -0.005528           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015977871+du0n_lvt'
+LU0        = '-1.2718352e-010+dlu0n_lvt'
+UA         = '-1.943848e-009+duan_lvt'
+LUA        = '9.0845374e-018+dluan_lvt'
+UB         = '2.4016641e-018+dubn_lvt'
+LUB        = '-3.0110845e-026+dlubn_lvt'
+UC         = 7.1737735e-011      LUC        = -4.3721401e-018     VSAT       = '103187.84+dvsatn_lvt'
+LVSAT      = '-0.00072676299+dlvsatn_lvt'
+A0         = 4.8899566           LA0        = -7.956403e-007      AGS        = -2.8296974
+LAGS       = 9.4148842e-007      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.06610277
+LKETA      = 9.2315417e-009      DWG        = 0                   DWB        = 0
+PCLM       = 1.0035779           LPCLM      = -5.7810692e-008     PDIBLC1    = 0
+PDIBLC2    = -0.0033166415       LPDIBLC2   = 2.8079479e-009      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0011396763        LTVOFF     = -3.4009205e-011     WTVOFF     = 0
+PTVOFF     = 0                   KT1        = '-0.23042531+dkt1n_lvt'
+LKT1       = '-2.8179905e-009+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.076299486        LKT2       = 2.6923265e-009
+UTE        = -1.0758784          LUTE       = 7.2676299e-009      UA1        = '1.5001468e-009+dua1n_lvt'
+LUA1       = '-5.3152802e-017+dlua1n_lvt'
+UB1        = '-1.0912977e-018+dub1n_lvt'
+LUB1       = '4.3429209e-026+dlub1n_lvt'
+UC1        = 1.0224874e-010      LUC1       = -5.1269826e-018     PRT        = 0
+AT         = 10260
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  WETA0      = '0+dweta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'       PU0        = '0+dpu0n_lvt'
+WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'       WUB        = '0+dwubn_lvt'
+PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'      WKT1       = '0+dwkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'      WVOFF      = '0+dwvoffn_lvt'
+PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.5 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-dxln_lvt'
+WMIN       = '1e-005-dxwn_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.23452+dvthn_lvt' LVTH0      = '2.8314967e-011+dlvthn_lvt'
+K1         = 0.217               K2         = '-0.02954405+dk2n_lvt'
+LK2        = '1.5363385e-009+dlk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0021258222+dcitn_lvt'
+LCIT       = '2.6107925e-010+dlcitn_lvt'
+VOFF       = '-0.098511915+dvoffn_lvt'
+LVOFF      = '-4.4875867e-009+dlvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.320681*ss_flag_lvt'
+ETA0       = '0.40323648+deta0n_lvt'
+LETA0      = '5.1211884e-009+dleta0n_lvt'
+ETAB       = -0.021562051
+Petab    = 0
+Wetab    = 0
+Letab    = 1.5357311e-09
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010513164+du0n_lvt'
+LU0        = '3.9622616e-010+dlu0n_lvt'
+UA         = '-2.4560086e-009+duan_lvt'
+LUA        = '5.8139284e-017+dluan_lvt'
+UB         = '2.2770536e-018+dubn_lvt'
+LUB        = '-1.8175653e-026+dlubn_lvt'
+UC         = 6.6351602e-11
+Puc      = 0
+Wuc      = 0
+LUC        = -3.8562356e-18
+VSAT       = '99768.905+dvsatn_lvt+962.043*ss_flag_lvt'
+LVSAT      = '-0.00039929768+dlvsatn_lvt-9.21439e-05*ss_flag_lvt'
+A0         = -2.4822033          LA0        = -8.9534826e-008     AGS        = 10.20685
+LAGS       = -3.0715206e-007     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.003472093
+LKETA      = 3.2327755e-009      DWG        = 0                   DWB        = 0
+PCLM       = 0.3871726           LPCLM      = 1.2286083e-009      PDIBLC1    = 0
+PDIBLC2    = 0.032413699         LPDIBLC2   = -6.1430413e-010     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.0014346284        LTVOFF     = -6.2259723e-011     WTVOFF     = 0
+PTVOFF     = 0
+KT1        = '-0.20571+dkt1n_lvt'
+LKT1       = '-5.185192e-09+dlkt1n_lvt'
+KT1L       = 0                   KT2        = -0.04520763         LKT2       = -2.8565142e-010
+UTE        = 0.49599538          LUTE       = -1.4328644e-007     UA1        = '3.3115344e-009+dua1n_lvt'
+LUA1       = '-2.2664751e-016+dlua1n_lvt'
+UB1        = '-1.1113672e-018+dub1n_lvt'
+LUB1       = '4.5351463e-026+dlub1n_lvt'
+UC1        = -3.4335819e-11
+Puc1     = 0
+Wuc1     = 0
+LUC1       = 7.9550049e-18
+PRT        = 0
+AT         = -33234.502          LAT        = 0.0041659034
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3
+XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1                   VTSSWGS    = 10
+VTSSWGD    = 10                  DMCG       = 6.25e-008           DMCI       = 6.75e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+WVTH0      = '0+dwvthn_lvt'
+PVTH0      = '0+dpvthn_lvt'      WK2        = '0+dwk2n_lvt'       PK2        = '0+dpk2n_lvt'
+LNFACTOR   = '0+dlnfactorn_lvt+3.07146e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+0.0*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt+0.0*ss_flag_lvt'
+WETA0      = '0+dweta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     WU0        = '0+dwu0n_lvt'
+PU0        = '0+dpu0n_lvt'       WUA        = '0+dwuan_lvt'       PUA        = '0+dpuan_lvt'
+WUB        = '0+dwubn_lvt'       PUB        = '0+dpubn_lvt'       WUA1       = '0+dwua1n_lvt'
+PUA1       = '0+dpua1n_lvt'      WUB1       = '0+dwub1n_lvt'      PUB1       = '0+dpub1n_lvt'
+WKT1       = '0+dwkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'
+PVSAT      = '0+dpvsatn_lvt+0.0*ss_flag_lvt'
+WVSAT      = '0+dwvsatn_lvt+0.0*ss_flag_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+WVOFF      = '0+dwvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_lvt'
+LMAX       = 2.001e-05           WMIN       = '1e-006-dxwn_lvt'   WMAX       = '1e-005-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24297418+dvthn_lvt'
+WVTH0      = '3.9954076e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.041528569+dk2n_lvt'
+WK2        = '1.8725433e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.093027422+dvoffn_lvt'
+WVOFF      = '-3.2723326e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020540733+du0n_lvt'
+WU0        = '-1.510348e-009+dwu0n_lvt'
+UA         = '-1.8724867e-009+duan_lvt'
+WUA        = '1.351364e-016+dwuan_lvt'
+UB         = '2.7691924e-018+dubn_lvt'
+WUB        = '-1.9683659e-025+dwubn_lvt'
+UC         = 1.1326513e-010      WUC        = -3.2716636e-017     VSAT       = '100000+dvsatn_lvt'
+A0         = 3.6182867           WA0        = 1.374076e-007       AGS        = 0.90926944
+WAGS       = -1.8649302e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.056897267
+WKETA      = 8.74412e-010        DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.004085
+WPDIBLC2   = -8.517e-010         PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00081586
+LTVOFF     = 0                   WTVOFF     = -5.246472e-010      PTVOFF     = 0
+KT1        = '-0.24254521+dkt1n_lvt'
+WKT1       = '-2.5045885e-008+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.0674086          WKT2       = 6.098172e-009
+UTE        = -1.31612            WUTE       = 6.13224e-008        UA1        = '1.9516867e-009+dua1n_lvt'
+WUA1       = '-2.373404e-016+dwua1n_lvt'
+UB1        = '-1.7011653e-018+dub1n_lvt'
+WUB1       = '4.0245664e-025+dwub1n_lvt'
+UC1        = 1.0537448e-011      WUC1       = -1.0926289e-017     PRT        = 0
+AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_lvt'
+LMAX       = '1e-005-dxln_lvt'   WMIN       = '1e-006-dxwn_lvt'   WMAX       = '1e-005-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24004061+dvthn_lvt'
+LVTH0      = '2.9233374e-008+dlvthn_lvt'
+WVTH0      = '4.5708499e-009+dwvthn_lvt'
+PVTH0      = '-5.7343455e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.042950901+dk2n_lvt'
+LK2        = '-1.4173692e-008+dlk2n_lvt'
+WK2        = '2.1404293e-009+dwk2n_lvt'
+PK2        = '-2.6695136e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.091634281+dvoffn_lvt'
+LVOFF      = '-1.3882805e-008+dlvoffn_lvt'
+WVOFF      = '-3.3146117e-009+dwvoffn_lvt'
+PVOFF      = '4.2131592e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.020828043+du0n_lvt'
+LU0        = '-2.8630725e-009+dlu0n_lvt'
+WU0        = '-1.5310498e-009+dwu0n_lvt'
+PU0        = '2.0629595e-016+dpu0n_lvt'
+UA         = '-1.8740359e-009+duan_lvt'
+LUA        = '1.5437752e-017+dluan_lvt'
+WUA        = '1.4743572e-016+dwuan_lvt'
+PUA        = '-1.2256407e-022+dpuan_lvt'
+UB         = '2.7976914e-018+dubn_lvt'
+LUB        = '-2.8399583e-025+dlubn_lvt'
+WUB        = '-2.110662e-025+dwubn_lvt'
+PUB        = '1.4179956e-031+dpubn_lvt'
+UC         = 1.158299e-010       LUC        = -2.5558206e-017     WUC        = -3.2574159e-017
+PUC        = -1.4198016e-024     VSAT       = '100000+dvsatn_lvt' A0         = 3.6910438
+LA0        = -7.2503291e-007     WA0        = 1.4118264e-007      PA0        = -3.7618674e-014
+AGS        = 0.87248295          LAGS       = 3.6658144e-007      WAGS       = -1.7074554e-008
+PAGS       = -1.5692542e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.056055662
+LKETA      = -8.3866816e-009     WKETA      = 7.2584597e-010      PKETA      = 1.4804768e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0038331778        LPDIBLC2   = 2.5094361e-009
+WPDIBLC2   = -1.5519088e-009     PPDIBLC2   = 6.9776572e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00081370559       LTVOFF     = 2.1468947e-011      WTVOFF     = -5.6473567e-010
+PTVOFF     = 3.9948605e-016      KT1        = '-0.24200164+dkt1n_lvt'
+LKT1       = '-5.4167744e-009+dlkt1n_lvt'
+WKT1       = '-2.6943244e-008+dwkt1n_lvt'
+PKT1       = '1.8907388e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.067575085        LKT2       = 1.6590418e-009
+WKT2       = 7.089424e-009       PKT2       = -9.8779356e-015     UTE        = -1.3254044
+LUTE       = 9.2519651e-008      WUTE       = 5.6573158e-008      PUTE       = 4.7326719e-014
+UA1        = '1.9820555e-009+dua1n_lvt'
+LUA1       = '-3.0262838e-016+dlua1n_lvt'
+WUA1       = '-2.4830019e-016+dwua1n_lvt'
+PUA1       = '1.0921551e-022+dpua1n_lvt'
+UB1        = '-1.6648663e-018+dub1n_lvt'
+LUB1       = '-3.6172355e-025+dlub1n_lvt'
+WUB1       = '4.0299245e-025+dwub1n_lvt'
+PUB1       = '-5.3394247e-033+dpub1n_lvt'
+UC1        = 8.855967e-012       LUC1       = 1.6756143e-017      WUC1       = -1.270197e-017
+PUC1       = 1.7694853e-023      PRT        = 0                   AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_lvt'
+LMAX       = '1.000002e-006-dxln_lvt'
+WMIN       = '1e-006-dxwn_lvt'   WMAX       = '1e-005-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27221843+dvthn_lvt'
+LVTH0      = '-1.8217676e-009+dlvthn_lvt'
+WVTH0      = '-4.4114797e-009+dwvthn_lvt'
+PVTH0      = '2.9345905e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.033870413+dk2n_lvt'
+LK2        = '-5.4100219e-009+dlk2n_lvt'
+WK2        = '-6.9460171e-010+dwk2n_lvt'
+PK2        = '6.6603234e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '3.1133522e-005+dcitn_lvt'
+LCIT       = '6.6463726e-011+dlcitn_lvt'
+WCIT       = '7.0243807e-011+dwcitn_lvt'
+PCIT       = '-6.7793001e-017+dpcitn_lvt'
+VOFF       = '-0.10019977+dvoffn_lvt'
+LVOFF      = '-5.6161626e-009+dlvoffn_lvt'
+WVOFF      = '1.3278935e-010+dwvoffn_lvt'
+PVOFF      = '-2.9058053e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915413+deta0n_lvt'
+WETA0      = '-3.2519042e-007+dweta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.018581163+du0n_lvt'
+LU0        = '-6.9458574e-010+dlu0n_lvt'
+WU0        = '-1.3699789e-009+dwu0n_lvt'
+PU0        = '5.0844751e-017+dpu0n_lvt'
+UA         = '-1.8432646e-009+duan_lvt'
+LUA        = '-1.4259852e-017+dluan_lvt'
+WUA        = '2.1143238e-017+dwuan_lvt'
+PUA        = '-6.7793001e-025+dpuan_lvt'
+UB         = '2.5720568e-018+dubn_lvt'
+LUB        = '-6.6233617e-026+dlubn_lvt'
+WUB        = '-4.6958447e-026+dwubn_lvt'
+PUB        = '-1.6582466e-032+dpubn_lvt'
+UC         = 9.9785376e-011      LUC        = -1.0073473e-017     WUC        = -3.515514e-017
+PUC        = 1.0711294e-024      VSAT       = '100000+dvsatn_lvt' A0         = 3.4160303
+LA0        = -4.5961458e-007     WA0        = 1.3381371e-007      PA0        = -3.050685e-014
+AGS        = 1.2445797           LAGS       = 7.4671837e-009      WAGS       = -1.1388789e-007
+PAGS       = 7.774298e-014       A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.076697269
+LKETA      = 1.153474e-008       WKETA      = 1.4344793e-009      PKETA      = 7.9656776e-016
+DWG        = 0                   DWB        = 0                   PCLM       = 0.81397991
+LPCLM      = -1.5518882e-008     WPCLM      = -1.2679007e-008     PPCLM      = 1.2236637e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.0057096168        LPDIBLC2   = 6.9846611e-010
+WPDIBLC2   = 6.7316571e-009      PPDIBLC2   = -1.016895e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00077057308       LTVOFF     = 6.3096562e-011      WTVOFF     = -2.1313221e-011
+PTVOFF     = -1.249764e-016      KT1        = '-0.24937656+dkt1n_lvt'
+LKT1       = '1.7008354e-009+dlkt1n_lvt'
+WKT1       = '-6.9304443e-009+dwkt1n_lvt'
+PKT1       = '-4.0716476e-016+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.066424731        LKT2       = 5.4882322e-010
+WKT2       = -2.6539054e-009     PKT2       = -4.7455101e-016     UTE        = -1.2853816
+LUTE       = 5.3893326e-008      WUTE       = 1.2282053e-007      PUTE       = -1.6609285e-014
+UA1        = '1.7912566e-009+dua1n_lvt'
+LUA1       = '-1.1848652e-016+dlua1n_lvt'
+WUA1       = '-1.628827e-016+dwua1n_lvt'
+PUA1       = '2.6778235e-023+dpua1n_lvt'
+UB1        = '-2.3986323e-018+dub1n_lvt'
+LUB1       = '3.4644131e-025+dlub1n_lvt'
+WUB1       = '5.8789026e-025+dwub1n_lvt'
+PUB1       = '-1.8378615e-031+dpub1n_lvt'
+UC1        = 8.9748141e-012      LUC1       = 1.6641443e-017      WUC1       = 1.4223394e-017
+PUC1       = -8.291084e-024      PRT        = 0                   AT         = 233196.22
+LAT        = -0.051340204        WAT        = -0.0070033076       PAT        = 6.7589622e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.9 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-dxln_lvt'
+LMAX       = '2.399959e-007-dxln_lvt'
+WMIN       = '1e-006-dxwn_lvt'   WMAX       = '1e-005-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.28615208+dvthn_lvt'
+LVTH0      = '-4.9983609e-009+dlvthn_lvt'
+WVTH0      = '8.4242078e-009+dwvthn_lvt'
+PVTH0      = '8.3105172e-018+dpvthn_lvt'
+K1         = 0.217               K2         = '0.027871333+dk2n_lvt'
+LK2        = '-4.0423516e-009+dlk2n_lvt'
+WK2        = '-6.7154904e-009+dwk2n_lvt'
+PK2        = '1.4392454e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00018742511+dcitn_lvt'
+LCIT       = '3.0832369e-011+dlcitn_lvt'
+WCIT       = '-1.0498717e-009+dwcitn_lvt'
+PCIT       = '1.8757092e-016+dpcitn_lvt'
+VOFF       = '-0.10966747+dvoffn_lvt'
+LVOFF      = '-3.4577165e-009+dlvoffn_lvt'
+WVOFF      = '-2.4677729e-008+dwvoffn_lvt'
+PVOFF      = '2.7504967e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.48915055+deta0n_lvt'
+LETA0      = '8.164015e-013+dleta0n_lvt'
+WETA0      = '-3.2518884e-007+dweta0n_lvt'
+PETA0      = '-3.586356e-019+dpeta0n_lvt'
+ETAB       = -0.0033359067       WETAB      = -2.1964775e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.016001195+du0n_lvt'
+LU0        = '-1.0640471e-010+dlu0n_lvt'
+WU0        = '-2.3370167e-010+dwu0n_lvt'
+PU0        = '-2.0820372e-016+dpu0n_lvt'
+UA         = '-1.9487815e-009+duan_lvt'
+LUA        = '9.7958842e-018+dluan_lvt'
+WUA        = '4.9434163e-017+dwuan_lvt'
+PUA        = '-7.127695e-024+dpuan_lvt'
+UB         = '2.4060267e-018+dubn_lvt'
+LUB        = '-2.8382073e-026+dlubn_lvt'
+WUB        = '-4.3713318e-026+dwubn_lvt'
+PUB        = '-1.7322291e-032+dpubn_lvt'
+UC         = 7.6073046e-011      LUC        = -4.6675362e-018     WUC        = -4.3439813e-017
+PUC        = 2.9598691e-024      VSAT       = '103154.99+dvsatn_lvt'
+LVSAT      = '-0.00071927513+dlvsatn_lvt'
+WVSAT      = '0.00032910066+dwvsatn_lvt'
+PVSAT      = '-7.5028368e-011+dpvsatn_lvt'
+A0         = 4.9425076           LA0        = -8.0762088e-007     WA0        = -5.2656106e-007
+PA0        = 1.2004539e-013      AGS        = -2.8687863          LAGS       = 9.4523235e-007
+WAGS       = 3.9167033e-007      PAGS       = -3.7514184e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.067891169        LKETA      = 9.527125e-009       WKETA      = 1.7919753e-008
+PKETA      = -2.9617448e-015     DWG        = 0                   DWB        = 0
+PCLM       = 0.99881327          LPCLM      = -5.7657191e-008     WPCLM      = 4.7741724e-008
+PPCLM      = -1.5380816e-015     PDIBLC1    = 0                   PDIBLC2    = -0.0030506425
+LPDIBLC2   = 2.69563e-009        WPDIBLC2   = -2.6653099e-009     PPDIBLC2   = 1.1254255e-015
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.0012247098        LTVOFF     = -4.0437533e-011
+WTVOFF     = -8.5203632e-010     PTVOFF     = 6.4411854e-017      KT1        = '-0.22886246+dkt1n_lvt'
+LKT1       = '-2.9759694e-009+dlkt1n_lvt'
+WKT1       = '-1.5659777e-008+dwkt1n_lvt'
+PKT1       = '1.5829485e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.075879437        LKT2       = 2.7043071e-009
+WKT2       = -4.2088909e-009     PKT2       = -1.2004539e-016     UTE        = -1.0844779
+LUTE       = 8.0912946e-009      WUTE       = 8.6167473e-008      PUTE       = -8.2531205e-015
+UA1        = '1.5080138e-009+dua1n_lvt'
+LUA1       = '-5.391282e-017+dlua1n_lvt'
+WUA1       = '-7.8827717e-017+dwua1n_lvt'
+PUA1       = '7.6153794e-024+dpua1n_lvt'
+UB1        = '-1.0938144e-018+dub1n_lvt'
+LUB1       = '4.8968935e-026+dlub1n_lvt'
+WUB1       = '2.5217669e-026+dwub1n_lvt'
+PUB1       = '-5.550805e-032+dpub1n_lvt'
+UC1        = 1.0838036e-010      LUC1       = -6.0210332e-018     WUC1       = -6.1438819e-017
+PUC1       = 8.9583872e-024      PRT        = 0                   AT         = 8000.1333
+WAT        = 0.022643864
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.10 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-dxln_lvt'
+WMIN       = '1e-006-dxwn_lvt'   WMAX       = '1e-005-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.23439418+dvthn_lvt+0.000545158*ff_flag_lvt-0.000545158*ss_flag_lvt'
+LVTH0      = '-4.0988817e-011+dlvthn_lvt-5.22149e-11*ff_flag_lvt+5.22149e-11*ss_flag_lvt'
+WVTH0      = '1.260777e-009+dwvthn_lvt-5.46248e-09*ff_flag_lvt+5.46248e-09*ss_flag_lvt'
+PVTH0      = '6.9442391e-016+dpvthn_lvt+5.23193e-16*ff_flag_lvt-5.23193e-16*ss_flag_lvt'
+K1         = 0.217               K2         = '-0.030127783+dk2n_lvt'
+LK2        = '1.5128037e-009+dlk2n_lvt'
+WK2        = '5.8489997e-009+dwk2n_lvt'
+PK2        = '2.3581857e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0025254154+dcitn_lvt'
+LCIT       = '2.9066824e-010+dlcitn_lvt'
+WCIT       = '4.0039237e-009+dwcitn_lvt'
+PCIT       = '-2.964816e-016+dpcitn_lvt'
+VOFF       = '-0.099451744+dvoffn_lvt'
+LVOFF      = '-4.436179e-009+dlvoffn_lvt'
+WVOFF      = '9.4170876e-009+dwvoffn_lvt'
+PVOFF      = '-5.1510487e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.357025*ss_flag_lvt'
+ETA0       = '0.48409488+deta0n_lvt-0.00181719*ff_flag_lvt'
+LETA0      = '4.8504901e-010+dleta0n_lvt+1.7405e-10*ff_flag_lvt'
+WETA0      = '-8.1020112e-007+dweta0n_lvt+1.82083e-08*ff_flag_lvt'
+PETA0      = '4.6454117e-014+dpeta0n_lvt-1.74398e-15*ff_flag_lvt'
+ETAB       = -0.018461361
+Petab    = 8.719881e-16
+Letab    = 1.4487063e-09
+WETAB      = -3.1068909e-08
+UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.010669839+du0n_lvt'
+LU0        = '4.0423259e-010+dlu0n_lvt'
+WU0        = '-1.5698813e-009+dwu0n_lvt'
+PU0        = '-8.0224433e-017+dpu0n_lvt'
+UA         = '-2.4269058e-009+duan_lvt'
+LUA        = '5.5590629e-017+dluan_lvt'
+WUA        = '-2.9161008e-016+dwuan_lvt'
+PUA        = '2.5537523e-023+dpuan_lvt'
+UB         = '2.2307279e-018+dubn_lvt'
+LUB        = '-1.1591957e-026+dlubn_lvt'
+WUB        = '4.6418333e-025+dwubn_lvt'
+PUB        = '-6.5968632e-032+dpubn_lvt'
+UC         = 6.6545728e-11
+LUC        = -3.7549892e-18
+WUC        = -1.945144e-18
+PUC        = -1.0144903e-24
+VSAT       = '99160.041+dvsatn_lvt+1071.07*ss_flag_lvt'
+LVSAT      = '-0.00033663866+dlvsatn_lvt-0.000102587*ss_flag_lvt'
+WVSAT      = '0.0061008173+dwvsatn_lvt-0.0010925*ss_flag_lvt'
+PVSAT      = '-6.2784339e-010+dpvsatn_lvt+1.04639e-10*ss_flag_lvt'
+A0         = -2.4893169          LA0        = -9.5800729e-008     WA0        = 7.1278269e-008
+PA0        = 6.2784339e-014      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = 0.0036497472        LKETA      = 2.6749361e-009
+WKETA      = -7.1360839e-008     PKETA      = 5.5895502e-015      DWG        = 0
+DWB        = 0                   PCLM       = 0.38255683          LPCLM      = 1.3678505e-009
+WPCLM      = 4.6250034e-008      PPCLM      = -1.3952075e-015     PDIBLC1    = 0
+PDIBLC2    = 0.030053261         LPDIBLC2   = -4.7506186e-010     WPDIBLC2   = 2.3651594e-008
+PPDIBLC2   = -1.3952075e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0016506047
+LTVOFF     = -8.1229742e-011     WTVOFF     = -2.164082e-009      PTVOFF     = 1.9007959e-016
+KT1        = '-0.19451937+dkt1n_lvt'
+LKT1       = '-6.2653157e-09+dlkt1n_lvt'
+WKT1       = '-1.1213008e-07+dwkt1n_lvt'
+PKT1       = '1.0822839e-14+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.044506216        LKT2       = -3.0061996e-010
+WKT2       = -7.0281664e-009     PKT2       = 1.4998481e-016      UTE        = 0.66554152
+LUTE       = -1.5952557e-007     WUTE       = -1.6988524e-006     PUTE       = 1.6271608e-013
+UA1        = '3.4887539e-009+dua1n_lvt'
+LUA1       = '-2.436281e-016+dlua1n_lvt'
+WUA1       = '-1.7757392e-015+dwua1n_lvt'
+PUA1       = '1.7014556e-022+dpua1n_lvt'
+UB1        = '-9.5527444e-019+dub1n_lvt'
+LUB1       = '3.5699574e-026+dlub1n_lvt'
+WUB1       = '-1.5640491e-024+dwub1n_lvt'
+PUB1       = '9.6711924e-032+dpub1n_lvt'
+UC1        = -4.3940601e-11
+LUC1       = 8.5681829e-18
+WUC1       = 9.6239901e-17
+PUC1       = -6.144046e-24
+PRT        = 0                   AT         = -40423.746
+LAT        = 0.0046380392        WAT        = 0.072036221         PAT        = -4.7307999e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt+3.41956e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+3.64165e-07*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt-3.48795e-14*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_lvt'
+LMAX       = 2.001e-05           WMIN       = '6e-007-dxwn_lvt'   WMAX       = '1e-006-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25979956+dvthn_lvt'
+WVTH0      = '-1.316648e-008+dwvthn_lvt'
+K1         = 0.217               K2         = '0.04162729+dk2n_lvt'
+WK2        = '1.7718485e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.10252774+dvoffn_lvt'
+WVOFF      = '6.417995e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0217105+du0n_lvt'
+WU0        = '-2.70351e-009+dwu0n_lvt'
+UA         = '-1.6005e-009+duan_lvt'
+WUA        = '-1.4229e-016+dwuan_lvt'
+UB         = '2.5142567e-018+dubn_lvt'
+WUB        = '6.3197756e-026+dwubn_lvt'
+UC         = 1.1622e-010         WUC        = -3.57306e-017       VSAT       = '100000+dvsatn_lvt'
+A0         = 3.2105              WA0        = 5.5335e-007         AGS        = 0.91545379
+WAGS       = -2.495734e-008      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.067014
+WKETA      = 1.119348e-008       DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0034353969
+WPDIBLC2   = -1.8910482e-010     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 6.032e-005
+LTVOFF     = 0                   WTVOFF     = 2.460036e-010       PTVOFF     = 0
+KT1        = '-0.28309631+dkt1n_lvt'
+WKT1       = '1.6316236e-008+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.048441           WKT2       = -1.324878e-008
+UTE        = -1.38465            WUTE       = 1.31223e-007        UA1        = '1.7934e-009+dua1n_lvt'
+WUA1       = '-7.5888e-017+dwua1n_lvt'
+UB1        = '-1.44703e-018+dub1n_lvt'
+WUB1       = '1.432386e-025+dwub1n_lvt'
+UC1        = -4.444973e-011      WUC1       = 4.5160633e-017      PRT        = 0
+AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_lvt'
+LMAX       = '1e-005-dxln_lvt'   WMIN       = '6e-007-dxwn_lvt'   WMAX       = '1e-006-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25761053+dvthn_lvt'
+LVTH0      = '2.181388e-008+dlvthn_lvt'
+WVTH0      = '-1.3350475e-008+dwvthn_lvt'
+PVTH0      = '1.8335387e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.04315219+dk2n_lvt'
+LK2        = '-1.5195793e-008+dlk2n_lvt'
+WK2        = '1.9351152e-009+dwk2n_lvt'
+PK2        = '-1.6269704e-015+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00011662134+dcitn_lvt'
+LCIT       = '-1.6563347e-010+dlcitn_lvt'
+WCIT       = '-1.6953766e-011+dwcitn_lvt'
+PCIT       = '1.6894614e-016+dpcitn_lvt'
+VOFF       = '-0.10160741+dvoffn_lvt'
+LVOFF      = '-9.1712041e-009+dlvoffn_lvt'
+WVOFF      = '6.8579819e-009+dwvoffn_lvt'
+PVOFF      = '-4.3845171e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.022015743+du0n_lvt'
+LU0        = '-3.0417785e-009+dlu0n_lvt'
+WU0        = '-2.7425037e-009+dwu0n_lvt'
+PU0        = '3.8857612e-016+dpu0n_lvt'
+UA         = '-1.5913207e-009+duan_lvt'
+LUA        = '-9.147242e-017+dluan_lvt'
+WUA        = '-1.409337e-016+dwuan_lvt'
+PUA        = '-1.3515691e-023+dpuan_lvt'
+UB         = '2.5309015e-018+dubn_lvt'
+LUB        = '-1.658671e-025+dlubn_lvt'
+WUB        = '6.1059469e-026+dwubn_lvt'
+PUB        = '2.1308264e-032+dpubn_lvt'
+UC         = 1.2039877e-010      LUC        = -4.1641857e-017     WUC        = -3.7234399e-017
+PUC        = 1.4985523e-023      VSAT       = '100000+dvsatn_lvt' A0         = 3.3002552
+LA0        = -8.9442074e-007     WA0        = 5.3978699e-007      PA0        = 1.3515691e-013
+AGS        = 0.88315909          LAGS       = 3.2182028e-007      WAGS       = -2.7964215e-008
+PAGS       = 2.9963838e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.066991213
+LKETA      = -2.2707815e-010     WKETA      = 1.1880108e-008      PKETA      = -6.8423187e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0026000831        LPDIBLC2   = 8.3239935e-009
+WPDIBLC2   = -2.941522e-010      PPDIBLC2   = 1.0468087e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = -1.2650895e-005     LTVOFF     = 7.2716299e-010      WTVOFF     = 2.7814794e-010
+PTVOFF     = -3.2032188e-016     KT1        = '-0.28601635+dkt1n_lvt'
+LKT1       = '2.9098542e-008+dlkt1n_lvt'
+WKT1       = '1.7951766e-008+dwkt1n_lvt'
+PKT1       = '-1.6298234e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.046679942        LKT2       = -1.7549133e-008
+WKT2       = -1.4223622e-008     PKT2       = 9.714403e-015       UTE        = -1.4007513
+LUTE       = 1.6045075e-007      WUTE       = 1.3342699e-007      PUTE       = -2.1962998e-014
+UA1        = '1.8176779e-009+dua1n_lvt'
+LUA1       = '-2.4193173e-016+dlua1n_lvt'
+WUA1       = '-8.0635054e-017+dwua1n_lvt'
+PUA1       = '4.7304919e-023+dpua1n_lvt'
+UB1        = '-1.416954e-018+dub1n_lvt'
+LUB1       = '-2.9971109e-025+dlub1n_lvt'
+WUB1       = '1.5012183e-025+dwub1n_lvt'
+PUB1       = '-6.8592133e-032+dpub1n_lvt'
+UC1        = -5.0274623e-011     LUC1       = 5.8045694e-017      WUC1       = 4.7611232e-017
+PUC1       = -2.4420489e-023     PRT        = 0                   AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.13 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_lvt'
+LMAX       = '1.000002e-006-dxln_lvt'
+WMIN       = '6e-007-dxwn_lvt'   WMAX       = '1e-006-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.2817733+dvthn_lvt'
+LVTH0      = '-1.5058442e-009+dlvthn_lvt'
+WVTH0      = '-1.415744e-008+dwvthn_lvt'
+PVTH0      = '2.6123487e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.03325103+dk2n_lvt'
+LK2        = '-5.640085e-009+dlk2n_lvt'
+WK2        = '-6.2831239e-011+dwk2n_lvt'
+PK2        = '3.0126767e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-7.0615088e-006+dcitn_lvt'
+LCIT       = '-4.6265917e-011+dlcitn_lvt'
+WCIT       = '1.0920274e-010+dwcitn_lvt'
+PCIT       = '4.7191236e-017+dpcitn_lvt'
+VOFF       = '-0.10079487+dvoffn_lvt'
+LVOFF      = '-9.9553928e-009+dlvoffn_lvt'
+WVOFF      = '7.3979162e-010+dwvoffn_lvt'
+PVOFF      = '1.5202095e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.124367+deta0n_lvt'
+WETA0      = '4.689246e-008+dweta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.019623129+du0n_lvt'
+LU0        = '-7.3264319e-010+dlu0n_lvt'
+WU0        = '-2.4327848e-009+dwu0n_lvt'
+PU0        = '8.9663348e-017+dpu0n_lvt'
+UA         = '-1.6380378e-009+duan_lvt'
+LUA        = '-4.6385313e-017+dluan_lvt'
+WUA        = '-1.8818814e-016+dwuan_lvt'
+PUA        = '3.209004e-023+dpuan_lvt'
+UB         = '2.3981278e-018+dubn_lvt'
+LUB        = '-3.7725886e-026+dlubn_lvt'
+WUB        = '1.3044909e-025+dwubn_lvt'
+PUB        = '-4.5660352e-032+dpubn_lvt'
+UC         = 9.5009464e-011      LUC        = -1.7138388e-017     WUC        = -3.028371e-017
+PUC        = 8.2773427e-024      VSAT       = '100000+dvsatn_lvt' A0         = 2.6745847
+LA0        = -2.9057981e-007     WA0        = 8.9008822e-007      PA0        = -2.0292231e-013
+AGS        = 1.1289677           LAGS       = 8.4587949e-008      WAGS       = 4.0363224e-009
+PAGS       = -9.2020078e-016     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.085198331
+LKETA      = 1.7344794e-008      WKETA      = 1.0105562e-008      PKETA      = -5.1296873e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.79200975
+LPCLM      = 5.684738e-009       WPCLM      = 9.7305549e-009      PPCLM      = -9.3910559e-015
+PDIBLC1    = 0                   PDIBLC2    = 0.013691513         LPDIBLC2   = -2.3804561e-009
+WPDIBLC2   = -1.4098767e-009     PPDIBLC2   = 2.1236056e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00077131362       LTVOFF     = -2.9449003e-011     WTVOFF     = -2.2068575e-011
+PTVOFF     = -3.0579921e-017     KT1        = '-0.26171967+dkt1n_lvt'
+LKT1       = '5.6495669e-009+dlkt1n_lvt'
+WKT1       = '5.6595266e-009+dwkt1n_lvt'
+PKT1       = '-4.4348709e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.059868619        LKT2       = -4.8206101e-009
+WKT2       = -9.3411397e-009     PKT2       = 5.002271e-015       UTE        = -1.3070263
+LUTE       = 6.9995855e-008      WUTE       = 1.4489808e-007      PUTE       = -3.3033865e-014
+UA1        = '1.6318871e-009+dua1n_lvt'
+LUA1       = '-6.2623158e-017+dlua1n_lvt'
+WUA1       = '-3.2575296e-019+dwua1n_lvt'
+PUA1       = '-3.0202391e-023+dpua1n_lvt'
+UB1        = '-1.8757435e-018+dub1n_lvt'
+LUB1       = '1.4307126e-025+dlub1n_lvt'
+WUB1       = '5.4543671e-026+dwub1n_lvt'
+PUB1       = '2.3651303e-032+dpub1n_lvt'
+UC1        = -1.2800613e-011     LUC1       = 2.1879152e-017      WUC1       = 3.6434329e-017
+PUC1       = -1.3633548e-023     PRT        = 0                   AT         = 221958.24
+LAT        = -0.040494319        WAT        = 0.0044594302        PAT        = -4.3038407e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.14 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-dxln_lvt'
+LMAX       = '2.399959e-007-dxln_lvt'
+WMIN       = '6e-007-dxwn_lvt'   WMAX       = '1e-006-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30139764+dvthn_lvt'
+LVTH0      = '-5.9798022e-009+dlvthn_lvt'
+WVTH0      = '-7.126262e-009+dwvthn_lvt'
+PVTH0      = '1.0093807e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.022481655+dk2n_lvt'
+LK2        = '-3.1848829e-009+dlk2n_lvt'
+WK2        = '-1.2180193e-009+dwk2n_lvt'
+PK2        = '5.6462745e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.0012641596+dcitn_lvt'
+LCIT       = '2.4032731e-010+dlcitn_lvt'
+WCIT       = '4.3074477e-010+dwcitn_lvt'
+PCIT       = '-2.6113916e-017+dpcitn_lvt'
+VOFF       = '-0.1452694+dvoffn_lvt'
+LVOFF      = '1.8390894e-010+dlvoffn_lvt'
+WVOFF      = '1.1636233e-008+dwvoffn_lvt'
+PVOFF      = '-9.6396125e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.1243618+deta0n_lvt'
+LETA0      = '1.1852348e-012+dleta0n_lvt'
+WETA0      = '4.6895683e-008+dweta0n_lvt'
+PETA0      = '-7.3484559e-019+dpeta0n_lvt'
+ETAB       = 0.0140815           WETAB      = -3.973053e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017962484+du0n_lvt'
+LU0        = '-3.540492e-010+dlu0n_lvt'
+WU0        = '-2.2342161e-009+dwu0n_lvt'
+PU0        = '4.4393657e-017+dpu0n_lvt'
+UA         = '-1.8908752e-009+duan_lvt'
+LUA        = '1.1256568e-017+dluan_lvt'
+WUA        = '-9.6302274e-018+dwuan_lvt'
+PUA        = '-8.6175922e-024+dpuan_lvt'
+UB         = '2.5042067e-018+dubn_lvt'
+LUB        = '-6.1909735e-026+dlubn_lvt'
+WUB        = '-1.4385689e-025+dwubn_lvt'
+PUB        = '1.6875925e-032+dpubn_lvt'
+UC         = 1.7203086e-011      LUC        = 5.9990981e-019      WUC        = 1.6607546e-017
+PUC        = -2.4129258e-024     VSAT       = '98536.493+dvsatn_lvt'
+LVSAT      = '0.00033365028+dlvsatn_lvt'
+WVSAT      = '0.0050399697+dwvsatn_lvt'
+PVSAT      = '-1.1490123e-009+dpvsatn_lvt'
+A0         = 4.7238631           LA0        = -7.577743e-007      WA0        = -3.0354363e-007
+PA0        = 6.9201876e-014      AGS        = -2.4847958          LAGS       = 9.0845374e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.038058485        LKETA      = 6.5978517e-009
+WKETA      = -1.2509585e-008     PKETA      = 2.6113916e-017      DWG        = 0
+DWB        = 0                   PCLM       = 1.2105486           LPCLM      = -8.9733757e-008
+WPCLM      = -1.6822835e-007     PPCLM      = 3.1180015e-014      PDIBLC1    = 0
+PDIBLC2    = -0.0237901          LPDIBLC2   = 6.1646019e-009      WPDIBLC2   = 1.8488936e-008
+PPDIBLC2   = -2.4129258e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00034240366
+LTVOFF     = 6.833389e-011       WTVOFF     = 4.7915972e-011      PTVOFF     = -4.6534998e-017
+KT1        = '-0.26987595+dkt1n_lvt'
+LKT1       = '7.5090358e-009+dlkt1n_lvt'
+WKT1       = '2.6173983e-008+dwkt1n_lvt'
+PKT1       = '-9.1117568e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.10692445         LKT2       = 5.9071791e-009
+WKT2       = 2.7457026e-008      PKT2       = -3.3869749e-015     UTE        = -1
+UA1        = '1.5826054e-009+dua1n_lvt'
+LUA1       = '-5.1387925e-017+dlua1n_lvt'
+WUA1       = '-1.5491114e-016+dwua1n_lvt'
+PUA1       = '5.0399857e-024+dpua1n_lvt'
+UB1        = '-9.7987827e-019+dub1n_lvt'
+LUB1       = '-6.116809e-026+dlub1n_lvt'
+WUB1       = '-9.0997215e-026+dwub1n_lvt'
+PUB1       = '5.6831715e-032+dpub1n_lvt'
+UC1        = 4.047626e-011       LUC1       = 9.7330908e-018      WUC1       = 7.8233597e-018
+PUC1       = -7.1108192e-024     PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.15 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-dxln_lvt'
+WMIN       = '6e-007-dxwn_lvt'   WMAX       = '1e-006-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '0.25840312+dvthn_lvt-0.012266*ff_flag_lvt+0.012266*ss_flag_lvt'
+LVTH0      = '-1.8617867e-009+dlvthn_lvt+1.17483e-09*ff_flag_lvt-1.17483e-09*ss_flag_lvt'
+WVTH0      = '-2.3228341e-008+dwvthn_lvt+7.60495e-09*ff_flag_lvt-7.60495e-09*ss_flag_lvt'
+PVTH0      = '2.5516377e-015+dpvthn_lvt-7.28397e-16*ff_flag_lvt+7.28397e-16*ss_flag_lvt'
+K1         = 0.217               K2         = '-0.025394525+dk2n_lvt'
+LK2        = '1.4006976e-009+dlk2n_lvt'
+WK2        = '1.0210766e-009+dwk2n_lvt'
+PK2        = '3.5016685e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '2.3457461e-006+dcitn_lvt'
+LCIT       = '1.1902142e-010+dlcitn_lvt'
+WCIT       = '1.4256073e-009+dwcitn_lvt'
+PCIT       = '-1.2140185e-016+dpcitn_lvt'
+VOFF       = '-0.1240989+dvoffn_lvt'
+LVOFF      = '-1.8438017e-009+dlvoffn_lvt'
+WVOFF      = '3.4557183e-008+dwvoffn_lvt'
+PVOFF      = '-3.1593298e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt-0.0994111*ss_flag_lvt'
+ETA0       = '-0.5294399+deta0n_lvt+0.0408868*ff_flag_lvt'
+LETA0      = '6.2622312e-008+dleta0n_lvt-3.91611e-09*ff_flag_lvt'
+WETA0      = '2.2360436e-007+dweta0n_lvt-2.53498e-08*ff_flag_lvt'
+PETA0      = '-1.6925892e-014+dpeta0n_lvt+2.42799e-15*ff_flag_lvt'
+ETAB       = 0.039736442
+LETAB      = -2.4572377e-09
+WETAB      = -9.0430667e-08
+PETAB      = 4.856051e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0082323123+du0n_lvt'
+LU0        = '5.7790661e-010+dlu0n_lvt'
+WU0        = '9.1639556e-010+dwu0n_lvt'
+PU0        = '-2.5737193e-016+dpu0n_lvt'
+UA         = '-3.0749301e-009+duan_lvt'
+LUA        = '1.2466534e-016+dluan_lvt'
+WUA        = '3.6937472e-016+dwuan_lvt'
+PUA        = '-4.4918686e-023+dpuan_lvt'
+UB         = '3.1425635e-018+dubn_lvt'
+LUB        = '-1.2305155e-025+dlubn_lvt'
+WUB        = '-4.6588894e-025+dwubn_lvt'
+PUB        = '4.7720155e-032+dpubn_lvt'
+UC         = 8.9822988e-11
+LUC        = -6.3555719e-18
+WUC        = -2.5687948e-17
+PUC        = 1.6381041e-24
+VSAT       = '120396.91+dvsatn_lvt-2485.28*ff_flag_lvt'
+LVSAT      = '-0.0017601405+dlvsatn_lvt+0.000238038*ff_flag_lvt'
+WVSAT      = '-0.01556079+dwvsatn_lvt+0.00253498*ff_flag_lvt'
+PVSAT      = '8.2412849e-010+dpvsatn_lvt-2.42799e-10*ff_flag_lvt'
+A0         = -3.488793           LA0        = 2.88339e-008        WA0        = 1.0907439e-006
+PA0        = -6.4342982e-014     AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0461879          LKETA      = 7.3764872e-009
+WKETA      = -2.0526438e-008     PKETA      = 7.9396812e-016      DWG        = 0
+DWB        = 0                   PCLM       = 0.17475972          LPCLM      = 9.4741054e-009
+WPCLM      = 2.5820308e-007      PPCLM      = -9.6635875e-015     PDIBLC1    = 0
+PDIBLC2    = 0.052953647         LPDIBLC2   = -1.1859141e-009     WPDIBLC2   = 2.9320051e-010
+PPDIBLC2   = -6.7013823e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0014296083
+LTVOFF     = -3.5798573e-011     WTVOFF     = -1.9386657e-009     PTVOFF     = 1.4373979e-016
+KT1        = '-0.12546444+dkt1n_lvt'
+LKT1       = '-6.3226983e-009+dlkt1n_lvt'
+WKT1       = '-1.8256611e-007+dwkt1n_lvt'
+PKT1       = '1.088137e-014+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.03619065         LKT2       = -8.6770458e-010
+WKT2       = -1.5510044e-008     PKT2       = 7.2841112e-016      UTE        = -1
+UA1        = '2.032528e-009+dua1n_lvt'
+LUA1       = '-9.448151e-017+dlua1n_lvt'
+WUA1       = '-2.9038879e-016+dwua1n_lvt'
+PUA1       = '1.8016035e-023+dpua1n_lvt'
+UB1        = '-3.5815882e-018+dub1n_lvt'
+LUB1       = '1.8802369e-025+dlub1n_lvt'
+WUB1       = '1.1147909e-024+dwub1n_lvt'
+PUB1       = '-5.8658669e-032+dpub1n_lvt'
+UC1        = 1.6779532e-10
+LUC1       = -2.461659e-18
+WUC1       = -1.1973073e-16
+PUC1       = 5.106393e-24
+PRT        = 0                   AT         = 44336
+WAT        = -0.01441872
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt+9.52153e-09*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt+1.01399e-07*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt-9.71196e-15*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_lvt'
+LMAX       = 2.001e-05           WMIN       = '3e-007-dxwn_lvt'   WMAX       = '6e-007-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24595584+dvthn_lvt'
+WVTH0      = '-4.583372e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.040769245+dk2n_lvt'
+WK2        = '2.3038361e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.099522454+dvoffn_lvt'
+WVOFF      = '4.5547152e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017403333+du0n_lvt'
+WU0        = '-3.3066667e-011+dwu0n_lvt'
+UA         = '-1.8950667e-009+duan_lvt'
+WUA        = '4.0341333e-017+dwuan_lvt'
+UB         = '2.6268698e-018+dubn_lvt'
+WUB        = '-6.6223275e-027+dwubn_lvt'
+UC         = 7.4440667e-011      WUC        = -9.8274133e-018     VSAT       = '100000+dvsatn_lvt'
+A0         = 4.6209909           WA0        = -3.2115438e-007     AGS        = 0.92102174
+WAGS       = -2.8409466e-008     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.048789333
+WKETA      = -1.0581333e-010     DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0026028042
+WPDIBLC2   = 3.2710267e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.00075843333
+LTVOFF     = 0                   WTVOFF     = -1.8682667e-010     PTVOFF     = 0
+KT1        = '-0.25769564+dkt1n_lvt'
+WKT1       = '5.678208e-010+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.080647333        WKT2       = 6.7191467e-009
+UTE        = -1.2071333          WUTE       = 2.1162667e-008      UA1        = '1.7158e-009+dua1n_lvt'
+WUA1       = '-2.7776e-017+dwua1n_lvt'
+UB1        = '-1.2896e-018+dub1n_lvt'
+WUB1       = '4.5632e-026+dwub1n_lvt'
+UC1        = 3.7414e-011         WUC1       = -5.59488e-018       PRT        = 0
+AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_lvt'
+LMAX       = '1e-005-dxln_lvt'   WMIN       = '3e-007-dxwn_lvt'   WMAX       = '6e-007-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.24360281+dvthn_lvt'
+LVTH0      = '2.3448206e-008+dlvthn_lvt'
+WVTH0      = '-4.6656848e-009+dwvthn_lvt'
+PVTH0      = '8.2025652e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.042674088+dk2n_lvt'
+LK2        = '-1.8981971e-008+dlk2n_lvt'
+WK2        = '2.2315379e-009+dwk2n_lvt'
+PK2        = '7.2046005e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '7.7838215e-005+dcitn_lvt'
+LCIT       = '2.2084463e-010+dlcitn_lvt'
+WCIT       = '7.0917713e-012+dwcitn_lvt'
+PCIT       = '-7.0670281e-017+dpcitn_lvt'
+VOFF       = '-0.098319641+dvoffn_lvt'
+LVOFF      = '-1.1986162e-008+dlvoffn_lvt'
+WVOFF      = '4.8195635e-009+dwvoffn_lvt'
+PVOFF      = '-2.6392432e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017645683+du0n_lvt'
+LU0        = '-2.4150429e-009+dlu0n_lvt'
+WU0        = '-3.3066667e-011+dwu0n_lvt'
+PU0        = '8.4471169e-030+dpu0n_lvt'
+UA         = '-1.8846149e-009+duan_lvt'
+LUA        = '-1.0415318e-016+dluan_lvt'
+WUA        = '4.0908675e-017+dwuan_lvt'
+PUA        = '-5.6536225e-024+dpuan_lvt'
+UB         = '2.6370304e-018+dubn_lvt'
+LUB        = '-1.0125132e-025+dlubn_lvt'
+WUB        = '-4.7404097e-027+dwubn_lvt'
+PUB        = '-1.8753518e-032+dpubn_lvt'
+UC         = 7.6521086e-011      LUC        = -2.0731611e-017     WUC        = -1.0030238e-017
+PUC        = 2.02117e-024        VSAT       = '100000+dvsatn_lvt' A0         = 4.7592867
+LA0        = -1.378132e-006      WA0        = -3.6481249e-007     PA0        = 4.3505791e-013
+AGS        = 0.89156087          LAGS       = 2.9358074e-007      WAGS       = -3.3173322e-008
+PAGS       = 4.7472353e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.047450905
+LKETA      = -1.3337591e-008     WKETA      = -2.3488357e-010     PKETA      = 1.2861991e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0014842922        LPDIBLC2   = 1.1146095e-008
+WPDIBLC2   = 3.976382e-010       PPDIBLC2   = -7.0289431e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00074609279       LTVOFF     = 1.2297484e-010      WTVOFF     = -1.9227315e-010
+PTVOFF     = 5.4274776e-017      KT1        = '-0.25910969+dkt1n_lvt'
+LKT1       = '1.4091184e-008+dlkt1n_lvt'
+WKT1       = '1.2696367e-009+dwkt1n_lvt'
+PKT1       = '-6.9936723e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.08054782         LKT2       = -9.9166362e-010
+WKT2       = 6.7744625e-009      PKT2       = -5.5122819e-016     UTE        = -1.2236832
+LUTE       = 1.6492107e-007      WUTE       = 2.3644787e-008      PUTE       = -2.4734598e-014
+UA1        = '1.718009e-009+dua1n_lvt'
+LUA1       = '-2.2013223e-017+dlua1n_lvt'
+WUA1       = '-1.8840368e-017+dwua1n_lvt'
+PUA1       = '-8.9044554e-023+dpua1n_lvt'
+UB1        = '-1.2219994e-018+dub1n_lvt'
+LUB1       = '-6.7364735e-025+dlub1n_lvt'
+WUB1       = '2.9250008e-026+dwub1n_lvt'
+PUB1       = '1.6324835e-031+dpub1n_lvt'
+UC1        = 3.5612604e-011      LUC1       = 1.7951106e-017      WUC1       = -5.638849e-018
+PUC1       = 4.3815574e-025      PRT        = 0                   AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.18 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_lvt'
+LMAX       = '1.000002e-006-dxln_lvt'
+WMIN       = '3e-007-dxwn_lvt'   WMAX       = '6e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.26663383+dvthn_lvt'
+LVTH0      = '1.2207367e-009+dlvthn_lvt'
+WVTH0      = '-4.7709703e-009+dwvthn_lvt'
+PVTH0      = '9.2186856e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.02840131+dk2n_lvt'
+LK2        = '-5.20717e-009+dlk2n_lvt'
+WK2        = '2.9439952e-009+dwk2n_lvt'
+PK2        = '3.2860339e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.00024274868+dcitn_lvt'
+LCIT       = '6.168789e-011+dlcitn_lvt'
+WCIT       = '-4.5679577e-011+dwcitn_lvt'
+PCIT       = '-1.9740125e-017+dpcitn_lvt'
+VOFF       = '-0.10568462+dvoffn_lvt'
+LVOFF      = '-4.8781474e-009+dlvoffn_lvt'
+WVOFF      = '3.7714337e-009+dwvoffn_lvt'
+PVOFF      = '-1.6276826e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712533+deta0n_lvt'
+WETA0      = '-4.4177067e-009+dweta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015755915+du0n_lvt'
+LU0        = '-5.9120877e-010+dlu0n_lvt'
+WU0        = '-3.5112042e-011+dwu0n_lvt'
+PU0        = '1.9740125e-018+dpu0n_lvt'
+UA         = '-2.0192139e-009+duan_lvt'
+LUA        = '2.5749719e-017+dluan_lvt'
+WUA        = '4.8141071e-017+dwuan_lvt'
+PUA        = '-1.263368e-023+dpuan_lvt'
+UB         = '2.6847752e-018+dubn_lvt'
+LUB        = '-1.4733035e-025+dlubn_lvt'
+WUB        = '-4.7272283e-026+dwubn_lvt'
+PUB        = '2.2294418e-032+dpubn_lvt'
+UC         = 5.8440231e-011      LUC        = -3.2815967e-018     WUC        = -7.6107853e-018
+PUC        = -3.1386798e-025     VSAT       = '100000+dvsatn_lvt' A0         = 3.8626774
+LA0        = -5.1280546e-007     WA0        = 1.5347073e-007      PA0        = -6.5142411e-014
+AGS        = 1.2666075           LAGS       = -6.8380511e-008     WAGS       = -8.1300367e-008
+PAGS       = 9.3920244e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.071378987
+LKETA      = 9.7556413e-009      WKETA      = 1.5375691e-009      PKETA      = -4.2441268e-016
+DWG        = 0                   DWB        = 0                   PCLM       = 0.82739918
+LPCLM      = -2.8469956e-008     WPCLM      = -1.2210893e-008     PPCLM      = 1.1784854e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.010961153         LPDIBLC2   = 1.9998816e-009
+WPDIBLC2   = 2.8294602e-010      PPDIBLC2   = -5.9220374e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00095856343       LTVOFF     = -8.2082702e-011     WTVOFF     = -1.3816346e-010
+PTVOFF     = 2.052973e-018       KT1        = '-0.24294349+dkt1n_lvt'
+LKT1       = '-1.5109831e-009+dlkt1n_lvt'
+WKT1       = '-5.9817051e-009+dwkt1n_lvt'
+PKT1       = '4.6701187e-018+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.087807131        LKT2       = 6.0143703e-009
+WKT2       = 7.9807381e-009      PKT2       = -1.7154168e-015     UTE        = -1.0694599
+LUTE       = 1.607865e-008       WUTE       = -2.3930751e-009     PUTE       = 3.9480249e-016
+UA1        = '1.6411584e-009+dua1n_lvt'
+LUA1       = '5.2156116e-017+dlua1n_lvt'
+WUA1       = '-6.0739617e-018+dwua1n_lvt'
+PUA1       = '-1.0136554e-022+dpua1n_lvt'
+UB1        = '-1.8791885e-018+dub1n_lvt'
+LUB1       = '-3.9387558e-026+dlub1n_lvt'
+WUB1       = '5.6679605e-026+dwub1n_lvt'
+PUB1       = '1.3677577e-031+dpub1n_lvt'
+UC1        = 5.9031464e-011      LUC1       = -4.6506699e-018     WUC1       = -8.101559e-018
+PUC1       = 2.8149418e-024      PRT        = 0                   AT         = 235814.84
+LAT        = -0.053867457        WAT        = -0.0041316588       PAT        = 3.9875052e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.19 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-dxln_lvt'
+LMAX       = '2.399959e-007-dxln_lvt'
+WMIN       = '3e-007-dxwn_lvt'   WMAX       = '6e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.29455797+dvthn_lvt'
+LVTH0      = '-5.1454089e-009+dlvthn_lvt'
+WVTH0      = '-2.8856656e-009+dwvthn_lvt'
+PVTH0      = '4.9205679e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.015783404+dk2n_lvt'
+LK2        = '-2.3305397e-009+dlk2n_lvt'
+WK2        = '2.9348965e-009+dwk2n_lvt'
+PK2        = '3.493466e-017+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.00058791931+dcitn_lvt'
+LCIT       = '2.5106358e-010+dlcitn_lvt'
+WCIT       = '1.1475784e-011+dwcitn_lvt'
+PCIT       = '-3.2770404e-017+dpcitn_lvt'
+VOFF       = '-0.1214655+dvoffn_lvt'
+LVOFF      = '-1.2804224e-009+dlvoffn_lvt'
+WVOFF      = '-3.1221832e-009+dwvoffn_lvt'
+PVOFF      = '-5.6075841e-017+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.20712743+deta0n_lvt'
+LETA0      = '-4.7887074e-013+dleta0n_lvt'
+WETA0      = '-4.419009e-009+dweta0n_lvt'
+PETA0      = '2.9689986e-019+dpeta0n_lvt'
+ETAB       = -0.013328           WETAB      = -2.273664e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.014401576+du0n_lvt'
+LU0        = '-2.8244653e-010+dlu0n_lvt'
+WU0        = '-2.6453333e-011+dwu0n_lvt'
+UA         = '-1.7663883e-009+duan_lvt'
+LUA        = '-3.1889479e-017+dluan_lvt'
+WUA        = '-8.6812156e-017+dwuan_lvt'
+PUA        = '1.8132957e-023+dpuan_lvt'
+UB         = '2.0198222e-018+dubn_lvt'
+LUB        = '4.2656435e-027+dlubn_lvt'
+WUB        = '1.564615e-025+dwubn_lvt'
+PUB        = '-2.415281e-032+dpubn_lvt'
+UC         = 5.8795347e-011      LUC        = -3.3625562e-018     WUC        = -9.1796557e-018
+PUC        = 4.3803107e-026      VSAT       = '108520.22+dvsatn_lvt'
+LVSAT      = '-0.0019424393+dlvsatn_lvt'
+WVSAT      = '-0.0011499396+dwvsatn_lvt'
+PVSAT      = '2.6216323e-010+dpvsatn_lvt'
+A0         = 3.3973626           LA0        = -4.06723e-007       WA0        = 5.1888664e-007
+PA0        = -1.4844993e-013     AGS        = -3.4045335          LAGS       = 9.9654622e-007
+WAGS       = 5.7023742e-007      PAGS       = -5.461734e-014      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.046815963        LKETA      = 4.1557629e-009      WKETA      = -7.0799485e-009
+PKETA      = 1.540209e-015       DWG        = 0                   DWB        = 0
+PCLM       = 0.90629038          LPCLM      = -4.6455571e-008     WPCLM      = 2.0411768e-008
+PPCLM      = 4.3475403e-015      PDIBLC1    = 0                   PDIBLC2    = 0.010722382
+LPDIBLC2   = 2.0543167e-009      WPDIBLC2   = -2.9088021e-009     PPDIBLC2   = 1.35451e-016
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.00072028087       LTVOFF     = -2.7759043e-011
+WTVOFF     = -1.863679e-010      PTVOFF     = 1.3042621e-017      KT1        = '-0.20011431+dkt1n_lvt'
+LKT1       = '-1.1275179e-008+dlkt1n_lvt'
+WKT1       = '-1.7078234e-008+dwkt1n_lvt'
+PKT1       = '2.5344567e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.071566702        LKT2       = 2.3118771e-009
+WKT2       = 5.5352199e-009      PKT2       = -1.1578876e-015     UTE        = -0.99816052
+LUTE       = -1.7618497e-010     WUTE       = -1.1404748e-009     PUTE       = 1.0923468e-016
+UA1        = '2.5321001e-009+dua1n_lvt'
+LUA1       = '-1.5096079e-016+dlua1n_lvt'
+WUA1       = '-7.4359787e-016+dwua1n_lvt'
+PUA1       = '6.677516e-023+dpua1n_lvt'
+UB1        = '-2.9465928e-018+dub1n_lvt'
+LUB1       = '2.0395926e-025+dlub1n_lvt'
+WUB1       = '1.1283658e-024+dwub1n_lvt'
+PUB1       = '-1.0754724e-031+dpub1n_lvt'
+UC1        = 6.9229918e-011      LUC1       = -6.9757134e-018     WUC1       = -1.0003908e-017
+PUC1       = 3.2486394e-024      PRT        = 0                   AT         = -8480.6947
+LAT        = 0.0018270381        WAT        = 0.018327631         PAT        = -1.1327636e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+PU0        = '0+dpu0n_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.20 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-dxln_lvt'
+WMIN       = '3e-007-dxwn_lvt'   WMAX       = '6e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.20722595+dvthn_lvt'
+LVTH0      = '3.2192517e-009+dlvthn_lvt'
+WVTH0      = '8.5015011e-009+dwvthn_lvt'
+PVTH0      = '-5.9860604e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '-0.014596791+dk2n_lvt'
+LK2        = '5.7927533e-010+dlk2n_lvt'
+WK2        = '-5.6735185e-009+dwk2n_lvt'
+PK2        = '8.5944865e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0036902057+dcitn_lvt'
+LCIT       = '-1.5869523e-010+dlcitn_lvt'
+WCIT       = '-8.6086582e-010+dwcitn_lvt'
+PCIT       = '5.0782474e-017+dpcitn_lvt'
+VOFF       = '-0.031594726+dvoffn_lvt'
+LVOFF      = '-9.8882451e-009+dlvoffn_lvt'
+WVOFF      = '-2.2795403e-008+dwvoffn_lvt'
+PVOFF      = '1.8282251e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt+0.132548*ss_flag_lvt'
+ETA0       = '-0.13563792+deta0n_lvt'
+LETA0      = '3.2829586e-008+dleta0n_lvt'
+WETA0      = '-2.0552874e-008+dweta0n_lvt'
+PETA0      = '1.5455985e-015+dpeta0n_lvt'
+ETAB       = -0.027749981
+LETAB      = 1.3813223e-09
+WETAB      = -4.8589085e-08
+PETAB      = 2.4761438e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.0066402542+du0n_lvt'
+LU0        = '4.6093286e-010+dlu0n_lvt'
+WU0        = '1.9034716e-009+dwu0n_lvt'
+PU0        = '-1.8484821e-016+dpu0n_lvt'
+UA         = '-2.998534e-009+duan_lvt'
+LUA        = '8.6125439e-017+dluan_lvt'
+WUA        = '3.2200911e-016+dwuan_lvt'
+PUA        = '-2.1023944e-023+dpuan_lvt'
+UB         = '2.7905183e-018+dubn_lvt'
+LUB        = '-6.9551629e-026+dlubn_lvt'
+WUB        = '-2.4762091e-025+dwubn_lvt'
+PUB        = '1.4550203e-032+dpubn_lvt'
+UC         = 1.1740653e-010      LUC        = -8.9763348e-018     WUC        = -4.2789741e-017
+PUC        = 3.2629771e-024
+VSAT       = '92003.053+dvsatn_lvt+1603.4*ff_flag_lvt'
+LVSAT      = '-0.00036042523+dlvsatn_lvt-0.000153573*ff_flag_lvt'
+WVSAT      = '0.0020434015+dwvsatn_lvt-4.8e-09*ff_flag_lvt'
+PVSAT      = '-4.3694978e-011+dpvsatn_lvt-1e-17*ff_flag_lvt'
+A0         = 2.5997933           LA0        = -3.3033181e-007     WA0        = -2.6841796e-006
+PA0        = 1.5833976e-013      AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.11385734         LKETA      = 1.0576986e-008
+WKETA      = 2.1428615e-008      PKETA      = -1.1903412e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.24683542          LPCLM      = 1.6707025e-008
+WPCLM      = 2.1351615e-007      PPCLM      = -1.4147997e-014     PDIBLC1    = 0
+PDIBLC2    = 0.05799222          LPDIBLC2   = -2.4731884e-009     WPDIBLC2   = -2.8307152e-009
+PPDIBLC2   = 1.2797184e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = -0.0023296862
+LTVOFF     = 2.6436681e-010      WTVOFF     = 3.9209693e-010      PTVOFF     = -4.236274e-017
+KT1        = '-0.48975663+dkt1n_lvt'
+LKT1       = '1.6466763e-008+dlkt1n_lvt'
+WKT1       = '4.3295048e-008+dwkt1n_lvt'
+PKT1       = '-3.2480962e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.045077644        LKT2       = -2.2524485e-010
+WKT2       = -1.0000108e-008     PKT2       = 3.3008608e-016      UTE        = -1
+UA1        = '1.622791e-009+dua1n_lvt'
+LUA1       = '-6.3867152e-017+dlua1n_lvt'
+WUA1       = '-3.6351816e-017+dwua1n_lvt'
+PUA1       = '-9.6486701e-025+dpua1n_lvt'
+UB1        = '-2.0632181e-018+dub1n_lvt'
+LUB1       = '1.1934964e-025+dlub1n_lvt'
+WUB1       = '1.7340143e-025+dwub1n_lvt'
+PUB1       = '-1.6080758e-032+dpub1n_lvt'
+UC1        = -1.5321945e-010     LUC1       = 1.4330487e-017      WUC1       = 7.9298416e-017
+PUC1       = -5.3047373e-024     PRT        = 0                   AT         = 10594.667
+WAT        = 0.0065009067
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt-1.26954e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt-4.24154e-08*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorn_lvt+4.06252e-15*ss_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.21 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_lvt'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.2394201+dvthn_lvt'
+WVTH0      = '-2.4919353e-009+dwvthn_lvt'
+K1         = 0.217               K2         = '0.03608656+dk2n_lvt'
+WK2        = '3.8022953e-009+dwk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.095458708+dvoffn_lvt'
+WVOFF      = '3.2543167e-009+dwvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.01751+du0n_lvt'  WU0        = '-6.72e-011+dwu0n_lvt'
+UA         = '-1.7238889e-009+duan_lvt'
+WUA        = '-1.4435556e-017+dwuan_lvt'
+UB         = '2.5175667e-018+dubn_lvt'
+WUB        = '2.8354667e-026+dwubn_lvt'
+UC         = 5.2511111e-011      WUC        = -2.8099556e-018     VSAT       = '100000+dvsatn_lvt'
+A0         = 2.8072373           WA0        = 2.5924677e-007      AGS        = 0.80255092
+WAGS       = 9.5011955e-009      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.049983333
+WKETA      = 2.7626667e-010      DWG        = 0                   DWB        = 0
+PCLM       = 0.7979              PDIBLC1    = 0                   PDIBLC2    = 0.0022930556
+WPDIBLC2   = 4.2622222e-010      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = 0.0003104
+LTVOFF     = 0                   WTVOFF     = -4.3456e-011        PTVOFF     = 0
+KT1        = '-0.25072969+dkt1n_lvt'
+WKT1       = '-1.6612836e-009+dwkt1n_lvt'
+KT1L       = 0                   KT2        = -0.061485556        WKT2       = 5.8737778e-010
+UTE        = -1.1456667          WUTE       = 1.4933333e-009      UA1        = '1.6608889e-009+dua1n_lvt'
+WUA1       = '-1.0204444e-017+dwua1n_lvt'
+UB1        = '-1.2131111e-018+dub1n_lvt'
+WUB1       = '2.1155556e-026+dwub1n_lvt'
+UC1        = 1.4563333e-011      WUC1       = 1.7173333e-018      PRT        = 0
+AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1
+XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'           CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'         CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'        CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20
+TNJTSSWG   = 1                   VTSSWGS    = 10                  VTSSWGD    = 10
+DMCG       = 6.25e-008           DMCI       = 6.75e-008           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LVTH0      = '0+dlvthn_lvt'      PVTH0      = '0+dpvthn_lvt'
+LK2        = '0+dlk2n_lvt'       PK2        = '0+dpk2n_lvt'       LNFACTOR   = '0+dlnfactorn_lvt'
+WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'  LETA0      = '0+dleta0n_lvt'
+PETA0      = '0+dpeta0n_lvt'     LU0        = '0+dlu0n_lvt'       PU0        = '0+dpu0n_lvt'
+LUA        = '0+dluan_lvt'       PUA        = '0+dpuan_lvt'       LUB        = '0+dlubn_lvt'
+PUB        = '0+dpubn_lvt'       LUA1       = '0+dlua1n_lvt'      PUA1       = '0+dpua1n_lvt'
+LUB1       = '0+dlub1n_lvt'      PUB1       = '0+dpub1n_lvt'      LKT1       = '0+dlkt1n_lvt'
+PKT1       = '0+dpkt1n_lvt'      PVSAT      = '0+dpvsatn_lvt'     WVSAT      = '0+dwvsatn_lvt'
+LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'      WCIT       = '0+dwcitn_lvt'
+PCIT       = '0+dpcitn_lvt'      LVOFF      = '0+dlvoffn_lvt'     PVOFF      = '0+dpvoffn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.22 NMOS	(	LEVEL      = 54                  LMIN       = '1.000002e-006-dxln_lvt'
+LMAX       = '1e-005-dxln_lvt'   WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25                  TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009
+DTOX       = 2.42e-010           EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0
+LLN        = 0                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   XL         = '-1e-09+dxln_lvt'
+XW         = '2e-08+dxwn_lvt'    DLC        = '1.694588E-08+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.23550929+dvthn_lvt'
+LVTH0      = '3.8971661e-008+dlvthn_lvt'
+WVTH0      = '-2.0757584e-009+dwvthn_lvt'
+PVTH0      = '-4.147249e-015+dpvthn_lvt'
+K1         = 0.217               K2         = '0.037766478+dk2n_lvt'
+LK2        = '-1.6740567e-008+dlk2n_lvt'
+WK2        = '3.8019731e-009+dwk2n_lvt'
+PK2        = '3.2107104e-018+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.092405221+dvoffn_lvt'
+LVOFF      = '-3.0428341e-008+dlvoffn_lvt'
+WVOFF      = '2.9269491e-009+dwvoffn_lvt'
+PVOFF      = '3.262254e-015+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.017755686+du0n_lvt'
+LU0        = '-2.4482883e-009+dlu0n_lvt'
+WU0        = '-6.8267579e-011+dwu0n_lvt'
+PU0        = '1.0638537e-017+dpu0n_lvt'
+UA         = '-1.7185033e-009+duan_lvt'
+LUA        = '-5.3667619e-017+dluan_lvt'
+WUA        = '-1.224702e-017+dwuan_lvt'
+PUA        = '-2.1809001e-023+dpuan_lvt'
+UB         = '2.5474812e-018+dubn_lvt'
+LUB        = '-2.9810178e-025+dlubn_lvt'
+WUB        = '2.3915315e-026+dwubn_lvt'
+PUB        = '4.4238627e-032+dpubn_lvt'
+UC         = 5.2058665e-011      LUC        = 4.5086737e-018      WUC        = -2.2022632e-018
+PUC        = -6.0557212e-024     VSAT       = '100000+dvsatn_lvt'
+A0         = '2.7222259+0.0667237*ff_flag_lvt-0.0250214*ss_flag_lvt'
+LA0        = '8.4714859e-007-6.64909e-07*ff_flag_lvt+2.49341e-07*ss_flag_lvt'
+WA0        = '2.8704696e-007-2.13516e-08*ff_flag_lvt+8.00684e-09*ss_flag_lvt'
+PA0        = '-2.7703189e-013+2.12771e-13*ff_flag_lvt-7.97891e-14*ss_flag_lvt'
+AGS        = 0.75433639          LAGS       = 4.8046309e-007      WAGS       = 1.0738512e-008
+PAGS       = -1.2329999e-014     A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.047646218
+LKETA      = -2.328961e-008      WKETA      = -1.7238319e-010     PKETA      = 4.4708451e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.7979
+PDIBLC1    = 0                   PDIBLC2    = 0.0011687322        LPDIBLC2   = 1.1204006e-008
+WPDIBLC2   = 4.9861739e-010      PPDIBLC2   = -7.2142578e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00025820304       LTVOFF     = 5.2014846e-010      WTVOFF     = -3.6148425e-011
+PTVOFF     = -7.2820785e-017     KT1        = '-0.25257404+dkt1n_lvt'
+LKT1       = '1.8379165e-008+dlkt1n_lvt'
+WKT1       = '-8.2177188e-010+dwkt1n_lvt'
+PKT1       = '-8.3658263e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.062433389        LKT2       = 9.4452635e-009
+WKT2       = 9.778446e-010       PKT2       = -3.8910449e-015     UTE        = -1.1560446
+LUTE       = 1.0341703e-007      WUTE       = 2.0004331e-009      PUTE       = -5.053305e-015
+UA1        = '1.7057844e-009+dua1n_lvt'
+LUA1       = '-4.4738847e-016+dlua1n_lvt'
+WUA1       = '-1.4928479e-017+dwua1n_lvt'
+PUA1       = '4.7075526e-023+dpua1n_lvt'
+UB1        = '-1.2163043e-018+dub1n_lvt'
+LUB1       = '3.1820624e-026+dlub1n_lvt'
+WUB1       = '2.7427579e-026+dwub1n_lvt'
+PUB1       = '-6.2501404e-032+dpub1n_lvt'
+UC1        = 1.4644593e-011      LUC1       = -8.0976363e-019     WUC1       = 1.0709146e-018
+PUC1       = 6.4416341e-024      PRT        = 0                   AT         = 180000
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.23 NMOS	(	LEVEL      = 54                  LMIN       = '2.399959e-007-dxln_lvt'
+LMAX       = '1.000002e-006-dxln_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.27355976+dvthn_lvt'
+LVTH0      = '2.2487734e-009+dlvthn_lvt'
+WVTH0      = '-6.9872667e-009+dwvthn_lvt'
+PVTH0      = '5.9289683e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.027085174+dk2n_lvt'
+LK2        = '-6.4319331e-009+dlk2n_lvt'
+WK2        = '3.3651588e-009+dwk2n_lvt'
+PK2        = '4.2478454e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0001+dcitn_lvt'
+VOFF       = '-0.11498798+dvoffn_lvt'
+LVOFF      = '-8.633498e-009+dlvoffn_lvt'
+WVOFF      = '6.7485077e-009+dwvoffn_lvt'
+PVOFF      = '-4.2597046e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812444+deta0n_lvt'
+WETA0      = '1.6625778e-009+dweta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.015832295+du0n_lvt'
+LU0        = '-5.9200475e-010+dlu0n_lvt'
+WU0        = '-5.955374e-011+dwu0n_lvt'
+PU0        = '2.2287238e-018+dpu0n_lvt'
+UA         = '-1.7646952e-009+duan_lvt'
+LUA        = '-9.0873558e-018+dluan_lvt'
+WUA        = '-3.3304914e-017+dwuan_lvt'
+PUA        = '-1.4858158e-024+dpuan_lvt'
+UB         = '2.3113844e-018+dubn_lvt'
+LUB        = '-7.0242343e-026+dlubn_lvt'
+WUB        = '7.2212786e-026+dwubn_lvt'
+PUB        = '-2.3737453e-033+dpubn_lvt'
+UC         = 6.5906414e-011      LUC        = -8.8559267e-018     WUC        = -9.9999637e-018
+PUC        = 1.4699176e-024      VSAT       = '100000+dvsatn_lvt'
+A0         = '4.2941631-0.814663*ff_flag_lvt+0.305499*ss_flag_lvt'
+LA0        = '-6.6994375e-007+1.85727e-07*ff_flag_lvt-6.96476e-08*ss_flag_lvt'
+WA0        = '1.53953e-008+2.60692e-07*ff_flag_lvt-9.77596e-08*ss_flag_lvt'
+PA0        = '-1.4858158e-014-5.94326e-14*ff_flag_lvt+2.22872e-14*ss_flag_lvt'
+AGS        = 1.0810171           LAGS       = 1.6518028e-007      WAGS       = -2.1911435e-008
+PAGS       = 1.9180791e-014      A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.085652449
+LKETA      = 1.3390584e-008      WKETA      = 6.1050767e-009      PKETA      = -1.5875942e-015
+DWG        = 0                   DWB        = 0                   PCLM       = 0.83112017
+LPCLM      = -3.206112e-008      WPCLM      = -1.3401609e-008     PPCLM      = 1.2934027e-014
+PDIBLC1    = 0                   PDIBLC2    = 0.014427274         LPDIBLC2   = -1.5919455e-009
+WPDIBLC2   = -8.2621265e-010     PPDIBLC2   = 5.5718094e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.3685              DELTA      = 0.008
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52                RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.5e-8              ALPHA1     = 3.68                BETA0      = 13.74
+AGIDL      = 1.596e-007          BGIDL      = 2.714e+009          CGIDL      = 0.225
+EGIDL      = 0.2944              AIGBACC    = 0.01389             BIGBACC    = 0.005478
+CIGBACC    = 0.1855              NIGBACC    = 10                  AIGBINV    = 0.01012
+BIGBINV    = 0.0009949           CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 1.314               AIGC       = 0.01138             BIGC       = 0.001244
+CIGC       = 0                   AIGSD      = 0.01054             BIGSD      = 0.0006367
+CIGSD      = 0.001732            NIGC       = 3.182               POXEDGE    = 1
+PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'         XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'
+CGBO       = 0                   CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_lvt'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 8.19                NOFF       = 2.063               VOFFCV     = -0.091411
+TVOFF      = 0.00098342151       LTVOFF     = -1.7976713e-010     WTVOFF     = -1.4611804e-010
+PTVOFF     = 3.3311991e-017      KT1        = '-0.22997626+dkt1n_lvt'
+LKT1       = '-3.4301783e-009+dlkt1n_lvt'
+WKT1       = '-1.0131217e-008+dwkt1n_lvt'
+PKT1       = '6.1881258e-016+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.050372423        LKT2       = -2.1948949e-009
+WKT2       = -3.9983684e-009     PKT2       = 9.1154802e-016      UTE        = -1.0637
+LUTE       = 1.4294344e-008      WUTE       = -4.2362501e-009     PUTE       = 9.6578029e-016
+UA1        = '1.4836845e-009+dua1n_lvt'
+LUA1       = '-2.3303761e-016+dlua1n_lvt'
+WUA1       = '4.4317693e-017+dwua1n_lvt'
+PUA1       = '-1.0103548e-023+dpua1n_lvt'
+UB1        = '-1.5493154e-018+dub1n_lvt'
+LUB1       = '3.5321292e-025+dlub1n_lvt'
+WUB1       = '-4.8879809e-026+dwub1n_lvt'
+PUB1       = '1.1143619e-032+dpub1n_lvt'
+UC1        = 2.0236834e-012      LUC1       = 1.1370803e-017      WUC1       = 1.0140931e-017
+PUC1       = -2.3119294e-024     PRT        = 0                   AT         = 230119.95
+LAT        = -0.048371265        WAT        = -0.0023092951       PAT        = 2.2287238e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+LETA0      = '0+dleta0n_lvt'     PETA0      = '0+dpeta0n_lvt'     PVSAT      = '0+dpvsatn_lvt'
+WVSAT      = '0+dwvsatn_lvt'     LVSAT      = '0+dlvsatn_lvt'     LCIT       = '0+dlcitn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.24 NMOS	(	LEVEL      = 54                  LMIN       = '9.99984e-008-dxln_lvt'
+LMAX       = '2.399959e-007-dxln_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.30108161+dvthn_lvt'
+LVTH0      = '-4.0256597e-009+dlvthn_lvt'
+WVTH0      = '-4.9732314e-009+dwvthn_lvt'
+PVTH0      = '1.3373705e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '0.01076282+dk2n_lvt'
+LK2        = '-2.7107629e-009+dlk2n_lvt'
+WK2        = '4.5414834e-009+dwk2n_lvt'
+PK2        = '1.5660607e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '-0.00055205749+dcitn_lvt'
+LCIT       = '1.4865607e-010+dlcitn_lvt'
+VOFF       = '-0.14844234+dvoffn_lvt'
+LVOFF      = '-1.0065716e-009+dlvoffn_lvt'
+WVOFF      = '5.5104062e-009+dwvoffn_lvt'
+PVOFF      = '-1.4370807e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '0.18812094+deta0n_lvt'
+LETA0      = '7.981179e-013+dleta0n_lvt'
+WETA0      = '1.6630679e-009+dweta0n_lvt'
+PETA0      = '-1.1173651e-019+dpeta0n_lvt'
+ETAB       = -0.058845556        WETAB      = -8.1710222e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.01477312+du0n_lvt'
+LU0        = '-3.5053396e-10+dlu0n_lvt'
+WU0        = '-1.4534752e-10+dwu0n_lvt'
+PU0        = '2.1787978e-17+dpu0n_lvt'
+UA         = '-1.8935091e-009+duan_lvt'
+LUA        = '2.0279624e-017+dluan_lvt'
+WUA        = '-4.6133495e-017+dwuan_lvt'
+PUA        = '1.4388439e-024+dpuan_lvt'
+UB         = '2.317566e-18+dubn_lvt'
+LUB        = '-7.1651638e-26+dlubn_lvt'
+WUB        = '6.1183458e-26+dwubn_lvt'
+PUB        = '1.407198e-34+dpubn_lvt'
+UC         = 4.0332202e-011      LUC        = -3.025518e-018      WUC        = -3.2714493e-018
+PUC        = -6.4049109e-026     VSAT       = '104306.8+dvsatn_lvt'
+LVSAT      = '-0.00098186414+dlvsatn_lvt'
+WVSAT      = '0.00019835428+dwvsatn_lvt'
+PVSAT      = '-4.5220808e-011+dpvsatn_lvt'
+A0         = 5.3012189
+LA0        = -8.9953223e-07
+WA0        = -9.034737e-08
+PA0        = 9.249022e-15
+AGS        = -1.9578627          LAGS       = 8.5798409e-007
+WAGS       = 1.0730274e-007      PAGS       = -1.0277456e-014     A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.041609695        LKETA      = 3.3497167e-009      WKETA      = -8.7459541e-009
+PKETA      = 1.7981438e-015      DWG        = 0                   DWB        = 0
+PCLM       = 0.85991114          LPCLM      = -3.8624884e-008     WPCLM      = 3.5253127e-008
+PPCLM      = 1.8417202e-015      PDIBLC1    = 0
+PDIBLC2    = -0.011808163
+LPDIBLC2   = 4.3892094e-09
+WPDIBLC2   = 4.3009722e-09
+PPDIBLC2   = -6.1171466e-16
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.3685
+DELTA      = 0.008               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                RSW        = '65+drdswn_lvt'
+RDW        = '65+drdswn_lvt'     PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.5e-8              ALPHA1     = 3.68
+BETA0      = 13.74               AGIDL      = 1.596e-007          BGIDL      = 2.714e+009
+CGIDL      = 0.225               EGIDL      = 0.2944              AIGBACC    = 0.01389
+BIGBACC    = 0.005478            CIGBACC    = 0.1855              NIGBACC    = 10
+AIGBINV    = 0.01012             BIGBINV    = 0.0009949           CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 1.314               AIGC       = 0.01138
+BIGC       = 0.001244            CIGC       = 0                   AIGSD      = 0.01054
+BIGSD      = 0.0006367           CIGSD      = 0.001732            NIGC       = 3.182
+POXEDGE    = 1                   PIGCD      = 2.659               NTOX       = 'ntoxn_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_lvt'
+CGDO       = 'cgon_lvt'          CGBO       = 0                   CGDL       = 'cgln_lvt'
+CGSL       = 'cgln_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 8.19                NOFF       = 2.063
+VOFFCV     = -0.091411           TVOFF      = 0.00016194292       LTVOFF     = 7.5135548e-012
+WTVOFF     = -7.6997524e-012     PTVOFF     = 1.7553896e-018      KT1        = '-0.20845774+dkt1n_lvt'
+LKT1       = '-8.3359715e-009+dlkt1n_lvt'
+WKT1       = '-1.4408336e-008+dwkt1n_lvt'
+PKT1       = '1.5939102e-015+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.04821708         LKT2       = -2.6862702e-009
+WKT2       = -1.936659e-009      PKT2       = 4.4151953e-016      UTE        = -1.0017245
+LUTE       = 1.6517341e-010      UA1        = '1.826609e-010+dua1n_lvt'
+LUA1       = '6.3569739e-017+dlua1n_lvt'
+WUA1       = '8.2226864e-018+dwua1n_lvt'
+PUA1       = '-1.8746081e-024+dpua1n_lvt'
+UB1        = '5.9907951e-019+dub1n_lvt'
+LUB1       = '-1.3657815e-025+dlub1n_lvt'
+WUB1       = '-6.2493499e-027+dwub1n_lvt'
+PUB1       = '1.4247268e-033+dpub1n_lvt'
+UC1        = 3.1233803e-011      LUC1       = 4.7114797e-018      WUC1       = 2.1548488e-018
+PUC1       = -4.9126242e-025     PRT        = 0                   AT         = 5787.807
+LAT        = 0.0027719768        WAT        = 0.01376171          PAT        = -1.435144e-009
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+WCIT       = '0+dwcitn_lvt'      PCIT       = '0+dpcitn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL nch_lvt.25 NMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.99984e-008-dxln_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwn_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_lvt'          TOXM       = 2.6e-009            DTOX       = 2.42e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415E-09
+LL         = 2.2652e-05          WL         = 0                   LLN        = -0.5009
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 2.2652e-05          WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1e-09+dxln_lvt'   XW         = '2e-08+dxwn_lvt'
+DLC        = '-5.415E-09+ddlcn_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '0.25624615+dvthn_lvt'
+LVTH0      = '2.686806e-010+dlvthn_lvt'
+WVTH0      = '-7.184963e-009+dwvthn_lvt'
+PVTH0      = '3.455767e-016+dpvthn_lvt'
+K1         = 0.217               K2         = '-0.043265034+dk2n_lvt'
+LK2        = '2.4640249e-009+dlk2n_lvt'
+WK2        = '3.5003192e-009+dwk2n_lvt'
+PK2        = '2.5632877e-016+dpk2n_lvt'
+K3         = -3                  K3B        = 3.225               W0         = 0
+DVT0       = 33.571              DVT1       = 1.7                 DVT2       = -0.01
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.65                MINV       = 0                   VOFFL      = 0
+DVTP0      = 3.8964e-007         DVTP1      = 0.5                 LPE0       = 1.12e-007
+LPEB       = 1e-009
+WEB        = -150
+WEC        = -3000
+SCREF      = 1e-6
+KVTH0WE    = 0.00465
+LKVTH0WE   = -12.6e-11
+WKVTH0WE   = -19.5e-11
+PKVTH0WE   = 1.00e-17
+K2WE       = 0.0018
+LK2WE      = 2e-11
+WK2WE      = -11.5e-11
+PK2WE      = 0
+XJ         = 8.6e-008            NGATE      = 7.8399e+020         NDEP       = 6.5e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = '0+dcdscdn_lvt'     CIT        = '0.0015487276+dcitn_lvt'
+LCIT       = '-5.2557131e-011+dlcitn_lvt'
+WCIT       = '-1.7559284e-010+dwcitn_lvt'
+PCIT       = '1.6818282e-017+dpcitn_lvt'
+VOFF       = '-0.094631602+dvoffn_lvt'
+LVOFF      = '-6.1605643e-009+dlvoffn_lvt'
+WVOFF      = '-2.6236025e-009+dwvoffn_lvt'
+PVOFF      = '6.3536728e-016+dpvoffn_lvt'
+NFACTOR    = '1+dnfactorn_lvt'   ETA0       = '-0.28639279+deta0n_lvt'
+LETA0      = '4.5449723e-008+dleta0n_lvt'
+WETA0      = '2.7688684e-008+dweta0n_lvt'
+PETA0      = '-2.4928453e-015+dpeta0n_lvt'
+ETAB       = -0.11934949
+LETAB      = 5.7950445e-09
+WETAB      = -1.9277245e-08
+PETAB      = 1.0637527e-15
+UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.001
+LKU0WE     = -0.8e-10
+WKU0WE     = -3.3e-10
+PKU0WE     = 0.8e-17
+U0         = '0.012830788+du0n_lvt'
+LU0        = '-1.6449814e-10+dlu0n_lvt'
+WU0        = '-7.749898e-11+dwu0n_lvt'
+PU0        = '1.5289711e-17+dpu0n_lvt'
+UA         = '-1.8189597e-009+duan_lvt'
+LUA        = '1.3139283e-017+dluan_lvt'
+WUA        = '-5.5454663e-017+dwuan_lvt'
+PUA        = '2.3316254e-024+dpuan_lvt'
+UB         = '1.736574e-18+dubn_lvt'
+LUB        = '-1.6004302e-26+dlubn_lvt'
+WUB        = '8.9641261e-26+dwubn_lvt'
+PUB        = '-2.5849419e-33+dpubn_lvt'
+UC         = 2.1635444e-012      LUC        = 6.3027603e-019      WUC        = -5.9119877e-018
+PUC        = 1.8886166e-025
+VSAT       = '97543.183+dvsatn_lvt+2850.5*ff_flag_lvt'
+LVSAT      = '-0.00033404493+dlvsatn_lvt-0.000273019*ff_flag_lvt'
+WVSAT      = '0.00027056001+dwvsatn_lvt-0.00039907*ff_flag_lvt'
+PVSAT      = '-5.2136674e-011+dpvsatn_lvt+3.82226e-11*ff_flag_lvt'
+A0         = -5.8388671
+LA0        = 1.6746271e-07
+WA0        = 1.61917e-08
+PA0        = -9.54492e-16
+AGS        = 10.20685            LAGS       = -3.0715206e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12857534         LKETA      = 1.1679287e-008
+WKETA      = 2.6138376e-008      PKETA      = -1.5430774e-015     DWG        = 0
+DWB        = 0                   PCLM       = 0.52046075          LPCLM      = -6.1123261e-009
+WPCLM      = 1.2595604e-007      PPCLM      = -6.8458052e-015     PDIBLC1    = 0
+PDIBLC2    = 0.076715215
+LPDIBLC2   = -4.0895614e-09
+WPDIBLC2   = -8.8220735e-09
+PPDIBLC2   = 6.4521118e-16
+PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.3685              DELTA      = 0.008               PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = '65+drdswn_lvt'     RDW        = '65+drdswn_lvt'     PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.5e-8
+ALPHA1     = 3.68                BETA0      = 13.74               AGIDL      = 1.596e-007
+BGIDL      = 2.714e+009          CGIDL      = 0.225               EGIDL      = 0.2944
+AIGBACC    = 0.01389             BIGBACC    = 0.005478            CIGBACC    = 0.1855
+NIGBACC    = 10                  AIGBINV    = 0.01012             BIGBINV    = 0.0009949
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 1.314
+AIGC       = 0.01138             BIGC       = 0.001244            CIGC       = 0
+AIGSD      = 0.01054             BIGSD      = 0.0006367           CIGSD      = 0.001732
+NIGC       = 3.182               POXEDGE    = 1                   PIGCD      = 2.659
+NTOX       = 'ntoxn_lvt'         XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_lvt'          CGDO       = 'cgon_lvt'          CGBO       = 0
+CGDL       = 'cgln_lvt'          CGSL       = 'cgln_lvt'          CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_lvt'           CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 8.19
+NOFF       = 2.063               VOFFCV     = -0.091411           TVOFF      = -0.0025740261
+LTVOFF     = 2.6956467e-010      WTVOFF     = 4.702857e-010       PTVOFF     = -4.4026057e-017
+KT1        = '-0.4429226+dkt1n_lvt'
+LKT1       = '1.4121057e-08+dlkt1n_lvt'
+WKT1       = '2.8308156e-08+dwkt1n_lvt'
+PKT1       = '-2.4974703e-15+dpkt1n_lvt'
+KT1L       = 0                   KT2        = -0.10473481         LKT2       = 2.7269984e-009
+WKT2       = 9.0901867e-009      PKT2       = -6.1463176e-016     UTE        = -1.2618927
+LUTE       = 2.5084085e-008      WUTE       = 8.3805672e-008      PUTE       = -8.0269073e-015
+UA1        = '1.5556327e-009+dua1n_lvt'
+LUA1       = '-6.7933504e-017+dlua1n_lvt'
+WUA1       = '-1.486119e-017+dwua1n_lvt'
+PUA1       = '3.3636564e-025+dpua1n_lvt'
+UB1        = '-1.9656468e-018+dub1n_lvt'
+LUB1       = '1.0907134e-025+dlub1n_lvt'
+WUB1       = '1.421786e-025+dwub1n_lvt'
+PUB1       = '-1.2791702e-032+dpub1n_lvt'
+UC1        = 1.1243771e-010      LUC1       = -3.0662308e-018     WUC1       = -5.7118742e-018
+PUC1       = 2.622123e-025       PRT        = 0                   AT         = 44705.755
+LAT        = -0.0009555842       WAT        = -0.0044146415       PAT        = 3.0578694e-010
+NOIA       = 'noian_lvt'
+NOIB       = 'noibn_lvt'
+NOIC       = 'noicn_lvt'
+EM         = 1e+06
+EF         = 1.00
+JSS        = 1.7e-07
+JSD        = 1.7e-07
+JSWS       = 2.8e-13
+JSWD       = 2.8e-13
+JSWGS      = 2.8e-13
+JSWGD      = 2.8e-13
+NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.3
+BVD        = 9.3
+XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7
+PBD        = 0.7
+CJS        = 'cjn_lvt'
+CJD        = 'cjn_lvt'
+MJS        = 0.31
+MJD        = 0.31
+PBSWS      = 0.5
+PBSWD      = 0.5
+CJSWS      = 'cjswn_lvt'
+CJSWD      = 'cjswn_lvt'
+MJSWS      = 0.08
+MJSWD      = 0.08
+PBSWGS     = 1
+PBSWGD     = 1
+CJSWGS     = 'cjswgn_lvt'
+CJSWGD     = 'cjswgn_lvt'
+MJSWGS     = 0.75
+MJSWGD     = 0.75
+TPB        = 0.0015
+TCJ        = 0.00073
+TPBSW      = 0.001
+TCJSW      = 0.0003
+TPBSWG     = 0.002
+TCJSWG     = 0.0015
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 20                  TNJTSSWG   = 1
+VTSSWGS    = 10                  VTSSWGD    = 10                  DMCG       = 6.25e-008
+DMCI       = 6.75e-008           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 4.0e-009
+LKVTH0     = -0.9e-008
+WKVTH0     = 6.5e-007
+PKVTH0     = 2e-015
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 4e-010
+LODK2      = 0.5
+LODETA0    = 1
+KU0        = -2.6e-008
+PKU0     = 10e-14
+LKU0       = 5e-008
+WKU0       = 0
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.75
+STETA0     = -7.3e-09
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorn_lvt'  WNFACTOR   = '0+dwnfactorn_lvt'  PNFACTOR   = '0+dpnfactorn_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )

**********************************************************************************************
*                                                                                            *
*                               1.2V LOW-VT PMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************



.MODEL pch_lvt.1 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-dxlp_lvt'
+LMAX       = 2.001e-05           WMIN       = '1e-005-dxwp_lvt'   WMAX       = 0.00090001
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_lvt'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.245727+dvthp_lvt'
+K1         = 0.1515              K2         = '0.02271+dk2p_lvt'  K3         = -3.625
+K3B        = 2.128               W0         = 0                   DVT0       = 34.51
+DVT1       = 2                   DVT2       = 0.03192             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.6563
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 1.291e-006
+DVTP1      = 2.22e-015           LPE0       = 1.366e-007          LPEB       = 4.44089e-021
+WEB        = -210                WEC        = -3550               SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007
+NGATE      = 1.5987e+020         NDEP       = 6.3687e+017         NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'  VOFF       = '-0.07321+dvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01172+du0p_lvt'  UA         = '2.506e-010+duap_lvt'
+UB         = '1.39584e-018+dubp_lvt'
+UC         = 1.261e-011          VSAT       = '95420+dvsatp_lvt'  A0         = '3.245+da0p_lvt'
+AGS        = '0.9114+dagsp_lvt'  A1         = 0                   A2         = 1
+B0         = 0                   B1         = 0                   KETA       = -0.02694
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.004575+dpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001548            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2285
+KT1L       = 0                   KT2        = -0.04746            UTE        = '-1.423+dutep_lvt'
+UA1        = '1.0400723e-009+dua1p_lvt'
+UB1        = '-2.0192616e-018+dub1p_lvt'
+UC1        = 4.302e-011          PRT        = 0                   AT         = '180000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'
+LK2        = '0+dlk2p_lvt'       WK2        = '0+dwk2p_lvt'       PK2        = '0+dpk2p_lvt'
+LU0        = '0+dlu0p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'
+LUB        = '0+dlubp_lvt'       WUB        = '0+dwubp_lvt'       PUB        = '0+dpubp_lvt'
+LUA1       = '0+dlua1p_lvt'      WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'
+LCIT       = '0+dlcitp_lvt'      WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'
+LVOFF      = '0+dlvoffp_lvt'     WVOFF      = '0+dwvoffp_lvt'     PVOFF      = '0+dpvoffp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LA0        = '0+dla0p_lvt'       WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+LPDIBLC2   = '0+dlpdiblc2p_lvt'  WPDIBLC2   = '0+dwpdiblc2p_lvt'  PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.2 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-dxlp_lvt'
+LMAX       = '9.999994e-006-dxlp_lvt'
+WMIN       = '1e-005-dxwp_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24557714+dvthp_lvt'
+LVTH0      = '-1.4932598e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.023357018+dk2p_lvt'
+LK2        = '-6.4469543e-009+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.7151111e-005+dcitp_lvt'
+LCIT       = '4.2695061e-010+dlcitp_lvt'
+VOFF       = '-0.073267478+dvoffp_lvt'
+LVOFF      = '5.7271155e-010+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011883897+du0p_lvt'
+LU0        = '-1.6330861e-009+dlu0p_lvt'
+UA         = '3.1555892e-010+duap_lvt'
+LUA        = '-6.4725713e-016+dluap_lvt'
+UB         = '1.350014e-018+dubp_lvt'
+LUB        = '4.5661484e-025+dlubp_lvt'
+UC         = 1.2906943e-011      LUC        = -2.9587678e-018     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.3958281+da0p_lvt'
+LA0        = '-1.5028662e-006+dla0p_lvt'
+AGS        = '0.83495758+dagsp_lvt'
+LAGS       = '7.616799e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025262466        LKETA      = -1.6715117e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0035233811+dpdiblc2p_lvt'
+LPDIBLC2   = '1.0478435e-008+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015817435        LTVOFF     = -3.3622361e-010
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.22058367
+LKT1       = -7.8879126e-008     KT1L       = 0                   KT2        = -0.046051343
+LKT2       = -1.4036001e-008     UTE        = '-1.4262137+dutep_lvt'
+LUTE       = '3.2021296e-008+dlutep_lvt'
+UA1        = '1.0282469e-009+dua1p_lvt'
+LUA1       = '1.1782963e-016+dlua1p_lvt'
+UB1        = '-2.0087181e-018+dub1p_lvt'
+LUB1       = '-1.0505657e-025+dlub1p_lvt'
+UC1        = 4.0713659e-011      LUC1       = 2.2980617e-017      PRT        = 0
+AT         = '181606.83+datp_lvt'
+LAT        = '-0.016010648+dlatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      WUTE       = '0+dwutep_lvt'
+PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.3 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-dxlp_lvt'
+LMAX       = '9.999943e-007-dxlp_lvt'
+WMIN       = '1e-005-dxwp_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24492653+dvthp_lvt'
+LVTH0      = '-2.1205141e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.017249919+dk2p_lvt'
+LK2        = '-5.5910011e-010+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0005+dcitp_lvt'
+VOFF       = '-0.063746806+dvoffp_lvt'
+LVOFF      = '-8.6061682e-009+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007+deta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010606915+du0p_lvt'
+LU0        = '-4.0194765e-010+dlu0p_lvt'
+UA         = '-2.4621094e-010+duap_lvt'
+LUA        = '-1.0565481e-016+dluap_lvt'
+UB         = '1.8280273e-018+dubp_lvt'
+LUB        = '-4.2377854e-027+dlubp_lvt'
+UC         = 4.0005646e-012      LUC        = 5.6278715e-018      VSAT       = '95420+dvsatp_lvt'
+A0         = '2.0210068+da0p_lvt'
+LA0        = '-1.7740095e-007+dla0p_lvt'
+AGS        = '-0.05990041+dagsp_lvt'
+LAGS       = '1.6244125e-006+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024606831        LKETA      = -1.7347214e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '2.1880819+dpclmp_lvt'
+LPCLM      = '-1.8132977e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.012634061+dpdiblc2p_lvt'
+LPDIBLC2   = '1.6948289e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001129555         LTVOFF     = 9.9731371e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.30563125
+LKT1       = 3.1152454e-009      KT1L       = 0                   KT2        = -0.058986226
+LKT2       = -1.5654803e-009     UTE        = '-1.5161937+dutep_lvt'
+LUTE       = '1.18771e-007+dlutep_lvt'
+UA1        = '1.0511404e-009+dua1p_lvt'
+LUA1       = '9.5758046e-017+dlua1p_lvt'
+UB1        = '-2.2556104e-018+dub1p_lvt'
+LUB1       = '1.3297232e-025+dlub1p_lvt'
+UC1        = 5.1337246e-011      LUC1       = 1.2738416e-017      PRT        = 0
+AT         = '201049.03+datp_lvt'
+LAT        = '-0.034754872+dlatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      WUTE       = '0+dwutep_lvt'
+PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'
+WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.4 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_lvt'
+LMAX       = '2.399901e-007-dxlp_lvt'
+WMIN       = '1e-005-dxwp_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25992226+dvthp_lvt'
+LVTH0      = '1.3298543e-009+dlvthp_lvt'
+K1         = 0.1515              K2         = '0.012592179+dk2p_lvt'
+LK2        = '5.1259931e-010+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00074032601+dcitp_lvt'
+LCIT       = '2.8538661e-010+dlcitp_lvt'
+VOFF       = '-0.079227655+dvoffp_lvt'
+LVOFF      = '-5.0441796e-009+dlvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.31007075+deta0p_lvt'
+LETA0      = '-1.7223091e-013+dleta0p_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0097253089+du0p_lvt'
+LU0        = '-1.9909893e-010+dlu0p_lvt'
+UA         = '-5.8982587e-010+duap_lvt'
+LUA        = '-2.6592452e-017+dluap_lvt'
+UB         = '1.8974557e-018+dubp_lvt'
+LUB        = '-2.0212565e-026+dlubp_lvt'
+UC         = 1.8758959e-011      LUC        = 2.2321126e-018      VSAT       = '95420+dvsatp_lvt'
+A0         = '5.1798199+da0p_lvt'
+LA0        = '-9.0421226e-007+dla0p_lvt'
+AGS        = '9.3204651+dagsp_lvt'
+LAGS       = '-5.3391581e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10047906         LKETA      = 1.1022778e-010
+DWG        = 0                   DWB        = 0                   PCLM       = '1.5497074+dpclmp_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0072748689+dpdiblc2p_lvt'
+LPDIBLC2   = '2.9279254e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017381577        LTVOFF     = -4.0302032e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.25915816
+LKT1       = -7.5777465e-009     KT1L       = 0                   KT2        = -0.065131287
+LKT2       = -1.515632e-010      UTE        = '-1+dutep_lvt'      UA1        = '1.3871611e-009+dua1p_lvt'
+LUA1       = '1.844303e-017+dlua1p_lvt'
+UB1        = '-1.8107081e-018+dub1p_lvt'
+LUB1       = '3.0604743e-026+dlub1p_lvt'
+UC1        = 5.9991284e-011      LUC1       = 1.0747209e-017      PRT        = 0
+AT         = '93415.153+datp_lvt'
+LAT        = '-0.0099893926+dlatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      WK2        = '0+dwk2p_lvt'
+PK2        = '0+dpk2p_lvt'       WU0        = '0+dwu0p_lvt'       PU0        = '0+dpu0p_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'       WUB        = '0+dwubp_lvt'
+PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'      WAT        = '0+dwatp_lvt'
+PAT        = '0+dpatp_lvt'       WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+WETA0      = '0+dweta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     WCIT       = '0+dwcitp_lvt'
+PCIT       = '0+dpcitp_lvt'      WVOFF      = '0+dwvoffp_lvt'     PVOFF      = '0+dpvoffp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+WA0        = '0+dwa0p_lvt'       PA0        = '0+dpa0p_lvt'       WAGS       = '0+dwagsp_lvt'
+PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'     WPDIBLC2   = '0+dwpdiblc2p_lvt'  PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.5 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_lvt'
+WMIN       = '1e-005-dxwp_lvt'   WMAX       = 0.00090001          VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.2308502+dvthp_lvt-0.0135829*ff_flag_lvt+0.0271658*ss_flag_lvt-0.00679147*sf_flag_lvt+0.00679147*fs_flag_lvt'
+LVTH0      = '-1.5337437e-009+dlvthp_lvt+1.33792e-09*ff_flag_lvt-2.67583e-09*ss_flag_lvt+6.68957e-10*sf_flag_lvt-6.68957e-10*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0057584566+dk2p_lvt'
+LK2        = '2.3201369e-009+dlk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023303306+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.4200206e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.080417806+dvoffp_lvt-0.0458424*ff_flag_lvt+0.050936*ss_flag_lvt-0.0339573*sf_flag_lvt+0.0339573*fs_flag_lvt'
+LVOFF      = '-4.9269497e-009+dlvoffp_lvt+4.51546e-09*ff_flag_lvt-5.01718e-09*ss_flag_lvt+3.34479e-09*sf_flag_lvt-3.34479e-09*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.0*ff_flag_lvt-0.679147*ss_flag_lvt'
+ETA0       = '-0.080311783+deta0p_lvt+0.0848933*ff_flag_lvt-0.0848933*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LETA0      = '3.8452507e-008+dleta0p_lvt-8.36197e-09*ff_flag_lvt+8.36197e-09*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+ETAB       = -0.1297             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0054866509+du0p_lvt+0.000169787*ff_flag_lvt-0.0011885*ss_flag_lvt+6.79147e-05*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '2.1840889e-010+dlu0p_lvt-1.67239e-11*ff_flag_lvt+1.17067e-10*ss_flag_lvt-6.68957e-12*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '-1.3372262e-009+duap_lvt'
+LUA        = '4.7026478e-017+dluap_lvt'
+UB         = '1.7168674e-018+dubp_lvt'
+LUB        = '-2.4246129e-027+dlubp_lvt'
+UC         = 3.8058322e-011      LUC        = 3.3112527e-019
+VSAT       = '90190.723+dvsatp_lvt+0.0*ff_flag_lvt+5093.6*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LVSAT      = '0.00051508375+dlvsatp_lvt+0.0*ff_flag_lvt-0.000501718*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+A0         = '-14.186903+da0p_lvt'
+LA0        = '1.0034099e-006+dla0p_lvt'
+AGS        = '-4.4583536+dagsp_lvt'
+LAGS       = '8.2329783e-007+dlagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26537425         LKETA      = 1.6352404e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '1.794236+dpclmp_lvt'
+LPCLM      = '-5.8532244e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.04888472+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.1706449e-009+dlpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0016023486        LTVOFF     = -2.6924832e-011
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.29154839
+LKT1       = -4.3873095e-009     KT1L       = 0                   KT2        = -0.063427169
+LKT2       = -3.1941882e-010     UTE        = '-1+dutep_lvt'      UA1        = '2.1847177e-009+dua1p_lvt'
+LUA1       = '-6.0116294e-017+dlua1p_lvt'
+UB1        = '-1.2998712e-018+dub1p_lvt'
+LUB1       = '-1.9712687e-026+dlub1p_lvt'
+UC1        = 2.202043e-010       LUC1       = -5.033773e-018      PRT        = 0
+AT         = '-8000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07            JSD        = 1.15e-07            JSWS       = 1.7e-13
+JSWD       = 1.7e-13             JSWGS      = 1.7e-13             JSWGD      = 1.7e-13
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9.4                 BVD        = 9.4                 XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjp_lvt'           CJD        = 'cjp_lvt'           MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.9                 PBSWD      = 0.9
+CJSWS      = 'cjswp_lvt'         CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06
+MJSWD      = 0.06                PBSWGS     = 0.5                 PBSWGD     = 0.5
+CJSWGS     = 'cjswgp_lvt'        CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9
+MJSWGD     = 0.9                 TPB        = 0.0017              TCJ        = 0.00091
+TPBSW      = 0.003               TCJSW      = 0.00022             TPBSWG     = 0.0005
+TCJSWG     = 0.003               XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9
+XTSSWGS    = 0.4055              XTSSWGD    = 0.4055              TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 6.1e-008
+DMCI       = 6.6e-008            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WVTH0      = '0+dwvthp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVTH0      = '0+dpvthp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WK2        = '0+dwk2p_lvt'       PK2        = '0+dpk2p_lvt'
+WU0        = '0+dwu0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '0+dpu0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WUA        = '0+dwuap_lvt'       PUA        = '0+dpuap_lvt'
+WUB        = '0+dwubp_lvt'       PUB        = '0+dpubp_lvt'       WUA1       = '0+dwua1p_lvt'
+PUA1       = '0+dpua1p_lvt'      WUB1       = '0+dwub1p_lvt'      PUB1       = '0+dpub1p_lvt'
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+WETA0      = '0+dweta0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PETA0      = '0+dpeta0p_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '0+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '0+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WVOFF      = '0+dwvoffp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVOFF      = '0+dpvoffp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+0.0*ff_flag_lvt+6.68957e-08*ss_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt'
+WA0        = '0+dwa0p_lvt'
+PA0        = '0+dpa0p_lvt'       WAGS       = '0+dwagsp_lvt'      PAGS       = '0+dpagsp_lvt'
+WVSAT      = '0+dwvsatp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PVSAT      = '0+dpvsatp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WPDIBLC2   = '0+dwpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.6 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-dxlp_lvt'
+LMAX       = 2.001e-05           WMIN       = '1e-006-dxwp_lvt'   WMAX       = '1e-005-dxwp_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_lvt'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.24613661+dvthp_lvt'
+WVTH0      = '4.1042855e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.022589867+dk2p_lvt'
+WK2        = '1.203736e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.073647406+dvoffp_lvt'
+WVOFF      = '4.3828091e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011690533+du0p_lvt'
+WU0        = '2.95256e-010+dwu0p_lvt'
+UA         = '2.7867675e-010+duap_lvt'
+WUA        = '-2.81329e-016+dwuap_lvt'
+UB         = '1.3827405e-018+dubp_lvt'
+WUB        = '1.3125719e-025+dwubp_lvt'
+UC         = 1.4039133e-011      WUC        = -1.4319916e-017     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.1594333+da0p_lvt'
+WA0        = '8.57378e-007+dwa0p_lvt'
+AGS        = '0.913406+dagsp_lvt'
+WAGS       = '-2.010012e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027008           WKETA      = 6.8136e-010
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0047535+dpdiblc2p_lvt'
+WPDIBLC2   = '-1.78857e-009+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015770133        LTVOFF     = 0
+WTVOFF     = -2.907136e-010      PTVOFF     = 0                   KT1        = -0.22664063
+WKT1       = -1.8630881e-008     KT1L       = 0                   KT2        = -0.047979067
+WKT2       = 5.201048e-009       UTE        = '-1.40974+dutep_lvt'
+WUTE       = '-1.328652e-007+dwutep_lvt'
+UA1        = '1.0481258e-009+dua1p_lvt'
+WUA1       = '-8.0696003e-017+dwua1p_lvt'
+UB1        = '-2.0755539e-018+dub1p_lvt'
+WUB1       = '5.6404955e-025+dwub1p_lvt'
+UC1        = 4.4673533e-011      WUC1       = -1.6568404e-017     PRT        = 0
+AT         = '178866.67+datp_lvt'
+WAT        = '0.011356+dwatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.7 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-dxlp_lvt'
+LMAX       = '9.999994e-006-dxlp_lvt'
+WMIN       = '1e-006-dxwp_lvt'   WMAX       = '1e-005-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.24628366+dvthp_lvt+1.82108e-05*ff_flag_lvt+1.82108e-05*ss_flag_lvt'
+LVTH0      = '1.4651906e-009+dlvthp_lvt-1.81454e-10*ff_flag_lvt-1.81454e-10*ss_flag_lvt'
+WVTH0      = '7.0793332e-009+dwvthp_lvt-1.82472e-10*ff_flag_lvt-1.82472e-10*ss_flag_lvt'
+PVTH0      = '-2.9643673e-014+dpvthp_lvt+1.81817e-15*ff_flag_lvt+1.81817e-15*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.023221102+dk2p_lvt'
+LK2        = '-6.2896941e-009+dlk2p_lvt'
+WK2        = '1.3618784e-009+dwk2p_lvt'
+PK2        = '-1.5757466e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.717782e-005+dcitp_lvt'
+LCIT       = '4.2668448e-010+dlcitp_lvt'
+WCIT       = '-2.6762559e-013+dwcitp_lvt'
+PCIT       = '2.6666481e-018+dpcitp_lvt'
+VOFF       = '-0.074024001+dvoffp_lvt'
+LVOFF      = '3.7524325e-009+dlvoffp_lvt'
+WVOFF      = '7.5803687e-009+dwvoffp_lvt'
+PVOFF      = '-3.1860804e-014+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011873005+du0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '-1.8181692e-009+dlu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WU0        = '1.0913457e-010+dwu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '1.8545326e-015+dpu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '3.4845103e-010+duap_lvt'
+LUA        = '-6.9523793e-016+dluap_lvt'
+WUA        = '-3.2957898e-016+dwuap_lvt'
+PUA        = '4.8076757e-022+dpuap_lvt'
+UB         = '1.3338644e-018+dubp_lvt'
+LUB        = '4.8700614e-025+dlubp_lvt'
+WUB        = '1.6181899e-025+dwubp_lvt'
+PUB        = '-3.0452079e-031+dpubp_lvt'
+UC         = 1.4333952e-011      LUC        = -2.9375981e-018     WUC        = -1.4298628e-017
+PUC        = -2.1211974e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '3.3128595+da0p_lvt'
+LA0        = '-1.5287536e-006+dla0p_lvt'
+WA0        = '8.3134533e-007+dwa0p_lvt'
+PA0        = '2.5939214e-013+dpa0p_lvt'
+AGS        = '0.83488391+dagsp_lvt'
+LAGS       = '7.8240194e-007+dlagsp_lvt'
+WAGS       = '7.3818164e-010+dwagsp_lvt'
+PAGS       = '-2.0763492e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025309949        LKETA      = -1.6919555e-008
+WKETA      = 4.7577489e-010      PKETA      = 2.0484706e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '0.0038497891+dpdiblc2p_lvt'
+LPDIBLC2   = '9.004666e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.2706075e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '1.476717e-014+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0016125536        LTVOFF     = -3.5412707e-010
+WTVOFF     = -3.087175e-010      PTVOFF     = 1.7939269e-016      KT1        = -0.21827619
+LKT1       = -8.3344177e-008     WKT1       = -2.3120981e-008     PKT1       = 4.473981e-014
+KT1L       = 0                   KT2        = -0.046399107        LKT2       = -1.5742879e-008
+WKT2       = 3.4845948e-009      PKT2       = 1.7102912e-014      UTE        = '-1.4113511+dutep_lvt'
+LUTE       = '1.6053343e-008+dlutep_lvt'
+WUTE       = '-1.4892274e-007+dwutep_lvt'
+PUTE       = '1.5999889e-013+dputep_lvt'
+UA1        = '1.0402771e-009+dua1p_lvt'
+LUA1       = '7.8205071e-017+dlua1p_lvt'
+WUA1       = '-1.2054286e-016+dwua1p_lvt'
+PUA1       = '3.9703806e-022+dpua1p_lvt'
+UB1        = '-2.0747062e-018+dub1p_lvt'
+LUB1       = '-8.4472996e-027+dlub1p_lvt'
+WUB1       = '6.612008e-025+dwub1p_lvt'
+PUB1       = '-9.6802486e-031+dpub1p_lvt'
+UC1        = 4.1972261e-011      LUC1       = 2.6915749e-017      WUC1       = -1.2611195e-017
+PUC1       = -3.9430029e-023     PRT        = 0                   AT         = '180534.2+datp_lvt'
+LAT        = '-0.016615495+dlatp_lvt'
+WAT        = '0.01074776+dwatp_lvt'
+PAT        = '6.060564e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.8 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-dxlp_lvt'
+LMAX       = '9.999943e-007-dxlp_lvt'
+WMIN       = '1e-006-dxwp_lvt'   WMAX       = '1e-005-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.24218566+dvthp_lvt-0.00022329*ff_flag_lvt-0.00022329*ss_flag_lvt'
+LVTH0      = '-2.4856887e-009+dlvthp_lvt+5.13767e-11*ff_flag_lvt+5.13767e-11*ss_flag_lvt'
+WVTH0      = '-2.7463476e-008+dwvthp_lvt+2.23736e-09*ff_flag_lvt+2.23736e-09*ss_flag_lvt'
+PVTH0      = '3.6590497e-015+dpvthp_lvt-5.14795e-16*ff_flag_lvt-5.14795e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.017269303+dk2p_lvt'
+LK2        = '-5.5156485e-010+dlk2p_lvt'
+WK2        = '-1.942292e-010+dwk2p_lvt'
+PK2        = '-7.5503297e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00052375953+dcitp_lvt'
+LCIT       = '-2.3146946e-011+dlcitp_lvt'
+WCIT       = '-2.380705e-010+dwcitp_lvt'
+PCIT       = '2.319324e-016+dpcitp_lvt'
+VOFF       = '-0.060877121+dvoffp_lvt'
+LVOFF      = '-8.9224745e-009+dlvoffp_lvt'
+WVOFF      = '-2.8754236e-008+dwvoffp_lvt'
+PVOFF      = '3.1693892e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908056+deta0p_lvt'
+WETA0      = '1.9302929e-007+dweta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010395877+du0p_lvt+1.77633e-06*ff_flag_lvt+1.42106e-06*sf_flag_lvt-1.42106e-06*fs_flag_lvt'
+LU0        = '-3.9406988e-010+dlu0p_lvt-1.71256e-12*ff_flag_lvt-1.37005e-12*sf_flag_lvt+1.37005e-12*fs_flag_lvt'
+WU0        = '2.1145986e-009+dwu0p_lvt-1.77988e-11*ff_flag_lvt-1.4239e-11*sf_flag_lvt+1.4239e-11*fs_flag_lvt'
+PU0        = '-7.8935265e-017+dpu0p_lvt+1.71598e-17*ff_flag_lvt+1.37279e-17*sf_flag_lvt-1.37279e-17*fs_flag_lvt'
+UA         = '-2.5869874e-010+duap_lvt'
+LUA        = '-1.0988483e-016+dluap_lvt'
+WUA        = '1.2512776e-016+dwuap_lvt'
+PUA        = '4.2384805e-023+dpuap_lvt'
+UB         = '1.8394369e-018+dubp_lvt'
+LUB        = '-4.1626778e-028+dlubp_lvt'
+WUB        = '-1.1432372e-025+dwubp_lvt'
+PUB        = '-3.8291607e-032+dpubp_lvt'
+UC         = 5.6728158e-012      LUC        = 5.4126028e-018      WUC        = -1.6755957e-017
+PUC        = 2.1569919e-024      VSAT       = '95420+dvsatp_lvt'  A0         = '1.8687681+da0p_lvt'
+LA0        = '-1.3650505e-007+dla0p_lvt'
+WA0        = '1.5254322e-006+dwa0p_lvt'
+PA0        = '-4.0977698e-013+dpa0p_lvt'
+AGS        = '-0.014002595+dagsp_lvt'
+LAGS       = '1.6008134e-006+dlagsp_lvt'
+WAGS       = '-4.5989611e-007+dwagsp_lvt'
+PAGS       = '2.364626e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024608797        LKETA      = -1.7595535e-008
+WKETA      = 1.969543e-011       PKETA      = 2.4881768e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.1880819+dpclmp_lvt'
+LPCLM      = '-1.8132977e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.011019429+dpdiblc2p_lvt'
+LPDIBLC2   = '2.0924166e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.6178618e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-3.9838285e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0011426831        LTVOFF     = 9.8875092e-011
+WTVOFF     = -1.3154421e-010     PTVOFF     = 8.5799201e-018      KT1        = -0.30860044
+LKT1       = 3.7374386e-009      WKT1       = 2.9751321e-008      PKT1       = -6.2343759e-015
+KT1L       = 0                   KT2        = -0.061534653        LKT2       = -1.1506986e-009
+WKT2       = 2.5535238e-008      PKT2       = -4.1561133e-015     UTE        = '-1.523649+dutep_lvt'
+LUTE       = '1.2431969e-007+dlutep_lvt'
+WUTE       = '7.4702169e-008+dwutep_lvt'
+PUTE       = '-5.5597882e-014+dputep_lvt'
+UA1        = '1.0105665e-009+dua1p_lvt'
+LUA1       = '1.068491e-016+dlua1p_lvt'
+WUA1       = '4.0655021e-016+dwua1p_lvt'
+PUA1       = '-1.1113237e-022+dpua1p_lvt'
+UB1        = '-2.2150103e-018+dub1p_lvt'
+LUB1       = '1.2681996e-025+dlub1p_lvt'
+WUB1       = '-4.0681235e-025+dwub1p_lvt'
+PUB1       = '6.1646616e-032+dpub1p_lvt'
+UC1        = 5.7156411e-011      LUC1       = 1.227671e-017       WUC1       = -5.8308033e-017
+PUC1       = 4.6262929e-024      PRT        = 0                   AT         = '198771.73+datp_lvt'
+LAT        = '-0.03419829+dlatp_lvt'
+WAT        = '0.022818616+dwatp_lvt'
+PAT        = '-5.5769481e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.9 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_lvt'
+LMAX       = '2.399901e-007-dxlp_lvt'
+WMIN       = '1e-006-dxwp_lvt'   WMAX       = '1e-005-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25856533+dvthp_lvt'
+LVTH0      = '1.2831097e-009+dlvthp_lvt'
+WVTH0      = '-1.3596429e-008+dwvthp_lvt'
+PVTH0      = '4.6838072e-016+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.012847493+dk2p_lvt'
+LK2        = '4.6584946e-010+dlk2p_lvt'
+WK2        = '-2.5582468e-009+dwk2p_lvt'
+PK2        = '4.6843351e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00089759495+dcitp_lvt'
+LCIT       = '3.0389251e-010+dlcitp_lvt'
+WCIT       = '1.5758347e-009+dwcitp_lvt'
+PCIT       = '-1.8542906e-016+dpcitp_lvt'
+VOFF       = '-0.076341704+dvoffp_lvt'
+LVOFF      = '-5.3642287e-009+dlvoffp_lvt'
+WVOFF      = '-2.8917229e-008+dwvoffp_lvt'
+PVOFF      = '3.2068922e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.2908066+deta0p_lvt'
+LETA0      = '-2.3078942e-013+dleta0p_lvt'
+WETA0      = '1.9302674e-007+dweta0p_lvt'
+PETA0      = '5.8675625e-019+dpeta0p_lvt'
+ETAB       = -0.12870267         WETAB      = -9.99328e-009       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0095315421+du0p_lvt-5.66666e-06*ff_flag_lvt+8.48339e-06*ss_flag_lvt-4.53333e-06*sf_flag_lvt+4.53333e-06*fs_flag_lvt'
+LU0        = '-1.9519503e-010+dlu0p_lvt+5e-20*ff_flag_lvt-1.95194e-12*ss_flag_lvt+2.4e-19*sf_flag_lvt-2.4e-19*fs_flag_lvt'
+WU0        = '1.9415438e-009+dwu0p_lvt+5.678e-11*ff_flag_lvt-8.50036e-11*ss_flag_lvt+4.5424e-11*sf_flag_lvt-4.5424e-11*fs_flag_lvt'
+PU0        = '-3.9117084e-017+dpu0p_lvt-1e-24*ff_flag_lvt+1.95585e-17*ss_flag_lvt+3.2e-24*sf_flag_lvt-3.2e-24*fs_flag_lvt'
+UA         = '-6.2902859e-010+duap_lvt'
+LUA        = '-2.4675637e-017+dluap_lvt'
+WUA        = '3.9281125e-016+dwuap_lvt'
+PUA        = '-1.9206488e-023+dpuap_lvt'
+UB         = '1.9421977e-018+dubp_lvt'
+LUB        = '-2.4060497e-026+dlubp_lvt'
+WUB        = '-4.483143e-025+dwubp_lvt'
+PUB        = '3.8556285e-032+dpubp_lvt'
+UC         = 2.0476309e-011      LUC        = 2.0064671e-018      WUC        = -1.7207848e-017
+PUC        = 2.2609674e-024      VSAT       = '95420+dvsatp_lvt'  A0         = '5.3771092+da0p_lvt'
+LA0        = '-9.4373925e-007+dla0p_lvt'
+WA0        = '-1.9768385e-006+dwa0p_lvt'
+PA0        = '3.9606047e-013+dpa0p_lvt'
+AGS        = '9.1959311+dagsp_lvt'
+LAGS       = '-5.1830021e-007+dlagsp_lvt'
+WAGS       = '1.247831e-006+dwagsp_lvt'
+PAGS       = '-1.5646833e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10081881         LKETA      = -6.0372674e-011
+WKETA      = 3.4042853e-009      PKETA      = 1.7094166e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.5497074+dpclmp_lvt'
+LPCLM      = '-3.4446181e-008+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0053026122+dpdiblc2p_lvt'
+LPDIBLC2   = '3.4077988e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.9762013e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-4.8083317e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017946473        LTVOFF     = -5.1135356e-011
+WTVOFF     = -5.6602631e-010     PTVOFF     = 1.0854991e-016      KT1        = -0.25661569
+LKT1       = -8.2237324e-009     WKT1       = -2.5475566e-008     PKT1       = 6.4727785e-015
+KT1L       = 0                   KT2        = -0.066243771        LKT2       = -6.7177655e-011
+WKT2       = 1.1147085e-008      PKT2       = -8.4554314e-016     UTE        = '-0.97086937+dutep_lvt'
+LUTE       = '-2.8693669e-009+dlutep_lvt'
+WUTE       = '-2.918889e-007+dwutep_lvt'
+PUTE       = '2.8751056e-014+dputep_lvt'
+UA1        = '1.3742656e-009+dua1p_lvt'
+LUA1       = '2.3165574e-017+dlua1p_lvt'
+WUA1       = '1.292132e-016+dwua1p_lvt'
+PUA1       = '-4.7319897e-023+dpua1p_lvt'
+UB1        = '-1.8019021e-018+dub1p_lvt'
+LUB1       = '3.1767874e-026+dlub1p_lvt'
+WUB1       = '-8.8236177e-026+dwub1p_lvt'
+PUB1       = '-1.1654575e-032+dpub1p_lvt'
+UC1        = 6.1440336e-011      LUC1       = 1.1291022e-017      WUC1       = -1.4519504e-017
+PUC1       = -5.4490097e-024     PRT        = 0                   AT         = '93662.863+datp_lvt'
+LAT        = '-0.010013792+dlatp_lvt'
+WAT        = '-0.0024820485+dwatp_lvt'
+PAT        = '2.4448177e-010+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.10 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_lvt'
+WMIN       = '1e-006-dxwp_lvt'   WMAX       = '1e-005-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22989511+dvthp_lvt-0.0126208*ff_flag_lvt+0.0275506*ss_flag_lvt-0.00555994*sf_flag_lvt+0.00555994*fs_flag_lvt'
+LVTH0      = '-1.5409072e-009+dlvthp_lvt+1.24315e-09*ff_flag_lvt-2.71373e-09*ss_flag_lvt+5.47654e-10*sf_flag_lvt-5.47654e-10*fs_flag_lvt'
+WVTH0      = '-9.5700168e-009+dwvthp_lvt-9.64051e-09*ff_flag_lvt-3.85616e-09*ss_flag_lvt-1.23398e-08*sf_flag_lvt+1.23398e-08*fs_flag_lvt'
+PVTH0      = '7.1779158e-017+dpvthp_lvt+9.49589e-16*ff_flag_lvt+3.79834e-16*ss_flag_lvt+1.21547e-15*sf_flag_lvt-1.21547e-15*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0058141688+dk2p_lvt'
+LK2        = '2.3040232e-009+dlk2p_lvt'
+WK2        = '5.5823676e-010+dwk2p_lvt'
+PK2        = '1.6145988e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0023914926+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.5104142e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '6.1284302e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-9.0574373e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.081864514+dvoffp_lvt-0.0481515*ff_flag_lvt+0.0567087*ss_flag_lvt-0.0356506*sf_flag_lvt+0.0354005*fs_flag_lvt'
+LVOFF      = '-4.8202319e-009+dlvoffp_lvt+4.7429e-09*ff_flag_lvt-5.58579e-09*ss_flag_lvt+3.51158e-09*sf_flag_lvt-3.48694e-09*fs_flag_lvt'
+WVOFF      = '1.4496007e-008+dwvoffp_lvt+2.31371e-08*ff_flag_lvt-5.78429e-08*ss_flag_lvt+1.69672e-08*sf_flag_lvt-1.44607e-08*fs_flag_lvt'
+PVOFF      = '-1.0693116e-015+dpvoffp_lvt-2.27901e-15*ff_flag_lvt+5.69751e-15*ss_flag_lvt-1.67127e-15*sf_flag_lvt+1.42438e-15*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.0769699*ff_flag_lvt-0.756116*ss_flag_lvt+0.061576*sf_flag_lvt-0.061576*fs_flag_lvt'
+ETA0       = '-0.13126921+deta0p_lvt+0.0945146*ff_flag_lvt-0.0945146*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LETA0      = '4.1574237e-008+dleta0p_lvt-9.30966e-09*ff_flag_lvt+9.30966e-09*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WETA0      = '5.1059346e-007+dweta0p_lvt-9.64048e-08*ff_flag_lvt+9.64048e-08*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PETA0      = '-3.1279736e-014+dpeta0p_lvt+9.49585e-15*ff_flag_lvt-9.49585e-15*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+ETAB       = -0.12742346         LETAB      = -1.2600153e-010     WETAB      = -2.2810897e-008
+PETAB      = 1.2625353e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.005376774+du0p_lvt+0.000206454*ff_flag_lvt-0.00127681*ss_flag_lvt+8.95511e-05*sf_flag_lvt-1.39395e-05*fs_flag_lvt'
+LU0        = '2.1404963e-010+dlu0p_lvt-2.08938e-11*ff_flag_lvt+1.24649e-10*ss_flag_lvt-9.26729e-12*sf_flag_lvt+1.81956e-12*fs_flag_lvt'
+WU0        = '1.1009666e-009+dwu0p_lvt-3.67401e-10*ff_flag_lvt+8.848e-10*ss_flag_lvt-2.16797e-10*sf_flag_lvt+1.39673e-10*fs_flag_lvt'
+PU0        = '4.3679771e-017+dpu0p_lvt+4.17817e-17*ff_flag_lvt-7.59665e-17*ss_flag_lvt+2.58287e-17*sf_flag_lvt-1.8232e-17*fs_flag_lvt'
+UA         = '-1.3371304e-009+duap_lvt'
+LUA        = '4.5072393e-017+dluap_lvt'
+WUA        = '-9.5951684e-019+dwuap_lvt'
+PUA        = '1.9579932e-023+dpuap_lvt'
+UB         = '1.6937477e-018+dubp_lvt'
+LUB        = '4.118249e-028+dlubp_lvt'
+WUB        = '2.3165923e-025+dwubp_lvt'
+PUB        = '-2.8421107e-032+dpubp_lvt'
+UC         = 3.7123107e-011      LUC        = 3.6675747e-019      WUC        = 9.3708533e-018
+PUC        = -3.5703465e-025
+VSAT       = '88131.837+dvsatp_lvt-192.425*ff_flag_lvt+5478.45*ss_flag_lvt-153.94*sf_flag_lvt+153.94*fs_flag_lvt'
+LVSAT      = '0.00071788404+dlvsatp_lvt+1.89538e-05*ff_flag_lvt-0.000539625*ss_flag_lvt+1.5163e-05*sf_flag_lvt-1.5163e-05*fs_flag_lvt'
+WVSAT      = '0.02063004+dwvsatp_lvt+0.0019281*ff_flag_lvt-0.00385619*ss_flag_lvt+0.00154248*sf_flag_lvt-0.00154248*fs_flag_lvt'
+PVSAT      = '-2.0320589e-009+dpvsatp_lvt-1.89917e-10*ff_flag_lvt+3.79834e-10*ss_flag_lvt-1.51934e-10*sf_flag_lvt+1.51934e-10*fs_flag_lvt'
+A0         = '-14.929677+da0p_lvt'
+LA0        = '1.0564791e-006+dla0p_lvt'
+WA0        = '7.4425951e-006+dwa0p_lvt'
+PA0        = '-5.3175373e-013+dpa0p_lvt'
+AGS        = '-4.6385162+dagsp_lvt'
+LAGS       = '8.4439285e-007+dlagsp_lvt'
+WAGS       = '1.8052297e-006+dwagsp_lvt'
+PAGS       = '-2.1137211e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.26812734         LKETA      = 1.6419518e-008
+WKETA      = 2.7585962e-008      PKETA      = -6.7247856e-016     DWG        = 0
+DWB        = 0                   PCLM       = '1.784615+dpclmp_lvt'
+LPCLM      = '-5.758458e-008+dlpclmp_lvt'
+WPCLM      = '9.6402055e-008+dwpclmp_lvt'
+PPCLM      = '-9.4956024e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.052858802+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.2764859e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.9820308e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '1.0605269e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0015192227        LTVOFF     = -2.4006025e-011
+WTVOFF     = 8.3292153e-010      PTVOFF     = -2.9246455e-017     KT1        = -0.29861114
+LKT1       = -4.0871805e-009     WKT1       = 7.0768803e-008      PKT1       = -3.0072918e-015
+KT1L       = 0                   KT2        = -0.062670217        LKT2       = -4.1917268e-010
+WKT2       = -7.58466e-009       PKT2       = 9.995337e-016       UTE        = '-1+dutep_lvt'
+UA1        = '2.2956478e-009+dua1p_lvt'
+LUA1       = '-6.7590577e-017+dlua1p_lvt'
+WUA1       = '-1.1115199e-015+dwua1p_lvt'
+PUA1       = '7.4892317e-023+dpua1p_lvt'
+UB1        = '-1.2411257e-018+dub1p_lvt'
+LUB1       = '-2.3468592e-026+dlub1p_lvt'
+WUB1       = '-5.8862958e-025+dwub1p_lvt'
+PUB1       = '3.7634175e-032+dpub1p_lvt'
+UC1        = 2.35025e-010        LUC1       = -5.8070676e-018     WUC1       = -1.4850348e-016
+PUC1       = 7.7484116e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt-7.58152e-09*ff_flag_lvt+7.44773e-08*ss_flag_lvt-6.06521e-09*sf_flag_lvt+6.06521e-09*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt-7.71239e-07*ff_flag_lvt+7.71239e-07*ss_flag_lvt-6.16991e-07*sf_flag_lvt+6.16991e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+7.59668e-14*ff_flag_lvt-7.59668e-14*ss_flag_lvt+6.07734e-14*sf_flag_lvt-6.07734e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.11 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-dxlp_lvt'
+LMAX       = 2.001e-05           WMIN       = '6e-007-dxwp_lvt'   WMAX       = '1e-006-dxwp_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_lvt'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23966304+dvthp_lvt'
+WVTH0      = '-2.4987547e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.0218635+dk2p_lvt'
+WK2        = '1.94463e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.069351363+dvoffp_lvt'
+WVOFF      = '8.448864e-013+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0115615+du0p_lvt'
+WU0        = '4.2687e-010+dwu0p_lvt'
+UA         = '-1.213e-013+duap_lvt'
+WUA        = '3.045006e-018+dwuap_lvt'
+UB         = '1.6050812e-018+dubp_lvt'
+WUB        = '-9.5530344e-026+dwubp_lvt'
+UC         = -6.1535e-012        WUC        = 6.27657e-018        VSAT       = '95420+dvsatp_lvt'
+A0         = '4.90365+da0p_lvt'  WA0        = '-9.21723e-007+dwa0p_lvt'
+AGS        = '0.880215+dagsp_lvt'
+WAGS       = '1.37547e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0353765          WKETA      = 9.21723e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.003775+dpdiblc2p_lvt'
+WPDIBLC2   = '-7.905e-010+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00154465          LTVOFF     = 0
+WTVOFF     = -2.57703e-010       PTVOFF     = 0                   KT1        = -0.25164405
+WKT1       = 6.872607e-009       KT1L       = 0                   KT2        = -0.0534665
+WKT2       = 1.079823e-008       UTE        = '-1.50745+dutep_lvt'
+WUTE       = '-3.3201e-008+dwutep_lvt'
+UA1        = '1.0318411e-009+dua1p_lvt'
+WUA1       = '-6.4085573e-017+dwua1p_lvt'
+UB1        = '-1.6581697e-018+dub1p_lvt'
+WUB1       = '1.3831758e-025+dwub1p_lvt'
+UC1        = 9.3902e-011         WUC1       = -6.678144e-017      PRT        = 0
+AT         = '208600+datp_lvt'   WAT        = '-0.018972+dwatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.12 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-dxlp_lvt'
+LMAX       = '9.999994e-006-dxlp_lvt'
+WMIN       = '6e-007-dxwp_lvt'   WMAX       = '1e-006-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23700857+dvthp_lvt-0.000409743*ff_flag_lvt-0.000409743*ss_flag_lvt'
+LVTH0      = '-2.6449461e-008+dlvthp_lvt+4.08272e-09*ff_flag_lvt+4.08272e-09*ss_flag_lvt'
+WVTH0      = '-2.38126e-009+dwvthp_lvt+2.5404e-10*ff_flag_lvt+2.5404e-10*ss_flag_lvt'
+PVTH0      = '-1.1707287e-015+dpvthp_lvt-2.53128e-15*ff_flag_lvt-2.53128e-15*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.022769641+dk2p_lvt'
+LK2        = '-9.0288794e-009+dlk2p_lvt'
+WK2        = '1.8223689e-009+dwk2p_lvt'
+PK2        = '1.2182224e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.0544859e-005+dcitp_lvt'
+LCIT       = '8.9133997e-010+dlcitp_lvt'
+WCIT       = '4.7297995e-011+dwcitp_lvt'
+PCIT       = '-4.7128195e-016+dpcitp_lvt'
+VOFF       = '-0.067296285+dvoffp_lvt'
+LVOFF      = '-2.0477e-008+dlvoffp_lvt'
+WVOFF      = '7.1809804e-010+dwvoffp_lvt'
+PVOFF      = '-7.1467822e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01130746+du0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LU0        = '2.5312835e-009+dlu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WU0        = '6.8599116e-010+dwu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PU0        = '-2.5819091e-015+dpu0p_lvt+0.0*ff_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+UA         = '-4.4552523e-011+duap_lvt'
+LUA        = '4.4271715e-016+dluap_lvt'
+WUA        = '7.1284647e-017+dwuap_lvt'
+PUA        = '-6.7994661e-022+dpuap_lvt'
+UB         = '1.6089615e-018+dubp_lvt'
+LUB        = '-3.8663777e-026+dlubp_lvt'
+WUB        = '-1.1878006e-025+dwubp_lvt'
+PUB        = '2.3166252e-031+dpubp_lvt'
+UC         = -6.4772287e-012     LUC        = 3.2256653e-018      WUC        = 6.9287763e-018
+PUC        = -6.4986484e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '5.2249899+da0p_lvt'
+LA0        = '-3.2018628e-006+dla0p_lvt'
+WA0        = '-1.1190277e-006+dwa0p_lvt'
+PA0        = '1.9659635e-012+dpa0p_lvt'
+AGS        = '0.82899665+dagsp_lvt'
+LAGS       = '5.1034474e-007+dlagsp_lvt'
+WAGS       = '6.7431863e-009+dwagsp_lvt'
+PAGS       = '6.9863423e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.03395472         LKETA      = -1.4166755e-008
+WKETA      = 9.2934421e-009      PKETA      = -7.5938504e-016     DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '0.0016673703+dpdiblc2p_lvt'
+LPDIBLC2   = '2.1000633e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '-1.0445404e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '2.5312835e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0014756676        LTVOFF     = 6.8734779e-010
+WTVOFF     = -1.6909373e-010     PTVOFF     = -8.8291167e-016     KT1        = -0.25379916
+LKT1       = 2.1473739e-008      WKT1       = 1.3112455e-008      PKT1       = -6.2174464e-014
+KT1L       = 0                   KT2        = -0.055487093        LKT2       = 2.013339e-008
+WKT2       = 1.2754341e-008      PKT2       = -1.9490883e-014     UTE        = '-1.5470531+dutep_lvt'
+LUTE       = '3.9460911e-007+dlutep_lvt'
+WUTE       = '-1.0506729e-008+dwutep_lvt'
+PUTE       = '-2.2612799e-013+dputep_lvt'
+UA1        = '9.4498436e-010+dua1p_lvt'
+LUA1       = '8.6544905e-016+dlua1p_lvt'
+WUA1       = '-2.3344232e-017+dwua1p_lvt'
+PUA1       = '-4.059508e-022+dpua1p_lvt'
+UB1        = '-1.5086827e-018+dub1p_lvt'
+LUB1       = '-1.4895027e-024+dlub1p_lvt'
+WUB1       = '8.3856899e-026+dwub1p_lvt'
+PUB1       = '5.4265167e-031+dpub1p_lvt'
+UC1        = 1.0049273e-010      LUC1       = -6.5670715e-017     WUC1       = -7.2302076e-017
+PUC1       = 5.5008164e-023      PRT        = 0                   AT         = '211331.62+datp_lvt'
+LAT        = '-0.027218102+dlatp_lvt'
+WAT        = '-0.020665602+dwatp_lvt'
+PAT        = '1.6875223e-008+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.13 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-dxlp_lvt'
+LMAX       = '9.999943e-007-dxlp_lvt'
+WMIN       = '6e-007-dxwp_lvt'   WMAX       = '1e-006-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.26707757+dvthp_lvt+0.00502402*ff_flag_lvt+0.00502402*ss_flag_lvt'
+LVTH0      = '2.5400675e-009+dlvthp_lvt-1.15598e-09*ff_flag_lvt-1.15598e-09*ss_flag_lvt'
+WVTH0      = '-2.0737266e-009+dwvthp_lvt-3.11489e-09*ff_flag_lvt-3.11489e-09*ss_flag_lvt'
+PVTH0      = '-1.4672217e-015+dpvthp_lvt+7.16705e-16*ff_flag_lvt+7.16705e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.013134035+dk2p_lvt'
+LK2        = '2.6080868e-010+dlk2p_lvt'
+WK2        = '4.0237449e-009+dwk2p_lvt'
+PK2        = '-9.041243e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0005295005+dcitp_lvt'
+LCIT       = '3.9101483e-010+dlcitp_lvt'
+WCIT       = '-2.4392629e-010+dwcitp_lvt'
+PCIT       = '-1.9051261e-016+dpcitp_lvt'
+VOFF       = '-0.083898674+dvoffp_lvt'
+LVOFF      = '-4.4706369e-009+dlvoffp_lvt'
+WVOFF      = '-5.2722525e-009+dwvoffp_lvt'
+PVOFF      = '-1.3714852e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.728019+deta0p_lvt'
+WETA0      = '-2.5292838e-007+dweta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.014500725+du0p_lvt-3.99673e-05*ff_flag_lvt-3.19739e-05*sf_flag_lvt+3.19739e-05*fs_flag_lvt'
+LU0        = '-5.473439e-010+dlu0p_lvt+3.85325e-11*ff_flag_lvt+3.0826e-11*sf_flag_lvt-3.0826e-11*fs_flag_lvt'
+WU0        = '-2.0723465e-009+dwu0p_lvt+2.47798e-11*ff_flag_lvt+1.98238e-11*sf_flag_lvt-1.98238e-11*fs_flag_lvt'
+PU0        = '7.7404237e-017+dpu0p_lvt-2.38902e-17*ff_flag_lvt-1.91121e-17*sf_flag_lvt+1.91121e-17*fs_flag_lvt'
+UA         = '4.9072443e-010+duap_lvt'
+LUA        = '-7.3343357e-017+dluap_lvt'
+WUA        = '-6.3928388e-016+dwuap_lvt'
+PUA        = '5.1125021e-024+dpuap_lvt'
+UB         = '1.6403507e-018+dubp_lvt'
+LUB        = '-6.8926099e-026+dlubp_lvt'
+WUB        = '8.8744158e-026+dwubp_lvt'
+PUB        = '3.1588421e-032+dpubp_lvt'
+UC         = -1.2857777e-011     LUC        = 9.3771515e-018      WUC        = 2.1452469e-018
+PUC        = -1.8868477e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '2.0457921+da0p_lvt'
+LA0        = '-1.367982e-007+dla0p_lvt'
+WA0        = '1.3448676e-006+dwa0p_lvt'
+PA0        = '-4.0947797e-013+dpa0p_lvt'
+AGS        = '-1.0041691+dagsp_lvt'
+LAGS       = '2.2776998e-006+dlagsp_lvt'
+WAGS       = '5.5007369e-007+dwagsp_lvt'
+PAGS       = '-4.5396152e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.028273774        LKETA      = -1.9643756e-008
+WKETA      = 3.757972e-009       PKETA      = 4.5773617e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.0909063+dpclmp_lvt'
+LPCLM      = '-8.764272e-008+dlpclmp_lvt'
+WPCLM      = '9.9119165e-008+dwpclmp_lvt'
+PPCLM      = '-9.5560787e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.032317748+dpdiblc2p_lvt'
+LPDIBLC2   = '-8.5493962e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-5.5456679e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '6.8708206e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0024398906        LTVOFF     = -2.4225959e-010
+WTVOFF     = -1.4546958e-009     PTVOFF     = 3.565373e-016       KT1        = -0.20936915
+LKT1       = -2.1361236e-008     WKT1       = -7.1464598e-008     PKT1       = 1.9366273e-014
+KT1L       = 0                   KT2        = -0.027274605        LKT2       = -7.0662699e-009
+WKT2       = -9.4100116e-009     PKT2       = 1.8777695e-015      UTE        = '-1.1635172+dutep_lvt'
+LUTE       = '2.4842178e-008+dlutep_lvt'
+WUTE       = '-2.926322e-007+dwutep_lvt'
+PUTE       = '4.5869178e-014+dputep_lvt'
+UA1        = '1.8881319e-009+dua1p_lvt'
+LUA1       = '-4.3839481e-017+dlua1p_lvt'
+WUA1       = '-4.8856649e-016+dwua1p_lvt'
+PUA1       = '4.2569984e-023+dpua1p_lvt'
+UB1        = '-3.3980433e-018+dub1p_lvt'
+LUB1       = '3.3202984e-025+dlub1p_lvt'
+WUB1       = '7.9988131e-025+dwub1p_lvt'
+PUB1       = '-1.4766746e-031+dpub1p_lvt'
+UC1        = 1.8904547e-011      LUC1       = 1.2988455e-017      WUC1       = -1.9291132e-017
+PUC1       = 3.9003135e-024      PRT        = 0                   AT         = '211542.06+datp_lvt'
+LAT        = '-0.027420989+dlatp_lvt'
+WAT        = '0.0097928748+dwatp_lvt'
+PAT        = '-1.2489795e-008+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.14 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_lvt'
+LMAX       = '2.399901e-007-dxlp_lvt'
+WMIN       = '6e-007-dxwp_lvt'   WMAX       = '1e-006-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.25615176+dvthp_lvt'
+LVTH0      = '2.6146736e-011+dlvthp_lvt'
+WVTH0      = '-1.6058274e-008+dwvthp_lvt'
+PVTH0      = '1.7504829e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.011836098+dk2p_lvt'
+LK2        = '5.5945104e-010+dlk2p_lvt'
+WK2        = '-1.5266232e-009+dwk2p_lvt'
+PK2        = '3.729599e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0022505953+dcitp_lvt'
+LCIT       = '-4.9918717e-012+dlcitp_lvt'
+WCIT       = '-1.6353193e-009+dwcitp_lvt'
+PCIT       = '1.2963301e-016+dpcitp_lvt'
+VOFF       = '-0.082218583+dvoffp_lvt'
+LVOFF      = '-4.857209e-009+dlvoffp_lvt'
+WVOFF      = '-2.2922812e-008+dwvoffp_lvt'
+PVOFF      = '2.6897322e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.72801286+deta0p_lvt'
+LETA0      = '1.4122934e-012+dleta0p_lvt'
+WETA0      = '-2.5292365e-007+dweta0p_lvt'
+PETA0      = '-1.0891883e-018+dpeta0p_lvt'
+ETAB       = -0.139275           WETAB      = 7.905e-010          UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013299349+du0p_lvt+0.0001275*ff_flag_lvt-0.000190876*ss_flag_lvt+0.000102*sf_flag_lvt-0.000102*fs_flag_lvt'
+LU0        = '-2.7091922e-010+dlu0p_lvt+4.6e-17*ff_flag_lvt+4.39187e-11*ss_flag_lvt-2.3e-17*sf_flag_lvt+2.3e-17*fs_flag_lvt'
+WU0        = '-1.9016192e-009+dwu0p_lvt-7.90503e-11*ff_flag_lvt+1.18343e-10*ss_flag_lvt-6.32397e-11*sf_flag_lvt+6.32397e-11*fs_flag_lvt'
+PU0        = '3.8121589e-017+dpu0p_lvt+5e-24*ff_flag_lvt-2.72296e-17*ss_flag_lvt-3.6e-23*sf_flag_lvt+3.6e-23*fs_flag_lvt'
+UA         = '4.0037736e-010+duap_lvt'
+LUA        = '-5.25554e-017+dluap_lvt'
+WUA        = '-6.5718282e-016+dwuap_lvt'
+PUA        = '9.2308705e-024+dpuap_lvt'
+UB         = '1.3125234e-018+dubp_lvt'
+LUB        = '6.503691e-027+dlubp_lvt'
+WUB        = '1.9395346e-025+dwubp_lvt'
+PUB        = '7.3808134e-033+dpubp_lvt'
+UC         = 3.741207e-012       LUC        = 5.5578914e-018      WUC        = -1.3804404e-019
+PUC        = -1.3614853e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '4.8804857+da0p_lvt'
+LA0        = '-7.8903284e-007+dla0p_lvt'
+WA0        = '-1.4702825e-006+dwa0p_lvt'
+PA0        = '2.3825993e-013+dpa0p_lvt'
+AGS        = '13.322597+dagsp_lvt'
+LAGS       = '-1.0187458e-006+dlagsp_lvt'
+WAGS       = '-2.9613684e-006+dwagsp_lvt'
+PAGS       = '3.5398618e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.12042563         LKETA      = 1.5594647e-009
+WKETA      = 2.3403238e-008      PKETA      = 5.7182383e-017      DWG        = 0
+DWB        = 0                   PCLM       = '1.8016958+dpclmp_lvt'
+LPCLM      = '-2.1098286e-008+dlpclmp_lvt'
+WPCLM      = '-2.5702814e-007+dwpclmp_lvt'
+PPCLM      = '-1.3614853e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0045558737+dpdiblc2p_lvt'
+LPDIBLC2   = '-2.1616665e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '2.0523686e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '8.7252298e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00051555308       LTVOFF     = 2.0051122e-010
+WTVOFF     = 7.3864983e-010      PTVOFF     = -1.481296e-016      KT1        = -0.30869919
+LKT1       = 1.4936139e-009      WKT1       = 2.7649606e-008      PKT1       = -3.4389148e-015
+KT1L       = 0                   KT2        = -0.047392572        LKT2       = -2.4373269e-009
+WKT2       = -8.0811386e-009     PKT2       = 1.5720091e-015      UTE        = '-1.0971312+dutep_lvt'
+LUTE       = '9.5674269e-009+dlutep_lvt'
+WUTE       = '-1.6310179e-007+dwutep_lvt'
+PUTE       = '1.6065527e-014+dputep_lvt'
+UA1        = '2.0289308e-009+dua1p_lvt'
+LUA1       = '-7.6235902e-017+dlua1p_lvt'
+WUA1       = '-5.385453e-016+dwua1p_lvt'
+PUA1       = '5.4069609e-023+dpua1p_lvt'
+UB1        = '-2.1814336e-018+dub1p_lvt'
+LUB1       = '5.2100107e-026+dlub1p_lvt'
+WUB1       = '2.9888601e-025+dwub1p_lvt'
+PUB1       = '-3.2393453e-032+dpub1p_lvt'
+UC1        = -1.051804e-012      LUC1       = 1.7580211e-017      WUC1       = 4.9222478e-017
+PUC1       = -1.1863983e-023     PRT        = 0                   AT         = '167495.43+datp_lvt'
+LAT        = '-0.017286299+dlatp_lvt'
+WAT        = '-0.077791263+dwatp_lvt'
+PAT        = '7.6624394e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.15 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_lvt'
+WMIN       = '6e-007-dxwp_lvt'   WMAX       = '1e-006-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.25450344+dvthp_lvt+0.00687633*ff_flag_lvt+0.0106116*ss_flag_lvt+0.0055011*sf_flag_lvt-0.0055011*fs_flag_lvt'
+LVTH0      = '-1.3621188e-010+dlvthp_lvt-6.77323e-10*ff_flag_lvt-1.04524e-09*ss_flag_lvt-5.41853e-10*sf_flag_lvt+5.41853e-10*fs_flag_lvt'
+WVTH0      = '1.5530487e-008+dwvthp_lvt-2.95276e-08*ff_flag_lvt+1.34216e-08*ss_flag_lvt-2.36221e-08*sf_flag_lvt+2.36221e-08*fs_flag_lvt'
+PVTH0      = '-1.3610101e-015+dpvthp_lvt+2.90846e-15*ff_flag_lvt-1.32203e-15*ss_flag_lvt+2.32676e-15*sf_flag_lvt-2.32676e-15*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.007175021+dk2p_lvt'
+LK2        = '2.4320462e-009+dlk2p_lvt'
+WK2        = '1.9463059e-009+dwk2p_lvt'
+PK2        = '3.0876379e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0019620846+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.099571e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '1.7484688e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-4.8668363e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.078139928+dvoffp_lvt-0.00704616*ff_flag_lvt-0.0210535*ss_flag_lvt-0.00217331*sf_flag_lvt+0.0120124*fs_flag_lvt'
+LVOFF      = '-5.2589566e-009+dlvoffp_lvt+6.94039e-10*ff_flag_lvt+2.07377e-09*ss_flag_lvt+2.14071e-10*sf_flag_lvt-1.18321e-09*fs_flag_lvt'
+WVOFF      = '1.0696929e-008+dwvoffp_lvt-1.87903e-08*ff_flag_lvt+2.14746e-08*ss_flag_lvt-1.71796e-08*sf_flag_lvt+9.39513e-09*fs_flag_lvt'
+PVOFF      = '-6.2181242e-016+dpvoffp_lvt+1.85084e-15*ff_flag_lvt-2.11524e-15*ss_flag_lvt+1.6922e-15*sf_flag_lvt-9.25416e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt+0.110365*ff_flag_lvt+0.0*ss_flag_lvt+0.0882879*sf_flag_lvt+0.70122*fs_flag_lvt'
+ETA0       = '0.90417384+deta0p_lvt-0.00394754*ff_flag_lvt-0.0263169*ss_flag_lvt+0.0*sf_flag_lvt-0.0184218*fs_flag_lvt'
+LETA0      = '-1.7350444e-008+dleta0p_lvt+3.88831e-10*ff_flag_lvt+2.59221e-09*ss_flag_lvt+0.0*sf_flag_lvt+1.81455e-09*fs_flag_lvt'
+WETA0      = '-5.4555845e-007+dweta0p_lvt+4.02649e-09*ff_flag_lvt+2.68433e-08*ss_flag_lvt+0.0*sf_flag_lvt+1.87903e-08*fs_flag_lvt'
+PETA0      = '2.8823439e-014+dpeta0p_lvt-3.96608e-16*ff_flag_lvt-2.64405e-15*ss_flag_lvt+0.0*sf_flag_lvt-1.85084e-15*fs_flag_lvt'
+ETAB       = -0.12919863         LETAB      = -9.9252291e-010     WETAB      = -2.1000232e-008
+PETAB      = 2.1463871e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0076226273+du0p_lvt-0.000313096*ff_flag_lvt+0.000193026*ss_flag_lvt-0.000250477*sf_flag_lvt+0.000234687*fs_flag_lvt'
+LU0        = '2.8823786e-010+dlu0p_lvt+4.33987e-11*ff_flag_lvt+6.10414e-12*ss_flag_lvt+3.47189e-11*sf_flag_lvt-3.31636e-11*fs_flag_lvt'
+WU0        = '-1.1898039e-009+dwu0p_lvt+1.6254e-10*ff_flag_lvt-6.14436e-10*ss_flag_lvt+1.30031e-10*sf_flag_lvt-1.13925e-10*fs_flag_lvt'
+PU0        = '-3.199222e-017+dpu0p_lvt-2.37964e-17*ff_flag_lvt+4.49488e-17*ss_flag_lvt-1.90372e-17*sf_flag_lvt+1.74507e-17*fs_flag_lvt'
+UA         = '-7.9459861e-010+duap_lvt'
+LUA        = '6.5149733e-017+dluap_lvt'
+WUA        = '-5.5434195e-016+dwuap_lvt'
+PUA        = '-8.9895493e-025+dpuap_lvt'
+UB         = '1.6575544e-018+dubp_lvt'
+LUB        = '-2.7481865e-026+dlubp_lvt'
+WUB        = '2.6857637e-025+dwubp_lvt'
+PUB        = '3.0456064e-035+dpubp_lvt'
+UC         = 7.2023206e-011      LUC        = -1.1678855e-018     WUC        = -2.6227247e-017
+PUC        = 1.2083012e-024
+VSAT       = '114146.92+dvsatp_lvt-2249.67*ff_flag_lvt+17488*ss_flag_lvt-1799.74*sf_flag_lvt+1799.74*fs_flag_lvt'
+LVSAT      = '-0.0018446019+dlvsatp_lvt+0.000221592*ff_flag_lvt-0.00172256*ss_flag_lvt+0.000177274*sf_flag_lvt-0.000177274*fs_flag_lvt'
+WVSAT      = '-0.0059053474+dwvsatp_lvt+0.00402649*ff_flag_lvt-0.016106*ss_flag_lvt+0.00322119*sf_flag_lvt-0.00322119*fs_flag_lvt'
+PVSAT      = '5.8167672e-010+dpvsatp_lvt-3.96609e-10*ff_flag_lvt+1.58643e-09*ss_flag_lvt-3.17287e-10*sf_flag_lvt+3.17287e-10*fs_flag_lvt'
+A0         = '-10.141985+da0p_lvt'
+LA0        = '6.9068048e-007+dla0p_lvt'
+WA0        = '2.5591493e-006+dwa0p_lvt'
+PA0        = '-1.5863911e-013+dpa0p_lvt'
+AGS        = '-8.9308661+dagsp_lvt'
+LAGS       = '1.1732203e-006+dlagsp_lvt'
+WAGS       = '6.1834266e-006+dwagsp_lvt'
+PAGS       = '-5.4677612e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.32533612         LKETA      = 2.1743148e-008
+WKETA      = 8.5938917e-008      PKETA      = -6.102582e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.3982077+dpclmp_lvt'
+LPCLM      = '-7.9854705e-008+dlpclmp_lvt'
+WPCLM      = '-5.2946244e-007+dwpclmp_lvt'
+PPCLM      = '1.3219926e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.050735071+dpdiblc2p_lvt'
+LPDIBLC2   = '3.2844916e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '6.5845443e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-3.5916701e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0037991805        LTVOFF     = -1.2292608e-010
+WTVOFF     = -1.4926354e-009     PTVOFF     = 7.1651996e-017
+KT1        = '-0.26285479-0.0263169*ff_flag_lvt-0.0210535*sf_flag_lvt+0.0210535*fs_flag_lvt'
+LKT1       = '-3.0220599e-009+2.59221e-09*ff_flag_lvt+2.07377e-09*sf_flag_lvt-2.07377e-09*fs_flag_lvt'
+WKT1       = '3.4297323e-008+2.68433e-08*ff_flag_lvt+2.14746e-08*sf_flag_lvt-2.14746e-08*fs_flag_lvt'
+PKT1       = '-4.0937149e-015-2.64405e-15*ff_flag_lvt-2.11524e-15*sf_flag_lvt+2.11524e-15*fs_flag_lvt'
+KT1L       = 0                   KT2        = -0.098812272        LKT2       = 2.6275136e-009
+WKT2       = 2.9280236e-008      PKT2       = -2.1080863e-015     UTE        = '-1+dutep_lvt'
+UA1        = '1.22313e-009+dua1p_lvt'
+LUA1       = '3.1354809e-018+dlua1p_lvt'
+WUA1       = '-1.7551692e-017+dwua1p_lvt'
+PUA1       = '2.7517381e-024+dpua1p_lvt'
+UB1        = '-1.6557558e-018+dub1p_lvt'
+LUB1       = '3.2084074e-028+dlub1p_lvt'
+WUB1       = '-1.6570695e-025+dwub1p_lvt'
+PUB1       = '1.3368954e-032+dpub1p_lvt'
+UC1        = 2.2844606e-010      LUC1       = -5.0253277e-018     WUC1       = -1.4179295e-016
+PUC1       = 6.9510368e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt-1.08707e-08*ff_flag_lvt+0.0*ss_flag_lvt-8.69675e-09*sf_flag_lvt-6.90695e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt-8.05299e-07*ff_flag_lvt+0.0*ss_flag_lvt-6.44238e-07*sf_flag_lvt-1.6106e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt+7.93218e-14*ff_flag_lvt+0.0*ss_flag_lvt+6.34573e-14*sf_flag_lvt+1.58643e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.16 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-dxlp_lvt'
+LMAX       = 2.001e-05           WMIN       = '3e-007-dxwp_lvt'   WMAX       = '6e-007-dxwp_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_lvt'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23575365+dvthp_lvt'
+WVTH0      = '-4.9225791e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.017874667+dk2p_lvt'
+WK2        = '4.4177067e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.066934213+dvoffp_lvt'
+WVOFF      = '-1.4977877e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01353+du0p_lvt'  WU0        = '-7.936e-010+dwu0p_lvt'
+UA         = '5.9293933e-010+duap_lvt'
+WUA        = '-3.6465259e-016+dwuap_lvt'
+UB         = '1.2795536e-018+dubp_lvt'
+WUB        = '1.062968e-025+dwubp_lvt'
+UC         = 1.748e-013          WUC        = 2.353024e-018       VSAT       = '95420+dvsatp_lvt'
+A0         = '2.9295333+da0p_lvt'
+WA0        = '3.0222933e-007+dwa0p_lvt'
+AGS        = '0.9259776+dagsp_lvt'
+WAGS       = '-1.4618112e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022291333        WKETA      = 1.1044267e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.0024703061+dpdiblc2p_lvt'
+WPDIBLC2   = '1.8410197e-011+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.00153572          LTVOFF     = 0
+WTVOFF     = -2.521664e-010      PTVOFF     = 0                   KT1        = -0.23770992
+WKT1       = -1.7665536e-009     KT1L       = 0                   KT2        = -0.036412667
+WKT2       = 2.2485333e-010      UTE        = '-1.5215333+dutep_lvt'
+WUTE       = '-2.4469333e-008+dwutep_lvt'
+UA1        = '1.1222722e-009+dua1p_lvt'
+WUA1       = '-1.2015289e-016+dwua1p_lvt'
+UB1        = '-1.9038678e-018+dub1p_lvt'
+WUB1       = '2.9065041e-025+dwub1p_lvt'
+UC1        = -2.9513333e-012     WUC1       = -6.7323733e-018     PRT        = 0
+AT         = '175866.67+datp_lvt'
+WAT        = '0.0013226667+dwatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.17 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-dxlp_lvt'
+LMAX       = '9.999994e-006-dxlp_lvt'
+WMIN       = '3e-007-dxwp_lvt'   WMAX       = '6e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23088874+dvthp_lvt'
+LVTH0      = '-4.8474388e-008+dlvthp_lvt'
+WVTH0      = '-6.1755499e-009+dwvthp_lvt'
+PVTH0      = '1.2484726e-014+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.018336586+dk2p_lvt'
+LK2        = '-4.6026059e-009+dlk2p_lvt'
+WK2        = '4.5708632e-009+dwk2p_lvt'
+PK2        = '-1.5260672e-015+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016912175+dcitp_lvt'
+LCIT       = '-6.8873606e-010+dlcitp_lvt'
+WCIT       = '-5.101968e-011+dwcitp_lvt'
+PCIT       = '5.0836519e-016+dpcitp_lvt'
+VOFF       = '-0.060732147+dvoffp_lvt'
+LVOFF      = '-6.1798009e-008+dlvoffp_lvt'
+WVOFF      = '-3.3516675e-009+dwvoffp_lvt'
+PVOFF      = '1.8472243e-014+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.013703952+du0p_lvt'
+LU0        = '-1.7332772e-009+dlu0p_lvt'
+WU0        = '-7.9983423e-010+dwu0p_lvt'
+PU0        = '6.2118468e-017+dpu0p_lvt'
+UA         = '6.7846422e-010+duap_lvt'
+LUA        = '-8.5217848e-016+dluap_lvt'
+WUA        = '-3.7698573e-016+dwuap_lvt'
+PUA        = '1.2288868e-022+dpuap_lvt'
+UB         = '1.2389008e-018+dubp_lvt'
+LUB        = '4.0506803e-025+dlubp_lvt'
+WUB        = '1.1065758e-025+dwubp_lvt'
+PUB        = '-4.3451198e-032+dpubp_lvt'
+UC         = 6.4009608e-013      LUC        = -4.6362567e-018     WUC        = 2.5160349e-018
+PUC        = -1.6242568e-024     VSAT       = '95420+dvsatp_lvt'  A0         = '2.839515+da0p_lvt'
+LA0        = '8.9695208e-007+dla0p_lvt'
+WA0        = '3.5996678e-007+dwa0p_lvt'
+PA0        = '-5.7530172e-013+dpa0p_lvt'
+AGS        = '0.86185112+dagsp_lvt'
+LAGS       = '6.3896262e-007+dlagsp_lvt'
+WAGS       = '-1.3626586e-008+dwagsp_lvt'
+PAGS       = '-9.87966e-015+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.020377559        LKETA      = -1.9069038e-008
+WKETA      = 8.7560217e-010      PKETA      = 2.2800301e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '-0.00096435659+dpdiblc2p_lvt'
+LPDIBLC2   = '3.4223323e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '5.8713031e-010+dwpdiblc2p_lvt'
+PPDIBLC2   = '-5.6667841e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.001636702         LTVOFF     = -1.0061945e-009
+WTVOFF     = -2.6893506e-010     PTVOFF     = 1.6708456e-016      KT1        = -0.23113179
+LKT1       = -6.5545134e-008     WKT1       = -9.4131471e-010     PKT1       = -8.2227628e-015
+KT1L       = 0                   KT2        = -0.035745581        LKT2       = -6.6469095e-009
+WKT2       = 5.1460323e-010      PKT2       = -2.887097e-015      UTE        = '-1.5272751+dutep_lvt'
+LUTE       = '5.7211382e-008+dlutep_lvt'
+WUTE       = '-2.2769089e-008+dwutep_lvt'
+PUTE       = '-1.69414e-014+dputep_lvt'
+UA1        = '1.0849918e-009+dua1p_lvt'
+LUA1       = '3.7146639e-016+dlua1p_lvt'
+WUA1       = '-1.1014882e-016+dwua1p_lvt'
+PUA1       = '-9.9681548e-023+dpua1p_lvt'
+UB1        = '-1.8271261e-018+dub1p_lvt'
+LUB1       = '-7.6466195e-025+dlub1p_lvt'
+WUB1       = '2.8129178e-025+dwub1p_lvt'
+PUB1       = '9.3250387e-032+dpub1p_lvt'
+UC1        = -4.9914189e-012     LUC1       = 2.0327617e-017      WUC1       = -6.9019018e-018
+PUC1       = 1.6891988e-024      PRT        = 0                   AT         = '175866.67+datp_lvt'
+WAT        = '0.0013226667+dwatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'       LPCLM      = '0+dlpclmp_lvt'
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.18 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-dxlp_lvt'
+LMAX       = '9.999943e-007-dxlp_lvt'
+WMIN       = '3e-007-dxwp_lvt'   WMAX       = '6e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.2841419+dvthp_lvt'
+LVTH0      = '2.866984e-009+dlvthp_lvt'
+WVTH0      = '8.5061597e-009+dwvthp_lvt'
+PVTH0      = '-1.6699099e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.014882296+dk2p_lvt'
+LK2        = '-1.2723252e-009+dlk2p_lvt'
+WK2        = '2.9398229e-009+dwk2p_lvt'
+PK2        = '4.6418728e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00087291832+dcitp_lvt'
+LCIT       = '3.1589478e-010+dlcitp_lvt'
+WCIT       = '6.2557338e-010+dwcitp_lvt'
+PCIT       = '-1.4393818e-016+dpcitp_lvt'
+VOFF       = '-0.12130234+dvoffp_lvt'
+LVOFF      = '-3.4022871e-009+dlvoffp_lvt'
+WVOFF      = '1.791802e-008+dwvoffp_lvt'
+PVOFF      = '-2.0338621e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36273667+deta0p_lvt'
+WETA0      = '-2.6453333e-008+dweta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.012392848+du0p_lvt'
+LU0        = '-4.6924114e-010+dlu0p_lvt'
+WU0        = '-7.6546234e-010+dwu0p_lvt'
+PU0        = '2.8980526e-017+dpu0p_lvt'
+UA         = '-1.4775568e-010+duap_lvt'
+LUA        = '-5.5619884e-017+dluap_lvt'
+WUA        = '-2.4342621e-016+dwuap_lvt'
+PUA        = '-5.8760515e-024+dpuap_lvt'
+UB         = '1.7096201e-018+dubp_lvt'
+LUB        = '-4.8752482e-026+dlubp_lvt'
+WUB        = '4.5797109e-026+dwubp_lvt'
+PUB        = '1.9080778e-032+dpubp_lvt'
+UC         = -1.1871005e-011     LUC        = 7.4256957e-018      WUC        = 1.5334484e-018
+PUC        = -6.7694512e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '4.8648962+da0p_lvt'
+LA0        = '-1.055718e-006+dla0p_lvt'
+WA0        = '-4.0297693e-007+dwa0p_lvt'
+PA0        = '1.6025232e-013+dpa0p_lvt'
+AGS        = '0.067371045+dagsp_lvt'
+LAGS       = '1.4049209e-006+dlagsp_lvt'
+WAGS       = '-1.1428118e-007+dwagsp_lvt'
+PAGS       = '8.7161431e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.024690692        LKETA      = -1.4910747e-008
+WKETA      = 1.5364611e-009      PKETA      = 1.642896e-015       DWG        = 0
+DWB        = 0                   PCLM       = '2.2507759+dpclmp_lvt'
+LPCLM      = '-2.4177302e-007+dlpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.029773189+dpdiblc2p_lvt'
+LPDIBLC2   = '4.5892549e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-3.9680413e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '-1.2751432e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.000219292         LTVOFF     = 3.6033045e-010
+WTVOFF     = -7.7924692e-011     PTVOFF     = -1.7068531e-017     KT1        = -0.31187246
+LKT1       = 1.2296943e-008      WKT1       = -7.9125459e-009     PKT1       = -1.5017989e-015
+KT1L       = 0                   KT2        = -0.035773757        LKT2       = -6.6197453e-009
+WKT2       = -4.1405375e-009     PKT2       = 1.6009242e-015      UTE        = '-1.5590695+dutep_lvt'
+LUTE       = '8.7864345e-008+dlutep_lvt'
+WUTE       = '-4.7389807e-008+dwutep_lvt'
+PUTE       = '6.7954337e-015+dputep_lvt'
+UA1        = '1.5130551e-009+dua1p_lvt'
+LUA1       = '-4.1229464e-017+dlua1p_lvt'
+WUA1       = '-2.5601888e-016+dwua1p_lvt'
+PUA1       = '4.0951774e-023+dpua1p_lvt'
+UB1        = '-2.8218002e-018+dub1p_lvt'
+LUB1       = '1.9430338e-025+dlub1p_lvt'
+WUB1       = '4.4261056e-025+dwub1p_lvt'
+PUB1       = '-6.2277056e-032+dpub1p_lvt'
+UC1        = -1.1959973e-011     LUC1       = 2.7045999e-017      WUC1       = -1.5512966e-019
+PUC1       = -4.8153643e-024     PRT        = 0                   AT         = '230082.11+datp_lvt'
+LAT        = '-0.052269111+dlatp_lvt'
+WAT        = '-0.0017019579+dwatp_lvt'
+PAT        = '2.9160405e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'     LETA0      = '0+dleta0p_lvt'
+PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'
+PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.19 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_lvt'
+LMAX       = '2.399901e-007-dxlp_lvt'
+WMIN       = '3e-007-dxwp_lvt'   WMAX       = '6e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.29225957+dvthp_lvt'
+LVTH0      = '4.734777e-009+dlvthp_lvt'
+WVTH0      = '6.3285683e-009+dwvthp_lvt'
+PVTH0      = '-1.1688679e-015+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.0023338612+dk2p_lvt'
+LK2        = '1.6149441e-009+dlk2p_lvt'
+WK2        = '4.3647633e-009+dwk2p_lvt'
+PK2        = '-2.814458e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00048392909+dcitp_lvt'
+LCIT       = '2.2639225e-010+dlcitp_lvt'
+WCIT       = '6.0085813e-011+dwcitp_lvt'
+PCIT       = '-1.3825145e-017+dpcitp_lvt'
+VOFF       = '-0.14449513+dvoffp_lvt'
+LVOFF      = '1.9341412e-009+dlvoffp_lvt'
+WVOFF      = '1.5688644e-008+dwvoffp_lvt'
+PVOFF      = '-1.520905e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.36274136+deta0p_lvt'
+LETA0      = '-1.0793137e-012+dleta0p_lvt'
+WETA0      = '-2.6455314e-008+dweta0p_lvt'
+PETA0      = '4.5560816e-019+dpeta0p_lvt'
+ETAB       = -0.1572             WETAB      = 1.1904e-008         UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.011364291+du0p_lvt'
+LU0        = '-2.3258062e-010+dlu0p_lvt'
+WU0        = '-7.0188344e-010+dwu0p_lvt'
+PU0        = '1.4351657e-017+dpu0p_lvt'
+UA         = '-5.7550375e-011+duap_lvt'
+LUA        = '-7.6375221e-017+dluap_lvt'
+WUA        = '-3.7326763e-016+dwuap_lvt'
+PUA        = '2.399916e-023+dpuap_lvt'
+UB         = '1.1523993e-018+dubp_lvt'
+LUB        = '7.9458454e-026+dlubp_lvt'
+WUB        = '2.9323037e-025+dwubp_lvt'
+PUB        = '-3.785114e-032+dpubp_lvt'
+UC         = 1.9740141e-012      LUC        = 4.2400953e-018      WUC        = 9.5761559e-019
+PUC        = -5.4445175e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '0.16429284+da0p_lvt'
+LA0        = '2.5843822e-008+dla0p_lvt'
+WA0        = '1.453757e-006+dwa0p_lvt'
+PA0        = '-2.669636e-013+dpa0p_lvt'
+AGS        = '8.6744454+dagsp_lvt'
+LAGS       = '-5.7548087e-007+dlagsp_lvt'
+WAGS       = '-7.9514289e-008+dwagsp_lvt'
+PAGS       = '7.9161918e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.10413855         LKETA      = 3.3694106e-009
+WKETA      = 1.3305248e-008      PKETA      = -1.0649841e-015     DWG        = 0
+DWB        = 0                   PCLM       = '1.2244921+dpclmp_lvt'
+LPCLM      = '-5.6353953e-009+dlpclmp_lvt'
+WPCLM      = '1.0083813e-007+dwpclmp_lvt'
+PPCLM      = '-2.3201846e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.070866338+dpdiblc2p_lvt'
+LPDIBLC2   = '-4.8658676e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-2.0588802e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '2.5491277e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0017913715        LTVOFF     = -1.3893293e-012
+WTVOFF     = -5.2357608e-011     PTVOFF     = -2.2951261e-017
+KT1        = -0.23514196
+LKT1       = -5.3579814e-09
+WKT1       = -1.7955882e-08
+PKT1       = 8.090743e-16
+KT1L       = 0                   KT2        = -0.068827129        LKT2       = 9.8550525e-010
+WKT2       = 5.2082872e-009      PKT2       = -5.5014685e-016     UTE        = '-1.3098408+dutep_lvt'
+LUTE       = '3.0519317e-008+dlutep_lvt'
+WUTE       = '-3.1221879e-008+dwutep_lvt'
+PUTE       = '3.0753551e-015+dputep_lvt'
+UA1        = '1.3982017e-009+dua1p_lvt'
+LUA1       = '-1.4802841e-017+dlua1p_lvt'
+WUA1       = '-1.4749325e-016+dwua1p_lvt'
+PUA1       = '1.5981111e-023+dpua1p_lvt'
+UB1        = '-2.3054812e-018+dub1p_lvt'
+LUB1       = '7.5503531e-026+dlub1p_lvt'
+WUB1       = '3.7579549e-025+dwub1p_lvt'
+PUB1       = '-4.6903575e-032+dpub1p_lvt'
+UC1        = 1.074981e-010       LUC1       = -4.4010738e-019     WUC1       = -1.8078459e-017
+PUC1       = -6.9138538e-025     PRT        = 0                   AT         = '11083.534+datp_lvt'
+LAT        = '-0.0018797281+dlatp_lvt'
+WAT        = '0.01918411+dwatp_lvt'
+PAT        = '-1.8896348e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'
+LVSAT      = '0+dlvsatp_lvt'     WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.20 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_lvt'
+WMIN       = '3e-007-dxwp_lvt'   WMAX       = '6e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.20377098+dvthp_lvt-0.0298825*ff_flag_lvt+0.0304485*ss_flag_lvt-0.0239059*sf_flag_lvt+0.0239059*fs_flag_lvt'
+LVTH0      = '-3.9813484e-009+dlvthp_lvt+2.94341e-09*ff_flag_lvt-2.99916e-09*ss_flag_lvt+2.35473e-09*sf_flag_lvt-2.35473e-09*fs_flag_lvt'
+WVTH0      = '-1.5923639e-008+dwvthp_lvt-6.73717e-09*ff_flag_lvt+1.12281e-09*ss_flag_lvt-5.38973e-09*sf_flag_lvt+5.38973e-09*fs_flag_lvt'
+PVTH0      = '1.0229745e-015+dpvthp_lvt+6.63608e-16*ff_flag_lvt-1.10599e-16*ss_flag_lvt+5.30883e-16*sf_flag_lvt-5.30883e-16*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.0015527958+dk2p_lvt'
+LK2        = '1.9977798e-009+dlk2p_lvt'
+WK2        = '-1.5394737e-009+dwk2p_lvt'
+PK2        = '3.0012154e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.00080120866+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '2.5764428e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '-5.4489619e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '4.5765583e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.040953063+dvoffp_lvt-0.0445973*ff_flag_lvt+0.00996083*ss_flag_lvt-0.0356779*sf_flag_lvt+0.0300636*fs_flag_lvt'
+LVOFF      = '-8.264752e-009+dlvoffp_lvt+4.39282e-09*ff_flag_lvt-9.81134e-10*ss_flag_lvt+3.51425e-09*sf_flag_lvt-2.96125e-09*fs_flag_lvt'
+WVOFF      = '-1.2358927e-008+dwvoffp_lvt+4.4914e-09*ff_flag_lvt+2.24572e-09*ss_flag_lvt+3.59318e-09*sf_flag_lvt-1.79658e-09*fs_flag_lvt'
+PVOFF      = '1.2417808e-015+dpvoffp_lvt-4.42403e-16*ff_flag_lvt-2.21202e-16*ss_flag_lvt-3.53926e-16*sf_flag_lvt+1.76966e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt-1.73183*ff_flag_lvt+0.0*ss_flag_lvt-1.38546*sf_flag_lvt+0.332782*fs_flag_lvt'
+ETA0       = '0.12791292+deta0p_lvt+0.00797998*ff_flag_lvt+0.0169786*ss_flag_lvt+0.0126774*sf_flag_lvt+0.0155072*fs_flag_lvt'
+LETA0      = '2.3129522e-008+dleta0p_lvt-7.86025e-10*ff_flag_lvt-1.67239e-09*ss_flag_lvt-1.24872e-09*sf_flag_lvt-1.52746e-09*fs_flag_lvt'
+WETA0      = '-6.4276683e-008+dweta0p_lvt-3.36856e-09*ff_flag_lvt-4.4e-14*ss_flag_lvt-7.85999e-09*sf_flag_lvt-2.24571e-09*fs_flag_lvt'
+PETA0      = '3.7258605e-015+dpeta0p_lvt+3.31802e-16*ff_flag_lvt+5e-22*ss_flag_lvt+7.74207e-16*sf_flag_lvt+2.21202e-16*fs_flag_lvt'
+ETAB       = -0.19995624         LETAB      = 4.2114898e-009      WETAB      = 2.286949e-008
+PETAB      = -1.0801008e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0055557057+du0p_lvt-1.47151e-05*ff_flag_lvt-0.000816104*ss_flag_lvt-1.17719e-05*sf_flag_lvt+3.28257e-05*fs_flag_lvt'
+LU0        = '3.3956506e-010+dlu0p_lvt+1.44937e-12*ff_flag_lvt+8.03862e-11*ss_flag_lvt+1.15952e-12*sf_flag_lvt-3.23325e-12*fs_flag_lvt'
+WU0        = '9.1687561e-011+dwu0p_lvt-2.24571e-11*ff_flag_lvt+1.12284e-11*ss_flag_lvt-1.79657e-11*sf_flag_lvt+1.12285e-11*fs_flag_lvt'
+PU0        = '-6.3815086e-017+dpu0p_lvt+2.21202e-18*ff_flag_lvt-1.10596e-18*ss_flag_lvt+1.76962e-18*sf_flag_lvt-1.10601e-18*fs_flag_lvt'
+UA         = '-2.0770824e-009+duap_lvt'
+LUA        = '1.2254868e-016+dluap_lvt'
+WUA        = '2.4079799e-016+dwuap_lvt'
+PUA        = '-3.6486303e-023+dpuap_lvt'
+UB         = '3.0338164e-018+dubp_lvt'
+LUB        = '-1.0586113e-025+dlubp_lvt'
+WUB        = '-5.8470606e-025+dwubp_lvt'
+PUB        = '4.8625598e-032+dpubp_lvt'
+UC         = 5.3010594e-011      LUC        = -7.8700784e-019     WUC        = -1.4439428e-017
+PUC        = 9.7215703e-025
+VSAT       = '101362.36+dvsatp_lvt+1528.08*ff_flag_lvt-13922.5*ss_flag_lvt+1222.47*sf_flag_lvt-1222.47*fs_flag_lvt'
+LVSAT      = '-0.00058532244+dlvsatp_lvt-0.000150515*ff_flag_lvt+0.00137136*ss_flag_lvt-0.000120412*sf_flag_lvt+0.000120412*fs_flag_lvt'
+WVSAT      = '0.0020210815+dwvsatp_lvt+0.00168428*ff_flag_lvt+0.00336857*ss_flag_lvt+0.00134743*sf_flag_lvt-0.00134743*fs_flag_lvt'
+PVSAT      = '-1.9907653e-010+dpvsatp_lvt-1.65902e-10*ff_flag_lvt-3.31803e-10*ss_flag_lvt-1.32721e-10*sf_flag_lvt+1.32721e-10*fs_flag_lvt'
+A0         = '-0.54674847+da0p_lvt'
+LA0        = '9.5881391e-008+dla0p_lvt'
+WA0        = '-3.3898971e-006+dwa0p_lvt'
+PA0        = '2.1013633e-013+dpa0p_lvt'
+AGS        = '-1.6414085+dagsp_lvt'
+LAGS       = '4.4063074e-007+dlagsp_lvt'
+WAGS       = '1.6639629e-006+dwagsp_lvt'
+PAGS       = '-9.2570584e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.18027688         LKETA      = 1.0869036e-008
+WKETA      = -3.9978133e-009     PKETA      = 6.3936744e-016      DWG        = 0
+DWB        = 0                   PCLM       = '2.0398674+dpclmp_lvt'
+LPCLM      = '-8.5949863e-008+dlpclmp_lvt'
+WPCLM      = '-3.072915e-007+dwpclmp_lvt'
+PPCLM      = '1.6998923e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.03456476+dpdiblc2p_lvt'
+LPDIBLC2   = '-1.2901622e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.2959548e-008+dwpdiblc2p_lvt'
+PPDIBLC2   = '-7.5538481e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0026786944        LTVOFF     = -8.8790628e-011
+WTVOFF     = -7.9793405e-010     PTVOFF     = 5.0488019e-017
+KT1        = '-0.17394713+0.0350892*ff_flag_lvt+0.0280714*sf_flag_lvt-0.0280714*fs_flag_lvt'
+LKT1       = '-1.1385656e-08-3.45628e-09*ff_flag_lvt-2.76502e-09*sf_flag_lvt+2.76502e-09*fs_flag_lvt'
+WKT1       = '-2.0825425e-08-1.12286e-08*ff_flag_lvt-8.98284e-09*sf_flag_lvt+8.98284e-09*fs_flag_lvt'
+PKT1       = '1.0917144e-15+1.10601e-15*ff_flag_lvt+8.84808e-16*sf_flag_lvt-8.84808e-16*fs_flag_lvt'
+KT1L       = 0                   KT2        = -0.0502518          LKT2       = -8.4416474e-010
+WKT2       = -8.2725695e-010     PKT2       = 4.435425e-017       UTE        = '-1+dutep_lvt'
+UA1        = '1.2100567e-009+dua1p_lvt'
+LUA1       = '3.7294345e-018+dlua1p_lvt'
+WUA1       = '-9.4462998e-018+dwua1p_lvt'
+PUA1       = '2.3834868e-024+dpua1p_lvt'
+UB1        = '-1.3247201e-018+dub1p_lvt'
+LUB1       = '-2.1101433e-026+dlub1p_lvt'
+WUB1       = '-3.7094907e-025+dwub1p_lvt'
+PUB1       = '2.6650764e-032+dpub1p_lvt'
+UC1        = 9.9012965e-011      LUC1       = 3.9567797e-019      WUC1       = -6.1544436e-017
+PUC1       = 3.5900133e-024      PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+1.70585e-07*ff_flag_lvt+0.0*ss_flag_lvt+1.36468e-07*sf_flag_lvt-3.27789e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+3.36857e-07*ff_flag_lvt+0.0*ss_flag_lvt+2.69485e-07*sf_flag_lvt+6.73718e-08*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt-3.31803e-14*ff_flag_lvt+0.0*ss_flag_lvt-2.65442e-14*sf_flag_lvt-6.6361e-15*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.21 PMOS	(	LEVEL      = 54                  LMIN       = '9.999994e-006-dxlp_lvt'
+LMAX       = 2.001e-05           WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_lvt'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25
+TOXE       = 'toxp_lvt'          TOXM       = 2.8e-009            DTOX       = 3.472e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.894715e-08
+LL         = 0                   WL         = 0                   LLN        = 0
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'
+DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.23207797+dvthp_lvt'
+WVTH0      = '-6.0987967e-009+dwvthp_lvt'
+K1         = 0.1515              K2         = '0.021475556+dk2p_lvt'
+WK2        = '3.2654222e-009+dwk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0001+dcitp_lvt'
+VOFF       = '-0.077578135+dvoffp_lvt'
+WVOFF      = '1.9082672e-009+dwvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.01049+du0p_lvt'  WU0        = '1.792e-010+dwu0p_lvt'
+UA         = '-3.0587778e-010+duap_lvt'
+WUA        = '-7.7031111e-017+dwuap_lvt'
+UB         = '1.5348392e-018+dubp_lvt'
+WUB        = '2.4605392e-026+dwubp_lvt'
+UC         = 1.3196289e-011      WUC        = -1.8138524e-018     VSAT       = '95420+dvsatp_lvt'
+A0         = '3.2035556+da0p_lvt'
+WA0        = '2.1454222e-007+dwa0p_lvt'
+AGS        = '0.942204+dagsp_lvt'
+WAGS       = '-1.981056e-008+dwagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.026827778        WKETA      = 2.5560889e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '2+dpclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '-0.00017273244+dpdiblc2p_lvt'
+WPDIBLC2   = '8.6418254e-010+dwpdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0011656           LTVOFF     = 0
+WTVOFF     = -1.33728e-010       PTVOFF     = 0                   KT1        = -0.225106
+WKT1       = -5.799808e-009      KT1L       = 0                   KT2        = -0.037973333
+WKT2       = 7.2426667e-010      UTE        = '-1.5163333+dutep_lvt'
+WUTE       = '-2.6133333e-008+dwutep_lvt'
+UA1        = '8.7548773e-010+dua1p_lvt'
+WUA1       = '-4.1181851e-017+dwua1p_lvt'
+UB1        = '-1.2078251e-018+dub1p_lvt'
+WUB1       = '6.7916763e-026+dwub1p_lvt'
+UC1        = -1.3583333e-011     WUC1       = -3.3301333e-018     PRT        = 0
+AT         = '164444.44+datp_lvt'
+WAT        = '0.0049777778+dwatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LVTH0      = '0+dlvthp_lvt'      PVTH0      = '0+dpvthp_lvt'      LK2        = '0+dlk2p_lvt'
+PK2        = '0+dpk2p_lvt'       LU0        = '0+dlu0p_lvt'       PU0        = '0+dpu0p_lvt'
+LUA        = '0+dluap_lvt'       PUA        = '0+dpuap_lvt'       LUB        = '0+dlubp_lvt'
+PUB        = '0+dpubp_lvt'       LUA1       = '0+dlua1p_lvt'      PUA1       = '0+dpua1p_lvt'
+LUB1       = '0+dlub1p_lvt'      PUB1       = '0+dpub1p_lvt'      LUTE       = '0+dlutep_lvt'
+PUTE       = '0+dputep_lvt'      LAT        = '0+dlatp_lvt'       PAT        = '0+dpatp_lvt'
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LCIT       = '0+dlcitp_lvt'
+WCIT       = '0+dwcitp_lvt'      PCIT       = '0+dpcitp_lvt'      LVOFF      = '0+dlvoffp_lvt'
+PVOFF      = '0+dpvoffp_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'  WNFACTOR   = '0+dwnfactorp_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt'  LA0        = '0+dla0p_lvt'       PA0        = '0+dpa0p_lvt'
+LAGS       = '0+dlagsp_lvt'      PAGS       = '0+dpagsp_lvt'      LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'     LPDIBLC2   = '0+dlpdiblc2p_lvt'
+PPDIBLC2   = '0+dppdiblc2p_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.22 PMOS	(	LEVEL      = 54                  LMIN       = '9.999943e-007-dxlp_lvt'
+LMAX       = '9.999994e-006-dxlp_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = 1.894715e-08        LL         = 0
+WL         = 0                   LLN        = 0                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '1.894715e-08+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23167235+dvthp_lvt+0.000208293*ff_flag_lvt+0.000208293*ss_flag_lvt'
+LVTH0      = '-4.0415773e-009+dlvthp_lvt-2.07545e-09*ff_flag_lvt-2.07545e-09*ss_flag_lvt'
+WVTH0      = '-5.9247948e-009+dwvthp_lvt-6.66538e-11*ff_flag_lvt-6.66538e-11*ss_flag_lvt'
+PVTH0      = '-1.7337731e-015+dpvthp_lvt+6.64145e-16*ff_flag_lvt+6.64145e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.022358933+dk2p_lvt'
+LK2        = '-8.8020613e-009+dlk2p_lvt'
+WK2        = '3.283712e-009+dwk2p_lvt'
+PK2        = '-1.822415e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-2.7232634e-005+dcitp_lvt'
+LCIT       = '1.2677587e-009+dlcitp_lvt'
+WCIT       = '1.1813724e-011+dwcitp_lvt'
+PCIT       = '-1.1771313e-016+dpcitp_lvt'
+VOFF       = '-0.078145166+dvoffp_lvt'
+LVOFF      = '5.6499486e-009+dlvoffp_lvt'
+WVOFF      = '2.2204984e-009+dwvoffp_lvt'
+PVOFF      = '-3.1111031e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.010637138+du0p_lvt'
+LU0        = '-1.466101e-009+dlu0p_lvt'
+WU0        = '1.8154622e-010+dwu0p_lvt'
+PU0        = '-2.3377918e-017+dpu0p_lvt'
+UA         = '-2.4629273e-010+duap_lvt'
+LUA        = '-5.9371136e-016+dluap_lvt'
+WUA        = '-8.1063508e-017+dwuap_lvt'
+PUA        = '4.0179203e-023+dpuap_lvt'
+UB         = '1.4877119e-018+dubp_lvt'
+LUB        = '4.6958144e-025+dlubp_lvt'
+WUB        = '3.1038034e-026+dwubp_lvt'
+PUB        = '-6.409549e-032+dpubp_lvt'
+UC         = 1.4512412e-011      LUC        = -1.3113978e-017     WUC        = -1.9231061e-018
+PUC        = 1.088614e-024       VSAT       = '95420+dvsatp_lvt'  A0         = '3.1571597+da0p_lvt'
+LA0        = '4.6229264e-007+dla0p_lvt'
+WA0        = '2.5832046e-007+dwa0p_lvt'
+PA0        = '-4.362107e-013+dpa0p_lvt'
+AGS        = '0.87347719+dagsp_lvt'
+LAGS       = '6.848008e-007+dlagsp_lvt'
+WAGS       = '-1.7346928e-008+dwagsp_lvt'
+PAGS       = '-2.4547877e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025882365        LKETA      = -9.4201909e-009
+WKETA      = 2.6371399e-009      PKETA      = -8.0760081e-016     DWG        = 0
+DWB        = 0                   PCLM       = '2+dpclmp_lvt'      PDIBLC1    = 0
+PDIBLC2    = '-0.0026557284+dpdiblc2p_lvt'
+LPDIBLC2   = '2.474082e-008+dlpdiblc2p_lvt'
+WPDIBLC2   = '1.1283693e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '-2.6323831e-015+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0012700025        LTVOFF     = -1.040277e-009
+WTVOFF     = -1.5159123e-010     PTVOFF     = 1.7799097e-016      KT1        = -0.21244842
+LKT1       = -1.2612135e-007     WKT1       = -6.9199922e-009     PKT1       = 1.1161628e-014
+KT1L       = 0                   KT2        = -0.036235811        LKT2       = -1.7312847e-008
+WKT2       = 6.7147684e-010      PKT2       = 5.2600316e-016      UTE        = '-1.5140957+dutep_lvt'
+LUTE       = '-2.229631e-008+dlutep_lvt'
+WUTE       = '-2.6986502e-008+dwutep_lvt'
+PUTE       = '8.5010611e-015+dputep_lvt'
+UA1        = '8.8114204e-010+dua1p_lvt'
+LUA1       = '-5.6340082e-017+dlua1p_lvt'
+WUA1       = '-4.4916912e-017+dwua1p_lvt'
+PUA1       = '3.7216523e-023+dpua1p_lvt'
+UB1        = '-1.1839841e-018+dub1p_lvt'
+LUB1       = '-2.3755459e-025+dlub1p_lvt'
+WUB1       = '7.5486335e-026+dwub1p_lvt'
+PUB1       = '-7.5423968e-032+dpub1p_lvt'
+UC1        = -1.6683093e-011     LUC1       = 3.0886319e-017      WUC1       = -3.160566e-018
+PUC1       = -1.6895859e-024     PRT        = 0                   AT         = '158612.24+datp_lvt'
+LAT        = '0.058112722+dlatp_lvt'
+WAT        = '0.0068440849+dwatp_lvt'
+PAT        = '-1.8596071e-008+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LPCLM      = '0+dlpclmp_lvt'     WPCLM      = '0+dwpclmp_lvt'     PPCLM      = '0+dppclmp_lvt'
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.23 PMOS	(	LEVEL      = 54                  LMIN       = '2.399901e-007-dxlp_lvt'
+LMAX       = '9.999943e-007-dxlp_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -7.573426e-09       LL         = 1.85e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.85e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-7.573426e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.22994433+dvthp_lvt-0.00255397*ff_flag_lvt-0.00255397*ss_flag_lvt'
+LVTH0      = '-5.7075599e-009+dlvthp_lvt+5.87642e-10*ff_flag_lvt+5.87642e-10*ss_flag_lvt'
+WVTH0      = '-8.8370624e-009+dwvthp_lvt+8.1727e-10*ff_flag_lvt+8.1727e-10*ss_flag_lvt'
+PVTH0      = '1.0739442e-015+dpvthp_lvt-1.88045e-16*ff_flag_lvt-1.88045e-16*ss_flag_lvt'
+K1         = 0.1515              K2         = '0.014372997+dk2p_lvt'
+LK2        = '-1.1028208e-009+dlk2p_lvt'
+WK2        = '3.1027984e-009+dwk2p_lvt'
+PK2        = '-7.8227004e-018+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.001534664+dcitp_lvt'
+LCIT       = '-2.3806584e-010+dlcitp_lvt'
+WCIT       = '-1.4485296e-010+dwcitp_lvt'
+PCIT       = '3.3329217e-017+dpcitp_lvt'
+VOFF       = '-0.058857695+dvoffp_lvt'
+LVOFF      = '-1.2945101e-008+dlvoffp_lvt'
+WVOFF      = '-2.0642663e-009+dwvoffp_lvt'
+PVOFF      = '1.0198385e-015+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339556+deta0p_lvt'
+WETA0      = '-2.9864178e-008+dweta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0094906926+du0p_lvt'
+LU0        = '-3.6081265e-010+dlu0p_lvt'
+WU0        = '1.6322723e-010+dwu0p_lvt'
+PU0        = '-5.7165888e-018+dpu0p_lvt'
+UA         = '-8.0920554e-010+duap_lvt'
+LUA        = '-5.1007123e-017+dluap_lvt'
+WUA        = '-3.1762255e-017+dwuap_lvt'
+PUA        = '-7.3521349e-024+dpuap_lvt'
+UB         = '2.0311877e-018+dubp_lvt'
+LUB        = '-5.4383563e-026+dlubp_lvt'
+WUB        = '-5.7104497e-026+dwubp_lvt'
+PUB        = '2.0882724e-032+dpubp_lvt'
+UC         = -5.4948441e-012     LUC        = 6.1750173e-018      WUC        = -5.0692306e-019
+PUC        = -2.7672803e-025     VSAT       = '95420+dvsatp_lvt'  A0         = '4.4161338+da0p_lvt'
+LA0        = '-7.5148428e-007+dla0p_lvt'
+WA0        = '-2.5937296e-007+dwa0p_lvt'
+PA0        = '6.289752e-014+dpa0p_lvt'
+AGS        = '-0.54071184+dagsp_lvt'
+LAGS       = '2.0482204e-006+dlagsp_lvt'
+WAGS       = '8.0305347e-008+dwagsp_lvt'
+PAGS       = '-1.1869444e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.021041111        LKETA      = -1.4087644e-008
+WKETA      = 3.6859525e-010      PKETA      = 1.3795031e-015      DWG        = 0
+DWB        = 0                   PCLM       = '2.1532519+dpclmp_lvt'
+LPCLM      = '-1.4775018e-007+dlpclmp_lvt'
+WPCLM      = '3.1207664e-008+dwpclmp_lvt'
+PPCLM      = '-3.0087309e-014+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.023948764+dpdiblc2p_lvt'
+LPDIBLC2   = '-9.0857103e-010+dlpdiblc2p_lvt'
+WPDIBLC2   = '-2.1042251e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '4.8416115e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = -0.000116633        LTVOFF     = 2.9657826e-010
+WTVOFF     = 2.9571307e-011      PTVOFF     = 3.3321695e-018      KT1        = -0.35276219
+LKT1       = 9.1551518e-009      WKT1       = 5.1721695e-009      PKT1       = -4.9642556e-016
+KT1L       = 0                   KT2        = -0.051379872        LKT2       = -2.7124582e-009
+WKT2       = 8.5341936e-010      PKT2       = 3.5059237e-016      UTE        = '-1.6325867+dutep_lvt'
+LUTE       = '9.1940907e-008+dlutep_lvt'
+WUTE       = '-2.3864288e-008+dwutep_lvt'
+PUTE       = '5.490934e-015+dputep_lvt'
+UA1        = '7.282847e-010+dua1p_lvt'
+LUA1       = '9.1029681e-017+dlua1p_lvt'
+WUA1       = '-4.8923549e-018+dwua1p_lvt'
+PUA1       = '-1.3711525e-024+dpua1p_lvt'
+UB1        = '-1.4400093e-018+dub1p_lvt'
+LUB1       = '9.2793775e-027+dlub1p_lvt'
+WUB1       = '4.3748835e-028+dwub1p_lvt'
+PUB1       = '-3.0693749e-033+dpub1p_lvt'
+UC1        = 7.7213875e-012      LUC1       = 7.3579589e-018      WUC1       = -6.4531649e-018
+PUC1       = 1.4848087e-024      PRT        = 0                   AT         = '273160.97+datp_lvt'
+LAT        = '-0.052323711+dlatp_lvt'
+WAT        = '-0.015487192+dwatp_lvt'
+PAT        = '2.9335127e-009+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LETA0      = '0+dleta0p_lvt'     PETA0      = '0+dpeta0p_lvt'     LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.24 PMOS	(	LEVEL      = 54                  LMIN       = '9.999946e-008-dxlp_lvt'
+LMAX       = '2.399901e-007-dxlp_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.26672322+dvthp_lvt'
+LVTH0      = '2.7548946e-009+dlvthp_lvt'
+WVTH0      = '-1.8430616e-009+dwvthp_lvt'
+PVTH0      = '-5.3530549e-016+dpvthp_lvt'
+K1         = 0.1515              K2         = '0.004357706+dk2p_lvt'
+LK2        = '1.2015976e-009+dlk2p_lvt'
+WK2        = '3.717133e-009+dwk2p_lvt'
+PK2        = '-1.4917493e-016+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00033261947+dcitp_lvt'
+LCIT       = '1.9157741e-010+dlcitp_lvt'
+WCIT       = '1.1666733e-011+dwcitp_lvt'
+PCIT       = '-2.6843986e-018+dpcitp_lvt'
+VOFF       = '-0.11135937+dvoffp_lvt'
+LVOFF      = '-8.6499066e-010+dlvoffp_lvt'
+WVOFF      = '5.0852027e-009+dwvoffp_lvt'
+PVOFF      = '-6.2518281e-016+dpvoffp_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt' ETA0       = '0.37339522+deta0p_lvt'
+LETA0      = '7.654707e-014+dleta0p_lvt'
+WETA0      = '-2.986455e-008+dweta0p_lvt'
+PETA0      = '8.5732718e-020+dpeta0p_lvt'
+ETAB       = -0.13151111         WETAB      = 3.6835556e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.0086965429+du0p_lvt'
+LU0        = '-1.7808676e-010+dlu0p_lvt'
+WU0        = '1.5179601e-010+dwu0p_lvt'
+PU0        = '-3.0863779e-018+dpu0p_lvt'
+UA         = '-1.0842845e-009+duap_lvt'
+LUA        = '1.2285805e-017+dluap_lvt'
+WUA        = '-4.4712693e-017+dwuap_lvt'
+PUA        = '-4.3723686e-024+dpuap_lvt'
+UB         = '2.1266618e-018+dubp_lvt'
+LUB        = '-7.6351201e-026+dlubp_lvt'
+WUB        = '-1.8533615e-026+dwubp_lvt'
+PUB        = '1.200795e-032+dpubp_lvt'
+UC         = 1.1100322e-011      LUC        = 2.3566355e-018      WUC        = -1.962803e-018
+PUC        = 5.8255382e-026      VSAT       = '95420+dvsatp_lvt'  A0         = '5.0674997+da0p_lvt'
+LA0        = '-9.0135705e-007+dla0p_lvt'
+WA0        = '-1.1526917e-007+dwa0p_lvt'
+PA0        = '2.974068e-014+dpa0p_lvt'
+AGS        = '10.168412+dagsp_lvt'
+LAGS       = '-4.1584196e-007+dlagsp_lvt'
+WAGS       = '-5.5758374e-007+dwagsp_lvt'
+PAGS       = '2.8077465e-014+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.06629674         LKETA      = -3.674776e-009
+WKETA      = 1.1958692e-009      PKETA      = 1.1891557e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.9098153+dpclmp_lvt'
+LPCLM      = '-9.1737836e-008+dlpclmp_lvt'
+WPCLM      = '-1.1846527e-007+dwpclmp_lvt'
+PPCLM      = '4.3509354e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.010601701+dpdiblc2p_lvt'
+LPDIBLC2   = '2.1624547e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-1.304118e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '3.0006451e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = 0.0021459306        LTVOFF     = -2.24015e-010
+WTVOFF     = -1.6581652e-010     PTVOFF     = 4.8288953e-017
+KT1        = -0.29052289
+LKT1       = -5.1654891e-09
+WKT1       = -2.33983e-10
+PKT1       = 7.474767e-16
+KT1L       = 0                   KT2        = -0.053663548        LKT2       = -2.1870072e-009
+WKT2       = 3.5594117e-010      PKT2       = 4.6505713e-016      UTE        = '-1.4074092+dutep_lvt'
+LUTE       = '4.0129801e-008+dlutep_lvt'
+UA1        = '9.9069073e-010+dua1p_lvt'
+LUA1       = '3.0652677e-017+dlua1p_lvt'
+WUA1       = '-1.7089746e-017+dwua1p_lvt'
+PUA1       = '1.4353453e-024+dpua1p_lvt'
+UB1        = '-1.0503232e-018+dub1p_lvt'
+LUB1       = '-8.038351e-026+dlub1p_lvt'
+WUB1       = '-2.5855062e-026+dwub1p_lvt'
+PUB1       = '2.980278e-033+dpub1p_lvt'
+UC1        = 5.1002911e-011      LUC1       = -2.6006867e-018     PRT        = 0
+AT         = '85993.585+datp_lvt'
+LAT        = '-0.0092583681+dlatp_lvt'
+WAT        = '-0.0047871061+dwatp_lvt'
+PAT        = '4.7152995e-010+dpatp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'      LNFACTOR   = '0+dlnfactorp_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt'  PNFACTOR   = '0+dpnfactorp_lvt'  LVSAT      = '0+dlvsatp_lvt'
+WVSAT      = '0+dwvsatp_lvt'     PVSAT      = '0+dpvsatp_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.MODEL pch_lvt.25 PMOS	(	LEVEL      = 54                  LMIN       = 6e-08
+LMAX       = '9.999946e-008-dxlp_lvt'
+WMIN       = 1.2e-07             WMAX       = '3e-007-dxwp_lvt'   VERSION    = 4.5
+RGEOMOD    = 1                   BINUNIT    = 2                   PARAMCHK   = 1
+MOBMOD     = 0                   CAPMOD     = 2                   IGCMOD     = 1
+IGBMOD     = 1                   DIOMOD     = 1                   RDSMOD     = 1
+RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_lvt'
+PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+WPEMOD     = 1                   TNOM       = 25                  TOXE       = 'toxp_lvt'
+TOXM       = 2.8e-009            DTOX       = 3.472e-010          EPSROX     = 3.9
+WINT       = 0                   LINT       = -6.55e-09           LL         = 1.71e-05
+WL         = 0                   LLN        = -0.474              WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 1.71e-05            WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '2e-09+dxlp_lvt'    XW         = '2e-08+dxwp_lvt'    DLC        = '-6.55e-09+ddlcp_lvt'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009
+VTH0       = '-0.23029373+dvthp_lvt-0.0641416*ff_flag_lvt+0.0339573*ss_flag_lvt-0.0513133*sf_flag_lvt+0.0513133*fs_flag_lvt'
+LVTH0      = '-8.3341025e-010+dlvthp_lvt+6.31793e-09*ff_flag_lvt-3.34479e-09*ss_flag_lvt+5.05435e-09*sf_flag_lvt-5.05435e-09*fs_flag_lvt'
+WVTH0      = '-7.4363591e-009+dwvthp_lvt+4.2258e-09*ff_flag_lvt+1.1e-15*ss_flag_lvt+3.38062e-09*sf_flag_lvt-3.38062e-09*fs_flag_lvt'
+PVTH0      = '1.5634322e-017+dpvthp_lvt-4.1624e-16*ff_flag_lvt-2.8e-22*ss_flag_lvt-3.32992e-16*sf_flag_lvt+3.32992e-16*fs_flag_lvt'
+K1         = 0.1515              K2         = '-0.01476424+dk2p_lvt'
+LK2        = '3.0851093e-009+dlk2p_lvt'
+WK2        = '2.6881883e-009+dwk2p_lvt'
+PK2        = '-4.7823884e-017+dpk2p_lvt'
+K3         = -3.625              K3B        = 2.128               W0         = 0
+DVT0       = 34.51               DVT1       = 2                   DVT2       = 0.03192
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.6563              MINV       = 0                   VOFFL      = 0
+DVTP0      = 1.291e-006          DVTP1      = 2.22e-015           LPE0       = 1.366e-007
+LPEB       = 4.44089e-021        WEB        = -210                WEC        = -3550
+SCREF      = 1e-006
+KVTH0WE    = -0.0042
+LKVTH0WE   = 5e-11
+WKVTH0WE   = 3.3e-11
+PKVTH0WE   = 0.65e-17
+K2WE       = 0.0006
+LK2WE      = 15e-11
+WK2WE      = 15e-11
+PK2WE      = -1.7e-17
+XJ         = 1.1e-007            NGATE      = 1.5987e+020         NDEP       = 6.3687e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.0033642604+dcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+LCIT       = '4.9019404e-010+dlcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+WCIT       = '2.7528035e-010+dwcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+PCIT       = '-2.865034e-017+dpcitp_lvt+0.0*ff_flag_lvt+0.0*ss_flag_lvt+0.0*sf_flag_lvt+0.0*fs_flag_lvt'
+VOFF       = '-0.056041086+dvoffp_lvt-0.0226382*ff_flag_lvt-0.00547089*ss_flag_lvt-0.0170541*sf_flag_lvt+0.0170541*fs_flag_lvt'
+LVOFF      = '-6.3138418e-009+dlvoffp_lvt+2.22986e-09*ff_flag_lvt+5.38886e-10*ss_flag_lvt+1.67983e-09*sf_flag_lvt-1.67983e-09*fs_flag_lvt'
+WVOFF      = '-7.5307595e-009+dwvoffp_lvt-2.53548e-09*ff_flag_lvt+7.18386e-09*ss_flag_lvt-2.36645e-09*sf_flag_lvt+2.36645e-09*fs_flag_lvt'
+PVOFF      = '6.1748948e-016+dpvoffp_lvt+2.49744e-16*ff_flag_lvt-7.07608e-16*ss_flag_lvt+2.33094e-16*sf_flag_lvt-2.33094e-16*fs_flag_lvt'
+NFACTOR    = '0.6+dnfactorp_lvt-1.20737*ff_flag_lvt+0.0*ss_flag_lvt-0.965897*sf_flag_lvt+0.965897*fs_flag_lvt'
+ETA0       = '-0.056142859+deta0p_lvt+0.0218836*ff_flag_lvt+0.0301843*ss_flag_lvt+3e-09*sf_flag_lvt-0.0060369*fs_flag_lvt'
+LETA0      = '4.2309578e-008+dleta0p_lvt-2.15553e-09*ff_flag_lvt-2.97314e-09*ss_flag_lvt-7e-16*sf_flag_lvt+5.94631e-10*fs_flag_lvt'
+WETA0      = '-5.3788334e-009+dweta0p_lvt-7.81773e-09*ff_flag_lvt-4.2258e-09*ss_flag_lvt-3.80322e-09*sf_flag_lvt+4.64838e-09*fs_flag_lvt'
+PETA0      = '-2.4117574e-015+dpeta0p_lvt+7.70044e-16*ff_flag_lvt+4.1624e-16*ss_flag_lvt+3.74616e-16*sf_flag_lvt-4.57864e-16*fs_flag_lvt'
+ETAB       = -0.14145277         LETAB      = 9.7925374e-010      WETAB      = 4.1483802e-009
+PETAB      = -4.5785222e-017     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0132
+LKU0WE     = 6.5e-10
+WKU0WE     = 6.2e-10
+PKU0WE     = -6.5e-17
+U0         = '0.004826651+du0p_lvt-0.000216949*ff_flag_lvt-0.000199974*ss_flag_lvt-0.00017356*sf_flag_lvt+0.00017356*fs_flag_lvt'
+LU0        = '2.030976e-010+dlu0p_lvt+2.13695e-11*ff_flag_lvt+1.96975e-11*ss_flag_lvt+1.70956e-11*sf_flag_lvt-1.70956e-11*fs_flag_lvt'
+WU0        = '3.2498504e-010+dwu0p_lvt+4.2258e-11*ff_flag_lvt-1.85935e-10*ss_flag_lvt+3.38064e-11*sf_flag_lvt-3.38064e-11*fs_flag_lvt'
+PU0        = '-2.0145498e-017+dpu0p_lvt-4.1624e-18*ff_flag_lvt+1.83146e-17*ss_flag_lvt-3.32992e-18*sf_flag_lvt+3.32992e-18*fs_flag_lvt'
+UA         = '-7.1760304e-010+duap_lvt'
+LUA        = '-2.3832323e-017+dluap_lvt'
+WUA        = '-1.942354e-016+dwuap_lvt'
+PUA        = '1.0355618e-023+dpuap_lvt'
+UB         = '1.1232978e-019+dubp_lvt'
+LUB        = '1.220605e-025+dlubp_lvt'
+WUB        = '3.5016965e-025+dwubp_lvt'
+PUB        = '-2.4309322e-032+dpubp_lvt'
+UC         = 1.9449027e-011      LUC        = 1.5342881e-018      WUC        = -3.6997264e-018
+PUC        = 2.2934234e-025
+VSAT       = '117212.43+dvsatp_lvt+5470.89*ff_flag_lvt-6036.86*ss_flag_lvt+4376.72*sf_flag_lvt-4376.72*fs_flag_lvt'
+LVSAT      = '-0.0021465539+dlvsatp_lvt-0.000538885*ff_flag_lvt+0.000594629*ss_flag_lvt-0.000431106*sf_flag_lvt+0.000431106*fs_flag_lvt'
+WVSAT      = '-0.0030509396+dwvsatp_lvt+0.00042258*ff_flag_lvt+0.00084516*ss_flag_lvt+0.00033806*sf_flag_lvt-0.00033806*fs_flag_lvt'
+PVSAT      = '3.0051755e-010+dpvsatp_lvt-4.16241e-11*ff_flag_lvt-8.3248e-11*ss_flag_lvt-3.32991e-11*sf_flag_lvt+3.32991e-11*fs_flag_lvt'
+A0         = '-17.084839+da0p_lvt'
+LA0        = '1.2806483e-006+dla0p_lvt'
+WA0        = '1.902292e-006+dwa0p_lvt'
+PA0        = '-1.6898909e-013+dpa0p_lvt'
+AGS        = '8.8272963+dagsp_lvt'
+LAGS       = '-2.8374202e-007+dlagsp_lvt'
+WAGS       = '-1.6860227e-006+dwagsp_lvt'
+PAGS       = '1.392287e-013+dpagsp_lvt'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.30463264         LKETA      = 1.980131e-008
+WKETA      = 3.5796028e-008      PKETA      = -2.21896e-015       DWG        = 0
+DWB        = 0                   PCLM       = '1.4395749+dpclmp_lvt'
+LPCLM      = '-4.5419164e-008+dlpclmp_lvt'
+WPCLM      = '-1.151979e-007+dwpclmp_lvt'
+PPCLM      = '4.0290996e-015+dppclmp_lvt'
+PDIBLC1    = 0                   PDIBLC2    = '0.091843329+dpdiblc2p_lvt'
+LPDIBLC2   = '-5.8398456e-009+dlpdiblc2p_lvt'
+WPDIBLC2   = '-5.369594e-009+dwpdiblc2p_lvt'
+PPDIBLC2   = '7.005139e-016+dppdiblc2p_lvt'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.015               PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0.15                PDITSD     = 1.3
+PDITSL     = 100000              RSH        = 14.55                  RSW        = 87.04
+RDW        = 87.04               PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 2.26e-8             ALPHA1     = 0.034
+BETA0      = 14.74               AGIDL      = 1.7199e-008         BGIDL      = 2.5021e+009
+CGIDL      = 1                   EGIDL      = 0.008744            AIGBACC    = 0.01321
+BIGBACC    = 0.005279            CIGBACC    = 0.1855              NIGBACC    = 1
+AIGBINV    = 0.01195             BIGBINV    = 0.002916            CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 10                  AIGC       = 0.007225
+BIGC       = 0.0006483           CIGC       = 0                   AIGSD      = 0.006142
+BIGSD      = 0.0001998           CIGSD      = 0.001682            NIGC       = 2.122
+POXEDGE    = 1                   PIGCD      = 2.668               NTOX       = 'ntoxp_lvt'
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgop_lvt'
+CGDO       = 'cgop_lvt'          CGBO       = 0                   CGDL       = 'cglp_lvt'
+CGSL       = 'cglp_lvt'          CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfp_lvt'           CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 1.03                MOIN       = 11.434              NOFF       = 2.054
+VOFFCV     = -0.10789            TVOFF      = -0.0025499865       LTVOFF     = 2.3853283e-010
+WTVOFF     = 8.7524381e-010      PTVOFF     = -5.4255488e-017
+KT1        = -0.28244227
+LKT1       = -5.9614337e-09
+WKT1       = 1.3893019e-08
+PKT1       = -6.440366e-16
+KT1L       = 0                   KT2        = -0.059474552        LKT2       = -1.6146233e-009
+WKT2       = 2.1240238e-009      PKT2       = 2.9090099e-016      UTE        = '-1+dutep_lvt'
+UA1        = '1.2992311e-009+dua1p_lvt'
+LUA1       = '2.6145406e-019+dlua1p_lvt'
+WUA1       = '-3.7982084e-017+dwua1p_lvt'
+PUA1       = '3.4932406e-024+dpua1p_lvt'
+UB1        = '-2.5120633e-018+dub1p_lvt'
+LUB1       = '6.3597893e-026+dlub1p_lvt'
+WUB1       = '9.0007619e-027+dwub1p_lvt'
+PUB1       = '-4.5302063e-034+dpub1p_lvt'
+UC1        = -2.1750872e-010     LUC1       = 2.3847709e-017      WUC1       = 3.9742503e-017
+PUC1       = -3.9146365e-024     PRT        = 0                   AT         = '-8000+datp_lvt'
+NOIA       = 'noiap_lvt'
+NOIB       = 'noibp_lvt'
+NOIC       = 'noicp_lvt'
+EM         = 1.00000e+06
+EF         = 1.1
+JSS        = 1.15e-07
+JSD        = 1.15e-07            JSWS       = 1.7e-13             JSWD       = 1.7e-13
+JSWGS      = 1.7e-13             JSWGD      = 1.7e-13             NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9.4
+BVD        = 9.4                 XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_lvt'
+CJD        = 'cjp_lvt'           MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.9                 PBSWD      = 0.9                 CJSWS      = 'cjswp_lvt'
+CJSWD      = 'cjswp_lvt'         MJSWS      = 0.06                MJSWD      = 0.06
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_lvt'
+CJSWGD     = 'cjswgp_lvt'        MJSWGS     = 0.9                 MJSWGD     = 0.9
+TPB        = 0.0017              TCJ        = 0.00091             TPBSW      = 0.003
+TCJSW      = 0.00022             TPBSWG     = 0.0005              TCJSWG     = 0.003
+XTIS       = 3                   XTID       = 3
+JTSSWGS    = 0
+JTSSWGD    = 0
+NJTSSWG    = 39.9                XTSSWGS    = 0.4055
+XTSSWGD    = 0.4055              TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 6.1e-008            DMCI       = 6.6e-008
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 4.05e-007
+SBREF      = 4.05e-007
+WLOD       = 2.8e-7
+KVTH0      = 2e-010
+LKVTH0     = 2e-9
+WKVTH0     = 2e-008
+PKVTH0     = 0e-013
+LLODVTH    = 2
+WLODVTH    = 1
+STK2       = 2e-012
+LODK2      = 1
+LODETA0    = 1
+KU0        = -1.2e-009
+PKU0     = 0e-14
+LKU0       = -3.8e-008
+WKU0       = 0e-008
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1
+STETA0     = -1e-010
+TKU0       = 0
+LUTE       = '0+dlutep_lvt'      WUTE       = '0+dwutep_lvt'      PUTE       = '0+dputep_lvt'
+LAT        = '0+dlatp_lvt'       WAT        = '0+dwatp_lvt'       PAT        = '0+dpatp_lvt'
+LNFACTOR   = '0+dlnfactorp_lvt+1.18926e-07*ff_flag_lvt+0.0*ss_flag_lvt+9.51406e-08*sf_flag_lvt-9.51406e-08*fs_flag_lvt'
+WNFACTOR   = '0+dwnfactorp_lvt+1.69032e-07*ff_flag_lvt+0.0*ss_flag_lvt+1.35226e-07*sf_flag_lvt-1.35226e-07*fs_flag_lvt'
+PNFACTOR   = '0+dpnfactorp_lvt-1.66496e-14*ff_flag_lvt+0.0*ss_flag_lvt-1.33197e-14*sf_flag_lvt+1.33197e-14*fs_flag_lvt'
+FNOIMOD  = 1
+TNOIMOD  = 1    )



.ENDL MOS_lvt








***************************************************************
*                                                             *
*                     1.8V IO DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_18
**********************************************************************************************
*                                                                                            *
*                                   1.8V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

.MODEL nch_18.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_18'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-dxwn_18'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+dvthn_18'
+K1         = 0.71631             K2         = '-0.048803+dk2n_18' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_18'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_18'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_18'   A0         = '1.1773+da0n_18'    AGS        = '0.3986+dagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       WVTH0      = '0+dwvthn_18'
+PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       LA0        = '0+dla0n_18'        WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'       WAGS       = '0+dwagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      WETA0      = '0+dweta0n_18'
+PETA0      = '0+dpeta0n_18'      LK2        = '0+dlk2n_18'        WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'       )



.MODEL nch_18.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_18'
+LMAX       = '1e-005-dxln_18'    WMIN       = '1e-005-dxwn_18'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+dvthn_18'
+LVTH0      = '1.4790281e-008+dlvthn_18'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_18'
+LK2        = '-1.2153578e-008+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_18'
+LCIT       = '7.5887589e-010+dlcitn_18'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_18'
+LU0        = '2.6891421e-011+dlu0n_18'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.2321467+da0n_18' LA0        = '-5.4764378e-007+dla0n_18'
+AGS        = '0.38027424+dagsn_18'
+LAGS       = '1.8298267e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'        WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'        PA0        = '0+dpa0n_18'
+WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'
+WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'      )



.MODEL nch_18.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_18'
+LMAX       = '1.2e-006-dxln_18'  WMIN       = '1e-005-dxwn_18'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+dvthn_18'
+LVTH0      = '3.2469e-010+dlvthn_18'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_18'
+LK2        = '-6.7649162e-009+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_18'
+LCIT       = '5.941827e-011+dlcitn_18'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_18'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_18'
+A0         = '1.3065331+da0n_18' LA0        = '-6.3579172e-007+dla0n_18'
+AGS        = '0.9247153+dagsn_18'
+LAGS       = '-4.6217998e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'
+WCIT       = '0+dwcitn_18'       PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'
+LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'
+LETA0      = '0+dleta0n_18'      WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'
+WK2        = '0+dwk2n_18'        PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.4 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_18'
+LMAX       = '7e-007-dxln_18'    WMIN       = '1e-005-dxwn_18'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59985+dvthn_18'
+LVTH0      = '-2.50025e-009+dlvthn_18'
+K1         = 0.71631             K2         = '-0.060148641+dk2n_18'
+LK2        = '-1.2743462e-009+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00063515313+dcitn_18'
+LCIT       = '1.1360511e-010+dlcitn_18'
+VOFF       = -0.14569953         LVOFF      = 1.2165279e-008      NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_18'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_18'   UA         = -6.221e-010
+LUA        = -1.650165e-016      UB         = 2.8987125e-018      LUB        = 6.9381938e-026
+UC         = 1.8519984e-010      LUC        = -1.7056393e-017     VSAT       = '89640+dvsatn_18'
+A0         = '1.1521358+da0n_18' LA0        = '-5.3002956e-007+dla0n_18'
+AGS        = '-2.0187031+dagsn_18'
+LAGS       = '1.5540616e-006+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.053365313        LKETA      = 1.4642089e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.268725+dpclmn_18'
+LPCLM      = '-1.6251625e-008+dlpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00478125          LPDIBLC2   = -1.5626563e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0011922813        LTVOFF     = 1.4845234e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29436875         LKT1       = 5.9380938e-009
+KT1L       = 0                   KT2        = -0.055789375        LKT2       = -2.7815281e-009
+UTE        = -1.3999688          LUTE       = 1.1094859e-007      UA1        = 2.5822766e-009
+LUA1       = 2.1799055e-017      UB1        = -3.2810594e-018     LUB1       = 9.4228172e-026
+UC1        = -4.6245625e-011     LUC1       = 4.3535603e-017      PRT        = 0
+AT         = 14157.766           LAT        = -0.0055325845
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'
+WCIT       = '0+dwcitn_18'       PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'
+PA0        = '0+dpa0n_18'        WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.5 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxln_18'  WMIN       = '1e-005-dxwn_18'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55216667+dvthn_18'
+LVTH0      = '1.4904167e-008+dlvthn_18'
+K1         = 0.71631             K2         = '-0.11018183+dk2n_18'
+LK2        = '1.6987769e-008+dlk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00098580417+dcitn_18'
+LCIT       = '-1.4382521e-011+dlcitn_18'
+VOFF       = -0.082500417        LVOFF      = -1.0902398e-008     NFACTOR    = 0.55
+ETA0       = '0.51692083+deta0n_18'
+LETA0      = '3.2043958e-009+dleta0n_18'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04639875+du0n_18'
+LU0        = '-2.8392438e-009+dlu0n_18'
+UA         = -1.5034583e-010     LUA        = -3.3720677e-016     UB         = 1.854e-018
+LUB        = 4.50702e-025        UC         = 2.3945083e-010      LUC        = -3.6858004e-017
+VSAT       = '108015+dvsatn_18'  LVSAT      = '-0.006706875+dlvsatn_18'
+A0         = '0.472975+da0n_18'  LA0        = '-2.8213588e-007+dla0n_18'
+AGS        = '3.9374625+dagsn_18'
+LAGS       = '-6.1993881e-007+dlagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067201042        LKETA      = 1.969213e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.0075291667+dpclmn_18'
+LPCLM      = '8.4581146e-008+dlpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015416667       LPDIBLC2   = 7.4520833e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0012294583        LTVOFF     = 1.3488271e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.35874583         LKT1       = 2.9435729e-008
+KT1L       = 0                   KT2        = -0.13942125         LKT2       = 2.7744106e-008
+UTE        = -1.292              LUTE       = 7.154e-008          UA1        = 3.4635667e-009
+LUA1       = -2.9987183e-016     UB1        = -4.2291167e-018     LUB1       = 4.4026908e-025
+UC1        = 9.5549583e-011      LUC1       = -8.2196479e-018     PRT        = 0
+AT         = -37750              LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+WU0        = '0+dwu0n_18'        PU0        = '0+dpu0n_18'        WCIT       = '0+dwcitn_18'
+PCIT       = '0+dpcitn_18'       WA0        = '0+dwa0n_18'        PA0        = '0+dpa0n_18'
+WAGS       = '0+dwagsn_18'       PAGS       = '0+dpagsn_18'       WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'
+WETA0      = '0+dweta0n_18'      PETA0      = '0+dpeta0n_18'      WK2        = '0+dwk2n_18'
+PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_18'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-dxwn_18'    WMAX       = '1e-005-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+dvthn_18'
+WVTH0      = '-1.9034426e-009+dwvthn_18'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_18'
+WK2        = '8.915949e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_18'
+WCIT       = '3.148518e-010+dwcitn_18'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_18'
+WU0        = '-6.4829015e-009+dwu0n_18'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.1644663+da0n_18' WA0        = '1.2842639e-007+dwa0n_18'
+AGS        = '0.4003119+dagsn_18'
+WAGS       = '-1.7130983e-008+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       PCIT       = '0+dpcitn_18'
+LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'
+LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_18'
+LMAX       = '1e-005-dxln_18'    WMIN       = '1e-006-dxwn_18'    WMAX       = '1e-005-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+dvthn_18'
+LVTH0      = '1.6445149e-008+dlvthn_18'
+WVTH0      = '-2.4492827e-010+dwvthn_18'
+PVTH0      = '-1.6560265e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_18'
+LK2        = '-1.2004489e-008+dlk2n_18'
+WK2        = '9.0653661e-009+dwk2n_18'
+PK2        = '-1.4919294e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_18'
+LCIT       = '8.1447946e-010+dlcitn_18'
+WCIT       = '3.7057788e-010+dwcitn_18'
+PCIT       = '-5.5642492e-016+dpcitn_18'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_18'
+LU0        = '1.1847165e-011+dlu0n_18'
+WU0        = '-6.4979789e-009+dwu0n_18'
+PU0        = '1.5054787e-016+dpu0n_18'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_18'   A0         = '1.2162348+da0n_18' LA0        = '-5.1690836e-007+dla0n_18'
+WA0        = '1.5922953e-007+dwa0n_18'
+PA0        = '-3.0756929e-013+dpa0n_18'
+AGS        = '0.38190343+dagsn_18'
+LAGS       = '1.838086e-007+dlagsn_18'
+WAGS       = '-1.6303234e-008+dwagsn_18'
+PAGS       = '-8.2650779e-015+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'   )  



.MODEL nch_18.8 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_18'
+LMAX       = '1.2e-006-dxln_18'  WMIN       = '1e-006-dxwn_18'    WMAX       = '1e-005-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+dvthn_18'
+LVTH0      = '1.7778581e-009+dlvthn_18'
+WVTH0      = '-1.9482295e-009+dwvthn_18'
+PVTH0      = '-1.4541854e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_18'
+LK2        = '-6.2688409e-009+dlk2n_18'
+WK2        = '1.1995574e-008+dwk2n_18'
+PK2        = '-4.9642252e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_18'
+LCIT       = '6.6229996e-011+dlcitn_18'
+WCIT       = '-4.145586e-011+dwcitn_18'
+PCIT       = '-6.8164938e-017+dpcitn_18'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_18'
+WETA0      = '-2.2393442e-008+dweta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_18'
+LU0        = '-3.4512743e-011+dlu0n_18'
+WU0        = '-6.662385e-009+dwu0n_18'
+PU0        = '3.4536902e-016+dpu0n_18'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.3201499+da0n_18' LA0        = '-6.4004769e-007+dla0n_18'
+WA0        = '-1.3626309e-007+dwa0n_18'
+PA0        = '4.2589454e-014+dpa0n_18'
+AGS        = '0.94327311+dagsn_18'
+LAGS       = '-4.8141448e-007+dlagsn_18'
+WAGS       = '-1.8570803e-007+dwagsn_18'
+PAGS       = '1.9247961e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.9 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_18'
+LMAX       = '7e-007-dxln_18'    WMIN       = '1e-006-dxwn_18'    WMAX       = '1e-005-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+dvthn_18'
+LVTH0      = '-3.3832116e-009+dlvthn_18'
+WVTH0      = '-3.6076185e-008+dwvthn_18'
+PVTH0      = '8.8357962e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.061138887+dk2n_18'
+LK2        = '-9.2107413e-010+dlk2n_18'
+WK2        = '9.9093956e-009+dwk2n_18'
+PK2        = '-3.5351933e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitn_18'
+LCIT       = '1.1765275e-010+dlcitn_18'
+WCIT       = '-8.1835785e-011+dwcitn_18'
+PCIT       = '-4.050469e-017+dpcitn_18'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0n_18'
+LETA0      = '-3.8911504e-009+dleta0n_18'
+WETA0      = '-7.9238321e-008+dweta0n_18'
+PETA0      = '3.8938742e-014+dpeta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0n_18'
+LU0        = '-6.818911e-010+dlu0n_18'
+WU0        = '-1.6119779e-008+dwu0n_18'
+PU0        = '6.8236842e-015+dpu0n_18'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatn_18'
+LVSAT      = '0.00017484387+dlvsatn_18'
+WVSAT      = '0.002554252+dwvsatn_18'
+PVSAT      = '-1.7496626e-009+dpvsatn_18'
+A0         = '1.1807466+da0n_18' LA0        = '-5.4455646e-007+dla0n_18'
+WA0        = '-2.8630873e-007+dwa0n_18'
+PA0        = '1.4537072e-013+dpa0n_18'
+AGS        = '-2.065376+dagsn_18'
+LAGS       = '1.5795102e-006+dlagsn_18'
+WAGS       = '4.6705548e-007+dwagsn_18'
+PAGS       = '-2.546634e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmn_18'
+LPCLM      = '-2.7249305e-008+dlpclmn_18'
+WPCLM      = '-1.6066245e-007+dwpclmn_18'
+PPCLM      = '1.1005378e-013+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_18.10 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxln_18'  WMIN       = '1e-006-dxwn_18'    WMAX       = '1e-005-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55572846+dvthn_18'
+LVTH0      = '1.4037009e-008+dlvthn_18'
+WVTH0      = '-3.5642896e-008+dwvthn_18'
+PVTH0      = '8.6776455e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.10872301+dk2n_18'
+LK2        = '1.644713e-008+dlk2n_18'
+WK2        = '-1.4598472e-008+dwk2n_18'
+PK2        = '5.4101782e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010116733+dcitn_18'
+LCIT       = '-1.6792218e-011+dlcitn_18'
+WCIT       = '-2.5887286e-010+dwcitn_18'
+PCIT       = '2.4113842e-017+dpcitn_18'
+VOFF       = -0.074529266        LVOFF      = -1.2586685e-008     WVOFF      = -7.9767307e-008
+PVOFF      = 1.6854658e-014      NFACTOR    = 0.55                ETA0       = '0.51487061+deta0n_18'
+LETA0      = '2.9517528e-009+dleta0n_18'
+WETA0      = '2.0516592e-008+dweta0n_18'
+PETA0      = '2.5281986e-015+dpeta0n_18'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.045622847+du0n_18'
+LU0        = '-2.6499699e-009+dlu0n_18'
+WU0        = '7.7644596e-009+dwu0n_18'
+PU0        = '-1.894063e-015+dpu0n_18'
+UA         = -1.8818992e-010     LUA        = -3.3434682e-016     WUA        = 3.7870577e-016
+PUA        = -2.8619542e-023     UB         = 1.7929581e-018      LUB        = 4.7803414e-025
+WUB        = 6.1084645e-025      PUB        = -2.7351271e-031     UC         = 2.3992245e-010
+LUC        = -3.5871529e-017     WUC        = -4.7194646e-018     PUC        = -9.8716561e-024
+VSAT       = '108695.66+dvsatn_18'
+LVSAT      = '-0.0068736361+dlvsatn_18'
+WVSAT      = '-0.0068113387+dwvsatn_18'
+PVSAT      = '1.668778e-009+dpvsatn_18'
+A0         = '0.49116347+da0n_18'
+LA0        = '-2.9285861e-007+dla0n_18'
+WA0        = '-1.8201203e-007+dwa0n_18'
+PA0        = '1.0730242e-013+dpa0n_18'
+AGS        = '3.9145724+dagsn_18'
+LAGS       = '-6.0317099e-007+dlagsn_18'
+WAGS       = '2.2906159e-007+dwagsn_18'
+PAGS       = '-1.6779563e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.067214855        LKETA      = 1.9482929e-008
+WKETA      = 1.3823285e-010      PKETA      = 2.093482e-015       DWG        = 0
+DWB        = 0                   PCLM       = '-0.064254502+dpclmn_18'
+LPCLM      = '1.0014829e-007+dlpclmn_18'
+WPCLM      = '5.6765043e-007+dwpclmn_18'
+PPCLM      = '-1.5578042e-013+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0015463108       LPDIBLC2   = 7.6691395e-010
+WPDIBLC2   = 4.6473857e-011      PPDIBLC2   = -2.1720814e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0010417601
+LTVOFF     = 2.060063e-010       WTVOFF     = 1.8782966e-009      PTVOFF     = -7.1173381e-016
+KT1        = -0.38578061         LKT1       = 3.676321e-008       WKT1       = 2.7053704e-007
+PKT1       = -7.3326104e-014     KT1L       = 0                   KT2        = -0.14373694
+LKT2       = 2.8827219e-008      WKT2       = 4.3187153e-008      PKT2       = -1.0838713e-014
+UTE        = -1.3246716          LUTE       = 7.9544531e-008      WUTE       = 3.2694426e-007
+PUTE       = -8.0101343e-014     UA1        = 3.3726047e-009      LUA1       = -2.7712562e-016
+WUA1       = 9.102561e-016       PUA1       = -2.2762132e-022     UB1        = -4.0327032e-018
+LUB1       = 3.8096885e-025      WUB1       = -1.9655098e-024     PUB1       = 5.9341745e-031
+UC1        = 9.7340458e-011      LUC1       = -7.4108568e-018     WUC1       = -1.7921285e-017
+PUC1       = -8.0935732e-024     PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_18.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_18'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-dxwn_18'    WMAX       = '1e-006-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+dvthn_18'
+WVTH0      = '-3.8203063e-009+dwvthn_18'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_18'
+WK2        = '2.9951201e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_18'
+WCIT       = '-9.5507656e-011+dwcitn_18'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_18'
+WU0        = '-4.3551491e-009+dwu0n_18'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_18'   A0         = '1.472886+da0n_18'  WA0        = '-1.821522e-007+dwa0n_18'
+AGS        = '0.4053948+dagsn_18'
+WAGS       = '-2.2249464e-008+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       PVTH0      = '0+dpvthn_18'       LU0        = '0+dlu0n_18'
+PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'       PCIT       = '0+dpcitn_18'
+LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'        LAGS       = '0+dlagsn_18'
+PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'
+LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_18'
+LMAX       = '1e-005-dxln_18'    WMIN       = '6e-007-dxwn_18'    WMAX       = '1e-006-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+dvthn_18'
+LVTH0      = '1.4894822e-008+dlvthn_18'
+WVTH0      = '-2.3181445e-009+dwvthn_18'
+PVTH0      = '-1.4999085e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_18'
+LK2        = '-1.6226287e-008+dlk2n_18'
+WK2        = '2.7187635e-009+dwk2n_18'
+PK2        = '2.7594208e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_18'
+LCIT       = '2.1866624e-010+dlcitn_18'
+WCIT       = '-9.9870099e-011+dwcitn_18'
+PCIT       = '4.3558988e-017+dpcitn_18'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_18'
+LU0        = '-2.2871153e-009+dlu0n_18'
+WU0        = '-4.6020798e-009+dwu0n_18'
+PU0        = '2.4656031e-015+dpu0n_18'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.5788249+da0n_18' LA0        = '-1.0578002e-006+dla0n_18'
+WA0        = '-2.0589871e-007+dwa0n_18'
+PA0        = '2.3710883e-013+dpa0n_18'
+AGS        = '0.39080402+dagsn_18'
+LAGS       = '1.4568891e-007+dlagsn_18'
+WAGS       = '-2.5266134e-008+dwagsn_18'
+PAGS       = '3.0121451e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.13 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_18'
+LMAX       = '1.2e-006-dxln_18'  WMIN       = '6e-007-dxwn_18'    WMAX       = '1e-006-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+dvthn_18'
+LVTH0      = '-3.5476441e-009+dlvthn_18'
+WVTH0      = '-7.2295476e-009+dwvthn_18'
+PVTH0      = '-9.1790728e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_18'
+LK2        = '-1.1063061e-008+dlk2n_18'
+WK2        = '5.1625327e-009+dwk2n_18'
+PK2        = '-1.3644568e-016+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_18'
+LCIT       = '4.2051414e-012+dlcitn_18'
+WCIT       = '-5.8296345e-011+dwcitn_18'
+PCIT       = '-5.7059101e-018+dpcitn_18'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_18'
+WETA0      = '-6.3569896e-008+dweta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_18'
+LU0        = '-3.7564604e-009+dlu0n_18'
+WU0        = '-5.975723e-009+dwu0n_18'
+PU0        = '4.0933703e-015+dpu0n_18'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.2496434+da0n_18' LA0        = '-6.6772012e-007+dla0n_18'
+WA0        = '-6.5263056e-008+dwa0n_18'
+PA0        = '7.0455585e-014+dpa0n_18'
+AGS        = '0.79778898+dagsn_18'
+LAGS       = '-3.3658827e-007+dlagsn_18'
+WAGS       = '-3.9205511e-008+dwagsn_18'
+PAGS       = '4.6639613e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.14 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_18'
+LMAX       = '7e-007-dxln_18'    WMIN       = '6e-007-dxwn_18'    WMAX       = '1e-006-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58171161+dvthn_18'
+LVTH0      = '9.7781262e-009+dlvthn_18'
+WVTH0      = '-1.4180499e-008+dwvthn_18'
+PVTH0      = '-4.4176708e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.048365474+dk2n_18'
+LK2        = '-9.8169855e-009+dlk2n_18'
+WK2        = '-2.953431e-009+dwk2n_18'
+PK2        = '5.4229894e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074160091+dcitn_18'
+LCIT       = '-2.3146846e-013+dlcitn_18'
+WCIT       = '-1.8079361e-010+dwcitn_18'
+PCIT       = '7.8204713e-017+dpcitn_18'
+VOFF       = -0.11884305         LVOFF      = -1.1113064e-008     WVOFF      = 4.4821743e-009
+PVOFF      = 9.0741347e-016      NFACTOR    = 0.55                ETA0       = '0.44101649+deta0n_18'
+LETA0      = '8.7550883e-008+dleta0n_18'
+WETA0      = '1.401169e-008+dweta0n_18'
+PETA0      = '-5.3143386e-014+dpeta0n_18'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.025036647+du0n_18'
+LU0        = '5.5370966e-009+dlu0n_18'
+WU0        = '-8.1921692e-010+dwu0n_18'
+PU0        = '5.6116359e-016+dpu0n_18'
+UA         = -1.4231724e-009     LUA        = 1.2263258e-016      WUA        = 5.0256129e-017
+PUA        = 8.5010314e-023      UB         = 2.596331e-018       LUB        = 2.9694512e-025
+WUB        = 7.5816365e-026      PUB        = -1.9115381e-031     UC         = 2.1086049e-010
+LUC        = -4.198412e-017      WUC        = -9.6723469e-017     PUC        = 4.0547054e-023
+VSAT       = '95383.047+dvsatn_18'
+LVSAT      = '-0.0039339871+dlvsatn_18'
+WVSAT      = '-0.0034860295+dwvsatn_18'
+PVSAT      = '2.3879302e-009+dpvsatn_18'
+A0         = '0.73982141+da0n_18'
+LA0        = '-3.1849206e-007+dla0n_18'
+WA0        = '1.5770296e-007+dwa0n_18'
+PA0        = '-8.2276134e-014+dpa0n_18'
+AGS        = '-0.68085015+dagsn_18'
+LAGS       = '6.7627954e-007+dlagsn_18'
+WAGS       = '-9.2716206e-007+dwagsn_18'
+PAGS       = '6.5488985e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0862105          LKETA      = 3.3782933e-008
+WKETA      = 2.4398099e-008      PKETA      = -1.4179529e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.15414038+dpclmn_18'
+LPCLM      = '6.223884e-008+dlpclmn_18'
+WPCLM      = '-2.9108346e-008+dwpclmn_18'
+PPCLM      = '1.9939217e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0056516605        LPDIBLC2   = -2.1588875e-009
+WPDIBLC2   = -3.1370779e-010     PPDIBLC2   = 2.1488984e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00060686363
+LTVOFF     = 5.281993e-010       WTVOFF     = 6.9751629e-010      PTVOFF     = -4.4534898e-016
+KT1        = -0.40438432         LKT1       = 7.9708361e-008      WKT1       = 4.7749053e-008
+PKT1       = -2.8416369e-014     KT1L       = 0                   KT2        = -0.063060512
+LKT2       = 1.0747559e-009      WKT2       = 5.0857827e-010      PKT2       = 3.0326713e-015
+UTE        = -2.3760029          LUTE       = 6.1191079e-007      WUTE       = 9.4373503e-007
+PUTE       = -4.549007e-013      UA1        = -1.6665862e-009     LUA1       = 2.0626574e-015
+WUA1       = 2.9130074e-015      PUA1       = -1.4626072e-021     UB1        = -1.9404259e-019
+LUB1       = -1.4505154e-024     WUB1       = -1.745708e-024      PUB1       = 9.4657552e-031
+UC1        = -7.7186558e-011     LUC1       = 5.2991232e-017      WUC1       = 5.4432153e-017
+PUC1       = -3.1179204e-023     PRT        = 0                   AT         = 24063.347
+LAT        = -0.0091481218       WAT        = 0.0068366768        PAT        = -2.495387e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_18.15 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxln_18'  WMIN       = '6e-007-dxwn_18'    WMAX       = '1e-006-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59972388+dvthn_18'
+LVTH0      = '3.2036506e-009+dlvthn_18'
+WVTH0      = '-7.9946276e-008+dwvthn_18'
+PVTH0      = '1.9586838e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.12001801+dk2n_18'
+LK2        = '1.6336191e-008+dlk2n_18'
+WK2        = '-3.2244022e-009+dwk2n_18'
+PK2        = '5.5218939e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00065351553+dcitn_18'
+LCIT       = '3.1919695e-011+dlcitn_18'
+WCIT       = '1.0179206e-010+dwcitn_18'
+PCIT       = '-2.4939055e-017+dpcitn_18'
+VOFF       = -0.17478981         LVOFF      = 9.307503e-009       WVOFF      = 2.1195059e-008
+PVOFF      = -5.1927895e-015     NFACTOR    = 0.55                ETA0       = '0.93270502+deta0n_18'
+LETA0      = '-9.191543e-008+dleta0n_18'
+WETA0      = '-4.0024266e-007+dweta0n_18'
+PETA0      = '9.8059452e-014+dpeta0n_18'
+ETAB       = -0.085957954        LETAB      = 8.5944877e-010      WETAB      = 3.5325099e-009
+PETAB      = -8.6546491e-016     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.051163941+du0n_18'
+LU0        = '-3.9993655e-009+dlu0n_18'
+WU0        = '2.1845785e-009+dwu0n_18'
+PU0        = '-5.3522172e-016+dpu0n_18'
+UA         = -9.0783387e-010     LUA        = -6.5465993e-017     WUA        = 1.1033872e-015
+PUA        = -2.9938253e-022     UB         = 3.7524286e-018      LUB        = -1.250305e-025
+WUB        = -1.3623403e-024     PUB        = 3.3377338e-031      UC         = 2.1755704e-010
+LUC        = -4.4428363e-017     WUC        = 1.78025e-017        PUC        = -1.2549241e-024
+VSAT       = '92700.208+dvsatn_18'
+LVSAT      = '-0.002954751+dlvsatn_18'
+WVSAT      = '0.0092960785+dwvsatn_18'
+PVSAT      = '-2.2775392e-009+dpvsatn_18'
+A0         = '0.51493963+da0n_18'
+LA0        = '-2.3641021e-007+dla0n_18'
+WA0        = '-2.0595462e-007+dwa0n_18'
+PA0        = '5.0458882e-014+dpa0n_18'
+AGS        = '1.5230769+dagsn_18'
+LAGS       = '-1.2815385e-007+dlagsn_18'
+WAGS       = '2.6372975e-006+dwagsn_18'
+PAGS       = '-6.4613788e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023431248        LKETA      = 1.0868506e-008
+WKETA      = -4.3951859e-008     PKETA      = 1.0768206e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.42236732+dpclmn_18'
+LPCLM      = '-3.5663994e-008+dlpclmn_18'
+WPCLM      = '7.7622256e-008+dwpclmn_18'
+PPCLM      = '-1.9017453e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0023308989       LPDIBLC2   = 7.5474674e-010
+WPDIBLC2   = 8.3655411e-010      PPDIBLC2   = -2.0495576e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0044855794
+LTVOFF     = -8.8753195e-010     WTVOFF     = -1.5896294e-009     PTVOFF     = 3.8945921e-016
+KT1        = -0.026194302        LKT1       = -5.8330996e-008     WKT1       = -9.1566374e-008
+PKT1       = 2.2433762e-014      KT1L       = 0                   KT2        = -0.12748276
+LKT2       = 2.4588876e-008      WKT2       = 2.6819187e-008      PKT2       = -6.5707007e-015
+UTE        = -0.086085625        LUTE       = -2.2390902e-007     WUTE       = -9.2031178e-007
+PUTE       = 2.2547639e-013      UA1        = 7.5813954e-009      LUA1       = -1.3128559e-015
+WUA1       = -3.3279961e-015     PUA1       = 8.1535905e-022      UB1        = -8.544895e-018
+LUB1       = 1.5975458e-024      WUB1       = 2.5782674e-024      PUB1       = -6.3167551e-031
+UC1        = 1.7315074e-010      LUC1       = -3.8381881e-017     WUC1       = -9.4262236e-017
+PUC1       = 2.3094248e-023      PRT        = 0                   AT         = -37750
+LAT        = 0.01341375
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_18.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_18'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+dvthn_18'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_18'
+WK2        = '7.0038392e-009+dwk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_18'
+WCIT       = '-1.734284e-010+dwcitn_18'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_18'  WU0        = '2.47049e-010+dwu0n_18'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_18'   A0         = '0.761323+da0n_18'  WA0        = '2.4976654e-007+dwa0n_18'
+AGS        = '0.3716704+dagsn_18'
+WAGS       = '-1.7787528e-009+dwagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_18'           CGDO       = 'cgon_18'
+CGBO       = 0                   CGDL       = 'cgln_18'           CGSL       = 'cgln_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_18'
+CJD        = 'cjn_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_18'
+CJSWD      = 'cjswn_18'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'
+CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_18'       WVTH0      = '0+dwvthn_18'       PVTH0      = '0+dpvthn_18'
+LU0        = '0+dlu0n_18'        PU0        = '0+dpu0n_18'        LCIT       = '0+dlcitn_18'
+PCIT       = '0+dpcitn_18'       LA0        = '0+dla0n_18'        PA0        = '0+dpa0n_18'
+LAGS       = '0+dlagsn_18'       PAGS       = '0+dpagsn_18'       LVSAT      = '0+dlvsatn_18'
+WVSAT      = '0+dwvsatn_18'      PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'
+WPCLM      = '0+dwpclmn_18'      PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'
+PETA0      = '0+dpeta0n_18'      LK2        = '0+dlk2n_18'        PK2        = '0+dpk2n_18'      )  



.MODEL nch_18.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_18'
+LMAX       = '1e-005-dxln_18'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+dvthn_18'
+LVTH0      = '-2.9748634e-009+dlvthn_18'
+WVTH0      = '4.1584242e-010+dwvthn_18'
+PVTH0      = '-4.1521866e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_18'
+LK2        = '-8.5746992e-009+dlk2n_18'
+WK2        = '7.1926316e-009+dwk2n_18'
+PK2        = '-1.8850927e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_18'
+LCIT       = '2.8299186e-011+dlcitn_18'
+WCIT       = '-1.8936348e-010+dwcitn_18'
+PCIT       = '1.5911179e-016+dpcitn_18'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_18'
+LU0        = '-1.3444366e-009+dlu0n_18'
+WU0        = '5.7424856e-011+dwu0n_18'
+PU0        = '1.8933971e-015+dpu0n_18'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_18'   A0         = '0.77421149+da0n_18'
+LA0        = '-1.2869158e-007+dla0n_18'
+WA0        = '2.8250165e-007+dwa0n_18'
+PA0        = '-3.2686013e-013+dpa0n_18'
+AGS        = '0.35349094+dagsn_18'
+LAGS       = '1.8152193e-007+dlagsn_18'
+WAGS       = '-2.6170911e-009+dwagsn_18'
+PAGS       = '8.3708082e-015+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.18 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_18'
+LMAX       = '1.2e-006-dxln_18'  WMIN       = 4e-07               WMAX       = '6e-007-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+dvthn_18'
+LVTH0      = '4.9190535e-010+dlvthn_18'
+WVTH0      = '6.7271443e-009+dwvthn_18'
+PVTH0      = '-1.1631079e-014+dpvthn_18'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_18'
+LK2        = '-8.0997573e-009+dlk2n_18'
+WK2        = '7.2348917e-009+dwk2n_18'
+PK2        = '-1.935171e-015+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_18'
+LCIT       = '-4.8473782e-011+dlcitn_18'
+WCIT       = '-7.7260869e-011+dwcitn_18'
+PCIT       = '2.6270196e-017+dpcitn_18'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_18'
+LU0        = '4.2425619e-009+dlu0n_18'
+WU0        = '2.2982969e-009+dwu0n_18'
+PU0        = '-7.6203623e-016+dpu0n_18'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_18'   A0         = '1.2504613+da0n_18' LA0        = '-6.9304756e-007+dla0n_18'
+WA0        = '-6.5759503e-008+dwa0n_18'
+PA0        = '8.5829344e-014+dpa0n_18'
+AGS        = '0.85077416+dagsn_18'
+LAGS       = '-4.0775869e-007+dlagsn_18'
+WAGS       = '-7.1367515e-008+dwagsn_18'
+PAGS       = '8.9840061e-014+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_18'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_18'
+CGDO       = 'cgon_18'           CGBO       = 0                   CGDL       = 'cgln_18'
+CGSL       = 'cgln_18'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_18'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_18'            CJD        = 'cjn_18'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_18'      WVSAT      = '0+dwvsatn_18'
+PVSAT      = '0+dpvsatn_18'      LPCLM      = '0+dlpclmn_18'      WPCLM      = '0+dwpclmn_18'
+PPCLM      = '0+dppclmn_18'      LETA0      = '0+dleta0n_18'      PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.19 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_18'
+LMAX       = '7e-007-dxln_18'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58475731+dvthn_18'
+LVTH0      = '-4.0187612e-009+dlvthn_18'
+WVTH0      = '-1.6029234e-008+dwvthn_18'
+PVTH0      = '3.9570398e-015+dpvthn_18'
+K1         = 0.71631             K2         = '-0.059827546+dk2n_18'
+LK2        = '-1.3408216e-009+dlk2n_18'
+WK2        = '4.0040467e-009+dwk2n_18'
+PK2        = '2.7795792e-016+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00035790792+dcitn_18'
+LCIT       = '2.3132079e-010+dlcitn_18'
+WCIT       = '5.2108038e-011+dwcitn_18'
+PCIT       = '-6.2347505e-017+dpcitn_18'
+VOFF       = -0.10692563         LVOFF      = -5.1820416e-009     WVOFF      = -2.7517012e-009
+PVOFF      = -2.6927173e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_18'
+WETA0      = '-1.114191e-007+dweta0n_18'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.023868909+du0n_18'
+LU0        = '4.9987811e-009+dlu0n_18'
+WU0        = '-1.1040002e-010+dwu0n_18'
+PU0        = '8.8792113e-016+dpu0n_18'
+UA         = -1.080391e-009      LUA        = 3.9287131e-017      WUA        = -1.578122e-016
+PUA        = 1.35601e-022        UB         = 2.4785956e-018      LUB        = 1.6217676e-025
+WUB        = 1.4728174e-025      PUB        = -1.0934942e-031     UC         = 6.4726623e-011
+LUC        = 4.0047207e-017      WUC        = -8.0202142e-018     PUC        = -9.2459613e-024
+VSAT       = '84997.656+dvsatn_18'
+LVSAT      = '0.0031800055+dlvsatn_18'
+WVSAT      = '0.0028179027+dwvsatn_18'
+PVSAT      = '-1.9302633e-009+dpvsatn_18'
+A0         = '0.72691983+da0n_18'
+LA0        = '-3.3442168e-007+dla0n_18'
+WA0        = '1.6553422e-007+dwa0n_18'
+PA0        = '-7.2606855e-014+dpa0n_18'
+AGS        = '-3.3021125+dagsn_18'
+LAGS       = '2.4369687e-006+dlagsn_18'
+WAGS       = '6.6394419e-007+dwagsn_18'
+PAGS       = '-4.1384846e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.044413375        LKETA      = 5.5893089e-009
+WKETA      = -9.7275544e-010     PKETA      = 2.9340003e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15038105+dpclmn_18'
+LPCLM      = '6.4813981e-008+dlpclmn_18'
+WPCLM      = '-2.6826433e-008+dwpclmn_18'
+PPCLM      = '1.8376107e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.0084649305        LPDIBLC2   = -4.3647724e-009
+WPDIBLC2   = -2.0213626e-009     PPDIBLC2   = 1.553862e-015       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.005244197
+LTVOFF     = -1.9592623e-009     WTVOFF     = -2.117345e-009      PTVOFF     = 1.0645402e-015
+KT1        = -0.34824522         LKT1       = 2.46259e-008        WKT1       = 1.3672618e-008
+PKT1       = 5.0186846e-015      KT1L       = 0                   KT2        = -0.076610106
+LKT2       = 1.3194132e-008      WKT2       = 8.7331822e-009      PKT2       = -4.3237898e-015
+UTE        = -0.6594357          LUTE       = -2.7902399e-007     WUTE       = -9.8221278e-008
+PUTE       = 8.5896718e-014      UA1        = 3.9503485e-009      LUA1       = -9.1136066e-016
+WUA1       = -4.9647199e-016     PUA1       = 3.4262174e-022      UB1        = -3.5230482e-018
+LUB1       = 3.9527663e-025      WUB1       = 2.7499835e-025      PUB1       = -1.7382021e-031
+UC1        = 3.7157106e-011      LUC1       = -2.5993185e-017     WUC1       = -1.4974451e-017
+PUC1       = 1.6764337e-023      PRT        = 0                   AT         = 44822.861
+LAT        = -0.016725344        WAT        = -0.005764348        PAT        = 2.103987e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LETA0      = '0+dleta0n_18'
+PETA0      = '0+dpeta0n_18'      )



.MODEL nch_18.20 NMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxln_18'  WMIN       = 4e-07               WMAX       = '6e-007-dxwn_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_18'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_18'  XW         = '7e-09+dxwn_18'
+DLC        = 'dlcn_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.47864106+dvthn_18'
+LVTH0      = '3.4713667e-008+dlvthn_18'
+WVTH0      = '-6.4490083e-009+dwvthn_18'
+PVTH0      = '4.6025743e-016+dpvthn_18'
+K1         = 0.71631             K2         = '-0.080568945+dk2n_18'
+LK2        = '6.2297889e-009+dlk2n_18'
+WK2        = '-2.7169986e-008+dwk2n_18'
+PK2        = '1.165648e-014+dpk2n_18'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0010105438+dcitn_18'
+LCIT       = '-6.8913141e-012+dlcitn_18'
+WCIT       = '-1.1492411e-010+dwcitn_18'
+PCIT       = '-1.3807723e-018+dpcitn_18'
+VOFF       = -0.11072071         LVOFF      = -3.7968365e-009     WVOFF      = -1.7694885e-008
+PVOFF      = 2.7615446e-015      NFACTOR    = 0.55                ETA0       = '0.19330368+deta0n_18'
+LETA0      = '1.6583896e-007+dleta0n_18'
+WETA0      = '4.8573951e-008+dweta0n_18'
+PETA0      = '-5.8397463e-014+dpeta0n_18'
+ETAB       = -0.046964442        LETAB      = -1.7188975e-009     WETAB      = -2.0136552e-008
+PETAB      = 6.995913e-016       UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.089825967+du0n_18'
+LU0        = '-1.9075545e-008+dlu0n_18'
+WU0        = '-2.1283271e-008+dwu0n_18'
+PU0        = '8.6160192e-015+dpu0n_18'
+UA         = 3.8588645e-009      LUA        = -1.7635411e-015     WUA        = -1.7899987e-015
+PUA        = 7.3134906e-022      UB         = 1.0327685e-019      LUB        = 1.0291681e-024
+WUB        = 8.5269477e-025      PUB        = -3.6682518e-031     UC         = 4.9553956e-010
+LUC        = -1.1719951e-016     WUC        = -1.5093289e-016     PUC        = 4.2917165e-023
+VSAT       = '120394.58+dvsatn_18'
+LVSAT      = '-0.0097398729+dlvsatn_18'
+WVSAT      = '-0.0075144071+dwvsatn_18'
+PVSAT      = '1.8410297e-009+dpvsatn_18'
+A0         = '0.1352109+da0n_18' LA0        = '-1.1844792e-007+dla0n_18'
+WA0        = '2.4540715e-008+dwa0n_18'
+PA0        = '-2.1144227e-014+dpa0n_18'
+AGS        = '8.2224801+dagsn_18'
+LAGS       = '-1.7695076e-006+dlagsn_18'
+WAGS       = '-1.4292402e-006+dwagsn_18'
+PAGS       = '3.5016386e-013+dpagsn_18'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.13577392         LKETA      = 3.8935906e-008
+WKETA      = 2.4240139e-008      PKETA      = -6.2687063e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.8732156+dpclmn_18'
+LPCLM      = '-1.9902063e-007+dlpclmn_18'
+WPCLM      = '-1.9604265e-007+dwpclmn_18'
+PPCLM      = '8.0140024e-014+dppclmn_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0083658273       LPDIBLC2   = 1.7784542e-009
+WPDIBLC2   = 4.4997556e-009      PPDIBLC2   = -8.263462e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_18'           CGDO       = 'cgon_18'           CGBO       = 0
+CGDL       = 'cgln_18'           CGSL       = 'cgln_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = -0.0015688388
+LTVOFF     = 5.2749572e-010      WTVOFF     = 2.0854024e-009      PTVOFF     = -4.6946258e-016
+KT1        = -0.2979223          LKT1       = 6.258036e-009       WKT1       = 7.3372524e-008
+PKT1       = -1.6771781e-014     KT1L       = 0                   KT2        = -0.073393373
+LKT2       = 1.2020024e-008      WKT2       = -6.0130697e-009     PKT2       = 1.0585921e-015
+UTE        = -2.8086658          LUTE       = 5.05445e-007        WUTE       = 7.3229441e-007
+PUTE       = -2.1724151e-013     UA1        = 7.3240948e-010      LUA1       = 2.6318709e-016
+WUA1       = 8.2933835e-016      PUA1       = -1.4129903e-022     UB1        = -6.4724218e-018
+LUB1       = 1.471798e-024       WUB1       = 1.3202762e-024      PUB1       = -5.5534662e-031
+UC1        = -1.616876e-010      LUC1       = 4.6585134e-017      WUC1       = 1.0898464e-016
+PUC1       = -2.848073e-023      PRT        = 0                   AT         = -33595.208
+LAT        = 0.011897251         WAT        = -0.0025219585       PAT        = 9.2051487e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_18'
+NOIB       = 'noibn_18'
+NOIC       = 'noicn_18'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_18'            CJD        = 'cjn_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_18'          CJSWD      = 'cjswn_18'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_18'         CJSWGD     = 'cjswgn_18'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              

**********************************************************************************************
*                                                                                            *
*                                   1.8V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.MODEL pch_18.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_18'
+LMAX       = 900.001e-6          WMIN       = '1e-005-dxwp_18'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+dvthp_18'
+K1         = 0.72417             K2         = '-0.05886+dk2p_18'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_18'
+VOFF       = '-0.08693+dvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_18'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_18'
+A0         = '1.297+da0p_18'     AGS        = '0.2718+dagsp_18'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_18'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'
+LCIT       = '0+dlcitp_18'       WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'
+LU0        = '0+dlu0p_18'        WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+LA0        = '0+dla0p_18'        WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+LPCLM      = '0+dlpclmp_18'      WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+LVOFF      = '0+dlvoffp_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+LK2        = '0+dlk2p_18'        WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_18'
+LMAX       = '1e-005-dxlp_18'    WMIN       = '1e-005-dxwp_18'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+dvthp_18'
+LVTH0      = '4.3026273e-009+dlvthp_18'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_18'
+LK2        = '-7.5295977e-010+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_18'
+LCIT       = '2.3222086e-010+dlcitp_18'
+VOFF       = '-0.087552125+dvoffp_18'
+LVOFF      = '6.2119181e-009+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_18'
+LU0        = '9.4119972e-011+dlu0p_18'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_18'  A0         = '1.3227199+da0p_18' LA0        = '-2.5681307e-007+dla0p_18'
+AGS        = '0.25480602+dagsp_18'
+LAGS       = '1.6968486e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_18'
+LPCLM      = '2.5143478e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'
+PAGS       = '0+dpagsp_18'       WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'      WK2        = '0+dwk2p_18'
+PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_18'
+LMAX       = '1.2e-006-dxlp_18'  WMIN       = '1e-005-dxwp_18'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+dvthp_18'
+LVTH0      = '1.3149945e-008+dlvthp_18'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_18'
+LK2        = '4.740474e-009+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_18'
+LCIT       = '2.0991209e-010+dlcitp_18'
+VOFF       = '-0.09229456+dvoffp_18'
+LVOFF      = '1.1831704e-008+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.5883+deta0p_18'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_18' LU0        = '-5.032695e-010+dlu0p_18'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_18'  A0         = '1.5469482+da0p_18' LA0        = '-5.2252362e-007+dla0p_18'
+AGS        = '0.2391074+dagsp_18'
+LAGS       = '1.8828773e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_18'
+LPCLM      = '1.2183992e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'
+WA0        = '0+dwa0p_18'        PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'
+PAGS       = '0+dpagsp_18'       WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      WETA0      = '0+dweta0p_18'      PETA0      = '0+dpeta0p_18'
+WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'      WK2        = '0+dwk2p_18'
+PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.4 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_18'
+LMAX       = '7e-007-dxlp_18'    WMIN       = '1e-005-dxwp_18'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63663281+dvthp_18'
+LVTH0      = '3.5159766e-009+dlvthp_18'
+K1         = 0.72417             K2         = '-0.044249688+dk2p_18'
+LK2        = '-8.3914641e-009+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00023317656+dcitp_18'
+LCIT       = '5.6802555e-011+dlcitp_18'
+VOFF       = '-0.11314283+dvoffp_18'
+LVOFF      = '2.6112767e-008+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58864219+deta0p_18'
+LETA0      = '-2.3439844e-010+dleta0p_18'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01097875+du0p_18'
+LU0        = '5.6255625e-010+dlu0p_18'
+UA         = 6.8244047e-010      LUA        = -2.4986092e-016     UB         = 7.2901719e-019
+LUB        = 4.3105873e-025      UC         = 4.7293438e-011      LUC        = 1.5204645e-017
+VSAT       = '102400.16+dvsatp_18'
+LVSAT      = '0.012055893+dlvsatp_18'
+A0         = '0.75410734+da0p_18'
+LA0        = '2.057237e-008+dla0p_18'
+AGS        = '0.16182344+dagsp_18'
+LAGS       = '2.4122725e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.051643594        LKETA      = 5.7427617e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.43326891+dpclmp_18'
+LPCLM      = '-2.1384951e-008+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0057335625
+LTVOFF     = -1.1032353e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21198906         LKT1       = -4.1175992e-008     KT1L       = 0
+KT2        = -0.071645938        LKT2       = 4.9223672e-009      UTE        = -0.43653125
+LUTE       = -3.8597609e-007     UA1        = 3.7772211e-009      LUA1       = -1.3427515e-015
+UB1        = -3.6822922e-018     LUB1       = 6.0779515e-025      UC1        = 1.0510078e-010
+LUC1       = -5.6732235e-017     PRT        = 0                   AT         = 122856.09
+LAT        = -0.040871274
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      WA0        = '0+dwa0p_18'
+PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      WETA0      = '0+dweta0p_18'
+PETA0      = '0+dpeta0p_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.5 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxlp_18'  WMIN       = '1e-005-dxwp_18'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58085833+dvthp_18'
+LVTH0      = '-1.6841708e-008+dlvthp_18'
+K1         = 0.72417             K2         = '-0.028775+dk2p_18' LK2        = '-1.4039725e-008+dlk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00037328333+dcitp_18'
+LCIT       = '5.6635833e-012+dlcitp_18'
+VOFF       = '-0.015000125+dvoffp_18'
+LVOFF      = '-9.7093194e-009+dlvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.62434167+deta0p_18'
+LETA0      = '-1.3264708e-008+dleta0p_18'
+ETAB       = -0.027946667        LETAB      = -2.4562067e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010029167+du0p_18'
+LU0        = '9.0915417e-010+dlu0p_18'
+UA         = 2.7778208e-010      LUA        = -1.0216061e-016     UB         = -3.1541667e-019
+LUB        = 8.1227708e-025      UC         = 1.165125e-010       LUC        = -1.0060313e-017
+VSAT       = '166932.92+dvsatp_18'
+LVSAT      = '-0.011498565+dlvsatp_18'
+A0         = '0.91432958+da0p_18'
+LA0        = '-3.7908748e-008+dla0p_18'
+AGS        = '0.034065+dagsp_18' LAGS       = '2.8785908e-007+dlagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14540458         LKETA      = 3.9965523e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.06344125+dpclmp_18'
+LPCLM      = '1.5991426e-007+dlpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0073827417
+LTVOFF     = -1.7051857e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.4099375          LKT1       = 3.1075188e-008      KT1L       = 0
+KT2        = -0.09246            LKT2       = 1.25195e-008        UTE        = -2.4045833
+LUTE       = 3.3236292e-007      UA1        = -4.5311313e-009     LUA1       = 1.6897972e-015
+UB1        = 3.3788208e-018      LUB1       = -1.9695111e-024     UC1        = -1.4464275e-010
+LUC1       = 3.4424154e-017      PRT        = 0                   AT         = 49426.667
+LAT        = -0.014069533
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_18'       PVTH0      = '0+dpvthp_18'       WCIT       = '0+dwcitp_18'
+PCIT       = '0+dpcitp_18'       WU0        = '0+dwu0p_18'        PU0        = '0+dpu0p_18'
+LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      WA0        = '0+dwa0p_18'
+PA0        = '0+dpa0p_18'        WAGS       = '0+dwagsp_18'       PAGS       = '0+dpagsp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      WETA0      = '0+dweta0p_18'
+PETA0      = '0+dpeta0p_18'      WVOFF      = '0+dwvoffp_18'      PVOFF      = '0+dpvoffp_18'
+WK2        = '0+dwk2p_18'        PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_18'
+LMAX       = 900.001e-6          WMIN       = '1e-006-dxwp_18'    WMAX       = '1e-005-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+dvthp_18'
+WVTH0      = '-1.5339508e-008+dwvthp_18'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_18'
+WK2        = '-1.0189016e-009+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_18'
+WCIT       = '-1.017782e-011+dwcitp_18'
+VOFF       = '-0.085385933+dvoffp_18'
+WVOFF      = '-1.5451475e-008+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_18'
+WU0        = '-2.0154098e-010+dwu0p_18'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.2936433+da0p_18' WA0        = '3.3590163e-008+dwa0p_18'
+AGS        = '0.27102797+dagsp_18'
+WAGS       = '7.7257376e-009+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'
+PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'       PCIT       = '0+dpcitp_18'
+LU0        = '0+dlu0p_18'        PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'
+PA0        = '0+dpa0p_18'        LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'
+LPCLM      = '0+dlpclmp_18'      WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'
+LETA0      = '0+dleta0p_18'      PETA0      = '0+dpeta0p_18'      LVOFF      = '0+dlvoffp_18'
+PVOFF      = '0+dpvoffp_18'      LK2        = '0+dlk2p_18'        PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_18'
+LMAX       = '1e-005-dxlp_18'    WMIN       = '1e-006-dxwp_18'    WMAX       = '1e-005-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+dvthp_18'
+LVTH0      = '2.9336e-009+dlvthp_18'
+WVTH0      = '-1.6711552e-008+dwvthp_18'
+PVTH0      = '1.3699856e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_18'
+LK2        = '-5.724287e-010+dlk2p_18'
+WK2        = '-8.3797279e-010+dwk2p_18'
+PK2        = '-1.8065744e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_18'
+LCIT       = '2.5685734e-010+dlcitp_18'
+WCIT       = '1.4512935e-011+dwcitp_18'
+PCIT       = '-2.4653719e-016+dpcitp_18'
+VOFF       = '-0.085808935+dvoffp_18'
+LVOFF      = '4.2236693e-009+dlvoffp_18'
+WVOFF      = '-1.7444105e-008+dwvoffp_18'
+PVOFF      = '1.9896406e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_18'
+LU0        = '6.5535886e-011+dlu0p_18'
+WU0        = '-2.3018805e-010+dwu0p_18'
+PU0        = '2.8604095e-016+dpu0p_18'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.3194838+da0p_18' LA0        = '-2.5801661e-007+dla0p_18'
+WA0        = '3.2383971e-008+dwa0p_18'
+PA0        = '1.2043829e-014+dpa0p_18'
+AGS        = '0.25390291+dagsp_18'
+LAGS       = '1.7099371e-007+dlagsp_18'
+WAGS       = '9.0374716e-009+dwagsp_18'
+PAGS       = '-1.3097665e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_18'
+LPCLM      = '2.479746e-007+dlpclmp_18'
+WPCLM      = '-3.4678027e-009+dwpclmp_18'
+PPCLM      = '3.462601e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.8 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_18'
+LMAX       = '1.2e-006-dxlp_18'  WMIN       = '1e-006-dxwp_18'    WMAX       = '1e-005-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+dvthp_18'
+LVTH0      = '1.3912858e-008+dlvthp_18'
+WVTH0      = '1.2921016e-009+dwvthp_18'
+PVTH0      = '-7.6344731e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_18'
+LK2        = '5.12738e-009+dlk2p_18'
+WK2        = '9.0480703e-010+dwk2p_18'
+PK2        = '-3.8717685e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_18'
+LCIT       = '2.2066735e-010+dlcitp_18'
+WCIT       = '-1.027101e-010+dwcitp_18'
+PCIT       = '-1.0762789e-016+dpcitp_18'
+VOFF       = '-0.092580246+dvoffp_18'
+LVOFF      = '1.2247673e-008+dlvoffp_18'
+WVOFF      = '2.8588588e-009+dwvoffp_18'
+PVOFF      = '-4.1626056e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.58755034+deta0p_18'
+WETA0      = '7.5018031e-009+dweta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_18'
+LU0        = '-5.6139623e-010+dlu0p_18'
+WU0        = '-4.7966753e-010+dwu0p_18'
+PU0        = '5.8167414e-016+dpu0p_18'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.5239739+da0p_18' LA0        = '-5.0033737e-007+dla0p_18'
+WA0        = '2.2990429e-007+dwa0p_18'
+PA0        = '-2.2201775e-013+dpa0p_18'
+AGS        = '0.23113396+dagsp_18'
+LAGS       = '1.9797491e-007+dlagsp_18'
+WAGS       = '7.9790186e-008+dwagsp_18'
+PAGS       = '-9.6939631e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_18'
+LPCLM      = '1.321774e-007+dlpclmp_18'
+WPCLM      = '1.130496e-007+dwpclmp_18'
+PPCLM      = '-1.0344711e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.9 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_18'
+LMAX       = '7e-007-dxlp_18'    WMIN       = '1e-006-dxwp_18'    WMAX       = '1e-005-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+dvthp_18'
+LVTH0      = '2.5718197e-009+dlvthp_18'
+WVTH0      = '-2.3646075e-008+dwvthp_18'
+PVTH0      = '9.4481782e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.042954661+dk2p_18'
+LK2        = '-8.9535871e-009+dlk2p_18'
+WK2        = '-1.295933e-008+dwk2p_18'
+PK2        = '5.6251653e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitp_18'
+LCIT       = '4.6455294e-011+dlcitp_18'
+WCIT       = '-4.1099174e-010+dwcitp_18'
+PCIT       = '1.0354503e-016+dpcitp_18'
+VOFF       = '-0.11299764+dvoffp_18'
+LVOFF      = '2.6233584e-008+dlvoffp_18'
+WVOFF      = '-1.4529495e-009+dwvoffp_18'
+PVOFF      = '-1.2090169e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.56211263+deta0p_18'
+LETA0      = '1.7424833e-008+dleta0p_18'
+WETA0      = '2.6548126e-007+dweta0p_18'
+PETA0      = '-1.7671593e-013+dpeta0p_18'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0p_18'
+LU0        = '5.5390148e-010+dlu0p_18'
+WU0        = '2.4305632e-010+dwu0p_18'
+PU0        = '8.66083e-017+dpu0p_18'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatp_18'
+LVSAT      = '0.013404813+dlvsatp_18'
+WVSAT      = '0.019706054+dwvsatp_18'
+PVSAT      = '-1.3498647e-008+dpvsatp_18'
+A0         = '0.80514856+da0p_18'
+LA0        = '-7.9420433e-009+dla0p_18'
+WA0        = '-5.107694e-007+dwa0p_18'
+PA0        = '2.8534373e-013+dpa0p_18'
+AGS        = '0.15467694+dagsp_18'
+LAGS       = '2.5034798e-007+dlagsp_18'
+WAGS       = '7.1515032e-008+dwagsp_18'
+PAGS       = '-9.1271151e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmp_18'
+LPCLM      = '-5.4009069e-008+dlpclmp_18'
+WPCLM      = '-5.1456596e-007+dwpclmp_18'
+PPCLM      = '3.2646955e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18' )  



.MODEL pch_18.10 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxlp_18'  WMIN       = '1e-006-dxwp_18'    WMAX       = '1e-005-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.58297816+dvthp_18'
+LVTH0      = '-1.614965e-008+dlvthp_18'
+WVTH0      = '2.1213121e-008+dwvthp_18'
+PVTH0      = '-6.9254286e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.028405534+dk2p_18'
+LK2        = '-1.4264019e-008+dlk2p_18'
+WK2        = '-3.6972506e-009+dwk2p_18'
+PK2        = '2.2445064e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00038792399+dcitp_18'
+LCIT       = '4.9631869e-012+dlcitp_18'
+WCIT       = '-1.465091e-010+dwcitp_18'
+PCIT       = '7.0088675e-018+dpcitp_18'
+VOFF       = '-0.013277558+dvoffp_18'
+LVOFF      = '-1.0164244e-008+dlvoffp_18'
+WVOFF      = '-1.7237725e-008+dwvoffp_18'
+PVOFF      = '4.5524263e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.68737441+deta0p_18'
+LETA0      = '-2.8295717e-008+dleta0p_18'
+WETA0      = '-6.3076868e-007+dweta0p_18'
+PETA0      = '1.504153e-013+dpeta0p_18'
+ETAB       = -0.028279629        LETAB      = -2.5050677e-008     WETAB      = 3.3319576e-009
+PETAB      = 4.8895195e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010241816+du0p_18'
+LU0        = '8.1401698e-010+dlu0p_18'
+WU0        = '-2.1279835e-009+dwu0p_18'
+PU0        = '9.5203784e-016+dpu0p_18'
+UA         = 4.0849535e-010      LUA        = -1.3942504e-016     WUA        = -1.3080476e-015
+PUA        = 3.7290513e-022      UB         = -4.0724388e-019     LUB        = 8.4209396e-025
+WUB        = 9.189149e-025       PUB        = -2.983775e-031      UC         = 1.2103011e-010
+LUC        = -1.089245e-017      WUC        = -4.5207695e-017     PUC        = 8.3272021e-024
+VSAT       = '172184.19+dvsatp_18'
+LVSAT      = '-0.012785126+dlvsatp_18'
+WVSAT      = '-0.052549478+dwvsatp_18'
+PVSAT      = '1.2874622e-008+dpvsatp_18'
+A0         = '0.82373599+da0p_18'
+LA0        = '-1.4726459e-008+dla0p_18'
+WA0        = '9.0657005e-007+dwa0p_18'
+PA0        = '-2.3198517e-013+dpa0p_18'
+AGS        = '0.04584401+dagsp_18'
+LAGS       = '2.9007199e-007+dlagsp_18'
+WAGS       = '-1.1787255e-007+dwagsp_18'
+PAGS       = '-2.2144684e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.14638767         LKETA      = 3.9857962e-008
+WKETA      = 9.8377191e-009      PKETA      = 1.0763618e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.15360943+dpclmp_18'
+LPCLM      = '1.7897004e-007+dlpclmp_18'
+WPCLM      = '9.0231296e-007+dwpclmp_18'
+PPCLM      = '-1.9069126e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00011387158       LPDIBLC2   = -3.7913128e-011
+WPDIBLC2   = -1.0394429e-009     PPDIBLC2   = 3.7939667e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0076679045
+LTVOFF     = -1.7804783e-009     WTVOFF     = -2.8536243e-009     PTVOFF     = 7.5345326e-016
+KT1        = -0.41340326         LKT1       = 3.1625499e-008      WKT1       = 3.4681844e-008
+PKT1       = -5.5069673e-015     KT1L       = 0                   KT2        = -0.092982335
+LKT2       = 1.2636233e-008      WKT2       = 5.2270026e-009      PKT2       = -1.1681446e-015
+UTE        = -2.466649           LUTE       = 3.5179058e-007      WUTE       = 6.2109145e-007
+PUTE       = -1.9441263e-013     UA1        = -4.6320665e-009     LUA1       = 1.7261219e-015
+WUA1       = 1.0100585e-015      PUA1       = -3.6350156e-022     UB1        = 3.0960016e-018
+LUB1       = -1.902715e-024      WUB1       = 2.8301719e-024      PUB1       = -6.6842902e-031
+UC1        = -1.6278309e-010     LUC1       = 3.9547387e-017      WUC1       = 1.8153039e-016
+PUC1       = -5.1268197e-023     PRT        = 0                   AT         = 57017.018
+LAT        = -0.015929169        WAT        = -0.075956643        PAT        = 1.8609378e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18' )  



.MODEL pch_18.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_18'
+LMAX       = 900.001e-6          WMIN       = '6e-007-dxwp_18'    WMAX       = '1e-006-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+dvthp_18'
+WVTH0      = '-9.168735e-010+dwvthp_18'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_18'
+WK2        = '6.3722708e-009+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.1087682+dvoffp_18'
+WVOFF      = '8.0944649e-009+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_18'
+WU0        = '-4.7371798e-010+dwu0p_18'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.1646275+da0p_18' WA0        = '1.6350911e-007+dwa0p_18'
+AGS        = '0.26549775+dagsp_18'
+WAGS       = '1.3294666e-008+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LU0        = '0+dlu0p_18'
+PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'
+PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'
+PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'       LPCLM      = '0+dlpclmp_18'
+WPCLM      = '0+dwpclmp_18'      PPCLM      = '0+dppclmp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'      LVOFF      = '0+dlvoffp_18'      PVOFF      = '0+dpvoffp_18'
+LK2        = '0+dlk2p_18'        PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_18'
+LMAX       = '1e-005-dxlp_18'    WMIN       = '6e-007-dxwp_18'    WMAX       = '1e-006-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+dvthp_18'
+LVTH0      = '2.5515924e-008+dlvthp_18'
+WVTH0      = '-1.1460919e-011+dwvthp_18'
+PVTH0      = '-9.0405446e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_18'
+LK2        = '-7.6918538e-009+dlk2p_18'
+WK2        = '5.8351965e-009+dwk2p_18'
+PK2        = '5.3626867e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_18'
+LCIT       = '3.029537e-011+dlcitp_18'
+WCIT       = '1.8416915e-012+dwcitp_18'
+PCIT       = '-1.838929e-017+dpcitp_18'
+VOFF       = '-0.11242711+dvoffp_18'
+LVOFF      = '3.6534227e-008+dlvoffp_18'
+WVOFF      = '9.3603963e-009+dwvoffp_18'
+PVOFF      = '-1.2640325e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_18'
+LU0        = '-2.8293136e-010+dlu0p_18'
+WU0        = '-5.3750841e-010+dwu0p_18'
+PU0        = '6.3694746e-016+dpu0p_18'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_18'  A0         = '1.1751703+da0p_18' LA0        = '-1.0526983e-007+dla0p_18'
+WA0        = '1.7770762e-007+dwa0p_18'
+PA0        = '-1.4177218e-013+dpa0p_18'
+AGS        = '0.25327996+dagsp_18'
+LAGS       = '1.2199468e-007+dlagsp_18'
+WAGS       = '9.6647844e-009+dwagsp_18'
+PAGS       = '3.6244365e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_18'
+LPCLM      = '2.6195605e-007+dlpclmp_18'
+WPCLM      = '-2.0577559e-009+dwpclmp_18'
+PPCLM      = '2.0546692e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.13 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_18'
+LMAX       = '1.2e-006-dxlp_18'  WMIN       = '6e-007-dxwp_18'    WMAX       = '1e-006-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+dvthp_18'
+LVTH0      = '-7.9573402e-009+dlvthp_18'
+WVTH0      = '-1.9783074e-008+dwvthp_18'
+PVTH0      = '1.4388817e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_18'
+LK2        = '1.295992e-008+dlk2p_18'
+WK2        = '2.0283992e-008+dwk2p_18'
+PK2        = '-1.1759136e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_18'
+LCIT       = '2.8646031e-010+dlcitp_18'
+WCIT       = '1.3305867e-010+dwcitp_18'
+PCIT       = '-1.7388141e-016+dpcitp_18'
+VOFF       = '-0.073036514+dvoffp_18'
+LVOFF      = '-1.0143628e-008+dlvoffp_18'
+WVOFF      = '-1.6821679e-008+dwvoffp_18'
+PVOFF      = '1.8385435e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.66465325+deta0p_18'
+WETA0      = '-7.0140823e-008+dweta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_18'
+LU0        = '-1.6343677e-009+dlu0p_18'
+WU0        = '-1.4026636e-009+dwu0p_18'
+PU0        = '1.6621564e-015+dpu0p_18'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_18'  A0         = '2.1264181+da0p_18' LA0        = '-1.2324985e-006+dla0p_18'
+WA0        = '-3.7675707e-007+dwa0p_18'
+PA0        = '5.1526849e-013+dpa0p_18'
+AGS        = '0.24152159+dagsp_18'
+LAGS       = '1.3592834e-007+dlagsp_18'
+WAGS       = '6.9329848e-008+dwagsp_18'
+PAGS       = '-3.4458735e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_18'
+LPCLM      = '-2.323312e-007+dlpclmp_18'
+WPCLM      = '-2.0717704e-007+dwpclmp_18'
+PPCLM      = '2.6361305e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.14 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_18'
+LMAX       = '7e-007-dxlp_18'    WMIN       = '6e-007-dxwp_18'    WMAX       = '1e-006-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.69392971+dvthp_18'
+LVTH0      = '3.5904762e-008+dlvthp_18'
+WVTH0      = '3.6431396e-008+dwvthp_18'
+PVTH0      = '-2.4118095e-014+dpvthp_18'
+K1         = 0.72417             K2         = '-0.056981+dk2p_18' LK2        = '-4.6954695e-009+dlk2p_18'
+WK2        = '1.1651934e-009+dwk2p_18'
+PK2        = '1.3372409e-015+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.6053841e-005+dcitp_18'
+LCIT       = '1.9867537e-010+dlcitp_18'
+WCIT       = '-4.8168809e-011+dwcitp_18'
+PCIT       = '-4.9740586e-017+dpcitp_18'
+VOFF       = '-0.1585485+dvoffp_18'
+LVOFF      = '4.8432079e-008+dlvoffp_18'
+WVOFF      = '4.4416767e-008+dwvoffp_18'
+PVOFF      = '-2.3562901e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.98182545+deta0p_18'
+LETA0      = '-2.1726296e-007+dleta0p_18'
+WETA0      = '-1.5716955e-007+dweta0p_18'
+PETA0      = '5.9614677e-014+dpeta0p_18'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013590704+du0p_18'
+LU0        = '-1.6970388e-009+dlu0p_18'
+WU0        = '-2.41164e-009+dwu0p_18'
+PU0        = '2.3533052e-015+dpu0p_18'
+UA         = 1.3822488e-009      LUA        = -9.5202533e-016     WUA        = -1.1215123e-015
+PUA        = 7.6520029e-022      UB         = 4.2523021e-019      LUB        = 7.7972679e-025
+WUB        = 6.4094711e-025      PUB        = -4.4009553e-031     UC         = 2.9244119e-011
+LUC        = 1.5938293e-017      WUC        = -1.2591491e-017     PUC        = 3.1401282e-024
+VSAT       = '120000+dvsatp_18'  A0         = '-0.72475126+da0p_18'
+LA0        = '7.2055254e-007+dla0p_18'
+WA0        = '1.0298397e-006+dwa0p_18'
+PA0        = '-4.4825031e-013+dpa0p_18'
+AGS        = '0.47827608+dagsp_18'
+LAGS       = '-2.6248484e-008+dlagsp_18'
+WAGS       = '-2.5434931e-007+dwagsp_18'
+PAGS       = '1.8726148e-013+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.016556925         LKETA      = -2.0853335e-008
+WKETA      = -2.6719222e-008     PKETA      = 1.5664822e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.500404+dpclmp_18'
+LPCLM      = '4.7410182e-007+dlpclmp_18'
+WPCLM      = '4.774232e-007+dwpclmp_18'
+PPCLM      = '-2.0533812e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00085814023       LPDIBLC2   = -5.8097606e-010
+WPDIBLC2   = -8.5407722e-010     PPDIBLC2   = 5.8504289e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.002836154
+LTVOFF     = -7.3891568e-010     WTVOFF     = 1.7227432e-009      PTVOFF     = -1.8984045e-016
+KT1        = -0.20204794         LKT1       = -5.5033628e-008     WKT1       = -1.696216e-008
+PKT1       = 2.292413e-014       KT1L       = 0                   KT2        = -0.070902278
+LKT2       = 3.3231253e-009      WKT2       = -2.3320582e-009     PKT2       = 2.8535766e-015
+UTE        = -0.91151582         LUTE       = -1.4167628e-007     WUTE       = 1.0302888e-007
+PUTE       = -7.9995661e-014     UA1        = 2.6228981e-009      LUA1       = -9.8687309e-016
+WUA1       = 2.0802761e-016      PUA1       = -5.3728429e-024     UB1        = -4.4978011e-018
+LUB1       = 1.5789137e-024      WUB1       = 9.670389e-025       PUB1       = -7.0324544e-031
+UC1        = 6.8312674e-011      LUC1       = -2.7390649e-017     WUC1       = -1.0991737e-017
+PUC1       = 1.4685771e-024      PRT        = 0                   AT         = -159164.07
+LAT        = 0.079546663         WAT        = 0.093253222         PAT        = -5.9837948e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'     )



.MODEL pch_18.15 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxlp_18'  WMIN       = '6e-007-dxwp_18'    WMAX       = '1e-006-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.5067577+dvthp_18'
+LVTH0      = '-3.2413023e-008+dlvthp_18'
+WVTH0      = '-5.5540886e-008+dwvthp_18'
+PVTH0      = '9.4517879e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.0081827813+dk2p_18'
+LK2        = '-2.2506819e-008+dlk2p_18'
+WK2        = '-2.4061562e-008+dwk2p_18'
+PK2        = '1.0545007e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070009869+dcitp_18'
+LCIT       = '-8.82703e-011+dlcitp_18'
+WCIT       = '-4.6086901e-010+dwcitp_18'
+PCIT       = '1.0089499e-016+dpcitp_18'
+VOFF       = '0.017174816+dvoffp_18'
+LVOFF      = '-1.5706929e-008+dlvoffp_18'
+WVOFF      = '-4.7903266e-008+dwvoffp_18'
+PVOFF      = '1.0133911e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.01118986+deta0p_18'
+LETA0      = '1.3701903e-007+dleta0p_18'
+WETA0      = '5.014916e-008+dweta0p_18'
+PETA0      = '-1.6056652e-014+dpeta0p_18'
+ETAB       = -0.029119931        LETAB      = -1.7096607e-008     WETAB      = 4.1781416e-009
+PETAB      = -3.1202288e-015     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0030644114+du0p_18'
+LU0        = '2.145058e-009+dlu0p_18'
+WU0        = '5.0996631e-009+dwu0p_18'
+PU0        = '-3.8832044e-016+dpu0p_18'
+UA         = -2.5009653e-009     LUA        = 4.6534778e-016      WUA        = 1.6217792e-015
+PUA        = -2.3610111e-022     UB         = 1.0680103e-018      LUB        = 5.4511207e-025
+WUB        = -5.6666603e-025     PUB        = 6.8326177e-034      UC         = 1.2523854e-010
+LUC        = -1.9099671e-017     WUC        = -4.9445587e-017     PUC        = 1.6591873e-023
+VSAT       = '120000+dvsatp_18'  A0         = '2.493794+da0p_18'  LA0        = '-4.5421648e-007+dla0p_18'
+WA0        = '-7.7517834e-007+dwa0p_18'
+PA0        = '2.1058128e-013+dpa0p_18'
+AGS        = '-0.56632958+dagsp_18'
+LAGS       = '3.5503258e-007+dlagsp_18'
+WAGS       = '4.9858626e-007+dwagsp_18'
+PAGS       = '-8.7559996e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1798753          LKETA      = 5.0844428e-008
+WKETA      = 4.3559769e-008      PKETA      = -9.9870096e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.81372593+dpclmp_18'
+LPCLM      = '-5.5556027e-009+dlpclmp_18'
+WPCLM      = '-7.1793742e-008+dwpclmp_18'
+PPCLM      = '-4.873934e-015+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0043099773       LPDIBLC2   = 1.3053868e-009
+WPDIBLC2   = 3.4153729e-009      PPDIBLC2   = -9.733064e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0025684765
+LTVOFF     = -6.4121339e-010     WTVOFF     = 2.2814996e-009      PTVOFF     = -3.9378654e-016
+KT1        = -0.49760571         LKT1       = 5.2844959e-008      WKT1       = 1.1947371e-007
+PKT1       = -2.6874963e-014     KT1L       = 0                   KT2        = -0.088716077
+LKT2       = 9.825162e-009       WKT2       = 9.3088129e-010      PKT2       = 1.6626037e-015
+UTE        = -1.6168123          LUTE       = 1.1575694e-007      WUTE       = -2.3469415e-007
+PUTE       = 4.3273246e-014      UA1        = -3.673827e-009      LUA1       = 1.3114316e-015
+WUA1       = 4.511145e-017       PUA1       = 5.4091557e-023      UB1        = 7.5163146e-018
+LUB1       = -2.8062385e-024     WUB1       = -1.6210833e-024     PUB1       = 2.4141916e-031
+UC1        = 4.9793198e-012      LUC1       = -4.2739747e-018     WUC1       = 1.259364e-017
+PUC1       = -7.1400855e-024     PRT        = 0                   AT         = 195098.16
+LAT        = -0.049759049        WAT        = -0.21500435         PAT        = 5.2676066e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'    ) 



.MODEL pch_18.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_18'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+dvthp_18'
+WVTH0      = '-1.235245e-008+dwvthp_18'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_18'
+WK2        = '1.0981328e-008+dwk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.082272655+dvoffp_18'
+WVOFF      = '-7.9883294e-009+dwvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_18'
+WU0        = '5.0645045e-010+dwu0p_18'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_18'  A0         = '1.517435+da0p_18'  WA0        = '-5.0645045e-008+dwa0p_18'
+AGS        = '0.2802775+dagsp_18'
+WAGS       = '4.3233575e-009+dwagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_18'
+WPCLM      = '-1.235245e-008+dwpclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'
+CGBO       = 0                   CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_18'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_18'
+CJD        = 'cjp_18'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_18'
+CJSWD      = 'cjswp_18'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'
+CJSWGD     = 'cjswgp_18'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_18'       PVTH0      = '0+dpvthp_18'       LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LU0        = '0+dlu0p_18'
+PU0        = '0+dpu0p_18'        LNFACTOR   = '0+dlnfactorp_18'   WNFACTOR   = '0+dwnfactorp_18'
+PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'      WVSAT      = '0+dwvsatp_18'
+PVSAT      = '0+dpvsatp_18'      LA0        = '0+dla0p_18'        PA0        = '0+dpa0p_18'
+LAGS       = '0+dlagsp_18'       PAGS       = '0+dpagsp_18'       LPCLM      = '0+dlpclmp_18'
+PPCLM      = '0+dppclmp_18'      LETA0      = '0+dleta0p_18'      PETA0      = '0+dpeta0p_18'
+LVOFF      = '0+dlvoffp_18'      PVOFF      = '0+dpvoffp_18'      LK2        = '0+dlk2p_18'
+PK2        = '0+dpk2p_18'      )  



.MODEL pch_18.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_18'
+LMAX       = '1e-005-dxlp_18'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+dvthp_18'
+LVTH0      = '1.3084693e-008+dlvthp_18'
+WVTH0      = '-1.2202747e-008+dwvthp_18'
+PVTH0      = '-1.4947872e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_18'
+LK2        = '1.8463044e-008+dlk2p_18'
+WK2        = '1.2034241e-008+dwk2p_18'
+PK2        = '-1.0513336e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.08299213+dvoffp_18'
+LVOFF      = '7.1839623e-009+dlvoffp_18'
+WVOFF      = '-8.5066354e-009+dwvoffp_18'
+PVOFF      = '5.1752854e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_18'
+LU0        = '8.2354975e-011+dlu0p_18'
+WU0        = '4.6486621e-010+dwu0p_18'
+PU0        = '4.1521866e-016+dpu0p_18'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.5401338+da0p_18' LA0        = '-2.2664761e-007+dla0p_18'
+WA0        = '-4.3825229e-008+dwa0p_18'
+PA0        = '-6.809586e-014+dpa0p_18'
+AGS        = '0.25532754+dagsp_18'
+LAGS       = '2.4912535e-007+dlagsp_18'
+WAGS       = '8.4219004e-009+dwagsp_18'
+PAGS       = '-4.0923951e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_18'
+LPCLM      = '4.3261573e-007+dlpclmp_18'
+WPCLM      = '-4.0356016e-009+dwpclmp_18'
+PPCLM      = '-8.3043732e-014+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.18 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_18'
+LMAX       = '1.2e-006-dxlp_18'  WMIN       = 4e-07               WMAX       = '6e-007-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+dvthp_18'
+LVTH0      = '1.3104488e-008+dlvthp_18'
+WVTH0      = '-1.4817999e-008+dwvthp_18'
+PVTH0      = '1.6042868e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_18'
+LK2        = '-2.3393752e-008+dlk2p_18'
+WK2        = '-5.536121e-009+dwk2p_18'
+PK2        = '1.0307543e-014+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_18'
+VOFF       = '-0.10923032+dvoffp_18'
+LVOFF      = '3.8276211e-008+dlvoffp_18'
+WVOFF      = '5.1479577e-009+dwvoffp_18'
+PVOFF      = '-1.1005407e-014+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.4866255+deta0p_18'
+WETA0      = '3.7922022e-008+dweta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_18'
+LU0        = '1.9298762e-009+dlu0p_18'
+WU0        = '1.2383331e-009+dwu0p_18'
+PU0        = '-5.0133962e-016+dpu0p_18'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_18'  A0         = '1.8892247+da0p_18' LA0        = '-6.4032034e-007+dla0p_18'
+WA0        = '-2.3278069e-007+dwa0p_18'
+PA0        = '1.5581636e-013+dpa0p_18'
+AGS        = '0.50163406+dagsp_18'
+LAGS       = '-4.2747874e-008+dlagsp_18'
+WAGS       = '-8.855842e-008+dwagsp_18'
+PAGS       = '7.3997729e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_18'
+LPCLM      = '3.733935e-009+dlpclmp_18'
+WPCLM      = '-1.7565184e-007+dwpclmp_18'
+PPCLM      = '1.2032151e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_18'
+WCIT       = '0+dwcitp_18'       PCIT       = '0+dpcitp_18'       LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'      LETA0      = '0+dleta0p_18'
+PETA0      = '0+dpeta0p_18'   )   



.MODEL pch_18.19 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_18'
+LMAX       = '7e-007-dxlp_18'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63703339+dvthp_18'
+LVTH0      = '1.238952e-008+dlvthp_18'
+WVTH0      = '1.8953291e-009+dwvthp_18'
+PVTH0      = '-9.8443429e-015+dpvthp_18'
+K1         = 0.72417             K2         = '-0.070684483+dk2p_18'
+LK2        = '-2.5242368e-009+dlk2p_18'
+WK2        = '9.4832075e-009+dwk2p_18'
+PK2        = '1.9302633e-017+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.6494656e-005+dcitp_18'
+LCIT       = '-3.527384e-011+dlcitp_18'
+WCIT       = '-1.3469575e-010+dwcitp_18'
+PCIT       = '9.2266587e-017+dpcitp_18'
+VOFF       = '-0.077660392+dvoffp_18'
+LVOFF      = '1.6650813e-008+dlvoffp_18'
+WVOFF      = '-4.682312e-009+dwvoffp_18'
+PVOFF      = '-4.2716727e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.47744455+deta0p_18'
+LETA0      = '6.2889491e-009+dleta0p_18'
+WETA0      = '1.4898966e-007+dweta0p_18'
+PETA0      = '-7.6081329e-014+dpeta0p_18'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0078316258+du0p_18'
+LU0        = '2.8318066e-009+dlu0p_18'
+WU0        = '1.0841205e-009+dwu0p_18'
+PU0        = '-3.9570398e-016+dpu0p_18'
+UA         = -9.9789287e-010     LUA        = 6.6674929e-016      WUA        = 3.232337e-016
+PUA        = -2.1739591e-022     UB         = 1.890541e-018       LUB        = -1.2815735e-025
+WUB        = -2.4849655e-025     PUB        = 1.1099014e-031      UC         = -3.3997165e-011
+LUC        = 4.3196624e-017      WUC        = 2.5795969e-017      PUC        = -1.3405679e-023
+VSAT       = '120000+dvsatp_18'  A0         = '-0.15470335+da0p_18'
+LA0        = '7.5977038e-007+dla0p_18'
+WA0        = '6.8382063e-007+dwa0p_18'
+PA0        = '-4.7205555e-013+dpa0p_18'
+AGS        = '0.10781513+dagsp_18'
+LAGS       = '2.2701809e-007+dlagsp_18'
+WAGS       = '-2.9479508e-008+dwagsp_18'
+PAGS       = '3.3528674e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.030607227        LKETA      = 4.9059202e-009
+WKETA      = 1.9094186e-009      PKETA      = 2.895395e-017       DWG        = 0
+DWB        = 0                   PCLM       = '-0.090043958+dpclmp_18'
+LPCLM      = '3.9349411e-007+dlpclmp_18'
+WPCLM      = '2.2833465e-007+dwpclmp_18'
+PPCLM      = '-1.5640924e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = 0.00061167969       LPDIBLC2   = -4.1215059e-010
+WPDIBLC2   = -7.0447566e-010     PPDIBLC2   = 4.8256583e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0082648363
+LTVOFF     = -2.2727898e-009     WTVOFF     = -1.5724669e-009     PTVOFF     = 7.4122112e-016
+KT1        = -0.19230335         LKT1       = -5.3678414e-008     WKT1       = -2.2877123e-008
+PKT1       = 2.2101515e-014      KT1L       = 0                   KT2        = -0.076128019
+LKT2       = 3.9538328e-009      WKT2       = 8.399666e-010       PKT2       = 2.4707371e-015
+UTE        = 0.58430742          LUTE       = -1.0382562e-006     WUTE       = -8.0493582e-007
+PUTE       = 4.6422833e-013      UA1        = 7.9580462e-009      LUA1       = -3.9680757e-015
+WUA1       = -3.0304073e-015     PUA1       = 1.8042171e-021      UB1        = -6.5789123e-018
+LUB1       = 2.5859383e-024      WUB1       = 2.2302735e-024      PUB1       = -1.3145093e-030
+UC1        = 1.2043095e-010      LUC1       = -5.3909297e-017     WUC1       = -4.2627533e-017
+PUC1       = 1.7565396e-023      PRT        = 0                   AT         = 121939.93
+LAT        = -0.073315847        WAT        = -0.077376905        PAT        = 3.2949595e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'     )



.MODEL pch_18.20 PMOS	(	LEVEL      = 54                  LMIN       = 2.6e-07
+LMAX       = '3.8e-007-dxlp_18'  WMIN       = 4e-07               WMAX       = '6e-007-dxwp_18'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_18'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_18'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_18'  XW         = '7e-09+dxwp_18'
+DLC        = 'dlcp_18'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.55860975+dvthp_18'
+LVTH0      = '-1.6235109e-008+dlvthp_18'
+WVTH0      = '-2.406669e-008+dwvthp_18'
+PVTH0      = '-3.6820595e-016+dpvthp_18'
+K1         = 0.72417             K2         = '-0.065028842+dk2p_18'
+LK2        = '-4.5885458e-009+dlk2p_18'
+WK2        = '1.0443997e-008+dwk2p_18'
+PK2        = '-3.3138535e-016+dpk2p_18'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0013748333+dcitp_18'
+LCIT       = '4.8716087e-010+dlcitp_18'
+WCIT       = '7.9861472e-010+dwcitp_18'
+PCIT       = '-2.4839173e-016+dpcitp_18'
+VOFF       = '-0.050350218+dvoffp_18'
+LVOFF      = '6.6825998e-009+dlvoffp_18'
+WVOFF      = '-6.9155706e-009+dwvoffp_18'
+PVOFF      = '-3.4565333e-015+dpvoffp_18'
+NFACTOR    = '0.63002+dnfactorp_18'
+ETA0       = '0.33230907+deta0p_18'
+LETA0      = '5.9263401e-008+dleta0p_18'
+WETA0      = '-1.447702e-007+dweta0p_18'
+PETA0      = '3.1141018e-014+dpeta0p_18'
+ETAB       = -0.031595123        LETAB      = -3.3565264e-008     WETAB      = 5.6805829e-009
+PETAB      = 6.8762461e-015      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.022434483+du0p_18'
+LU0        = '-2.4982364e-009+dlu0p_18'
+WU0        = '-6.6579706e-009+dwu0p_18'
+PU0        = '2.4301593e-015+dpu0p_18'
+UA         = 3.3367804e-009      LUA        = -9.1540647e-016     WUA        = -1.9217324e-015
+PUA        = 6.0201672e-022      UB         = -1.2534117e-018     LUB        = 1.0193854e-024
+WUB        = 8.4243709e-025      PUB        = -2.8720064e-031     UC         = 6.9600342e-011
+LUC        = 5.383534e-018       WUC        = -1.56732e-017       PUC        = 1.730568e-024
+VSAT       = '120000+dvsatp_18'  A0         = '3.7602519+da0p_18' LA0        = '-6.6918829e-007+dla0p_18'
+WA0        = '-1.5439183e-006+dwa0p_18'
+PA0        = '3.4106917e-013+dpa0p_18'
+AGS        = '-0.27523098+dagsp_18'
+LAGS       = '3.6682992e-007+dlagsp_18'
+WAGS       = '3.2188941e-007+dwagsp_18'
+PAGS       = '-9.472098e-014+dpagsp_18'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1057803          LKETA      = 3.2344091e-008
+WKETA      = -1.4158996e-009     PKETA      = 1.2426951e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.6985672+dpclmp_18'
+LPCLM      = '-2.5934897e-007+dlpclmp_18'
+WPCLM      = '-6.0889241e-007+dwpclmp_18'
+PPCLM      = '1.4917864e-013+dppclmp_18'
+PDIBLC1    = 0                   PDIBLC2    = -0.0001163125       LPDIBLC2   = -1.4643344e-010
+WPDIBLC2   = 8.6981835e-010      PPDIBLC2   = -9.2051487e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_18'           CGDO       = 'Cgop_18'           CGBO       = 0
+CGDL       = 'Cglp_18'           CGSL       = 'Cglp_18'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_18'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00038167646
+LTVOFF     = 8.8318738e-010      WTVOFF     = 4.0722425e-009      PTVOFF     = -1.3190978e-015
+KT1        = -0.55188969         LKT1       = 7.7570598e-008      WKT1       = 1.5242409e-007
+PKT1       = -4.1883427e-014     KT1L       = 0                   KT2        = -0.084262275
+LKT2       = 6.9228364e-009      WKT2       = -1.7725766e-009     PKT2       = 3.4243153e-015
+UTE        = -4.413831           LUTE       = 7.8606438e-007      WUTE       = 1.4630962e-006
+PUTE       = -3.6360337e-013     UA1        = -1.2992661e-008     LUA1       = 3.6789326e-015
+WUA1       = 5.7016439e-015      PUA1       = -1.3829815e-021     UB1        = 1.0411731e-017
+LUB1       = -3.6156465e-024     WUB1       = -3.378601e-024      PUB1       = 7.3272984e-031
+UC1        = -8.9982585e-011     LUC1       = 2.2891645e-017      WUC1       = 7.0235516e-017
+PUC1       = -2.3629617e-023     PRT        = 0                   AT         = -223731.43
+LAT        = 0.052854199         WAT        = 0.039225205         PAT        = -9.6101752e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_18'
+NOIB       = 'noibp_18'
+NOIC       = 'noicp_18'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_18'            CJD        = 'cjp_18'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_18'          CJSWD      = 'cjswp_18'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_18'         CJSWGD     = 'cjswgp_18'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_18'
+WNFACTOR   = '0+dwnfactorp_18'   PNFACTOR   = '0+dpnfactorp_18'   LVSAT      = '0+dlvsatp_18'
+WVSAT      = '0+dwvsatp_18'      PVSAT      = '0+dpvsatp_18'    ) 



.ENDL MOS_18








***************************************************************
*                                                             *
*                     2.5V IO DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_25
**********************************************************************************************
*                                                                                            *
*                                   2.5V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

.MODEL nch_25.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_25'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-dxwn_25'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+dvthn_25'
+K1         = 0.71631             K2         = '-0.048803+dk2n_25' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_25'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_25'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_25'   A0         = '1.1773+da0n_25'    AGS        = '0.3986+dagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       WVTH0      = '0+dwvthn_25'
+PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       LA0        = '0+dla0n_25'        WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'       WAGS       = '0+dwagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      WETA0      = '0+dweta0n_25'
+PETA0      = '0+dpeta0n_25'      LK2        = '0+dlk2n_25'        WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'  )        



.MODEL nch_25.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_25'
+LMAX       = '1e-005-dxln_25'    WMIN       = '1e-005-dxwn_25'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+dvthn_25'
+LVTH0      = '1.4790281e-008+dlvthn_25'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_25'
+LK2        = '-1.2153578e-008+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_25'
+LCIT       = '7.5887589e-010+dlcitn_25'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_25'
+LU0        = '2.6891421e-011+dlu0n_25'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.2321467+da0n_25' LA0        = '-5.4764378e-007+dla0n_25'
+AGS        = '0.38027424+dagsn_25'
+LAGS       = '1.8298267e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'        WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'        PA0        = '0+dpa0n_25'
+WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'
+WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'  )        



.MODEL nch_25.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_25'
+LMAX       = '1.2e-006-dxln_25'  WMIN       = '1e-005-dxwn_25'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+dvthn_25'
+LVTH0      = '3.2469e-010+dlvthn_25'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_25'
+LK2        = '-6.7649162e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_25'
+LCIT       = '5.941827e-011+dlcitn_25'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_25'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_25'
+A0         = '1.3065331+da0n_25' LA0        = '-6.3579172e-007+dla0n_25'
+AGS        = '0.9247153+dagsn_25'
+LAGS       = '-4.6217998e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'
+WCIT       = '0+dwcitn_25'       PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'
+LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'
+LETA0      = '0+dleta0n_25'      WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'
+WK2        = '0+dwk2n_25'        PK2        = '0+dpk2n_25'        )



.MODEL nch_25.4 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_25'
+LMAX       = '7e-007-dxln_25'    WMIN       = '1e-005-dxwn_25'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59985+dvthn_25'
+LVTH0      = '-2.50025e-009+dlvthn_25'
+K1         = 0.71631             K2         = '-0.060148641+dk2n_25'
+LK2        = '-1.2743462e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00063515313+dcitn_25'
+LCIT       = '1.1360511e-010+dlcitn_25'
+VOFF       = -0.14569953         LVOFF      = 1.2165279e-008      NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_25'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_25'   UA         = -6.221e-010
+LUA        = -1.650165e-016      UB         = 2.8987125e-018      LUB        = 6.9381938e-026
+UC         = 1.8519984e-010      LUC        = -1.7056393e-017     VSAT       = '89640+dvsatn_25'
+A0         = '1.1521358+da0n_25' LA0        = '-5.3002956e-007+dla0n_25'
+AGS        = '-2.0187031+dagsn_25'
+LAGS       = '1.5540616e-006+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.053365313        LKETA      = 1.4642089e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.268725+dpclmn_25'
+LPCLM      = '-1.6251625e-008+dlpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00478125          LPDIBLC2   = -1.5626563e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0011922813        LTVOFF     = 1.4845234e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29436875         LKT1       = 5.9380938e-009
+KT1L       = 0                   KT2        = -0.055789375        LKT2       = -2.7815281e-009
+UTE        = -1.3999688          LUTE       = 1.1094859e-007      UA1        = 2.5822766e-009
+LUA1       = 2.1799055e-017      UB1        = -3.2810594e-018     LUB1       = 9.4228172e-026
+UC1        = -4.6245625e-011     LUC1       = 4.3535603e-017      PRT        = 0
+AT         = 14157.766           LAT        = -0.0055325845
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'
+WCIT       = '0+dwcitn_25'       PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'
+PA0        = '0+dpa0n_25'        WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'  )        



.MODEL nch_25.5 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxln_25'  WMIN       = '1e-005-dxwn_25'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5771+dvthn_25'
+LVTH0      = '5.8035e-009+dlvthn_25'
+K1         = 0.71631             K2         = '-0.086854+dk2n_25' LK2        = '8.47311e-009+dlk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00159936+dcitn_25'
+LCIT       = '-2.383304e-010+dlcitn_25'
+VOFF       = -0.094509           LVOFF      = -6.519265e-009      NFACTOR    = 0.55
+ETA0       = '0.3724505+deta0n_25'
+LETA0      = '5.5936068e-008+dleta0n_25'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03148355+du0n_25'
+LU0        = '2.6048043e-009+dlu0n_25'
+UA         = -1.138065e-009      LUA        = 2.3310725e-017      UB         = 2.59272e-018
+LUB        = 1.810692e-025       UC         = 2.917725e-010       LUC        = -5.5955413e-017
+VSAT       = '106268.75+dvsatn_25'
+LVSAT      = '-0.0060694938+dlvsatn_25'
+A0         = '1.025+da0n_25'     LA0        = '-4.83625e-007+dla0n_25'
+AGS        = '4.79731+dagsn_25'  LAGS       = '-9.3378315e-007+dlagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.09492035         LKETA      = 2.9809678e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2926495+dpclmn_25'
+LPCLM      = '-2.4984068e-008+dlpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000394            LPDIBLC2   = 3.869e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0027173           LTVOFF     = -4.081795e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.375355           LKT1       = 3.5498075e-008
+KT1L       = 0                   KT2        = -0.164534           LKT2       = 3.691026e-008
+UTE        = -1.3504             LUTE       = 9.2856e-008         UA1        = 3.44283e-009
+LUA1       = -2.9230295e-016     UB1        = -4.38606e-018       LUB1       = 4.975534e-025
+UC1        = 1.41029e-010        LUC1       = -2.4819635e-017     PRT        = 0
+AT         = -32800              LAT        = 0.011607
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+WU0        = '0+dwu0n_25'        PU0        = '0+dpu0n_25'        WCIT       = '0+dwcitn_25'
+PCIT       = '0+dpcitn_25'       WA0        = '0+dwa0n_25'        PA0        = '0+dpa0n_25'
+WAGS       = '0+dwagsn_25'       PAGS       = '0+dpagsn_25'       WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'
+WETA0      = '0+dweta0n_25'      PETA0      = '0+dpeta0n_25'      WK2        = '0+dwk2n_25'
+PK2        = '0+dpk2n_25'  )        



.MODEL nch_25.6 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_25'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-dxwn_25'    WMAX       = '1e-005-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+dvthn_25'
+WVTH0      = '-1.9034426e-009+dwvthn_25'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_25'
+WK2        = '8.915949e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_25'
+WCIT       = '3.148518e-010+dwcitn_25'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_25'
+WU0        = '-6.4829015e-009+dwu0n_25'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.1644663+da0n_25' WA0        = '1.2842639e-007+dwa0n_25'
+AGS        = '0.4003119+dagsn_25'
+WAGS       = '-1.7130983e-008+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       PCIT       = '0+dpcitn_25'
+LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'
+LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25'        )



.MODEL nch_25.7 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_25'
+LMAX       = '1e-005-dxln_25'    WMIN       = '1e-006-dxwn_25'    WMAX       = '1e-005-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+dvthn_25'
+LVTH0      = '1.6445149e-008+dlvthn_25'
+WVTH0      = '-2.4492827e-010+dwvthn_25'
+PVTH0      = '-1.6560265e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_25'
+LK2        = '-1.2004489e-008+dlk2n_25'
+WK2        = '9.0653661e-009+dwk2n_25'
+PK2        = '-1.4919294e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_25'
+LCIT       = '8.1447946e-010+dlcitn_25'
+WCIT       = '3.7057788e-010+dwcitn_25'
+PCIT       = '-5.5642492e-016+dpcitn_25'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_25'
+LU0        = '1.1847165e-011+dlu0n_25'
+WU0        = '-6.4979789e-009+dwu0n_25'
+PU0        = '1.5054787e-016+dpu0n_25'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_25'   A0         = '1.2162348+da0n_25' LA0        = '-5.1690836e-007+dla0n_25'
+WA0        = '1.5922953e-007+dwa0n_25'
+PA0        = '-3.0756929e-013+dpa0n_25'
+AGS        = '0.38190343+dagsn_25'
+LAGS       = '1.838086e-007+dlagsn_25'
+WAGS       = '-1.6303234e-008+dwagsn_25'
+PAGS       = '-8.2650779e-015+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      )



.MODEL nch_25.8 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_25'
+LMAX       = '1.2e-006-dxln_25'  WMIN       = '1e-006-dxwn_25'    WMAX       = '1e-005-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+dvthn_25'
+LVTH0      = '1.7778581e-009+dlvthn_25'
+WVTH0      = '-1.9482295e-009+dwvthn_25'
+PVTH0      = '-1.4541854e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_25'
+LK2        = '-6.2688409e-009+dlk2n_25'
+WK2        = '1.1995574e-008+dwk2n_25'
+PK2        = '-4.9642252e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_25'
+LCIT       = '6.6229996e-011+dlcitn_25'
+WCIT       = '-4.145586e-011+dwcitn_25'
+PCIT       = '-6.8164938e-017+dpcitn_25'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_25'
+WETA0      = '-2.2393442e-008+dweta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_25'
+LU0        = '-3.4512743e-011+dlu0n_25'
+WU0        = '-6.662385e-009+dwu0n_25'
+PU0        = '3.4536902e-016+dpu0n_25'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.3201499+da0n_25' LA0        = '-6.4004769e-007+dla0n_25'
+WA0        = '-1.3626309e-007+dwa0n_25'
+PA0        = '4.2589454e-014+dpa0n_25'
+AGS        = '0.94327311+dagsn_25'
+LAGS       = '-4.8141448e-007+dlagsn_25'
+WAGS       = '-1.8570803e-007+dwagsn_25'
+PAGS       = '1.9247961e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      )



.MODEL nch_25.9 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_25'
+LMAX       = '7e-007-dxln_25'    WMIN       = '1e-006-dxwn_25'    WMAX       = '1e-005-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.6034551+dvthn_25'
+LVTH0      = '-3.3832116e-009+dlvthn_25'
+WVTH0      = '-3.6076185e-008+dwvthn_25'
+PVTH0      = '8.8357962e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.061138887+dk2n_25'
+LK2        = '-9.2107413e-010+dlk2n_25'
+WK2        = '9.9093956e-009+dwk2n_25'
+PK2        = '-3.5351933e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00064333098+dcitn_25'
+LCIT       = '1.1765275e-010+dlcitn_25'
+WCIT       = '-8.1835785e-011+dwcitn_25'
+PCIT       = '-4.050469e-017+dpcitn_25'
+VOFF       = -0.14920249         LVOFF      = 1.4669043e-008      WVOFF      = 3.5054135e-008
+PVOFF      = -2.5055169e-014     NFACTOR    = 0.55                ETA0       = '0.53361829+deta0n_25'
+LETA0      = '-3.8911504e-009+dleta0n_25'
+WETA0      = '-7.9238321e-008+dweta0n_25'
+PETA0      = '3.8938742e-014+dpeta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.04023085+du0n_25'
+LU0        = '-6.818911e-010+dlu0n_25'
+WU0        = '-1.6119779e-008+dwu0n_25'
+PU0        = '6.8236842e-015+dpu0n_25'
+UA         = -5.3805291e-010     LUA        = -2.0664683e-016     WUA        = -8.410592e-016
+PUA        = 4.1659467e-022      UB         = 2.9241216e-018      LUB        = 6.5159458e-026
+WUB        = -2.5426879e-025     PUB        = 4.2254352e-032      UC         = 1.9307576e-010
+LUC        = -1.8772486e-017     WUC        = -7.8814245e-017     PUC        = 1.7172939e-023
+VSAT       = '89384.754+dvsatn_25'
+LVSAT      = '0.00017484387+dlvsatn_25'
+WVSAT      = '0.002554252+dwvsatn_25'
+PVSAT      = '-1.7496626e-009+dpvsatn_25'
+A0         = '1.1807466+da0n_25' LA0        = '-5.4455646e-007+dla0n_25'
+WA0        = '-2.8630873e-007+dwa0n_25'
+PA0        = '1.4537072e-013+dpa0n_25'
+AGS        = '-2.065376+dagsn_25'
+LAGS       = '1.5795102e-006+dlagsn_25'
+WAGS       = '4.6705548e-007+dwagsn_25'
+PAGS       = '-2.546634e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.052401201        LKETA      = 1.4075945e-008
+WKETA      = -9.6478647e-009     PKETA      = 5.6654076e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.28478001+dpclmn_25'
+LPCLM      = '-2.7249305e-008+dlpclmn_25'
+WPCLM      = '-1.6066245e-007+dwpclmn_25'
+PPCLM      = '1.1005378e-013+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0047187172        LPDIBLC2   = -1.5198213e-009
+WPDIBLC2   = 6.257662e-010       PPDIBLC2   = -4.2864985e-016     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0011802812
+LTVOFF     = 1.554461e-010       WTVOFF     = 1.2008483e-010      PTVOFF     = -6.9986505e-017
+KT1        = -0.28736468         LKT1       = 8.413949e-010       WKT1       = -7.0089725e-008
+PKT1       = 5.1002665e-014      KT1L       = 0                   KT2        = -0.055032324
+LKT2       = -3.5499669e-009     WKT2       = -7.5758065e-009     PKT2       = 7.6897672e-015
+UTE        = -1.3956208          LUTE       = 1.0544101e-007      WUTE       = -4.3509758e-008
+PUTE       = 5.5114373e-014      UA1        = 2.7340096e-009      LUA1       = -4.4038405e-017
+WUA1       = -1.5183926e-015     PUA1       = 6.5883546e-022      UB1        = -3.4324947e-018
+LUB1       = 1.6189275e-025      WUB1       = 1.5154132e-024      PUB1       = -6.7711944e-031
+UC1        = -4.8831695e-011     LUC1       = 4.5941979e-017      WUC1       = 2.5878807e-017
+PUC1       = -2.4080607e-023     PRT        = 0                   AT         = 12289.81
+LAT        = -0.0048507808       WAT        = 0.018692629         PAT        = -6.8228094e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_25.10 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxln_25'  WMIN       = '1e-006-dxwn_25'    WMAX       = '1e-005-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58142898+dvthn_25'
+LVTH0      = '4.65632e-009+dlvthn_25'
+WVTH0      = '-4.3320114e-008+dwvthn_25'
+PVTH0      = '1.147983e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.083157012+dk2n_25'
+LK2        = '7.1155415e-009+dlk2n_25'
+WK2        = '-3.6995758e-008+dwk2n_25'
+PK2        = '1.3585188e-014+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0016696855+dcitn_25'
+LCIT       = '-2.5696666e-010+dlcitn_25'
+WCIT       = '-7.0374751e-010+dwcitn_25'
+PCIT       = '1.8649309e-016+dpcitn_25'
+VOFF       = -0.088709128        LVOFF      = -7.4110351e-009     WVOFF      = -5.8039324e-008
+PVOFF      = 8.9239435e-015      NFACTOR    = 0.55                ETA0       = '0.33936373+deta0n_25'
+LETA0      = '6.7011766e-008+dleta0n_25'
+WETA0      = '3.3109936e-007+dweta0n_25'
+PETA0      = '-1.1083451e-013+dpeta0n_25'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.030175686+du0n_25'
+LU0        = '2.9882438e-009+dlu0n_25'
+WU0        = '1.3087791e-008+dwu0n_25'
+PU0        = '-3.8370791e-015+dpu0n_25'
+UA         = -1.228116e-009      LUA        = 4.5226192e-017      WUA        = 9.0114011e-016
+PUA        = -2.1930808e-022     UB         = 2.570298e-018       LUB        = 1.9430506e-025
+WUB        = 2.2437669e-025      PUB        = -1.3245125e-031     UC         = 3.0335865e-010
+LUC        = -5.9025742e-017     WUC        = -1.1594261e-016     PUC        = 3.0724791e-023
+VSAT       = '106277.56+dvsatn_25'
+LVSAT      = '-0.005991031+dlvsatn_25'
+WVSAT      = '-8.8174179e-005+dwvsatn_25'
+PVSAT      = '-7.8517707e-010+dpvsatn_25'
+A0         = '0.95451+da0n_25'   LA0        = '-4.6198009e-007+dla0n_25'
+WA0        = '7.0539343e-007+dwa0n_25'
+PA0        = '-2.1660057e-013+dpa0n_25'
+AGS        = '4.7706648+dagsn_25'
+LAGS       = '-9.1564472e-007+dlagsn_25'
+WAGS       = '2.6663872e-007+dwagsn_25'
+PAGS       = '-1.8151128e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.098453102        LKETA      = 3.0884888e-008
+WKETA      = 3.5352247e-008      PKETA      = -1.0759633e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.26948005+dpclmn_25'
+LPCLM      = '-2.1664821e-008+dlpclmn_25'
+WPCLM      = '2.3185666e-007+dwpclmn_25'
+PPCLM      = '-3.3215697e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00043695717       LPDIBLC2   = 4.3021146e-011
+WPDIBLC2   = -4.2987236e-010     PPDIBLC2   = -4.3341774e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0027434372
+LTVOFF     = -4.1510587e-010     WTVOFF     = -2.6155541e-010     PTVOFF     = 6.9312182e-017
+KT1        = -0.39571654         LKT1       = 4.0389824e-008      WKT1       = 2.0375793e-007
+PKT1       = -4.8951729e-014     KT1L       = 0                   KT2        = -0.17137354
+LKT2       = 3.8914578e-008      WKT2       = 6.8443317e-008      PKT2       = -2.0057213e-014
+UTE        = -1.3896059          LUTE       = 1.0324556e-007      WUTE       = 3.9233311e-007
+PUTE       = -1.0396827e-013     UA1        = 3.3235151e-009      LUA1       = -2.5920789e-016
+WUA1       = 1.1939848e-015      PUA1       = -3.3118227e-022     UB1        = -4.1858919e-018
+LUB1       = 4.3688273e-025      WUB1       = -2.0030822e-024     PUB1       = 6.071314e-031
+UC1        = 1.5268558e-010      LUC1       = -2.7611828e-017     WUC1       = -1.1664744e-016
+PUC1       = 2.7941474e-023      PRT        = 0                   AT         = -33393.011
+LAT        = 0.011823449         WAT        = 0.0059342622        PAT        = -2.1660057e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_25.11 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_25'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-dxwn_25'    WMAX       = '1e-006-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+dvthn_25'
+WVTH0      = '-3.8203063e-009+dwvthn_25'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_25'
+WK2        = '2.9951201e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_25'
+WCIT       = '-9.5507656e-011+dwcitn_25'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_25'
+WU0        = '-4.3551491e-009+dwu0n_25'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_25'   A0         = '1.472886+da0n_25'  WA0        = '-1.821522e-007+dwa0n_25'
+AGS        = '0.4053948+dagsn_25'
+WAGS       = '-2.2249464e-008+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       PVTH0      = '0+dpvthn_25'       LU0        = '0+dlu0n_25'
+PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'       PCIT       = '0+dpcitn_25'
+LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'        LAGS       = '0+dlagsn_25'
+PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'
+LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25'        )



.MODEL nch_25.12 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_25'
+LMAX       = '1e-005-dxln_25'    WMIN       = '6e-007-dxwn_25'    WMAX       = '1e-006-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+dvthn_25'
+LVTH0      = '1.4894822e-008+dlvthn_25'
+WVTH0      = '-2.3181445e-009+dwvthn_25'
+PVTH0      = '-1.4999085e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_25'
+LK2        = '-1.6226287e-008+dlk2n_25'
+WK2        = '2.7187635e-009+dwk2n_25'
+PK2        = '2.7594208e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_25'
+LCIT       = '2.1866624e-010+dlcitn_25'
+WCIT       = '-9.9870099e-011+dwcitn_25'
+PCIT       = '4.3558988e-017+dpcitn_25'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_25'
+LU0        = '-2.2871153e-009+dlu0n_25'
+WU0        = '-4.6020798e-009+dwu0n_25'
+PU0        = '2.4656031e-015+dpu0n_25'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.5788249+da0n_25' LA0        = '-1.0578002e-006+dla0n_25'
+WA0        = '-2.0589871e-007+dwa0n_25'
+PA0        = '2.3710883e-013+dpa0n_25'
+AGS        = '0.39080402+dagsn_25'
+LAGS       = '1.4568891e-007+dlagsn_25'
+WAGS       = '-2.5266134e-008+dwagsn_25'
+PAGS       = '3.0121451e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25'      )



.MODEL nch_25.13 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_25'
+LMAX       = '1.2e-006-dxln_25'  WMIN       = '6e-007-dxwn_25'    WMAX       = '1e-006-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+dvthn_25'
+LVTH0      = '-3.5476441e-009+dlvthn_25'
+WVTH0      = '-7.2295476e-009+dwvthn_25'
+PVTH0      = '-9.1790728e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_25'
+LK2        = '-1.1063061e-008+dlk2n_25'
+WK2        = '5.1625327e-009+dwk2n_25'
+PK2        = '-1.3644568e-016+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_25'
+LCIT       = '4.2051414e-012+dlcitn_25'
+WCIT       = '-5.8296345e-011+dwcitn_25'
+PCIT       = '-5.7059101e-018+dpcitn_25'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_25'
+WETA0      = '-6.3569896e-008+dweta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_25'
+LU0        = '-3.7564604e-009+dlu0n_25'
+WU0        = '-5.975723e-009+dwu0n_25'
+PU0        = '4.0933703e-015+dpu0n_25'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.2496434+da0n_25' LA0        = '-6.6772012e-007+dla0n_25'
+WA0        = '-6.5263056e-008+dwa0n_25'
+PA0        = '7.0455585e-014+dpa0n_25'
+AGS        = '0.79778898+dagsn_25'
+LAGS       = '-3.3658827e-007+dlagsn_25'
+WAGS       = '-3.9205511e-008+dwagsn_25'
+PAGS       = '4.6639613e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25' )      



.MODEL nch_25.14 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_25'
+LMAX       = '7e-007-dxln_25'    WMIN       = '6e-007-dxwn_25'    WMAX       = '1e-006-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58171161+dvthn_25'
+LVTH0      = '9.7781262e-009+dlvthn_25'
+WVTH0      = '-1.4180499e-008+dwvthn_25'
+PVTH0      = '-4.4176708e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.048365474+dk2n_25'
+LK2        = '-9.8169855e-009+dlk2n_25'
+WK2        = '-2.953431e-009+dwk2n_25'
+PK2        = '5.4229894e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074160091+dcitn_25'
+LCIT       = '-2.3146846e-013+dlcitn_25'
+WCIT       = '-1.8079361e-010+dwcitn_25'
+PCIT       = '7.8204713e-017+dpcitn_25'
+VOFF       = -0.11884305         LVOFF      = -1.1113064e-008     WVOFF      = 4.4821743e-009
+PVOFF      = 9.0741347e-016      NFACTOR    = 0.55                ETA0       = '0.44101649+deta0n_25'
+LETA0      = '8.7550883e-008+dleta0n_25'
+WETA0      = '1.401169e-008+dweta0n_25'
+PETA0      = '-5.3143386e-014+dpeta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.025036647+du0n_25'
+LU0        = '5.5370966e-009+dlu0n_25'
+WU0        = '-8.1921692e-010+dwu0n_25'
+PU0        = '5.6116359e-016+dpu0n_25'
+UA         = -1.4231724e-009     LUA        = 1.2263258e-016      WUA        = 5.0256129e-017
+PUA        = 8.5010314e-023      UB         = 2.596331e-018       LUB        = 2.9694512e-025
+WUB        = 7.5816365e-026      PUB        = -1.9115381e-031     UC         = 2.1086049e-010
+LUC        = -4.198412e-017      WUC        = -9.6723469e-017     PUC        = 4.0547054e-023
+VSAT       = '95383.047+dvsatn_25'
+LVSAT      = '-0.0039339871+dlvsatn_25'
+WVSAT      = '-0.0034860295+dwvsatn_25'
+PVSAT      = '2.3879302e-009+dpvsatn_25'
+A0         = '0.73982141+da0n_25'
+LA0        = '-3.1849206e-007+dla0n_25'
+WA0        = '1.5770296e-007+dwa0n_25'
+PA0        = '-8.2276134e-014+dpa0n_25'
+AGS        = '-0.68085015+dagsn_25'
+LAGS       = '6.7627954e-007+dlagsn_25'
+WAGS       = '-9.2716206e-007+dwagsn_25'
+PAGS       = '6.5488985e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0862105          LKETA      = 3.3782933e-008
+WKETA      = 2.4398099e-008      PKETA      = -1.4179529e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.15414038+dpclmn_25'
+LPCLM      = '6.223884e-008+dlpclmn_25'
+WPCLM      = '-2.9108346e-008+dwpclmn_25'
+PPCLM      = '1.9939217e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0056516605        LPDIBLC2   = -2.1588875e-009
+WPDIBLC2   = -3.1370779e-010     PPDIBLC2   = 2.1488984e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00060686363
+LTVOFF     = 5.281993e-010       WTVOFF     = 6.9751629e-010      PTVOFF     = -4.4534898e-016
+KT1        = -0.40438432         LKT1       = 7.9708361e-008      WKT1       = 4.7749053e-008
+PKT1       = -2.8416369e-014     KT1L       = 0                   KT2        = -0.063060512
+LKT2       = 1.0747559e-009      WKT2       = 5.0857827e-010      PKT2       = 3.0326713e-015
+UTE        = -2.3760029          LUTE       = 6.1191079e-007      WUTE       = 9.4373503e-007
+PUTE       = -4.549007e-013      UA1        = -1.6665862e-009     LUA1       = 2.0626574e-015
+WUA1       = 2.9130074e-015      PUA1       = -1.4626072e-021     UB1        = -1.9404259e-019
+LUB1       = -1.4505154e-024     WUB1       = -1.745708e-024      PUB1       = 9.4657552e-031
+UC1        = -7.7186558e-011     LUC1       = 5.2991232e-017      WUC1       = 5.4432153e-017
+PUC1       = -3.1179204e-023     PRT        = 0                   AT         = 24063.347
+LAT        = -0.0091481218       WAT        = 0.0068366768        PAT        = -2.495387e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_25.15 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxln_25'  WMIN       = '6e-007-dxwn_25'    WMAX       = '1e-006-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.64131926+dvthn_25'
+LVTH0      = '-1.1978666e-008+dlvthn_25'
+WVTH0      = '-1.0362963e-007+dwvthn_25'
+PVTH0      = '2.8231261e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.11830162+dk2n_25'
+LK2        = '1.5709707e-008+dlk2n_25'
+WK2        = '-1.6051399e-009+dwk2n_25'
+PK2        = '4.9308632e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00095730149+dcitn_25'
+LCIT       = '-7.8962179e-011+dlcitn_25'
+WCIT       = '1.3623212e-011+dwcitn_25'
+PCIT       = '7.2425748e-018+dpcitn_25'
+VOFF       = -0.20469819         LVOFF      = 2.0224061e-008      WVOFF      = 5.8761659e-008
+PVOFF      = -1.8904598e-014     NFACTOR    = 0.55                ETA0       = '0.86582953+deta0n_25'
+LETA0      = '-6.7505877e-008+dleta0n_25'
+WETA0      = '-1.9905171e-007+dweta0n_25'
+PETA0      = '2.4624754e-014+dpeta0n_25'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.064737693+du0n_25'
+LU0        = '-8.9537849e-009+dlu0n_25'
+WU0        = '-2.1716149e-008+dwu0n_25'
+PU0        = '8.1885437e-015+dpu0n_25'
+UA         = 7.4278131e-010      LUA        = -6.6794053e-016     WUA        = -1.0835535e-015
+PUA        = 4.9885082e-022      UB         = 3.1458048e-018      LUB        = 9.6387188e-026
+WUB        = -3.5515859e-025     PUB        = -3.3847952e-032     UC         = 1.3273841e-010
+LUC        = -1.3469561e-017     WUC        = 5.5871979e-017      PUC        = -1.5150284e-023
+VSAT       = '95257.02+dvsatn_25'
+LVSAT      = '-0.0038879871+dlvsatn_25'
+WVSAT      = '0.011009511+dwvsatn_25'
+PVSAT      = '-2.9029422e-009+dpvsatn_25'
+A0         = '2.7047026+da0n_25' LA0        = '-1.0356737e-006+dla0n_25'
+WA0        = '-1.0570505e-006+dwa0n_25'
+PA0        = '3.6110887e-013+dpa0n_25'
+AGS        = '3.7151795+dagsn_25'
+LAGS       = '-9.2827128e-007+dlagsn_25'
+WAGS       = '1.3295124e-006+dwagsn_25'
+PAGS       = '-1.6879634e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.012901258        LKETA      = 7.0250594e-009
+WKETA      = -5.0798459e-008     PKETA      = 1.3267215e-014      DWG        = 0
+DWB        = 0                   PCLM       = '1.0606992+dpclmn_25'
+LPCLM      = '-2.6865514e-007+dlpclmn_25'
+WPCLM      = '-5.6490105e-007+dwpclmn_25'
+PPCLM      = '2.1550355e-013+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.00025049996      LPDIBLC2   = -4.5988869e-012
+WPDIBLC2   = 2.6239697e-010      PPDIBLC2   = 4.6115986e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0035286809
+LTVOFF     = -5.3826399e-010     WTVOFF     = -1.0522957e-009     PTVOFF     = 1.9333241e-016
+KT1        = -0.1329178          LKT1       = -1.9376919e-008     WKT1       = -6.08804e-008
+PKT1       = 1.1233381e-014      KT1L       = 0                   KT2        = -0.14192015
+LKT2       = 2.9858524e-008      WKT2       = 3.8783749e-008      PKT2       = -1.0937766e-014
+UTE        = 0.09669725          LUTE       = -2.9062477e-007     WUTE       = -1.1043741e-006
+PUTE       = 2.9265915e-013      UA1        = 1.0517893e-008      LUA1       = -2.3846775e-015
+WUA1       = -6.0507539e-015     PUA1       = 1.8091656e-021      UB1        = -1.2366845e-017
+LUB1       = 2.9925574e-024      WUB1       = 6.2351371e-024      PUB1       = -1.966433e-030
+UC1        = 1.2356123e-010      LUC1       = -2.0281709e-017     WUC1       = -8.7319212e-017
+PUC1       = 2.0560044e-023      PRT        = 0                   AT         = -31521.375
+LAT        = 0.011140302         WAT        = 0.0040495246        PAT        = -1.4780765e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              



.MODEL nch_25.16 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_25'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+dvthn_25'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_25'
+WK2        = '7.0038392e-009+dwk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_25'
+WCIT       = '-1.734284e-010+dwcitn_25'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_25'  WU0        = '2.47049e-010+dwu0n_25'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_25'   A0         = '0.761323+da0n_25'  WA0        = '2.4976654e-007+dwa0n_25'
+AGS        = '0.3716704+dagsn_25'
+WAGS       = '-1.7787528e-009+dwagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_25'           CGDO       = 'cgon_25'
+CGBO       = 0                   CGDL       = 'cgln_25'           CGSL       = 'cgln_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_25'       WVTH0      = '0+dwvthn_25'       PVTH0      = '0+dpvthn_25'
+LU0        = '0+dlu0n_25'        PU0        = '0+dpu0n_25'        LCIT       = '0+dlcitn_25'
+PCIT       = '0+dpcitn_25'       LA0        = '0+dla0n_25'        PA0        = '0+dpa0n_25'
+LAGS       = '0+dlagsn_25'       PAGS       = '0+dpagsn_25'       LVSAT      = '0+dlvsatn_25'
+WVSAT      = '0+dwvsatn_25'      PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'
+WPCLM      = '0+dwpclmn_25'      PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'
+PETA0      = '0+dpeta0n_25'      LK2        = '0+dlk2n_25'        PK2        = '0+dpk2n_25' )        



.MODEL nch_25.17 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_25'
+LMAX       = '1e-005-dxln_25'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+dvthn_25'
+LVTH0      = '-2.9748634e-009+dlvthn_25'
+WVTH0      = '4.1584242e-010+dwvthn_25'
+PVTH0      = '-4.1521866e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_25'
+LK2        = '-8.5746992e-009+dlk2n_25'
+WK2        = '7.1926316e-009+dwk2n_25'
+PK2        = '-1.8850927e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_25'
+LCIT       = '2.8299186e-011+dlcitn_25'
+WCIT       = '-1.8936348e-010+dwcitn_25'
+PCIT       = '1.5911179e-016+dpcitn_25'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_25'
+LU0        = '-1.3444366e-009+dlu0n_25'
+WU0        = '5.7424856e-011+dwu0n_25'
+PU0        = '1.8933971e-015+dpu0n_25'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_25'   A0         = '0.77421149+da0n_25'
+LA0        = '-1.2869158e-007+dla0n_25'
+WA0        = '2.8250165e-007+dwa0n_25'
+PA0        = '-3.2686013e-013+dpa0n_25'
+AGS        = '0.35349094+dagsn_25'
+LAGS       = '1.8152193e-007+dlagsn_25'
+WAGS       = '-2.6170911e-009+dwagsn_25'
+PAGS       = '8.3708082e-015+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25' )      



.MODEL nch_25.18 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_25'
+LMAX       = '1.2e-006-dxln_25'  WMIN       = 4e-07               WMAX       = '6e-007-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+dvthn_25'
+LVTH0      = '4.9190535e-010+dlvthn_25'
+WVTH0      = '6.7271443e-009+dwvthn_25'
+PVTH0      = '-1.1631079e-014+dpvthn_25'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_25'
+LK2        = '-8.0997573e-009+dlk2n_25'
+WK2        = '7.2348917e-009+dwk2n_25'
+PK2        = '-1.935171e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_25'
+LCIT       = '-4.8473782e-011+dlcitn_25'
+WCIT       = '-7.7260869e-011+dwcitn_25'
+PCIT       = '2.6270196e-017+dpcitn_25'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_25'
+LU0        = '4.2425619e-009+dlu0n_25'
+WU0        = '2.2982969e-009+dwu0n_25'
+PU0        = '-7.6203623e-016+dpu0n_25'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_25'   A0         = '1.2504613+da0n_25' LA0        = '-6.9304756e-007+dla0n_25'
+WA0        = '-6.5759503e-008+dwa0n_25'
+PA0        = '8.5829344e-014+dpa0n_25'
+AGS        = '0.85077416+dagsn_25'
+LAGS       = '-4.0775869e-007+dlagsn_25'
+WAGS       = '-7.1367515e-008+dwagsn_25'
+PAGS       = '8.9840061e-014+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_25'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_25'
+CGDO       = 'cgon_25'           CGBO       = 0                   CGDL       = 'cgln_25'
+CGSL       = 'cgln_25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_25'            CJD        = 'cjn_25'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_25'      WVSAT      = '0+dwvsatn_25'
+PVSAT      = '0+dpvsatn_25'      LPCLM      = '0+dlpclmn_25'      WPCLM      = '0+dwpclmn_25'
+PPCLM      = '0+dppclmn_25'      LETA0      = '0+dleta0n_25'      PETA0      = '0+dpeta0n_25' )      



.MODEL nch_25.19 NMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxln_25'
+LMAX       = '7e-007-dxln_25'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58475731+dvthn_25'
+LVTH0      = '-4.0187612e-009+dlvthn_25'
+WVTH0      = '-1.6029234e-008+dwvthn_25'
+PVTH0      = '3.9570398e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.059827546+dk2n_25'
+LK2        = '-1.3408216e-009+dlk2n_25'
+WK2        = '4.0040467e-009+dwk2n_25'
+PK2        = '2.7795792e-016+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00035790792+dcitn_25'
+LCIT       = '2.3132079e-010+dlcitn_25'
+WCIT       = '5.2108038e-011+dwcitn_25'
+PCIT       = '-6.2347505e-017+dpcitn_25'
+VOFF       = -0.10692563         LVOFF      = -5.1820416e-009     WVOFF      = -2.7517012e-009
+PVOFF      = -2.6927173e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_25'
+WETA0      = '-1.114191e-007+dweta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.023868909+du0n_25'
+LU0        = '4.9987811e-009+dlu0n_25'
+WU0        = '-1.1040002e-010+dwu0n_25'
+PU0        = '8.8792113e-016+dpu0n_25'
+UA         = -1.080391e-009      LUA        = 3.9287131e-017      WUA        = -1.578122e-016
+PUA        = 1.35601e-022        UB         = 2.4785956e-018      LUB        = 1.6217676e-025
+WUB        = 1.4728174e-025      PUB        = -1.0934942e-031     UC         = 6.4726623e-011
+LUC        = 4.0047207e-017      WUC        = -8.0202142e-018     PUC        = -9.2459613e-024
+VSAT       = '84997.656+dvsatn_25'
+LVSAT      = '0.0031800055+dlvsatn_25'
+WVSAT      = '0.0028179027+dwvsatn_25'
+PVSAT      = '-1.9302633e-009+dpvsatn_25'
+A0         = '0.72691983+da0n_25'
+LA0        = '-3.3442168e-007+dla0n_25'
+WA0        = '1.6553422e-007+dwa0n_25'
+PA0        = '-7.2606855e-014+dpa0n_25'
+AGS        = '-3.3021125+dagsn_25'
+LAGS       = '2.4369687e-006+dlagsn_25'
+WAGS       = '6.6394419e-007+dwagsn_25'
+PAGS       = '-4.1384846e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.044413375        LKETA      = 5.5893089e-009
+WKETA      = -9.7275544e-010     PKETA      = 2.9340003e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15038105+dpclmn_25'
+LPCLM      = '6.4813981e-008+dlpclmn_25'
+WPCLM      = '-2.6826433e-008+dwpclmn_25'
+PPCLM      = '1.8376107e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0084649305        LPDIBLC2   = -4.3647724e-009
+WPDIBLC2   = -2.0213626e-009     PPDIBLC2   = 1.553862e-015       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.005244197
+LTVOFF     = -1.9592623e-009     WTVOFF     = -2.117345e-009      PTVOFF     = 1.0645402e-015
+KT1        = -0.34824522         LKT1       = 2.46259e-008        WKT1       = 1.3672618e-008
+PKT1       = 5.0186846e-015      KT1L       = 0                   KT2        = -0.076610106
+LKT2       = 1.3194132e-008      WKT2       = 8.7331822e-009      PKT2       = -4.3237898e-015
+UTE        = -0.6594357          LUTE       = -2.7902399e-007     WUTE       = -9.8221278e-008
+PUTE       = 8.5896718e-014      UA1        = 3.9503485e-009      LUA1       = -9.1136066e-016
+WUA1       = -4.9647199e-016     PUA1       = 3.4262174e-022      UB1        = -3.5230482e-018
+LUB1       = 3.9527663e-025      WUB1       = 2.7499835e-025      PUB1       = -1.7382021e-031
+UC1        = 3.7157106e-011      LUC1       = -2.5993185e-017     WUC1       = -1.4974451e-017
+PUC1       = 1.6764337e-023      PRT        = 0                   AT         = 44822.861
+LAT        = -0.016725344        WAT        = -0.005764348        PAT        = 2.103987e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_25'            CJD        = 'cjn_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_25'          CJSWD      = 'cjswn_25'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'         CJSWGD     = 'cjswgn_25'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LETA0      = '0+dleta0n_25'
+PETA0      = '0+dpeta0n_25'   )      



.MODEL nch_25.20 NMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxln_25'  WMIN       = 4e-07               WMAX       = '6e-007-dxwn_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_25'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_25'  XW         = '7e-09+dxwn_25'
+DLC        = 'dlcn_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.43761783+dvthn_25'
+LVTH0      = '4.9687149e-008+dlvthn_25'
+WVTH0      = '2.0017145e-008+dwvthn_25'
+PVTH0      = '-9.1998886e-015+dpvthn_25'
+K1         = 0.71631             K2         = '-0.095507584+dk2n_25'
+LK2        = '1.1682392e-008+dlk2n_25'
+WK2        = '-1.5441118e-008+dwk2n_25'
+PK2        = '7.3754432e-015+dpk2n_25'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0028885852+dcitn_25'
+LCIT       = '-6.9237641e-010+dlcitn_25'
+WCIT       = '-1.158666e-009+dwcitn_25'
+PCIT       = '3.7958501e-016+dpcitn_25'
+VOFF       = -0.033502075        LVOFF      = -3.1981638e-008     WVOFF      = -4.5154381e-008
+PVOFF      = 1.2784261e-014      NFACTOR    = 0.55                ETA0       = '0.87164759+deta0n_25'
+LETA0      = '-8.1756564e-008+dleta0n_25'
+WETA0      = '-2.0258327e-007+dweta0n_25'
+PETA0      = '3.3274922e-014+dpeta0n_25'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03786259+du0n_25'
+LU0        = '-1.0891235e-010+dlu0n_25'
+WU0        = '-5.4029616e-009+dwu0n_25'
+PU0        = '2.8197061e-015+dpu0n_25'
+UA         = -9.6780348e-010     LUA        = -1.8073066e-018     WUA        = -4.5228496e-017
+PUA        = 9.4507946e-023      UB         = 3.2824026e-018      LUB        = -1.3121278e-025
+WUB        = -4.3807346e-025     PUB        = 1.0430523e-031      UC         = 4.517043e-010
+LUC        = -1.0119964e-016     WUC        = -1.3774032e-016     PUC        = 3.8101876e-023
+VSAT       = '128250.1+dvsatn_25'
+LVSAT      = '-0.012607137+dlvsatn_25'
+WVSAT      = '-0.0090172885+dwvsatn_25'
+PVSAT      = '2.3895815e-009+dpvsatn_25'
+A0         = '1.0561856+da0n_25' LA0        = '-4.5460368e-007+dla0n_25'
+WA0        = '-5.6400669e-008+dwa0n_25'
+PA0        = '8.3993788e-015+dpa0n_25'
+AGS        = '8.4937151+dagsn_25'
+LAGS       = '-1.8685084e-006+dlagsn_25'
+WAGS       = '-1.5710587e-006+dwagsn_25'
+PAGS       = '4.019276e-013+dpagsn_25'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.071396718        LKETA      = 1.5438229e-008
+WKETA      = -1.5291716e-008     PKETA      = 8.1604207e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.15677659+dpclmn_25'
+LPCLM      = '6.2479611e-008+dlpclmn_25'
+WPCLM      = '-1.6220002e-008+dwpclmn_25'
+PPCLM      = '1.4504759e-014+dppclmn_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.011607408        LPDIBLC2   = 2.961631e-009
+WPDIBLC2   = 7.1560399e-009      PPDIBLC2   = -1.7958899e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_25'           CGDO       = 'cgon_25'           CGBO       = 0
+CGDL       = 'cgln_25'           CGSL       = 'cgln_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = -0.0028262422
+LTVOFF     = 9.8644798e-010      WTVOFF     = 2.8051426e-009      PTVOFF     = -7.3216776e-016
+KT1        = -0.5264585          LKT1       = 8.9673748e-008      WKT1       = 1.779988e-007
+PKT1       = -5.4960373e-014     KT1L       = 0                   KT2        = -0.033099305
+LKT2       = -2.6873107e-009     WKT2       = -2.7270504e-008     PKT2       = 8.8175556e-015
+UTE        = -3.221274           LUTE       = 6.5604699e-007      WUTE       = 9.0963442e-007
+PUTE       = -2.8197061e-013     UA1        = -4.1086269e-009     LUA1       = 2.0301654e-015
+WUA1       = 2.8275437e-015      PUA1       = -8.70644e-022       UB1        = 3.9057585e-019
+LUB1       = -1.0331961e-024     WUB1       = -1.5086171e-024     PUB1       = 4.7719942e-031
+UC1        = -3.1633616e-010     LUC1       = 1.0303186e-016      WUC1       = 1.796985e-016
+PUC1       = -5.4291291e-023     PRT        = 0                   AT         = -24850
+LAT        = 0.00870525
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_25'
+NOIB       = 'noibn_25'
+NOIC       = 'noicn_25'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_25'
+CJD        = 'cjn_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_25'
+CJSWD      = 'cjswn_25'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_25'
+CJSWGD     = 'cjswgn_25'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0     )              

**********************************************************************************************
*                                                                                            *
*                                   2.5V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.MODEL pch_25.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_25'
+LMAX       = 900.001e-6          WMIN       = '1e-005-dxwp_25'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+dvthp_25'
+K1         = 0.72417             K2         = '-0.05886+dk2p_25'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_25'
+VOFF       = '-0.08693+dvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_25'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_25'
+A0         = '1.297+da0p_25'     AGS        = '0.2718+dagsp_25'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_25'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'
+LCIT       = '0+dlcitp_25'       WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'
+LU0        = '0+dlu0p_25'        WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+LA0        = '0+dla0p_25'        WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+LPCLM      = '0+dlpclmp_25'      WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+LVOFF      = '0+dlvoffp_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+LK2        = '0+dlk2p_25'        WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_25'
+LMAX       = '1e-005-dxlp_25'    WMIN       = '1e-005-dxwp_25'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+dvthp_25'
+LVTH0      = '4.3026273e-009+dlvthp_25'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_25'
+LK2        = '-7.5295977e-010+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_25'
+LCIT       = '2.3222086e-010+dlcitp_25'
+VOFF       = '-0.087552125+dvoffp_25'
+LVOFF      = '6.2119181e-009+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_25'
+LU0        = '9.4119972e-011+dlu0p_25'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_25'  A0         = '1.3227199+da0p_25' LA0        = '-2.5681307e-007+dla0p_25'
+AGS        = '0.25480602+dagsp_25'
+LAGS       = '1.6968486e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_25'
+LPCLM      = '2.5143478e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'
+PAGS       = '0+dpagsp_25'       WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'      WK2        = '0+dwk2p_25'
+PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_25'
+LMAX       = '1.2e-006-dxlp_25'  WMIN       = '1e-005-dxwp_25'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+dvthp_25'
+LVTH0      = '1.3149945e-008+dlvthp_25'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_25'
+LK2        = '4.740474e-009+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_25'
+LCIT       = '2.0991209e-010+dlcitp_25'
+VOFF       = '-0.09229456+dvoffp_25'
+LVOFF      = '1.1831704e-008+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.5883+deta0p_25'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_25' LU0        = '-5.032695e-010+dlu0p_25'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_25'  A0         = '1.5469482+da0p_25' LA0        = '-5.2252362e-007+dla0p_25'
+AGS        = '0.2391074+dagsp_25'
+LAGS       = '1.8828773e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_25'
+LPCLM      = '1.2183992e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'
+WA0        = '0+dwa0p_25'        PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'
+PAGS       = '0+dpagsp_25'       WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      WETA0      = '0+dweta0p_25'      PETA0      = '0+dpeta0p_25'
+WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'      WK2        = '0+dwk2p_25'
+PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.4 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_25'
+LMAX       = '7e-007-dxlp_25'    WMIN       = '1e-005-dxwp_25'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63663281+dvthp_25'
+LVTH0      = '3.5159766e-009+dlvthp_25'
+K1         = 0.72417             K2         = '-0.044249688+dk2p_25'
+LK2        = '-8.3914641e-009+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00023317656+dcitp_25'
+LCIT       = '5.6802555e-011+dlcitp_25'
+VOFF       = '-0.11314283+dvoffp_25'
+LVOFF      = '2.6112767e-008+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58864219+deta0p_25'
+LETA0      = '-2.3439844e-010+dleta0p_25'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01097875+du0p_25'
+LU0        = '5.6255625e-010+dlu0p_25'
+UA         = 6.8244047e-010      LUA        = -2.4986092e-016     UB         = 7.2901719e-019
+LUB        = 4.3105873e-025      UC         = 4.7293438e-011      LUC        = 1.5204645e-017
+VSAT       = '102400.16+dvsatp_25'
+LVSAT      = '0.012055893+dlvsatp_25'
+A0         = '0.75410734+da0p_25'
+LA0        = '2.057237e-008+dla0p_25'
+AGS        = '0.16182344+dagsp_25'
+LAGS       = '2.4122725e-007+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.051643594        LKETA      = 5.7427617e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.43326891+dpclmp_25'
+LPCLM      = '-2.1384951e-008+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0057335625
+LTVOFF     = -1.1032353e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.21198906         LKT1       = -4.1175992e-008     KT1L       = 0
+KT2        = -0.071645938        LKT2       = 4.9223672e-009      UTE        = -0.43653125
+LUTE       = -3.8597609e-007     UA1        = 3.7772211e-009      LUA1       = -1.3427515e-015
+UB1        = -3.6822922e-018     LUB1       = 6.0779515e-025      UC1        = 1.0510078e-010
+LUC1       = -5.6732235e-017     PRT        = 0                   AT         = 122856.09
+LAT        = -0.040871274
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      WA0        = '0+dwa0p_25'
+PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      WETA0      = '0+dweta0p_25'
+PETA0      = '0+dpeta0p_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.5 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxlp_25'  WMIN       = '1e-005-dxwp_25'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67417+dvthp_25'
+LVTH0      = '1.721705e-008+dlvthp_25'
+K1         = 0.72417             K2         = '-0.014558+dk2p_25' LK2        = '-1.922893e-008+dlk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00075662+dcitp_25'
+LCIT       = '-1.342543e-010+dlcitp_25'
+VOFF       = '-0.06555965+dvoffp_25'
+LVOFF      = '8.7449073e-009+dlvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.587205+deta0p_25'
+LETA0      = '2.90175e-010+dleta0p_25'
+ETAB       = -0.09524            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010718+du0p_25'  LU0        = '6.5773e-010+dlu0p_25'
+UA         = 1.007205e-011       LUA        = -4.4464483e-018     UB         = 1.377615e-018
+LUB        = 1.9432053e-025      UC         = 1.79368e-010        LUC        = -3.300257e-017
+VSAT       = '176319.5+dvsatp_25'
+LVSAT      = '-0.014924668+dlvsatp_25'
+A0         = '0.7361905+da0p_25' LA0        = '2.7112018e-008+dla0p_25'
+AGS        = '0.655558+dagsp_25' LAGS       = '6.101413e-008+dlagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.1545505          LKETA      = 4.3303783e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.544393+dpclmp_25'
+LPCLM      = '3.3546165e-007+dlpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.008210545
+LTVOFF     = -2.0073339e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.387605           LKT1       = 2.2923825e-008      KT1L       = 0
+KT2        = -0.0916772          LKT2       = 1.2233778e-008      UTE        = -1.99591
+LUTE       = 1.8319715e-007      UA1        = 1.29243e-010        LUA1       = -1.1239445e-017
+UB1        = -3.63625e-018       LUB1       = 5.9098975e-025      UC1        = -1.036215e-010
+LUC1       = 1.9451398e-017      PRT        = 0                   AT         = 82801
+LAT        = -0.026251165
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_25'       PVTH0      = '0+dpvthp_25'       WCIT       = '0+dwcitp_25'
+PCIT       = '0+dpcitp_25'       WU0        = '0+dwu0p_25'        PU0        = '0+dpu0p_25'
+LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      WA0        = '0+dwa0p_25'
+PA0        = '0+dpa0p_25'        WAGS       = '0+dwagsp_25'       PAGS       = '0+dpagsp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      WETA0      = '0+dweta0p_25'
+PETA0      = '0+dpeta0p_25'      WVOFF      = '0+dwvoffp_25'      PVOFF      = '0+dpvoffp_25'
+WK2        = '0+dwk2p_25'        PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.6 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_25'
+LMAX       = 900.001e-6          WMIN       = '1e-006-dxwp_25'    WMAX       = '1e-005-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+dvthp_25'
+WVTH0      = '-1.5339508e-008+dwvthp_25'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_25'
+WK2        = '-1.0189016e-009+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_25'
+WCIT       = '-1.017782e-011+dwcitp_25'
+VOFF       = '-0.085385933+dvoffp_25'
+WVOFF      = '-1.5451475e-008+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_25'
+WU0        = '-2.0154098e-010+dwu0p_25'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.2936433+da0p_25' WA0        = '3.3590163e-008+dwa0p_25'
+AGS        = '0.27102797+dagsp_25'
+WAGS       = '7.7257376e-009+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'
+PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'       PCIT       = '0+dpcitp_25'
+LU0        = '0+dlu0p_25'        PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'
+PA0        = '0+dpa0p_25'        LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'
+LPCLM      = '0+dlpclmp_25'      WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'
+LETA0      = '0+dleta0p_25'      PETA0      = '0+dpeta0p_25'      LVOFF      = '0+dlvoffp_25'
+PVOFF      = '0+dpvoffp_25'      LK2        = '0+dlk2p_25'        PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.7 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_25'
+LMAX       = '1e-005-dxlp_25'    WMIN       = '1e-006-dxwp_25'    WMAX       = '1e-005-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+dvthp_25'
+LVTH0      = '2.9336e-009+dlvthp_25'
+WVTH0      = '-1.6711552e-008+dwvthp_25'
+PVTH0      = '1.3699856e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_25'
+LK2        = '-5.724287e-010+dlk2p_25'
+WK2        = '-8.3797279e-010+dwk2p_25'
+PK2        = '-1.8065744e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_25'
+LCIT       = '2.5685734e-010+dlcitp_25'
+WCIT       = '1.4512935e-011+dwcitp_25'
+PCIT       = '-2.4653719e-016+dpcitp_25'
+VOFF       = '-0.085808935+dvoffp_25'
+LVOFF      = '4.2236693e-009+dlvoffp_25'
+WVOFF      = '-1.7444105e-008+dwvoffp_25'
+PVOFF      = '1.9896406e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_25'
+LU0        = '6.5535886e-011+dlu0p_25'
+WU0        = '-2.3018805e-010+dwu0p_25'
+PU0        = '2.8604095e-016+dpu0p_25'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.3194838+da0p_25' LA0        = '-2.5801661e-007+dla0p_25'
+WA0        = '3.2383971e-008+dwa0p_25'
+PA0        = '1.2043829e-014+dpa0p_25'
+AGS        = '0.25390291+dagsp_25'
+LAGS       = '1.7099371e-007+dlagsp_25'
+WAGS       = '9.0374716e-009+dwagsp_25'
+PAGS       = '-1.3097665e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_25'
+LPCLM      = '2.479746e-007+dlpclmp_25'
+WPCLM      = '-3.4678027e-009+dwpclmp_25'
+PPCLM      = '3.462601e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.8 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_25'
+LMAX       = '1.2e-006-dxlp_25'  WMIN       = '1e-006-dxwp_25'    WMAX       = '1e-005-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+dvthp_25'
+LVTH0      = '1.3912858e-008+dlvthp_25'
+WVTH0      = '1.2921016e-009+dwvthp_25'
+PVTH0      = '-7.6344731e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_25'
+LK2        = '5.12738e-009+dlk2p_25'
+WK2        = '9.0480703e-010+dwk2p_25'
+PK2        = '-3.8717685e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_25'
+LCIT       = '2.2066735e-010+dlcitp_25'
+WCIT       = '-1.027101e-010+dwcitp_25'
+PCIT       = '-1.0762789e-016+dpcitp_25'
+VOFF       = '-0.092580246+dvoffp_25'
+LVOFF      = '1.2247673e-008+dlvoffp_25'
+WVOFF      = '2.8588588e-009+dwvoffp_25'
+PVOFF      = '-4.1626056e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.58755034+deta0p_25'
+WETA0      = '7.5018031e-009+dweta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_25'
+LU0        = '-5.6139623e-010+dlu0p_25'
+WU0        = '-4.7966753e-010+dwu0p_25'
+PU0        = '5.8167414e-016+dpu0p_25'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.5239739+da0p_25' LA0        = '-5.0033737e-007+dla0p_25'
+WA0        = '2.2990429e-007+dwa0p_25'
+PA0        = '-2.2201775e-013+dpa0p_25'
+AGS        = '0.23113396+dagsp_25'
+LAGS       = '1.9797491e-007+dlagsp_25'
+WAGS       = '7.9790186e-008+dwagsp_25'
+PAGS       = '-9.6939631e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_25'
+LPCLM      = '1.321774e-007+dlpclmp_25'
+WPCLM      = '1.130496e-007+dwpclmp_25'
+PPCLM      = '-1.0344711e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.9 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_25'
+LMAX       = '7e-007-dxlp_25'    WMIN       = '1e-006-dxwp_25'    WMAX       = '1e-005-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63426986+dvthp_25'
+LVTH0      = '2.5718197e-009+dlvthp_25'
+WVTH0      = '-2.3646075e-008+dwvthp_25'
+PVTH0      = '9.4481782e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.042954661+dk2p_25'
+LK2        = '-8.9535871e-009+dlk2p_25'
+WK2        = '-1.295933e-008+dwk2p_25'
+PK2        = '5.6251653e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00027424699+dcitp_25'
+LCIT       = '4.6455294e-011+dlcitp_25'
+WCIT       = '-4.1099174e-010+dwcitp_25'
+PCIT       = '1.0354503e-016+dpcitp_25'
+VOFF       = '-0.11299764+dvoffp_25'
+LVOFF      = '2.6233584e-008+dlvoffp_25'
+WVOFF      = '-1.4529495e-009+dwvoffp_25'
+PVOFF      = '-1.2090169e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.56211263+deta0p_25'
+LETA0      = '1.7424833e-008+dleta0p_25'
+WETA0      = '2.6548126e-007+dweta0p_25'
+PETA0      = '-1.7671593e-013+dpeta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010954461+du0p_25'
+LU0        = '5.5390148e-010+dlu0p_25'
+WU0        = '2.4305632e-010+dwu0p_25'
+PU0        = '8.66083e-017+dpu0p_25'
+UA         = 7.2875217e-010      LUA        = -2.5631878e-016     WUA        = -4.6344121e-016
+PUA        = 6.4623789e-023      UB         = 6.9179123e-019      LUB        = 4.4094615e-025
+WUB        = 3.7252016e-025      PUB        = -9.8943421e-032     UC         = 5.071201e-011
+LUC        = 1.4773655e-017      WUC        = -3.4209657e-017     PUC        = 4.3129184e-024
+VSAT       = '100430.93+dvsatp_25'
+LVSAT      = '0.013404813+dlvsatp_25'
+WVSAT      = '0.019706054+dwvsatp_25'
+PVSAT      = '-1.3498647e-008+dpvsatp_25'
+A0         = '0.80514856+da0p_25'
+LA0        = '-7.9420433e-009+dla0p_25'
+WA0        = '-5.107694e-007+dwa0p_25'
+PA0        = '2.8534373e-013+dpa0p_25'
+AGS        = '0.15467694+dagsp_25'
+LAGS       = '2.5034798e-007+dlagsp_25'
+WAGS       = '7.1515032e-008+dwagsp_25'
+PAGS       = '-9.1271151e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.056305672        LKETA      = 6.9780337e-009
+WKETA      = 4.6653413e-008      PKETA      = -1.2361366e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.48468951+dpclmp_25'
+LPCLM      = '-5.4009069e-008+dlpclmp_25'
+WPCLM      = '-5.1456596e-007+dwpclmp_25'
+PPCLM      = '3.2646955e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0058663344
+LTVOFF     = -1.1229053e-009     WTVOFF     = -1.3286484e-009     PTVOFF     = 1.9683705e-016
+KT1        = -0.21121668         LKT1       = -4.2172602e-008     WKT1       = -7.7292365e-009
+PKT1       = 9.973077e-015       KT1L       = 0                   KT2        = -0.071470027
+LKT2       = 4.7842405e-009      WKT2       = -1.7603345e-009     PKT2       = 1.3822335e-015
+UTE        = -0.39483341         LUTE       = -4.0442212e-007     WUTE       = -4.1727031e-007
+PUTE       = 1.8458941e-013      UA1        = 3.8832628e-009      LUA1       = -1.3819733e-015
+WUA1       = -1.0611596e-015     PUA1       = 3.9249307e-022      UB1        = -3.6984946e-018
+LUB1       = 5.7727615e-025      WUB1       = 1.6213727e-025      PUB1       = 3.0540361e-031
+UC1        = 1.1043827e-010      LUC1       = -6.0178408e-017     WUC1       = -5.3412209e-017
+PUC1       = 3.448585e-023       PRT        = 0                   AT         = 144049.55
+LAT        = -0.047696043        WAT        = -0.21208289         PAT        = 6.8295456e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'  )   



.MODEL pch_25.10 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxlp_25'  WMIN       = '1e-006-dxwp_25'    WMAX       = '1e-005-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.67973088+dvthp_25'
+LVTH0      = '1.9165092e-008+dlvthp_25'
+WVTH0      = '5.5647704e-008+dwvthp_25'
+PVTH0      = '-1.9494051e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.012522909+dk2p_25'
+LK2        = '-2.0061177e-008+dlk2p_25'
+WK2        = '-2.0365156e-008+dwk2p_25'
+PK2        = '8.3282919e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00081076359+dcitp_25'
+LCIT       = '-1.4937327e-010+dlcitp_25'
+WCIT       = '-5.4181493e-010+dwcitp_25'
+PCIT       = '1.512955e-016+dpcitp_25'
+VOFF       = '-0.067282633+dvoffp_25'
+LVOFF      = '9.5476086e-009+dlvoffp_25'
+WVOFF      = '1.7241887e-008+dwvoffp_25'
+PVOFF      = '-8.0326321e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.61679273+deta0p_25'
+LETA0      = '-2.5334029e-009+dleta0p_25'
+WETA0      = '-2.9608441e-007+dweta0p_25'
+PETA0      = '2.8255544e-014+dpeta0p_25'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010886745+du0p_25'
+LU0        = '5.7861787e-010+dlu0p_25'
+WU0        = '-1.6886335e-009+dwu0p_25'
+PU0        = '7.9167508e-016+dpu0p_25'
+UA         = 1.1398858e-010      LUA        = -3.1930067e-017     WUA        = -1.0398927e-015
+PUA        = 2.7502857e-022      UB         = 1.3302664e-018      LUB        = 2.079027e-025
+WUB        = 4.7381725e-025      PUB        = -1.3591686e-031     UC         = 1.8555523e-010
+LUC        = -3.4444121e-017     WUC        = -6.1915628e-017     PUC        = 1.4425598e-023
+VSAT       = '182621.03+dvsatp_25'
+LVSAT      = '-0.016594572+dlvsatp_25'
+WVSAT      = '-0.063059374+dwvsatp_25'
+PVSAT      = '1.6710734e-008+dpvsatp_25'
+A0         = '0.51664235+da0p_25'
+LA0        = '9.7362723e-008+dla0p_25'
+WA0        = '2.1970184e-006+dwa0p_25'
+PA0        = '-7.0299881e-013+dpa0p_25'
+AGS        = '0.70207782+dagsp_25'
+LAGS       = '5.0546654e-008+dlagsp_25'
+WAGS       = '-4.6552383e-007+dwagsp_25'
+PAGS       = '1.0474804e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.15710918         LKETA      = 4.3771313e-008
+WKETA      = 2.5604662e-008      PKETA      = -4.6785723e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.61881187+dpclmp_25'
+LPCLM      = '3.4876893e-007+dlpclmp_25'
+WPCLM      = '7.447096e-007+dwpclmp_25'
+PPCLM      = '-1.3316603e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.0020711584        LPDIBLC2   = -7.5232281e-010
+WPDIBLC2   = -2.0626012e-008     PPDIBLC2   = 7.5284943e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0081615735
+LTVOFF     = -1.9606675e-009     WTVOFF     = 4.9005809e-010      PTVOFF     = -4.6699083e-016
+KT1        = -0.39063048         LKT1       = 2.3313433e-008      WKT1       = 3.0275934e-008
+PKT1       = -3.8988103e-015     KT1L       = 0                   KT2        = -0.090158504
+LKT2       = 1.1605535e-008      WKT2       = -1.519759e-008      PKT2       = 6.2868315e-015
+UTE        = -2.0042748          LUTE       = 1.8302399e-007      WUTE       = 8.3706687e-008
+PUTE       = 1.7328046e-015      UA1        = 4.4969032e-010      LUA1       = -1.2871933e-016
+WUA1       = -3.2067163e-015     PUA1       = 1.1756213e-021      UB1        = -4.3385654e-018
+LUB1       = 8.1090199e-025      WUB1       = 7.0280699e-024      PUB1       = -2.2006618e-030
+UC1        = -1.2214762e-010     LUC1       = 2.4715439e-017      WUC1       = 1.8539083e-016
+PUC1       = -5.2677259e-023     PRT        = 0                   AT         = 89033.317
+LAT        = -0.027615119        WAT        = -0.0623668          PAT        = 1.3649085e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'  )   



.MODEL pch_25.11 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_25'
+LMAX       = 900.001e-6          WMIN       = '6e-007-dxwp_25'    WMAX       = '1e-006-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+dvthp_25'
+WVTH0      = '-9.168735e-010+dwvthp_25'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_25'
+WK2        = '6.3722708e-009+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.1087682+dvoffp_25'
+WVOFF      = '8.0944649e-009+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_25'
+WU0        = '-4.7371798e-010+dwu0p_25'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.1646275+da0p_25' WA0        = '1.6350911e-007+dwa0p_25'
+AGS        = '0.26549775+dagsp_25'
+WAGS       = '1.3294666e-008+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LU0        = '0+dlu0p_25'
+PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'
+PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'
+PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'       LPCLM      = '0+dlpclmp_25'
+WPCLM      = '0+dwpclmp_25'      PPCLM      = '0+dppclmp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'        LVOFF      = '0+dlvoffp_25'      PVOFF      = '0+dpvoffp_25'
+LK2        = '0+dlk2p_25'        PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.12 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_25'
+LMAX       = '1e-005-dxlp_25'    WMIN       = '6e-007-dxwp_25'    WMAX       = '1e-006-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+dvthp_25'
+LVTH0      = '2.5515924e-008+dlvthp_25'
+WVTH0      = '-1.1460919e-011+dwvthp_25'
+PVTH0      = '-9.0405446e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_25'
+LK2        = '-7.6918538e-009+dlk2p_25'
+WK2        = '5.8351965e-009+dwk2p_25'
+PK2        = '5.3626867e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_25'
+LCIT       = '3.029537e-011+dlcitp_25'
+WCIT       = '1.8416915e-012+dwcitp_25'
+PCIT       = '-1.838929e-017+dpcitp_25'
+VOFF       = '-0.11242711+dvoffp_25'
+LVOFF      = '3.6534227e-008+dlvoffp_25'
+WVOFF      = '9.3603963e-009+dwvoffp_25'
+PVOFF      = '-1.2640325e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_25'
+LU0        = '-2.8293136e-010+dlu0p_25'
+WU0        = '-5.3750841e-010+dwu0p_25'
+PU0        = '6.3694746e-016+dpu0p_25'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_25'  A0         = '1.1751703+da0p_25' LA0        = '-1.0526983e-007+dla0p_25'
+WA0        = '1.7770762e-007+dwa0p_25'
+PA0        = '-1.4177218e-013+dpa0p_25'
+AGS        = '0.25327996+dagsp_25'
+LAGS       = '1.2199468e-007+dlagsp_25'
+WAGS       = '9.6647844e-009+dwagsp_25'
+PAGS       = '3.6244365e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_25'
+LPCLM      = '2.6195605e-007+dlpclmp_25'
+WPCLM      = '-2.0577559e-009+dwpclmp_25'
+PPCLM      = '2.0546692e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.13 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_25'
+LMAX       = '1.2e-006-dxlp_25'  WMIN       = '6e-007-dxwp_25'    WMAX       = '1e-006-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+dvthp_25'
+LVTH0      = '-7.9573402e-009+dlvthp_25'
+WVTH0      = '-1.9783074e-008+dwvthp_25'
+PVTH0      = '1.4388817e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_25'
+LK2        = '1.295992e-008+dlk2p_25'
+WK2        = '2.0283992e-008+dwk2p_25'
+PK2        = '-1.1759136e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_25'
+LCIT       = '2.8646031e-010+dlcitp_25'
+WCIT       = '1.3305867e-010+dwcitp_25'
+PCIT       = '-1.7388141e-016+dpcitp_25'
+VOFF       = '-0.073036514+dvoffp_25'
+LVOFF      = '-1.0143628e-008+dlvoffp_25'
+WVOFF      = '-1.6821679e-008+dwvoffp_25'
+PVOFF      = '1.8385435e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.66465325+deta0p_25'
+WETA0      = '-7.0140823e-008+dweta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_25'
+LU0        = '-1.6343677e-009+dlu0p_25'
+WU0        = '-1.4026636e-009+dwu0p_25'
+PU0        = '1.6621564e-015+dpu0p_25'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_25'  A0         = '2.1264181+da0p_25' LA0        = '-1.2324985e-006+dla0p_25'
+WA0        = '-3.7675707e-007+dwa0p_25'
+PA0        = '5.1526849e-013+dpa0p_25'
+AGS        = '0.24152159+dagsp_25'
+LAGS       = '1.3592834e-007+dlagsp_25'
+WAGS       = '6.9329848e-008+dwagsp_25'
+PAGS       = '-3.4458735e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_25'
+LPCLM      = '-2.323312e-007+dlpclmp_25'
+WPCLM      = '-2.0717704e-007+dwpclmp_25'
+PPCLM      = '2.6361305e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.14 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_25'
+LMAX       = '7e-007-dxlp_25'    WMIN       = '6e-007-dxwp_25'    WMAX       = '1e-006-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.69392971+dvthp_25'
+LVTH0      = '3.5904762e-008+dlvthp_25'
+WVTH0      = '3.6431396e-008+dwvthp_25'
+PVTH0      = '-2.4118095e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.056981+dk2p_25' LK2        = '-4.6954695e-009+dlk2p_25'
+WK2        = '1.1651934e-009+dwk2p_25'
+PK2        = '1.3372409e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-8.6053841e-005+dcitp_25'
+LCIT       = '1.9867537e-010+dlcitp_25'
+WCIT       = '-4.8168809e-011+dwcitp_25'
+PCIT       = '-4.9740586e-017+dpcitp_25'
+VOFF       = '-0.1585485+dvoffp_25'
+LVOFF      = '4.8432079e-008+dlvoffp_25'
+WVOFF      = '4.4416767e-008+dwvoffp_25'
+PVOFF      = '-2.3562901e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.98182545+deta0p_25'
+LETA0      = '-2.1726296e-007+dleta0p_25'
+WETA0      = '-1.5716955e-007+dweta0p_25'
+PETA0      = '5.9614677e-014+dpeta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013590704+du0p_25'
+LU0        = '-1.6970388e-009+dlu0p_25'
+WU0        = '-2.41164e-009+dwu0p_25'
+PU0        = '2.3533052e-015+dpu0p_25'
+UA         = 1.3822488e-009      LUA        = -9.5202533e-016     WUA        = -1.1215123e-015
+PUA        = 7.6520029e-022      UB         = 4.2523021e-019      LUB        = 7.7972679e-025
+WUB        = 6.4094711e-025      PUB        = -4.4009553e-031     UC         = 2.9244119e-011
+LUC        = 1.5938293e-017      WUC        = -1.2591491e-017     PUC        = 3.1401282e-024
+VSAT       = '120000+dvsatp_25'  A0         = '-0.72475126+da0p_25'
+LA0        = '7.2055254e-007+dla0p_25'
+WA0        = '1.0298397e-006+dwa0p_25'
+PA0        = '-4.4825031e-013+dpa0p_25'
+AGS        = '0.47827608+dagsp_25'
+LAGS       = '-2.6248484e-008+dlagsp_25'
+WAGS       = '-2.5434931e-007+dwagsp_25'
+PAGS       = '1.8726148e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.016556925         LKETA      = -2.0853335e-008
+WKETA      = -2.6719222e-008     PKETA      = 1.5664822e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.500404+dpclmp_25'
+LPCLM      = '4.7410182e-007+dlpclmp_25'
+WPCLM      = '4.774232e-007+dwpclmp_25'
+PPCLM      = '-2.0533812e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00085814023       LPDIBLC2   = -5.8097606e-010
+WPDIBLC2   = -8.5407722e-010     PPDIBLC2   = 5.8504289e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.002836154
+LTVOFF     = -7.3891568e-010     WTVOFF     = 1.7227432e-009      PTVOFF     = -1.8984045e-016
+KT1        = -0.20204794         LKT1       = -5.5033628e-008     WKT1       = -1.696216e-008
+PKT1       = 2.292413e-014       KT1L       = 0                   KT2        = -0.070902278
+LKT2       = 3.3231253e-009      WKT2       = -2.3320582e-009     PKT2       = 2.8535766e-015
+UTE        = -0.91151582         LUTE       = -1.4167628e-007     WUTE       = 1.0302888e-007
+PUTE       = -7.9995661e-014     UA1        = 2.6228981e-009      LUA1       = -9.8687309e-016
+WUA1       = 2.0802761e-016      PUA1       = -5.3728429e-024     UB1        = -4.4978011e-018
+LUB1       = 1.5789137e-024      WUB1       = 9.670389e-025       PUB1       = -7.0324544e-031
+UC1        = 6.8312674e-011      LUC1       = -2.7390649e-017     WUC1       = -1.0991737e-017
+PUC1       = 1.4685771e-024      PRT        = 0                   AT         = -159164.07
+LAT        = 0.079546663         WAT        = 0.093253222         PAT        = -5.9837948e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      )



.MODEL pch_25.15 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxlp_25'  WMIN       = '6e-007-dxwp_25'    WMAX       = '1e-006-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.49731109+dvthp_25'
+LVTH0      = '-3.5861036e-008+dlvthp_25'
+WVTH0      = '-1.2804903e-007+dwvthp_25'
+PVTH0      = '3.5917259e-014+dpvthp_25'
+K1         = 0.72417             K2         = '-0.015424238+dk2p_25'
+LK2        = '-1.9863688e-008+dlk2p_25'
+WK2        = '-1.7443518e-008+dwk2p_25'
+PK2        = '8.1294207e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00074340556+dcitp_25'
+LCIT       = '-1.0407731e-010+dlcitp_25'
+WCIT       = '-4.739854e-010+dwcitp_25'
+PCIT       = '1.0568247e-016+dpcitp_25'
+VOFF       = '0.07906712+dvoffp_25'
+LVOFF      = '-3.8297621e-008+dlvoffp_25'
+WVOFF      = '-1.3013231e-007+dwvoffp_25'
+PVOFF      = '4.0147514e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.53621805+deta0p_25'
+LETA0      = '-5.4616255e-008+dleta0p_25'
+WETA0      = '-2.1494571e-007+dweta0p_25'
+PETA0      = '8.0702976e-014+dpeta0p_25'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '-0.0032467764+du0p_25'
+LU0        = '4.4486415e-009+dlu0p_25'
+WU0        = '1.2543823e-008+dwu0p_25'
+PU0        = '-3.1054387e-015+dpu0p_25'
+UA         = -4.4555912e-009     LUA        = 1.1787862e-015      WUA        = 3.5616741e-015
+PUA        = -9.4416274e-022     UB         = 3.6830818e-018      LUB        = -4.0938905e-025
+WUB        = -1.8954679e-024     PUB        = 4.8569593e-031      UC         = 1.2501464e-010
+LUC        = -1.9017949e-017     WUC        = -9.5125626e-019     PUC        = -1.1085574e-024
+VSAT       = '120000+dvsatp_25'  A0         = '4.5284548+da0p_25' LA0        = '-1.1968677e-006+dla0p_25'
+WA0        = '-1.8428768e-006+dwa0p_25'
+PA0        = '6.002912e-013+dpa0p_25'
+AGS        = '-0.61902699+dagsp_25'
+LAGS       = '3.7426714e-007+dlagsp_25'
+WAGS       = '8.648287e-007+dwagsp_25'
+PAGS       = '-2.2123849e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.16119939         LKETA      = 4.4027721e-008
+WKETA      = 2.9723511e-008      PKETA      = -4.9367755e-015     DWG        = 0
+DWB        = 0                   PCLM       = '-0.026314886+dpclmp_25'
+LPCLM      = '3.010593e-007+dlpclmp_25'
+WPCLM      = '1.4806514e-007+dwpclmp_25'
+PPCLM      = '-8.5122425e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.029013451        LPDIBLC2   = 1.0322155e-008
+WPDIBLC2   = 1.067619e-008       PPDIBLC2   = -3.6235045e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0098913079
+LTVOFF     = -3.3140468e-009     WTVOFF     = -1.2517845e-009     PTVOFF     = 8.9586216e-016
+KT1        = -0.53396973         LKT1       = 6.6117825e-008      WKT1       = 1.7461856e-007
+PKT1       = -4.7002832e-014     KT1L       = 0                   KT2        = -0.13690558
+LKT2       = 2.7414329e-008      WKT2       = 3.1876712e-008      PKT2       = -9.6326245e-015
+UTE        = -2.2252494          LUTE       = 3.3783649e-007      WUTE       = 3.0622811e-007
+PUTE       = -1.5416338e-013     UA1        = -7.0184478e-009     LUA1       = 2.5322182e-015
+WUA1       = 4.3136988e-015      PUA1       = -1.5039428e-021     UB1        = 9.7141728e-018
+LUB1       = -3.6084567e-024     WUB1       = -7.1230374e-024     PUB1       = 2.2496324e-030
+UC1        = 8.4798945e-011      LUC1       = -3.3408138e-017     WUC1       = -2.3004356e-017
+PUC1       = 5.8531829e-024      PRT        = 0                   AT         = 258419.48
+LAT        = -0.072871331        WAT        = -0.23293867         PAT        = 5.9222091e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      )



.MODEL pch_25.16 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_25'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+dvthp_25'
+WVTH0      = '-1.235245e-008+dwvthp_25'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_25'
+WK2        = '1.0981328e-008+dwk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.082272655+dvoffp_25'
+WVOFF      = '-7.9883294e-009+dwvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_25'
+WU0        = '5.0645045e-010+dwu0p_25'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_25'  A0         = '1.517435+da0p_25'  WA0        = '-5.0645045e-008+dwa0p_25'
+AGS        = '0.2802775+dagsp_25'
+WAGS       = '4.3233575e-009+dwagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_25'
+WPCLM      = '-1.235245e-008+dwpclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'
+CGBO       = 0                   CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_25'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_25'
+CJD        = 'cjp_25'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_25'
+CJSWD      = 'cjswp_25'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'
+CJSWGD     = 'cjswgp_25'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_25'       PVTH0      = '0+dpvthp_25'       LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LU0        = '0+dlu0p_25'
+PU0        = '0+dpu0p_25'        LNFACTOR   = '0+dlnfactorp_25'   WNFACTOR   = '0+dwnfactorp_25'
+PNFACTOR   = '0+dpnfactorp_25'   LVSAT      = '0+dlvsatp_25'      WVSAT      = '0+dwvsatp_25'
+PVSAT      = '0+dpvsatp_25'      LA0        = '0+dla0p_25'        PA0        = '0+dpa0p_25'
+LAGS       = '0+dlagsp_25'       PAGS       = '0+dpagsp_25'       LPCLM      = '0+dlpclmp_25'
+PPCLM      = '0+dppclmp_25'      LETA0      = '0+dleta0p_25'      PETA0      = '0+dpeta0p_25'
+LVOFF      = '0+dlvoffp_25'      PVOFF      = '0+dpvoffp_25'      LK2        = '0+dlk2p_25'
+PK2        = '0+dpk2p_25'  )        



.MODEL pch_25.17 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_25'
+LMAX       = '1e-005-dxlp_25'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+dvthp_25'
+LVTH0      = '1.3084693e-008+dlvthp_25'
+WVTH0      = '-1.2202747e-008+dwvthp_25'
+PVTH0      = '-1.4947872e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_25'
+LK2        = '1.8463044e-008+dlk2p_25'
+WK2        = '1.2034241e-008+dwk2p_25'
+PK2        = '-1.0513336e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.08299213+dvoffp_25'
+LVOFF      = '7.1839623e-009+dlvoffp_25'
+WVOFF      = '-8.5066354e-009+dwvoffp_25'
+PVOFF      = '5.1752854e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_25'
+LU0        = '8.2354975e-011+dlu0p_25'
+WU0        = '4.6486621e-010+dwu0p_25'
+PU0        = '4.1521866e-016+dpu0p_25'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.5401338+da0p_25' LA0        = '-2.2664761e-007+dla0p_25'
+WA0        = '-4.3825229e-008+dwa0p_25'
+PA0        = '-6.809586e-014+dpa0p_25'
+AGS        = '0.25532754+dagsp_25'
+LAGS       = '2.4912535e-007+dlagsp_25'
+WAGS       = '8.4219004e-009+dwagsp_25'
+PAGS       = '-4.0923951e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_25'
+LPCLM      = '4.3261573e-007+dlpclmp_25'
+WPCLM      = '-4.0356016e-009+dwpclmp_25'
+PPCLM      = '-8.3043732e-014+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.18 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_25'
+LMAX       = '1.2e-006-dxlp_25'  WMIN       = 4e-07               WMAX       = '6e-007-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+dvthp_25'
+LVTH0      = '1.3104488e-008+dlvthp_25'
+WVTH0      = '-1.4817999e-008+dwvthp_25'
+PVTH0      = '1.6042868e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_25'
+LK2        = '-2.3393752e-008+dlk2p_25'
+WK2        = '-5.536121e-009+dwk2p_25'
+PK2        = '1.0307543e-014+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_25'
+VOFF       = '-0.10923032+dvoffp_25'
+LVOFF      = '3.8276211e-008+dlvoffp_25'
+WVOFF      = '5.1479577e-009+dwvoffp_25'
+PVOFF      = '-1.1005407e-014+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.4866255+deta0p_25'
+WETA0      = '3.7922022e-008+dweta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_25'
+LU0        = '1.9298762e-009+dlu0p_25'
+WU0        = '1.2383331e-009+dwu0p_25'
+PU0        = '-5.0133962e-016+dpu0p_25'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_25'  A0         = '1.8892247+da0p_25' LA0        = '-6.4032034e-007+dla0p_25'
+WA0        = '-2.3278069e-007+dwa0p_25'
+PA0        = '1.5581636e-013+dpa0p_25'
+AGS        = '0.50163406+dagsp_25'
+LAGS       = '-4.2747874e-008+dlagsp_25'
+WAGS       = '-8.855842e-008+dwagsp_25'
+PAGS       = '7.3997729e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_25'
+LPCLM      = '3.733935e-009+dlpclmp_25'
+WPCLM      = '-1.7565184e-007+dwpclmp_25'
+PPCLM      = '1.2032151e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_25'
+WCIT       = '0+dwcitp_25'       PCIT       = '0+dpcitp_25'       LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      LETA0      = '0+dleta0p_25'
+PETA0      = '0+dpeta0p_25'  )      



.MODEL pch_25.19 PMOS	(	LEVEL      = 54                  LMIN       = '3.8e-007-dxlp_25'
+LMAX       = '7e-007-dxlp_25'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63703339+dvthp_25'
+LVTH0      = '1.238952e-008+dlvthp_25'
+WVTH0      = '1.8953291e-009+dwvthp_25'
+PVTH0      = '-9.8443429e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.070684483+dk2p_25'
+LK2        = '-2.5242368e-009+dlk2p_25'
+WK2        = '9.4832075e-009+dwk2p_25'
+PK2        = '1.9302633e-017+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5.6494656e-005+dcitp_25'
+LCIT       = '-3.527384e-011+dlcitp_25'
+WCIT       = '-1.3469575e-010+dwcitp_25'
+PCIT       = '9.2266587e-017+dpcitp_25'
+VOFF       = '-0.077660392+dvoffp_25'
+LVOFF      = '1.6650813e-008+dlvoffp_25'
+WVOFF      = '-4.682312e-009+dwvoffp_25'
+PVOFF      = '-4.2716727e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.47744455+deta0p_25'
+LETA0      = '6.2889491e-009+dleta0p_25'
+WETA0      = '1.4898966e-007+dweta0p_25'
+PETA0      = '-7.6081329e-014+dpeta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0078316258+du0p_25'
+LU0        = '2.8318066e-009+dlu0p_25'
+WU0        = '1.0841205e-009+dwu0p_25'
+PU0        = '-3.9570398e-016+dpu0p_25'
+UA         = -9.9789287e-010     LUA        = 6.6674929e-016      WUA        = 3.232337e-016
+PUA        = -2.1739591e-022     UB         = 1.890541e-018       LUB        = -1.2815735e-025
+WUB        = -2.4849655e-025     PUB        = 1.1099014e-031      UC         = -3.3997165e-011
+LUC        = 4.3196624e-017      WUC        = 2.5795969e-017      PUC        = -1.3405679e-023
+VSAT       = '120000+dvsatp_25'  A0         = '-0.15470335+da0p_25'
+LA0        = '7.5977038e-007+dla0p_25'
+WA0        = '6.8382063e-007+dwa0p_25'
+PA0        = '-4.7205555e-013+dpa0p_25'
+AGS        = '0.10781513+dagsp_25'
+LAGS       = '2.2701809e-007+dlagsp_25'
+WAGS       = '-2.9479508e-008+dwagsp_25'
+PAGS       = '3.3528674e-014+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.030607227        LKETA      = 4.9059202e-009
+WKETA      = 1.9094186e-009      PKETA      = 2.895395e-017       DWG        = 0
+DWB        = 0                   PCLM       = '-0.090043958+dpclmp_25'
+LPCLM      = '3.9349411e-007+dlpclmp_25'
+WPCLM      = '2.2833465e-007+dwpclmp_25'
+PPCLM      = '-1.5640924e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = 0.00061167969       LPDIBLC2   = -4.1215059e-010
+WPDIBLC2   = -7.0447566e-010     PPDIBLC2   = 4.8256583e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0082648363
+LTVOFF     = -2.2727898e-009     WTVOFF     = -1.5724669e-009     PTVOFF     = 7.4122112e-016
+KT1        = -0.19230335         LKT1       = -5.3678414e-008     WKT1       = -2.2877123e-008
+PKT1       = 2.2101515e-014      KT1L       = 0                   KT2        = -0.076128019
+LKT2       = 3.9538328e-009      WKT2       = 8.399666e-010       PKT2       = 2.4707371e-015
+UTE        = 0.58430742          LUTE       = -1.0382562e-006     WUTE       = -8.0493582e-007
+PUTE       = 4.6422833e-013      UA1        = 7.9580462e-009      LUA1       = -3.9680757e-015
+WUA1       = -3.0304073e-015     PUA1       = 1.8042171e-021      UB1        = -6.5789123e-018
+LUB1       = 2.5859383e-024      WUB1       = 2.2302735e-024      PUB1       = -1.3145093e-030
+UC1        = 1.2043095e-010      LUC1       = -5.3909297e-017     WUC1       = -4.2627533e-017
+PUC1       = 1.7565396e-023      PRT        = 0                   AT         = 121939.93
+LAT        = -0.073315847        WAT        = -0.077376905        PAT        = 3.2949595e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      )



.MODEL pch_25.20 PMOS	(	LEVEL      = 54                  LMIN       = 2.8e-07
+LMAX       = '3.8e-007-dxlp_25'  WMIN       = 4e-07               WMAX       = '6e-007-dxwp_25'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_25'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_25'  XW         = '7e-09+dxwp_25'
+DLC        = 'dlcp_25'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.68798623+dvthp_25'
+LVTH0      = '3.0987305e-008+dlvthp_25'
+WVTH0      = '-1.2309216e-008+dwvthp_25'
+PVTH0      = '-4.6596838e-015+dpvthp_25'
+K1         = 0.72417             K2         = '-0.06622436+dk2p_25'
+LK2        = '-4.1521818e-009+dlk2p_25'
+WK2        = '1.3392156e-008+dwk2p_25'
+PK2        = '-1.4074635e-015+dpk2p_25'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.0010738143+dcitp_25'
+LCIT       = '3.7728892e-010+dlcitp_25'
+WCIT       = '6.2906705e-010+dwcitp_25'
+PCIT       = '-1.8650683e-016+dpcitp_25'
+VOFF       = '-0.12935096+dvoffp_25'
+LVOFF      = '3.551787e-008+dlvoffp_25'
+WVOFF      = '-3.6225413e-009+dwvoffp_25'
+PVOFF      = '-4.658489e-015+dpvoffp_25'
+NFACTOR    = '0.63002+dnfactorp_25'
+ETA0       = '0.52223945+deta0p_25'
+LETA0      = '-1.0061189e-008+dleta0p_25'
+WETA0      = '-2.064607e-007+dweta0p_25'
+PETA0      = '5.3658052e-014+dpeta0p_25'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.019683455+du0p_25'
+LU0        = '-1.4941111e-009+dlu0p_25'
+WU0        = '-1.3748277e-009+dwu0p_25'
+PU0        = '5.0181211e-016+dpu0p_25'
+UA         = 3.0725555e-009      LUA        = -8.1896436e-016     WUA        = -1.0079109e-015
+PUA        = 2.6847187e-022      UB         = -5.0726275e-019     LUB        = 7.4704103e-025
+WUB        = 6.4807129e-025      PUB        = -2.1625712e-031     UC         = 1.4501647e-010
+LUC        = -2.2143351e-017     WUC        = -1.3092362e-017     PUC        = 7.8856188e-025
+VSAT       = '120000+dvsatp_25'  A0         = '3.6857665+da0p_25' LA0        = '-6.4200111e-007+dla0p_25'
+WA0        = '-1.331365e-006+dwa0p_25'
+PA0        = '2.634872e-013+dpa0p_25'
+AGS        = '-1.0058362+dagsp_25'
+LAGS       = '6.3350082e-007+dlagsp_25'
+WAGS       = '1.0996219e-006+dwagsp_25'
+PAGS       = '-3.7859334e-013+dpagsp_25'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.099167818        LKETA      = 2.9930536e-008
+WKETA      = -7.9296553e-009     PKETA      = 3.6202159e-015      DWG        = 0
+DWB        = 0                   PCLM       = '1.7853663+dpclmp_25'
+LPCLM      = '-2.9103063e-007+dlpclmp_25'
+WPCLM      = '-9.5162534e-007+dwpclmp_25'
+PPCLM      = '2.7427616e-013+dppclmp_25'
+PDIBLC1    = 0                   PDIBLC2    = -0.02050574         LPDIBLC2   = 7.2957075e-009
+WPDIBLC2   = 5.5120091e-009      PPDIBLC2   = -1.7864511e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_25'           CGDO       = 'Cgop_25'           CGBO       = 0
+CGDL       = 'Cglp_25'           CGSL       = 'Cglp_25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.0012059534
+LTVOFF     = 1.1840485e-009      WTVOFF     = 5.4842531e-009      PTVOFF     = -1.8344817e-015
+KT1        = -0.37469333         LKT1       = 1.2893926e-008      WKT1       = 7.7937783e-008
+PKT1       = -1.4695926e-014     KT1L       = 0                   KT2        = -0.093167253
+LKT2       = 1.0173153e-008      WKT2       = 5.3275499e-009      PKT2       = 8.3276914e-016
+UTE        = -4.8611772          LUTE       = 9.4934572e-007      WUTE       = 1.9062363e-006
+PUTE       = -5.2534948e-013     UA1        = -1.2135077e-008     LUA1       = 3.3659144e-015
+WUA1       = 7.4194929e-015      PUA1       = -2.0099964e-021     UB1        = 7.3080953e-018
+LUB1       = -2.4828195e-024     WUB1       = -5.6625484e-024     PUB1       = 1.5663706e-030
+UC1        = -1.0663781e-010     LUC1       = 2.8970801e-017      WUC1       = 9.3197753e-017
+PUC1       = -3.2010833e-023     PRT        = 0                   AT         = -238957.71
+LAT        = 0.058411792         WAT        = 0.068969287         PAT        = -2.0466765e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_25'
+NOIB       = 'noibp_25'
+NOIC       = 'noicp_25'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_25'            CJD        = 'cjp_25'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_25'          CJSWD      = 'cjswp_25'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_25'         CJSWGD     = 'cjswgp_25'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_25'
+WNFACTOR   = '0+dwnfactorp_25'   PNFACTOR   = '0+dpnfactorp_25'     LVSAT      = '0+dlvsatp_25'
+WVSAT      = '0+dwvsatp_25'      PVSAT      = '0+dpvsatp_25'      )



.ENDL MOS_25








***************************************************************
*                                                             *
*                     3.3V IO DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_33
**********************************************************************************************
*                                                                                            *
*                                   3.3V NMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************

.MODEL nch_33.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_33'
+LMAX       = 900.0001e-6         WMIN       = '1e-005-dxwn_33'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.585+dvthn_33'
+K1         = 0.71631             K2         = '-0.048803+dk2n_33' K3         = -2.272
+K3B        = 2.548               W0         = 0                   DVT0       = 38.99
+DVT1       = 0.4502              DVT2       = 0.01565             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.326
+MINV       = -0.3                VOFFL      = 0                   DVTP0      = 1.154e-007
+DVTP1      = 3.5                 LPE0       = 8.393e-008          LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008
+NGATE      = 6.423e+020          NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.0002+dcitn_33'   VOFF       = -0.1271
+NFACTOR    = 0.55                ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.0386+du0n_33'
+UA         = -9.744e-010         UB         = 3.27e-018           UC         = 1.4048e-010
+VSAT       = '89640+dvsatn_33'   A0         = '1.1773+da0n_33'    AGS        = '0.3986+dagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02653            DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.0007              PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001559            LTVOFF     = 0
+WTVOFF     = 0                   PTVOFF     = 0                   KT1        = -0.2781
+KT1L       = 0                   KT2        = -0.05732            UTE        = -1.468
+UA1        = 2.225e-009          UB1        = -3.5797e-018        UC1        = -5.469e-012
+PRT        = 0                   AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       WVTH0      = '0+dwvthn_33'
+PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       WCIT       = '0+dwcitn_33'
+PCIT       = '0+dpcitn_33'       LA0        = '0+dla0n_33'        WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'       WAGS       = '0+dwagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      WETA0      = '0+dweta0n_33'
+PETA0      = '0+dpeta0n_33'      LK2        = '0+dlk2n_33'        WK2        = '0+dwk2n_33'
+PK2        = '0+dpk2n_33'  )        



.MODEL nch_33.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_33'
+LMAX       = '1e-005-dxln_33'    WMIN       = '1e-005-dxwn_33'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58351875+dvthn_33'
+LVTH0      = '1.4790281e-008+dlvthn_33'
+K1         = 0.71631             K2         = '-0.047585817+dk2n_33'
+LK2        = '-1.2153578e-008+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00012399841+dcitn_33'
+LCIT       = '7.5887589e-010+dlcitn_33'
+VOFF       = -0.12703267         LVOFF      = -6.7228551e-010     NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038597307+du0n_33'
+LU0        = '2.6891421e-011+dlu0n_33'
+UA         = -9.8046101e-010     LUA        = 6.0519142e-017      UB         = 3.2821193e-018
+LUB        = -1.2101139e-025     UC         = 1.3839278e-010      LUC        = 2.0840851e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.2321467+da0n_33' LA0        = '-5.4764378e-007+dla0n_33'
+AGS        = '0.38027424+dagsn_33'
+LAGS       = '1.8298267e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025029898        LKETA      = -1.4978521e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00053840909       LPDIBLC2   = 1.6134852e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0015565761        LTVOFF     = 2.4202278e-011      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.27744017         LKT1       = -6.588398e-009
+KT1L       = 0                   KT2        = -0.056817722        LKT2       = -5.0152499e-009
+UTE        = -1.4833511          LUTE       = 1.532811e-007       UA1        = 2.1901233e-009
+LUA1       = 3.482439e-016       UB1        = -3.5757006e-018     LUB1       = -3.9933759e-026
+UC1        = -5.8704188e-012     LUC1       = 4.0081662e-018      PRT        = 0
+AT         = 231673.38           LAT        = -0.21640871
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'        WCIT       = '0+dwcitn_33'
+PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'        PA0        = '0+dpa0n_33'
+WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'
+WETA0      = '0+dweta0n_33'      PETA0      = '0+dpeta0n_33'      WK2        = '0+dwk2n_33'
+PK2        = '0+dpk2n_33'  )        



.MODEL nch_33.3 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_33'
+LMAX       = '1.2e-006-dxln_33'  WMIN       = '1e-005-dxwn_33'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.595726+dvthn_33'
+LVTH0      = '3.2469e-010+dlvthn_33'
+K1         = 0.71631             K2         = '-0.05213321+dk2n_33'
+LK2        = '-6.7649162e-009+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000714258+dcitn_33'
+LCIT       = '5.941827e-011+dlcitn_33'
+VOFF       = -0.1271342          LVOFF      = -5.51973e-010       NFACTOR    = 0.55
+ETA0       = '0.5257+deta0n_33'  ETAB       = -0.0915             UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_33'   UA         = -1.0203443e-009
+LUA        = 1.0778085e-016      UB         = 3.4266e-018         LUB        = -2.92221e-025
+UC         = 1.500616e-010       LUC        = 7.013304e-018       VSAT       = '89640+dvsatn_33'
+A0         = '1.3065331+da0n_33' LA0        = '-6.3579172e-007+dla0n_33'
+AGS        = '0.9247153+dagsn_33'
+LAGS       = '-4.6217998e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0454516          LKETA      = 9.221196e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.001078            LPDIBLC2   = 9.7407e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.00180716          LTVOFF     = -2.727396e-010      WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.279301           LKT1       = -4.383315e-009
+KT1L       = 0                   KT2        = -0.062694           LKT2       = 1.94814e-009
+UTE        = -1.51292            LUTE       = 1.883202e-007       UA1        = 2.305763e-009
+LUA1       = 2.1121085e-016      UB1        = -4.247683e-018      LUB1       = 7.5636536e-025
+UC1        = -2.961126e-011      LUC1       = 3.2141063e-017      PRT        = 0
+AT         = 107917.53           LAT        = -0.069758023
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'
+WCIT       = '0+dwcitn_33'       PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'
+LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'
+LETA0      = '0+dleta0n_33'      WETA0      = '0+dweta0n_33'      PETA0      = '0+dpeta0n_33'
+WK2        = '0+dwk2n_33'        PK2        = '0+dpk2n_33'       )



.MODEL nch_33.4 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-dxln_33'    WMIN       = '1e-005-dxwn_33'    WMAX       = 900.0001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.610265+dvthn_33'
+LVTH0      = '-9.634525e-009+dlvthn_33'
+K1         = 0.71631             K2         = '-0.061443975+dk2n_33'
+LK2        = '-3.8704213e-010+dlk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000563835+dcitn_33'
+LCIT       = '1.6245803e-010+dlcitn_33'
+VOFF       = -0.1374945          LVOFF      = 6.5448325e-009      NFACTOR    = 0.55
+ETA0       = '0.5384555+deta0n_33'
+LETA0      = '-8.7375175e-009+dleta0n_33'
+ETAB       = -0.0915             UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03862+du0n_33'   UA         = -6.3473475e-010     LUA        = -1.563617e-016
+UB         = 2.789025e-018       LUB        = 1.4451788e-025      UC         = 1.588935e-010
+LUC        = 9.634525e-019       VSAT       = '89640+dvsatn_33'   A0         = '0.237041+da0n_33'
+LA0        = '9.6810365e-008+dla0n_33'
+AGS        = '0.85381797+dagsn_33'
+LAGS       = '-4.1361531e-007+dlagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0366945          LKETA      = 3.2225825e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '-0.016415+dpclmn_33'
+LPCLM      = '1.7906928e-007+dlpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.004925            LPDIBLC2   = -1.661125e-009
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0010792           LTVOFF     = 2.25913e-010        WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.29831            LKT1       = 8.63785e-009
+KT1L       = 0                   KT2        = -0.0551455          LKT2       = -3.2225825e-009
+UTE        = -1.516875           LUTE       = 1.9102938e-007      UA1        = 2.0056675e-009
+LUA1       = 4.1677626e-016      UB1        = -2.91846e-018       LUB1       = -1.541524e-025
+UC1        = -9.48705e-011       LUC1       = 7.6843643e-017      PRT        = 0
+AT         = 20827.425           LAT        = -0.010101301
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        WU0        = '0+dwu0n_33'        PU0        = '0+dpu0n_33'
+WCIT       = '0+dwcitn_33'       PCIT       = '0+dpcitn_33'       WA0        = '0+dwa0n_33'
+PA0        = '0+dpa0n_33'        WAGS       = '0+dwagsn_33'       PAGS       = '0+dpagsn_33'
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      WETA0      = '0+dweta0n_33'
+PETA0      = '0+dpeta0n_33'      WK2        = '0+dwk2n_33'        PK2        = '0+dpk2n_33'       )



.MODEL nch_33.5 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_33'
+LMAX       = 900.0001e-6         WMIN       = '1e-006-dxwn_33'    WMAX       = '1e-005-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58519021+dvthn_33'
+WVTH0      = '-1.9034426e-009+dwvthn_33'
+K1         = 0.71631             K2         = '-0.049693971+dk2n_33'
+WK2        = '8.915949e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00016853684+dcitn_33'
+WCIT       = '3.148518e-010+dwcitn_33'
+VOFF       = -0.12722308         WVOFF      = 1.2316393e-009      NFACTOR    = 0.55
+ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039247837+du0n_33'
+WU0        = '-6.4829015e-009+dwu0n_33'
+UA         = -9.7030487e-010     WUA        = -4.0979999e-017     UB         = 3.3098324e-018
+WUB        = -3.9860327e-025     UC         = 1.465634e-010       WUC        = -6.0876573e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.1644663+da0n_33' WA0        = '1.2842639e-007+dwa0n_33'
+AGS        = '0.4003119+dagsn_33'
+WAGS       = '-1.7130983e-008+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027370286        WKETA      = 8.4087376e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00072461556       WPDIBLC2   = -2.4632786e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.001581154         LTVOFF     = 0                   WTVOFF     = -2.2169508e-010
+PTVOFF     = 0                   KT1        = -0.27804406         WKT1       = -5.5983606e-010
+KT1L       = 0                   KT2        = -0.057737346        WKT2       = 4.176377e-009
+UTE        = -1.4932869          WUTE       = 2.530459e-007       UA1        = 2.2205804e-009
+WUA1       = 4.4227048e-017      UB1        = -3.6431074e-018     WUB1       = 6.3451819e-025
+UC1        = -2.8036948e-012     WUC1       = -2.6671709e-017     PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       PCIT       = '0+dpcitn_33'
+LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'
+LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'     )  



.MODEL nch_33.6 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_33'
+LMAX       = '1e-005-dxln_33'    WMIN       = '1e-006-dxwn_33'    WMAX       = '1e-005-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58354323+dvthn_33'
+LVTH0      = '1.6445149e-008+dlvthn_33'
+WVTH0      = '-2.4492827e-010+dwvthn_33'
+PVTH0      = '-1.6560265e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.048491719+dk2n_33'
+LK2        = '-1.2004489e-008+dlk2n_33'
+WK2        = '9.0653661e-009+dwk2n_33'
+PK2        = '-1.4919294e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '8.6966544e-005+dcitn_33'
+LCIT       = '8.1447946e-010+dlcitn_33'
+WCIT       = '3.7057788e-010+dwcitn_33'
+PCIT       = '-5.5642492e-016+dpcitn_33'
+VOFF       = -0.12727628         LVOFF      = 5.3125495e-010      WVOFF      = 2.4378316e-009
+PVOFF      = -1.2043829e-014     NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03924665+du0n_33'
+LU0        = '1.1847165e-011+dlu0n_33'
+WU0        = '-6.4979789e-009+dwu0n_33'
+PU0        = '1.5054787e-016+dpu0n_33'
+UA         = -9.7770697e-010     LUA        = 7.3910034e-017      WUA        = -2.7559603e-017
+PUA        = -1.3400266e-022     UB         = 3.3227051e-018      LUB        = -1.2853352e-025
+WUB        = -4.0614197e-025     PUB        = 7.5273934e-032      UC         = 1.4438955e-010
+LUC        = 2.1705896e-017      WUC        = -6.0009622e-017     PUC        = -8.6565024e-024
+VSAT       = '89640+dvsatn_33'   A0         = '1.2162348+da0n_33' LA0        = '-5.1690836e-007+dla0n_33'
+WA0        = '1.5922953e-007+dwa0n_33'
+PA0        = '-3.0756929e-013+dpa0n_33'
+AGS        = '0.38190343+dagsn_33'
+LAGS       = '1.838086e-007+dlagsn_33'
+WAGS       = '-1.6303234e-008+dwagsn_33'
+PAGS       = '-8.2650779e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.025919603        LKETA      = -1.448507e-008
+WKETA      = 8.9032764e-009      PKETA      = -4.9379701e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00056031261       LPDIBLC2   = 1.6405649e-009      WPDIBLC2   = -2.1918854e-010
+PPDIBLC2   = -2.7098616e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0015768317        LTVOFF     = 4.3158041e-011
+WTVOFF     = -2.0269755e-010     PTVOFF     = -1.8969031e-016     KT1        = -0.27727725
+LKT1       = -7.6565402e-009     WKT1       = -1.6303317e-009     PKT1       = 1.0688899e-014
+KT1L       = 0                   KT2        = -0.05726505         LKT2       = -4.7158692e-009
+WKT2       = 4.4764173e-009      PKT2       = -2.9959026e-015     UTE        = -1.5083518
+LUTE       = 1.5042269e-007      WUTE       = 2.5018119e-007      PUTE       = 2.8604095e-014
+UA1        = 2.1881249e-009      LUA1       = 3.2406778e-016      WUA1       = 1.9997662e-017
+PUA1       = 2.4193042e-022      UB1        = -3.6434518e-018     LUB1       = 3.43883e-027
+WUB1       = 6.7798634e-025      PUB1       = -4.340295e-031      UC1        = -2.7449416e-012
+LUC1       = -5.8665038e-019     WUC1       = -3.127665e-017      PUC1       = 4.598033e-023
+PRT        = 0                   AT         = 231822.24           LAT        = -0.21789508
+WAT        = -0.0014896474       PAT        = 1.4874129e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.7 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_33'
+LMAX       = '1.2e-006-dxln_33'  WMIN       = '1e-006-dxwn_33'    WMAX       = '1e-005-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.59592069+dvthn_33'
+LVTH0      = '1.7778581e-009+dlvthn_33'
+WVTH0      = '-1.9482295e-009+dwvthn_33'
+PVTH0      = '-1.4541854e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.053331928+dk2n_33'
+LK2        = '-6.2688409e-009+dlk2n_33'
+WK2        = '1.1995574e-008+dwk2n_33'
+PK2        = '-4.9642252e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00071840069+dcitn_33'
+LCIT       = '6.6229996e-011+dlcitn_33'
+WCIT       = '-4.145586e-011+dwcitn_33'
+PCIT       = '-6.8164938e-017+dpcitn_33'
+VOFF       = -0.12551295         LVOFF      = -1.5582919e-009     WVOFF      = -1.6223825e-008
+PVOFF      = 1.0070234e-014      NFACTOR    = 0.55                ETA0       = '0.52793778+deta0n_33'
+WETA0      = '-2.2393442e-008+dweta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039285773+du0n_33'
+LU0        = '-3.4512743e-011+dlu0n_33'
+WU0        = '-6.662385e-009+dwu0n_33'
+PU0        = '3.4536902e-016+dpu0n_33'
+UA         = -1.0189193e-009     LUA        = 1.2274666e-016      WUA        = -1.4259808e-017
+PUA        = -1.4976291e-022     UB         = 3.4813786e-018      LUB        = -3.1656157e-025
+WUB        = -5.4816907e-025     PUB        = 2.4357605e-031      UC         = 1.5864621e-010
+LUC        = 4.8117543e-018      WUC        = -8.5906171e-017     PUC        = 2.2030908e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.3201499+da0n_33' LA0        = '-6.4004769e-007+dla0n_33'
+WA0        = '-1.3626309e-007+dwa0n_33'
+PA0        = '4.2589454e-014+dpa0n_33'
+AGS        = '0.94327311+dagsn_33'
+LAGS       = '-4.8141448e-007+dlagsn_33'
+WAGS       = '-1.8570803e-007+dwagsn_33'
+PAGS       = '1.9247961e-013+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.046761841        LKETA      = 1.0212983e-008
+WKETA      = 1.3111584e-008      PKETA      = -9.924815e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.0011840707        LPDIBLC2   = 9.0141159e-010      WPDIBLC2   = -1.0614492e-009
+PPDIBLC2   = 7.2709268e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0018955298        LTVOFF     = -3.3449925e-010
+WTVOFF     = -8.8431703e-010     PTVOFF     = 6.1802877e-016      KT1        = -0.28045334
+LKT1       = -3.8928708e-009     WKT1       = 1.1531503e-008      PKT1       = -4.9078756e-015
+KT1L       = 0                   KT2        = -0.062655689        LKT2       = 1.6720381e-009
+WKT2       = -3.8337573e-010     PKT2       = 2.7629522e-015      UTE        = -1.5728298
+LUTE       = 2.2682916e-007      WUTE       = 5.9951724e-007      PUTE       = -3.8535912e-013
+UA1        = 2.1764753e-009      LUA1       = 3.3787261e-016      WUA1       = 1.2937822e-015
+PUA1       = -1.2675043e-021     UB1        = -4.249371e-018      LUB1       = 7.2145299e-025
+WUB1       = 1.6891374e-026      PUB1       = 3.4936803e-031      UC1        = -3.2663348e-011
+LUC1       = 3.4866662e-017      WUC1       = 3.0542248e-017      PUC1       = -2.7275064e-023
+PRT        = 0                   AT         = 106493.08           LAT        = -0.069380018
+WAT        = 0.014254512         PAT        = -3.7826996e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.8 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-dxln_33'    WMIN       = '1e-006-dxwn_33'    WMAX       = '1e-005-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.61260823+dvthn_33'
+LVTH0      = '-9.6531111e-009+dlvthn_33'
+WVTH0      = '-2.3448733e-008+dwvthn_33'
+PVTH0      = '1.8599153e-016+dpvthn_33'
+K1         = 0.71631             K2         = '-0.061361997+dk2n_33'
+LK2        = '-7.6824392e-010+dlk2n_33'
+WK2        = '-8.2035576e-010+dwk2n_33'
+PK2        = '3.8146864e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00056199471+dcitn_33'
+LCIT       = '1.7336809e-010+dlcitn_33'
+WCIT       = '1.8415807e-011+dwcitn_33'
+PCIT       = '-1.0917703e-016+dpcitn_33'
+VOFF       = -0.13952383         LVOFF      = 8.0391584e-009      WVOFF      = 2.0307493e-008
+PVOFF      = -1.4953719e-014     NFACTOR    = 0.55                ETA0       = '0.54212048+deta0n_33'
+LETA0      = '-9.7151486e-009+dleta0n_33'
+WETA0      = '-3.667542e-008+dweta0n_33'
+PETA0      = '9.7831547e-015+dpeta0n_33'
+ETAB       = -0.092512594        WETAB      = 1.0133033e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.039864876+du0n_33'
+LU0        = '-4.3119852e-010+dlu0n_33'
+WU0        = '-1.2457472e-008+dwu0n_33'
+PU0        = '4.3150036e-015+dpu0n_33'
+UA         = -5.7018434e-010     LUA        = -1.846368e-016      WUA        = -6.4595592e-016
+PUA        = 2.8294892e-022      UB         = 2.795246e-018       LUB        = 1.5343922e-025
+WUB        = -6.2253769e-026     PUB        = -8.9275936e-032     UC         = 1.6565338e-010
+LUC        = 1.1841976e-020      WUC        = -6.764611e-017      PUC        = 9.5227665e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.2429578+da0n_33' LA0        = '9.7828886e-008+dla0n_33'
+WA0        = '-5.9209381e-008+dwa0n_33'
+PA0        = '-1.0192336e-014+dpa0n_33'
+AGS        = '0.82120683+dagsn_33'
+LAGS       = '-3.9779908e-007+dlagsn_33'
+WAGS       = '3.2633961e-007+dwagsn_33'
+PAGS       = '-1.5827303e-013+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.033517974        LKETA      = 1.1409345e-009
+WKETA      = -3.1787491e-008     PKETA      = 2.0831052e-014      DWG        = 0
+DWB        = 0                   PCLM       = '-0.018151516+dpclmn_33'
+LPCLM      = '1.8025879e-007+dlpclmn_33'
+WPCLM      = '1.7377311e-008+dwpclmn_33'
+PPCLM      = '-1.1903458e-014+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0049521331        LPDIBLC2   = -1.6797111e-009
+WPDIBLC2   = -2.7152049e-010     PPDIBLC2   = 1.8599153e-016      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.00095938099
+LTVOFF     = 3.0676272e-010      WTVOFF     = 1.1990289e-009      PTVOFF     = -8.0906317e-016
+KT1        = -0.29378102         LKT1       = 5.2365858e-009      WKT1       = -4.5321528e-008
+PKT1       = 3.4036451e-014      KT1L       = 0                   KT2        = -0.054709833
+LKT2       = -3.7708737e-009     WKT2       = -4.3597233e-009     PKT2       = 5.4867502e-015
+UTE        = -1.4961476          LUTE       = 1.7430185e-007      WUTE       = -2.0741926e-007
+PUTE       = 1.6739238e-013      UA1        = 2.1614356e-009      LUA1       = 3.4817481e-016
+WUA1       = -1.5587711e-015     PUA1       = 6.8649475e-022      UB1        = -3.0099966e-018
+LUB1       = -1.2751846e-025     WUB1       = 9.1600655e-025      PUB1       = -2.6652587e-031
+UC1        = -1.0154792e-010     LUC1       = 8.2052595e-017      WUC1       = 6.6820968e-017
+PUC1       = -5.2125987e-023     PRT        = 0                   AT         = 17838.697
+LAT        = -0.0086517678       WAT        = 0.029908206         PAT        = -1.450548e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      )



.MODEL nch_33.9 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_33'
+LMAX       = 900.0001e-6         WMIN       = '6e-007-dxwn_33'    WMAX       = '1e-006-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58709375+dvthn_33'
+WVTH0      = '-3.8203063e-009+dwvthn_33'
+K1         = 0.71631             K2         = '-0.0438143+dk2n_33'
+WK2        = '2.9951201e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00057604375+dcitn_33'
+WCIT       = '-9.5507656e-011+dwcitn_33'
+VOFF       = -0.13276805         WVOFF      = 6.8154264e-009      NFACTOR    = 0.55
+ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.037134875+du0n_33'
+WU0        = '-4.3551491e-009+dwu0n_33'
+UA         = -8.13725e-010       WUA        = -1.9865593e-016     UB         = 3.02933e-018
+WUB        = -1.1613731e-025     UC         = 1.2242378e-010      WUC        = -3.6567971e-017
+VSAT       = '89640+dvsatn_33'   A0         = '1.472886+da0n_33'  WA0        = '-1.821522e-007+dwa0n_33'
+AGS        = '0.4053948+dagsn_33'
+WAGS       = '-2.2249464e-008+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.02396705         WKETA      = 4.9816794e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.000677275         WPDIBLC2   = -1.9865593e-010
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.0016022825        LTVOFF     = 0                   WTVOFF     = -2.4297148e-010
+PTVOFF     = 0                   KT1        = -0.29908625         WKT1       = 2.0629654e-008
+KT1L       = 0                   KT2        = -0.057581025        WKT2       = 4.0189622e-009
+UTE        = -1.5804025          WUTE       = 3.4077132e-007      UA1        = 1.6188038e-009
+WUA1       = 6.5021612e-016      UB1        = -3.0316653e-018     WUB1       = 1.8795907e-026
+UC1        = -4.4480175e-011     WUC1       = 1.5296506e-017      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       PVTH0      = '0+dpvthn_33'       LU0        = '0+dlu0n_33'
+PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'       PCIT       = '0+dpcitn_33'
+LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'        LAGS       = '0+dlagsn_33'
+PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'
+LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'        )



.MODEL nch_33.10 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_33'
+LMAX       = '1e-005-dxln_33'    WMIN       = '6e-007-dxwn_33'    WMAX       = '1e-006-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58560203+dvthn_33'
+LVTH0      = '1.4894822e-008+dlvthn_33'
+WVTH0      = '-2.3181445e-009+dwvthn_33'
+PVTH0      = '-1.4999085e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.042189234+dk2n_33'
+LK2        = '-1.6226287e-008+dlk2n_33'
+WK2        = '2.7187635e-009+dwk2n_33'
+PK2        = '2.7594208e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00055414428+dcitn_33'
+LCIT       = '2.1866624e-010+dlcitn_33'
+WCIT       = '-9.9870099e-011+dwcitn_33'
+PCIT       = '4.3558988e-017+dpcitn_33'
+VOFF       = -0.13106354         LVOFF      = -1.7019513e-008     WVOFF      = 6.2516012e-009
+PVOFF      = 5.6297937e-015      NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.03736393+du0n_33'
+LU0        = '-2.2871153e-009+dlu0n_33'
+WU0        = '-4.6020798e-009+dwu0n_33'
+PU0        = '2.4656031e-015+dpu0n_33'
+UA         = -7.9247411e-010     LUA        = -2.1219012e-016     WUA        = -2.1408909e-016
+PUA        = 1.5410019e-022      UB         = 3.0385989e-018      LUB        = -9.2550185e-026
+WUB        = -1.2004705e-025     PUB        = 3.9038715e-032      UC         = 1.232626e-010
+LUC        = -8.3757027e-018     WUC        = -3.8734788e-017     PUC        = 2.1635667e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.5788249+da0n_33' LA0        = '-1.0578002e-006+dla0n_33'
+WA0        = '-2.0589871e-007+dwa0n_33'
+PA0        = '2.3710883e-013+dpa0n_33'
+AGS        = '0.39080402+dagsn_33'
+LAGS       = '1.4568891e-007+dlagsn_33'
+WAGS       = '-2.5266134e-008+dwagsn_33'
+PAGS       = '3.0121451e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.023024514        LKETA      = -9.411224e-009
+WKETA      = 5.987922e-009       PKETA      = -1.0047333e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00066866019       LPDIBLC2   = 8.6018931e-011      WPDIBLC2   = -3.2829455e-010
+PPDIBLC2   = 1.2944416e-015      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.001708781         LTVOFF     = -1.0633876e-009
+WTVOFF     = -3.3557049e-010     PTVOFF     = 9.2460116e-016      KT1        = -0.301099
+LKT1       = 2.0097303e-008      WKT1       = 2.2358169e-008      PKT1       = -1.7259222e-014
+KT1L       = 0                   KT2        = -0.056806688        LKT2       = -7.731754e-009
+WKT2       = 4.0148467e-009      PKT2       = 4.1093385e-017      UTE        = -1.6240597
+LUTE       = 4.3591665e-007      WUTE       = 3.6669904e-007      PUTE       = -2.5888832e-013
+UA1        = 1.4496318e-009      LUA1       = 1.6891816e-015      WUA1       = 7.6366021e-016
+PUA1       = -1.1327392e-021     UB1        = -2.9143598e-018     LUB1       = -1.1712945e-024
+WUB1       = -5.6209295e-026     PUB1       = 7.4892694e-031      UC1        = -5.025414e-011
+LUC1       = 5.7653037e-017      WUC1       = 1.6565113e-017      PUC1       = -1.2667036e-023
+PRT        = 0                   AT         = 230187.65           LAT        = -0.20157365
+WAT        = 0.00015638945       PAT        = -1.5615486e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'     )



.MODEL nch_33.11 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_33'
+LMAX       = '1.2e-006-dxln_33'  WMIN       = '6e-007-dxwn_33'    WMAX       = '1e-006-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.60116529+dvthn_33'
+LVTH0      = '-3.5476441e-009+dlvthn_33'
+WVTH0      = '-7.2295476e-009+dwvthn_33'
+PVTH0      = '-9.1790728e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.046546386+dk2n_33'
+LK2        = '-1.1063061e-008+dlk2n_33'
+WK2        = '5.1625327e-009+dwk2n_33'
+PK2        = '-1.3644568e-016+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00073512411+dcitn_33'
+LCIT       = '4.2051414e-012+dlcitn_33'
+WCIT       = '-5.8296345e-011+dwcitn_33'
+PCIT       = '-5.7059101e-018+dpcitn_33'
+VOFF       = -0.15961852         LVOFF      = 1.681813e-008       WVOFF      = 1.8120477e-008
+PVOFF      = -8.4348236e-015     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.038603884+du0n_33'
+LU0        = '-3.7564604e-009+dlu0n_33'
+WU0        = '-5.975723e-009+dwu0n_33'
+PU0        = '4.0933703e-015+dpu0n_33'
+UA         = -5.9806283e-010     LUA        = -4.4256749e-016     WUA        = -4.3806229e-016
+PUA        = 4.1950843e-022      UB         = 2.8655154e-018      LUB        = 1.1255379e-025
+WUB        = 7.2005132e-026      PUB        = -1.8854312e-031     UC         = 7.0470339e-011
+LUC        = 5.4183131e-017      WUC        = 2.886929e-018       PUC        = -2.7686068e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.2496434+da0n_33' LA0        = '-6.6772012e-007+dla0n_33'
+WA0        = '-6.5263056e-008+dwa0n_33'
+PA0        = '7.0455585e-014+dpa0n_33'
+AGS        = '0.79778898+dagsn_33'
+LAGS       = '-3.3658827e-007+dlagsn_33'
+WAGS       = '-3.9205511e-008+dwagsn_33'
+PAGS       = '4.6639613e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.022848026        LKETA      = -9.6203618e-009
+WKETA      = -1.0969627e-008     PKETA      = 1.0047363e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = -0.0016682375       LPDIBLC2   = 2.8552427e-009      WPDIBLC2   = 1.8108252e-009
+PPDIBLC2   = -1.2404152e-015     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 3.5234e-005         LTVOFF     = 9.197656e-010
+WTVOFF     = 9.8900088e-010      PTVOFF     = -6.4501592e-016     KT1        = -0.27882023
+LKT1       = -6.3030446e-009     WKT1       = 9.8869526e-009      PKT1       = -2.4808305e-015
+KT1L       = 0                   KT2        = -0.06585197         LKT2       = 2.9869045e-009
+WKT2       = 2.8352785e-009      PKT2       = 1.4388817e-015      UTE        = -0.94588565
+LUTE       = -3.6771954e-007     WUTE       = -3.181551e-008      PUTE       = 2.1335142e-013
+UA1        = 4.9718988e-009      LUA1       = -2.4847048e-015     WUA1       = -1.5212093e-015
+PUA1       = 1.5748312e-021      UB1        = -6.0827527e-018     LUB1       = 2.5832511e-024
+WUB1       = 1.8631068e-024      PUB1       = -1.5254627e-030     UC1        = -4.0331162e-012
+LUC1       = 2.8811245e-018      WUC1       = 1.7116042e-018      PUC1       = 4.9343718e-024
+PRT        = 0                   AT         = 127726.88           LAT        = -0.080157641
+WAT        = -0.0071279274       PAT        = 7.0703669e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.12 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-dxln_33'    WMIN       = '6e-007-dxwn_33'    WMAX       = '1e-006-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.62416051+dvthn_33'
+LVTH0      = '-1.9299366e-008+dlvthn_33'
+WVTH0      = '-3.5081872e-008+dwvthn_33'
+PVTH0      = '9.8997697e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.084614633+dk2n_33'
+LK2        = '1.5013688e-008+dlk2n_33'
+WK2        = '2.2595049e-008+dwk2n_33'
+PK2        = '-1.2077719e-014+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '4.4407725e-005+dcitn_33'
+LCIT       = '4.7734586e-010+dlcitn_33'
+WCIT       = '5.396259e-010+dwcitn_33'
+PCIT       = '-4.1528265e-016+dpcitn_33'
+VOFF       = -0.14499566         LVOFF      = 6.8014763e-009      WVOFF      = 2.581763e-008
+PVOFF      = -1.3707373e-014     NFACTOR    = 0.55                ETA0       = '0.568828+deta0n_33'
+WETA0      = '-6.3569896e-008+dweta0n_33'
+ETAB       = -0.0836033          WETAB      = 1.1613731e-009      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.027494+du0n_33'  LU0        = '3.85381e-009+dlu0n_33'
+UA         = -1.544506e-009      LUA        = 2.0574611e-016      WUA        = 3.3518603e-016
+PUA        = -1.1016667e-022     UB         = 3.0456506e-018      LUB        = -1.0838841e-026
+WUB        = -3.144112e-025      PUB        = 7.6152075e-032      UC         = 1.3026419e-010
+LUC        = 1.3224341e-017      WUC        = -3.20092e-017       PUC        = -3.7822197e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.071022788+da0n_33'
+LA0        = '1.39635e-007+dla0n_33'
+WA0        = '1.1392917e-007+dwa0n_33'
+PA0        = '-5.2291091e-014+dpa0n_33'
+AGS        = '1.0470243+dagsn_33'
+LAGS       = '-5.0731446e-007+dlagsn_33'
+WAGS       = '9.8941424e-008+dwagsn_33'
+PAGS       = '-4.7991037e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.057717038        LKETA      = 1.4264911e-008
+WKETA      = -7.4190347e-009     PKETA      = 7.6152075e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.063135913+dpclmn_33'
+LPCLM      = '1.245769e-007+dlpclmn_33'
+WPCLM      = '-6.4479129e-008+dwpclmn_33'
+PPCLM      = '4.4168203e-014+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.0065224688        LPDIBLC2   = -2.7553911e-009
+WPDIBLC2   = -1.8528485e-009     PPDIBLC2   = 1.2692012e-015      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0014579395
+LTVOFF     = -5.478764e-011      WTVOFF     = 6.9698049e-010      PTVOFF     = -4.4498196e-016
+KT1        = -0.41345609         LKT1       = 8.5922521e-008      WKT1       = 7.5191268e-008
+PKT1       = -4.7214286e-014     KT1L       = 0                   KT2        = -0.083150049
+LKT2       = 1.4836089e-008      WKT2       = 2.4279574e-008      PKT2       = -1.3250461e-014
+UTE        = -4.5226643          LUTE       = 2.0823738e-006      WUTE       = 2.8402831e-006
+PUTE       = -1.7540361e-012     UA1        = -8.8292082e-009     LUA1       = 6.9690535e-015
+WUA1       = 9.5088072e-015      PUA1       = -5.9807301e-021     UB1        = 3.5556533e-018
+LUB1       = -4.0190571e-024     WUB1       = -5.6956029e-024     PUB1       = 3.6522535e-030
+UC1        = -9.3333628e-011     LUC1       = 6.4051975e-017      WUC1       = 5.8549173e-017
+PUC1       = -3.3999363e-023     PRT        = 0                   AT         = 36676.356
+LAT        = -0.017788033        WAT        = 0.010938683         PAT        = -5.3052612e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+WU0        = '0+dwu0n_33'
+PU0        = '0+dpu0n_33'        LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.13 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_33'
+LMAX       = 900.0001e-6         WMIN       = 4e-07               WMAX       = '6e-007-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.5808+dvthn_33'
+K1         = 0.71631             K2         = '-0.05041845+dk2n_33'
+WK2        = '7.0038392e-009+dwk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000704414+dcitn_33'
+WCIT       = '-1.734284e-010+dwcitn_33'
+VOFF       = -0.1114464          WVOFF      = -6.1268152e-009     NFACTOR    = 0.55
+ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029553+du0n_33'  WU0        = '2.47049e-010+dwu0n_33'
+UA         = -1.240715e-009      WUA        = 6.0527005e-017      UB         = 3.00894e-018
+WUB        = -1.0376058e-025     UC         = 8.6193e-011         WUC        = -1.4575891e-017
+VSAT       = '89640+dvsatn_33'   A0         = '0.761323+da0n_33'  WA0        = '2.4976654e-007+dwa0n_33'
+AGS        = '0.3716704+dagsn_33'
+WAGS       = '-1.7787528e-009+dwagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.0189346          WKETA      = 1.9269822e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.245+dpclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00045175          WPDIBLC2   = -6.176225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0
+RSW        = 80                  RDW        = 80                  PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 1.8998              BETA0      = 16.376              AGIDL      = 1.55e-008
+BGIDL      = 3.486e+009          CGIDL      = 0.5                 EGIDL      = 0.8
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'cgon_33'           CGDO       = 'cgon_33'
+CGBO       = 0                   CGDL       = 'cgln_33'           CGSL       = 'cgln_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 8.339               NOFF       = 2.5646              VOFFCV     = -0.0366
+TVOFF      = 0.000923205         LTVOFF     = 0                   WTVOFF     = 1.6922857e-010
+PTVOFF     = 0                   KT1        = -0.274461           WKT1       = 5.682127e-009
+KT1L       = 0                   KT2        = -0.0508379          WKT2       = -7.41147e-011
+UTE        = -1.057665           WUTE       = 2.3469655e-008      UA1        = 2.985075e-009
+WUA1       = -1.7911053e-016     UB1        = -3.441074e-018      WUB1       = 2.6730702e-025
+UC1        = -3.395235e-011      WUC1       = 8.9061165e-018      PRT        = 0
+AT         = 210000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7
+JSD        = 1.399e-7            JSWS       = 5e-14               JSWD       = 5e-14
+JSWGS      = 9e-14               JSWGD      = 9e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjn_33'
+CJD        = 'cjn_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.48                PBSWD      = 0.48                CJSWS      = 'cjswn_33'
+CJSWD      = 'cjswn_33'          MJSWS      = 0.12                MJSWD      = 0.12
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'
+CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3                 MJSWGD     = 0.3
+TPB        = 1.7e-3              TCJ        = 8.62e-4             TPBSW      = 1.1e-3
+TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1.5e-009
+JTSSWGD    = 1.5e-009            NJTSSWG    = 16                  XTSSWGS    = 0.27919
+XTSSWGD    = 0.27919             TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVTH0      = '0+dlvthn_33'       WVTH0      = '0+dwvthn_33'       PVTH0      = '0+dpvthn_33'
+LU0        = '0+dlu0n_33'        PU0        = '0+dpu0n_33'        LCIT       = '0+dlcitn_33'
+PCIT       = '0+dpcitn_33'       LA0        = '0+dla0n_33'        PA0        = '0+dpa0n_33'
+LAGS       = '0+dlagsn_33'       PAGS       = '0+dpagsn_33'       LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'
+WPCLM      = '0+dwpclmn_33'      PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'
+PETA0      = '0+dpeta0n_33'      LK2        = '0+dlk2n_33'        PK2        = '0+dpk2n_33'    )   



.MODEL nch_33.14 NMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxln_33'
+LMAX       = '1e-005-dxln_33'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.58109793+dvthn_33'
+LVTH0      = '-2.9748634e-009+dlvthn_33'
+WVTH0      = '4.1584242e-010+dwvthn_33'
+PVTH0      = '-4.1521866e-015+dpvthn_33'
+K1         = 0.71631             K2         = '-0.049559692+dk2n_33'
+LK2        = '-8.5746992e-009+dlk2n_33'
+WK2        = '7.1926316e-009+dwk2n_33'
+PK2        = '-1.8850927e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00070157983+dcitn_33'
+LCIT       = '2.8299186e-011+dlcitn_33'
+WCIT       = '-1.8936348e-010+dwcitn_33'
+PCIT       = '1.5911179e-016+dpcitn_33'
+VOFF       = -0.11112018         LVOFF      = -3.2573578e-009     WVOFF      = -5.8540226e-009
+PVOFF      = -2.7238344e-015     NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.029687646+du0n_33'
+LU0        = '-1.3444366e-009+dlu0n_33'
+WU0        = '5.7424856e-011+dwu0n_33'
+PU0        = '1.8933971e-015+dpu0n_33'
+UA         = -1.214746e-009      LUA        = -2.5930052e-016     WUA        = 4.2229938e-017
+PUA        = 1.8269621e-022      UB         = 2.9991624e-018      LUB        = 9.7629302e-026
+WUB        = -9.6109079e-026     PUB        = -7.6400233e-032     UC         = 8.42157e-011
+LUC        = 1.9743345e-017      WUC        = -1.5033318e-017     PUC        = 4.5674052e-024
+VSAT       = '89640+dvsatn_33'   A0         = '0.77421149+da0n_33'
+LA0        = '-1.2869158e-007+dla0n_33'
+WA0        = '2.8250165e-007+dwa0n_33'
+PA0        = '-3.2686013e-013+dpa0n_33'
+AGS        = '0.35349094+dagsn_33'
+LAGS       = '1.8152193e-007+dlagsn_33'
+WAGS       = '-2.6170911e-009+dwagsn_33'
+PAGS       = '8.3708082e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.017087919        LKETA      = -1.8439111e-008
+WKETA      = 2.3844089e-009      PKETA      = -4.5674052e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00018845781       LPDIBLC2   = 2.6289725e-009      WPDIBLC2   = -3.6811705e-011
+PPDIBLC2   = -2.491312e-016      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.0008272779        LTVOFF     = 9.5783206e-010
+WTVOFF     = 1.9950189e-010      PTVOFF     = -3.0227918e-016     KT1        = -0.2761472
+LKT1       = 1.6836718e-008      WKT1       = 7.2124271e-009      PKT1       = -1.5280047e-014
+KT1L       = 0                   KT2        = -0.048946815        LKT2       = -1.8882483e-008
+WKT2       = -7.5609627e-010     PKT2       = 6.809586e-015       UTE        = -1.0835445
+LUTE       = 2.5840638e-007      WUTE       = 3.8606319e-008      PUTE       = -1.5113959e-013
+UA1        = 3.0150179e-009      LUA1       = -2.9898016e-016     WUA1       = -1.8652915e-016
+PUA1       = 7.4075009e-023      UB1        = -3.5027448e-018     LUB1       = 6.157826e-025
+WUB1       = 3.0094035e-025      PUB1       = -3.3582885e-031     UC1        = -4.0762502e-011
+LUC1       = 6.7999367e-017      WUC1       = 1.0803689e-017      PUC1       = -1.8947258e-023
+PRT        = 0                   AT         = 230582.31           LAT        = -0.20551432
+WAT        = -8.3168484e-005     PAT        = 8.3043732e-010
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.15 NMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxln_33'
+LMAX       = '1.2e-006-dxln_33'  WMIN       = 4e-07               WMAX       = '6e-007-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.57817239+dvthn_33'
+LVTH0      = '4.9190535e-010+dlvthn_33'
+WVTH0      = '6.7271443e-009+dwvthn_33'
+PVTH0      = '-1.1631079e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.049960487+dk2n_33'
+LK2        = '-8.0997573e-009+dlk2n_33'
+WK2        = '7.2348917e-009+dwk2n_33'
+PK2        = '-1.935171e-015+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00076636715+dcitn_33'
+LCIT       = '-4.8473782e-011+dlcitn_33'
+WCIT       = '-7.7260869e-011+dwcitn_33'
+PCIT       = '2.6270196e-017+dpcitn_33'
+VOFF       = -0.11301734         LVOFF      = -1.0092177e-009     WVOFF      = -1.0166437e-008
+PVOFF      = 2.3863766e-015      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.024972879+du0n_33'
+LU0        = '4.2425619e-009+dlu0n_33'
+WU0        = '2.2982969e-009+dwu0n_33'
+PU0        = '-7.6203623e-016+dpu0n_33'
+UA         = -1.9959877e-009     LUA        = 6.6647087e-016      WUA        = 4.1047809e-016
+PUA        = -2.5367785e-022     UB         = 3.583244e-018       LUB        = -5.9450739e-025
+WUB        = -3.6365613e-025     PUB        = 2.4064302e-031      UC         = 7.0308009e-011
+LUC        = 3.6223959e-017      WUC        = 2.9854636e-018      PUC        = -1.6784851e-023
+VSAT       = '89640+dvsatn_33'   A0         = '1.2504613+da0n_33' LA0        = '-6.9304756e-007+dla0n_33'
+WA0        = '-6.5759503e-008+dwa0n_33'
+PA0        = '8.5829344e-014+dpa0n_33'
+AGS        = '0.85077416+dagsn_33'
+LAGS       = '-4.0775869e-007+dlagsn_33'
+WAGS       = '-7.1367515e-008+dwagsn_33'
+PAGS       = '8.9840061e-014+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.027708884        LKETA      = -5.8532678e-009
+WKETA      = -8.019087e-009      PKETA      = 7.7607374e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.245+dpclmn_33'   PDIBLC1    = 0
+PDIBLC2    = 0.00283718          LPDIBLC2   = -5.097633e-010      WPDIBLC2   = -9.2396326e-010
+PPDIBLC2   = 8.021434e-016       PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0                   DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80                  RDW        = 80
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 0                   ALPHA1     = 1.8998              BETA0      = 16.376
+AGIDL      = 1.55e-008           BGIDL      = 3.486e+009          CGIDL      = 0.5
+EGIDL      = 0.8                 AIGC       = 0.43                AIGSD      = 0.43
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_33'
+CGDO       = 'cgon_33'           CGBO       = 0                   CGDL       = 'cgln_33'
+CGSL       = 'cgln_33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 8.339               NOFF       = 2.5646
+VOFFCV     = -0.0366             TVOFF      = 0.00061028755       LTVOFF     = 1.2149656e-009
+WTVOFF     = 6.3994338e-010      PTVOFF     = -8.2420234e-016     KT1        = -0.19295128
+LKT1       = -8.1750448e-008     WKT1       = -4.2235497e-008     PKT1       = 4.3315744e-014
+KT1L       = 0                   KT2        = -0.075201336        LKT2       = 1.2229124e-008
+WKT2       = 8.510344e-009       PKT2       = -4.1711457e-015     UTE        = -0.5897127
+LUTE       = -3.2678425e-007     WUTE       = -2.4801249e-007     PUTE       = 1.885037e-013
+UA1        = 2.958376e-009       LUA1       = -2.3185951e-016     WUA1       = -2.9900093e-016
+PUA1       = 2.0735407e-022      UB1        = -3.0339172e-018     LUB1       = 6.0221878e-026
+WUB1       = 1.2463622e-026      PUB1       = 6.0160755e-033      UC1        = 4.047274e-011
+LUC1       = -2.8264394e-017     WUC1       = -2.530345e-017      PUC1       = 2.3839702e-023
+PRT        = 0                   AT         = 107494.79           LAT        = -0.059655618
+WAT        = 0.005152948         PAT        = -5.3743608e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7            JSWS       = 5e-14
+JSWD       = 5e-14               JSWGS      = 9e-14               JSWGD      = 9e-14
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   BVD        = 9                   XJBVS      = 1
+XJBVD      = 1                   PBS        = 0.7                 PBD        = 0.7
+CJS        = 'cjn_33'            CJD        = 'cjn_33'            MJS        = 0.31
+MJD        = 0.31                PBSWS      = 0.48                PBSWD      = 0.48
+CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'          MJSWS      = 0.12
+MJSWD      = 0.12                PBSWGS     = 0.6                 PBSWGD     = 0.6
+CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'         MJSWGS     = 0.3
+MJSWGD     = 0.3                 TPB        = 1.7e-3              TCJ        = 8.62e-4
+TPBSW      = 1.1e-3              TCJSW      = 3.52e-4             TPBSWG     = 1.4e-3
+TCJSWG     = 1e-3                XTIS       = 3                   XTID       = 3
+JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009            NJTSSWG    = 16
+XTSSWGS    = 0.27919             XTSSWGD    = 0.27919             TNJTSSWG   = 0
+VTSSWGS    = 1                   VTSSWGD    = 1                   DMCG       = 1.245e-7
+DMCI       = 3.05e-7             DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'      WVSAT      = '0+dwvsatn_33'
+PVSAT      = '0+dpvsatn_33'      LPCLM      = '0+dlpclmn_33'      WPCLM      = '0+dwpclmn_33'
+PPCLM      = '0+dppclmn_33'      LETA0      = '0+dleta0n_33'      PETA0      = '0+dpeta0n_33'      )



.MODEL nch_33.16 NMOS	(	LEVEL      = 54                  LMIN       = 5e-07
+LMAX       = '7e-007-dxln_33'    WMIN       = 4e-07               WMAX       = '6e-007-dxwn_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxn_33'           TOXM       = 5.6e-009            DTOX       = 3.3653e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxln_33'  XW         = '7e-09+dxwn_33'
+DLC        = 'dlcn_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '0.55808764+dvthn_33'
+LVTH0      = '1.4249961e-008+dlvthn_33'
+WVTH0      = '5.024359e-009+dwvthn_33'
+PVTH0      = '-1.0464671e-014+dpvthn_33'
+K1         = 0.71631             K2         = '-0.05327862+dk2n_33'
+LK2        = '-5.8268361e-009+dlk2n_33'
+WK2        = '3.5740888e-009+dwk2n_33'
+PK2        = '5.7247908e-016+dpk2n_33'
+K3         = -2.272              K3B        = 2.548               W0         = 0
+DVT0       = 38.99               DVT1       = 0.4502              DVT2       = 0.01565
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.326               MINV       = -0.3                VOFFL      = 0
+DVTP0      = 1.154e-007          DVTP1      = 3.5                 LPE0       = 8.393e-008
+LPEB       = 4.44089e-021
+WEB        = -300
+WEC        = -500
+SCREF      = 1e-6
+KVTH0WE    = 0.0155
+LKVTH0WE   = -1.5e-9
+WKVTH0WE   = 0.5e-8
+PKVTH0WE   = -5e-17
+K2WE       = 0.0033
+LK2WE      = -1e-10
+WK2WE      = 9e-10
+PK2WE      = -5e-17
+XJ         = 8.1e-008            NGATE      = 6.423e+020          NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0013478911+dcitn_33'
+LCIT       = '-4.4681771e-010+dlcitn_33'
+WCIT       = '-2.5158853e-010+dwcitn_33'
+PCIT       = '1.4568464e-016+dpcitn_33'
+VOFF       = -0.057007723        LVOFF      = -3.9375805e-008     WVOFF      = -2.759105e-008
+PVOFF      = 1.4322237e-014      NFACTOR    = 0.55                ETA0       = '0.647657+deta0n_33'
+WETA0      = '-1.114191e-007+dweta0n_33'
+ETAB       = -0.05167375         WETAB      = -1.8219864e-008     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0020
+LKU0WE     = -7e-10
+WKU0WE     = -15e-10
+PKU0WE     = -0.0e-17
+U0         = '0.027415653+du0n_33'
+LU0        = '2.569262e-009+dlu0n_33'
+WU0        = '4.7556933e-011+dwu0n_33'
+PU0        = '7.7972061e-016+dpu0n_33'
+UA         = -3.1525033e-010     LUA        = -4.8483422e-016     WUA        = -4.1097219e-016
+PUA        = 3.0901559e-022      UB         = 1.9361005e-018      LUB        = 5.3378591e-025
+WUB        = 3.5908572e-025      PUB        = -2.5443515e-031     UC         = 2.7124189e-010
+LUC        = -1.0141575e-016     WUC        = -1.1758266e-016     PUC        = 6.5804316e-023
+VSAT       = '89640+dvsatn_33'   A0         = '-0.34514734+da0n_33'
+LA0        = '3.9994433e-007+dla0n_33'
+WA0        = '3.6654444e-007+dwa0n_33'
+PA0        = '-2.1029886e-013+dpa0n_33'
+AGS        = '1.1144919+dagsn_33'
+LAGS       = '-5.8840536e-007+dlagsn_33'
+WAGS       = '5.7988577e-008+dwagsn_33'
+PAGS       = '1.2311378e-015+dpagsn_33'
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.15385781         LKETA      = 8.0558749e-008
+WKETA      = 5.0938416e-008      PKETA      = -3.2625152e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.29050755+dpclmn_33'
+LPCLM      = '-3.1172672e-008+dlpclmn_33'
+WPCLM      = '-2.0249371e-007+dwpclmn_33'
+PPCLM      = '1.3870819e-013+dppclmn_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.00044751625       LPDIBLC2   = 1.1271564e-009
+WPDIBLC2   = 1.8346476e-009      PPDIBLC2   = -1.0875051e-015     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0                   DELTA      = 0.0075
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 0
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 15.52
+RDSW       = 0                   RSW        = 80
+RDW        = 80                  PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 1.8998
+BETA0      = 16.376              AGIDL      = 1.55e-008           BGIDL      = 3.486e+009
+CGIDL      = 0.5                 EGIDL      = 0.8                 AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_33'           CGDO       = 'cgon_33'           CGBO       = 0
+CGDL       = 'cgln_33'           CGSL       = 'cgln_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 8.339
+NOFF       = 2.5646              VOFFCV     = -0.0366             TVOFF      = 0.0081349215
+LTVOFF     = -3.9394086e-009     WTVOFF     = -3.3559476e-009     PTVOFF     = 1.912983e-015
+KT1        = -0.41004433         LKT1       = 6.6958288e-008      WKT1       = 7.3120328e-008
+PKT1       = -3.5702997e-014     KT1L       = 0                   KT2        = 0.0022587488
+LKT2       = -4.0831034e-008     WKT2       = -2.7563566e-008     PKT2       = 2.0539483e-014
+UTE        = 1.8537909           LUTE       = -2.0005842e-006     WUTE       = -1.0302252e-006
+PUTE       = 7.2431941e-013      UA1        = 1.3867563e-008      LUA1       = -7.7046524e-015
+WUA1       = -4.2681328e-015     PUA1       = 2.9262094e-021      UB1        = -1.1144346e-017
+LUB1       = 5.6158658e-024      WUB1       = 3.2272968e-024      PUB1       = -2.1961447e-030
+UC1        = -8.990499e-011      LUC1       = 6.104435e-017       WUC1       = 5.646799e-017
+PUC1       = -3.2173735e-023     PRT        = 0                   AT         = 69891.578
+LAT        = -0.033897415        WAT        = -0.0092229568       PAT        = 4.473134e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_33'
+NOIB       = 'noibn_33'
+NOIC       = 'noicn_33'
+EM         = 1.1200e+08
+EF         = 1.00
+JSS        = 1.399e-7            JSD        = 1.399e-7
+JSWS       = 5e-14               JSWD       = 5e-14               JSWGS      = 9e-14
+JSWGD      = 9e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjn_33'            CJD        = 'cjn_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.48
+PBSWD      = 0.48                CJSWS      = 'cjswn_33'          CJSWD      = 'cjswn_33'
+MJSWS      = 0.12                MJSWD      = 0.12                PBSWGS     = 0.6
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_33'         CJSWGD     = 'cjswgn_33'
+MJSWGS     = 0.3                 MJSWGD     = 0.3                 TPB        = 1.7e-3
+TCJ        = 8.62e-4             TPBSW      = 1.1e-3              TCJSW      = 3.52e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1e-3                XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1.5e-009            JTSSWGD    = 1.5e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.27919             XTSSWGD    = 0.27919
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = -5e-009
+LKVTH0     = 2.5e-007
+WKVTH0     = 2.6e-006
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.45e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = -3.52839e-008
+PKU0     = 0
+LKU0       = 3.228575e-007
+WKU0       = 3.8e-007
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0
+STETA0     = -0e-9
+TKU0       = 0
+LVSAT      = '0+dlvsatn_33'
+WVSAT      = '0+dwvsatn_33'      PVSAT      = '0+dpvsatn_33'      LETA0      = '0+dleta0n_33'   
+PETA0      = '0+dpeta0n_33'      )

**********************************************************************************************
*                                                                                            *
*                                   3.3V PMOS DEVICE MODELS                                    *
*                                                                                            *
**********************************************************************************************



.MODEL pch_33.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_33'
+LMAX       = 900.001e-6          WMIN       = '1e-005-dxwp_33'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6428+dvthp_33'
+K1         = 0.72417             K2         = '-0.05886+dk2p_33'  K3         = -3.442
+K3B        = 3                   W0         = 0                   DVT0       = 5.375
+DVT1       = 0.2233              DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.2921
+MINV       = 0                   VOFFL      = 0                   DVTP0      = 4.44089e-020
+DVTP1      = 1                   LPE0       = 2.47e-009           LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008
+NGATE      = 3.7301e+020         NDEP       = 7.81e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '1.409e-005+dcitp_33'
+VOFF       = '-0.08693+dvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01204+du0p_33'   UA         = 8.427e-010
+UB         = 8.5201e-019         UC         = -1.548e-011         VSAT       = '120000+dvsatp_33'
+A0         = '1.297+da0p_33'     AGS        = '0.2718+dagsp_33'   A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = -0.01106            DWG        = 0                   DWB        = 0
+PCLM       = '0.14+dpclmp_33'    PDIBLC1    = 0                   PDIBLC2    = 1e-005
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.003351            LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   KT1        = -0.2454             KT1L       = 0
+KT2        = -0.0545             UTE        = -1.007              UA1        = 1.62e-009
+UB1        = -2.31e-018          UC1        = 2.339e-011          PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'
+LCIT       = '0+dlcitp_33'       WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'
+LU0        = '0+dlu0p_33'        WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+LA0        = '0+dla0p_33'        WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       WAGS       = '0+dwagsp_33'       PAGS       = '0+dpagsp_33'
+LPCLM      = '0+dlpclmp_33'      WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+LVOFF      = '0+dlvoffp_33'      WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'
+LK2        = '0+dlk2p_33'        WK2        = '0+dwk2p_33'        PK2        = '0+dpk2p_33'        )



.MODEL pch_33.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_33'
+LMAX       = '1e-005-dxlp_33'    WMIN       = '1e-005-dxwp_33'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64323091+dvthp_33'
+LVTH0      = '4.3026273e-009+dlvthp_33'
+K1         = 0.72417             K2         = '-0.058784591+dk2p_33'
+LK2        = '-7.5295977e-010+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-9.1669716e-006+dcitp_33'
+LCIT       = '2.3222086e-010+dlcitp_33'
+VOFF       = '-0.087552125+dvoffp_33'
+LVOFF      = '6.2119181e-009+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012030574+du0p_33'
+LU0        = '9.4119972e-011+dlu0p_33'
+UA         = 8.7450648e-010      LUA        = -3.1758768e-016     UB         = 8.1484544e-019
+LUB        = 3.7108816e-025      UC         = -2.1728182e-011     LUC        = 6.2388096e-017
+VSAT       = '120000+dvsatp_33'  A0         = '1.3227199+da0p_33' LA0        = '-2.5681307e-007+dla0p_33'
+AGS        = '0.25480602+dagsp_33'
+LAGS       = '1.6968486e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0084907046       LKETA      = -2.5654415e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.11481875+dpclmp_33'
+LPCLM      = '2.5143478e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032825932
+LTVOFF     = 6.8304208e-010      WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.24386489         LKT1       = -1.532811e-008      KT1L       = 0
+KT2        = -0.052345455        LKT2       = -2.1513136e-008     UTE        = -1.0060574
+LUTE       = -9.4119972e-009     UA1        = 1.6194614e-009      LUA1       = 5.3782841e-018
+UB1        = -2.2617921e-018     LUB1       = -4.8135643e-025     UC1        = 1.9289631e-011
+LUC1       = 4.0942188e-017      PRT        = 0                   AT         = 258362.33
+LAT        = -0.083497861
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'
+PK2        = '0+dpk2p_33'       )



.MODEL pch_33.3 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_33'
+LMAX       = '1.2e-006-dxlp_33'  WMIN       = '1e-005-dxwp_33'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.650697+dvthp_33'
+LVTH0      = '1.3149945e-008+dlvthp_33'
+K1         = 0.72417             K2         = '-0.0634204+dk2p_33'
+LK2        = '4.740474e-009+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '9.659e-006+dcitp_33'
+LCIT       = '2.0991209e-010+dlcitp_33'
+VOFF       = '-0.09229456+dvoffp_33'
+LVOFF      = '1.1831704e-008+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.5883+deta0p_33'  ETAB       = -0.09524            UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0125347+du0p_33' LU0        = '-5.032695e-010+dlu0p_33'
+UA         = 1.0021834e-009      LUA        = -4.6888483e-016     UB         = 8.12489e-019
+LUB        = 3.7388054e-025      UC         = -2.19209e-011       LUC        = 6.2616467e-017
+VSAT       = '120000+dvsatp_33'  A0         = '1.5469482+da0p_33' LA0        = '-5.2252362e-007+dla0p_33'
+AGS        = '0.2391074+dagsp_33'
+LAGS       = '1.8828773e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0121656          LKETA      = -2.1299664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.2241815+dpclmp_33'
+LPCLM      = '1.2183992e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00349732
+LTVOFF     = 4.285908e-010       WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.235839           LKT1       = -2.4838785e-008     KT1L       = 0
+KT2        = -0.0787748          LKT2       = 9.805638e-009       UTE        = -1.03318
+LUTE       = 2.27283e-008        UA1        = 1.35959e-009        LUA1       = 3.1332585e-016
+UB1        = -2.49401e-018       LUB1       = -2.0617815e-025     UC1        = 9.70772e-011
+LUC1       = -5.1236082e-017     PRT        = 0                   AT         = 358752.7
+LAT        = -0.20246045
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'
+WVOFF      = '0+dwvoffp_33'      PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'
+PK2        = '0+dpk2p_33'        )



.MODEL pch_33.4 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-dxlp_33'    WMIN       = '1e-005-dxwp_33'    WMAX       = 900.001e-6
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66820333+dvthp_33'
+LVTH0      = '2.5141783e-008+dlvthp_33'
+K1         = 0.72417             K2         = '-0.057809+dk2p_33' LK2        = '8.96665e-010+dlk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00019533833+dcitp_33'
+LCIT       = '8.2721742e-011+dlcitp_33'
+VOFF       = '-0.13908857+dvoffp_33'
+LVOFF      = '4.3885598e-008+dlvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.95879833+deta0p_33'
+LETA0      = '-2.5379136e-007+dleta0p_33'
+ETAB       = 0.25185033          LETAB      = -2.3775688e-007     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012313333+du0p_33'
+LU0        = '-3.5163333e-010+dlu0p_33'
+UA         = 7.2328648e-010      LUA        = -2.7784044e-016     UB         = 1.059925e-018
+LUB        = 2.0438688e-025      UC         = 4.4832033e-011      LUC        = 1.6890707e-017
+VSAT       = '120000+dvsatp_33'  A0         = '0.37262633+da0p_33'
+LA0        = '2.8188686e-007+dla0p_33'
+AGS        = '0.30685+dagsp_33'  LAGS       = '1.4188405e-007+dlagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.052654           LKETA      = 6.43489e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.010440833+dpclmp_33'
+LPCLM      = '2.6825228e-007+dlpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0059350667
+LTVOFF     = -1.2412657e-009     WTVOFF     = 0                   PTVOFF     = 0
+KT1        = -0.20446833         LKT1       = -4.6327692e-008     KT1L       = 0
+KT2        = -0.072545           LKT2       = 5.538225e-009       UTE        = -0.36603333
+LUTE       = -4.3426717e-007     UA1        = 4.0224725e-009      LUA1       = -1.5107487e-015
+UB1        = -4.1472483e-018     LUB1       = 9.2629011e-025      UC1        = 1.1546283e-010
+LUC1       = -6.3830241e-017     PRT        = 0                   AT         = 130321.17
+LAT        = -0.045984849
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+WVTH0      = '0+dwvthp_33'       PVTH0      = '0+dpvthp_33'       WCIT       = '0+dwcitp_33'
+PCIT       = '0+dpcitp_33'       WU0        = '0+dwu0p_33'        PU0        = '0+dpu0p_33'
+LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'
+LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'
+WA0        = '0+dwa0p_33'        PA0        = '0+dpa0p_33'        WAGS       = '0+dwagsp_33'
+PAGS       = '0+dpagsp_33'       WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+WETA0      = '0+dweta0p_33'      PETA0      = '0+dpeta0p_33'      WVOFF      = '0+dwvoffp_33'
+PVOFF      = '0+dpvoffp_33'      WK2        = '0+dwk2p_33'        PK2        = '0+dpk2p_33'        )



.MODEL pch_33.5 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_33'
+LMAX       = 900.001e-6          WMIN       = '1e-006-dxwp_33'    WMAX       = '1e-005-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64126712+dvthp_33'
+WVTH0      = '-1.5339508e-008+dwvthp_33'
+K1         = 0.72417             K2         = '-0.058758181+dk2p_33'
+WK2        = '-1.0189016e-009+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.510707e-005+dcitp_33'
+WCIT       = '-1.017782e-011+dwcitp_33'
+VOFF       = '-0.085385933+dvoffp_33'
+WVOFF      = '-1.5451475e-008+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01206014+du0p_33'
+WU0        = '-2.0154098e-010+dwu0p_33'
+UA         = 8.9686541e-010      WUA        = -5.4203327e-016     UB         = 8.2336756e-019
+WUB        = 2.8662486e-025      UC         = -1.5030207e-011     WUC        = -4.5010819e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.2936433+da0p_33' WA0        = '3.3590163e-008+dwa0p_33'
+AGS        = '0.27102797+dagsp_33'
+WAGS       = '7.7257376e-009+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.012275505        WKETA      = 1.2163558e-008
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0033675596
+LTVOFF     = 0                   WTVOFF     = -1.6571147e-010     PTVOFF     = 0
+KT1        = -0.24517622         WKT1       = -2.2393442e-009     KT1L       = 0
+KT2        = -0.053948388        WKT2       = -5.5199835e-009     UTE        = -0.99077611
+WUTE       = -1.6235246e-007     UA1        = 1.6620702e-009      WUA1       = -4.2099671e-016
+UB1        = -2.3592311e-018     WUB1       = 4.9265573e-025      UC1        = 2.2275587e-011
+WUC1       = 1.1151934e-017      PRT        = 0                   AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'
+PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'       PCIT       = '0+dpcitp_33'
+LU0        = '0+dlu0p_33'        PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'
+PA0        = '0+dpa0p_33'        LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'
+LPCLM      = '0+dlpclmp_33'      WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'
+LETA0      = '0+dleta0p_33'      PETA0      = '0+dpeta0p_33'      LVOFF      = '0+dlvoffp_33'
+PVOFF      = '0+dpvoffp_33'      LK2        = '0+dlk2p_33'        PK2        = '0+dpk2p_33'       )



.MODEL pch_33.6 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_33'
+LMAX       = '1e-005-dxlp_33'    WMIN       = '1e-006-dxwp_33'    WMAX       = '1e-005-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.64156092+dvthp_33'
+LVTH0      = '2.9336e-009+dlvthp_33'
+WVTH0      = '-1.6711552e-008+dwvthp_33'
+PVTH0      = '1.3699856e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.058700852+dk2p_33'
+LK2        = '-5.724287e-010+dlk2p_33'
+WK2        = '-8.3797279e-010+dwk2p_33'
+PK2        = '-1.8065744e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-1.061725e-005+dcitp_33'
+LCIT       = '2.5685734e-010+dlcitp_33'
+WCIT       = '1.4512935e-011+dwcitp_33'
+PCIT       = '-2.4653719e-016+dpcitp_33'
+VOFF       = '-0.085808935+dvoffp_33'
+LVOFF      = '4.2236693e-009+dlvoffp_33'
+WVOFF      = '-1.7444105e-008+dwvoffp_33'
+PVOFF      = '1.9896406e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012053577+du0p_33'
+LU0        = '6.5535886e-011+dlu0p_33'
+WU0        = '-2.3018805e-010+dwu0p_33'
+PU0        = '2.8604095e-016+dpu0p_33'
+UA         = 9.296211e-010       LUA        = -3.2706556e-016     WUA        = -5.5153203e-016
+PUA        = 9.4845157e-023      UB         = 7.8560048e-019      LUB        = 3.7710435e-025
+WUB        = 2.9265432e-025      PUB        = -6.0204092e-032     UC         = -2.140269e-011
+LUC        = 6.3629247e-017      WUC        = -3.2571962e-018     PUC        = -1.2420199e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.3194838+da0p_33' LA0        = '-2.5801661e-007+dla0p_33'
+WA0        = '3.2383971e-008+dwa0p_33'
+PA0        = '1.2043829e-014+dpa0p_33'
+AGS        = '0.25390291+dagsp_33'
+LAGS       = '1.7099371e-007+dlagsp_33'
+WAGS       = '9.0374716e-009+dwagsp_33'
+PAGS       = '-1.3097665e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.009686826        LKETA      = -2.584796e-008
+WKETA      = 1.1969587e-008      PKETA      = 1.9367983e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11516529+dpclmp_33'
+LPCLM      = '2.479746e-007+dlpclmp_33'
+WPCLM      = '-3.4678027e-009+dwpclmp_33'
+PPCLM      = '3.462601e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1.0043995e-005      LPDIBLC2   = -4.3929227e-013
+WPDIBLC2   = -4.4026016e-013     PPDIBLC2   = 4.3959977e-018      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0032968626
+LTVOFF     = 7.0590935e-010      WTVOFF     = -1.4279382e-010     PTVOFF     = -2.2883276e-016
+KT1        = -0.24355221         LKT1       = -1.6215721e-008     WKT1       = -3.128911e-009
+PKT1       = 8.8823242e-015      KT1L       = 0                   KT2        = -0.051605055
+LKT2       = -2.3398182e-008     WKT2       = -7.4091821e-009     PKT2       = 1.8863648e-014
+UTE        = -0.98908016         LUTE       = -1.6934125e-008     WUTE       = -1.6989116e-007
+PUTE       = 7.5273934e-014      UA1        = 1.6647559e-009      LUA1       = -2.6816423e-017
+WUA1       = -4.5326236e-016     PUA1       = 3.2217244e-022      UB1        = -2.3135092e-018
+LUB1       = -4.565334e-025      WUB1       = 5.1753344e-025      PUB1       = -2.4840398e-031
+UC1        = 1.7633413e-011      LUC1       = 4.6352102e-017      WUC1       = 1.6573768e-017
+PUC1       = -5.4137013e-023     PRT        = 0                   AT         = 257969.09
+LAT        = -0.07957131         WAT        = 0.0039352022        PAT        = -3.9292993e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.7 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_33'
+LMAX       = '1.2e-006-dxlp_33'  WMIN       = '1e-006-dxwp_33'    WMAX       = '1e-005-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65082612+dvthp_33'
+LVTH0      = '1.3912858e-008+dlvthp_33'
+WVTH0      = '1.2921016e-009+dwvthp_33'
+PVTH0      = '-7.6344731e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.063510817+dk2p_33'
+LK2        = '5.12738e-009+dlk2p_33'
+WK2        = '9.0480703e-010+dwk2p_33'
+PK2        = '-3.8717685e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9922825e-005+dcitp_33'
+LCIT       = '2.2066735e-010+dlcitp_33'
+WCIT       = '-1.027101e-010+dwcitp_33'
+PCIT       = '-1.0762789e-016+dpcitp_33'
+VOFF       = '-0.092580246+dvoffp_33'
+LVOFF      = '1.2247673e-008+dlvoffp_33'
+WVOFF      = '2.8588588e-009+dwvoffp_33'
+PVOFF      = '-4.1626056e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.58755034+deta0p_33'
+WETA0      = '7.5018031e-009+dweta0p_33'
+ETAB       = -0.09691162         WETAB      = 1.6727901e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012582633+du0p_33'
+LU0        = '-5.6139623e-010+dlu0p_33'
+WU0        = '-4.7966753e-010+dwu0p_33'
+PU0        = '5.8167414e-016+dpu0p_33'
+UA         = 1.063318e-009       LUA        = -4.8549636e-016     WUA        = -6.1177373e-016
+PUA        = 1.6623156e-022      UB         = 7.8643556e-019      LUB        = 3.7611478e-025
+WUB        = 2.6071677e-025      PUB        = -2.23581e-032       UC         = -2.2488647e-011
+LUC        = 6.4916105e-017      WUC        = 5.6814402e-018      PUC        = -2.3012483e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.5239739+da0p_33' LA0        = '-5.0033737e-007+dla0p_33'
+WA0        = '2.2990429e-007+dwa0p_33'
+PA0        = '-2.2201775e-013+dpa0p_33'
+AGS        = '0.23113396+dagsp_33'
+LAGS       = '1.9797491e-007+dlagsp_33'
+WAGS       = '7.9790186e-008+dwagsp_33'
+PAGS       = '-9.6939631e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.011470994        LKETA      = -2.3733721e-008
+WKETA      = -6.9509245e-009     PKETA      = 2.4357605e-014      DWG        = 0
+DWB        = 0                   PCLM       = '0.21288445+dpclmp_33'
+LPCLM      = '1.321774e-007+dlpclmp_33'
+WPCLM      = '1.130496e-007+dwpclmp_33'
+PPCLM      = '-1.0344711e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 9.2256841e-006      LPDIBLC2   = 5.3040637e-013
+WPDIBLC2   = 7.7485789e-012      PPDIBLC2   = -5.3077765e-018     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0034343154
+LTVOFF     = 5.4302779e-010      WTVOFF     = 6.3048737e-010      PTVOFF     = -1.145171e-015
+KT1        = -0.23593813         LKT1       = -2.5238406e-008     WKT1       = 9.9202949e-010
+PKT1       = 3.9990097e-015      KT1L       = 0                   KT2        = -0.080754887
+LKT2       = 1.1144369e-008      WKT2       = 1.9814725e-008      PKT2       = -1.3396683e-014
+UTE        = -1.0282222          LUTE       = 2.9449203e-008      WUTE       = -4.9612671e-008
+PUTE       = -6.7256073e-014     UA1        = 1.3357152e-009      LUA1       = 3.6309686e-016
+WUA1       = 2.3891564e-016      PUA1       = -4.9805848e-022     UB1        = -2.4836983e-018
+LUB1       = -2.5485928e-025     WUB1       = -1.0318898e-025     PUB1       = 4.8715209e-031
+UC1        = 1.0355179e-010      LUC1       = -5.5461168e-017     WUC1       = -6.479117e-017
+PUC1       = 4.2280439e-023      PRT        = 0                   AT         = 350288.32
+LAT        = -0.1889696          WAT        = 0.084703083         PAT        = -1.3500293e-007
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.8 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-dxlp_33'    WMIN       = '1e-006-dxwp_33'    WMAX       = '1e-005-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.66803718+dvthp_33'
+LVTH0      = '2.5702433e-008+dlvthp_33'
+WVTH0      = '-1.6627131e-009+dwvthp_33'
+PVTH0      = '-5.610425e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.057186693+dk2p_33'
+LK2        = '7.9535455e-010+dlk2p_33'
+WK2        = '-6.2274297e-009+dwk2p_33'
+PK2        = '1.0138136e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00024196023+dcitp_33'
+LCIT       = '6.8571721e-011+dlcitp_33'
+WCIT       = '-4.6654535e-010+dwcitp_33'
+PCIT       = '1.4159925e-016+dpcitp_33'
+VOFF       = '-0.14042777+dvoffp_33'
+LVOFF      = '4.5023226e-008+dlvoffp_33'
+WVOFF      = '1.3401393e-008+dwvoffp_33'
+PVOFF      = '-1.1384241e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.93976958+deta0p_33'
+LETA0      = '-2.4127017e-007+dleta0p_33'
+WETA0      = '1.9042077e-007+dweta0p_33'
+PETA0      = '-1.2529949e-013+dpeta0p_33'
+ETAB       = 0.25993714          LETAB      = -2.444414e-007      WETAB      = -8.0924675e-008
+PETAB      = 6.6892015e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012394154+du0p_33'
+LU0        = '-4.3228825e-010+dlu0p_33'
+WU0        = '-8.0877649e-010+dwu0p_33'
+PU0        = '8.0711378e-016+dpu0p_33'
+UA         = 8.0725558e-010      LUA        = -3.1009362e-016     WUA        = -8.4027877e-016
+PUA        = 3.2275752e-022      UB         = 9.9890938e-019      LUB        = 2.3057022e-025
+WUB        = 6.1058333e-025      PUB        = -2.6201669e-031     UC         = 4.4873815e-011
+LUC        = 1.8772819e-017      WUC        = -4.1810423e-019     PUC        = -1.8834295e-023
+VSAT       = '120000+dvsatp_33'  A0         = '0.37683406+da0p_33'
+LA0        = '2.8545338e-007+dla0p_33'
+WA0        = '-4.2106763e-008+dwa0p_33'
+PA0        = '-3.5690177e-014+dpa0p_33'
+AGS        = '0.30127989+dagsp_33'
+LAGS       = '1.4992495e-007+dlagsp_33'
+WAGS       = '5.5740077e-008+dwagsp_33'
+PAGS       = '-8.0465306e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.055844456        LKETA      = 6.6621008e-009
+WKETA      = 3.192689e-008       PKETA      = -2.2736986e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.037038631+dpclmp_33'
+LPCLM      = '2.5263178e-007+dlpclmp_33'
+WPCLM      = '-2.6616416e-007+dwpclmp_33'
+PPCLM      = '1.5631432e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0061726627
+LTVOFF     = -1.3327402e-009     WTVOFF     = -2.3776237e-009     PTVOFF     = 9.1538514e-016
+KT1        = -0.20602676         LKT1       = -4.5727698e-008     WKT1       = 1.5595166e-008
+PKT1       = -6.0041391e-015     KT1L       = 0                   KT2        = -0.07260376
+LKT2       = 5.5608477e-009      WKT2       = 5.8801447e-010      PKT2       = -2.2638557e-016
+UTE        = -0.33231002         LUTE       = -4.4725064e-007     WUTE       = -3.3746917e-007
+PUTE       = 1.2992563e-013      UA1        = 4.1338616e-009      LUA1       = -1.5536335e-015
+WUA1       = -1.1146709e-015     PUA1       = 4.291483e-022       UB1        = -4.2763388e-018
+LUB1       = 9.7309947e-025      WUB1       = 1.2918086e-024      PUB1       = -4.6842128e-031
+UC1        = 1.1616285e-010      LUC1       = -6.4099746e-017     WUC1       = -7.005042e-018
+PUC1       = 2.6969412e-024      PRT        = 0                   AT         = 155963.66
+LAT        = -0.055857208        WAT        = -0.2566044          PAT        = 9.8792695e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      )



.MODEL pch_33.9 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_33'
+LMAX       = 900.001e-6          WMIN       = '6e-007-dxwp_33'    WMAX       = '1e-006-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.6555895+dvthp_33'
+WVTH0      = '-9.168735e-010+dwvthp_33'
+K1         = 0.72417             K2         = '-0.066097975+dk2p_33'
+WK2        = '6.3722708e-009+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.1087682+dvoffp_33'
+WVOFF      = '8.0944649e-009+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012330425+du0p_33'
+WU0        = '-4.7371798e-010+dwu0p_33'
+UA         = 8.1076948e-010      WUA        = -4.5533466e-016     UB         = 8.909975e-019
+WUB        = 2.1852152e-025      UC         = -2.46595e-011       WUC        = 5.1956165e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.1646275+da0p_33' WA0        = '1.6350911e-007+dwa0p_33'
+AGS        = '0.26549775+dagsp_33'
+WAGS       = '1.3294666e-008+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0069562038       WKETA      = 6.8070217e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.14+dpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -5.175e-006         WPDIBLC2   = 1.5281225e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 0.00700282          LTVOFF     = 0                   WTVOFF     = -3.8264187e-009
+PTVOFF     = 0                   KT1        = -0.23753625         WKT1       = -9.9327963e-009
+KT1L       = 0                   KT2        = -0.05178787         WKT2       = -7.6956249e-009
+UTE        = -1.045775           WUTE       = -1.0696858e-007     UA1        = 1.4003025e-009
+WUA1       = -1.5739662e-016     UB1        = -2.04603e-018       WUB1       = 1.7726221e-025
+UC1        = 7.465125e-013       WUC1       = 3.2831712e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LU0        = '0+dlu0p_33'
+PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'
+PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'
+PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'       LPCLM      = '0+dlpclmp_33'
+WPCLM      = '0+dwpclmp_33'      PPCLM      = '0+dppclmp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      LVOFF      = '0+dlvoffp_33'      PVOFF      = '0+dpvoffp_33'
+LK2        = '0+dlk2p_33'        PK2        = '0+dpk2p_33'        )



.MODEL pch_33.10 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_33'
+LMAX       = '1e-005-dxlp_33'    WMIN       = '6e-007-dxwp_33'    WMAX       = '1e-006-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.65814493+dvthp_33'
+LVTH0      = '2.5515924e-008+dlvthp_33'
+WVTH0      = '-1.1460919e-011+dwvthp_33'
+PVTH0      = '-9.0405446e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.065327634+dk2p_33'
+LK2        = '-7.6918538e-009+dlk2p_33'
+WK2        = '5.8351965e-009+dwk2p_33'
+PK2        = '5.3626867e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '1.9659119e-006+dcitp_33'
+LCIT       = '3.029537e-011+dlcitp_33'
+WCIT       = '1.8416915e-012+dwcitp_33'
+PCIT       = '-1.838929e-017+dpcitp_33'
+VOFF       = '-0.11242711+dvoffp_33'
+LVOFF      = '3.6534227e-008+dlvoffp_33'
+WVOFF      = '9.3603963e-009+dwvoffp_33'
+PVOFF      = '-1.2640325e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.012358761+du0p_33'
+LU0        = '-2.8293136e-010+dlu0p_33'
+WU0        = '-5.3750841e-010+dwu0p_33'
+PU0        = '6.3694746e-016+dpu0p_33'
+UA         = 8.6102921e-010      LUA        = -5.0184345e-016     WUA        = -4.8246e-016
+PUA        = 2.708465e-022       UB         = 8.4143993e-019      LUB        = 4.9483239e-025
+WUB        = 2.3642399e-025      PUB        = -1.7875622e-031     UC         = -3.0368911e-011
+LUC        = 5.7008467e-017      WUC        = 5.7717881e-018      PUC        = -5.7530739e-024
+VSAT       = '120000+dvsatp_33'  A0         = '1.1751703+da0p_33' LA0        = '-1.0526983e-007+dla0p_33'
+WA0        = '1.7770762e-007+dwa0p_33'
+PA0        = '-1.4177218e-013+dpa0p_33'
+AGS        = '0.25327996+dagsp_33'
+LAGS       = '1.2199468e-007+dlagsp_33'
+WAGS       = '9.6647844e-009+dwagsp_33'
+PAGS       = '3.6244365e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.0047940203       LKETA      = -2.1589402e-008
+WKETA      = 7.0425318e-009      PKETA      = -2.3515689e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.11376504+dpclmp_33'
+LPCLM      = '2.6195605e-007+dlpclmp_33'
+WPCLM      = '-2.0577559e-009+dwpclmp_33'
+PPCLM      = '2.0546692e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -3.453733e-008      LPDIBLC2   = -5.132752e-011
+WPDIBLC2   = 9.7088221e-012      PPDIBLC2   = 5.5640443e-017      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0072258431
+LTVOFF     = -2.2268853e-009     WTVOFF     = -4.0992772e-009     PTVOFF     = 2.7244914e-015
+KT1        = -0.23550825         LKT1       = -2.0249576e-008     WKT1       = -1.1229182e-008
+PKT1       = 1.2944416e-014      KT1L       = 0                   KT2        = -0.049140649
+LKT2       = -2.6432505e-008     WKT2       = -9.8908389e-009     PKT2       = 2.1919211e-014
+UTE        = -1.0480915          LUTE       = 2.3129983e-008      WUTE       = -1.1046676e-007
+PUTE       = 3.4929377e-014      UA1        = 1.3797337e-009      LUA1       = 2.0537986e-016
+WUA1       = -1.6624497e-016     PUA1       = 8.8350777e-023      UB1        = -1.982551e-018
+LUB1       = -6.338375e-025      WUB1       = 1.8425858e-025      PUB1       = -6.9858754e-032
+UC1        = -8.1320865e-012     LUC1       = 8.8652811e-017      WUC1       = 4.2519627e-017
+PUC1       = -9.6733828e-023     PRT        = 0                   AT         = 259690.44
+LAT        = -0.096759028        WAT        = 0.0022017988        PAT        = -2.1984961e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.11 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_33'
+LMAX       = '1.2e-006-dxlp_33'  WMIN       = '6e-007-dxwp_33'    WMAX       = '1e-006-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.62989745+dvthp_33'
+LVTH0      = '-7.9573402e-009+dlvthp_33'
+WVTH0      = '-1.9783074e-008+dwvthp_33'
+PVTH0      = '1.4388817e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.082755292+dk2p_33'
+LK2        = '1.295992e-008+dlk2p_33'
+WK2        = '2.0283992e-008+dwk2p_33'
+PK2        = '-1.1759136e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00021420703+dcitp_33'
+LCIT       = '2.8646031e-010+dlcitp_33'
+WCIT       = '1.3305867e-010+dwcitp_33'
+PCIT       = '-1.7388141e-016+dpcitp_33'
+VOFF       = '-0.073036514+dvoffp_33'
+LVOFF      = '-1.0143628e-008+dlvoffp_33'
+WVOFF      = '-1.6821679e-008+dwvoffp_33'
+PVOFF      = '1.8385435e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.66465325+deta0p_33'
+WETA0      = '-7.0140823e-008+dweta0p_33'
+ETAB       = -0.07595995         WETAB      = -4.3704304e-009     UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.013499213+du0p_33'
+LU0        = '-1.6343677e-009+dlu0p_33'
+WU0        = '-1.4026636e-009+dwu0p_33'
+PU0        = '1.6621564e-015+dpu0p_33'
+UA         = 1.0473222e-009      LUA        = -7.2260064e-016     WUA        = -5.9566597e-016
+PUA        = 4.0499558e-022      UB         = 8.4185843e-019      LUB        = 4.9433647e-025
+WUB        = 2.0490595e-025      PUB        = -1.4140734e-031     UC         = -2.9898414e-011
+LUC        = 5.6450928e-017      WUC        = 1.3143076e-017      PUC        = -1.448805e-023
+VSAT       = '120000+dvsatp_33'  A0         = '2.1264181+da0p_33' LA0        = '-1.2324985e-006+dla0p_33'
+WA0        = '-3.7675707e-007+dwa0p_33'
+PA0        = '5.1526849e-013+dpa0p_33'
+AGS        = '0.24152159+dagsp_33'
+LAGS       = '1.3592834e-007+dlagsp_33'
+WAGS       = '6.9329848e-008+dwagsp_33'
+PAGS       = '-3.4458735e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.035516949        LKETA      = 1.4817269e-008
+WKETA      = 1.7263353e-008      PKETA      = -1.4463242e-014     DWG        = 0
+DWB        = 0                   PCLM       = '0.53088508+dpclmp_33'
+LPCLM      = '-2.323312e-007+dlpclmp_33'
+WPCLM      = '-2.0717704e-007+dwpclmp_33'
+PPCLM      = '2.6361305e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = -0.00011643689      LPDIBLC2   = 8.6609272e-011
+WPDIBLC2   = 1.3429079e-010      PPDIBLC2   = -9.1989194e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.010263778
+LTVOFF     = -5.826838e-009      WTVOFF     = -6.2467814e-009     PTVOFF     = 5.2692839e-015
+KT1        = -0.21178078         LKT1       = -4.8366634e-008     WKT1       = -2.3334431e-008
+PKT1       = 2.7289135e-014      KT1L       = 0                   KT2        = -0.078838477
+LKT2       = 8.7594219e-009      WKT2       = 1.7884901e-008      PKT2       = -1.0995041e-014
+UTE        = -0.9055876          LUTE       = -1.4573711e-007     WUTE       = -1.7310572e-007
+PUTE       = 1.0915654e-013      UA1        = 2.0611042e-009      LUA1       = -6.0204426e-016
+WUA1       = -4.9155117e-016     PUA1       = 4.7383862e-022      UB1        = -2.962161e-018
+LUB1       = 5.2700028e-025      WUB1       = 3.7862291e-025      PUB1       = -3.0018049e-031
+UC1        = 1.1922551e-010      LUC1       = -6.2265943e-017     WUC1       = -8.0574614e-017
+PUC1       = 4.9132848e-023      PRT        = 0                   AT         = 480909.73
+LAT        = -0.35890388         WAT        = -0.046832676        PAT        = 3.6120892e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.12 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-dxlp_33'    WMIN       = '6e-007-dxwp_33'    WMAX       = '1e-006-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.71413591+dvthp_33'
+LVTH0      = '4.9746007e-008+dlvthp_33'
+WVTH0      = '4.4758708e-008+dwvthp_33'
+PVTH0      = '-2.9822304e-014+dpvthp_33'
+K1         = 0.72417             K2         = '-0.081500912+dk2p_33'
+LK2        = '1.210067e-008+dlk2p_33'
+WK2        = '1.8256989e-008+dwk2p_33'
+PK2        = '-1.0370639e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00027074978+dcitp_33'
+LCIT       = '3.2519209e-010+dlcitp_33'
+WCIT       = '4.9753631e-011+dwcitp_33'
+PCIT       = '-1.1681746e-016+dpcitp_33'
+VOFF       = '-0.16416909+dvoffp_33'
+LVOFF      = '5.2282189e-008+dlvoffp_33'
+WVOFF      = '3.7308907e-008+dwvoffp_33'
+PVOFF      = '-1.8694017e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '1.6257923+deta0p_33'
+LETA0      = '-6.5838023e-007+dleta0p_33'
+WETA0      = '-5.0040409e-007+dweta0p_33'
+PETA0      = '2.9473034e-013+dpeta0p_33'
+ETAB       = 0.28491024          LETAB      = -2.4719608e-007     WETAB      = -1.0607259e-007
+PETAB      = 6.9665977e-014      UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0129307+du0p_33' LU0        = '-1.2449358e-009+dlu0p_33'
+WU0        = '-1.3490775e-009+dwu0p_33'
+PU0        = '1.6254499e-015+dpu0p_33'
+UA         = 6.2049606e-010      LUA        = -4.3022473e-016     WUA        = -6.5221192e-016
+PUA        = 4.4372955e-022      UB         = 1.2460966e-018      LUB        = 2.1743335e-025
+WUB        = 3.6166585e-025      PUB        = -2.4878787e-031     UC         = 8.592997e-011
+LUC        = -2.2891515e-017     WUC        = -4.1761652e-017     PUC        = 2.3121689e-023
+VSAT       = '120000+dvsatp_33'  A0         = '-1.1286012+da0p_33'
+LA0        = '9.9718972e-007+dla0p_33'
+WA0        = '1.4738665e-006+dwa0p_33'
+PA0        = '-7.5240867e-013+dpa0p_33'
+AGS        = '0.33709696+dagsp_33'
+LAGS       = '7.0459211e-008+dlagsp_33'
+WAGS       = '1.9672285e-008+dwagsp_33'
+PAGS       = '-4.4330452e-016+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.01845363         LKETA      = 3.1288949e-009
+WKETA      = -5.7256713e-009     PKETA      = 1.2842398e-015      DWG        = 0
+DWB        = 0                   PCLM       = '-0.91948422+dpclmp_33'
+LPCLM      = '7.6117178e-007+dlpclmp_33'
+WPCLM      = '6.9705435e-007+dwpclmp_33'
+PPCLM      = '-3.5578546e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00053371608
+LTVOFF     = 8.3825431e-010      WTVOFF     = 3.3007955e-009      PTVOFF     = -1.2708063e-015
+KT1        = -0.22796155         LKT1       = -3.7282803e-008     WKT1       = 3.7683501e-008
+PKT1       = -1.4508148e-014     KT1L       = 0                   KT2        = -0.076177783
+LKT2       = 6.9368466e-009      WKT2       = 4.1870557e-009      PKT2       = -1.6120164e-015
+UTE        = -0.63624871         LUTE       = -3.3023425e-007     WUTE       = -3.1402917e-008
+PUTE       = 1.2090123e-014      UA1        = 2.5730296e-009      LUA1       = -9.5271316e-016
+WUA1       = 4.5708691e-016      PUA1       = -1.7597846e-022     UB1        = -2.4655743e-018
+LUB1       = 1.8683839e-025      WUB1       = -5.3163127e-025     PUB1       = 3.2334363e-031
+UC1        = 1.2926861e-010      LUC1       = -6.9145464e-017     WUC1       = -2.0202544e-017
+PUC1       = 7.7779793e-024      PRT        = 0                   AT         = -112231.74
+LAT        = 0.04739802          WAT        = 0.013468362         PAT        = -5.1853195e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      )



.MODEL pch_33.13 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_33'
+LMAX       = 900.001e-6          WMIN       = 4e-07               WMAX       = '6e-007-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63675+dvthp_33'
+WVTH0      = '-1.235245e-008+dwvthp_33'
+K1         = 0.72417             K2         = '-0.07369115+dk2p_33'
+WK2        = '1.0981328e-008+dwk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.082272655+dvoffp_33'
+WVOFF      = '-7.9883294e-009+dwvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.01071565+du0p_33'
+WU0        = '5.0645045e-010+dwu0p_33'
+UA         = 1.4266085e-010      WUA        = -4.9792726e-017     UB         = 1.26321e-018
+WUB        = -7.41147e-027       UC         = -2.845245e-011      WUC        = 7.4979372e-018
+VSAT       = '120000+dvsatp_33'  A0         = '1.517435+da0p_33'  WA0        = '-5.0645045e-008+dwa0p_33'
+AGS        = '0.2802775+dagsp_33'
+WAGS       = '4.3233575e-009+dwagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.001423245         WKETA      = 1.7206963e-009
+DWG        = 0                   DWB        = 0                   PCLM       = '0.16035+dpclmp_33'
+WPCLM      = '-1.235245e-008+dwpclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 3.0175e-005         WPDIBLC2   = -6.176225e-012
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0072              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0
+RSW        = 100                 RDW        = 100                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 0
+ALPHA1     = 7.5395              BETA0      = 27.52               AGIDL      = 6.1e-012
+BGIDL      = 1.1868e+009         CGIDL      = 0.5                 EGIDL      = 0.552
+AIGC       = 0.43                AIGSD      = 0.43                XRCRG1     = 12
+XRCRG2     = 1                   CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'
+CGBO       = 0                   CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfp_33'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 1.03
+MOIN       = 5.4649              NOFF       = 2.8966              VOFFCV     = 0.069
+TVOFF      = 1.524e-005          LTVOFF     = 0                   WTVOFF     = 4.1504232e-010
+PTVOFF     = 0                   KT1        = -0.2581735          WKT1       = 2.5940145e-009
+KT1L       = 0                   KT2        = -0.069828225        WKT2       = 3.2548706e-009
+UTE        = -1.02257            WUTE       = -1.2105401e-007     UA1        = 1.7578085e-009
+WUA1       = -3.7440276e-016     UB1        = -2.386885e-018      WUB1       = 3.841612e-025
+UC1        = 1.6642423e-010      WUC1       = -6.773466e-017      PRT        = 0
+AT         = 250000
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7
+JSD        = 1.13e-7             JSWS       = 1e-14               JSWD       = 1e-14
+JSWGS      = 5e-14               JSWGD      = 5e-14               NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+BVD        = 9                   XJBVS      = 1                   XJBVD      = 1
+PBS        = 0.7                 PBD        = 0.7                 CJS        = 'cjp_33'
+CJD        = 'cjp_33'            MJS        = 0.31                MJD        = 0.31
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswp_33'
+CJSWD      = 'cjswp_33'          MJSWS      = 0.082               MJSWD      = 0.082
+PBSWGS     = 0.5                 PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'
+CJSWGD     = 'cjswgp_33'         MJSWGS     = 0.35                MJSWGD     = 0.35
+TPB        = 1.6e-3              TCJ        = 8.78e-4             TPBSW      = 1.5e-3
+TCJSW      = 3.16e-4             TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3
+XTIS       = 3                   XTID       = 3                   JTSSWGS    = 1e-009
+JTSSWGD    = 1e-009              NJTSSWG    = 16                  XTSSWGS    = 0.25
+XTSSWGD    = 0.25                TNJTSSWG   = 0                   VTSSWGS    = 1
+VTSSWGD    = 1                   DMCG       = 1.245e-7            DMCI       = 3.05e-7
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LVTH0      = '0+dlvthp_33'       PVTH0      = '0+dpvthp_33'       LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LU0        = '0+dlu0p_33'
+PU0        = '0+dpu0p_33'        LNFACTOR   = '0+dlnfactorp_33'   WNFACTOR   = '0+dwnfactorp_33'
+PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'      WVSAT      = '0+dwvsatp_33'
+PVSAT      = '0+dpvsatp_33'      LA0        = '0+dla0p_33'        PA0        = '0+dpa0p_33'
+LAGS       = '0+dlagsp_33'       PAGS       = '0+dpagsp_33'       LPCLM      = '0+dlpclmp_33'
+PPCLM      = '0+dppclmp_33'      LETA0      = '0+dleta0p_33'      PETA0      = '0+dpeta0p_33'
+LVOFF      = '0+dlvoffp_33'      PVOFF      = '0+dpvoffp_33'      LK2        = '0+dlk2p_33'
+PK2        = '0+dpk2p_33'        )



.MODEL pch_33.14 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_33'
+LMAX       = '1e-005-dxlp_33'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63806044+dvthp_33'
+LVTH0      = '1.3084693e-008+dlvthp_33'
+WVTH0      = '-1.2202747e-008+dwvthp_33'
+PVTH0      = '-1.4947872e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.075540228+dk2p_33'
+LK2        = '1.8463044e-008+dlk2p_33'
+WK2        = '1.2034241e-008+dwk2p_33'
+PK2        = '-1.0513336e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.08299213+dvoffp_33'
+LVOFF      = '7.1839623e-009+dlvoffp_33'
+WVOFF      = '-8.5066354e-009+dwvoffp_33'
+PVOFF      = '5.1752854e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.010707402+du0p_33'
+LU0        = '8.2354975e-011+dlu0p_33'
+WU0        = '4.6486621e-010+dwu0p_33'
+PU0        = '4.1521866e-016+dpu0p_33'
+UA         = 1.5842427e-010      LUA        = -1.573977e-016      WUA        = -5.5978798e-017
+PUA        = 6.1767928e-023      UB         = 1.2464342e-018      LUB        = 1.6750666e-025
+WUB        = -9.4075136e-027     PUB        = 1.9930496e-032      UC         = -3.5837868e-011
+LUC        = 7.3743401e-017      WUC        = 9.0914453e-018      PUC        = -1.5911179e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.5401338+da0p_33' LA0        = '-2.2664761e-007+dla0p_33'
+WA0        = '-4.3825229e-008+dwa0p_33'
+PA0        = '-6.809586e-014+dpa0p_33'
+AGS        = '0.25532754+dagsp_33'
+LAGS       = '2.4912535e-007+dlagsp_33'
+WAGS       = '8.4219004e-009+dwagsp_33'
+PAGS       = '-4.0923951e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = 0.0047892099        LKETA      = -3.360916e-008
+WKETA      = 1.2255111e-009      PKETA      = 4.9444238e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.11702344+dpclmp_33'
+LPCLM      = '4.3261573e-007+dlpclmp_33'
+WPCLM      = '-4.0356016e-009+dwpclmp_33'
+PPCLM      = '-8.3043732e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1.6544134e-005      LPDIBLC2   = 1.361042e-010
+WPDIBLC2   = -3.5443109e-013     PPDIBLC2   = -5.8130612e-017     PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = -0.00041952034
+LTVOFF     = 4.341082e-009       WTVOFF     = 5.4145842e-010      PTVOFF     = -1.2622647e-015
+KT1        = -0.25951437         LKT1       = 1.3388566e-008      WKT1       = 3.3425309e-009
+PKT1       = -7.4739359e-015     KT1L       = 0                   KT2        = -0.073868569
+LKT2       = 4.0342838e-008      WKT2       = 5.119009e-009       PKT2       = -1.8613422e-014
+UTE        = -1.0799752          LUTE       = 5.7319063e-007      WUTE       = -9.1113356e-008
+PUTE       = -2.9895743e-013     UA1        = 1.544734e-009       LUA1       = 2.127549e-015
+WUA1       = -2.6640017e-016     PUA1       = -1.0784059e-021     UB1        = -2.1959647e-018
+LUB1       = -1.9063395e-024     WUB1       = 3.1380066e-025      PUB1       = 7.0254997e-031
+UC1        = 1.8783718e-010      LUC1       = -2.1380834e-016     WUC1       = -7.6433717e-017
+PUC1       = 8.6860089e-023      PRT        = 0                   AT         = 264605.73
+LAT        = -0.14583822         WAT        = -0.00078178375      PAT        = 7.8061108e-009
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.15 PMOS	(	LEVEL      = 54                  LMIN       = '7e-007-dxlp_33'
+LMAX       = '1.2e-006-dxlp_33'  WMIN       = 4e-07               WMAX       = '6e-007-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.63807714+dvthp_33'
+LVTH0      = '1.3104488e-008+dlvthp_33'
+WVTH0      = '-1.4817999e-008+dwvthp_33'
+PVTH0      = '1.6042868e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.040218037+dk2p_33'
+LK2        = '-2.3393752e-008+dlk2p_33'
+WK2        = '-5.536121e-009+dwk2p_33'
+PK2        = '1.0307543e-014+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '5e-006+dcitp_33'
+VOFF       = '-0.10923032+dvoffp_33'
+LVOFF      = '3.8276211e-008+dlvoffp_33'
+WVOFF      = '5.1479577e-009+dwvoffp_33'
+PVOFF      = '-1.1005407e-014+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.4866255+deta0p_33'
+WETA0      = '3.7922022e-008+dweta0p_33'
+ETAB       = -0.12355475         WETAB      = 2.4519613e-008      UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.0091483125+du0p_33'
+LU0        = '1.9298762e-009+dlu0p_33'
+WU0        = '1.2383331e-009+dwu0p_33'
+PU0        = '-5.0133962e-016+dpu0p_33'
+UA         = 9.4284767e-011      LUA        = -8.1392396e-017     WUA        = -1.7172253e-017
+PUA        = 1.5782171e-023      UB         = 9.553358e-019       LUB        = 5.1245823e-025
+WUB        = 1.3602518e-025      PUB        = -1.5240725e-031     UC         = 2.2733923e-011
+LUC        = 4.3358291e-018      WUC        = -1.8804752e-017     PUC        = 1.7145815e-023
+VSAT       = '120000+dvsatp_33'  A0         = '1.8892247+da0p_33' LA0        = '-6.4032034e-007+dla0p_33'
+WA0        = '-2.3278069e-007+dwa0p_33'
+PA0        = '1.5581636e-013+dpa0p_33'
+AGS        = '0.50163406+dagsp_33'
+LAGS       = '-4.2747874e-008+dlagsp_33'
+WAGS       = '-8.855842e-008+dwagsp_33'
+PAGS       = '7.3997729e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.023747831        LKETA      = 2.0723339e-010
+WKETA      = 1.0119498e-008      PKETA      = -5.5949502e-015     DWG        = 0
+DWB        = 0                   PCLM       = '0.478949+dpclmp_33'
+LPCLM      = '3.733935e-009+dlpclmp_33'
+WPCLM      = '-1.7565184e-007+dwpclmp_33'
+PPCLM      = '1.2032151e-013+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 0.000297718         LPDIBLC2   = -1.9708683e-010
+WPDIBLC2   = -1.1710123e-010     PPDIBLC2   = 8.021434e-017       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.00091065465
+LTVOFF     = 2.7648246e-009      WTVOFF     = -5.6943559e-010     PTVOFF     = 5.4144679e-017
+KT1        = -0.2174595          LKT1       = -3.6446453e-008     WKT1       = -1.9887445e-008
+PKT1       = 2.0053585e-014      KT1L       = 0                   KT2        = 0.0020048874
+LKT2       = -4.9567208e-008     WKT2       = -3.1187021e-008     PKT2       = 2.4409224e-014
+UTE        = -0.13714875         LUTE       = -5.4405868e-007     WUTE       = -6.395481e-007
+PUTE       = 3.5093774e-013      UA1        = 4.9497456e-009      LUA1       = -1.9073898e-015
+WUA1       = -2.2449565e-015     PUA1       = 1.2661834e-021      UB1        = -5.1758819e-018
+LUB1       = 1.6248624e-024      WUB1       = 1.7223515e-024      PUB1       = -9.665828e-031
+UC1        = -3.9614374e-011     LUC1       = 5.5721752e-017      WUC1       = 1.5841197e-017
+PUC1       = -2.2485684e-023     PRT        = 0                   AT         = 315013.12
+LAT        = -0.20557098         WAT        = 0.053866564         PAT        = -5.6952181e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LCIT       = '0+dlcitp_33'
+WCIT       = '0+dwcitp_33'       PCIT       = '0+dpcitp_33'       LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      LETA0      = '0+dleta0p_33'
+PETA0      = '0+dpeta0p_33'      )



.MODEL pch_33.16 PMOS	(	LEVEL      = 54                  LMIN       = 4e-07
+LMAX       = '7e-007-dxlp_33'    WMIN       = 4e-07               WMAX       = '6e-007-dxwp_33'
+VERSION    = 4.5                 RGEOMOD    = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0
+WPEMOD     = 1
+TNOM       = 25
+TOXE       = 'toxp_33'           TOXM       = 5.9e-009            DTOX       = 3.9481e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-1.5e-08+dxlp_33'  XW         = '7e-09+dxwp_33'
+DLC        = 'dlcp_33'           DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.61514398+dvthp_33'
+LVTH0      = '-2.6047239e-009+dlvthp_33'
+WVTH0      = '-1.532939e-008+dwvthp_33'
+PVTH0      = '1.9545899e-015+dpvthp_33'
+K1         = 0.72417             K2         = '-0.058122211+dk2p_33'
+LK2        = '-1.1129393e-008+dlk2p_33'
+WK2        = '4.0661177e-009+dwk2p_33'
+PK2        = '3.7300091e-015+dpk2p_33'
+K3         = -3.442              K3B        = 3                   W0         = 0
+DVT0       = 5.375               DVT1       = 0.2233              DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.2921              MINV       = 0                   VOFFL      = 0
+DVTP0      = 4.44089e-020        DVTP1      = 1                   LPE0       = 2.47e-009
+LPEB       = 4.44089e-021
+WEB        = 0
+WEC        = 0
+SCREF      = 1e-6
+KVTH0WE    = -0.004
+LKVTH0WE   = 0.5e-9
+WKVTH0WE   = -3.7e-9
+PKVTH0WE   = 0e-17
+K2WE       = 0.0040
+LK2WE      = -5e-10
+WK2WE      = 4e-10
+PK2WE      = -0e-17
+XJ         = 9.5e-008            NGATE      = 3.7301e+020         NDEP       = 7.81e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '-0.00023030751+dcitp_33'
+LCIT       = '1.6118564e-010+dlcitp_33'
+WCIT       = '2.5205174e-011+dwcitp_33'
+PCIT       = '-1.7265544e-017+dpcitp_33'
+VOFF       = '-0.076624005+dvoffp_33'
+LVOFF      = '1.5940888e-008+dlvoffp_33'
+WVOFF      = '-1.5830962e-008+dwvoffp_33'
+PVOFF      = '3.3651523e-015+dpvoffp_33'
+NFACTOR    = '0.63002+dnfactorp_33'
+ETA0       = '0.64909037+deta0p_33'
+LETA0      = '-1.1128843e-007+dleta0p_33'
+WETA0      = '9.2453971e-008+dweta0p_33'
+PETA0      = '-3.7354385e-014+dpeta0p_33'
+ETAB       = -0.13694024         LETAB      = 9.1690589e-009      WETAB      = 1.4999065e-007
+PETAB      = -8.5947663e-014     UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0
+KU0WE      = -0.0025
+LKU0WE     = 0.0e-9
+WKU0WE     = -15e-10
+PKU0WE     = -0e-17
+U0         = '0.014444088+du0p_33'
+LU0        = '-1.6977297e-009+dlu0p_33'
+WU0        = '-2.267704e-009+dwu0p_33'
+PU0        = '1.9002958e-015+dpu0p_33'
+UA         = 6.2446178e-010      LUA        = -4.4456365e-016     WUA        = -6.5461912e-016
+PUA        = 4.5243327e-022      UB         = 1.4852981e-018      LUB        = 1.4943406e-025
+WUB        = 2.1647051e-025      PUB        = -2.075123e-031      UC         = 7.8058186e-012
+LUC        = 1.456158e-017       WUC        = 5.6597073e-018      PUC        = 3.8766034e-025
+VSAT       = '120000+dvsatp_33'  A0         = '2.0277567+da0p_33' LA0        = '-7.3521475e-007+dla0p_33'
+WA0        = '-4.4204272e-007+dwa0p_33'
+PA0        = '2.9916085e-013+dpa0p_33'
+AGS        = '0.27898717+dagsp_33'
+LAGS       = '1.0976525e-007+dlagsp_33'
+WAGS       = '5.4944933e-008+dwagsp_33'
+PAGS       = '-2.4302068e-014+dpagsp_33'
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0                   KETA       = -0.017067018        LKETA      = -4.3691233e-009
+WKETA      = -6.5673447e-009     PKETA      = 5.8355368e-015      DWG        = 0
+DWB        = 0                   PCLM       = '0.38502207+dpclmp_33'
+LPCLM      = '6.8073884e-008+dlpclmp_33'
+WPCLM      = '-9.4780967e-008+dwpclmp_33'
+PPCLM      = '6.4924962e-014+dppclmp_33'
+PDIBLC1    = 0                   PDIBLC2    = 1e-005              PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 1.5                 DELTA      = 0.0072
+PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55
+RDSW       = 0                   RSW        = 100
+RDW        = 100                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 0                   ALPHA1     = 7.5395
+BETA0      = 27.52               AGIDL      = 6.1e-012            BGIDL      = 1.1868e+009
+CGIDL      = 0.5                 EGIDL      = 0.552               AIGC       = 0.43
+AIGSD      = 0.43                XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'Cgop_33'           CGDO       = 'Cgop_33'           CGBO       = 0
+CGDL       = 'Cglp_33'           CGSL       = 'Cglp_33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfp_33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 1.03                MOIN       = 5.4649
+NOFF       = 2.8966              VOFFCV     = 0.069               TVOFF      = 0.0078162936
+LTVOFF     = -1.965538e-009      WTVOFF     = -1.119729e-009      PTVOFF     = 4.3109567e-016
+KT1        = -0.20119403         LKT1       = -4.7588297e-008     WKT1       = 2.1435618e-008
+PKT1       = -8.252713e-015      KT1L       = 0                   KT2        = -0.086007533
+LKT2       = 1.07213e-008        WKT2       = 1.0153714e-008      PKT2       = -3.9091799e-015
+UTE        = -0.20938525         LUTE       = -4.9457668e-007     WUTE       = -2.9050904e-007
+PUTE       = 1.1184598e-013      UA1        = 4.8176091e-009      LUA1       = -1.8168763e-015
+WUA1       = -9.0537282e-016     PUA1       = 3.4856854e-022      UB1        = -4.6703481e-018
+LUB1       = 1.2785718e-024      WUB1       = 8.0666645e-025      PUB1       = -3.3933853e-031
+UC1        = 1.5987652e-010      LUC1       = -8.0929511e-017     WUC1       = -3.8781546e-017
+PUC1       = 1.4930895e-023      PRT        = 0                   AT         = 20080.692
+LAT        = -0.0035422663       WAT        = -0.066845283        PAT        = 2.5735434e-008
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noiap_33'
+NOIB       = 'noibp_33'
+NOIC       = 'noicp_33'
+EM         = 2.00000e+06
+EF         = 1.05
+JSS        = 1.13e-7             JSD        = 1.13e-7
+JSWS       = 1e-14               JSWD       = 1e-14               JSWGS      = 5e-14
+JSWGD      = 5e-14               NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   BVD        = 9
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 0.7
+PBD        = 0.7                 CJS        = 'cjp_33'            CJD        = 'cjp_33'
+MJS        = 0.31                MJD        = 0.31                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswp_33'          CJSWD      = 'cjswp_33'
+MJSWS      = 0.082               MJSWD      = 0.082               PBSWGS     = 0.5
+PBSWGD     = 0.5                 CJSWGS     = 'cjswgp_33'         CJSWGD     = 'cjswgp_33'
+MJSWGS     = 0.35                MJSWGD     = 0.35                TPB        = 1.6e-3
+TCJ        = 8.78e-4             TPBSW      = 1.5e-3              TCJSW      = 3.16e-4
+TPBSWG     = 1.4e-3              TCJSWG     = 1.13e-3             XTIS       = 3
+XTID       = 3                   JTSSWGS    = 1e-009              JTSSWGD    = 1e-009
+NJTSSWG    = 16                  XTSSWGS    = 0.25                XTSSWGD    = 0.25
+TNJTSSWG   = 0                   VTSSWGS    = 1                   VTSSWGD    = 1
+DMCG       = 1.245e-7            DMCI       = 3.05e-7             DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.30e-008
+RSHG       = 14.93
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 0
+KVTH0      = 1.5e-009
+LKVTH0     = -1.0e-007
+WKVTH0     = 7e-007
+PKVTH0     = 0
+LLODVTH    = 1
+WLODVTH    = 1
+STK2       = 0.5e-9
+LODK2      = 1
+LODETA0    = 1
+KU0        = 4e-009
+PKU0     = 0
+LKU0       = -10.0e-008
+WKU0       = 1.1e-006
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 0.8
+STETA0     = 4e-9
+TKU0       = 0
+LNFACTOR   = '0+dlnfactorp_33'
+WNFACTOR   = '0+dwnfactorp_33'   PNFACTOR   = '0+dpnfactorp_33'   LVSAT      = '0+dlvsatp_33'
+WVSAT      = '0+dwvsatp_33'      PVSAT      = '0+dpvsatp_33'      )



.ENDL MOS_33


 
***************************************************************
*                                                             *
*                     Native DEVICE MODELS                    *
*                                                             *
***************************************************************
.LIB MOS_na
**********************************************************************************************
*                                                                                            *
*                               1.2V NATIVE NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_na.1 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-dxln_na' 
+LMAX       = 20.001e-6           WMIN       = '1e-005-dxwn_na'    WMAX       = 900.001e-6          
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = 'toxn_na'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+dxln_na' 
+XW         = '2e-08+dxwn_na'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.2215+dvthn_na'  
+K1         = 0.07                
+K2         = '0.003274+dk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            
+W0         = 0                   DVT0       = 1.2e-006            DVT1       = 0.1                 
+DVT2       = 0.16                DVT0W      = 0                   DVT1W      = 0                   
+DVT2W      = 0                   DSUB       = 0.1693              MINV       = -0.45422941         
+VOFFL      = 0                   DVTP0      = 0.0001              DVTP1      = 2.22e-015           
+LPE0       = 1.114e-006          LPEB       = 6.974e-008          WEB        = 0                   
+WEC        = 0                   SCREF      = 1e-006              KVTH0WE    = 0                   
+LKVTH0WE   = 0                   WKVTH0WE   = 0                   PKVTH0WE   = 0                   
+K2WE       = 0                   LK2WE      = 0                   WK2WE      = 0                   
+PK2WE      = 0                   XJ         = 8.6e-008            NGATE      = 1e+023              
+NDEP       = 6.5e+017            NSD        = 1e+020              PHIN       = 0                   
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0                   
+CIT        = 0.001465            VOFF       = -0.02904            NFACTOR    = 1                   
+ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                   U0         = 0.0417              UA         = -8.233e-012         
+UB         = 2.608e-18           
+Pub      = 0 
+Wub      = 0 
+Lub      = 0 
+UC         = 5.201e-011          VSAT       = '110000+dvsatn_na'  
+A0         = 12                  
+Pa0      = 0 
+Wa0      = 0 
+La0      = 0 
+AGS        = 0.9672              A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.03098            
+Pketa    = 0 
+Wketa    = 0 
+Lketa    = 0 
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.00784             
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+laigc    = 0 
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+laigsd   = 0 
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.01783             LTVOFF     = 0                   WTVOFF     = 0                   
+PTVOFF     = 0                   KT1        = -0.3204             KT1L       = 0                   
+KT2        = -0.01368            
+Pkt2     = 0 
+Wkt2     = 0 
+Lkt2     = 0 
+UTE        = -1.896              UA1        = 1.097e-009          
+UB1        = -2.747e-018        
+UC1        = 6.4e-11             
+Puc1     = 0 
+Wuc1     = 0 
+Luc1     = 0 
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.2 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-dxln_na' 
+LMAX       = '1.000489e-005-dxln_na' 
+WMIN       = '1e-005-dxwn_na'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.22523998+dvthn_na' 
+LVTH0      = '3.7287579e-08+dlvthn_na'  
+K1         = 0.07               
+K2         = '0.0044363938+dk2n_na'  
+LK2        = '-1.1589065e-08+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.001393201         
+LCIT       = 7.1583604e-010      VOFF       = -0.023729017        LVOFF      = -5.2950498e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                   U0         = 0.041365652         
+LU0        = 3.3334454e-009      UA         = -8.1219795e-012     LUA        = -1.1068748e-018     
+UB         = 2.5680284e-18       
+Pub      = 0 
+Wub      = 0 
+LUB        = 3.9851769e-25      
+UC         = 5.5815668e-11       
+Puc      = 0 
+Wuc      = 0 
+LUC        = -3.7942517e-17      
+VSAT       = '110000+dvsatn_na' 
+A0         = 12.835012           
+Pa0      = 0 
+Wa0      = 0 
+LA0        = -8.3250658e-06      
+AGS        = 0.78933137          LAGS       = 1.7733502e-006      
+A1         = 0                   A2         = 1                   B0         = 0                   
+B1         = 0                  
+KETA       = -0.028856036        
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = -2.1175926e-08      
+DWG        = 0                   DWB        = 0                   PCLM       = 2                   
+PDIBLC1    = 0                   PDIBLC2    = 0.0083560955        LPDIBLC2   = -5.1454722e-009     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.039283729         
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = 1.0684121e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.0192573           
+LTVOFF     = -1.4230179e-008     WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.30997307         LKT1       = -1.0395649e-007     KT1L       = 0                   
+KT2        = -0.012746613        
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -9.305869e-09       
+UTE        = -1.9069306          
+LUTE       = 1.0897802e-007      UA1        = 1.0204858e-009      LUA1       = 7.6284616e-016      
+UB1        = -2.593543e-018      LUB1       = -1.529966e-024     
+UC1        = 6.3503837e-11       
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 4.946747e-18        
+PRT        = 0                   AT         = 93999.975           
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             JSD        = 5.11E-6             
+JSWS       = 5.46E-12            JSWD       = 5.46E-12            JSWGS      = 5.46E-12            
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01                
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01                
+BVS        = 19                BVD        = 19                XJBVS      = 1                   
+XJBVD      = 1                   JSWGD      = 5.46E-12            PBS        = 0.25                
+PBD        = 0.25                CJS        = 'cjn_na'            CJD        = 'cjn_na'            
+MJS        = 0.24                MJD        = 0.24                PBSWS      = 1                   
+PBSWD      = 1                   CJSWS      = 'cjswn_na'          CJSWD      = 'cjswn_na'          
+MJSWS      = 0.01                MJSWD      = 0.01                PBSWGS     = 0.6                 
+PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         CJSWGD     = 'cjswgn_na'         
+MJSWGS     = 0.5                 MJSWGD     = 0.5                 TPB        = 1.0e-3              
+TCJ        = 1.68e-3             TPBSW      = 1E-03               TCJSW      = 1E-04               
+TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            XTIS       = 3                   
+XTID       = 3                  
+DMCG       = 6.7e-8             
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0                   
+XGW        = 0                   XGL        = -2.11e-008          RSHG       = 15.06                  
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50                  
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50                  
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7              
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.3 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-dxln_na' 
+LMAX       = '9.998918e-007-dxln_na' 
+WMIN       = '1e-005-dxwn_na'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.20387473+dvthn_na' 
+LVTH0      = '1.6670122e-08+dlvthn_na'  
+K1         = 0.07               
+K2         = '-0.0053184497+dk2n_na' 
+LK2        = '-2.1756411e-09+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.002061386         
+LCIT       = 7.1037474e-011      VOFF       = -0.041989322        LVOFF      = -3.5329304e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                  
+U0         = 0.042395668         
+Pu0      = 0 
+Wu0      = 0 
+LU0        = 2.3394906e-09       
+UA         = -1.4913719e-011     LUA        = 5.4471535e-018      
+UB         = 2.9623511e-018      LUB        = 1.799616e-026      
+UC         = 1.023081e-10        
+Puc      = 0 
+Wuc      = 0 
+LUC        = -8.28078e-17        
+VSAT       = '41293.995+dvsatn_na' 
+A0         = 7.5946349           
+LA0        = -3.2681027e-006    
+AGS        = 4.2238601           
+Pags     = 0 
+Wags     = 0 
+LAGS       = -1.541004e-06       
+A1         = 0                   A2         = 1                   B0         = 0                   
+B1         = 0                  
+KETA       = -0.083974999        
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = 3.2014043e-08       
+DWG        = 0                   DWB        = 0                   PCLM       = 2                   
+PDIBLC1    = 0                   PDIBLC2    = -0.017790103        LPDIBLC2   = 2.0085609e-008      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.25796658          
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = -1.0418801e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.005493501         
+LTVOFF     = -9.4811349e-010     WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.41622772         LKT1       = -1.4207495e-009     KT1L       = 0                   
+KT2        = -0.01635363         
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -5.825086e-09       
+UTE        = -1.6801437          
+LUTE       = -1.0987129e-007     UA1        = 3.3062468e-009      LUA1       = -1.4429132e-015     
+UB1        = -5.1929097e-018     LUB1       = 9.7842281e-025     
+UC1        = -2.8413175e-11      
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 9.3646513e-17       
+PRT        = 0                   AT         = 122876.25           
+LAT        = -0.02786561        
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      
+PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.066301464+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.4 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007' 
+LMAX       = '4.997495e-007-dxln_na' 
+WMIN       = '1e-005-dxwn_na'    WMAX       = 900.001e-6          VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.15172282+dvthn_na' 
+LVTH0      = '-8.2584959e-09+dlvthn_na' 
+K1         = 0.07               
+K2         = '-0.0040961665+dk2n_na' 
+LK2        = '-2.7598923e-09+dlk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0022557772        
+LCIT       = -2.1881503e-011     VOFF       = -0.087843005        LVOFF      = -1.3411244e-008     
+NFACTOR    = 1                   ETA0       = '0.1276+deta0n_na'  ETAB       = 0.04529             
+UD         = 0                   LUD        = 0                   WUD        = 0                   
+PUD        = 0                   KU0WE      = 0                   LKU0WE     = 0                   
+WKU0WE     = 0                   PKU0WE     = 0                  
+U0         = 0.049593625         
+Pu0      = 0 
+Wu0      = 0 
+LU0        = -1.1011326e-09      
+UA         = -5.597171e-012      LUA        = 9.9384373e-019      
+UB         = 3e-018             
+UC         = -1.2001495e-10      
+Puc      = 0 
+Wuc      = 0 
+LUC        = 2.34626e-17         
+VSAT       = '283367.82+dvsatn_na' 
+A0         = 10.572528           LA0        = -4.6915353e-006     
+AGS        = 2.475217            
+Pags     = 0 
+Wags     = 0 
+LAGS       = -7.05155e-07        
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.04398699          
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = -2.9151779e-08      
+DWG        = 0                   
+DWB        = 0                   PCLM       = 2.9834715           LPCLM      = -4.7009938e-007     
+PDIBLC1    = 0                   PDIBLC2    = 0.048037098         LPDIBLC2   = -1.1379793e-008     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.025233168         
+Ppdits   = 0 
+Wpdits   = 0 
+Lpdits   = 7.058545e-09 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+waigc    = 0 
+LAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084           
+AIGSD      = 0.01016             
+paigsd   = 0 
+waigsd   = 0 
+LAIGSD     = 0                   
+BIGSD      = 1e-005              CIGSD      = 7.8125e-005         
+NIGC       = 0.1                 POXEDGE    = 1                   PIGCD      = 4.227               
+NTOX       = 'ntoxn_na'          XRCRG1     = 12                  XRCRG2     = 1                   
+CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           CGBO       = 0                   
+CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           CLC        = 1e-007              
+CLE        = 0.6                 CF         = 'cfn_na'            CKAPPAS    = 0.6                 
+CKAPPAD    = 0.6                 ACDE       = 0.41                MOIN       = 10.5                
+NOFF       = 2.9                 VOFFCV     = -0.125              TVOFF      = 0.00010919689       
+LTVOFF     = 1.6255839e-009      WTVOFF     = 0                   PTVOFF     = 0                   
+KT1        = -0.66270511         
+Pkt1     = 0 
+Wkt1     = 0 
+LKT1       = 1.1639544e-07       
+KT1L       = 0                   
+KT2        = -0.020034267        
+Pkt2     = 0 
+Wkt2     = 0 
+LKT2       = -4.065741e-09       
+UTE        = -3.114974           
+Pute     = 0 
+Wute     = 0 
+LUTE       = 5.7597756e-07       
+UA1        = -2.7697264e-009     LUA1       = 1.461402e-015       
+UB1        = -2.1403782e-018     LUB1       = -4.806872e-025     
+UC1        = -7.24611e-11        
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 1.147014e-16        
+PRT        = 0                   AT         = 164499.82           
+LAT        = -0.047761673       
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+WVTH0      = '0+dwvthn_na'       
+PVTH0      = '0+dpvthn_na'      
+WK2        = '0+dwk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      WETA0      = '0+dweta0n_na'      
+PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.049409815+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.5 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-dxln_na' 
+LMAX       = 20.001e-6           WMIN       = '1e-006-dxwn_na'    WMAX       = '1e-005-dxwn_na'    
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = 'toxn_na'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+dxln_na' 
+XW         = '2e-08+dxwn_na'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.215482+dvthn_na' 
+WVTH0      = '-6.030036e-08+dwvthn_na'  
+K1         = 0.07               
+K2         = '0.0031123866+dk2n_na'  
+WK2        = '1.6193656e-09+dwk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0014504933        
+WCIT       = 1.453568e-010       VOFF       = -0.03273682         WVOFF      = 3.7042136e-008      
+NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.042123867         
+Pu0      = 0 
+Lu0      = 0 
+WU0        = -4.247144e-09       
+UA         = -8.45196e-012       WUA        = 2.1939792e-018     
+UB         = 2.6014266e-18       
+Pub      = 0 
+Lub      = 0 
+WUB        = 6.58648e-26         
+UC         = 5.6513867e-011      WUC        = -4.5128744e-017     
+VSAT       = '110000+dvsatn_na' 
+A0         = 11.66               
+Pa0      = 0 
+Wa0      = 3.4068e-06 
+La0      = 0 
+AGS        = 0.97915667          
+WAGS       = -1.198058e-007      A1         = 0                   A2         = 1                   
+B0         = 0                   B1         = 0                  
+KETA       = -0.032103133        
+Pketa    = 0 
+Lketa    = 0 
+WKETA      = 1.1253796e-08       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.0083970333        
+WPDIBLC2   = -5.581474e-009      PDIBLCB    = 0.22000011          DROUT      = 0.56                
+PVAG       = 1.5                 DELTA      = 0.05                PSCBE1     = 9.264e+008          
+PSCBE2     = 1e-020              FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52                
+RSW        = 16.58               RDW        = 16.58               PRWG       = 0                   
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.2e-008            
+ALPHA1     = 0.01                BETA0      = 11                  AIGBACC    = 0.01302             
+BIGBACC    = 0.005269            CIGBACC    = 0.19351             NIGBACC    = 20.288              
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006               
+EIGBINV    = 1.1                 NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+laigc    = 0 
+WAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084            
+AIGSD      = 0.01016             
+paigsd   = 0 
+laigsd   = 0 
+WAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.019850733         LTVOFF     = 0                   WTVOFF     = -2.0247748e-008     
+PTVOFF     = 0                  
+KT1        = -0.29934267         
+Pkt1     = 0 
+Lkt1     = 0 
+WKT1       = -2.1099448e-07      
+KT1L       = 0                  
+KT2        = -0.0152304          
+Pkt2     = 0 
+Lkt2     = 0 
+WKT2       = 1.5535008e-08       
+UTE        = -1.8615466          
+Pute     = 0 
+Lute     = 0 
+WUTE       = -3.452224e-07       
+UA1        = 1.2236863e-009      
+WUA1       = -1.2693964e-015     UB1        = -3.0583267e-018     WUB1       = 3.1194932e-024      
+UC1        = 9.3919993e-11       
+Puc1     = 0 
+Luc1     = 0 
+WUC1       = -2.997984e-16       
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      
+LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.6 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-dxln_na' 
+LMAX       = '1.000489e-005-dxln_na' 
+WMIN       = '1e-006-dxwn_na'    WMAX       = '1e-005-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.2187799+dvthn_na'  
+LVTH0      = '3.2880023e-08+dlvthn_na'  
+WVTH0      = '-6.473002e-08+dwvthn_na'   
+PVTH0      = '4.4163708e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '0.0042329285+dk2n_na'  
+LK2        = '-1.1171801e-08+dlk2n_na'  
+WK2        = '2.0387229e-09+dwk2n_na'  
+PK2        = '-4.1809925e-15+dpk2n_na' 
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0013810505        
+LCIT       = 6.9234522e-010      WCIT       = 1.2174817e-010      PCIT       = 2.35378e-016        
+VOFF       = -0.027734675        LVOFF      = -4.9871385e-008     WVOFF      = 4.0136692e-008      
+PVOFF      = -3.0852717e-014     NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.041828626         
+LU0        = 2.9435463e-09       
+WU0        = -4.6389985e-09      
+PU0        = 3.9067896e-15       
+UA         = -8.3513357e-012     
+LUA        = -1.0032246e-018     WUA        = 2.2981492e-018      PUA        = -1.0385751e-024     
+UB         = 2.5597183e-18       
+LUB        = 4.1583308e-25       
+WUB        = 8.326704e-26        
+PUB        = -1.735003e-31      
+UC         = 6.0664505e-11       
+LUC        = -4.138186e-17       
+WUC        = -4.858534e-17       
+PUC        = 3.446225e-23        
+VSAT       = '110000+dvsatn_na'  
+A0         = 12.440833           
+LA0        = -7.7848987e-06      
+WA0        = 3.9496768e-06       
+PA0        = -5.4124809e-12      
+AGS        = 0.81069442          LAGS       = 1.6795686e-006      
+WAGS       = -2.1405776e-007     PAGS       = 9.3969207e-013      A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.029991314        
+LKETA      = -2.1054839e-08      
+WKETA      = 1.137549e-08        
+PKETA      = -1.213289e-15       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = 0.0089570334        
+LPDIBLC2   = -5.5832006e-009     WPDIBLC2   = -6.0213976e-009     PPDIBLC2   = 4.3860385e-015      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.039283729         
+Ppdits   = 0              
+Wpdits   = 0             
+Lpdits   = 1.0684121e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.021496742         LTVOFF     = -1.6410709e-008     WTVOFF     = -2.2439213e-008     
+PTVOFF     = 2.1848902e-014     
+KT1        = -0.28690572         
+LKT1       = -1.2399633e-07      
+WKT1       = -2.3113483e-07      
+PKT1       = 2.0079927e-13       
+KT1L       = 0                   
+KT2        = -0.014328833        
+LKT2       = -8.988622e-09       
+WKT2       = 1.5853845e-08       
+PKT2       = -3.178812e-15      
+UTE        = -1.8685544          
+LUTE       = 6.986702e-08        
+WUTE       = -3.8452956e-07      
+PUTE       = 3.9189226e-13       
+UA1        = 1.1597887e-009      
+LUA1       = 6.3705889e-016      WUA1       = -1.3958145e-015     PUA1       = 1.2603885e-021      
+UB1        = -2.9333743e-018     LUB1       = -1.2457755e-024     WUB1       = 3.4051089e-024      
+PUB1       = -2.8475885e-030    
+UC1        = 9.7249182e-11       
+LUC1       = -3.3191927e-17      
+WUC1       = -3.3812834e-16      
+PUC1       = 3.8214951e-22       
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      
+WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.7 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-dxln_na' 
+LMAX       = '9.998918e-007-dxln_na' 
+WMIN       = '1e-006-dxwn_na'    WMAX       = '1e-005-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.20106992+dvthn_na' 
+LVTH0      = '1.578989e-08+dlvthn_na'   
+WVTH0      = '-2.8104333e-08+dwvthn_na'  
+PVTH0      = '8.819929e-15+dpvthn_na'   
+K1         = 0.07               
+K2         = '-0.0052218906+dk2n_na' 
+LK2        = '-2.0478999e-09+dlk2n_na'  
+WK2        = '-9.675219e-10+dwk2n_na'  
+PK2        = '-1.2799665e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020538148        
+LCIT       = 4.312764e-011       WCIT       = 7.5863676e-011      PCIT       = 2.7965654e-016      
+VOFF       = -0.044304802        LVOFF      = -3.3881213e-008     WVOFF      = 2.3201101e-008      
+PVOFF      = -1.4509872e-014     NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.042679304         
+LU0        = 2.122652e-09        
+WU0        = -2.842046e-09       
+PU0        = 2.1727235e-15       
+UA         = -1.5646256e-011     
+LUA        = 6.0363731e-018      WUA        = 7.3400194e-018      PUA        = -5.9039798e-024     
+UB         = 2.9814398e-018      LUB        = 8.8717912e-027      WUB        = -1.9126815e-025     
+PUB        = 9.1426177e-032     
+UC         = 1.0314189e-10       
+LUC        = -8.237264e-17       
+WUC        = -8.35487e-18        
+PUC        = -4.36032e-24        
+VSAT       = '40181.613+dvsatn_na' 
+A0         = 7.9071503           LA0        = -3.4098954e-006     WA0        = -3.1314046e-006     
+PA0        = 1.4207628e-012     
+AGS        = 4.1848595           
+LAGS       = -1.576535e-06       
+WAGS       = 3.90785e-07         
+PAGS       = 3.56021e-13         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.087750154        
+LKETA      = 3.4682632e-08       
+WKETA      = 3.7827079e-08       
+PKETA      = -2.6739261e-14      
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = -0.019028806        
+LPDIBLC2   = 2.1423134e-008      WPDIBLC2   = 1.2411805e-008      PPDIBLC2   = -1.3402002e-014     
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.26575327          
+Ppdits   = 7.5291941e-14 
+Wpdits   = -7.8022542e-08 
+Lpdits   = -1.1170218e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.0055207155        LTVOFF     = -9.9384268e-010     WTVOFF     = -2.7268857e-010     
+PTVOFF     = 4.5820649e-016      KT1        = -0.40785341         LKT1       = -7.2818147e-009     
+WKT1       = -8.391058e-008      PKT1       = 5.8727874e-014      KT1L       = 0                   
+KT2        = -0.018440266        
+LKT2       = -5.0210717e-09      
+WKT2       = 2.0908104e-08       
+PKT2       = -8.056216e-15       
+UTE        = -1.6135514          LUTE       = -1.7621082e-007     
+WUTE       = -6.6725478e-007     PUTE       = 6.6472208e-013      UA1        = 3.6370587e-009      
+LUA1       = -1.7535067e-015     WUA1       = -3.3147353e-015     PUA1       = 3.1121471e-021      
+UB1        = -5.4148903e-018     LUB1       = 1.1488875e-024      WUB1       = 2.2242463e-024      
+PUB1       = -1.7080561e-030    
+UC1        = -3.606643e-11       
+LUC1       = 9.545744e-17        
+WUC1       = 7.668546e-17        
+PUC1       = -1.814561e-23       
+PRT        = 0                   
+AT         = 118154.16           LAT        = -0.023308792        WAT        = 0.047315345         
+PAT        = -4.5659308e-008    
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.067374916+dlvsatn_na' 
+WVSAT      = '0.011146077+dwvsatn_na' 
+PVSAT      = '-1.0755991e-08+dpvsatn_na' )


.MODEL nch_na.8 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007' 
+LMAX       = '4.997495e-007-dxln_na' 
+WMIN       = '1e-006-dxwn_na'    WMAX       = '1e-005-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.15122808+dvthn_na' 
+LVTH0      = '-8.034504e-09+dlvthn_na'  
+WVTH0      = '-4.9572123e-09+dwvthn_na' 
+PVTH0      = '-2.2443959e-15+dpvthn_na' 
+K1         = 0.07               
+K2         = '-0.0034294495+dk2n_na' 
+LK2        = '-2.9046867e-09+dlk2n_na'  
+WK2        = '-6.6805046e-09+dwk2n_na'  
+PK2        = '1.4508391e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0020602825        
+LCIT       = 4.0036091e-011      WCIT       = 1.958857e-009       PCIT       = -6.2041429e-016     
+VOFF       = -0.086693876        LVOFF      = -1.3619235e-008     WVOFF      = -1.1514278e-008     
+PVOFF      = 2.084079e-015       NFACTOR    = 1                   ETA0       = '0.1308266+deta0n_na' 
+WETA0      = '-3.2330532e-008+dweta0n_na' 
+ETAB       = 0.046634133         WETAB      = -1.3468216e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.04910732          
+LU0        = -9.4993853e-10      
+WU0        = 4.8727838e-09       
+PU0        = -1.5149657e-15      
+UA         = -5.586217e-012      
+LUA        = 1.2276746e-018      WUA        = -1.0975898e-019     PUA        = -2.3429858e-024     
+UB         = 2.9797497e-018      LUB        = 9.6796238e-027      WUB        = 2.029076e-025       
+PUB        = -9.6989831e-032    
+UC         = -1.1125513e-10      
+LUC        = 2.010914e-17        
+WUC        = -8.777345e-17       
+PUC        = 3.3601749e-23       
+VSAT       = '286174.73+dvsatn_na' 
+A0         = 10.203165           LA0        = -4.5073905e-006     WA0        = 3.7010098e-006      
+PA0        = -1.8451313e-012    
+AGS        = 2.3421029           
+LAGS       = -6.95699e-07        
+WAGS       = 1.333811e-06        
+PAGS       = -9.4745e-14         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.05210738          
+LKETA      = -3.2169259e-08      
+WKETA      = -8.136628e-08       
+PKETA      = 3.0235153e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 3.0949316           LPCLM      = -5.2337731e-007     WPCLM      = -1.1168302e-006     
+PPCLM      = 5.3384485e-013      PDIBLC1    = 0                   PDIBLC2    = 0.051189809         
+LPDIBLC2   = -1.2141364e-008     WPDIBLC2   = -3.1590156e-008     PPDIBLC2   = 7.6309355e-015      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.005584814         
+Ppdits   = -5.6109786e-14 
+Wpdits   = 1.968765e-07  
+Lpdits   = 1.2658324e-08 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.00026518598      LTVOFF     = 1.7718182e-009      WTVOFF     = 3.7513163e-009      
+PTVOFF     = -1.4652679e-015    
+KT1        = -0.68108559         
+LKT1       = 1.2332316e-07       
+WKT1       = 1.841725e-07        
+PKT1       = -6.9415831e-14      
+KT1L       = 0                   
+KT2        = -0.022681454        
+LKT2       = -2.993785e-09       
+WKT2       = 2.652482e-08        
+PKT2       = -1.0741004e-14      
+UTE        = -3.2531062          
+LUTE       = 6.0749632e-07       
+WUTE       = 1.3840846e-06       
+PUTE       = -3.1581813e-13      
+UA1        = -3.3895002e-009     
+LUA1       = 1.6051884e-015      WUA1       = 6.2101328e-015      PUA1       = -1.4407399e-021     
+UB1        = -1.8405564e-018     LUB1       = -5.5964413e-025     WUB1       = -3.0042151e-024     
+PUB1       = 7.9114846e-031     
+UC1        = -1.1418203e-10      
+LUC1       = 1.3279669e-16       
+WUC1       = 4.1804357e-16       
+PUC1       = -1.8131477e-22      
+PRT        = 0                   
+AT         = 175592.58           LAT        = -0.050764357        WAT        = -0.1111495          
+PAT        = 3.0086887e-008     
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.050209783+dlvsatn_na' 
+WVSAT      = '-0.02812521+dwvsatn_na' 
+PVSAT      = '8.015684e-09+dpvsatn_na'  )


.MODEL nch_na.9 NMOS	(	LEVEL      = 54                  LMIN       = '1.000489e-005-dxln_na' 
+LMAX       = 20.001e-6           WMIN       = 5e-07               WMAX       = '1e-006-dxwn_na'    
+VERSION    = 4.5                 RGEOMOD    = 1                   NGCON      = 1                   
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0                   
+CAPMOD     = 2                   IGCMOD     = 1                   IGBMOD     = 1                   
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0                   
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   
+TRNQSMOD   = 0                   TEMPMOD    = 0                   WPEMOD     = 1                   
+TNOM       = 25                  TOXE       = 'toxn_na'           TOXM       = 2.6e-009            
+DTOX       = 2.05e-010           EPSROX     = 3.9                 WINT       = 0                   
+LINT       = 1.694588E-08        LL         = 0                   WL         = 0                   
+LLN        = 0                   WLN        = 1                   LW         = 0                   
+WW         = 0                   LWN        = 1                   WWN        = 1                   
+LWL        = 0                   WWL        = 0                   LLC        = 0                   
+WLC        = 0                   LWC        = 0                   WWC        = 0                   
+LWLC       = 0                   WWLC       = 0                   XL         = '-1.00E-09+dxln_na' 
+XW         = '2e-08+dxwn_na'     DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.262536+dvthn_na' 
+WVTH0      = '-1.230528e-08+dwvthn_na'  
+K1         = 0.07               
+K2         = '0.00669472+dk2n_na' 
+WK2        = '-2.0346144e-09+dwk2n_na' 
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.00117492          
+WCIT       = 4.264416e-010       VOFF       = 0.00313076          WVOFF      = 4.572048e-010       
+NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.0381472           
+Pu0      = 0 
+Lu0      = 0 
+WU0        = -1.90944e-10        
+UA         = -7.51988e-012       WUA        = 1.2432576e-018     
+UB         = 2.91456e-18         
+Pub      = 0 
+Lub      = 0 
+WUB        = -2.535312e-25       
+UC         = 1.00444e-011        WUC        = 2.270112e-018       
+VSAT       = '110000+dvsatn_na'  A0         = 15                  AGS        = 0.8981              
+WAGS       = -3.7128e-008        A1         = 0                   A2         = 1                   
+B0         = 0                   B1         = 0                  
+KETA       = -0.035942           
+Pketa    = 0 
+Lketa    = 0 
+WKETA      = 1.516944e-08        
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                   PDIBLC2    = -0.0084162          
+WPDIBLC2   = 1.1568024e-008      PDIBLCB    = 0.22000011          DROUT      = 0.56                
+PVAG       = 1.5                 DELTA      = 0.05                PSCBE1     = 9.264e+008          
+PSCBE2     = 1e-020              FPROUT     = 600                
+PDITS      = 0.07392             
+Ppdits   = 0 
+Wpdits   = -2.43984e-08 
+Lpdits   = 0 
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52                
+RSW        = 16.58               RDW        = 16.58               PRWG       = 0                   
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1.2e-008            
+ALPHA1     = 0.01                BETA0      = 11                  AIGBACC    = 0.01302             
+BIGBACC    = 0.005269            CIGBACC    = 0.19351             NIGBACC    = 20.288              
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006               
+EIGBINV    = 1.1                 NIGBINV    = 1                  
+AIGC       = 0.01217             
+paigc    = 0 
+laigc    = 0 
+WAIGC      = 0                   
+BIGC       = 0.001832            CIGC       = 0.038084            
+AIGSD      = 0.01016             
+paigsd   = 0 
+laigsd   = 0 
+WAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.0743288           LTVOFF     = 0                   WTVOFF     = -7.5815376e-008     
+PTVOFF     = 0                  
+KT1        = -0.586696           
+Pkt1     = 0 
+Lkt1     = 0 
+WKT1       = 8.210592e-08        
+KT1L       = 0                   KT2        = -1.8023768e-017     WKT2       = 1.8030359e-023      
+UTE        = -2.408              
+Pute     = 0 
+Wute     = 2.1216e-07 
+Lute     = 0 
+UA1        = 4.84232e-11         
+Pua1     = 0 
+Lua1     = 0 
+WUA1       = -7.062806e-17       
+UB1        = 3.33067e-034       
+UC1        = -2.77584e-10        
+Puc1     = 0 
+Luc1     = 0 
+WUC1       = 7.913568e-17        
+PRT        = 0                   AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             JSD        = 5.11E-6             JSWS       = 5.46E-12            
+JSWD       = 5.46E-12            JSWGS      = 5.46E-12            NJS        = 1                   
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 19                
+BVD        = 19                XJBVS      = 1                   XJBVD      = 1                   
+JSWGD      = 5.46E-12            PBS        = 0.25                PBD        = 0.25                
+CJS        = 'cjn_na'            CJD        = 'cjn_na'            MJS        = 0.24                
+MJD        = 0.24                PBSWS      = 1                   PBSWD      = 1                   
+CJSWS      = 'cjswn_na'          CJSWD      = 'cjswn_na'          MJSWS      = 0.01                
+MJSWD      = 0.01                PBSWGS     = 0.6                 PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgn_na'         CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 
+MJSWGD     = 0.5                 TPB        = 1.0e-3              TCJ        = 1.68e-3             
+TPBSW      = 1E-03               TCJSW      = 1E-04               TPBSWG     = 5.00E-04            
+TCJSWG     = 1.50E-03            XTIS       = 3                   XTID       = 3                   
+DMCG       = 6.7e-8             
+DMCI       = 7.2e-8              
+DMDG       = 0                   
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0                   
+XGL        = -2.11e-008          RSHG       = 15.06                  GBMIN      = 1e-012              
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50                  
+RBDB       = 50                  RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LVTH0      = '0+dlvthn_na'       
+PVTH0      = '0+dpvthn_na'       
+LK2        = '0+dlk2n_na'        
+PK2        = '0+dpk2n_na'        
+LETA0      = '0+dleta0n_na'      
+PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      WVSAT      = '0+dwvsatn_na'      
+PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.10 NMOS	(	LEVEL      = 54                  LMIN       = '9.998918e-007-dxln_na' 
+LMAX       = '1.000489e-005-dxln_na' 
+WMIN       = 5e-07               WMAX       = '1e-006-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 1.694588E-08        
+LL         = 0                   WL         = 0                   LLN        = 0                   
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 0                   WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '1.694588E-08+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.27377651+dvthn_na' 
+LVTH0      = '1.1206787e-07+dlvthn_na'  
+WVTH0      = '-8.6334751e-09+dwvthn_na'  
+PVTH0      = '-3.6607898e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '0.0089179387+dk2n_na' 
+LK2        = '-2.216549e-08+dlk2n_na'   
+WK2        = '-2.7399876e-09+dwk2n_na' 
+PK2        = '7.03257e-15+dpk2n_na'    
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0011669214        
+LCIT       = 7.9746271e-011      WCIT       = 3.4015986e-010      PCIT       = 8.6022893e-016      
+VOFF       = 0.012363636         LVOFF      = -9.205177e-008      WVOFF      = -7.6358516e-010     
+PVOFF      = 1.2171276e-014      NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.037307302         
+LU0        = 8.3737859e-09       
+WU0        = -2.724741e-11       
+PU0        = -1.632055e-15       
+UA         = -7.4390536e-012     
+LUA        = -8.0583906e-019     WUA        = 1.3676215e-018      PUA        = -1.2399084e-024     
+UB         = 2.9023949e-18       
+LUB        = 1.2128611e-25       
+WUB        = -2.6626316e-25      
+PUB        = 1.2693761e-31      
+UC         = 5.5331115e-12       
+LUC        = 4.4977537e-17       
+WUC        = 7.648683e-18        
+PUC        = -5.3624341e-23      
+VSAT       = '110000+dvsatn_na'  
+A0         = 16.318525           LA0        = -1.3145698e-005     WA0        = -5.5702308e-009     
+PA0        = 5.5535201e-014      AGS        = 0.57560247          LAGS       = 3.2153004e-006      
+WAGS       = 2.5736033e-008      PAGS       = -6.2675441e-013     A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = -0.039830546        
+LKETA      = 3.8768827e-08       
+WKETA      = 2.141151e-08        
+PKETA      = -6.223343e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                  
+PDIBLC2    = -0.0095824258       
+LPDIBLC2   = 1.1627272e-08       
+WPDIBLC2   = 1.2888851e-08       
+PPDIBLC2   = -1.3168643e-14      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.06576706          
+Ppdits   = 2.6067545e-14  
+Wpdits   = -2.7012999e-08 
+Lpdits   = 8.128479e-08  
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = 0.083017641         LTVOFF     = -8.6627742e-008     WTVOFF     = -8.5190529e-008     
+PTVOFF     = 9.3470276e-014     
+KT1        = -0.58531147         
+LKT1       = -1.380387e-08       
+WKT1       = 7.3239023e-08       
+PKT1       = 8.8402969e-14       
+KT1L       = 0                   
+KT2        = -0.0008900086       
+LKT2       = 8.873378e-09        
+WKT2       = 2.146244e-09        
+PKT2       = -2.1398053e-14     
+UTE        = -2.4243445          
+LUTE       = 1.6295422e-07       
+WUTE       = 1.8237632e-07       
+PUTE       = 2.9694331e-13       
+UA1        = -2.7562915e-10      
+LUA1       = 3.2308018e-15       
+WUA1       = 6.831169e-17        
+PUA1       = -1.3852293e-21      
+UB1        = 8.261343e-019       LUB1       = -8.236559e-024      WUB1       = -4.2958984e-025     
+PUB1       = 4.2830107e-030     
+UC1        = -3.1174403e-10      
+LUC1       = 3.4057554e-16       
+WUC1       = 7.9044742e-17       
+PUC1       = 9.0669e-25          
+PRT        = 0                   
+AT         = 93999.975          
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      LVSAT      = '0+dlvsatn_na'      
+WVSAT      = '0+dwvsatn_na'      PVSAT      = '0+dpvsatn_na'      )


.MODEL nch_na.11 NMOS	(	LEVEL      = 54                  LMIN       = '4.997495e-007-dxln_na' 
+LMAX       = '9.998918e-007-dxln_na' 
+WMIN       = 5e-07               WMAX       = '1e-006-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.16928865+dvthn_na' 
+LVTH0      = '1.1237128e-08+dlvthn_na'  
+WVTH0      = '-6.052123e-08+dwvthn_na'   
+PVTH0      = '1.3463745e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '-0.01029922+dk2n_na' 
+LK2        = '-3.6209357e-09+dlk2n_na'  
+WK2        = '4.2113542e-09+dwk2n_na'  
+PK2        = '3.245302e-16+dpk2n_na'    
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 6.1253963e-005      
+LCIT       = 1.1467153e-009      WCIT       = 2.1082757e-009      PCIT       = -8.460029e-016      
+VOFF       = -0.028959602        LVOFF      = -5.2174846e-008     WVOFF      = 7.548997e-009       
+PVOFF      = 4.1496342e-015      NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.04345602          
+LU0        = 2.4402754e-09       
+WU0        = -3.6342964e-09      
+PU0        = 1.8487474e-15       
+UA         = -8.2913947e-012     
+LUA        = 1.6670127e-020      WUA        = -1.6193864e-019     PUA        = 2.361172e-025       
+UB         = 3.0495164e-018      LUB        = -2.0686113e-026     WUB        = -2.607063e-025      
+PUB        = 1.2157524e-031     
+UC         = 2.0119193e-10       
+LUC        = -1.4383359e-16      
+WUC        = -1.0836587e-16      
+PUC        = 5.832985e-23        
+VSAT       = '51109.136+dvsatn_na' 
+A0         = 4.6215339           LA0        = -1.8581016e-006     WA0        = 2.199241e-007       
+PA0        = -1.6206683e-013    
+AGS        = 5.779722            
+LAGS       = -1.806705e-06       
+WAGS       = -1.235974e-06       
+PAGS       = 5.90795e-13         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.015026988         
+LKETA      = -1.4168771e-08      
+WKETA      = -6.7005605e-08      
+PKETA      = 2.3089167e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 2                   PDIBLC1    = 0                  
+PDIBLC2    = 0.0060641877        
+LPDIBLC2   = -3.4717082e-09      
+WPDIBLC2   = -1.3183049e-08      
+PPDIBLC2   = 1.1990738e-14       
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.087183083         
+Ppdits   = -1.0047513e-13 
+Wpdits   = 1.0411905e-07  
+Lpdits   = 6.0618485e-08  
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.013966012        LTVOFF     = 6.9614831e-009      WTVOFF     = 1.9603774e-008      
+PTVOFF     = -7.6562258e-015     KT1        = -0.72931399         LKT1       = 1.2515856e-007      
+WKT1       = 2.4397921e-007      PKT1       = -7.6361307e-014     KT1L       = 0                   
+KT2        = 0.023254924         
+LKT2       = -1.442648e-08       
+WKT2       = -2.1620989e-08      
+PKT2       = 1.537301e-15        
+UTE        = -3.1534526          LUTE       = 8.6654353e-007      
+WUTE       = 9.0344437e-007      PUTE       = -3.9888735e-013     UA1        = 5.9062311e-010      
+LUA1       = 2.3948684e-015      WUA1       = -2.0737094e-016     PUA1       = -1.1191955e-021     
+UB1        = -6.5978836e-018     LUB1       = -1.0723817e-024     WUB1       = 3.4308995e-024      
+PUB1       = 5.5763849e-031     
+UC1        = 8.625428e-11        
+LUC1       = -4.349334e-17       
+WUC1       = -4.808166e-17       
+PUC1       = 1.2358419e-22       
+PRT        = 0                   
+AT         = 133785.65           LAT        = -0.038393174        WAT        = 0.031371232         
+PAT        = -3.0273239e-008    
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '0.056829831+dlvsatn_na' 
+WVSAT      = '0+dwvsatn_na'           
+PVSAT      = '0+dpvsatn_na'             )


.MODEL nch_na.12 NMOS	(	LEVEL      = 54                  LMIN       = '2.995932e-007-dxln_na' 
+LMAX       = '4.997495e-007-dxln_na' 
+WMIN       = 5e-07               WMAX       = '1e-006-dxwn_na'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.098413894+dvthn_na' 
+LVTH0      = '-2.2641001e-08+dlvthn_na'  
+WVTH0      = '-5.8827684e-08+dwvthn_na'  
+PVTH0      = '1.2654232e-14+dpvthn_na'  
+K1         = 0.07               
+K2         = '-0.016401262+dk2n_na' 
+LK2        = '-7.041595e-10+dlk2n_na'  
+WK2        = '6.5507443e-09+dwk2n_na'  
+PK2        = '-7.936985e-16+dpk2n_na'   
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = 0.0049850742        
+LCIT       = -1.2068708e-009     WCIT       = -1.0244305e-009     PCIT       = 6.5143068e-016      
+VOFF       = -0.15551324         LVOFF      = 8.3177944e-009      WVOFF      = 5.8681477e-008      
+PVOFF      = -2.0291691e-014     NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.05981412          
+LU0        = -5.3788956e-09      
+WU0        = -6.0481528e-09      
+PU0        = 3.0025707e-15       
+UA         = -7.2924817e-012     
+LUA        = -4.6081033e-019     WUA        = 1.630631e-018       PUA        = -6.2073108e-025     
+UB         = 3.3799592e-018      LUB        = -1.7863776e-025     WUB        = -2.0530602e-025     
+PUB        = 9.5093905e-032     
+UC         = -2.0850659e-10      
+LUC        = 5.2002276e-17       
+WUC        = 1.142306e-17        
+PUC        = 1.070741e-24        
+VSAT       = '289316+dvsatn_na'    
+A0         = 25.046353           
+LA0        = -1.1621166e-05      
+WA0        = -1.1439042e-05      
+PA0        = 5.410919e-12        
+AGS        = 5.365513            
+LAGS       = -1.6087171e-06      
+WAGS       = -1.750066e-06       
+PAGS       = 8.365331e-13        
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.038709988         
+LKETA      = -2.5489243e-08      
+WKETA      = -6.7700945e-08      
+PKETA      = 2.3421536e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 3.5357505           
+Ppclm    = 7.4877045e-13 
+Wpclm    = -1.5664655e-06 
+Lpclm    = -7.3408868e-07 
+PDIBLC1    = 0                  
+PDIBLC2    = -0.01307004         
+LPDIBLC2   = 5.6744528e-09       
+WPDIBLC2   = 3.395489e-08        
+PPDIBLC2   = -1.0541198e-14      
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.45617604          
+Ppdits   = 7.4877045e-14 
+Wpdits   = -2.6272655e-07 
+Lpdits   = -1.1576014e-07 
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.0024810079       LTVOFF     = 1.471651e-009       WTVOFF     = 6.0114547e-009      
+PTVOFF     = -1.1590974e-015    
+KT1        = -0.62425846         
+LKT1       = 7.4942016e-08       
+WKT1       = 1.2620882e-07       
+PKT1       = -2.0067065e-14      
+KT1L       = 0                   
+KT2        = 0.056643439         
+LKT2       = -3.038619e-08       
+WKT2       = -5.4386579e-08      
+PKT2       = 1.7199249e-14       
+UTE        = -2.0620486          
+LUTE       = 3.4485242e-07       
+WUTE       = 1.6920585e-07       
+PUTE       = -4.792134e-14       
+UA1        = 5.3123939e-009      
+LUA1       = 1.3786194e-016      WUA1       = -2.6657992e-015     PUA1       = 5.5933186e-023      
+UB1        = -9.7631652e-018     LUB1       = 4.4062288e-025      WUB1       = 5.0768459e-024      
+PUB1       = -2.291239e-031     
+UC1        = -1.1999426e-10      
+LUC1       = 5.5093456e-17       
+WUC1       = 4.2397207e-16       
+PUC1       = -1.0205747e-22      
+PRT        = 0                   
+AT         = 144229.87           LAT        = -0.043385514        WAT        = -0.079159534        
+PAT        = 2.2560467e-008     
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'     
+LVSAT      = '-0.057033044+dlvsatn_na' 
+WVSAT      = '-0.031329311+dwvsatn_na' 
+PVSAT      = '1.4975409e-08+dpvsatn_na' )


.MODEL nch_na.13 NMOS	(	LEVEL      = 54                  LMIN       = 2e-07               
+LMAX       = '2.995932e-007-dxln_na' 
+WMIN       = 5e-07               WMAX       = '1.01e-006'    VERSION    = 4.5                 
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2                   
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2                   
+IGCMOD     = 1                   IGBMOD     = 1                   DIOMOD     = 1                   
+RDSMOD     = 1                   RBODYMOD   = 0                  
+RGATEMOD   = '1*rgflag_na'       
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0                   
+TEMPMOD    = 0                   WPEMOD     = 1                   TNOM       = 25                  
+TOXE       = 'toxn_na'           TOXM       = 2.6e-009            DTOX       = 2.05e-010           
+EPSROX     = 3.9                 WINT       = 0                   LINT       = -5.415000E-09       
+LL         = 2.2652000E-05       WL         = 0                   LLN        = -0.5009             
+WLN        = 1                   LW         = 0                   WW         = 0                   
+LWN        = 1                   WWN        = 1                   LWL        = 0                   
+WWL        = 0                   LLC        = 2.2652000E-05       WLC        = 0                   
+LWC        = 0                   WWC        = 0                   LWLC       = 0                   
+WWLC       = 0                   XL         = '-1.00E-09+dxln_na' XW         = '2e-08+dxwn_na'     
+DLC        = '-5.415000E-09+ddlcn_na' 
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009              
+DLCIG      = 2.5e-009           
+VTH0       = '-0.14018532+dvthn_na'  
+LVTH0      = '-1.0736146e-08+dlvthn_na' 
+WVTH0      = '-2.5725481e-08+dwvthn_na' 
+PVTH0      = '3.220104e-15+dpvthn_na'   
+K1         = 0.07               
+K2         = '-0.03257056+dk2n_na'   
+LK2        = '3.9040877e-09+dlk2n_na'  
+WK2        = '1.5265834e-08+dwk2n_na'  
+PK2        = '-3.277497e-15+dpk2n_na'  
+K3         = 5.2342166           K3B        = -1.46875            W0         = 0                   
+DVT0       = 1.2e-006            DVT1       = 0.1                 DVT2       = 0.16                
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0                   
+DSUB       = 0.1693              MINV       = -0.45422941         VOFFL      = 0                   
+DVTP0      = 0.0001              DVTP1      = 2.22e-015           LPE0       = 1.114e-006          
+LPEB       = 6.974e-008          WEB        = 0                   WEC        = 0                   
+SCREF      = 1e-006              KVTH0WE    = 0                   LKVTH0WE   = 0                   
+WKVTH0WE   = 0                   PKVTH0WE   = 0                   K2WE       = 0                   
+LK2WE      = 0                   WK2WE      = 0                   PK2WE      = 0                   
+XJ         = 8.6e-008            NGATE      = 1e+023              NDEP       = 6.5e+017            
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0                   
+CDSCB      = 0                   CDSCD      = 0                   CIT        = -0.00085172         
+LCIT       = 4.566156e-010       WCIT       = 3.0688944e-009      PCIT       = -5.1516691e-016     
+VOFF       = -0.068713742        
+LVOFF      = -1.6420061e-08      
+WVOFF      = -4.5987983e-08      
+PVOFF      = 9.5391021e-15       
+NFACTOR    = 1                   ETA0       = '0.0938572+deta0n_na' 
+WETA0      = '5.378256e-009+dweta0n_na' 
+ETAB       = 0.0535228           WETAB      = -2.0494656e-008     UD         = 0                   
+LUD        = 0                   WUD        = 0                   PUD        = 0                   
+KU0WE      = 0                   LKU0WE     = 0                   WKU0WE     = 0                   
+PKU0WE     = 0                  
+U0         = 0.035277235         
+LU0        = 1.6141152e-09       
+WU0        = 1.232442e-08        
+PU0        = -2.2336115e-15      
+UA         = -3.1681784e-010     
+LUA        = 8.7753917e-017      WUA        = 1.3959704e-016      PUA        = -3.9941157e-023     
+UB         = 2.87556e-018        LUB        = -3.4884e-026        WUB        = 6.47088e-026        
+PUB        = 1.813968e-032      
+UC         = -8.186544e-11       
+LUC        = 1.5909557e-17       
+WUC        = 5.097627e-17        
+PUC        = -1.0201927e-23      
+VSAT       = '111866.01+dvsatn_na' 
+LVSAT      = '-0.006459814+dlvsatn_na' 
+WVSAT      = '0.030196514+dwvsatn_na'  
+PVSAT      = '-2.5594431e-09+dpvsatn_na' 
+A0         = -27.195624          
+LA0        = 3.267799e-06        
+WA0        = 2.2646677e-05       
+PA0        = -4.3035117e-12      
+AGS        = -0.063126           
+LAGS       = -6.15469e-08        
+WAGS       = 1.5083e-06          
+PAGS       = -9.2107e-14         
+A1         = 0                   
+A2         = 1                   B0         = 0                   B1         = 0                   
+KETA       = 0.06139791          
+LKETA      = -3.1955324e-08      
+WKETA      = -3.317461e-08       
+PKETA      = 1.3581555e-14       
+DWG        = 0                   DWB        = 0                   
+PCLM       = 1.5052841           
+LPCLM      = -1.5540615e-07      
+WPCLM      = 2.5539941e-06       
+PPCLM      = -4.2556016e-13      
+PDIBLC1    = 0                  
+PDIBLC2    = 0.017114269         
+LPDIBLC2   = -2.928076e-09       
+WPDIBLC2   = -7.6776225e-09      
+PPDIBLC2   = 1.3240692e-15       
+PDIBLCB    = 0.22000011          DROUT      = 0.56                PVAG       = 1.5                 
+DELTA      = 0.05                PSCBE1     = 9.264e+008          PSCBE2     = 1e-020              
+FPROUT     = 600                
+PDITS      = 0.05                
+PDITSD     = 0                   
+PDITSL     = 0                   RSH        = 15.52                RSW        = 16.58               
+RDW        = 16.58               PRWG       = 0                   PRWB       = 0                   
+WR         = 1                   ALPHA0     = 1.2e-008            ALPHA1     = 0.01                
+BETA0      = 11                  AIGBACC    = 0.01302             BIGBACC    = 0.005269            
+CIGBACC    = 0.19351             NIGBACC    = 20.288              AIGBINV    = 0.35                
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1                 
+NIGBINV    = 1                  
+AIGC       = 0.01217             
+LAIGC      = 0                   
+WAIGC      = 0                   
+PAIGC      = 0                   
+BIGC       = 0.001832            
+CIGC       = 0.038084           
+AIGSD      = 0.01016             
+LAIGSD     = 0                   
+WAIGSD     = 0                   
+PAIGSD     = 0                   
+BIGSD      = 1e-005              
+CIGSD      = 7.8125e-005         NIGC       = 0.1                 POXEDGE    = 1                   
+PIGCD      = 4.227               NTOX       = 'ntoxn_na'          XRCRG1     = 12                  
+XRCRG2     = 1                   CGSO       = 'cgon_na'           CGDO       = 'cgon_na'           
+CGBO       = 0                   CGDL       = 'cgln_na'           CGSL       = 'cgln_na'           
+CLC        = 1e-007              CLE        = 0.6                 CF         = 'cfn_na'            
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.41                
+MOIN       = 10.5                NOFF       = 2.9                 VOFFCV     = -0.125              
+TVOFF      = -0.00651548         LTVOFF     = 2.6214756e-009      WTVOFF     = 8.0482896e-009      
+PTVOFF     = -1.7395953e-015    
+KT1        = -0.79589667         
+LKT1       = 1.2385889e-07       
+WKT1       = 3.3264227e-07       
+PKT1       = -7.8900579e-14      
+KT1L       = 0                   
+KT2        = -0.04538432         
+LKT2       = -1.3083e-09         
+WKT2       = 1.117282e-08        
+PKT2       = -1.485166e-15      
+UTE        = -1.2634695          
+LUTE       = 1.1725738e-07       
+WUTE       = 2.1500415e-07       
+PUTE       = -6.0973837e-14      
+UA1        = 1.207196e-008       
+LUA1       = -1.7886144e-015     WUA1       = -7.5040992e-015     PUA1       = 1.4348487e-021      
+UB1        = -1.790136e-017      LUB1       = 2.7600084e-024      WUB1       = 1.2288307e-023      
+PUB1       = -2.2843904e-030    
+UC1        = -1.7613512e-10      
+LUC1       = 7.1093577e-17       
+WUC1       = 9.175608e-17        
+PUC1       = -7.375925e-24       
+PRT        = 0                   
+AT         = -65995.12           LAT        = 0.016528609         WAT        = 0.025594982         
+PAT        = -7.29457e-009      
+FNOIMOD    = 1
+TNOIMOD    = 1
+NOIA       = 'noian_na'
+NOIB       = 'noibn_na'
+NOIC       = 'noicn_na'
+EM         = 1.12000e+06
+EF         = 1.00
+JSS        = 5.11E-6             
+JSD        = 5.11E-6             JSWS       = 5.46E-12            JSWD       = 5.46E-12            
+JSWGS      = 5.46E-12            NJS        = 1                   NJD        = 1                   
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01                
+IJTHDREV   = 0.01                BVS        = 19                BVD        = 19                
+XJBVS      = 1                   XJBVD      = 1                   JSWGD      = 5.46E-12            
+PBS        = 0.25                PBD        = 0.25                CJS        = 'cjn_na'            
+CJD        = 'cjn_na'            MJS        = 0.24                MJD        = 0.24                
+PBSWS      = 1                   PBSWD      = 1                   CJSWS      = 'cjswn_na'          
+CJSWD      = 'cjswn_na'          MJSWS      = 0.01                MJSWD      = 0.01                
+PBSWGS     = 0.6                 PBSWGD     = 0.6                 CJSWGS     = 'cjswgn_na'         
+CJSWGD     = 'cjswgn_na'         MJSWGS     = 0.5                 MJSWGD     = 0.5                 
+TPB        = 1.0e-3              TCJ        = 1.68e-3             TPBSW      = 1E-03               
+TCJSW      = 1E-04               TPBSWG     = 5.00E-04            TCJSWG     = 1.50E-03            
+XTIS       = 3                   XTID       = 3                  
+DMCG       = 6.7e-8              
+DMCI       = 7.2e-8              
+DMDG       = 0                   DMCGT      = 0                   
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-008          
+RSHG       = 15.06                  GBMIN      = 1e-012              RBPB       = 50                  
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50                  
+RBSB       = 50                 
+SAREF      = 4.05e-007           
+SBREF      = 4.05e-007           
+WLOD       = 5e-8                
+KVTH0      = 3.5e-009            
+LKVTH0     = -1e-10              
+WKVTH0     = 6e-007              
+PKVTH0     = 8.0e-014            
+LLODVTH    = 1                   
+WLODVTH    = 1                   
+STK2       = 0.6e-010            
+LODK2      = 1                   
+LODETA0    = 1                   
+KU0        = -2.8e-008           
+PKU0     = -1e-14 
+LKU0       = 1.57e-007           
+WKU0       = 3.5e-7             
+LLODKU0    = 1                   
+WLODKU0    = 1                   
+KVSAT      = 0.5                 
+STETA0     = 2.5e-09             
+TKU0       = 0                   
+LETA0      = '0+dleta0n_na'      PETA0      = '0+dpeta0n_na'      )

.ENDL MOS_na

 

***************************************************************
*                                                             *
*                     Native 2.5V IO DEVICE MODELS            *
*                                                             *
***************************************************************
.LIB MOS_na25
**********************************************************************************************
*                                                                                            *
*                               2.5V NATIVE NMOS DEVICE MODELS                               *
*                                                                                            *
**********************************************************************************************

.MODEL nch_na25.1 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25'
+LMAX       = 900.00001e-06       WMIN       = '1e-005-dxwn_na25'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25'
+K1         = 0.083826            K2         = -0.00094810982      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000703125+dcitn_na25'
+VOFF       = -0.12480063         NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021196+deta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062834873+du0n_na25'
+UA         = 1.2235048e-009      UB         = 2.4999846e-018      UC         = -4.7661329e-011
+VSAT       = '78400+dvsatn_na25'   A0         = 3.5135779           AGS        = 1.0683639
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055602815        DWG        = 0
+DWB        = 0                   PCLM       = 0.01                PDIBLC1    = 0
+PDIBLC2    = 0.0001485           PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3e-018             UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'        WU0        = '0+dwu0n_na25'
+PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'
+PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'
+PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'      WETA0      = '0+dweta0n_na25'
+PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'
+PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25'
+LMAX       = '9.99999e-006-dxln_na25'
+WMIN       = '1e-005-dxwn_na25'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = -4.5976888e-005     LK2        = -8.986516e-009      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00087551455+dcitn_na25'
+LCIT       = '-1.717243e-009+dlcitn_na25'
+VOFF       = -0.12541317         LVOFF      = 6.1017084e-009      NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021196+deta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062126092+du0n_na25'
+LU0        = '7.0604626e-009+dlu0n_na25'
+UA         = 1.0246402e-009      LUA        = 1.9809716e-015      UB         = 2.7182203e-018
+LUB        = -2.1739356e-024     UC         = -1.5214257e-011     LUC        = -3.2321858e-016
+VSAT       = '78400+dvsatn_na25'   A0         = 4.1247439           LA0        = -6.0880748e-006
+AGS        = 0.58809352          LAGS       = 4.7841698e-006      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.049079469        LKETA      = -6.4981729e-008     DWG        = 0
+DWB        = 0                   PCLM       = -0.026664974        LPCLM      = 3.6523484e-007
+PDIBLC1    = 0                   PDIBLC2    = 0.00015511976       LPDIBLC2   = -6.5942131e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25'
+CGDO       = 'cgon_na25'           CGBO       = 0                   CGDL       = 'cgln_na25'
+CGSL       = 'cgln_na25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283             KT1        = -0.25050115         LKT1       = -8.1870746e-008
+KT1L       = 0                   KT2        = -0.015762253        LKT2       = -2.7200338e-008
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -3.0882242e-018
+LUB1       = 8.7883765e-025      UC1        = -1.5421529e-010     LUC1       = 6.9476141e-016
+PRT        = 0                   AT         = 183960.37           LAT        = -0.19162228
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       WU0        = '0+dwu0n_na25'
+PU0        = '0+dpu0n_na25'        WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      WETA0      = '0+dweta0n_na25'      PETA0      = '0+dpeta0n_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.3 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25'
+WMIN       = '1e-005-dxwn_na25'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = -0.00065388215      LK2        = -7.7941645e-009     K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0+dcitn_na25'
+VOFF       = -0.13332084         LVOFF      = 2.1611887e-008      NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021196+deta0n_na25'
+ETAB       = -0.0015372917       LETAB      = 5.1498547e-009      U0         = '0.062294657+du0n_na25'
+LU0        = '6.729838e-009+dlu0n_na25'
+UA         = 1.2107717e-009      LUA        = 1.6158914e-015      UB         = 2.478809e-018
+LUB        = -1.7043519e-024     UC         = -1.654901e-010      LUC        = -2.8466042e-017
+VSAT       = '78400+dvsatn_na25'   A0         = 2.1609292           LA0        = -2.2362292e-006
+AGS        = -8.613579           LAGS       = 2.2832422e-005      A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = '-0.080253643'
+Pketa    = '0'
+Wketa    = '0'
+LKETA      = '-3.8364353e-09'
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33322887          LPCLM      = -3.4066454e-007
+PDIBLC1    = 0                   PDIBLC2    = 0.0001458025        LPDIBLC2   = -4.7667175e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25'
+CGDO       = 'cgon_na25'           CGBO       = 0                   CGDL       = 'cgln_na25'
+CGSL       = 'cgln_na25'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283             KT1        = -0.2672704          LKT1       = -4.897936e-008
+KT1L       = 0                   KT2        = -0.02963            UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -2.64016e-018       UC1        = 4.3901206e-011
+LUC1       = 3.0617374e-016      PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+WU0        = '0+dwu0n_na25'        PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'
+WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'
+WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'
+WETA0      = '0+dweta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25'
+LMAX       = 900.00001e-06       WMIN       = '1.2e-006-dxwn_na25'  WMAX       = '1e-005-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25'
+K1         = 0.083826            K2         = -0.00082308439      WK2        = -1.2511295e-009
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00079956499+dcitn_na25'
+WCIT       = '-9.6507494e-010+dwcitn_na25'
+VOFF       = -0.12477695         WVOFF      = -2.3700525e-010     NFACTOR    = '0.8+dnfactorn_na25'
+ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062945581+du0n_na25'
+WU0        = '-1.1078502e-009+dwu0n_na25'
+UA         = 1.2235048e-009      UB         = 2.4999846e-018      UC         = -5.7780526e-011
+WUC        = 1.0126281e-016      VSAT       = '78400+dvsatn_na25'   A0         = 3.7916851
+WA0        = -2.783019e-006      AGS        = 1.0095994           WAGS       = 5.8805572e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.059213254        WKETA      = 3.6129664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = -0.0085221351
+WPCLM      = 1.8535101e-007      PDIBLC1    = 0                   PDIBLC2    = 0.00015035165
+WPDIBLC2   = -1.8529439e-011     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -2.9809198e-018     WUB1       = -1.9093557e-025
+UC1        = -8.447e-011         PRT        = 0                   AT         = 164723.91
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'
+PU0        = '0+dpu0n_na25'        LCIT       = '0+dlcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.5 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25'
+LMAX       = '9.99999e-006-dxln_na25'
+WMIN       = '1.2e-006-dxwn_na25'  WMAX       = '1e-005-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = 0.00014232922       LK2        = -9.6168808e-009     WK2        = -1.8843792e-009
+PK2        = 6.3080606e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00099559933+dcitn_na25'
+LCIT       = '-1.9527785e-009+dlcitn_na25'
+WCIT       = '-1.2016884e-009+dwcitn_na25'
+PCIT       = '2.3570036e-015+dpcitn_na25'
+VOFF       = -0.12535694         LVOFF      = 5.777557e-009       WVOFF      = -5.6264021e-010
+PVOFF      = 3.2437834e-015      NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062119625+du0n_na25'
+LU0        = '8.2276866e-009+dlu0n_na25'
+WU0        = '6.471586e-011+dwu0n_na25'
+PU0        = '-1.1680411e-014+dpu0n_na25'
+UA         = 1.0066817e-009      LUA        = 2.1598628e-015      WUA        = 1.7970992e-016
+PUA        = -1.7901642e-021     UB         = 2.7288894e-018      LUB        = -2.2802153e-024
+WUB        = -1.0676613e-025     PUB        = 1.0635412e-030      UC         = -2.2362049e-011
+LUC        = -3.5281798e-016     WUC        = 7.1527948e-017      PUC        = 2.9620114e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 4.4672822           LA0        = -6.7298994e-006
+WA0        = -3.427781e-006      PA0        = 6.4227384e-012      AGS        = 0.49648423
+LAGS       = 5.1113508e-006      WAGS       = 9.1673415e-007      PAGS       = -3.2741006e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.05319211         LKETA      = -5.9979091e-008
+WKETA      = 4.1155197e-008      PKETA      = -5.0061403e-014     DWG        = 0
+DWB        = 0                   PCLM       = -0.050216044        LPCLM      = 4.1533012e-007
+WPCLM      = 2.3567555e-007      PPCLM      = -5.0130345e-013     PDIBLC1    = 0
+PDIBLC2    = 0.00015787937       LPDIBLC2   = -7.4986694e-011     WPDIBLC2   = -2.7615395e-011
+PPDIBLC2   = 9.0508939e-017      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25050115
+LKT1       = -8.1870746e-008     KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008     UTE        = -1.48               UA1        = 1.67e-009
+UB1        = -3.064466e-018      LUB1       = 8.3223805e-025      WUB1       = -2.3774844e-025
+PUB1       = 4.6632217e-031      UC1        = -1.6378149e-010     LUC1       = 7.9005425e-016
+WUC1       = 9.5728966e-017      PUC1       = -9.5359548e-022     PRT        = 0
+AT         = 183960.37           LAT        = -0.19162228         JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'
+PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.6 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25'
+WMIN       = '1.2e-006-dxwn_na25'  WMAX       = '1e-005-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = -0.0002474582       LK2        = -8.8523478e-009     WK2        = -4.0670845e-009
+PK2        = 1.0589241e-014      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.13409419
+LVOFF      = 2.2914876e-008      WVOFF      = 7.7389381e-009      PVOFF      = -1.3039015e-014
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.021777966+deta0n_na25'
+WETA0      = '-5.823734e-009+dweta0n_na25'
+ETAB       = -0.0014451533       LETAB      = 4.9691335e-009      WETAB      = -9.2202907e-010
+PETAB      = 1.808477e-015       U0         = '0.062618082+du0n_na25'
+LU0        = '7.2500067e-009+dlu0n_na25'
+WU0        = '-3.2365228e-009+dwu0n_na25'
+PU0        = '-5.2053284e-015+dpu0n_na25'
+UA         = 1.2361917e-009      LUA        = 1.7096996e-015      WUA        = -2.5437827e-016
+PUA        = -9.3873932e-022     UB         = 2.4638385e-018      LUB        = -1.7603418e-024
+WUB        = 1.4980948e-025      PUB        = 5.6029122e-031      UC         = -1.9983058e-010
+LUC        = -4.7294195e-018     WUC        = 3.4364521e-016      PUC        = -2.3753239e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 2.2652791           LA0        = -2.4108685e-006
+WA0        = -1.0442288e-006     PA0        = 1.7476153e-012      AGS        = -9.9452213
+LAGS       = 2.5591817e-005      WAGS       = 1.3325745e-005      PAGS       = -2.7613259e-011
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0
+KETA       = '-0.083185601'
+LKETA      = '-1.1496065e-09'
+WKETA      = '2.9340101e-08'
+PKETA      = '-2.6887095e-14'
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33215077          LPCLM      = -3.3464797e-007
+WPCLM      = 1.0788531e-008      PPCLM      = -6.0207799e-014     PDIBLC1    = 0
+PDIBLC2    = 0.00012335961       LPDIBLC2   = -7.2792913e-012     WPDIBLC2   = 2.2458608e-010
+PPDIBLC2   = -4.0416155e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.2672704
+LKT1       = -4.897936e-008      KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = 6.1508484e-011      LUC1       = 3.4816825e-016      WUC1       = -1.7619603e-016
+PUC1       = -4.2023907e-022     PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.7 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25'
+LMAX       = 900.00001e-06       WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'
+DLC        = '0+ddlcn_na25'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25'
+K1         = 0.083826            K2         = 0.012003617         WK2        = -1.6732958e-008
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0+dcitn_na25'        VOFF       = -0.12783168         WVOFF      = 3.4500609e-009
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.06106174+du0n_na25'
+WU0        = '1.1659461e-009+dwu0n_na25'
+UA         = 1.2854346e-009      WUA        = -7.4749352e-017     UB         = 2.4999846e-018
+UC         = 2.6115752e-011      VSAT       = '78400+dvsatn_na25'   A0         = 1.4808087
+WA0        = 6.2088783e-009      AGS        = 1.6647716           WAGS       = -2.027371e-007
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.029279813        DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.000135            PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25871994
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3.13911e-018       UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25'
+CJD        = 'cjn_na25'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'
+CJSWD      = 'cjswn_na25'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'
+CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'
+PVTH0      = '0+dpvthn_na25'       LU0        = '0+dlu0n_na25'        PU0        = '0+dpu0n_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LETA0      = '0+dleta0n_na25'      PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'
+WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.8 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25'
+LMAX       = '9.99999e-006-dxln_na25'
+WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = 0.012933166         LK2        = -9.2596208e-009     WK2        = -1.7322919e-008
+PK2        = 5.8768479e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.12905814
+LVOFF      = 1.221718e-008       WVOFF      = 3.9046996e-009      PVOFF      = -4.528842e-015
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+ETAB       = 0.0010882964        U0         = '0.062004206+du0n_na25'
+LU0        = '-9.3882913e-009+dlu0n_na25'
+WU0        = '2.040266e-010+dwu0n_na25'
+PU0        = '9.5820743e-015+dpu0n_na25'
+UA         = 1.2896963e-009      LUA        = -4.2452701e-017     WUA        = -1.6188868e-016
+PUA        = 8.6803058e-022      UB         = 2.594245e-018       LUB        = -9.389669e-025
+WUB        = 5.5749704e-026      PUB        = -5.5534566e-031     UC         = 3.2781608e-011
+LUC        = -6.6401324e-017     WUC        = 4.9695541e-018      PUC        = -4.9503766e-023
+VSAT       = '78400+dvsatn_na25'   A0         = 1.5569963           LA0        = -7.5893653e-007
+WA0        = 8.4934061e-008      PA0        = -7.8421382e-013     AGS        = 1.5962099
+LAGS       = 6.8297174e-007      WAGS       = -4.1063467e-007     PAGS       = 2.0709529e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.01641015         LKETA      = -1.2819999e-007
+WKETA      = -3.2406274e-009     PKETA      = 3.2281218e-014      DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.000135            PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.25050115
+LKT1       = -8.1870746e-008     KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008     UTE        = -1.48               UA1        = 1.67e-009
+UB1        = -3.2614407e-018     LUB1       = 1.2185862e-024      UC1        = -8.447e-011
+PRT        = 0                   AT         = 183960.37           LAT        = -0.19162228
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25'            CJD        = 'cjn_na25'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'
+WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'       LCIT       = '0+dlcitn_na25'
+WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'       LNFACTOR   = '0+dlnfactorn_na25'
+WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'   LETA0      = '0+dleta0n_na25'
+PETA0      = '0+dpeta0n_na25'      LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'
+PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.MODEL nch_na25.9 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25'
+WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25' XW         = '7e-09+dxwn_na25'     DLC        = '0+ddlcn_na25'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009            VTH0       = '-0.03365+dvthn_na25' K1         = 0.083826
+K2         = 0.0070517436        LK2        = 2.2762599e-009      WK2        = -1.2877221e-008
+PK2        = -2.842989e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25'        VOFF       = -0.12106439
+LVOFF      = -3.4618388e-009     WVOFF      = -7.9880317e-009     PVOFF      = 1.879768e-014
+NFACTOR    = '0.8+dnfactorn_na25'  ETA0       = '0.028641812+deta0n_na25'
+LETA0      = '-2.0005323e-016+dleta0n_na25'
+WETA0      = '-1.4108396e-008+dweta0n_na25'
+PETA0      = '2.4146429e-022+dpeta0n_na25'
+ETAB       = -0.0045972791       LETAB      = 1.1151745e-008      WETAB      = 2.8825868e-009
+PETAB      = -5.6539345e-015     U0         = '0.061722716+du0n_na25'
+LU0        = '-8.8361755e-009+dlu0n_na25'
+WU0        = '-2.1558162e-009+dwu0n_na25'
+PU0        = '1.4210694e-014+dpu0n_na25'
+UA         = 1.6235236e-009      LUA        = -6.9722491e-016     WUA        = -7.2188788e-016
+PUA        = 1.9664186e-021      UB         = 1.8314711e-018      LUB        = 5.5714547e-025
+WUB        = 9.1307699e-025      PUB        = -2.236916e-030      UC         = 1.6131981e-010
+LUC        = -3.1851744e-016     WUC        = -9.2263315e-017     PUC        = 1.4120976e-022
+VSAT       = '78400+dvsatn_na25'   A0         = 1.8138372           LA0        = -1.2627068e-006
+WA0        = -4.9933847e-007     PA0        = 3.6178416e-013      AGS        = 1.253264
+LAGS       = 1.3556292e-006      WAGS       = -1.9082677e-007     PAGS       = 1.6398195e-012
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.080802003        LKETA      = -1.9011631e-009
+WKETA      = 2.6463098e-008      PKETA      = -2.5979966e-014     DWG        = 0
+DWB        = 0                   PCLM       = 0.53198689          LPCLM      = -7.5895904e-007
+WPCLM      = -2.3041366e-007     PPCLM      = 4.5193566e-013      PDIBLC1    = 0
+PDIBLC2    = 0.00030623536       LPDIBLC2   = -3.3586275e-010     WPDIBLC2   = 3.8550414e-012
+PPDIBLC2   = -7.5613168e-018     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25'           CGDO       = 'cgon_na25'           CGBO       = 0
+CGDL       = 'cgln_na25'           CGSL       = 'cgln_na25'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283             KT1        = -0.2672704
+LKT1       = -4.897936e-008      KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.48               UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = -8.447e-011         PRT        = 0                   AT         = 128258.51
+LAT        = -0.082368082        JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25'            CJD        = 'cjn_na25'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25'          CJSWD      = 'cjswn_na25'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25'         CJSWGD     = 'cjswgn_na25'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25'       WVTH0      = '0+dwvthn_na25'       PVTH0      = '0+dpvthn_na25'
+LCIT       = '0+dlcitn_na25'       WCIT       = '0+dwcitn_na25'       PCIT       = '0+dpcitn_na25'
+LNFACTOR   = '0+dlnfactorn_na25'   WNFACTOR   = '0+dwnfactorn_na25'   PNFACTOR   = '0+dpnfactorn_na25'
+LVSAT      = '0+dlvsatn_na25'      WVSAT      = '0+dwvsatn_na25'      PVSAT      = '0+dpvsatn_na25'
+FNOIMOD  = 1
+NOIA     = 'noian_na25'
+NOIB     = 'noibn_na25'
+NOIC     = 'noicn_na25'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 1
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0   ) 


.ENDL MOS_na25


*******************************************************************************
*                                                                             *
*                     Native 2.5V over-drive 3.3V IO DEVICE MODELS            *
*                                                                             *
*******************************************************************************
.LIB MOS_na25od33
**************************************************************************************************************
*                                                                                                            *
*                               2.5V over-drive 3.3V NATIVE NMOS DEVICE MODELS                               *
*                                                                                                            *
**************************************************************************************************************

.MODEL nch_na25od33.1 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25od33'
+LMAX       = 900.00001e-06       WMIN       = '1e-005-dxwn_na25od33'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25od33'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'
+DLC        = '0+ddlcn_na25od33'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009           
+VTH0       = '-0.10245+dvthn_na25od33' 
+K1         = 0.083826            K2         = -0.00094810982      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000703125+dcitn_na25od33'
+VOFF       = '-0.05480063+dvoffn_na25od33' 
+pvoff    = '0+dpvoffn_na25od33' 
+wvoff    = '0+dwvoffn_na25od33' 
+lvoff    = '0+dlvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.021196+deta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.050954873+du0n_na25od33' 
+UA         = 6.049048e-10       
+Pua      = 0 
+Wua      = 0 
+Lua      = 0 
+UB         = 2.5219846e-18       
+Pub      = 0 
+Wub      = 0 
+Lub      = 0 
+UC         = -4.7661329e-011
+VSAT       = '78400+dvsatn_na25od33'  
+A0         = 1.3135779           
+Pa0      = 0 
+Wa0      = 0 
+La0      = 0 
+AGS        = '2.1483639+dagsn_na25od33' 
+Pags     = 0 
+Wags     = '0+dwagsn_na25od33' 
+Lags     = 0 
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.055602815        DWG        = 0
+DWB        = 0                   PCLM       = 0.01                PDIBLC1    = 0
+PDIBLC2    = 0.0011485           
+PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.27271994 
+Pkt1     = 0 
+Wkt1     = 0 
+Lkt1     = 0 
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3e-018             UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25od33'
+CJD        = 'cjn_na25od33'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'
+CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'
+CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25od33'       
+WVTH0      = '0+dwvthn_na25od33' 
+PVTH0      = '0+dpvthn_na25od33'       
+LU0        = '0+dlu0n_na25od33'        
+WU0        = '0+dwu0n_na25od33' 
+PU0        = '0+dpu0n_na25od33'        
+LCIT       = '0+dlcitn_na25od33'       WCIT       = '0+dwcitn_na25od33'
+PCIT       = '0+dpcitn_na25od33'       LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'
+PNFACTOR   = '0+dpnfactorn_na25od33'   LETA0      = '0+dleta0n_na25od33'      WETA0      = '0+dweta0n_na25od33'
+PETA0      = '0+dpeta0n_na25od33'      LVSAT      = '0+dlvsatn_na25od33'      WVSAT      = '0+dwvsatn_na25od33'
+PVSAT      = '0+dpvsatn_na25od33'
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.2 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25od33'
+LMAX       = '9.99999e-006-dxln_na25od33'
+WMIN       = '1e-005-dxwn_na25od33'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.10171202+dvthn_na25od33'  
+K1         = 0.083826
+K2         = -4.5976888e-005     LK2        = -8.986516e-009      K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00087551455+dcitn_na25od33'
+LCIT       = '-1.717243e-009+dlcitn_na25od33'
+VOFF       = '-0.05541317+dvoffn_na25od33' 
+pvoff    = '0+dpvoffn_na25od33' 
+wvoff    = '0+dwvoffn_na25od33' 
+LVOFF      = '6.1017084e-09+dlvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33' 
+ETA0       = '0.021196+deta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.051030652+du0n_na25od33' 
+LU0        = '-7.54853e-10+dlu0n_na25od33'  
+UA         = 5.1671219e-10       
+Pua      = 0 
+Wua      = 0 
+LUA        = 8.785236e-16       
+UB         = 2.6587732e-18 
+Pub      = 0 
+Wub      = 0 
+LUB        = -1.3626081e-24      
+UC         = -4.8312882e-11      
+Puc      = 0 
+Wuc      = 0 
+LUC        = 6.49006e-18    
+VSAT       = '61237.75+dvsatn_na25od33' 
+A0         = 1.5079464           
+Pa0      = 0 
+Wa0      = 0 
+LA0        = -1.9361882e-06 
+AGS        = '2.1290225+dagsn_na25od33' 
+Pags     = 0 
+Wags     = '0+dwagsn_na25od33' 
+LAGS       = 1.926716e-07        
+A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.064062113        
+Pketa    = 0 
+Wketa    = 0 
+LKETA      = 8.4266381e-08       
+DWG        = 0
+DWB        = 0                   PCLM       = -0.026664974        LPCLM      = 3.6523484e-007
+PDIBLC1    = 0                  
+PDIBLC2    = 0.0011551198        
+LPDIBLC2   = -6.5942131e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25od33'
+CGDO       = 'cgon_na25od33'           CGBO       = 0                   CGDL       = 'cgln_na25od33'
+CGSL       = 'cgln_na25od33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25od33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283            
+KT1        = -0.26352045         
+Pkt1     = 0 
+Wkt1     = 0 
+LKT1       = -9.1639891e-08 
+KT1L       = 0                   KT2        = -0.015762253        LKT2       = -2.7200338e-008
+UTE        = -1.4947105          
+Pute     = 0 
+Wute     = 0 
+Lute     = 1.4653717e-07 
+UA1        = 1.67e-009           UB1        = -3.0882242e-018
+LUB1       = 8.7883765e-025     
+UC1        = -1.4195654e-10      
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = 5.726471e-16  
+PRT        = 0                  
+AT         = 161894.62           
+Pat      = 0 
+Wat      = 0 
+LAT        = 0.02818348 
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '-7.351282e-09+dlvthn_na25od33'  
+WVTH0      = '0+dwvthn_na25od33'       
+PVTH0      = '0+dpvthn_na25od33'       
+WU0        = '0+dwu0n_na25od33' 
+PU0        = '0+dpu0n_na25od33'        
+WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'
+LETA0      = '0+dleta0n_na25od33'      WETA0      = '0+dweta0n_na25od33'      PETA0      = '0+dpeta0n_na25od33'
+LVSAT      = '0.17096004+dlvsatn_na25od33' 
+WVSAT      = '0+dwvsatn_na25od33'      
+PVSAT      = '0+dpvsatn_na25od33' 
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.3 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25od33'
+WMIN       = '1e-005-dxwn_na25od33'    WMAX       = 900.00001e-06
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.14095895+dvthn_na25od33' 
+K1         = 0.083826
+K2         = -0.00065388215      LK2        = -7.7941645e-009     K3         = 2.6118349
+K3B        = -4.9758566          W0         = 0                   DVT0       = 0.064799587
+DVT1       = 0.02075738          DVT2       = 0.30031818          DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.03344
+MINV       = -0.5                VOFFL      = 0                   DVTP0      = 8.4008771e-009
+DVTP1      = 3.5                 LPE0       = 2.8116619e-009      LPEB       = 1.51e-010
+XJ         = 8.1e-008            NGATE      = 5.9092e+020         NDEP       = 5.11e+017
+NSD        = 1e+020              PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0+dcitn_na25od33'
+VOFF       = '-0.019767421+dvoffn_na25od33' 
+pvoff    = '0+dpvoffn_na25od33' 
+wvoff    = '0+dwvoffn_na25od33' 
+LVOFF      = '-6.381379e-08+dlvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33' 
+ETA0       = '0.021196+deta0n_na25od33'
+ETAB       = -0.0015372917       LETAB      = 5.1498547e-009     
+U0         = '0.050611824+du0n_na25od33' 
+LU0        = '6.6636e-11+dlu0n_na25od33'    
+UA         = 8.652102e-10        
+Pua      = 0 
+Wua      = 0 
+LUA        = 1.949776e-16        
+UB         = 2.23865e-18   
+Pub      = 0 
+Wub      = 0 
+LUB        = -5.385762e-25       
+UC         = -9.72963e-12        
+Puc      = 0 
+Wuc      = 0 
+LUC        = -6.918562e-17  
+VSAT       = '191953.42+dvsatn_na25od33' 
+A0         = 0.9350389           
+Pa0      = 0 
+Wa0      = 0 
+LA0        = -8.124679e-07  
+AGS        = '4.668694+dagsn_na25od33' 
+Pags     = 0 
+Wags     = '0+dwagsn_na25od33' 
+LAGS       = -4.788547e-06       
+A1         = 0
+A2         = 1                   B0         = 0                   B1         = 0
+KETA       = -0.033530783  
+Pketa    = 0  
+Wketa    = 0  
+LKETA      = 2.4382521e-08   
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33322887          LPCLM      = -3.4066454e-007
+PDIBLC1    = 0                  
+PDIBLC2    = 0.0011458025        
+LPDIBLC2   = -4.7667175e-011
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 1.5
+DELTA      = 0.0075              PSCBE1     = 9.264e+008          PSCBE2     = 1e-020
+FPROUT     = 600                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52                  RDSW       = 0
+RSW        = 173                 RDW        = 173                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 2.46634e-008
+ALPHA1     = 0.068220587         BETA0      = 18.128904           AGIDL      = 1e-008
+BGIDL      = 2.3e+009            CGIDL      = 0.5                 EGIDL      = 0.8
+XRCRG1     = 12                  XRCRG2     = 1                   CGSO       = 'cgon_na25od33'
+CGDO       = 'cgon_na25od33'           CGBO       = 0                   CGDL       = 'cgln_na25od33'
+CGSL       = 'cgln_na25od33'           CLC        = 1e-007              CLE        = 0.6
+CF         = 'cfn_na25od33'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 7.931               NOFF       = 2.5571
+VOFFCV     = -0.0283            
+KT1        = -0.27946328         
+Pkt1     = 0 
+Wkt1     = 0 
+LKT1       = -6.036945e-08 
+KT1L       = 0                   KT2        = -0.02963           
+UTE        = -1.3909644 
+Pute     = 0 
+Wute     = 0 
+Lute     = -5.695045e-08  
+UA1        = 1.67e-009           UB1        = -2.64016e-018      
+UC1        = 2.8425734e-10 
+Puc1     = 0 
+Wuc1     = 0 
+LUC1       = -2.6333077e-16      
+PRT        = 0                  
+AT         = 353274.11 
+Pat      = 0 
+Wat      = 0 
+LAT        = -0.34718768         
+JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '6.9627619e-08+dlvthn_na25od33' 
+WVTH0      = '0+dwvthn_na25od33'       
+PVTH0      = '0+dpvthn_na25od33' 
+WU0        = '0+dwu0n_na25od33'        
+PU0        = '0+dpu0n_na25od33'        
+LCIT       = '0+dlcitn_na25od33'
+WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'       LNFACTOR   = '0+dlnfactorn_na25od33'
+WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'   LETA0      = '0+dleta0n_na25od33'
+WETA0      = '0+dweta0n_na25od33'      PETA0      = '0+dpeta0n_na25od33'     
+LVSAT      = '-0.08542568+dlvsatn_na25od33' 
+WVSAT      = '0+dwvsatn_na25od33'      
+PVSAT      = '0+dpvsatn_na25od33' 
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.4 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25od33'
+LMAX       = 900.00001e-06       WMIN       = '1.2e-006-dxwn_na25od33'  WMAX       = '1e-005-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25od33'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'
+DLC        = '0+ddlcn_na25od33'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009           
+VTH0       = '-0.10393132+dvthn_na25od33'  
+K1         = 0.083826            K2         = -0.00082308439      WK2        = -1.2511295e-009
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00079956499+dcitn_na25od33'
+WCIT       = '-9.6507494e-010+dwcitn_na25od33'
+VOFF       = '-0.05477695+dvoffn_na25od33' 
+pvoff    = '0+dpvoffn_na25od33' 
+lvoff    = '0+dlvoffn_na25od33' 
+WVOFF      = '-2.3700525e-10+dwvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33' 
+ETA0       = '0.021777966+deta0n_na25od33'
+WETA0      = '-5.823734e-009+dweta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.049737881+du0n_na25od33' 
+WU0        = '1.2178444e-08+dwu0n_na25od33'  
+UA         = 4.7158619e-10      
+Pua      = 0 
+Wua      = 1.3341196e-15 
+Lua      = 0 
+UB         = 2.6141555e-18       
+Pub      = 0 
+Wub      = -9.2235432e-25 
+Lub      = 0 
+UC         = -5.7780526e-011
+WUC        = 1.0126281e-016      VSAT       = '78400+dvsatn_na25od33'  
+A0         = 1.2213555  
+Pa0      = 0 
+La0      = 0 
+WA0        = 9.228688e-07        
+AGS        = '2.2843654+dagsn_na25od33' 
+Pags     = 0 
+Lags     = 0 
+WAGS       = '-1.3609668e-06+dwagsn_na25od33' 
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.059213254        WKETA      = 3.6129664e-008
+DWG        = 0                   DWB        = 0                   PCLM       = -0.0085221351
+WPCLM      = 1.8535101e-007      PDIBLC1    = 0                  
+PDIBLC2    = 0.0011503517 
+WPDIBLC2   = -1.8529439e-011     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.27409153 
+Pkt1     = 0 
+Wkt1     = 1.372551e-08  
+Lkt1     = 0 
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -2.9809198e-018     WUB1       = -1.9093557e-025
+UC1        = -8.447e-011         PRT        = 0                   AT         = 164723.91
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25od33' 
+WVTH0      = '1.4823551e-08+dwvthn_na25od33'  
+PVTH0      = '0+dpvthn_na25od33'       
+LU0        = '0+dlu0n_na25od33' 
+PU0        = '0+dpu0n_na25od33'        
+LCIT       = '0+dlcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'
+LETA0      = '0+dleta0n_na25od33'      PETA0      = '0+dpeta0n_na25od33'      LVSAT      = '0+dlvsatn_na25od33'
+WVSAT      = '0+dwvsatn_na25od33'      PVSAT      = '0+dpvsatn_na25od33'
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.5 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25od33'
+LMAX       = '9.99999e-006-dxln_na25od33'
+WMIN       = '1.2e-006-dxwn_na25od33'  WMAX       = '1e-005-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.10332752+dvthn_na25od33'  
+K1         = 0.083826
+K2         = 0.00014232922       LK2        = -9.6168808e-009     WK2        = -1.8843792e-009
+PK2        = 6.3080606e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00099559933+dcitn_na25od33'
+LCIT       = '-1.9527785e-009+dlcitn_na25od33'
+WCIT       = '-1.2016884e-009+dwcitn_na25od33'
+PCIT       = '2.3570036e-015+dpcitn_na25od33'
+VOFF       = '-0.05535694+dvoffn_na25od33' 
+LVOFF      = '5.777557e-09+dlvoffn_na25od33' 
+WVOFF      = '-5.6264021e-10+dwvoffn_na25od33' 
+PVOFF      = '3.2437834e-15+dpvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.021777966+deta0n_na25od33'
+WETA0      = '-5.823734e-009+dweta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.049644731+du0n_na25od33' 
+LU0        = '9.279076e-10+dlu0n_na25od33'  
+WU0        = '1.3868908e-08+dwu0n_na25od33' 
+PU0        = '-1.683939e-14+dpu0n_na25od33'  
+UA         = 3.5700116e-10       
+LUA        = 1.1414282e-15       
+WUA        = 1.5982275e-15 
+PUA        = -2.6308865e-21     
+UB         = 2.7723002e-18       
+LUB        = -1.575345e-24  
+WUB        = -1.1360649e-24      
+PUB        = 2.1288584e-30       
+UC         = -6.0000451e-11 
+LUC        = 2.21132e-17         
+WUC        = 1.169575e-16        
+PUC        = -1.563408e-22 
+VSAT       = '61237.75+dvsatn_na25od33'  
+A0         = 1.3927225           
+LA0        = -1.7070602e-06 
+WA0        = 1.1530463e-06       
+PA0        = -2.2928836e-12      
+AGS        = '2.2748867+dagsn_na25od33' 
+LAGS       = 9.44261e-08         
+WAGS       = '-1.4596627e-06+dwagsn_na25od33' 
+PAGS       = 9.83146e-13    
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                  
+KETA       = -0.068580643        
+LKETA      = 9.3312255e-08  
+WKETA      = 4.5216936e-08       
+PKETA      = -9.0522e-14         
+DWG        = 0
+DWB        = 0                   PCLM       = -0.050216044        LPCLM      = 4.1533012e-007
+WPCLM      = 2.3567555e-007      PPCLM      = -5.0130345e-013     PDIBLC1    = 0
+PDIBLC2    = 0.0011578794        
+LPDIBLC2   = -7.4986694e-011     WPDIBLC2   = -2.7615395e-011
+PPDIBLC2   = 9.0508939e-017      PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.26489204 
+Pkt1     = 0              
+Wkt1     = 1.3725511e-08 
+LKT1       = -9.1639891e-08      
+KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008    
+UTE        = -1.4947105          
+Pute     = 0              
+Wute     = 0             
+Lute     = 1.4653717e-07 
+UA1        = 1.67e-009
+UB1        = -3.064466e-018      LUB1       = 8.3223805e-025      WUB1       = -2.3774844e-025
+PUB1       = 4.6632217e-031     
+UC1        = -1.4950506e-10      
+LUC1       = 6.4784103e-16 
+WUC1       = 7.5538054e-17       
+PUC1       = -7.5246574e-22      
+PRT        = 0
+AT         = 161894.62           
+Pat      = 0              
+Wat      = 0           
+LAT        = 0.028183482         
+JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25od33'
+CJD        = 'cjn_na25od33'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'
+CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'
+CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '-6.0147047e-09+dlvthn_na25od33' 
+WVTH0      = '1.6166246e-08+dwvthn_na25od33'  
+PVTH0      = '-1.3375128e-14+dpvthn_na25od33' 
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'
+PNFACTOR   = '0+dpnfactorn_na25od33'   LETA0      = '0+dleta0n_na25od33'      PETA0      = '0+dpeta0n_na25od33'
+LVSAT      = '0.17096004+dlvsatn_na25od33' 
+WVSAT      = '0+dwvsatn_na25od33'           
+PVSAT      = '0+dpvsatn_na25od33'              
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.6 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25od33'
+WMIN       = '1.2e-006-dxwn_na25od33'  WMAX       = '1e-005-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.14098737+dvthn_na25od33' 
+K1         = 0.083826
+K2         = -0.0002474582       LK2        = -8.8523478e-009     WK2        = -4.0670845e-009
+PK2        = 1.0589241e-014      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25od33'       
+VOFF       = '-0.02054077+dvoffn_na25od33'  
+LVOFF      = '-6.2510801e-08+dlvoffn_na25od33' 
+WVOFF      = '7.738938e-09+dwvoffn_na25od33'   
+PVOFF      = '-1.303901e-14+dpvoffn_na25od33'  
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.022176216+deta0n_na25od33' 
+WETA0      = '-9.80902e-09+dweta0n_na25od33'  
+ETAB       = -0.0014451533       LETAB      = 4.9691335e-009      WETAB      = -9.2202907e-010
+PETAB      = 1.808477e-015      
+U0         = '0.051447279+du0n_na25od33' 
+LU0        = '-2.6076149e-09+dlu0n_na25od33' 
+WU0        = '-8.3604133e-09+dwu0n_na25od33' 
+PU0        = '2.6761229e-14+dpu0n_na25od33'  
+UA         = 9.6052916e-10       
+LUA        = -4.233399e-17       
+WUA        = -9.538573e-16  
+PUA        = 2.3747768e-21       
+UB         = 2.1907395e-18       
+LUB        = -4.346693e-25  
+WUB        = 4.7944e-25          
+PUB        = -1.0397954e-30      
+UC         = -2.270615e-11  
+LUC        = -5.103405e-17       
+WUC        = 1.2985603e-16       
+PUC        = -1.816427e-22  
+VSAT       = '192949.05+dvsatn_na25od33' 
+A0         = 0.99182166          
+LA0        = -9.2071139e-07 
+WA0        = -5.6822439e-07      
+PA0        = 1.0831924e-12       
+AGS        = '4.9008425+dagsn_na25od33' 
+LAGS       = -5.0560199e-06      
+WAGS       = '-2.3231216e-06+dwagsn_na25od33' 
+PAGS       = 2.6766085e-12  
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0
+KETA       = -0.040406636  
+LKETA      = 3.8051982e-08   
+WKETA      = 6.880653e-08   
+PKETA      = -1.3679046e-13  
+DWG        = 0
+DWB        = 0                   PCLM       = 0.33215077          LPCLM      = -3.3464797e-007
+WPCLM      = 1.0788531e-008      PPCLM      = -6.0207799e-014     PDIBLC1    = 0
+PDIBLC2    = 0.0011233596        
+LPDIBLC2   = -7.2792913e-012     WPDIBLC2   = 2.2458608e-010
+PPDIBLC2   = -4.0416155e-016     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.27844537 
+Pkt1     = 4.690044e-14  
+Wkt1     = -1.0186205e-08 
+LKT1       = -6.5056214e-08      
+KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.3909643          
+Pute     = 0             
+Wute     = 0              
+Lute     = -5.6950444e-08 
+UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = 3.314688e-10        
+LUC1       = -2.9554335e-16      
+WUC1       = -4.7244514e-16 
+PUC1       = 3.2235123e-22       
+PRT        = 0                  
+AT         = 352676.74 
+Pat      = -1.172511e-08 
+Wat      = 0.005977929  
+LAT        = -0.34601599         
+JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '6.7851343e-08+dlvthn_na25od33' 
+WVTH0      = '2.84532e-10+dwvthn_na25od33'   
+PVTH0      = '1.7775267e-14+dpvthn_na25od33'  
+LCIT       = '0+dlcitn_na25od33'       WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'
+LETA0      = '-7.8112721e-10+dleta0n_na25od33' 
+PETA0      = '7.81674e-15+dpeta0n_na25od33' 
+LVSAT      = '-0.08737849+dlvsatn_na25od33'  
+WVSAT      = '-0.009963216+dwvsatn_na25od33' 
+PVSAT      = '1.954185e-08+dpvsatn_na25od33'  
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.7 NMOS	(	LEVEL      = 54                  LMIN       = '9.99999e-006-dxln_na25od33'
+LMAX       = 900.00001e-06       WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0
+TRNQSMOD   = 0                   TEMPMOD    = 0                   TNOM       = 25
+TOXE       = 'toxn_na25od33'           TOXM       = 5.6e-009            DTOX       = 2.5232e-010
+EPSROX     = 3.9                 WINT       = 0                   LINT       = 0
+LL         = 0                   WL         = 0                   LLN        = 1
+WLN        = 1                   LW         = 0                   WW         = 0
+LWN        = 1                   WWN        = 1                   LWL        = 0
+WWL        = 0                   LLC        = 0                   WLC        = 0
+LWC        = 0                   WWC        = 0                   LWLC       = 0
+WWLC       = 0                   XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'
+DLC        = '0+ddlcn_na25od33'        DWC        = 0                   XPART      = 1
+TOXREF     = 3e-009              DLCIG      = 2.5e-009           
+VTH0       = '-0.086942143+dvthn_na25od33' 
+K1         = 0.083826            K2         = 0.012003617         WK2        = -1.6732958e-008
+K3         = 2.6118349           K3B        = -4.9758566          W0         = 0
+DVT0       = 0.064799587         DVT1       = 0.02075738          DVT2       = 0.30031818
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.03344             MINV       = -0.5                VOFFL      = 0
+DVTP0      = 8.4008771e-009      DVTP1      = 3.5                 LPE0       = 2.8116619e-009
+LPEB       = 1.51e-010           XJ         = 8.1e-008            NGATE      = 5.9092e+020
+NDEP       = 5.11e+017           NSD        = 1e+020              PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0+dcitn_na25od33'       
+VOFF       = '-0.05783168+dvoffn_na25od33' 
+pvoff    = '0+dpvoffn_na25od33' 
+lvoff    = '0+dlvoffn_na25od33' 
+WVOFF      = '3.4500609e-09+dwvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.028641812+deta0n_na25od33'
+WETA0      = '-1.4108396e-008+dweta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.05886174+du0n_na25od33' 
+WU0        = '1.1659461e-009+dwu0n_na25od33'
+UA         = 1.5848029e-09       
+Pua      = 0 
+Lua      = 0 
+WUA        = -9.53307e-18        
+UB         = 1.9948418e-18 
+Pub      = 0 
+Wub      = -1.7484257e-25 
+Lub      = 0 
+UC         = 2.6115752e-011      VSAT       = '78400+dvsatn_na25od33'  
+A0         = 2.1980945 
+Pa0      = 0 
+La0      = 0 
+WA0        = -2.5605498e-07      
+AGS        = '1.2161288+dagsn_na25od33' 
+Pags     = 0 
+Lags     = 0 
+WAGS       = '-7.1605173e-08+dwagsn_na25od33' 
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                   KETA       = -0.029279813        DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.001135            
+PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.26344422 
+Pkt1     = 0 
+Wkt1     = 8.742128e-10  
+Lkt1     = 0 
+KT1L       = 0                   KT2        = -0.018492824        UTE        = -1.48
+UA1        = 1.67e-009           UB1        = -3.13911e-018       UC1        = -8.447e-011
+PRT        = 0                   AT         = 164723.91           JSS        = 8.43E-07
+JSD        = 8.43E-07            JSWS       = 1.36E-12            JSWD       = 1.36E-12
+JSWGS      = 1.36E-12            JSWGD      = 1.36E-12            NJS        = 1
+NJD        = 1                   IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 10
+BVD        = 10                  XJBVS      = 1                   XJBVD      = 1
+PBS        = 1                   PBD        = 1                   CJS        = 'cjn_na25od33'
+CJD        = 'cjn_na25od33'            MJS        = 0.53                MJD        = 0.53
+PBSWS      = 0.5                 PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'
+CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011               MJSWD      = 0.011
+PBSWGS     = 0.8                 PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'
+CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52                MJSWGD     = 0.52
+TPB        = 2.8E-03             TCJ        = 2.1E-03             TPBSW      = 1.0E-04
+TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.135e-007
+DMCI       = 3.05e-007           DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '0+dlvthn_na25od33'       
+WVTH0      = '-5.6823836e-09+dwvthn_na25od33' 
+PVTH0      = '0+dpvthn_na25od33'       
+LU0        = '0+dlu0n_na25od33'        PU0        = '0+dpu0n_na25od33'
+LCIT       = '0+dlcitn_na25od33'       WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'
+LETA0      = '0+dleta0n_na25od33'      PETA0      = '0+dpeta0n_na25od33'      LVSAT      = '0+dlvsatn_na25od33'
+WVSAT      = '0+dwvsatn_na25od33'      PVSAT      = '0+dpvsatn_na25od33'
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.8 NMOS	(	LEVEL      = 54                  LMIN       = '1.99999e-006-dxln_na25od33'
+LMAX       = '9.99999e-006-dxln_na25od33'
+WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.084249246+dvthn_na25od33' 
+K1         = 0.083826
+K2         = 0.012933166         LK2        = -9.2596208e-009     WK2        = -1.7322919e-008
+PK2        = 5.8768479e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25od33'       
+VOFF       = '-0.05905814+dvoffn_na25od33' 
+LVOFF      = '1.221718e-08+dlvoffn_na25od33' 
+WVOFF      = '3.9046996e-09+dwvoffn_na25od33' 
+PVOFF      = '-4.528842e-15+dpvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.028641812+deta0n_na25od33'
+WETA0      = '-1.4108396e-008+dweta0n_na25od33'
+ETAB       = 0.0010882964       
+U0         = '0.060883518+du0n_na25od33' 
+LU0        = '-2.0139741e-08+dlu0n_na25od33' 
+WU0        = '3.036925e-10+dwu0n_na25od33'  
+PU0        = '8.589263e-15+dpu0n_na25od33'  
+UA         = 1.7290495e-09       
+LUA        = -1.436899e-15       
+WUA        = -5.7834878e-17 
+PUA        = 4.8115446e-22       
+UB         = 1.9918902e-18       
+LUB        = 2.939954e-26  
+WUB        = -1.9411017e-25      
+PUB        = 1.9193161e-31       
+UC         = 3.2781608e-011
+LUC        = -6.6401324e-017     WUC        = 4.9695541e-018      PUC        = -4.9503766e-023
+VSAT       = '61237.749+dvsatn_na25od33' 
+A0         = 2.6121401           
+LA0        = -4.1244767e-06 
+WA0        = -3.1879099e-07      
+PA0        = 6.2493767e-13       
+AGS        = '1.0751528+dagsn_na25od33' 
+LAGS       = 1.4043185e-06       
+WAGS       = '-1.1583817e-08+dwagsn_na25od33' 
+PAGS       = -5.978947e-13  
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                  
+KETA       = -0.033878035        
+LKETA      = 4.5804604e-08  
+WKETA      = 3.3308879e-09       
+PKETA      = -3.3180275e-14      
+DWG        = 0
+DWB        = 0                   PCLM       = 0.14504125          PDIBLC1    = 0
+PDIBLC2    = 0.001135            
+PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.25442231 
+Pkt1     = -2.135078e-15  
+Wkt1     = 1.088548e-09  
+LKT1       = -8.9870976e-08      
+KT1L       = 0                   KT2        = -0.015762253
+LKT2       = -2.7200338e-008    
+UTE        = -1.4947105          
+Pute     = 0              
+Wute     = 0             
+Lute     = 1.4653718e-07 
+UA1        = 1.67e-009
+UB1        = -3.2614407e-018     LUB1       = 1.2185862e-024     
+UC1        = -8.8697518e-11 
+Puc1     = -2.135078e-23 
+Wuc1     = 2.1433514e-18 
+Luc1     = 4.2111993e-17 
+PRT        = 0                  
+AT         = 161894.62           
+Pat      = 0              
+Wat      = 0           
+LAT        = 0.02818349 
+JSS        = 8.43E-07            JSD        = 8.43E-07            JSWS       = 1.36E-12
+JSWD       = 1.36E-12            JSWGS      = 1.36E-12            JSWGD      = 1.36E-12
+NJS        = 1                   NJD        = 1                   IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 10                  BVD        = 10                  XJBVS      = 1
+XJBVD      = 1                   PBS        = 1                   PBD        = 1
+CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'            MJS        = 0.53
+MJD        = 0.53                PBSWS      = 0.5                 PBSWD      = 0.5
+CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'          MJSWS      = 0.011
+MJSWD      = 0.011               PBSWGS     = 0.8                 PBSWGD     = 0.8
+CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'         MJSWGS     = 0.52
+MJSWGD     = 0.52                TPB        = 2.8E-03             TCJ        = 2.1E-03
+TPBSW      = 1.0E-04             TCJSW      = 3.6E-04             TPBSWG     = 3.0E-03
+TCJSWG     = 3.0E-03             XTIS       = 3                   XTID       = 3
+DMCG       = 1.135e-007          DMCI       = 3.05e-007           DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '-2.6825026e-08+dlvthn_na25od33' 
+WVTH0      = '-6.8612269e-09+dwvthn_na25od33' 
+PVTH0      = '1.1742929e-14+dpvthn_na25od33' 
+LCIT       = '0+dlcitn_na25od33'
+WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'       LNFACTOR   = '0+dlnfactorn_na25od33'
+WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'   LETA0      = '0+dleta0n_na25od33'
+PETA0      = '0+dpeta0n_na25od33'     
+LVSAT      = '0.17096004+dlvsatn_na25od33' 
+WVSAT      = '0+dwvsatn_na25od33'          
+PVSAT      = '0+dpvsatn_na25od33'              
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.MODEL nch_na25od33.9 NMOS	(	LEVEL      = 54                  LMIN       = 1.2e-06
+LMAX       = '1.99999e-006-dxln_na25od33'
+WMIN       = 5e-07               WMAX       = '1.2e-006-dxwn_na25od33'
+VERSION    = 4.5
+RGEOMOD    = 1                   NGCON      = 1                   BINUNIT    = 2
+PARAMCHK   = 1                   MOBMOD     = 0                   CAPMOD     = 2
+IGCMOD     = 0                   IGBMOD     = 0                   DIOMOD     = 1
+RDSMOD     = 1                   RBODYMOD   = 0
+RGATEMOD   = '1*rgflag_na25od33'
+PERMOD     = 1                   ACNQSMOD   = 0                   TRNQSMOD   = 0
+TEMPMOD    = 0                   TNOM       = 25                  TOXE       = 'toxn_na25od33'
+TOXM       = 5.6e-009            DTOX       = 2.5232e-010         EPSROX     = 3.9
+WINT       = 0                   LINT       = 0                   LL         = 0
+WL         = 0                   LLN        = 1                   WLN        = 1
+LW         = 0                   WW         = 0                   LWN        = 1
+WWN        = 1                   LWL        = 0                   WWL        = 0
+LLC        = 0                   WLC        = 0                   LWC        = 0
+WWC        = 0                   LWLC       = 0                   WWLC       = 0
+XL         = '-3.859e-8+dxln_na25od33' XW         = '7e-09+dxwn_na25od33'     DLC        = '0+ddlcn_na25od33'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-009
+DLCIG      = 2.5e-009           
+VTH0       = '-0.11163674+dvthn_na25od33' 
+K1         = 0.083826
+K2         = 0.0070517436        LK2        = 2.2762599e-009      WK2        = -1.2877221e-008
+PK2        = -2.842989e-015      K3         = 2.6118349           K3B        = -4.9758566
+W0         = 0                   DVT0       = 0.064799587         DVT1       = 0.02075738
+DVT2       = 0.30031818          DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.03344             MINV       = -0.5
+VOFFL      = 0                   DVTP0      = 8.4008771e-009      DVTP1      = 3.5
+LPE0       = 2.8116619e-009      LPEB       = 1.51e-010           XJ         = 8.1e-008
+NGATE      = 5.9092e+020         NDEP       = 5.11e+017           NSD        = 1e+020
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0+dcitn_na25od33'       
+VOFF       = '-0.0422106+dvoffn_na25od33'  
+LVOFF      = '-2.082766e-08+dlvoffn_na25od33'  
+WVOFF      = '3.3894423e-08+dwvoffn_na25od33'  
+PVOFF      = '-6.3350567e-14+dpvoffn_na25od33' 
+NFACTOR    = '0.5+dnfactorn_na25od33'  
+ETA0       = '0.027315507+deta0n_na25od33' 
+LETA0      = '2.601415e-09+dleta0n_na25od33'   
+WETA0      = '-1.6012144e-08+dweta0n_na25od33' 
+PETA0      = '3.7340114e-15+dpeta0n_na25od33'  
+ETAB       = -0.0045972791       LETAB      = 1.1151745e-008      WETAB      = 2.8825868e-009
+PETAB      = -5.6539345e-015    
+U0         = '0.048289166+du0n_na25od33' 
+LU0        = '4.5628222e-09+dlu0n_na25od33'  
+WU0        = '-4.5485691e-09+dwu0n_na25od33' 
+PU0        = '1.8106513e-14+dpu0n_na25od33' 
+UA         = 9.5764173e-10       
+LUA        = 7.613697e-17        
+WUA        = -9.50372e-16   
+PUA        = 2.2317823e-21       
+UB         = 1.5651027e-18       
+LUB        = 8.6650846e-25 
+WUB        = 1.2345837e-24       
+PUB        = -2.6103171e-30      
+UC         = 1.6131981e-010
+LUC        = -3.1851744e-016     WUC        = -9.2263315e-017     PUC        = 1.4120976e-022
+VSAT       = '187428.42+dvsatn_na25od33' 
+A0         = 0.36907061          
+LA0        = 2.7507743e-07  
+WA0        = 1.834361e-07        
+PA0        = -3.6012468e-13      
+AGS        = '3.4051985+dagsn_na25od33' 
+LAGS       = -3.16583e-06        
+WAGS       = '-5.1787832e-07+dwagsn_na25od33' 
+PAGS       = 3.9514908e-13  
+A1         = 0                   A2         = 1                   B0         = 0
+B1         = 0                  
+KETA       = 0.069088692         
+LKETA      = -1.5615369e-07 
+WKETA      = -6.3354326e-08      
+PKETA      = 9.7615806e-14       
+DWG        = 0
+DWB        = 0                   PCLM       = 0.53198689          LPCLM      = -7.5895904e-007
+WPCLM      = -2.3041366e-007     PPCLM      = 4.5193566e-013      PDIBLC1    = 0
+PDIBLC2    = 0.0013062354        
+LPDIBLC2   = -3.3586275e-010     WPDIBLC2   = 3.8550414e-012
+PPDIBLC2   = -7.5613168e-018     PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 1.5                 DELTA      = 0.0075              PSCBE1     = 9.264e+008
+PSCBE2     = 1e-020              FPROUT     = 600                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RDSW       = 0                   RSW        = 173                 RDW        = 173
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 2.46634e-008        ALPHA1     = 0.068220587         BETA0      = 18.128904
+AGIDL      = 1e-008              BGIDL      = 2.3e+009            CGIDL      = 0.5
+EGIDL      = 0.8                 XRCRG1     = 12                  XRCRG2     = 1
+CGSO       = 'cgon_na25od33'           CGDO       = 'cgon_na25od33'           CGBO       = 0
+CGDL       = 'cgln_na25od33'           CGSL       = 'cgln_na25od33'           CLC        = 1e-007
+CLE        = 0.6                 CF         = 'cfn_na25od33'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 7.931
+NOFF       = 2.5571              VOFFCV     = -0.0283            
+KT1        = -0.28688464 
+Pkt1     = 0              
+Wkt1     = 0             
+LKT1       = -2.6199179e-08      
+KT1L       = 0                   KT2        = -0.02963
+UTE        = -1.3909644          
+Pute     = 0              
+Wute     = 0              
+Lute     = -5.6950456e-08 
+UA1        = 1.67e-009           UB1        = -2.64016e-018
+UC1        = -4.2194297e-11      
+Puc1     = 2.4893408e-23 
+Wuc1     = -2.1433782e-17 
+Luc1     = -4.9099425e-17 
+PRT        = 0                  
+AT         = 355526.45 
+Pat      = -4.978682e-09 
+Wat      = 0.0025383302  
+LAT        = -0.35160541         
+JSS        = 8.43E-07            JSD        = 8.43E-07
+JSWS       = 1.36E-12            JSWD       = 1.36E-12            JSWGS      = 1.36E-12
+JSWGD      = 1.36E-12            NJS        = 1                   NJD        = 1
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 10                  BVD        = 10
+XJBVS      = 1                   XJBVD      = 1                   PBS        = 1
+PBD        = 1                   CJS        = 'cjn_na25od33'            CJD        = 'cjn_na25od33'
+MJS        = 0.53                MJD        = 0.53                PBSWS      = 0.5
+PBSWD      = 0.5                 CJSWS      = 'cjswn_na25od33'          CJSWD      = 'cjswn_na25od33'
+MJSWS      = 0.011               MJSWD      = 0.011               PBSWGS     = 0.8
+PBSWGD     = 0.8                 CJSWGS     = 'cjswgn_na25od33'         CJSWGD     = 'cjswgn_na25od33'
+MJSWGS     = 0.52                MJSWGD     = 0.52                TPB        = 2.8E-03
+TCJ        = 2.1E-03             TPBSW      = 1.0E-04             TCJSW      = 3.6E-04
+TPBSWG     = 3.0E-03             TCJSWG     = 3.0E-03             XTIS       = 3
+XTID       = 3                   DMCG       = 1.135e-007          DMCI       = 3.05e-007
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0
+XGL        = -2.11e-008
+RSHG       = 15.06
+GBMIN      = 1e-012              RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+SAREF      = 0.46e-6
+SBREF      = 0.46e-6
+WLOD       = 1e-7
+KVTH0      = 0.8e-09
+LKVTH0     = -7.4e-007
+WKVTH0     = 6.6e-007
+PKVTH0     = 0e-14
+LLODVTH    = 1.0
+WLODVTH    = 1.0
+STK2       = 0.04e-09
+LODK2      = 1
+LODETA0    = 1
+KU0        = -7.40e-8
+LKU0       = 4.8e-007
+WKU0       = 5.2e-007
+PKU0       = -4e-014
+LLODKU0    = 1
+WLODKU0    = 1
+KVSAT      = 1.0
+STETA0     = -0.0e-9
+TKU0       = 0.8
+LVTH0      = '2.689281e-08+dlvthn_na25od33'  
+WVTH0      = '-3.5141676e-08+dwvthn_na25od33' 
+PVTH0      = '6.7212201e-14+dpvthn_na25od33'  
+LCIT       = '0+dlcitn_na25od33'       WCIT       = '0+dwcitn_na25od33'       PCIT       = '0+dpcitn_na25od33'
+LNFACTOR   = '0+dlnfactorn_na25od33'   WNFACTOR   = '0+dwnfactorn_na25od33'   PNFACTOR   = '0+dpnfactorn_na25od33'
+LVSAT      = '-0.076550358+dlvsatn_na25od33' 
+WVSAT      = '-0.00329983+dwvsatn_na25od33'  
+PVSAT      = '6.47228e-09+dpvsatn_na25od33'    
+FNOIMOD  = 1
+NOIA     = 'noian_na25od33'
+NOIB     = 'noibn_na25od33'
+NOIC     = 'noicn_na25od33'
+EM       = 1.12e+08
+EF       = 1.00
+TNOIMOD  = 0
+KVTH0WE  = 0
+K2WE     = 0
+KU0WE    = 0
+WEC      = 0
+WEB      = 0
+SCREF    = 1e-6
+WPEMOD   = 1
+UD       = 0 )


.ENDL MOS_na25od33


***************************************************************
*                                                             *
*                     2.5V HV DEVICE MODELS                   *
*                                                             *
***************************************************************
.LIB MOS_hv25_snw_spw
**********************************************************************************************
*                                                                                            *
*                                   2.5V HVNMOS DEVICE MODELS                                *
*                                                                                            *
**********************************************************************************************

.MODEL nch_hv25_snw.1 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hv25_snw'
+LMAX       = 0.0009000001        WMIN       = '1e-005-dxwn_hv25_snw'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.5704+dvthn_hv25_snw'   
+LVTH0      = '1.0886705e-15+dlvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+WVTH0      = '1.0228436e-13+dwvthn_hv25_snw' 
+PVTH0      = '-9.7981255e-19+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.03173+dk2n_hv25_snw'  
+LK2        = '0+dlk2n_hv25_snw' 
+WK2        = '0+dwk2n_hv25_snw'        
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0
+K3B        = 0.52562             W0         = 0                   DVT0       = 46.85
+DVT1       = 0.261               DVT2       = 0.04202             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.1
+MINV       = -0.3                VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20
+DVTP1      = 1.223               LPE0       = 3.507e-07           LPEB       = 1.362e-07
+XJ         = 2.35e-06            NGATE      = 4.282e+20           NDEP       = 5.11e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.000537+dcitn_hv25_snw'
+LCIT       = '0+dlcitn_hv25_snw'       WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'
+VOFF       = -0.1052276          NFACTOR    = 0.75                ETA0       = '0.003803+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '0+dweta0n_hv25_snw'      PETA0      = '0+dpeta0n_hv25_snw'
+ETAB       = -0.007951           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.02773+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '0+dwu0n_hv25_snw'        PU0        = '0+dpu0n_hv25_snw'
+UA         = -1.5453e-09        
+UB         = 3.02e-18 
+PUB      = 0 
+WUB      = 0 
+LUB      = 0 
+UC         = '1.2661e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+WUC      = '0+dwucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'      A0         = '1.28792+da0n_hv25_snw'   LA0        = '0+dla0n_hv25_snw'
+WA0        = '0+dwa0n_hv25_snw'        PA0        = '0+dpa0n_hv25_snw'        AGS        = '0.415+dagsn_hv25_snw'
+LAGS       = '0+dlagsn_hv25_snw'       WAGS       = '0+dwagsn_hv25_snw'       PAGS       = '0+dpagsn_hv25_snw'
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.04188+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+WKETA    = '0+dwketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.0005404+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '-1.0886718e-18+dlpdiblc2n_hv25_snw'
+WPDIBLC2   = '-1.0891898e-18+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '9.7981256e-22+dppdiblc2n_hv25_snw'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.399e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = 0 
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.002
+LTVOFF     = 0                   WTVOFF     = 0                   PTVOFF     = 0
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.269706           KT1L       = 0
+KT2        = -0.046              
+PKT2     = 0 
+WKT2     = 0 
+LKT2     = 0 
+UTE        = -1.095              UA1        = 2.8795633e-09
+UB1        = -3.470411e-18       LUB1       = 1.0009006e-30       WUB1       = 1.0446274e-30
+PUB1       = -2.9394377e-35
+UC1        = '-1.1e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+WUC1     = '0+dwuc1n_hv25_snw'
+LUC1     = '0+dluc1n_hv25_snw'
+PRT        = 0
+AT         = 222000              JSS        = 1.399e-07           JSWS       = 5e-14
+JSWGS      = 9e-14              
+NJS        = 1.00               
+NJD        = 1.007 
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01                IJTHSREV   = 0.01
+IJTHDREV   = 0.01                BVS        = 9                   XJBVS      = 1
+XJBVD      = 1                  
+JSD        = 2.299e-6            
+JSWD       = 2.001e-12 
+JSWGD      = 2.001e-12           
+BVD        = 14.5                JTSSWGS    = 1.086e-08
+JTSSWGD    = 1.086e-08           NJTSSWG    = 40                  XTSSWGS    = 0.29766
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1                   VTSSWGS    = 1
+VTSSWGD    = 1                   PBS        = 0.7                
+PBD        = 0.62 
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'           MJS        = 0.31
+MJD        = 0.35                
+PBSWS      = 0.48               
+PBSWD      = 0.6 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'         MJSWS      = 0.12
+MJSWD      = 0.27                
+PBSWGS     = 0.6                
+PBSWGD     = 0.6 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'        MJSWGS     = 0.3
+MJSWGD     = 0.32                
+TPB        = 1.95E-03            
+TCJ        = 1.71E-03 
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04            
+TPBSWG     = 1.75E-03 
+TCJSWG     = 1.33E-03            
+XTIS       = 3                   XTID       = 3
+DMCG       = 1.245e-07           DMCI       = 3.05e-07            DMDG       = 0
+DMCGT      = 0                   DWJ        = 0                   XGW        = 0
+XGL        = -2.11e-08           RSHG       = 15.06               GBMIN      = 1e-12
+RBPB       = 50                  RBPD       = 50                  RBPS       = 50
+RBDB       = 50                  RBSB       = 50                  NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.2 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-dxln_hv25_snw'
+LMAX       = '1e-005-dxln_hv25_snw'    WMIN       = '1e-005-dxwn_hv25_snw'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56815568+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '2.1498986e-08+dlvthn_hv25_snw' 
+WVTH0      = '0+dwvthn_hv25_snw'       
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096 
+K2         = '-0.030971118+dk2n_hv25_snw' 
+LK2        = '-7.2695682e-09+dlk2n_hv25_snw' 
+WK2        = '0+dwk2n_hv25_snw'        
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0
+K3B        = 0.52562             W0         = 0                   DVT0       = 46.85
+DVT1       = 0.261               DVT2       = 0.04202             DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.1
+MINV       = -0.3                VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20
+DVTP1      = 1.223               LPE0       = 3.507e-07           LPEB       = 1.362e-07
+XJ         = 2.35e-06            NGATE      = 4.282e+20           NDEP       = 5.11e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.0004898836+dcitn_hv25_snw'
+LCIT       = '4.5134213e-10+dlcitn_hv25_snw'
+WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'       VOFF       = -0.10578279
+LVOFF      = 5.3183037e-09       WVOFF      = 6.5135945e-16       PVOFF      = -6.2395688e-21
+NFACTOR    = 0.75                ETA0       = '0.0038497542+deta0n_hv25_snw'
+LETA0      = '-4.4787259e-10+dleta0n_hv25_snw'
+WETA0      = '0+dweta0n_hv25_snw'      PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.007951
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.02636607+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.3065492e-08+dlu0n_hv25_snw'
+WU0        = '6.5135954e-16+dwu0n_hv25_snw'
+PU0        = '-6.2395687e-21+dpu0n_hv25_snw'
+UA         = -1.621774e-09       LUA        = 7.3256777e-16       WUA        = 4.559517e-23
+PUA        = -4.3676981e-28     
+UB         = 3.0339031e-18       
+PUB      = 0 
+WUB      = 0 
+LUB        = -1.3318292e-25 
+UC         = '1.2170204e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+WUC      = '0+dwucn_hv25_snw' 
+LUC        = '4.7014805e-17+dlucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'
+KVSAT    = -0.4 
+LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'
+A0         = '1.4262467+da0n_hv25_snw' 
+LA0        = '-1.3250727e-06+dla0n_hv25_snw' 
+WA0        = '-5.8622361e-14+dwa0n_hv25_snw' 
+PA0        = '5.6156119e-19+dpa0n_hv25_snw' 
+AGS        = '0.38300976+dagsn_hv25_snw' 
+LAGS       = '3.0644404e-07+dlagsn_hv25_snw' 
+WAGS       = '0+dwagsn_hv25_snw'       
+PAGS       = '0+dpagsn_hv25_snw'       
+A1         = 0
+A2         = 0.82037             B0         = 0                   B1         = 0
+KETA       = '-0.039655488+dketan_hv25_snw'
+LKETA      = '-2.1309268e-08+dlketan_hv25_snw'
+WKETA      = '-6.5135948e-16+dwketan_hv25_snw'
+PKETA      = '6.2395686e-21+dpketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                  
+PDIBLC2    = '0.00056810277+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-2.6537314e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '1.0314925e-16+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-1.8718705e-23+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.3996436e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = -6.165876  
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.0020708033
+LTVOFF     = -6.7824639e-10      WTVOFF     = -3.9081577e-17      PTVOFF     = 3.7437412e-22
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.26501213         LKT1       = -4.4964041e-08
+WKT1       = -6.513595e-15       PKT1       = 6.2395686e-20       KT1L       = 0
+KT2        = -0.044283341        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = -1.6444391e-08      
+UTE        = -1.0816761
+LUTE       = -1.2763364e-07      UA1        = 2.8412992e-09       LUA1       = 3.6654358e-16
+UB1        = -3.4778955e-18      LUB1       = 7.1696745e-26       WUB1       = -2.0890393e-30
+PUB1       = 6.2395687e-37
+UC1        = '-1.2523559e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+WUC1     = '0+dwuc1n_hv25_snw'
+LUC1       = '1.4594629e-16+dluc1n_hv25_snw'
+PRT        = 0                   AT         = 237769.83           LAT        = -0.15106396
+WAT        = 1.0421753e-08       PAT        = -9.9833099e-14      JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.3 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-dxln_hv25_snw'    WMIN       = '1e-005-dxwn_hv25_snw'    WMAX       = 0.0009000001
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.65837596+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-3.0765622e-08+dlvthn_hv25_snw' 
+WVTH0      = '0+dwvthn_hv25_snw'       
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096 
+K2         = '-0.037720435+dk2n_hv25_snw' 
+LK2        = '-3.3596878e-09+dlk2n_hv25_snw' 
+WK2        = '2.8962057e-14+dwk2n_hv25_snw' 
+PK2        = '-1.677772e-20+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0019845+dcitn_hv25_snw'
+LCIT       = '-4.1448915e-10+dlcitn_hv25_snw'
+WCIT       = '0+dwcitn_hv25_snw'       PCIT       = '0+dpcitn_hv25_snw'       VOFF       = -0.11206397
+LVOFF      = 8.9569943e-09       WVOFF      = -2.9974009e-13      PVOFF      = 1.677772e-19
+NFACTOR    = 0.75                ETA0       = '0.0091687573+deta0n_hv25_snw'
+LETA0      = '-3.5291711e-09+dleta0n_hv25_snw'
+WETA0      = '2.0563061e-14+dweta0n_hv25_snw'
+PETA0      = '-1.1912181e-20+dpeta0n_hv25_snw'
+ETAB       = -0.007951           UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.015033924+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.9630205e-08+dlu0n_hv25_snw'
+WU0        = '-1.011952e-14+dwu0n_hv25_snw'
+PU0        = '1.9837617e-28+dpu0n_hv25_snw'
+UA         = -2.0646691e-09      LUA        = 9.8913684e-16       WUA        = 3.3463218e-21
+PUA        = -2.3488808e-27     
+UB         = 2.185808e-18        
+PUB      = 0 
+WUB      = 0 
+LUB        = 3.5811862e-25 
+UC         = '3.7054698e-10+ducn_hv25_snw' 
+LUC        = '-9.7141067e-17+dlucn_hv25_snw' 
+WUC        = '-1.8825334e-15+dwucn_hv25_snw' 
+PUC        = '1.0905516e-21+dpucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'
+KVSAT    = -0.4 
+WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '2.8370898+da0n_hv25_snw' 
+LA0        = '-2.1423742e-06+dla0n_hv25_snw' 
+WA0        = '3.5173417e-12+dwa0n_hv25_snw' 
+PA0        = '-1.5099948e-18+dpa0n_hv25_snw' 
+AGS        = '-2.6915442+dagsn_hv25_snw' 
+LAGS       = '2.0875331e-06+dlagsn_hv25_snw' 
+WAGS       = '-2.8962058e-12+dwagsn_hv25_snw' 
+PAGS       = '1.6777721e-18+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.17665855+dketan_hv25_snw' 
+LKETA      = '5.8056604e-08+dlketan_hv25_snw' 
+WKETA      = '3.8884465e-07+dwketan_hv25_snw' 
+PKETA      = '-2.252577e-13+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00010889385+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '6.4659e-13+dlpdiblc2n_hv25_snw'     
+WPDIBLC2   = '2.1564691e-16+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-8.3888599e-23+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.56072e+09 
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = -99.477394 
+CGIDL      = 70                  EGIDL      = 2.2484              AIGBACC    = 0.43
+BIGBACC    = 0.054               CIGBACC    = 0.075               NIGBACC    = 1
+AIGBINV    = 0.35                BIGBINV    = 0.03                CIGBINV    = 0.006
+EIGBINV    = 1.1                 NIGBINV    = 3                   AIGC       = 0.43
+BIGC       = 0.054               CIGC       = 0.075               AIGSD      = 0.43
+BIGSD      = 0.054               CIGSD      = 0.075               NIGC       = 1
+POXEDGE    = 1                   PIGCD      = 1                   NTOX       = 1
+XRCRG1     = 12                  XRCRG2     = 1                   VFBSDOFF   = 0.1
+LVFBSDOFF  = 0                   WVFBSDOFF  = 0                   PVFBSDOFF  = 0
+CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'          CGBO       = 0
+CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07
+CLE        = 0.6                 CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6
+CKAPPAD    = 0.6                 ACDE       = 0.4                 MOIN       = 5
+NOFF       = 2.3195              
+VOFFCV     = -0.022791           
+TVOFF      = 0.00061379989
+LTVOFF     = 1.6579571e-10       WTVOFF     = -5.5131128e-16      PTVOFF     = 6.7110882e-22
+TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0                   WTVFBSDOFF = 0
+PTVFBSDOFF = 0                   KT1        = -0.45116111         LKT1       = 6.2872069e-08
+WKT1       = 3.9081575e-13       PKT1       = -1.677772e-19       KT1L       = 0
+KT2        = -0.10893154         LKT2       = 2.100631e-08        WKT2       = -2.8962057e-14
+PKT2       = 1.6777718e-20       UTE        = -1.324896           LUTE       = 1.3263653e-08
+UA1        = 4.668441e-10        LUA1       = 1.7420654e-15       UB1        = -9.7213076e-19
+LUB1       = -1.3798927e-24      WUB1       = -1.0119517e-30      PUB1       = -3.4730437e-44
+UC1        = '1.4252689e-10+duc1n_hv25_snw' 
+LUC1       = '-9.16852e-18+dluc1n_hv25_snw' 
+WUC1       = '-8.6886172e-22+dwuc1n_hv25_snw' 
+PUC1       = '5.033316e-28+dpuc1n_hv25_snw' 
+PRT        = 0                  
+AT         = 26111.936 
+LAT        = -0.028450543        
+WAT        = -5.3841902e-07      
+PAT        = 2.1811036e-13 
+JSS        = 1.399e-07           JSWS       = 5e-14               JSWGS      = 9e-14
+NJS        = 1.00               
+NJD        = 1.007               
+IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   XJBVS      = 1                   XJBVD      = 1
+JSD        = 2.299e-6            
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12 
+BVD        = 14.5                JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08
+NJTSSWG    = 40                  XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774 
+TNJTSSWG   = 1                   VTSSWGS    = 1                   VTSSWGD    = 1
+PBS        = 0.7                
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'
+CJD        = 'cjdn_hv25_snw'           MJS        = 0.31               
+MJD        = 0.35 
+PBSWS      = 0.48               
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'
+CJSWD      = 'cjswdn_hv25_snw'         MJSWS      = 0.12               
+MJSWD      = 0.27 
+PBSWGS     = 0.6                
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'
+CJSWGD     = 'cjswgdn_hv25_snw'        MJSWGS     = 0.3                
+MJSWGD     = 0.32 
+TPB        = 1.95E-03            
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03 
+TCJSW      = 9.93E-04            
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03 
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.245e-07
+DMCI       = 3.05e-07            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.11e-08
+RSHG       = 15.06               GBMIN      = 1e-12               RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.4 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hv25_snw'
+LMAX       = 0.0009000001        WMIN       = '1e-006-dxwn_hv25_snw'    WMAX       = '1e-005-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56899962+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-1.0765758e-13+dlvthn_hv25_snw' 
+WVTH0      = '1.4013749e-08+dwvthn_hv25_snw' 
+PVTH0      = '1.0841118e-19+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.030898666+dk2n_hv25_snw' 
+LK2        = '0+dlk2n_hv25_snw'        
+WK2        = '-8.319164e-09+dwk2n_hv25_snw'  
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0                   K3B        = 0.52562
+W0         = 0                   DVT0       = 46.85               DVT1       = 0.261
+DVT2       = 0.04202             DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.1                 MINV       = -0.3
+VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20         DVTP1      = 1.223
+LPE0       = 3.507e-07           LPEB       = 1.362e-07           XJ         = 2.35e-06
+NGATE      = 4.282e+20           NDEP       = 5.11e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00057329675+dcitn_hv25_snw'
+LCIT       = '1.0833535e-17+dlcitn_hv25_snw'
+WCIT       = '-3.6322162e-10+dwcitn_hv25_snw'
+PCIT       = '-1.0841118e-22+dpcitn_hv25_snw'
+VOFF       = -0.10423309         WVOFF      = -9.9520936e-09      NFACTOR    = 0.75
+ETA0       = '0.0041001769+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '-2.9738491e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0080753085       WETAB      = 1.2439556e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.027320487+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '4.0979999e-09+dwu0n_hv25_snw'
+PU0        = '0+dpu0n_hv25_snw'        UA         = -1.604196e-09       WUA        = 5.8937233e-16
+UB         = 3.0668172e-18       
+LUB        = -1.0833535e-31      
+WUB        = -4.6850015e-25 
+PUB        = 1.0841118e-36 
+UC         = '1.3013561e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+WUC        = '-3.5280869e-17+dwucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.2661706+da0n_hv25_snw' 
+LA0        = '0+dla0n_hv25_snw' 
+WA0        = '2.1764634e-07+dwa0n_hv25_snw' 
+PA0        = '0+dpa0n_hv25_snw'        
+AGS        = '0.41553546+dagsn_hv25_snw'
+LAGS       = '0+dlagsn_hv25_snw'       WAGS       = '-5.3583029e-09+dwagsn_hv25_snw'
+PAGS       = '0+dpagsn_hv25_snw'       A1         = 0                   A2         = 0.82037
+B0         = 0                   B1         = 0
+KETA       = '-0.042854552+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+WKETA      = '9.7523441e-09+dwketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                   PDIBLC2    = '0.00037999609+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '1.0765758e-16+dlpdiblc2n_hv25_snw'
+WPDIBLC2   = '1.6051619e-09+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '-1.0841118e-22+dppdiblc2n_hv25_snw'
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4068322e+09 
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -78.377043          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0020559444        LTVOFF     = 0                   WTVOFF     = -5.5983606e-10
+PTVOFF     = 0                   TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26925912
+WKT1       = -4.4719704e-09      KT1L       = 0                  
+KT2        = -0.046223777 
+LKT2       = -1.0833534e-15      
+WKT2       = 2.239343e-09        
+PKT2       = 1.0841118e-20 
+UTE        = -1.1056295          LUTE       = 4.3334138e-14       WUTE       = 1.063689e-07
+PUTE       = -4.3364473e-19      UA1        = 2.8549361e-09       WUA1       = 2.4644465e-16
+UB1        = -3.4579588e-18      LUB1       = -2.0448162e-30      WUB1       = -1.2460853e-25
+PUB1       = 1.0841118e-36
+UC1        = '-1.1186071e-10+duc1n_hv25_snw'
+PUC1     = '0+dpuc1n_hv25_snw'
+LUC1     = '0+dluc1n_hv25_snw'
+WUC1       = '1.8620149e-17+dwuc1n_hv25_snw'
+PRT        = 0                   AT         = 222000              JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.5 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-dxln_hv25_snw'
+LMAX       = '1e-005-dxln_hv25_snw'    WMIN       = '1e-006-dxwn_hv25_snw'    WMAX       = '1e-005-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56650617+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '2.3885351e-08+dlvthn_hv25_snw' 
+WVTH0      = '1.6506672e-08+dwvthn_hv25_snw' 
+PVTH0      = '-2.3880361e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.03016535+dk2n_hv25_snw'  
+LK2        = '-7.0246556e-09+dlk2n_hv25_snw' 
+WK2        = '-8.0633169e-09+dwk2n_hv25_snw' 
+PK2        = '-2.4508341e-15+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00052439212+dcitn_hv25_snw'
+LCIT       = '4.6847218e-10+dlcitn_hv25_snw'
+WCIT       = '-3.4532676e-10+dwcitn_hv25_snw'
+PCIT       = '-1.7142036e-16+dpcitn_hv25_snw'
+VOFF       = -0.10484164         LVOFF      = 5.8294711e-09       WVOFF      = -9.4181028e-09
+PVOFF      = -5.1152585e-15      NFACTOR    = 0.75                ETA0       = '0.0041521624+deta0n_hv25_snw'
+LETA0      = '-4.9798456e-10+dleta0n_hv25_snw'
+WETA0      = '-3.0261985e-09+dweta0n_hv25_snw'
+PETA0      = '5.0147045e-16+dpeta0n_hv25_snw'
+ETAB       = -0.0080753085       WETAB      = 1.2439556e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.025956845+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.3062732e-08+dlu0n_hv25_snw'
+WU0        = '4.0951171e-09+dwu0n_hv25_snw'
+PU0        = '2.7615038e-17+dpu0n_hv25_snw'
+UA         = -1.6827304e-09      LUA        = 7.5230414e-16       WUA        = 6.0998995e-16
+PUA        = -1.9750235e-22     
+UB         = 3.0821927e-18       
+LUB        = -1.4728613e-25 
+WUB        = -4.8323292e-25      
+PUB        = 1.4113086e-31 
+UC         = '1.2522658e-10+ducn_hv25_snw' 
+LUC        = '4.7025153e-17+dlucn_hv25_snw' 
+WUC        = '-3.5270058e-17+dwucn_hv25_snw' 
+PUC        = '-1.03556e-25+dpucn_hv25_snw'   
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.4021929+da0n_hv25_snw' 
+LA0        = '-1.3029988e-06+dla0n_hv25_snw' 
+WA0        = '2.4070587e-07+dwa0n_hv25_snw' 
+PA0        = '-2.2089408e-13+dpa0n_hv25_snw' 
+AGS        = '0.38241298+dagsn_hv25_snw' 
+LAGS       = '3.1729015e-07+dlagsn_hv25_snw' 
+WAGS       = '5.97207e-09+dwagsn_hv25_snw'  
+PAGS       = '-1.0853704e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.04071521+dketan_hv25_snw'
+LKETA      = '-2.04934e-08+dlketan_hv25_snw'
+WKETA      = '1.0604639e-08+dwketan_hv25_snw'
+PKETA      = '-8.164386e-15+dpketan_hv25_snw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00039833343+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-1.7565876e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '1.698882e-09+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-8.9777177e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4074759e+09 
+PBGIDL   = 0              
+LBGIDL   = -6.1658759 
+WBGIDL     = -78.377048          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0021199845        LTVOFF     = -6.134585e-10       WTVOFF     = -4.9215553e-10
+PTVOFF     = -6.4833206e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26447988
+LKT1       = -4.5781779e-08      WKT1       = -5.3262253e-09      PKT1       = 8.1831642e-15
+KT1L       = 0                  
+KT2        = -0.044466284        
+LKT2       = -1.6835561e-08 
+WKT2       = 1.83071e-09         
+PKT2       = 3.9144316e-15       
+UTE        = -1.0912181
+LUTE       = -1.3805102e-07      WUTE       = 9.5486347e-08       PUTE       = 1.0424677e-13
+UA1        = 2.8216694e-09       LUA1       = 3.1867162e-16       WUA1       = 1.9643528e-16
+PUA1       = 4.790547e-22        UB1        = -3.4672797e-18      LUB1       = 8.928643e-26
+WUB1       = -1.0623345e-25      PUB1       = -1.7601936e-31
+UC1        = '-1.2707275e-10+duc1n_hv25_snw'
+LUC1       = '1.4572069e-16+dluc1n_hv25_snw'
+WUC1       = '1.8384482e-17+dwuc1n_hv25_snw'
+PUC1       = '2.257528e-24+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 237877.86           LAT        = -0.15209881
+WAT        = -0.0010810437       PAT        = 1.0355642e-08       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.6 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-dxln_hv25_snw'    WMIN       = '1e-006-dxwn_hv25_snw'    WMAX       = '1e-005-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.66406201+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '-3.2628752e-08+dlvthn_hv25_snw' 
+WVTH0      = '-5.6900341e-08+dwvthn_hv25_snw' 
+PVTH0      = '1.8644319e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '-0.038247886+dk2n_hv25_snw' 
+LK2        = '-2.3424433e-09+dlk2n_hv25_snw' 
+WK2        = '5.2782044e-09+dwk2n_hv25_snw'  
+PK2        = '-1.0179581e-14+dpk2n_hv25_snw' 
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0021558865+dcitn_hv25_snw'
+LCIT       = '-4.7665251e-10+dlcitn_hv25_snw'
+WCIT       = '-1.7150645e-09+dwcitn_hv25_snw'
+PCIT       = '6.2206871e-16+dpcitn_hv25_snw'
+VOFF       = -0.11277103         LVOFF      = 1.0422968e-08       WVOFF      = 7.0752106e-09
+PVOFF      = -1.4669835e-14      NFACTOR    = 0.75                ETA0       = '0.0097310283+deta0n_hv25_snw'
+LETA0      = '-3.7298216e-09+dleta0n_hv25_snw'
+WETA0      = '-5.6266249e-09+dweta0n_hv25_snw'
+PETA0      = '2.0078974e-15+dpeta0n_hv25_snw'
+ETAB       = -0.0080753085       WETAB      = 1.2439556e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.014856902+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '1.9492929e-08+dlu0n_hv25_snw'
+WU0        = '1.7714492e-09+dwu0n_hv25_snw'
+PU0        = '1.3737159e-15+dpu0n_hv25_snw'
+UA         = -2.0677308e-09      LUA        = 9.7533487e-16       WUA        = 3.0641927e-17
+PUA        = 1.3811397e-22      
+UB         = 2.1380215e-18       
+LUB        = 3.9967218e-25 
+WUB        = 4.7819848e-25       
+PUB        = -4.1582638e-31 
+UC         = '1.7208914e-10+ducn_hv25_snw' 
+LUC        = '1.9877672e-17+dlucn_hv25_snw' 
+WUC        = '1.0343415e-16+dwucn_hv25_snw' 
+PUC        = '-8.0454904e-23+dpucn_hv25_snw' 
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '2.7883693+da0n_hv25_snw' 
+LA0        = '-2.1060108e-06+dla0n_hv25_snw' 
+WA0        = '4.8754885e-07+dwa0n_hv25_snw'  
+PA0        = '-3.6389021e-13+dpa0n_hv25_snw' 
+AGS        = '-2.709636+dagsn_hv25_snw'  
+LAGS       = '2.1085142e-06+dlagsn_hv25_snw' 
+WAGS       = '1.8104222e-07+dwagsn_hv25_snw'  
+PAGS       = '-2.0995519e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.14077466+dketan_hv25_snw' 
+LKETA      = '3.7471039e-08+dlketan_hv25_snw' 
+WKETA      = '2.9754579e-08+dwketan_hv25_snw' 
+PKETA      = '-1.9257946e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.00016492465+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-4.044505e-11+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '-5.6069993e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '4.1120399e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.5813612e+09 
+PBGIDL   = 7.4254705e-05 
+LBGIDL   = -106.89768 
+WBGIDL     = -206.55712          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.00070206902       LTVOFF     = 2.0793992e-10       WTVOFF     = -8.8330974e-10
+PTVOFF     = -4.2173642e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.45776537 
+LKT1       = 6.6188505e-08       
+WKT1       = 6.6089134e-08       
+PKT1       = -3.3187753e-14 
+KT1L       = 0                   KT2        = -0.11375012         LKT2       = 2.3300562e-08
+WKT2       = 4.821945e-08        PKT2       = -2.2958565e-14      UTE        = -1.3588252
+LUTE       = 1.6973791e-08       WUTE       = 3.3952937e-07       PUTE       = -3.7127355e-14
+UA1        = 2.4590441e-10       LUA1       = 1.8108123e-15       WUA1       = 2.2109434e-15
+PUA1       = -6.8794985e-22     
+UB1        = -4.6546741e-19      
+LUB1       = -1.6496635e-24 
+WUB1       = -5.0701811e-24      
+PUB1       = 2.6995956e-30 
+UC1        = '1.897303e-10+duc1n_hv25_snw'  
+LUC1       = '-3.780332e-17+dluc1n_hv25_snw' 
+WUC1       = '-4.7236537e-16+dwuc1n_hv25_snw' 
+PUC1       = '2.8654892e-22+dpuc1n_hv25_snw'  
+PRT        = 0                  
+AT         = 21180.051           
+LAT        = -0.026565769 
+WAT        = 0.049352836         
+PAT        = -1.8860704e-08      
+JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.7 NMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxln_hv25_snw'
+LMAX       = 0.0009000001        WMIN       = 6e-07               WMAX       = '1e-006-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09             VTH0       = '0.5867339+dvthn_hv25_snw'
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '0+dlvthn_hv25_snw'       WVTH0      = '-3.8446798e-09+dwvthn_hv25_snw'
+PVTH0      = '0+dpvthn_hv25_snw'      
+K1         = 0.72096             
+K2         = '-0.029554225+dk2n_hv25_snw' 
+LK2        = '0+dlk2n_hv25_snw'        
+WK2        = '-9.673015e-09+dwk2n_hv25_snw'  
+PK2        = '0+dpk2n_hv25_snw'        
+K3         = 0                   K3B        = 0.52562
+W0         = 0                   DVT0       = 46.85               DVT1       = 0.261
+DVT2       = 0.04202             DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.1                 MINV       = -0.3
+VOFFL      = -1.22e-08           DVTP0      = 4.44089e-20         DVTP1      = 1.223
+LPE0       = 3.507e-07           LPEB       = 1.362e-07           XJ         = 2.35e-06
+NGATE      = 4.282e+20           NDEP       = 5.11e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00017147578+dcitn_hv25_snw'
+LCIT       = '-2.4375453e-16+dlcitn_hv25_snw'
+WCIT       = '4.1412104e-11+dwcitn_hv25_snw'
+PCIT       = '1.47959e-22+dpcitn_hv25_snw'
+VOFF       = -0.10549053         WVOFF      = -8.6858483e-09      NFACTOR    = 0.75
+ETA0       = '-0.002042785+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '3.2121135e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0098021603       WETAB      = 2.9828953e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.032042525+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '0+dlu0n_hv25_snw'        WU0        = '-6.5709268e-10+dwu0n_hv25_snw'
+PU0        = '0+dpu0n_hv25_snw'        UA         = -1.1506345e-09      LUA        = 4.4079146e-22
+WUA        = 1.326359e-16        PUA        = -4.4387699e-28     
+UB         = 2.8656853e-18 
+LUB        = 2.4375453e-30       
+WUB        = -2.6596025e-25      
+PUB        = -1.47959e-36 
+UC         = '1.4024866e-10+ducn_hv25_snw' 
+PUC      = '0+dpucn_hv25_snw' 
+LUC      = '0+dlucn_hv25_snw' 
+WUC        = '-4.54647e-17+dwucn_hv25_snw'  
+VSAT       = '100000+dvsatn_hv25_snw'
+KVSAT    = -0.4 
+LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'      PVSAT      = '0+dpvsatn_hv25_snw'
+A0         = '1.4858003+da0n_hv25_snw' 
+LA0        = '0+dla0n_hv25_snw'        
+WA0        = '-3.52079e-09+dwa0n_hv25_snw'   
+PA0        = '0+dpa0n_hv25_snw'        
+AGS        = '0.43224+dagsn_hv25_snw'  LAGS       = '0+dlagsn_hv25_snw'
+WAGS       = '-2.2179781e-08+dwagsn_hv25_snw'
+PAGS       = '0+dpagsn_hv25_snw'       A1         = 0                   A2         = 0.82037
+B0         = 0                   B1         = 0
+KETA       = '-0.03277545+dketan_hv25_snw'
+PKETA    = '0+dpketan_hv25_snw'
+LKETA    = '0+dlketan_hv25_snw'
+WKETA      = '-3.9731185e-10+dwketan_hv25_snw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'      WPCLM      = '0+dwpclmn_hv25_snw'
+PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0                   PDIBLC2    = '0.00164622+dpdiblc2n_hv25_snw'
+LPDIBLC2   = '0+dlpdiblc2n_hv25_snw'   WPDIBLC2   = '3.3007446e-10+dwpdiblc2n_hv25_snw'
+PPDIBLC2   = '0+dppdiblc2n_hv25_snw'   PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.112               DELTA      = 0.00375             PSCBE1     = 2170000
+PSCBE2     = 1.5952e-09          FPROUT     = 0                   PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 15.52
+RSW        = 80                  RDW        = 510                 PRWG       = 0
+PRWB       = 0                   WR         = 1                   ALPHA0     = 1e-09
+ALPHA1     = 0.978               BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'
+LAGIDL     = '0+dlagidln_hv25_snw'     WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'
+BGIDL      = 2.404875e+09        
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -76.406125          
+CGIDL      = 70
+EGIDL      = 2.2484              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.054
+CIGC       = 0.075               AIGSD      = 0.43                BIGSD      = 0.054
+CIGSD      = 0.075               NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'
+CGDO       = 'cgdon_hv25_snw'          CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'
+CGSL       = 'cgsln_hv25_snw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfn_hv25_snw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5                  
+NOFF       = 2.3195 
+VOFFCV     = -0.022791           
+TVOFF      = 0.00188241          LTVOFF     = 0
+WTVOFF     = -3.8508687e-10      PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.27014163         WKT1       = -3.5832792e-09      KT1L       = 0
+KT2        = -0.026943303        
+LKT2       = 2.4375454e-14       
+WKT2       = -1.7176095e-08 
+PKT2       = -1.47959e-20        
+UTE        = -0.9984824          LUTE       = -9.7501813e-13
+WUTE       = -1.5281843e-09      PUTE       = 5.91836e-19         UA1        = 3.4824632e-09
+WUA1       = -3.8547517e-16      UB1        = -4.1272103e-18      LUB1       = -9.6824044e-31
+WUB1       = 5.493278e-25        PUB1       = 2.2398669e-44
+UC1        = '-1.5751471e-10+duc1n_hv25_snw'
+LUC1       = '1.4693049e-23+dluc1n_hv25_snw'
+WUC1       = '6.4593727e-17+dwuc1n_hv25_snw'
+PUC1       = '-1.47959e-29+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 222000              JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.8 NMOS	(	LEVEL      = 54                  LMIN       = '1e-006-dxln_hv25_snw'
+LMAX       = '1e-005-dxln_hv25_snw'    WMIN       = 6e-07               WMAX       = '1e-006-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.58596616+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '7.354444e-09+dlvthn_hv25_snw'  
+WVTH0      = '-3.0895374e-09+dwvthn_hv25_snw' 
+PVTH0      = '-7.233735e-15+dpvthn_hv25_snw'  
+K1         = 0.72096             
+K2         = '-0.028027666+dk2n_hv25_snw' 
+LK2        = '-1.4623361e-08+dlk2n_hv25_snw' 
+WK2        = '-1.0215964e-08+dwk2n_hv25_snw' 
+PK2        = '5.201063e-15+dpk2n_hv25_snw'   
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00014362352+dcitn_hv25_snw'
+LCIT       = '2.6680484e-10+dlcitn_hv25_snw'
+WCIT       = '3.8107218e-11+dwcitn_hv25_snw'
+PCIT       = '3.1658649e-17+dpcitn_hv25_snw'
+VOFF       = -0.1051917          LVOFF      = -2.8625772e-09      WVOFF      = -9.0655873e-09
+PVOFF      = 3.6376342e-15       NFACTOR    = 0.75                ETA0       = '-0.002042785+deta0n_hv25_snw'
+LETA0      = '0+dleta0n_hv25_snw'      WETA0      = '3.2121135e-09+dweta0n_hv25_snw'
+PETA0      = '0+dpeta0n_hv25_snw'      ETAB       = -0.0098021603       WETAB      = 2.9828953e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.031079424+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '9.2258309e-09+dlu0n_hv25_snw'
+WU0        = '-1.0633201e-09+dwu0n_hv25_snw'
+PU0        = '3.8913744e-15+dpu0n_hv25_snw'
+UA         = -1.1838355e-09      LUA        = 3.1804303e-16       WUA        = 1.0760286e-16
+PUA        = 2.397986e-22       
+UB         = 2.8519788e-18       
+LUB        = 1.3130201e-25  
+WUB        = -2.5140743e-25      
+PUB        = -1.394074e-31  
+UC         = '1.3517962e-10+ducn_hv25_snw' 
+LUC        = '4.8557871e-17+dlucn_hv25_snw' 
+WUC        = '-4.5292767e-17+dwucn_hv25_snw' 
+PUC        = '-1.647003e-24+dpucn_hv25_snw'  
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '1.631829+da0n_hv25_snw'  
+LA0        = '-1.3988524e-06+dla0n_hv25_snw' 
+WA0        = '9.46235e-09+dwa0n_hv25_snw'    
+PA0        = '-1.2436942e-13+dpa0n_hv25_snw' 
+AGS        = '0.41461947+dagsn_hv25_snw' 
+LAGS       = '1.687924e-07+dlagsn_hv25_snw'  
+WAGS       = '-2.6459865e-08+dwagsn_hv25_snw' 
+PAGS       = '4.10002e-14+dpagsn_hv25_snw'  
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.031996639+dketan_hv25_snw' 
+LKETA      = '-7.460465e-09+dlketan_hv25_snw' 
+WKETA      = '1.8250375e-09+dwketan_hv25_snw' 
+PKETA      = '-2.1288551e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '0.0017293789+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '-7.9660291e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '3.5851924e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-2.7248101e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.4064954e+09 
+PBGIDL   = 9.422214e-06   
+LBGIDL   = -15.522593 
+WBGIDL     = -77.389725          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = 0.0020909319        LTVOFF     = -1.9974936e-09      WTVOFF     = -4.6289958e-10
+PTVOFF     = 7.4539129e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.26474403
+LKT1       = -5.1705255e-08      WKT1       = -5.0602247e-09      PKT1       = 1.4148105e-14
+KT1L       = 0                  
+KT2        = -0.025648252        
+LKT2       = -1.2405651e-08 
+WKT2       = -1.7119048e-08      
+PKT2       = -5.464875e-16       
+UTE        = -0.99653847
+LUTE       = -1.8622487e-08      WUTE       = 1.4400008e-10       PUTE       = -1.6017764e-14
+UA1        = 3.4032566e-09       LUA1       = 7.5874416e-16       WUA1       = -3.89223e-16
+PUA1       = 3.5901651e-23       UB1        = -4.122698e-18       LUB1       = -4.3225884e-26
+WUB1       = 5.5377274e-25       PUB1       = -4.2579456e-32
+UC1        = '-1.7286994e-10+duc1n_hv25_snw'
+LUC1       = '1.4709236e-16+dluc1n_hv25_snw'
+WUC1       = '6.4502251e-17+dwuc1n_hv25_snw'
+PUC1       = '8.7626402e-25+dpuc1n_hv25_snw'
+PRT        = 0                   AT         = 235827.57           LAT        = -0.13245844
+WAT        = 0.00098360183       PAT        = -9.422217e-09       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


.MODEL nch_hv25_snw.9 NMOS	(	LEVEL      = 54                  LMIN       = 8.5e-07
+LMAX       = '1e-006-dxln_hv25_snw'    WMIN       = 6e-07               WMAX       = '1e-006-dxwn_hv25_snw'
+XL         = '-1.5e-08+dxln_hv25_snw'  XW         = '7e-09+dxwn_hv25_snw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxn_hv25_snw'           TOXM       = 5.6e-09
+DTOX       = 3.0528e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 2.0285e-07          LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcn_hv25_snw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '0.56718873+dvthn_hv25_snw' 
+KVTH0    = -7e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.2e-006 
+LKVTH0   = -4.45e-007 
+LVTH0      = '1.8232216e-08+dlvthn_hv25_snw'  
+WVTH0      = '4.0651078e-08+dwvthn_hv25_snw'  
+PVTH0      = '-3.2572674e-14+dpvthn_hv25_snw' 
+K1         = 0.72096             
+K2         = '0.00596423+dk2n_hv25_snw'  
+LK2        = '-3.4314873e-08+dlk2n_hv25_snw' 
+WK2        = '-3.9243397e-08+dwk2n_hv25_snw' 
+PK2        = '2.2016659e-14+dpk2n_hv25_snw'  
+K3         = 0                   K3B        = 0.52562             W0         = 0
+DVT0       = 46.85               DVT1       = 0.261               DVT2       = 0.04202
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.1                 MINV       = -0.3                VOFFL      = -1.22e-08
+DVTP0      = 4.44089e-20         DVTP1      = 1.223               LPE0       = 3.507e-07
+LPEB       = 1.362e-07           XJ         = 2.35e-06            NGATE      = 4.282e+20
+NDEP       = 5.11e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '-0.00030429415+dcitn_hv25_snw'
+LCIT       = '5.2628355e-10+dlcitn_hv25_snw'
+WCIT       = '7.6233741e-10+dwcitn_hv25_snw'
+PCIT       = '-3.878879e-16+dpcitn_hv25_snw'
+VOFF       = -0.01579062         
+LVOFF      = -5.465262e-08       
+WVOFF      = -9.0584057e-08 
+PVOFF      = 5.0861284e-14       
+NFACTOR    = 0.75                ETA0       = '-0.0051352725+deta0n_hv25_snw'
+LETA0      = '1.791478e-09+dleta0n_hv25_snw'
+WETA0      = '9.34374e-09+dweta0n_hv25_snw'
+PETA0      = '-3.5520513e-15+dpeta0n_hv25_snw'
+ETAB       = -0.0098021603       WETAB      = 2.9828953e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '-0.0050681187+du0n_hv25_snw'
+KU0      = -6.52839e-008 
+PKU0     = 0e-13 
+WKU0     = 6.4e-007 
+LKU0     = 3.528575e-007 
+LU0        = '3.0166103e-08+dlu0n_hv25_snw'
+WU0        = '2.1835945e-08+dwu0n_hv25_snw'
+PU0        = '-9.3741698e-15+dpu0n_hv25_snw'
+UA         = -3.0092683e-09      LUA        = 1.3755162e-15       WUA        = 9.7877017e-16
+PUA        = -2.6486863e-22     
+UB         = 2.1142697e-18       
+LUB        = 5.5865688e-25 
+WUB        = 5.0211681e-25       
+PUB        = -5.7592393e-31 
+UC         = '2.1098788e-10+ducn_hv25_snw'
+LUC        = '4.6421442e-18+dlucn_hv25_snw'
+WUC        = '6.4263119e-17+dwucn_hv25_snw'
+PUC        = '-6.5112728e-23+dpucn_hv25_snw'
+VSAT       = '100000+dvsatn_hv25_snw'  LVSAT      = '0+dlvsatn_hv25_snw'      WVSAT      = '0+dwvsatn_hv25_snw'
+KVSAT    = -0.4 
+PVSAT      = '0+dpvsatn_hv25_snw'     
+A0         = '5.16666+da0n_hv25_snw'   
+LA0        = '-3.44658e-06+dla0n_hv25_snw'   
+WA0        = '-1.9073898e-06+dwa0n_hv25_snw' 
+PA0        = '9.8606318e-13+dpa0n_hv25_snw' 
+AGS        = '-1.8785318+dagsn_hv25_snw' 
+LAGS       = '1.497215e-06+dlagsn_hv25_snw'  
+WAGS       = '-6.5587953e-07+dwagsn_hv25_snw' 
+PAGS       = '4.0562309e-13+dpagsn_hv25_snw' 
+A1         = 0                   A2         = 0.82037             B0         = 0
+B1         = 0
+KETA       = '-0.02132804+dketan_hv25_snw' 
+LKETA      = '-1.3640783e-08+dlketan_hv25_snw' 
+WKETA      = '-9.0528161e-08+dwketan_hv25_snw' 
+PKETA      = '3.2211659e-14+dpketan_hv25_snw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.012+dpclmn_hv25_snw'   LPCLM      = '0+dlpclmn_hv25_snw'
+WPCLM      = '0+dwpclmn_hv25_snw'      PPCLM      = '0+dppclmn_hv25_snw'      PDIBLC1    = 0
+PDIBLC2    = '-0.0010274321+dpdiblc2n_hv25_snw' 
+LPDIBLC2   = '8.0041753e-10+dlpdiblc2n_hv25_snw' 
+WPDIBLC2   = '6.4000321e-10+dwpdiblc2n_hv25_snw' 
+PPDIBLC2   = '-4.3554467e-16+dppdiblc2n_hv25_snw' 
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.112
+DELTA      = 0.00375             PSCBE1     = 2170000             PSCBE2     = 1.5952e-09
+FPROUT     = 0                   PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 15.52               RSW        = 80
+RDW        = 510                 PRWG       = 0                   PRWB       = 0
+WR         = 1                   ALPHA0     = 1e-09               ALPHA1     = 0.978
+BETA0      = 28.93               AGIDL      = '1e-08+dagidln_hv25_snw'  LAGIDL     = '0+dlagidln_hv25_snw'
+WAGIDL     = '0+dwagidln_hv25_snw'     PAGIDL     = '0+dpagidln_hv25_snw'    
+BGIDL      = 2.5238016e+09 
+PBGIDL   = 5.0671216e-05  
+LBGIDL   = -83.47812  
+WBGIDL     = -148.59463          
+CGIDL      = 70                  EGIDL      = 2.2484
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.054               CIGC       = 0.075
+AIGSD      = 0.43                BIGSD      = 0.054               CIGSD      = 0.075
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgson_hv25_snw'          CGDO       = 'cgdon_hv25_snw'
+CGBO       = 0                   CGDL       = 'cgdln_hv25_snw'          CGSL       = 'cgsln_hv25_snw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfn_hv25_snw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5                  
+NOFF       = 2.3195              
+VOFFCV     = -0.022791 
+TVOFF      = -0.00044081598      LTVOFF     = -5.3085207e-10      WTVOFF     = 2.6757545e-10
+PTVOFF     = 3.2222711e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.46663637 
+LKT1       = 6.5250985e-08       
+WKT1       = 7.5022238e-08       
+PKT1       = -3.2243665e-14 
+KT1L       = 0                  
+KT2        = 0.023807743         
+LKT2       = -4.1055509e-08 
+WKT2       = -9.0301314e-08      
+PKT2       = 4.1847999e-14       
+UTE        = -1.8064983
+LUTE       = 4.5058726e-07       WUTE       = 7.9033623e-07       PUTE       = -4.7377612e-13
+UA1        = -8.9822497e-10      LUA1       = 3.2505924e-15       WUA1       = 3.3630817e-15
+PUA1       = -2.1378085e-21     
+UB1        = -7.7834337e-18      
+LUB1       = 2.0774383e-24 
+WUB1       = 2.299011e-24        
+PUB1       = -1.053596e-30 
+UC1        = '-1.6101782e-09+duc1n_hv25_snw' 
+LUC1       = '9.7972499e-16+dluc1n_hv25_snw' 
+WUC1       = '1.3401424e-15+dwuc1n_hv25_snw' 
+PUC1       = '-7.3810208e-22+dpuc1n_hv25_snw' 
+PRT        = 0                   AT         = 160587.12           LAT        = -0.088871641
+WAT        = -0.09103008         PAT        = 4.3881309e-08       JSS        = 1.399e-07
+JSWS       = 5e-14               JSWGS      = 9e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 2.299e-6 
+JSWD       = 2.001e-12           
+JSWGD      = 2.001e-12           
+BVD        = 14.5
+JTSSWGS    = 1.086e-08           JTSSWGD    = 1.086e-08           NJTSSWG    = 40
+XTSSWGS    = 0.29766            
+XTSSWGD    = 0.72774             
+TNJTSSWG   = 1
+VTSSWGS    = 1                   VTSSWGD    = 1                   PBS        = 0.7
+PBD        = 0.62                
+CJS        = 'cjsn_hv25_snw'           CJD        = 'cjdn_hv25_snw'
+MJS        = 0.31               
+MJD        = 0.35                
+PBSWS      = 0.48
+PBSWD      = 0.6                 
+CJSWS      = 'cjswsn_hv25_snw'         CJSWD      = 'cjswdn_hv25_snw'
+MJSWS      = 0.12               
+MJSWD      = 0.27                
+PBSWGS     = 0.6
+PBSWGD     = 0.6                 
+CJSWGS     = 'cjswgsn_hv25_snw'        CJSWGD     = 'cjswgdn_hv25_snw'
+MJSWGS     = 0.3                
+MJSWGD     = 0.32                
+TPB        = 1.95E-03 
+TCJ        = 1.71E-03            
+TPBSW      = 1.50E-03            
+TCJSW      = 9.93E-04 
+TPBSWG     = 1.75E-03            
+TCJSWG     = 1.33E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.11e-08           RSHG       = 15.06
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1
+FNOIMOD  = 1 
+NOIA     = 2.5e+41 
+NOIB     = 0.5e+026 
+NOIC     = 3e7  
+EM       = 1.8e+7  
+EF       = 1.00 
+TNOIMOD  = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = -0e-9 
+TKU0     = 0 )


**********************************************************************************************
*                                                                                            *
*                                   2.5V HVPMOS DEVICE MODELS                                *
*                                                                                            *
**********************************************************************************************

.MODEL pch_hv25_spw.1 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hv25_spw'
+LMAX       = 0.000900001         WMIN       = '1e-005-dxwp_hv25_spw'    WMAX       = 0.000900001
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6442+dvthp_hv25_spw'  
+LVTH0      = '0+dlvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.08232165+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '0+dwk2p_hv25_spw'        PK2        = '0+dpk2p_hv25_spw'
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.0004148+dcitp_hv25_spw'
+LCIT       = '0+dlcitp_hv25_spw'       WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'
+VOFF       = '-0.0865+dvoffp_hv25_spw' LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '0+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.006848+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'
+ETAB       = -0.02432            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.0116+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '0+dlu0p_hv25_spw'        WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'
+UA         = 8.334e-10           UB         = 7.75794e-19         UC         = -2.033e-12
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'      A0         = '1.1746748+da0p_hv25_spw' LA0        = '0+dla0p_hv25_spw'
+WA0        = '0+dwa0p_hv25_spw'        PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3121+dagsp_hv25_spw' 
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.02279+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = 1e-05               PDIBLCB    = 0                   DROUT      = 0.56
+PVAG       = 0.125               DELTA      = 0.005               PSCBE1     = 9.264e+08
+PSCBE2     = 1e-20               FPROUT     = 200                 PDITS      = 0
+PDITSD     = 0                   PDITSL     = 0                   RSH        = 14.55
+RSW        = 132                 RDW        = 1494                PRWG       = 0
+PRWB       = 0                   WR         = 1                  
+ALPHA0     = 4.408e-9 
+ALPHA1     = 5e-06               BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.836852e+09        
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL   = 0 
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.00164008         LTVOFF     = 0                   WTVOFF     = 0
+PTVOFF     = 0                   TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.3321398
+KT1L       = 0                  
+KT2        = -0.064              
+PKT2     = 0 
+WKT2     = 0 
+LKT2     = 0 
+UTE        = -1.11
+UA1        = 1.396008e-09        UB1        = -1.9674846e-18      LUB1       = 0
+WUB1       = 0                   PUB1       = 0                   UC1        = -7.169e-11
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.2 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_hv25_spw'
+LMAX       = '1e-005-dxlp_hv25_spw'    WMIN       = '1e-005-dxwp_hv25_spw'    WMAX       = 0.000900001
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6464583+dvthp_hv25_spw'  
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.1758676e-08+dlvthp_hv25_spw' 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.083168541+dk2p_hv25_spw' 
+LK2        = '8.1597909e-09+dlk2p_hv25_spw' 
+WK2        = '0+dwk2p_hv25_spw'        
+PK2        = '0+dpk2p_hv25_spw'        
+K3         = -2.3406
+K3B        = 2.028               W0         = 0                   DVT0       = 1.5477
+DVT1       = 0.15301             DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.22574
+MINV       = 0                   VOFFL      = -1.11e-09           DVTP0      = 0
+DVTP1      = 0                   LPE0       = 0                   LPEB       = 0
+XJ         = 1.6e-06             NGATE      = 1.842e+20           NDEP       = 7.81e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00039357392+dcitp_hv25_spw'
+LCIT       = '2.0451328e-10+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'      
+VOFF       = '-0.085975522+dvoffp_hv25_spw' 
+LVOFF      = '-5.053352e-09+dlvoffp_hv25_spw' 
+WVOFF      = '0+dwvoffp_hv25_spw'      
+PVOFF      = '0+dpvoffp_hv25_spw'      
+NFACTOR    = '0.5+dnfactorp_hv25_spw'
+LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'
+ETA0       = '0.006848+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'
+ETAB       = -0.02432            UD         = 0                   LUD        = 0
+WUD        = 0                   PUD        = 0                   U0         = '0.011675347+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '-7.2596536e-10+dlu0p_hv25_spw'
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'        UA         = 8.2448251e-10
+LUA        = 8.5919986e-17      
+UB         = 8.2361677e-19       
+PUB      = 0 
+WUB      = 0 
+LUB        = -4.6077234e-25 
+UC         = -4.9586313e-12      LUC        = 2.8188457e-17       VSAT       = '100090+dvsatp_hv25_spw'
+KVSAT    = 0.0  
+LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'
+A0         = '1.2235104+da0p_hv25_spw' 
+LA0        = '-4.7053122e-07+dla0p_hv25_spw' 
+WA0        = '0+dwa0p_hv25_spw'        
+PA0        = '0+dpa0p_hv25_spw'        
+AGS        = '0.33277669+dagsp_hv25_spw' 
+LAGS       = '-1.9921988e-07+dlagsp_hv25_spw' 
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = '-0.019854216+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA      = '-2.828628e-08+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.098675386+dpclmp_hv25_spw'
+LPCLM      = '1.2762652e-08+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = 9.9990511e-06       LPDIBLC2   = 9.1423011e-15       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8365868e+09       
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL     = 2.55509             
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0017957012       LTVOFF     = 1.4994105e-09
+WTVOFF     = 0                   PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.33251998         LKT1       = 3.6630623e-09       KT1L       = 0
+KT2        = -0.063905113        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = -9.1423e-10         
+UTE        = -1.098329
+LUTE       = -1.124503e-07       UA1        = 1.438989e-09        LUA1       = -4.1412173e-16
+UB1        = -2.0143922e-18      LUB1       = 4.5195495e-25       WUB1       = 0
+PUB1       = 0                   UC1        = -7.7851446e-11      LUC1       = 5.9365532e-17
+PRT        = 0                   AT         = 255674.15           LAT        = -0.22810042
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.3 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-dxlp_hv25_spw'  WMIN       = '1e-005-dxwp_hv25_spw'    WMAX       = 0.000900001
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.61303698+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-6.1481289e-09+dlvthp_hv25_spw' 
+WVTH0      = '0+dwvthp_hv25_spw'       
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415
+K2         = '-0.055422101+dk2p_hv25_spw' 
+LK2        = '-1.5008486e-08+dlk2p_hv25_spw' 
+WK2        = '0+dwk2p_hv25_spw'        
+PK2        = '0+dpk2p_hv25_spw'        
+K3         = -2.3406
+K3B        = 2.028               W0         = 0                   DVT0       = 1.5477
+DVT1       = 0.15301             DVT2       = 0                   DVT0W      = 0
+DVT1W      = 0                   DVT2W      = 0                   DSUB       = 0.22574
+MINV       = 0                   VOFFL      = -1.11e-09           DVTP0      = 0
+DVTP1      = 0                   LPE0       = 0                   LPEB       = 0
+XJ         = 1.6e-06             NGATE      = 1.842e+20           NDEP       = 7.81e+17
+NSD        = 1e+20               PHIN       = 0                   CDSC       = 0
+CDSCB      = 0                   CDSCD      = 0                   CIT        = '0.00068882917+dcitp_hv25_spw'
+LCIT       = '-4.2024854e-11+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'      
+VOFF       = '-0.10750902+dvoffp_hv25_spw' 
+LVOFF      = '1.292712e-08+dlvoffp_hv25_spw' 
+WVOFF      = '0+dwvoffp_hv25_spw'      
+PVOFF      = '0+dpvoffp_hv25_spw'      
+NFACTOR    = '0.5+dnfactorp_hv25_spw'
+LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'
+ETA0       = '0.0023308372+deta0p_hv25_spw'
+LETA0      = '3.7718309e-09+dleta0p_hv25_spw'
+WETA0      = '0+dweta0p_hv25_spw'      PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02432
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.0099700819+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '6.9793076e-10+dlu0p_hv25_spw'
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'       
+UA         = 3.2122981e-10 
+PUA      = 0 
+WUA      = 0 
+LUA        = 5.0613599e-16       
+UB         = 6.9157942e-19       
+PUB      = 0 
+WUB      = 0 
+LUB        = -3.5052116e-25 
+UC         = 5.4042917e-11       LUC        = -2.1077835e-17     
+VSAT       = '100125.15+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '-2.9351401e-05+dlvsatp_hv25_spw' 
+WVSAT      = '0+dwvsatp_hv25_spw'      
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '0.87352452+da0p_hv25_spw' 
+LA0        = '-1.7829298e-07+dla0p_hv25_spw' 
+WA0        = '0+dwa0p_hv25_spw'        
+PA0        = '0+dpa0p_hv25_spw'        
+AGS        = '-2.4069189+dagsp_hv25_spw' 
+LAGS       = '2.0884259e-06+dlagsp_hv25_spw' 
+WAGS       = '0+dwagsp_hv25_spw'       
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0
+A2         = 0.5                 B0         = 0                   B1         = 0
+KETA       = '-0.074408394+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+WKETA    = '0+dwketap_hv25_spw'
+LKETA      = '1.7266459e-08+dlketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.11820286+dpclmp_hv25_spw'
+LPCLM      = '-3.5427858e-09+dlpclmp_hv25_spw'
+WPCLM      = '0+dwpclmp_hv25_spw'      PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0
+PDIBLC2    = -0.00050816109      
+PPDIBLC2 = 0 
+WPDIBLC2 = 0 
+LPDIBLC2   = 4.3267286e-10       
+PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8385522e+09       
+PBGIDL   = 0 
+WBGIDL   = 0 
+LBGIDL     = 0.914016            
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = 0.0009629125        LTVOFF     = -8.0403194e-10
+WTVOFF     = 0                   PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.32316898         
+PKT1     = 0 
+WKT1     = 0 
+LKT1       = -4.1450232e-09      
+KT1L       = 0
+KT2        = -0.068916663        
+PKT2     = 0 
+WKT2     = 0 
+LKT2       = 3.2704163e-09       
+UTE        = -1.2067583
+LUTE       = -2.1911792e-08      UA1        = 1.3112044e-09       LUA1       = -3.0742157e-16
+UB1        = -2.3619412e-18      
+PUB1     = 0 
+WUB1     = 0 
+LUB1       = 7.4215833e-25       
+UC1        = -2.9164208e-11
+LUC1       = 1.8711689e-17       PRT        = 0                  
+AT         = -1637.4997 
+LAT        = -0.013245188        
+WAT        = 0                   
+PAT        = 0 
+JSS        = 1.13e-07            JSWS       = 1e-14               JSWGS      = 5e-14
+NJS        = 1.00               
+NJD        = 1.007               
+IJTHSFWD   = 0.01
+IJTHDFWD   = 0.01                IJTHSREV   = 0.01                IJTHDREV   = 0.01
+BVS        = 9                   XJBVS      = 1                   XJBVD      = 1
+JSD        = 3.060E-06           
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12 
+BVD        = 16.8                
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10
+NJTSSWG    = 26.124              XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470 
+TNJTSSWG   = 0.14981             VTSSWGS    = 20                  VTSSWGD    = 20
+PBS        = 0.7                
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'
+MJS        = 0.31                PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'
+MJSWS      = 0.082               PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'
+MJSWGS     = 0.35                CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29 
+PBSWD      = 0.4                 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18 
+PBSWGD     = 0.8                 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62 
+TPB        = 1.35E-03            
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04 
+TCJSW      = 3.00E-04            
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03 
+XTIS       = 3                   XTID       = 3                   DMCG       = 1.245e-07
+DMCI       = 3.05e-07            DMDG       = 0                   DMCGT      = 0
+DWJ        = 0                   XGW        = 0                   XGL        = -2.3e-08
+RSHG       = 14.93               GBMIN      = 1e-12               RBPB       = 50
+RBPD       = 50                  RBPS       = 50                  RBDB       = 50
+RBSB       = 50                  NGCON      = 1                  
+FNOIMOD    = 1 
+NOIA       = 1.5e+41             
+NOIB       = 0.5e+025            
+NOIC       = 1e7     
+EM         = 1.9e+7              
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.4 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hv25_spw'
+LMAX       = 0.000900001         WMIN       = '1e-006-dxwp_hv25_spw'    WMAX       = '1e-005-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.64345035+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '0+dlvthp_hv25_spw'       
+WVTH0      = '-7.5018037e-09+dwvthp_hv25_spw' 
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415             K2         = '-0.082607151+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '2.8570113e-09+dwk2p_hv25_spw'
+PK2        = '0+dpk2p_hv25_spw'        K3         = -2.3406             K3B        = 2.028
+W0         = 0                   DVT0       = 1.5477              DVT1       = 0.15301
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.22574             MINV       = 0
+VOFFL      = -1.11e-09           DVTP0      = 0                   DVTP1      = 0
+LPE0       = 0                   LPEB       = 0                   XJ         = 1.6e-06
+NGATE      = 1.842e+20           NDEP       = 7.81e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '0.00046065207+dcitp_hv25_spw'
+LCIT       = '0+dlcitp_hv25_spw'       WCIT       = '-4.5884163e-10+dwcitp_hv25_spw'
+PCIT       = '0+dpcitp_hv25_spw'       VOFF       = '-0.085646288+dvoffp_hv25_spw'
+LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '-8.5430982e-09+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0066149354+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '2.332277e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.024623219        WETAB      = 3.0343114e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011567552+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '0+dlu0p_hv25_spw'        WU0        = '3.2470491e-10+dwu0p_hv25_spw'
+PU0        = '0+dpu0p_hv25_spw'        UA         = 8.6781702e-10       WUA        = -3.4441114e-16
+UB         = 7.5548315e-19       WUB        = 2.0325072e-25       UC         = -1.4744507e-12
+WUC        = -5.5894032e-18      VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'
+KVSAT    = 0.0  
+WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'      A0         = '1.1735196+da0p_hv25_spw'
+LA0        = '0+dla0p_hv25_spw'        WA0        = '1.1560816e-08+dwa0p_hv25_spw'
+PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3103881+dagsp_hv25_spw'  
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '1.7130983e-08+dwagsp_hv25_spw' 
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0                   A2         = 0.5
+B0         = 0                   B1         = 0
+KETA       = '-0.023852944+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+WKETA      = '1.0636885e-08+dwketap_hv25_spw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'      WPCLM      = '0+dwpclmp_hv25_spw'
+PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0                   PDIBLC2    = 1e-05
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.125
+DELTA      = 0.005               PSCBE1     = 9.264e+08           PSCBE2     = 1e-20
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55               RSW        = 132
+RDW        = 1494                PRWG       = 0                   PRWB       = 0
+WR         = 1                  
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06
+BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8394845e+09       
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -26.343354          
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0014210886       LTVOFF     = 0
+WTVOFF     = -2.1914473e-09      PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.32992071         WKT1       = -2.2206419e-08      KT1L       = 0
+KT2        = -0.064129743        
+PKT2     = 0 
+LKT2     = 0 
+WKT2       = 1.298338e-09        
+UTE        = -1.1084336
+WUTE       = -1.567541e-08       UA1        = 1.3822259e-09       WUA1       = 1.379171e-16
+UB1        = -1.9969204e-18      LUB1       = 0                   WUB1       = 2.9456425e-25
+PUB1       = 0                  
+UC1        = -7.7090318e-11      
+PUC1     = 0 
+LUC1     = 0 
+WUC1       = 5.404097e-17  
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.5 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_hv25_spw'
+LMAX       = '1e-005-dxlp_hv25_spw'    WMIN       = '1e-006-dxwp_hv25_spw'    WMAX       = '1e-005-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.64575005+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.2157617e-08+dlvthp_hv25_spw' 
+WVTH0      = '-7.0874606e-09+dwvthp_hv25_spw' 
+PVTH0      = '-3.992188e-15+dpvthp_hv25_spw'  
+K1         = 0.77415            
+K2         = '-0.083597915+dk2p_hv25_spw' 
+LK2        = '9.546009e-09+dlk2p_hv25_spw' 
+WK2        = '4.2967504e-09+dwk2p_hv25_spw' 
+PK2        = '-1.3871885e-14+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00044123614+dcitp_hv25_spw'
+LCIT       = '1.8707246e-10+dlcitp_hv25_spw'
+WCIT       = '-4.7695583e-10+dwcitp_hv25_spw'
+PCIT       = '1.7453027e-16+dpcitp_hv25_spw'
+VOFF       = '-0.085078901+dvoffp_hv25_spw' 
+LVOFF      = '-5.4667641e-09+dlvoffp_hv25_spw' 
+WVOFF      = '-8.9724718e-09+dwvoffp_hv25_spw' 
+PVOFF      = '4.137011e-15+dpvoffp_hv25_spw'  
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0066149354+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '2.332277e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.024623219        WETAB      = 3.0343114e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011661877+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '-9.0882215e-10+dlu0p_hv25_spw'
+WU0        = '1.3478816e-10+dwu0p_hv25_spw'
+PU0        = '1.829848e-15+dpu0p_hv25_spw'
+UA         = 8.6340336e-10       
+LUA        = 4.2525664e-17       
+WUA        = -3.8948089e-16 
+PUA        = 4.3424698e-22       
+UB         = 8.0349339e-19       
+LUB        = -4.6257876e-25 
+WUB        = 2.0137456e-25       
+PUB        = 1.8076838e-32       
+UC         = -4.4689633e-12
+LUC        = 2.8852129e-17       WUC        = -4.9001076e-18      PUC        = -6.6413631e-24
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '1.2235888+da0p_hv25_spw' 
+LA0        = '-4.8241738e-07+dla0p_hv25_spw' 
+WA0        = '-7.84261e-10+dwa0p_hv25_spw'  
+PA0        = '1.1894482e-13+dpa0p_hv25_spw' 
+AGS        = '0.33792906+dagsp_hv25_spw' 
+LAGS       = '-2.653572e-07+dlagsp_hv25_spw'  
+WAGS       = '-5.1559855e-08+dwagsp_hv25_spw' 
+PAGS       = '6.618362e-13+dpagsp_hv25_spw'  
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.020950178+dketap_hv25_spw'
+LKETA      = '-2.7968151e-08+dlketap_hv25_spw'
+WKETA      = '1.0967297e-08+dwketap_hv25_spw'
+PKETA      = '-3.1835141e-15+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.098633344+dpclmp_hv25_spw'
+LPCLM      = '1.316773e-08+dlpclmp_hv25_spw'
+WPCLM      = '4.207168e-10+dwpclmp_hv25_spw'
+PPCLM      = '-4.0536063e-15+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = 1.0002555e-05       LPDIBLC2   = -2.4614122e-14
+WPDIBLC2   = -3.5059733e-14      PPDIBLC2   = 3.3780053e-19       PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8391677e+09       
+LBGIDL     = 3.051889            
+WBGIDL     = -25.827376 
+PBGIDL     = -4.971461e-06       
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.0015665472       LTVOFF     = 1.4014942e-09       WTVOFF     = -2.2931441e-09
+PTVOFF     = 9.7984913e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.33008289
+LKT1       = 1.562568e-09        WKT1       = -2.4388012e-08      PKT1       = 2.1019646e-14
+KT1L       = 0                  
+KT2        = -0.064096056        
+LKT2       = -3.245759e-10  
+WKT2       = 1.910758e-09        
+PKT2       = -5.900666e-15       
+UTE        = -1.0976437
+LUTE       = -1.0396005e-07      WUTE       = -6.8573555e-09      PUTE       = -8.4961951e-14
+UA1        = 1.4183791e-09       LUA1       = -3.4833558e-16      WUA1       = 2.0624321e-16
+PUA1       = -6.5832208e-22      UB1        = -2.0375734e-18      LUB1       = 3.9169107e-25
+WUB1       = 2.3197362e-25       PUB1       = 6.0306067e-31      
+UC1        = -8.3567717e-11 
+LUC1       = 6.2409748e-17       
+WUC1       = 5.7202725e-17       
+PUC1       = -3.046346e-23  
+PRT        = 0                   AT         = 255562.67           LAT        = -0.22702635
+WAT        = 0.0011155412        PAT        = -1.0748202e-08      JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.6 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-dxlp_hv25_spw'  WMIN       = '1e-006-dxwp_hv25_spw'    WMAX       = '1e-005-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.61206792+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-5.9669626e-09+dlvthp_hv25_spw' 
+WVTH0      = '-9.6973494e-09+dwvthp_hv25_spw' 
+PVTH0      = '-1.8129302e-15+dpvthp_hv25_spw' 
+K1         = 0.77415            
+K2         = '-0.053177777+dk2p_hv25_spw' 
+LK2        = '-1.5854807e-08+dlk2p_hv25_spw' 
+WK2        = '-2.2458953e-08+dwk2p_hv25_spw' 
+PK2        = '8.4691269e-15+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00071983749+dcitp_hv25_spw'
+LCIT       = '-4.5559673e-11+dlcitp_hv25_spw'
+WCIT       = '-3.1030033e-10+dwcitp_hv25_spw'
+PCIT       = '3.5372933e-17+dpcitp_hv25_spw'
+VOFF       = '-0.10705435+dvoffp_hv25_spw' 
+LVOFF      = '1.2882738e-08+dlvoffp_hv25_spw' 
+WVOFF      = '-4.549857e-09+dwvoffp_hv25_spw' 
+PVOFF      = '4.441281e-16+dpvoffp_hv25_spw'   
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0018533543+deta0p_hv25_spw'
+LETA0      = '3.9759202e-09+dleta0p_hv25_spw'
+WETA0      = '4.778171e-09+dweta0p_hv25_spw'
+PETA0      = '-2.0423215e-15+dpeta0p_hv25_spw'
+ETAB       = -0.024623219        WETAB      = 3.0343114e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.0097261642+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '7.0749829e-10+dlu0p_hv25_spw'
+WU0        = '2.4408843e-09+dwu0p_hv25_spw'
+PU0        = '-9.5742337e-17+dpu0p_hv25_spw'
+UA         = 3.0814582e-10       
+LUA        = 5.061657e-16        
+WUA        = 1.3093138e-16 
+PUA        = -2.97265e-25        
+UB         = 6.5583563e-19       
+LUB        = -3.3928452e-25 
+WUB        = 3.5768821e-25       
+PUB        = -1.1244506e-31      
+UC         = 5.5202067e-11
+LUC        = -2.0973181e-17      WUC        = -1.1599617e-17      PUC        = -1.0472732e-24
+VSAT       = '100125.17+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '-2.93663e-05+dlvsatp_hv25_spw'   
+WVSAT      = '-1.785e-07+dwvsatp_hv25_spw'    
+PVSAT      = '1.492e-13+dpvsatp_hv25_spw'     
+A0         = '0.88566989+da0p_hv25_spw' 
+LA0        = '-2.0025508e-07+dla0p_hv25_spw' 
+WA0        = '-1.2153872e-07+dwa0p_hv25_spw' 
+PA0        = '2.197748e-13+dpa0p_hv25_spw'  
+AGS        = '-2.7332125+dagsp_hv25_spw' 
+LAGS       = '2.299046e-06+dlagsp_hv25_spw'  
+WAGS       = '3.2652199e-06+dwagsp_hv25_spw' 
+PAGS       = '-2.107675e-12+dpagsp_hv25_spw'  
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.075485777+dketap_hv25_spw'
+LKETA      = '1.7569074e-08+dlketap_hv25_spw'
+WKETA      = '1.0781372e-08+dwketap_hv25_spw'
+PKETA      = '-3.0282673e-15+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.11907437+dpclmp_hv25_spw'
+LPCLM      = '-3.9005241e-09+dlpclmp_hv25_spw'
+WPCLM      = '-8.7211918e-09+dwpclmp_hv25_spw'
+PPCLM      = '3.5798873e-15+dppclmp_hv25_spw'
+PDIBLC1    = 0                  
+PDIBLC2    = -0.00049892196      
+LPDIBLC2   = 4.2492736e-10 
+WPDIBLC2   = -9.2455896e-11      
+PPDIBLC2   = 7.7509197e-17       
+PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8413607e+09       
+LBGIDL     = 1.220821            
+WBGIDL     = -28.104337 
+PBGIDL     = -3.070195e-06       
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = 0.00105037          LTVOFF     = -7.8363171e-10      WTVOFF     = -8.7518704e-10
+PTVOFF     = -2.0414503e-16      TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                  
+KT1        = -0.32447187 
+LKT1       = -3.1226367e-09      
+WKT1       = 1.3037938e-08       
+PKT1       = -1.0231022e-14 
+KT1L       = 0                  
+KT2        = -0.068293082        
+LKT2       = 3.1799411e-09 
+WKT2       = -6.24021e-09        
+PKT2       = 9.053923e-16        
+UTE        = -1.1916543
+LUTE       = -2.5461248e-08      WUTE       = -1.511464e-07       PUTE       = 3.5519405e-14
+UA1        = 1.4717343e-09       LUA1       = -3.9288719e-16      WUA1       = -1.6064233e-15
+PUA1       = 8.5525444e-22      
+UB1        = -2.6267678e-18      
+LUB1       = 8.8366834e-25 
+WUB1       = 2.6501189e-24       
+PUB1       = -1.4160907e-30      
+UC1        = -2.8459174e-11 
+LUC1       = 1.6394114e-17       
+WUC1       = -7.05528e-18        
+PUC1       = 2.3191974e-23 
+PRT        = 0                  
+AT         = 260.41626           
+LAT        = -0.013848961 
+WAT        = -0.01899244         
+PAT        = 6.041959e-09        
+JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.7 PMOS	(	LEVEL      = 54                  LMIN       = '1e-005-dxlp_hv25_spw'
+LMAX       = 0.000900001         WMIN       = 6e-07               WMAX       = '1e-006-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.6505965+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '0+dlvthp_hv25_spw'       
+WVTH0      = '-3.056245e-10+dwvthp_hv25_spw' 
+PVTH0      = '0+dpvthp_hv25_spw'       
+K1         = 0.77415             K2         = '-0.08095365+dk2p_hv25_spw'
+LK2        = '0+dlk2p_hv25_spw'        WK2        = '1.1919356e-09+dwk2p_hv25_spw'
+PK2        = '0+dpk2p_hv25_spw'        K3         = -2.3406             K3B        = 2.028
+W0         = 0                   DVT0       = 1.5477              DVT1       = 0.15301
+DVT2       = 0                   DVT0W      = 0                   DVT1W      = 0
+DVT2W      = 0                   DSUB       = 0.22574             MINV       = 0
+VOFFL      = -1.11e-09           DVTP0      = 0                   DVTP1      = 0
+LPE0       = 0                   LPEB       = 0                   XJ         = 1.6e-06
+NGATE      = 1.842e+20           NDEP       = 7.81e+17            NSD        = 1e+20
+PHIN       = 0                   CDSC       = 0                   CDSCB      = 0
+CDSCD      = 0                   CIT        = '5e-06+dcitp_hv25_spw'    LCIT       = '0+dlcitp_hv25_spw'
+WCIT       = '0+dwcitp_hv25_spw'       PCIT       = '0+dpcitp_hv25_spw'       VOFF       = '-0.09840935+dvoffp_hv25_spw'
+LVOFF      = '0+dlvoffp_hv25_spw'      WVOFF      = '4.3093055e-09+dwvoffp_hv25_spw'
+PVOFF      = '0+dpvoffp_hv25_spw'      NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'
+WNFACTOR   = '0+dwnfactorp_hv25_spw'   PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0078338475+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '1.1048326e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02777105         WETAB      = 6.2041774e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.01189+du0p_hv25_spw'   LU0        = '0+dlu0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+WU0        = '0+dwu0p_hv25_spw'        PU0        = '0+dpu0p_hv25_spw'        UA         = 7.3142125e-10
+WUA        = -2.070606e-16       UB         = 9.3050526e-19       WUB        = 2.7003453e-26
+UC         = -4.9627175e-12      WUC        = -2.0767185e-18      VSAT       = '100090+dvsatp_hv25_spw'
+KVSAT    = 0.0  
+LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'      PVSAT      = '0+dpvsatp_hv25_spw'
+A0         = '1.1243+da0p_hv25_spw'    LA0        = '0+dla0p_hv25_spw'        WA0        = '6.11249e-08+dwa0p_hv25_spw'
+PA0        = '0+dpa0p_hv25_spw'       
+AGS        = '0.3246685+dagsp_hv25_spw' 
+LAGS       = '0+dlagsp_hv25_spw'       
+WAGS       = '2.75062e-09+dwagsp_hv25_spw'    
+PAGS       = '0+dpagsp_hv25_spw'       
+A1         = 0                   A2         = 0.5
+B0         = 0                   B1         = 0
+KETA       = '-0.01842522+dketap_hv25_spw'
+PKETA    = '0+dpketap_hv25_spw'
+LKETA    = '0+dlketap_hv25_spw'
+WKETA      = '5.1711665e-09+dwketap_hv25_spw'
+DWG        = 0                   DWB        = 0
+PCLM       = '0.1+dpclmp_hv25_spw'     LPCLM      = '0+dlpclmp_hv25_spw'      WPCLM      = '0+dwpclmp_hv25_spw'
+PPCLM      = '0+dppclmp_hv25_spw'      PDIBLC1    = 0                   PDIBLC2    = 1e-05
+PDIBLCB    = 0                   DROUT      = 0.56                PVAG       = 0.125
+DELTA      = 0.005               PSCBE1     = 9.264e+08           PSCBE2     = 1e-20
+FPROUT     = 200                 PDITS      = 0                   PDITSD     = 0
+PDITSL     = 0                   RSH        = 14.55               RSW        = 132
+RDW        = 1494                PRWG       = 0                   PRWB       = 0
+WR         = 1                  
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06
+BETA0      = 29.15               AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8487188e+09       
+PBGIDL   = 0 
+LBGIDL   = 0 
+WBGIDL     = -35.642327          
+CGIDL      = 52
+EGIDL      = 1.8302              AIGBACC    = 0.43                BIGBACC    = 0.054
+CIGBACC    = 0.075               NIGBACC    = 1                   AIGBINV    = 0.35
+BIGBINV    = 0.03                CIGBINV    = 0.006               EIGBINV    = 1.1
+NIGBINV    = 3                   AIGC       = 0.43                BIGC       = 0.024
+CIGC       = 0.03                AIGSD      = 0.43                BIGSD      = 0.024
+CIGSD      = 0.03                NIGC       = 1                   POXEDGE    = 1
+PIGCD      = 1                   NTOX       = 1                   XRCRG1     = 12
+XRCRG2     = 1                   VFBSDOFF   = 0.1                 LVFBSDOFF  = 0
+WVFBSDOFF  = 0                   PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'
+CGDO       = 'cgdop_hv25_spw'          CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'
+CGSL       = 'cgslp_hv25_spw'          CLC        = 1e-07               CLE        = 0.6
+CF         = 'cfp_hv25_spw'            CKAPPAS    = 0.6                 CKAPPAD    = 0.6
+ACDE       = 0.4                 MOIN       = 5.512              
+NOFF       = 3.055 
+VOFFCV     = 0.066645            TVOFF      = -0.0077185505       LTVOFF     = 0
+WTVOFF     = 4.1500969e-09       PTVOFF     = 0                   TVFBSDOFF  = 0.01015
+LTVFBSDOFF = 0                   WTVFBSDOFF = 0                   PTVFBSDOFF = 0
+KT1        = -0.43539899         WKT1       = 8.4010209e-08       KT1L       = 0
+KT2        = -0.066840985        
+PKT2     = 0 
+LKT2     = 0 
+WKT2       = 4.028559e-09        
+UTE        = -1.04509
+WUTE       = -7.946237e-08       UA1        = 1.6192357e-09       WUA1       = -1.0075176e-16
+UB1        = -1.2508264e-18      LUB1       = 0                   WUB1       = -4.567525e-25
+PUB1       = 0                  
+UC1        = -4.160162e-11       
+PUC1     = 0 
+LUC1     = 0 
+WUC1       = 1.830385e-17   
+PRT        = 0                   AT         = 232000              LAT        = 0
+WAT        = 0                   PAT        = 0                   JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.8 PMOS	(	LEVEL      = 54                  LMIN       = '1.2e-006-dxlp_hv25_spw'
+LMAX       = '1e-005-dxlp_hv25_spw'    WMIN       = 6e-07               WMAX       = '1e-006-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.65367204+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '2.963285e-08+dlvthp_hv25_spw'  
+WVTH0      = '8.8999034e-10+dwvthp_hv25_spw'  
+PVTH0      = '-1.1519749e-14+dpvthp_hv25_spw' 
+K1         = 0.77415             K2         = '-0.080741289+dk2p_hv25_spw'
+LK2        = '-2.0461011e-09+dlk2p_hv25_spw'
+WK2        = '1.4201276e-09+dwk2p_hv25_spw'
+PK2        = '-2.1986302e-15+dpk2p_hv25_spw'
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '-5.6522539e-05+dcitp_hv25_spw'
+LCIT       = '5.9276966e-10+dlcitp_hv25_spw'
+WCIT       = '2.4287163e-11+dwcitp_hv25_spw'
+PCIT       = '-2.3400681e-16+dpcitp_hv25_spw'
+VOFF       = '-0.10051086+dvoffp_hv25_spw'  
+LVOFF      = '2.0248044e-08+dlvoffp_hv25_spw'  
+WVOFF      = '6.5675098e-09+dwvoffp_hv25_spw' 
+PVOFF      = '-2.1757799e-14+dpvoffp_hv25_spw' 
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0078338475+deta0p_hv25_spw'
+LETA0      = '0+dleta0p_hv25_spw'      WETA0      = '1.1048326e-09+dweta0p_hv25_spw'
+PETA0      = '0+dpeta0p_hv25_spw'      ETAB       = -0.02777105         WETAB      = 6.2041774e-09
+UD         = 0                   LUD        = 0                   WUD        = 0
+PUD        = 0                   U0         = '0.011841299+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '4.6923921e-10+dlu0p_hv25_spw'
+WU0        = '-4.5888963e-11+dwu0p_hv25_spw'
+PU0        = '4.4214016e-16+dpu0p_hv25_spw'
+UA         = 6.9516704e-10       
+LUA        = 3.4930927e-16       
+WUA        = -2.2006692e-16 
+PUA        = 1.2531589e-22       
+UB         = 9.6668554e-19       
+LUB        = -3.4859701e-25 
+WUB        = 3.7040068e-26       
+PUB        = -9.6702792e-32      
+UC         = -1.0203788e-11
+LUC        = 5.0497711e-17       WUC        = 8.7486055e-19       PUC        = -2.8438464e-23
+VSAT       = '100090+dvsatp_hv25_spw'  LVSAT      = '0+dlvsatp_hv25_spw'      WVSAT      = '0+dwvsatp_hv25_spw'
+KVSAT    = 0.0  
+PVSAT      = '0+dpvsatp_hv25_spw'     
+A0         = '1.1487502+da0p_hv25_spw' 
+LA0        = '-2.3557704e-07+dla0p_hv25_spw' 
+WA0        = '7.4578287e-08+dwa0p_hv25_spw' 
+PA0        = '-1.2962338e-13+dpa0p_hv25_spw' 
+AGS        = '0.26893051+dagsp_hv25_spw' 
+LAGS       = '5.370355e-07+dlagsp_hv25_spw'  
+WAGS       = '1.792169e-08+dwagsp_hv25_spw'   
+PAGS       = '-1.4617325e-13+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.013740616+dketap_hv25_spw'
+LKETA      = '-4.5136162e-08+dlketap_hv25_spw'
+WKETA      = '3.7072669e-09+dwketap_hv25_spw'
+PKETA      = '1.4104673e-14+dpketap_hv25_spw'
+DWG        = 0
+DWB        = 0                   PCLM       = '0.097611236+dpclmp_hv25_spw'
+LPCLM      = '2.3015743e-08+dlpclmp_hv25_spw'
+WPCLM      = '1.4499799e-09+dwpclmp_hv25_spw'
+PPCLM      = '-1.3970556e-14+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = 9.918782e-06        LPDIBLC2   = 7.8253527e-13
+WPDIBLC2   = 4.9299316e-14       PPDIBLC2   = -4.7499891e-19      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8498584e+09       
+LBGIDL     = -10.979692          
+WBGIDL     = -36.592851 
+PBGIDL     = 9.158342e-06        
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.008048839        LTVOFF     = 3.1823294e-09       WTVOFF     = 4.2345237e-09
+PTVOFF     = -8.13452e-16        TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.43957731
+LKT1       = 4.0258064e-08       WKT1       = 8.5872868e-08       PKT1       = -1.7946719e-14
+KT1L       = 0                  
+KT2        = -0.066003516        
+LKT2       = -8.069012e-09 
+WKT2       = 3.831571e-09        
+PKT2       = 1.89798e-15         
+UTE        = -1.0203598
+LUTE       = -2.382758e-07       WUTE       = -8.4682298e-08      PUTE       = 5.0294002e-14
+UA1        = 1.7590987e-09       LUA1       = -1.3475799e-15      WUA1       = -1.3686146e-16
+PUA1       = 3.4791691e-22       UB1        = -1.3906555e-18      LUB1       = 1.3472542e-24
+WUB1       = -4.1947264e-25      PUB1       = -3.5919144e-31     
+UC1        = -4.089859e-11 
+LUC1       = -6.77362e-18        
+WUC1       = 1.423492e-17        
+PUC1       = 3.920417e-23  
+PRT        = 0                   AT         = 255662.53           LAT        = -0.22798842
+WAT        = 0.0010149903        PAT        = -9.779388e-09       JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.MODEL pch_hv25_spw.9 PMOS	(	LEVEL      = 54                  LMIN       = 6e-07
+LMAX       = '1.2e-006-dxlp_hv25_spw'  WMIN       = 6e-07               WMAX       = '1e-006-dxwp_hv25_spw'
+XL         = '-1.5e-08+dxlp_hv25_spw'  XW         = '7e-09+dxwp_hv25_spw'     VERSION    = 4.5
+BINUNIT    = 2                   PARAMCHK   = 1                   MOBMOD     = 0
+CAPMOD     = 2                   IGCMOD     = 0                   IGBMOD     = 0
+DIOMOD     = 1                   RDSMOD     = 1                   RBODYMOD   = 0
+RGEOMOD    = 1                   RGATEMOD   = '1*rgflag_hv25_snw_spw'       PERMOD     = 1
+ACNQSMOD   = 0                   TRNQSMOD   = 0                   TEMPMOD    = 0
+TNOM       = 25                  TOXE       = 'toxp_hv25_spw'           TOXM       = 5.9e-09
+DTOX       = 4.1477e-10          EPSROX     = 3.9                 WINT       = 0
+LINT       = 1.75e-07            LL         = 0                   WL         = 0
+LLN        = 1                   WLN        = 1                   LW         = 0
+WW         = 0                   LWN        = 1                   WWN        = 1
+LWL        = 0                   WWL        = 0                   LLC        = 0
+WLC        = 0                   LWC        = 0                   WWC        = 0
+LWLC       = 0                   WWLC       = 0                   DLC        = 'dlcp_hv25_spw'
+DWC        = 0                   XPART      = 1                   TOXREF     = 3e-09
+DLCIG      = 2.5e-09            
+VTH0       = '-0.60744212+dvthp_hv25_spw' 
+KVTH0    = 5.5e-009 
+PKVTH0   = 0 
+WKVTH0   = 0.6e-006 
+LKVTH0   = -0.6e-007 
+LVTH0      = '-8.9691367e-09+dlvthp_hv25_spw' 
+WVTH0      = '-1.4355527e-08+dwvthp_hv25_spw' 
+PVTH0      = '1.2102586e-15+dpvthp_hv25_spw'  
+K1         = 0.77415            
+K2         = '-0.071926411+dk2p_hv25_spw' 
+LK2        = '-9.4065238e-09+dlk2p_hv25_spw' 
+WK2        = '-3.5790776e-09+dwk2p_hv25_spw' 
+PK2        = '1.9757061e-15+dpk2p_hv25_spw' 
+K3         = -2.3406             K3B        = 2.028               W0         = 0
+DVT0       = 1.5477              DVT1       = 0.15301             DVT2       = 0
+DVT0W      = 0                   DVT1W      = 0                   DVT2W      = 0
+DSUB       = 0.22574             MINV       = 0                   VOFFL      = -1.11e-09
+DVTP0      = 0                   DVTP1      = 0                   LPE0       = 0
+LPEB       = 0                   XJ         = 1.6e-06             NGATE      = 1.842e+20
+NDEP       = 7.81e+17            NSD        = 1e+20               PHIN       = 0
+CDSC       = 0                   CDSCB      = 0                   CDSCD      = 0
+CIT        = '0.00069636579+dcitp_hv25_spw'
+LCIT       = '-3.5892087e-11+dlcitp_hv25_spw'
+WCIT       = '-2.8666432e-10+dwcitp_hv25_spw'
+PCIT       = '2.5637674e-17+dpcitp_hv25_spw'
+VOFF       = '-0.085611855+dvoffp_hv25_spw' 
+LVOFF      = '7.80737e-09+dlvoffp_hv25_spw'   
+WVOFF      = '-2.6142459e-08+dwvoffp_hv25_spw' 
+PVOFF      = '5.5550242e-15+dpvoffp_hv25_spw'  
+NFACTOR    = '0.5+dnfactorp_hv25_spw'  LNFACTOR   = '0+dlnfactorp_hv25_spw'   WNFACTOR   = '0+dwnfactorp_hv25_spw'
+PNFACTOR   = '0+dpnfactorp_hv25_spw'   ETA0       = '0.0071615325+deta0p_hv25_spw'
+LETA0      = '5.6138303e-10+dleta0p_hv25_spw'
+WETA0      = '-5.6716436e-10+dweta0p_hv25_spw'
+PETA0      = '1.3961174e-15+dpeta0p_hv25_spw'
+ETAB       = -0.02777105         WETAB      = 6.2041774e-09       UD         = 0
+LUD        = 0                   WUD        = 0                   PUD        = 0
+U0         = '0.010301257+du0p_hv25_spw'
+KU0      = 4e-009 
+PKU0     = 0 
+WKU0     = 0.15e-006 
+LKU0     = -4.70e-007  
+LU0        = '1.755174e-09+dlu0p_hv25_spw'
+WU0        = '1.861766e-09+dwu0p_hv25_spw'
+PU0        = '-1.1507518e-15+dpu0p_hv25_spw'
+UA         = 1.969934e-11        
+LUA        = 9.1332481e-16       
+WUA        = 4.21397e-16  
+PUA        = -4.1030648e-22      
+UB         = 1.2517635e-18       
+LUB        = -5.866371e-25  
+WUB        = -2.4241117e-25      
+PUB        = 1.3663899e-31       
+UC         = 8.1280474e-11
+LUC        = -2.5891648e-17      WUC        = -3.7860572e-17      PUC        = 3.9056223e-24
+VSAT       = '97152.829+dvsatp_hv25_spw' 
+KVSAT    = 0.0  
+LVSAT      = '0.0024525374+dlvsatp_hv25_spw' 
+WVSAT      = '0.0029929677+dwvsatp_hv25_spw' 
+PVSAT      = '-2.499128e-09+dpvsatp_hv25_spw' 
+A0         = '0.62114912+da0p_hv25_spw'  
+LA0        = '2.0496981e-07+dla0p_hv25_spw'  
+WA0        = '1.4483368e-07+dwa0p_hv25_spw'  
+PA0        = '-1.8828667e-13+dpa0p_hv25_spw' 
+AGS        = '0.2741672+dagsp_hv25_spw'   
+LAGS       = '5.3266282e-07+dlagsp_hv25_spw'  
+WAGS       = '2.3678862e-07+dwagsp_hv25_spw'  
+PAGS       = '-3.2892711e-13+dpagsp_hv25_spw' 
+A1         = 0                   A2         = 0.5                 B0         = 0
+B1         = 0
+KETA       = '-0.085108059+dketap_hv25_spw' 
+LKETA      = '1.4455652e-08+dlketap_hv25_spw' 
+WKETA      = '2.047101e-08+dwketap_hv25_spw' 
+PKETA      = '1.069486e-16+dpketap_hv25_spw' 
+DWG        = 0
+DWB        = 0                   PCLM       = '0.12621674+dpclmp_hv25_spw'
+LPCLM      = '-8.6985116e-10+dlpclmp_hv25_spw'
+WPCLM      = '-1.591356e-08+dwpclmp_hv25_spw'
+PPCLM      = '5.2799965e-16+dppclmp_hv25_spw'
+PDIBLC1    = 0                   PDIBLC2    = -0.00067619849      LPDIBLC2   = 5.7369046e-10
+WPDIBLC2   = 8.6061567e-11       PPDIBLC2   = -7.2295242e-17      PDIBLCB    = 0
+DROUT      = 0.56                PVAG       = 0.125               DELTA      = 0.005
+PSCBE1     = 9.264e+08           PSCBE2     = 1e-20               FPROUT     = 200
+PDITS      = 0                   PDITSD     = 0                   PDITSL     = 0
+RSH        = 14.55               RSW        = 132                 RDW        = 1494
+PRWG       = 0                   PRWB       = 0                   WR         = 1
+ALPHA0     = 4.408e-9            
+ALPHA1     = 5e-06               BETA0      = 29.15
+AGIDL      = '6.77e-08+dagidlp_hv25_spw'
+LAGIDL     = '0+dlagidlp_hv25_spw'     WAGIDL     = '0+dwagidlp_hv25_spw'     PAGIDL     = '0+dpagidlp_hv25_spw'
+BGIDL      = 2.8388983e+09       
+LBGIDL     = -1.828032           
+WBGIDL     = -25.624782 
+PBGIDL     = 0                   
+CGIDL      = 52                  EGIDL      = 1.8302
+AIGBACC    = 0.43                BIGBACC    = 0.054               CIGBACC    = 0.075
+NIGBACC    = 1                   AIGBINV    = 0.35                BIGBINV    = 0.03
+CIGBINV    = 0.006               EIGBINV    = 1.1                 NIGBINV    = 3
+AIGC       = 0.43                BIGC       = 0.024               CIGC       = 0.03
+AIGSD      = 0.43                BIGSD      = 0.024               CIGSD      = 0.03
+NIGC       = 1                   POXEDGE    = 1                   PIGCD      = 1
+NTOX       = 1                   XRCRG1     = 12                  XRCRG2     = 1
+VFBSDOFF   = 0.1                 LVFBSDOFF  = 0                   WVFBSDOFF  = 0
+PVFBSDOFF  = 0                   CGSO       = 'cgsop_hv25_spw'          CGDO       = 'cgdop_hv25_spw'
+CGBO       = 0                   CGDL       = 'cgdlp_hv25_spw'          CGSL       = 'cgslp_hv25_spw'
+CLC        = 1e-07               CLE        = 0.6                 CF         = 'cfp_hv25_spw'
+CKAPPAS    = 0.6                 CKAPPAD    = 0.6                 ACDE       = 0.4
+MOIN       = 5.512              
+NOFF       = 3.055               
+VOFFCV     = 0.066645
+TVOFF      = -0.0019375589       LTVOFF     = -1.9205895e-09      WTVOFF     = 2.1336573e-09
+PTVOFF     = 9.4077142e-16       TVFBSDOFF  = 0.01015             LTVFBSDOFF = 0
+WTVFBSDOFF = 0                   PTVFBSDOFF = 0                   KT1        = -0.36922828
+LKT1       = -1.8483369e-08      WKT1       = 5.8107654e-08       PKT1       = 5.2372351e-15
+KT1L       = 0                   KT2        = -0.081154493        LKT2       = 4.5820536e-09
+WKT2       = 6.7112301e-09       PKT2       = -5.0653522e-16      UTE        = -1.4618981
+LUTE       = 1.3040868e-07       WUTE       = 1.209891e-07        PUTE       = -1.2144161e-13
+UA1        = -1.5936537e-09      LUA1       = 1.4519685e-15       WUA1       = 1.4804225e-15
+PUA1       = -1.0025152e-21     
+UB1        = 2.2580494e-18       
+LUB1       = -1.6994145e-24 
+WUB1       = -2.2688921e-24      
+PUB1       = 1.1850737e-30       
+UC1        = -1.4591413e-10 
+LUC1       = 8.0914363e-17       
+WUC1       = 1.1122185e-16       
+PUC1       = -4.1779916e-23 
+PRT        = 0                  
+AT         = -4411.3745          
+LAT        = -0.010826715 
+WAT        = -0.014287945        
+PAT        = 2.9985581e-09       
+JSS        = 1.13e-07
+JSWS       = 1e-14               JSWGS      = 5e-14              
+NJS        = 1.00 
+NJD        = 1.007               
+IJTHSFWD   = 0.01                IJTHDFWD   = 0.01
+IJTHSREV   = 0.01                IJTHDREV   = 0.01                BVS        = 9
+XJBVS      = 1                   XJBVD      = 1                  
+JSD        = 3.060E-06 
+JSWD       = 1.392E-12           
+JSWGD      = 1.392E-12           
+BVD        = 16.8 
+JTSSWGS    = 7.2e-10             JTSSWGD    = 7.2e-10             NJTSSWG    = 26.124
+XTSSWGS    = 0.17206            
+XTSSWGD    = 0.470               
+TNJTSSWG   = 0.14981
+VTSSWGS    = 20                  VTSSWGD    = 20                  PBS        = 0.7
+PBD        = 0.4                 
+CJS        = 'cjsp_hv25_spw'           MJS        = 0.31
+PBSWS      = 0.5                 CJSWS      = 'cjswsp_hv25_spw'         MJSWS      = 0.082
+PBSWGS     = 0.5                 CJSWGS     = 'cjswgsp_hv25_spw'        MJSWGS     = 0.35
+CJD        = 'cjdp_hv25_spw'          
+MJD        = 0.29                
+PBSWD      = 0.4 
+CJSWD      = 'cjswdp_hv25_spw'        
+MJSWD      = 0.18                
+PBSWGD     = 0.8 
+CJSWGD     = 'cjswgdp_hv25_spw'       
+MJSWGD     = 0.62                
+TPB        = 1.35E-03 
+TCJ        = 1.34E-03            
+TPBSW      = 1.50E-04            
+TCJSW      = 3.00E-04 
+TPBSWG     = 1.06E-03            
+TCJSWG     = 1.24E-03            
+XTIS       = 3
+XTID       = 3                   DMCG       = 1.245e-07           DMCI       = 3.05e-07
+DMDG       = 0                   DMCGT      = 0                   DWJ        = 0
+XGW        = 0                   XGL        = -2.3e-08            RSHG       = 14.93
+GBMIN      = 1e-12               RBPB       = 50                  RBPD       = 50
+RBPS       = 50                  RBDB       = 50                  RBSB       = 50
+NGCON      = 1                  
+FNOIMOD    = 1                   
+NOIA       = 1.5e+41 
+NOIB       = 0.5e+025            
+NOIC       = 1e7                 
+EM         = 1.9e+7  
+EF         = 1.1                 
+TNOIMOD    = 0 
+SAREF    = 0.46e-6 
+SBREF    = 0.46e-6 
+WLOD     = 0 
+LLODVTH  = 1 
+WLODVTH  = 1 
+STK2     = 0.5e-9 
+LODK2    = 1 
+LLODKU0  = 1 
+WLODKU0  = 1 
+LODETA0  = 1 
+STETA0   = 2.0e-9 
+TKU0     = 0 )


.ENDL MOS_hv25_snw_spw




***************************     LIBRARY OF STATISTICAL CASE     ***************************
.lib mc_bip
.param
*+par1_bip=AGAUSS(0,1,3) 
+A1_bip='par1_bip_dio*3.0000e+000*3/3' 

+bfa             = '1.0000e+000+(-5.0000e-002)*A1_bip'
+isa             = '1.0000e+000+(-1.0000e-001)*A1_bip'
+nfa             = '1.0000e+000+(-8.3333e-004)*A1_bip'
+rba             = '1.0000e+000+(6.6667e-002)*A1_bip'
+rea             = '1.0000e+000+(6.6667e-002)*A1_bip'
+rca             = '1.0000e+000+(6.6667e-002)*A1_bip'
+rbma            = '1.0000e+000+(6.6667e-002)*A1_bip'
+cjea            = '1.0000e+000+(2.3333e-002)*A1_bip'
+cjca            = '1.0000e+000+(2.3333e-002)*A1_bip'
+par_bjtp1=AGAUSS(0,1,1) 
+par_bjtp2=AGAUSS(0,1,1)


.lib 'crn65lp_v1d5.l' BIP
.endl mc_bip







***************************************************************
*                                                             *
*                     LIBRARY OF TYPICAL CASE                 *
*                                                             *
***************************************************************
.LIB TT_BIP
.param
+bfa    = 1        isa    = 1        nfa    = 1        rba    = 1        rea    = 1
+rca    = 1        rbma   = 1        cjea   = 1        cjca   = 1
+par_bjtp1=AGAUSS(0,1,1) 
+par_bjtp2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP
.ENDL TT_BIP







***************************************************************
*                                                             *
*                     LIBRARY OF SS CORNER CASE               *
*                                                             *
***************************************************************
.LIB SS_BIP
.param
+bfa    = 0.85     isa    = 0.7      nfa    = 0.9975   rba    = 1.2      rea    = 1.2
+rca    = 1.2      rbma   = 1.2      cjea   = 1.07     cjca   = 1.07
+par_bjtp1=AGAUSS(0,1,1) 
+par_bjtp2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP
.ENDL SS_BIP







***************************************************************
*                                                             *
*                     LIBRARY OF FF CORNER CASE               *
*                                                             *
***************************************************************
.LIB FF_BIP
.param
+bfa    = 1.15     isa    = 1.3      nfa    = 1.0025   rba    = 0.8      rea    = 0.8
+rca    = 0.8      rbma   = 0.8      cjea   = 0.93     cjca   = 0.93
+par_bjtp1=AGAUSS(0,1,1) 
+par_bjtp2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP
.ENDL FF_BIP







***************************************************************
*                                                             *
*         MODELS OF VERTICAL P+/NW/SUB PNP BIPOLAR            *
*                                                             *
***************************************************************
.LIB BIP
*
*
.MODEL PNP10 PNP (                                             LEVEL  = 1
+IS       = '7.0219e-018*isa'   BF       = '0.92115*bfa'       NF       = '1.005*nfa'
+VAF      = 486.5               IKF      = 0.0032652           ISE      = '5.1418e-018*isa'
+NE       = 1.147               BR       = 0.004008            NR       = 1
+VAR      = 75.713              IKR      = 0.0016463           ISC      = '8.8843e-018*isa'
+NC       = 1.1956              RB       = '32.724*rba'        IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '4.6688*rea'        RC       = '3.4826*rca'
+NKF      = 0.40045             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.003888
+TBR1     = 0.00049375          TIKF1    = -0.003565           TIKR1    = 3.92e-012
+TIS1     = 5.6                 TNC1     = 4e-012              TNE1     = 0.0004896
+TNF1     = 3.9381e-005         TNR1     = 0.00018             TRB1     = 0.0020386
+TRC1     = 0.0014048           TRE1     = 0.00018439          TVAF1    = 2e-012
+CJE      = '1.103E-13*cjea'    VJE      = 1                   MJE      = 0.40
+CJC      = '8.147E-14*cjca'    VJC      = 0.5                 MJC      = 0.33
+FC       = 0                   CTC      = 2.3E-03             CTE      = 1.05E-03
+TVJC     = 2.6E-03             TVJE     = 3E-3                )
*
*
.MODEL PNP5 PNP (                                              LEVEL  = 1
+IS       = '1.9237e-018*isa'   BF       = '1.1517*bfa'        NF       = '1.005*nfa'
+VAF      = 491.36              IKF      = 0.0018697           ISE      = '3.0013e-019*isa'
+NE       = 1.0187              BR       = 0.0018246           NR       = 1
+VAR      = 46.664              IKR      = 0.0016962           ISC      = '1.915e-018*isa'
+NC       = 1.0581              RB       = '55.724*rba'        IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '5.8166*rea'        RC       = '4.481*rca'
+NKF      = 0.39627             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.0047687
+TBR1     = 0.00092966          TIKF1    = -0.0052732          TIKR1    = 4.158e-011
+TIS1     = 5.6                 TNF1     = 3.6352e-005         TNR1     = 0.00015057
+TRB1     = 6.2925e-009         TRC1     = 0.001419            TRE1     = 0.00024503
+TVAF1    = 8e-011              TVAR1    = 3.762e-011          CJE      = '2.82E-14*cjea'
+VJE      = 1                   MJE      = 0.40                CJC      = '4.848E-14*cjca'
+VJC      = 0.5                 MJC      = 0.33                FC       = 0
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03
+TVJE     = 3E-3                )
*
*
.MODEL PNP2 PNP (                                              LEVEL  = 1
+IS       = '4.0941e-019*isa'   BF       = '1.5264*bfa'        NF       = '1.005*nfa'
+VAF      = 446.06              IKF      = 4.9459e-005         ISE      = '4.3678e-019*isa'
+NE       = 2.342               BR       = 0.00057407          NR       = 0.9938
+VAR      = 38.986              IKR      = 0.003172            ISC      = '4.8919e-019*isa'
+NC       = 1.2603              RB       = '115.1*rba'         IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '2.7182*rea'        RC       = '2.1222*rca'
+NKF      = 0.0082035           SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.0048367
+TBR1     = 0.0003161           TIKF1    = 0.002398            TIKR1    = 3.0219e-005
+TIS1     = 5.6                 TNC1     = 4e-012              TNE1     = -1.01e-010
+TNF1     = 6.0694e-005         TNR1     = 0.0001476           TRB1     = 0.00042689
+TRC1     = 0.001419            TRE1     = 0.00025             TVAF1    = 8e-011
+TVAR1    = 3.8e-011            CJE      = '4.820E-15*cjea'    VJE      = 1
+MJE      = 0.40                CJC      = '3.197E-14*cjca'    VJC      = 0.5
+MJC      = 0.33                FC       = 0                   CTC      = 2.3E-03
+CTE      = 1.05E-03            TVJC     = 2.6E-03             TVJE     = 3E-3
+)
*
.subckt pnp10_mis C B E
.param
+ismis='1+0.32e-2*(1/sqrt(10e-6*10e-6*1e12))*par_bjtp1'
+bfmis='1+0.713e-2*(1/sqrt(10e-6*10e-6*1e12))*par_bjtp2'
qin C B E PNP10
.MODEL PNP10 PNP (                                             LEVEL  = 1
+IS       = '7.0219e-018*isa*ismis'   BF       = '0.92115*bfa*bfmis'       NF       = '1.005*nfa'
+VAF      = 486.5               IKF      = 0.0032652           ISE      = '5.1418e-018*isa*ismis'
+NE       = 1.147               BR       = 0.004008            NR       = 1
+VAR      = 75.713              IKR      = 0.0016463           ISC      = '8.8843e-018*isa*ismis'
+NC       = 1.1956              RB       = '32.724*rba'        IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '4.6688*rea'        RC       = '3.4826*rca'
+NKF      = 0.40045             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.003888
+TBR1     = 0.00049375          TIKF1    = -0.003565           TIKR1    = 3.92e-012
+TIS1     = 5.6                 TNC1     = 4e-012              TNE1     = 0.0004896
+TNF1     = 3.9381e-005         TNR1     = 0.00018             TRB1     = 0.0020386
+TRC1     = 0.0014048           TRE1     = 0.00018439          TVAF1    = 2e-012
+CJE      = '1.103E-13*cjea'    VJE      = 1                   MJE      = 0.40
+CJC      = '8.147E-14*cjca'    VJC      = 0.5                 MJC      = 0.33
+FC       = 0                   CTC      = 2.3E-03             CTE      = 1.05E-03
+TVJC     = 2.6E-03             TVJE     = 3E-3                )
.ends pnp10_mis
*
*
.subckt pnp5_mis C B E
.param
+ismis='1+0.32e-2*(1/sqrt(5e-6*5e-6*1e12))*par_bjtp1'
+bfmis='1+0.713e-2*(1/sqrt(5e-6*5e-6*1e12))*par_bjtp2'
qin C B E PNP5
.MODEL PNP5 PNP (                                              LEVEL  = 1
+IS       = '1.9237e-018*isa*ismis'   BF       = '1.1517*bfa*bfmis'        NF       = '1.005*nfa'
+VAF      = 491.36              IKF      = 0.0018697           ISE      = '3.0013e-019*isa*ismis'
+NE       = 1.0187              BR       = 0.0018246           NR       = 1
+VAR      = 46.664              IKR      = 0.0016962           ISC      = '1.915e-018*isa*ismis'
+NC       = 1.0581              RB       = '55.724*rba'        IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '5.8166*rea'        RC       = '4.481*rca'
+NKF      = 0.39627             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.0047687
+TBR1     = 0.00092966          TIKF1    = -0.0052732          TIKR1    = 4.158e-011
+TIS1     = 5.6                 TNF1     = 3.6352e-005         TNR1     = 0.00015057
+TRB1     = 6.2925e-009         TRC1     = 0.001419            TRE1     = 0.00024503
+TVAF1    = 8e-011              TVAR1    = 3.762e-011          CJE      = '2.82E-14*cjea'
+VJE      = 1                   MJE      = 0.40                CJC      = '4.848E-14*cjca'
+VJC      = 0.5                 MJC      = 0.33                FC       = 0
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03
+TVJE     = 3E-3                )
*
.ends pnp5_mis
*
.subckt pnp2_mis C B E
.param
+ismis='1+0.32e-2*(1/sqrt(2e-6*2e-6*1e12))*par_bjtp1'
+bfmis='1+0.713e-2*(1/sqrt(2e-6*2e-6*1e12))*par_bjtp2'
qin C B E PNP2
.MODEL PNP2 PNP (                                              LEVEL  = 1
+IS       = '4.0941e-019*isa*ismis'   BF       = '1.5264*bfa*bfmis'        NF       = '1.005*nfa'
+VAF      = 446.06              IKF      = 4.9459e-005         ISE      = '4.3678e-019*isa*ismis'
+NE       = 2.342               BR       = 0.00057407          NR       = 0.9938
+VAR      = 38.986              IKR      = 0.003172            ISC      = '4.8919e-019*isa*ismis'
+NC       = 1.2603              RB       = '115.1*rba'         IRB      = 0.001
+RBM      = '0.1*rbma'          RE       = '2.7182*rea'        RC       = '2.1222*rca'
+NKF      = 0.0082035           SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 1                   TLEVC    = 1                   TBF1     = 0.0048367
+TBR1     = 0.0003161           TIKF1    = 0.002398            TIKR1    = 3.0219e-005
+TIS1     = 5.6                 TNC1     = 4e-012              TNE1     = -1.01e-010
+TNF1     = 6.0694e-005         TNR1     = 0.0001476           TRB1     = 0.00042689
+TRC1     = 0.001419            TRE1     = 0.00025             TVAF1    = 8e-011
+TVAR1    = 3.8e-011            CJE      = '4.820E-15*cjea'    VJE      = 1
+MJE      = 0.40                CJC      = '3.197E-14*cjca'    VJC      = 0.5
+MJC      = 0.33                FC       = 0                   CTC      = 2.3E-03
+CTE      = 1.05E-03            TVJC     = 2.6E-03             TVJE     = 3E-3
+)
**
.ends pnp2_mis
.ENDL BIP







.lib mc_bip_npn
.param
*+par1_bip_npn=AGAUSS(0,1,3) 
+A1_bip_npn='par1_bip_dio*3.0000e+000*3/3.1' 

+bfa_a           = '1.0000e+000+(-5.0000e-002)*A1_bip_npn'
+isa_a           = '1.0000e+000+(-1.0000e-001)*A1_bip_npn'
+nfa_a           = '1.0000e+000+(-8.3333e-004)*A1_bip_npn'
+rba_a           = '1.0000e+000+(6.6667e-002)*A1_bip_npn'
+rea_a           = '1.0000e+000+(6.6667e-002)*A1_bip_npn'
+rca_a           = '1.0000e+000+(6.6667e-002)*A1_bip_npn'
+rbma_a          = '1.0000e+000+(6.6667e-002)*A1_bip_npn'
+cjea_a          = '1.0000e+000+(2.3333e-002)*A1_bip_npn'
+cjca_a          = '1.0000e+000+(2.3333e-002)*A1_bip_npn'

+par_bjtn1=AGAUSS(0,1,1) 
+par_bjtn2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP_NPN
.endl mc_bip_npn







***************************************************************
*                                                             *
*                     LIBRARY OF TYPICAL CASE                 *
*                                                             *
***************************************************************
.LIB TT_BIP_NPN
.param
+bfa_a  = 1        isa_a  = 1        nfa_a  = 1        rba_a  = 1        rea_a  = 1
+rca_a  = 1        rbma_a = 1        cjea_a = 1        cjca_a = 1
+par_bjtn1=AGAUSS(0,1,1) 
+par_bjtn2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP_NPN
.ENDL TT_BIP_NPN







***************************************************************
*                                                             *
*                     LIBRARY OF SS CORNER CASE               *
*                                                             *
***************************************************************
.LIB SS_BIP_NPN
.param
+bfa_a  = 0.85     isa_a  = 0.7      nfa_a  = 0.9975   rba_a  = 1.2      rea_a  = 1.2
+rca_a  = 1.2      rbma_a = 1.2      cjea_a = 1.07     cjca_a = 1.07
+par_bjtn1=AGAUSS(0,1,1) 
+par_bjtn2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP_NPN
.ENDL SS_BIP_NPN







***************************************************************
*                                                             *
*                     LIBRARY OF FF CORNER CASE               *
*                                                             *
***************************************************************
.LIB FF_BIP_NPN
.param
+bfa_a  = 1.15     isa_a  = 1.3      nfa_a  = 1.0025   rba_a  = 0.8      rea_a  = 0.8
+rca_a  = 0.8      rbma_a = 0.8      cjea_a = 0.93     cjca_a = 0.93
+par_bjtn1=AGAUSS(0,1,1) 
+par_bjtn2=AGAUSS(0,1,1)

.lib 'crn65lp_v1d5.l' BIP_NPN
.ENDL FF_BIP_NPN







***************************************************************
*                                                             *
*         MODELS OF VERTICAL N+/PW/DNW NPN BIPOLAR            *
*                                                             *
***************************************************************
.LIB BIP_NPN
*
*
.MODEL NPN10 NPN (                                             LEVEL  = 1
+IS       = '1.2541e-017*isa_a' BF       = '4.8463*bfa_a'      NF       = '1.005*nfa_a'
+VAF      = 63.793              IKF      = 0.16438             ISE      = '2.1554e-018*isa_a'
+NE       = 1.0608              BR       = 0.37619             NR       = 1.0048
+VAR      = 30.857              IKR      = 0.040273            ISC      = '2.4836e-018*isa_a'
+NC       = 1.6254              RB       = '79.185*rba_a'      IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '4.8024*rea_a'      RC       = '3.4864*rca_a'
+NKF      = 1.0346              SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.00096751
+TBF2     = 1.6e-005            TBR1     = 0.0011474           TIKF1    = -0.0023902
+TIKR1    = 1e-010              TNC1     = 2.3335e-011         TNE1     = 0.00045093
+TNR1     = -9.8861e-011        TRB1     = 0.0051775           TRC1     = 5.0604e-005
+TRE1     = 0.000948            TVAF1    = -1e-010             TVAR1    = 9.9972e-011
+CJE      = '1.283E-13*cjea_a'  VJE      = 1                   MJE      = 0.40
+CJC      = '2.285E-13*cjca_a'  VJC      = 1.15                MJC      = 0.47
+CJS      = 0.000E+000          VJS      = 0.75                MJS      = 0.5
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04
+CTS      = 0                   TVJC     = 5.0E-03             TVJE     = 2.0E-3
+TVJS     = 0                   )
*
*
.MODEL NPN5 NPN (                                              LEVEL  = 1
+IS       = '3.5941e-018*isa_a' BF       = '4.7258*bfa_a'      NF       = '1.005*nfa_a'
+VAF      = 73.36               IKF      = 0.069191            ISE      = '3.9941e-018*isa_a'
+NE       = 1.1743              BR       = 0.20014             NR       = 1.0046
+VAR      = 35.552              IKR      = 1.2915              ISC      = '3.346e-018*isa_a'
+NC       = 1.2639              RB       = '97.27*rba_a'       IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '9.5028*rea_a'      RC       = '2.8068*rca_a'
+NKF      = 1.2591              SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0017963
+TBF2     = 1.6e-005            TBR1     = 0.00083027          TIKF1    = -0.0022508
+TNC1     = -9.9e-011           TNE1     = 0.00069292          TNF1     = 1.8809e-010
+TRB1     = 0.0015717           TRC1     = 0.0016685           TRE1     = 4.7874e-009
+TVAF1    = -1e-010             CJE      = '3.286E-14*cjea_a'  VJE      = 1
+MJE      = 0.40                CJC      = '1.169E-13*cjca_a'  VJC      = 1.15
+MJC      = 0.47                CJS      = 0.000E+000          VJS      = 0.75
+MJS      = 0.5                 FC       = 0                   CTC      = 1.5E-03
+CTE      = 7.00E-04            CTS      = 0                   TVJC     = 5.0E-03
+TVJE     = 2.0E-3              TVJS     = 0                   )
*
*
.MODEL NPN2 NPN (                                              LEVEL  = 1
+IS       = '7.411e-019*isa_a'  BF       = '6.478*bfa_a'       NF       = '1.005*nfa_a'
+VAF      = 68.913              IKF      = 0.0012456           ISE      = '1.8727e-018*isa_a'
+NE       = 1.166               BR       = 0.3358              NR       = 1.005
+VAR      = 28.81               IKR      = 0.07876             ISC      = '6.0512e-018*isa_a'
+NC       = 0.99267             RB       = '81.346*rba_a'      IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '26.543*rea_a'      RC       = '2.2211*rca_a'
+NKF      = 0.28319             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0013421
+TBF2     = 1.6e-005            TBR1     = 0.0018865           TIKF1    = -0.0023214
+TIKR1    = 2.02e-012           TNE1     = 0.00042165          TNF1     = 4.1208e-007
+TNR1     = 2e-012              TRB1     = 0.00048837          TRC1     = 0.0016519
+TRE1     = 9.184e-006          TVAF1    = 6e-012              TVAR1    = 2e-012
+CJE      = '5.636E-15*cjea_a'  VJE      = 1                   MJE      = 0.40
+CJC      = '6.746E-14*cjca_a'  VJC      = 1.15                MJC      = 0.47
+CJS      = 0.000E+000          VJS      = 0.75                MJS      = 0.5
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04
+CTS      = 0                   TVJC     = 5.0E-03             TVJE     = 2.0E-3
+TVJS     = 0                   )
*
*
****BIP_NPN MISMATCH MODEL**********
.subckt npn10_mis C B E
.param
+ismis='1+0.334e-2*(1/sqrt(10e-6*10e-6*1e12))*par_bjtn1'
+bfmis='1+1.455e-2*(1/sqrt(10e-6*10e-6*1e12))*par_bjtn2'
qin C B E NPN10
.MODEL NPN10 NPN (                                             LEVEL  = 1
+IS       = '1.2541e-017*isa_a*ismis' BF       = '4.8463*bfa_a*bfmis'      NF       = '1.005*nfa_a'
+VAF      = 63.793              IKF      = 0.16438             ISE      = '2.1554e-018*isa_a*ismis'
+NE       = 1.0608              BR       = 0.37619             NR       = 1.0048
+VAR      = 30.857              IKR      = 0.040273            ISC      = '2.4836e-018*isa_a*ismis'
+NC       = 1.6254              RB       = '79.185*rba_a'      IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '4.8024*rea_a'      RC       = '3.4864*rca_a'
+NKF      = 1.0346              SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.00096751
+TBF2     = 1.6e-005            TBR1     = 0.0011474           TIKF1    = -0.0023902
+TIKR1    = 1e-010              TNC1     = 2.3335e-011         TNE1     = 0.00045093
+TNR1     = -9.8861e-011        TRB1     = 0.0051775           TRC1     = 5.0604e-005
+TRE1     = 0.000948            TVAF1    = -1e-010             TVAR1    = 9.9972e-011
+CJE      = '1.283E-13*cjea_a'  VJE      = 1                   MJE      = 0.40
+CJC      = '2.285E-13*cjca_a'  VJC      = 1.15                MJC      = 0.47
+CJS      = 0.000E+000          VJS      = 0.75                MJS      = 0.5
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04
+CTS      = 0                   TVJC     = 5.0E-03             TVJE     = 2.0E-3
+TVJS     = 0                   )
*
.ends npn10_mis
*
.subckt npn5_mis C B E
.param
+ismis='1+0.334e-2*(1/sqrt(5e-6*5e-6*1e12))*par_bjtn1'
+bfmis='1+1.455e-2*(1/sqrt(5e-6*5e-6*1e12))*par_bjtn2'
qin C B E NPN5
.MODEL NPN5 NPN (                                              LEVEL  = 1
+IS       = '3.5941e-018*isa_a*ismis' BF       = '4.7258*bfa_a*bfmis'      NF       = '1.005*nfa_a'
+VAF      = 73.36               IKF      = 0.069191            ISE      = '3.9941e-018*isa_a*ismis'
+NE       = 1.1743              BR       = 0.20014             NR       = 1.0046
+VAR      = 35.552              IKR      = 1.2915              ISC      = '3.346e-018*isa_a*ismis'
+NC       = 1.2639              RB       = '97.27*rba_a'       IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '9.5028*rea_a'      RC       = '2.8068*rca_a'
+NKF      = 1.2591              SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0017963
+TBF2     = 1.6e-005            TBR1     = 0.00083027          TIKF1    = -0.0022508
+TNC1     = -9.9e-011           TNE1     = 0.00069292          TNF1     = 1.8809e-010
+TRB1     = 0.0015717           TRC1     = 0.0016685           TRE1     = 4.7874e-009
+TVAF1    = -1e-010             CJE      = '3.286E-14*cjea_a'  VJE      = 1
+MJE      = 0.40                CJC      = '1.169E-13*cjca_a'  VJC      = 1.15
+MJC      = 0.47                CJS      = 0.000E+000          VJS      = 0.75
+MJS      = 0.5                 FC       = 0                   CTC      = 1.5E-03
+CTE      = 7.00E-04            CTS      = 0                   TVJC     = 5.0E-03
+TVJE     = 2.0E-3              TVJS     = 0                   )
*
.ends npn5_mis
*
.subckt npn2_mis C B E
.param
+ismis='1+0.334e-2*(1/sqrt(2e-6*2e-6*1e12))*par_bjtn1'
+bfmis='1+1.455e-2*(1/sqrt(2e-6*2e-6*1e12))*par_bjtn2'
qin C B E NPN2
.MODEL NPN2 NPN (                                              LEVEL  = 1
+IS       = '7.411e-019*isa_a*ismis'  BF       = '6.478*bfa_a*bfmis'       NF       = '1.005*nfa_a'
+VAF      = 68.913              IKF      = 0.0012456           ISE      = '1.8727e-018*isa_a*ismis'
+NE       = 1.166               BR       = 0.3358              NR       = 1.005
+VAR      = 28.81               IKR      = 0.07876             ISC      = '6.0512e-018*isa_a*ismis'
+NC       = 0.99267             RB       = '81.346*rba_a'      IRB      = 0.001
+RBM      = '0.1*rbma_a'        RE       = '26.543*rea_a'      RC       = '2.2211*rca_a'
+NKF      = 0.28319             SUBS     = 1                   TREF     = 25
+XTB      = 0                   XTI      = 3                   EG       = 1.18
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0013421
+TBF2     = 1.6e-005            TBR1     = 0.0018865           TIKF1    = -0.0023214
+TIKR1    = 2.02e-012           TNE1     = 0.00042165          TNF1     = 4.1208e-007
+TNR1     = 2e-012              TRB1     = 0.00048837          TRC1     = 0.0016519
+TRE1     = 9.184e-006          TVAF1    = 6e-012              TVAR1    = 2e-012
+CJE      = '5.636E-15*cjea_a'  VJE      = 1                   MJE      = 0.40
+CJC      = '6.746E-14*cjca_a'  VJC      = 1.15                MJC      = 0.47
+CJS      = 0.000E+000          VJS      = 0.75                MJS      = 0.5
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04
+CTS      = 0                   TVJC     = 5.0E-03             TVJE     = 2.0E-3
+TVJS     = 0                   )
*
.ends npn2_mis
.ENDL BIP_NPN


***************************     LIBRARY OF STATISTICAL CASE     ***************************
.lib MC_BIP_S
.param
*+par1mc_bip_s=AGAUSS(0,1,3)
+A1_bip_s='par1_bip_dio*3.0000e+000*3/3'
+isc            ='1+(-0.1)*A1_bip_s'
+bfc            ='1+(-0.05)*A1_bip_s'
+nfc            ='1+(-0.00083333)*A1_bip_s'
+rbc            ='1+(0.066667)*A1_bip_s'
+rec            ='1+(0.066667)*A1_bip_s'
+rcc            ='1+(0.066667)*A1_bip_s'
+rbmc           ='1+(0.066667)*A1_bip_s'
+cjec           ='1+(0.023333)*A1_bip_s'
+cjcc           ='1+(0.023333)*A1_bip_s'
+par_bjtps1=AGAUSS(0,1,1)
+par_bjtps2=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' BIP_S
.endl MC_BIP_S

******************************    LIBRARY OF TYPICAL CASE    ******************************
.LIB TT_BIP_S
.param
+par_bjtps1=AGAUSS(0,1,1) 
+par_bjtps2=AGAUSS(0,1,1)
+isc    = 1        bfc    = 1        nfc    = 1        rbc    = 1        rec    = 1        
+rcc    = 1        rbmc   = 1        cjec   = 1        cjcc   = 1        
.lib 'crn65lp_v1d5.l' BIP_S
.ENDL TT_BIP_S

******************************  LIBRARY OF SS CORNER CASE  ******************************
.LIB SS_BIP_S
.param
+par_bjtps1=AGAUSS(0,1,1) 
+par_bjtps2=AGAUSS(0,1,1)
+isc    = 0.7      bfc    = 0.85     nfc    = 0.9975   rbc    = 1.2      rec    = 1.2      
+rcc    = 1.2      rbmc   = 1.2      cjec   = 1.07     cjcc   = 1.07     
.lib 'crn65lp_v1d5.l' BIP_S
.ENDL SS_BIP_S

******************************  LIBRARY OF FF CORNER CASE  ******************************
.LIB FF_BIP_S
.param
+par_bjtps1=AGAUSS(0,1,1) 
+par_bjtps2=AGAUSS(0,1,1)
+isc    = 1.3      bfc    = 1.15     nfc    = 1.0025   rbc    = 0.8      rec    = 0.8      
+rcc    = 0.8      rbmc   = 0.8      cjec   = 0.93     cjcc   = 0.93     
.lib 'crn65lp_v1d5.l' BIP_S
.ENDL FF_BIP_S

*******************************************************************************************
*                                                                                         *
*               MODELS OF VERTICAL P+/NW/PSUB PNP Small Area BIPOLAR                      *
*                                                                                         *
*******************************************************************************************
.LIB BIP_S 
*
*
.MODEL PNP10_S PNP (                                           LEVEL    = 1
+IS       = '7.48e-018*isc'     BF       = '0.91*bfc'          NF       = '1.006*nfc'         
+VAF      = 486.5               IKF      = 0.0079338           ISE      = '7.48e-018*isc'     
+NE       = 1.2502              BR       = 0.00675             NR       = 1                   
+VAR      = 51.485              IKR      = 0.0016463           ISC      = '7.48e-018*isc'     
+NC       = 1                   RB       = '30*rbc'            IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '11*rec'            RC       = '17*rcc'            
+NKF      = 0.3416              SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0037436           
+TBF2     = 2e-006              TBR1     = -0.00088878         TBR2     = 1.6e-005            
+TIKF1    = -0.0060116          TIKR1    = 3.92e-012           TNE1     = 0.0004896           
+TNF1     = -3e-005             TNR1     = 0.00018             TRB1     = 0.0020386           
+TRC1     = 0.0014048           TRE1     = 0.00018439          CJE      = '1.103E-13*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '5.281E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
*
.MODEL PNP5_S PNP (                                            LEVEL    = 1
+IS       = '2.075e-018*isc'    BF       = '1.0465*bfc'        NF       = '1.006*nfc'         
+VAF      = 486.5               IKF      = 0.0082441           ISE      = '2.075e-018*isc'    
+NE       = 1.2502              BR       = 0.00375             NR       = 1                   
+VAR      = 51.485              IKR      = 0.0016463           ISC      = '2.075e-018*isc'    
+NC       = 1.1956              RB       = '15*rbc'            IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '14*rec'            RC       = '18*rcc'            
+NKF      = 0.41665             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0040431           
+TBF2     = 1.4e-007            TBR1     = -0.0033083          TBR2     = 4.6e-005            
+TIKF1    = -0.0053503          TIKR1    = 3.92e-012           TNE1     = 0.0004896           
+TNF1     = 4.5e-005            TNR1     = 0.00018             TRB1     = 0.0020386           
+TRC1     = 0.0014048           TRE1     = 0.00018439          CJE      = '2.820E-14*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '2.567E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
*
.MODEL PNP2_S PNP (                                            LEVEL    = 1
+IS       = '4.27e-019*isc'     BF       = '1.665*bfc'         NF       = '1.006*nfc'         
+VAF      = 350                 IKF      = 0.00046541          ISE      = '4.27e-019*isc'     
+NE       = 1.177               BR       = 0.0017091           NR       = 0.9938              
+VAR      = 38.986              IKR      = 0.003172            ISC      = '4.27e-019*isc'     
+NC       = 1.2603              RB       = '29.29*rbc'         IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '23.25*rec'         RC       = '22.206*rcc'        
+NKF      = 0.27378             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0045815           
+TBR1     = 0.00014541          TBR2     = 1.64e-005           TIKF1    = -0.0057597          
+TIKR1    = 3.0219e-005         TNE1     = 0.00028785          TNF1     = 1e-005              
+TNR1     = 0.0001476           TRB1     = 0.00042689          TRC1     = 0.001419            
+TRE1     = 0.00025             TVAR1    = 3.8e-011            CJE      = '4.820E-15*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '1.268E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
*
*******************************************************************************************
*                                                                                         *
*           MODELS OF VERTICAL P+/NW/PSUB PNP Small Area BIPOLAR Mismatch Model           *
*                                                                                         *
*******************************************************************************************
*
*
.subckt PNP10_S_mis C B E
.param
+ismis10='1+3.6e-3*(1/sqrt(1e-5*1e-5*1e12))*par_bjtps1'
+bfmis10='1+8e-3*(1/sqrt(1e-5*1e-5*1e12))*par_bjtps2'
qin C B E PNP10Smis
*
.MODEL PNP10Smis PNP (                                         LEVEL    = 1
+IS       = '7.48e-018*isc*ismis10'                            BF       = '0.91*bfc*bfmis10'
+NF       = '1.006*nfc'         
+VAF      = 486.5               IKF      = 0.0079338           ISE      = '7.48e-018*isc'     
+NE       = 1.2502              BR       = 0.00675             NR       = 1                   
+VAR      = 51.485              IKR      = 0.0016463           ISC      = '7.48e-018*isc'     
+NC       = 1                   RB       = '30*rbc'            IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '11*rec'            RC       = '17*rcc'            
+NKF      = 0.3416              SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0037436           
+TBF2     = 2e-006              TBR1     = -0.00088878         TBR2     = 1.6e-005            
+TIKF1    = -0.0060116          TIKR1    = 3.92e-012           TNE1     = 0.0004896           
+TNF1     = -3e-005             TNR1     = 0.00018             TRB1     = 0.0020386           
+TRC1     = 0.0014048           TRE1     = 0.00018439          CJE      = '1.103E-13*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '5.281E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
.ends PNP10_S_mis
*
*
.subckt PNP5_S_mis C B E
.param
+ismis5='1+3.6e-3*(1/sqrt(5e-6*5e-6*1e12))*par_bjtps1'
+bfmis5='1+8e-3*(1/sqrt(5e-6*5e-6*1e12))*par_bjtps2'
qin C B E PNP5Smis
*
.MODEL PNP5Smis PNP (                                          LEVEL    = 1
+IS       = '2.075e-018*isc*ismis5'                            BF       = '1.0465*bfc*bfmis5'
+NF       = '1.006*nfc'         
+VAF      = 486.5               IKF      = 0.0082441           ISE      = '2.075e-018*isc'    
+NE       = 1.2502              BR       = 0.00375             NR       = 1                   
+VAR      = 51.485              IKR      = 0.0016463           ISC      = '2.075e-018*isc'    
+NC       = 1.1956              RB       = '15*rbc'            IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '14*rec'            RC       = '18*rcc'            
+NKF      = 0.41665             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0040431           
+TBF2     = 1.4e-007            TBR1     = -0.0033083          TBR2     = 4.6e-005            
+TIKF1    = -0.0053503          TIKR1    = 3.92e-012           TNE1     = 0.0004896           
+TNF1     = 4.5e-005            TNR1     = 0.00018             TRB1     = 0.0020386           
+TRC1     = 0.0014048           TRE1     = 0.00018439          CJE      = '2.820E-14*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '2.567E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
.ends PNP5_S_mis
*
*
.subckt PNP2_S_mis C B E
.param
+ismis2='1+3.6e-3*(1/sqrt(2e-6*2e-6*1e12))*par_bjtps1'
+bfmis2='1+8e-3*(1/sqrt(2e-6*2e-6*1e12))*par_bjtps2'
qin C B E PNP2Smis
*
.MODEL PNP2Smis PNP (                                          LEVEL    = 1
+IS       = '4.27e-019*isc*ismis2'                             BF       = '1.665*bfc*bfmis2'
+NF       = '1.006*nfc'         
+VAF      = 350                 IKF      = 0.00046541          ISE      = '4.27e-019*isc'     
+NE       = 1.177               BR       = 0.0017091           NR       = 0.9938              
+VAR      = 38.986              IKR      = 0.003172            ISC      = '4.27e-019*isc'     
+NC       = 1.2603              RB       = '29.29*rbc'         IRB      = 0.001               
+RBM      = '0.1*rbmc'          RE       = '23.25*rec'         RC       = '22.206*rcc'        
+NKF      = 0.27378             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0045815           
+TBR1     = 0.00014541          TBR2     = 1.64e-005           TIKF1    = -0.0057597          
+TIKR1    = 3.0219e-005         TNE1     = 0.00028785          TNF1     = 1e-005              
+TNR1     = 0.0001476           TRB1     = 0.00042689          TRC1     = 0.001419            
+TRE1     = 0.00025             TVAR1    = 3.8e-011            CJE      = '4.820E-15*cjec'    
+VJE      = 1                   MJE      = 0.4                 CJC      = '1.268E-14*cjcc'    
+VJC      = 0.5                 MJC      = 0.33                FC       = 0                   
+CTC      = 2.3E-03             CTE      = 1.05E-03            TVJC     = 2.6E-03             
+TVJE     = 3E-3                )
*
.ends PNP2_S_mis
*
*
.ENDL BIP_S
*


***************************     LIBRARY OF STATISTICAL CASE     ***************************
.lib MC_BIP_NPN_S
.param
*+par1mc_bip_npn_s=AGAUSS(0,1,3)
+A1_bip_npn_s='par1_bip_dio*3.0000e+000*3/3'
+isd            ='1+(-0.1)*A1_bip_npn_s'
+bfd            ='1+(-0.05)*A1_bip_npn_s'
+nfd            ='1+(-0.00083333)*A1_bip_npn_s'
+rbd            ='1+(0.066667)*A1_bip_npn_s'
+red            ='1+(0.066667)*A1_bip_npn_s'
+rcd            ='1+(0.066667)*A1_bip_npn_s'
+rbmd           ='1+(0.066667)*A1_bip_npn_s'
+cjed           ='1+(0.023333)*A1_bip_npn_s'
+cjcd           ='1+(0.023333)*A1_bip_npn_s'
+par_bjtns1=AGAUSS(0,1,1)
+par_bjtns2=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' BIP_NPN_S
.endl MC_BIP_NPN_S

******************************    LIBRARY OF TYPICAL CASE    ******************************
.LIB TT_BIP_NPN_S
.param
+par_bjtns1=AGAUSS(0,1,1)
+par_bjtns2=AGAUSS(0,1,1)
+isd    = 1        bfd    = 1        nfd    = 1        rbd    = 1        red    = 1        
+rcd    = 1        rbmd   = 1        cjed   = 1        cjcd   = 1        
.lib 'crn65lp_v1d5.l' BIP_NPN_S
.ENDL TT_BIP_NPN_S

******************************  LIBRARY OF SS CORNER CASE  ******************************
.LIB SS_BIP_NPN_S
.param
+par_bjtns1=AGAUSS(0,1,1)
+par_bjtns2=AGAUSS(0,1,1)
+isd    = 0.7      bfd    = 0.85     nfd    = 0.9975   rbd    = 1.2      red    = 1.2      
+rcd    = 1.2      rbmd   = 1.2      cjed   = 1.07     cjcd   = 1.07     
.lib 'crn65lp_v1d5.l' BIP_NPN_S
.ENDL SS_BIP_NPN_S

******************************  LIBRARY OF FF CORNER CASE  ******************************
.LIB FF_BIP_NPN_S
.param
+par_bjtns1=AGAUSS(0,1,1)
+par_bjtns2=AGAUSS(0,1,1)
+isd    = 1.3      bfd    = 1.15     nfd    = 1.0025   rbd    = 0.8      red    = 0.8      
+rcd    = 0.8      rbmd   = 0.8      cjed   = 0.93     cjcd   = 0.93     
.lib 'crn65lp_v1d5.l' BIP_NPN_S
.ENDL FF_BIP_NPN_S

*******************************************************************************************
*                                                                                         *
*                   MODELS OF VERTICAL N+/PW/DNW NPN Small Area BIPOLAR                   *
*                                                                                         *
*******************************************************************************************
.LIB BIP_NPN_S 
*
*
.MODEL NPN10_S NPN (                                           LEVEL    = 1
+IS       = '1.345e-017*isd'    BF       = '4.78*bfd'          NF       = '1.005*nfd'         
+VAF      = 63.793              IKF      = 0.19103             ISE      = '1.345e-017*isd'    
+NE       = 1.2                 BR       = 0.58                NR       = 1.0048              
+VAR      = 46.285              IKR      = 0.06041             ISC      = '1.345e-017*isd'    
+NC       = 1.6254              RB       = '79.185*rbd'        IRB      = 0.001               
+RBM      = '0.1*rbmd'          RE       = '4.2261*red'        RC       = '5.1599*rcd'        
+NKF      = 1.1041              SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0038998           
+TBF2     = -1.0237e-006        TBR1     = 0.0012162           TBR2     = -5.4e-006           
+TIKF1    = -0.0043143          TIKR1    = -1e-010             TNE1     = 0.0002              
+TNF1     = -0.00015            TNR1     = -9.8861e-011        TRB1     = 0.0051775           
+TRC1     = 5.0604e-005         TRE1     = 0.000948            TVAR1    = 9.9972e-011         
+CJE      = '1.283E-13*cjed'    VJE      = 1                   MJE      = 0.4                 
+CJC      = '1.339E-13*cjcd'    VJC      = 1.15                MJC      = 0.47                
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04            
+TVJC     = 5.0E-03             TVJE     = 2.0E-3              )
*
*
.MODEL NPN5_S NPN (                                            LEVEL    = 1
+IS       = '3.665e-018*isd'    BF       = '5.7*bfd'           NF       = '1.005*nfd'         
+VAF      = 63.793              IKF      = 0.0054068           ISE      = '3.665e-018*isd'    
+NE       = 1.1525              BR       = 0.416               NR       = 1.0048              
+VAR      = 46.285              IKR      = 0.03                ISC      = '3.665e-018*isd'    
+NC       = 1.07                RB       = '16*rbd'            IRB      = 0.001               
+RBM      = '0.1*rbmd'          RE       = '15*red'            RC       = '17*rcd'            
+NKF      = 0.23914             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0038              
+TBF2     = -8.2e-006           TBR1     = 0.0012162           TBR2     = -3.2589e-006        
+TIKF1    = -0.0043143          TIKR1    = -1e-010             TNE1     = 0.0002              
+TNE2     = 3e-006              TNF1     = -0.00015            TNR1     = -9.8861e-011        
+TRB1     = 0.0051775           TRC1     = 5.0604e-005         TRE1     = 0.000948            
+TVAR1    = 9.9972e-011         CJE      = '3.286E-14*cjed'    VJE      = 1                   
+MJE      = 0.4                 CJC      = '5.238E-14*cjcd'    VJC      = 1.15                
+MJC      = 0.47                FC       = 0                   CTC      = 1.5E-03             
+CTE      = 7.00E-04            TVJC     = 5.0E-03             TVJE     = 2.0E-3          )
*
*
.MODEL NPN2_S NPN (                                  LEVEL   = 1
+is      = '7.41e-019*isd' subs    = 1               rb      = '20*rbd'            
+re      = '21.183*red'    irb     = 0.001           rc      = '16.306*rcd'        
+rbm     = '0.1*rbmd'      bf      = '9*bfd'         nf      = '1.004*nfd'         
+vaf     = 68.913          ikf     = 0.00066735      ise     = '7.41e-019*isd'     
+ne      = 1.118           br      = 0.195           nr      = 1.005         
+var     = 28.81           ikr     = 0.1             nkf     = 0.2428        
+isc     = '7.41e-019*isd' nc      = 1.0399          xtb     = 0
+xti     = 3               eg      = 1.18            tref    = 25
+CJC     = '2.103E-14*cjcd'
+CJE     = '5.636E-15*cjed'
+mje     = 0.4    
+fc      = 0               mjc     = 0.47            vjc     = 1.15      
+ctc     = 0.0015          cte     = 0.0007          vje     = 1
+tlev    = 0               tlevc   = 1               tvjc    = 0.005         
+tvje    = 0.002           tis1    = 0             
+tise1   = 0               tisc1   = 0               tnf1    = -8.12e-005    
+tnr1    = 2e-012          tne1    = 0.00012598      tnc1    = 0             
+tbf1    = 0.003698        tbr1    = 0.0013496       tvaf1   = 6e-012        
+tvar1   = 0               tikf1   = -0.00621        tikr1   = -2.02e-012    
+trb1    = 0.00048837      trc1    = 0.0016519       tre1    = 9.184e-006    
+tbf2    = 9e-006          tbr2    = -4.4e-006      )
*
*
*******************************************************************************************
*                                                                                         *
*          MODELS OF VERTICAL N+/PW/DNW NPN Small Area BIPOLAR Mismatch Model             *
*                                                                                         *
*******************************************************************************************
*
*
.subckt NPN10_S_mis C B E
.param
+ismis10='1+3.4e-3*(1/sqrt(1e-5*1e-5*1e12))*par_bjtns1'
+bfmis10='1+3e-2*(1/sqrt(1e-5*1e-5*1e12))*par_bjtns2'
qin C B E NPN10Smis
*
.MODEL NPN10Smis NPN (                                         LEVEL    = 1
+IS       = '1.345e-017*isd*ismis10'
+BF       = '4.78*bfd*bfmis10'  NF       = '1.005*nfd'         
+VAF      = 63.793              IKF      = 0.19103             ISE      = '1.345e-017*isd'    
+NE       = 1.2                 BR       = 0.58                NR       = 1.0048              
+VAR      = 46.285              IKR      = 0.06041             ISC      = '1.345e-017*isd'    
+NC       = 1.6254              RB       = '79.185*rbd'        IRB      = 0.001               
+RBM      = '0.1*rbmd'          RE       = '4.2261*red'        RC       = '5.1599*rcd'        
+NKF      = 1.1041              SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0038998           
+TBF2     = -1.0237e-006        TBR1     = 0.0012162           TBR2     = -5.4e-006           
+TIKF1    = -0.0043143          TIKR1    = -1e-010             TNE1     = 0.0002              
+TNF1     = -0.00015            TNR1     = -9.8861e-011        TRB1     = 0.0051775           
+TRC1     = 5.0604e-005         TRE1     = 0.000948            TVAR1    = 9.9972e-011         
+CJE      = '1.283E-13*cjed'    VJE      = 1                   MJE      = 0.4                 
+CJC      = '1.339E-13*cjcd'    VJC      = 1.15                MJC      = 0.47                
+FC       = 0                   CTC      = 1.5E-03             CTE      = 7.00E-04            
+TVJC     = 5.0E-03             TVJE     = 2.0E-3              )
*
.ends NPN10_S_mis
*
*
.subckt NPN5_S_mis C B E
.param
+ismis5='1+3.4e-3*(1/sqrt(5e-6*5e-6*1e12))*par_bjtns1'
+bfmis5='1+3e-2*(1/sqrt(5e-6*5e-6*1e12))*par_bjtns2'
qin C B E NPN5Smis       
*
.MODEL NPN5Smis NPN (                                          LEVEL    = 1
+IS       = '3.665e-018*isd*ismis5'
+BF       = '5.7*bfd*bfmis5'    NF       = '1.005*nfd'         
+VAF      = 63.793              IKF      = 0.0054068           ISE      = '3.665e-018*isd'    
+NE       = 1.1525              BR       = 0.416               NR       = 1.0048              
+VAR      = 46.285              IKR      = 0.03                ISC      = '3.665e-018*isd'    
+NC       = 1.07                RB       = '16*rbd'            IRB      = 0.001               
+RBM      = '0.1*rbmd'          RE       = '15*red'            RC       = '17*rcd'            
+NKF      = 0.23914             SUBS     = 1                   TREF     = 25                  
+XTB      = 0                   XTI      = 3                   EG       = 1.18                
+TLEV     = 0                   TLEVC    = 1                   TBF1     = 0.0038              
+TBF2     = -8.2e-006           TBR1     = 0.0012162           TBR2     = -3.2589e-006        
+TIKF1    = -0.0043143          TIKR1    = -1e-010             TNE1     = 0.0002              
+TNE2     = 3e-006              TNF1     = -0.00015            TNR1     = -9.8861e-011        
+TRB1     = 0.0051775           TRC1     = 5.0604e-005         TRE1     = 0.000948            
+TVAR1    = 9.9972e-011         CJE      = '3.286E-14*cjed'    VJE      = 1                   
+MJE      = 0.4                 CJC      = '5.238E-14*cjcd'    VJC      = 1.15                
+MJC      = 0.47                FC       = 0                   CTC      = 1.5E-03             
+CTE      = 7.00E-04            TVJC     = 5.0E-03             TVJE     = 2.0E-3             )
*
.ends NPN5_S_mis
*
*
.subckt NPN2_S_mis C B E
.param
+ismis2='1+3.4e-3*(1/sqrt(2e-6*2e-6*1e12))*par_bjtns1'
+bfmis2='1+3e-2*(1/sqrt(2e-6*2e-6*1e12))*par_bjtns2'
qin C B E NPN2Smis
*
.MODEL NPN2Smis NPN (                                LEVEL   = 1
+is      = '7.41e-019*isd*ismis2'
+subs    = 1               rb      = '20*rbd'            
+re      = '21.183*red'    irb     = 0.001           rc      = '16.306*rcd'        
+rbm     = '0.1*rbmd'      bf      = '9*bfd*bfmis2'  nf      = '1.004*nfd'         
+vaf     = 68.913          ikf     = 0.00066735      ise     = '7.41e-019*isd'     
+ne      = 1.118           br      = 0.195           nr      = 1.005         
+var     = 28.81           ikr     = 0.1             nkf     = 0.2428        
+isc     = '7.41e-019*isd' nc      = 1.0399          xtb     = 0
+xti     = 3               eg      = 1.18            tref    = 25
+CJC     = '2.103E-14*cjcd'
+CJE     = '5.636E-15*cjed'
+mje     = 0.4    
+fc      = 0               mjc     = 0.47            vjc     = 1.15      
+ctc     = 0.0015          cte     = 0.0007          vje     = 1
+tlev    = 0               tlevc   = 1               tvjc    = 0.005         
+tvje    = 0.002           tis1    = 0             
+tise1   = 0               tisc1   = 0               tnf1    = -8.12e-005    
+tnr1    = 2e-012          tne1    = 0.00012598      tnc1    = 0             
+tbf1    = 0.003698        tbr1    = 0.0013496       tvaf1   = 6e-012        
+tvar1   = 0               tikf1   = -0.00621        tikr1   = -2.02e-012    
+trb1    = 0.00048837      trc1    = 0.0016519       tre1    = 9.184e-006    
+tbf2    = 9e-006          tbr2    = -4.4e-006       )
*
.ends NPN2_S_mis
*
*
.ENDL BIP_NPN_S


.lib mc_dio
.param
*+par1_dio=AGAUSS(0,1,3) 
+A1_dio='par1_bip_dio*2.4495e+000*3/3' 

+is_d            = '1.0000e+000+(-1.2247e-001)*A1_dio'
+x_jsw_d         = '0.0000e+000+(-4.0825e-001)*A1_dio'
+n_d             = '1.0000e+000+(-1.0206e-003)*A1_dio'
+rs_d            = '1.0000e+000+(8.1650e-002)*A1_dio'
+cj_d            = '1.0000e+000+(2.8577e-002)*A1_dio'
+cjsw_d          = '1.0000e+000+(2.8577e-002)*A1_dio'


.lib 'crn65lp_v1d5.l' DIO
.endl mc_dio








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO
.param
+is_d= 1         x_jsw_d= 0         n_d= 1         rs_d= 1
+cj_d= 1         cjsw_d= 1
.lib 'crn65lp_v1d5.l' DIO
.ENDL TT_DIO







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO
.param
+is_d= 0.7       x_jsw_d= -1       n_d= 0.9975         rs_d= 1.2
+cj_d= 1.07      cjsw_d= 1.07
.lib 'crn65lp_v1d5.l' DIO
.ENDL SS_DIO







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO
.param
+is_d= 1.3        x_jsw_d= 1        n_d= 1.0025         rs_d= 0.8
+cj_d= 0.93       cjsw_d= 0.93
.lib 'crn65lp_v1d5.l' DIO
.ENDL FF_DIO







***************************************************************
*                                                             *
*          Standard-vt Junction DIODE MODELS                  *
*                                                             *
***************************************************************
.LIB DIO
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************
.MODEL NDIO D (                                          LEVEL  = 3
+ IS     = '2.01E-07*is_d'   IKR    = 1E10               RS     = '1.0E-10*rs_d'
+ N      = '1.02*n_d'        BV     = 9.10               IBV    = 0.03
+ JSW    = '4.17E-13*pwr(2,x_jsw_d)'  CJ     = '1.251E-03*cj_d'   PJ     = 7.2E-4
+ MJ     = 0.40              FC     = 0                  CJSW   = '7.9E-11*cjsw_d'
+ AREA   = 3.08E-8           MJSW   = 0.005              TLEVC  = 1
+ CTA    = 7.00E-04          CTP    = 5.00E-04           TRS    = 2.5E-3
+ TCV    = -0.90E-03         TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 1                  PB     = 1
+ IK     = 1E20              TPB    = 2.0E-3             TREF   = 25
+ TPHP   = 4E-04             FCS    = 0                  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************
.MODEL PDIO D (                                          LEVEL  = 3
+ IS     = '1.82E-07*is_d'   IKR    = 1E10               RS     = '1.0E-10*rs_d'
+ N      = '1.00*n_d'        BV     = 9.4                IBV    = 0.03
+ JSW    = '2.71E-13*pwr(2,x_jsw_d)'  CJ     = '1.077E-03*cj_d'   PJ     = 7.2E-4
+ MJ     = 0.40              FC     = 0                  CJSW   = '6.4E-11*cjsw_d'
+ AREA   = 3.08E-8           MJSW   = 0.062              TLEVC  = 1
+ CTA    = 1.05E-03          CTP    = 2E-04              TRS    = 2.5E-3
+ TCV    = -8.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 1                  PB     = 1
+ IK     = 1E20              TPB    = 3E-3               TREF   = 25
+ TPHP   = 2E-03             FCS    = 0                  )

***************************************************************
*                      MODEL OF NW/PSUB DIODE                 *
*                                                             *
***************************************************************

.MODEL NWDIO D (                                         LEVEL  = 3
+ IS     = '3.41E-06*is_d'   IKR    = 1E10               RS     = '1.0E-10*rs_d'
+ N      = '1.02*n_d'        BV     = 12                 IBV    = 0.03
+ JSW    = '1.05E-12*pwr(2,x_jsw_d)'  CJ     = '1.37E-04*cj_d'    PJ     = 7.24E-4
+ MJ     = 0.33              FC     = 0                  CJSW   = '7.25E-10*cjsw_d'
+ AREA   = 3.1161E-8         MJSW   = 0.35               TLEVC  = 1
+ CTA    = 2.3E-03           CTP    = 1.16E-03           TRS    = 2.5E-3
+ TCV    = -9.5E-04          TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.65               PB     = 0.5
+ IK     = 1E20              TPB    = 2.6E-03            TREF   = 25
+ TPHP   = 1.90E-03          FCS    = 0                  )

.ENDL DIO








***************************************************************
*                                                             *
*          High-vt Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.lib mc_dio_HVT
.param
*+par1_dio_HVT=AGAUSS(0,1,3) 
+A1_dio_HVT='par1_bip_dio*2.4495e+000*3/2.95' 

+is_d_hvt        = '1.0000e+000+(-1.2247e-001)*A1_dio_HVT'
+x_jsw_d_hvt     = '0.0000e+000+(-4.0825e-001)*A1_dio_HVT'
+n_d_hvt         = '1.0000e+000+(-1.0206e-003)*A1_dio_HVT'
+rs_d_hvt        = '1.0000e+000+(8.1650e-002)*A1_dio_HVT'
+cj_d_hvt        = '1.0000e+000+(2.8577e-002)*A1_dio_HVT'
+cjsw_d_hvt      = '1.0000e+000+(2.8577e-002)*A1_dio_HVT'


.lib 'crn65lp_v1d5.l' DIO_hvt
.endl mc_dio_HVT








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_HVT
.param
+is_d_hvt= 1         x_jsw_d_hvt= 0         n_d_hvt= 1         rs_d_hvt= 1
+cj_d_hvt= 1         cjsw_d_hvt= 1
.lib 'crn65lp_v1d5.l' DIO_hvt
.ENDL TT_DIO_HVT







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_HVT
.param
+is_d_hvt= 0.7       x_jsw_d_hvt= -1       n_d_hvt= 0.9975         rs_d_hvt= 1.2
+cj_d_hvt= 1.07      cjsw_d_hvt= 1.07
.lib 'crn65lp_v1d5.l' DIO_hvt
.ENDL SS_DIO_HVT







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_HVT
.param
+is_d_hvt= 1.3        x_jsw_d_hvt= 1        n_d_hvt= 1.0025         rs_d_hvt= 0.8
+cj_d_hvt= 0.93       cjsw_d_hvt= 0.93
.lib 'crn65lp_v1d5.l' DIO_hvt
.ENDL FF_DIO_HVT







***************************************************************
*                                                             *
*          High-vt Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.LIB DIO_HVT
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************
.MODEL NDIO_hvt D (                                          LEVEL  = 3
+ IS     = '1.99E-07*is_d_hvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_hvt'
+ N      = '1.02*n_d_hvt'        BV     = 8.85              IBV    = 0.03
+ JSW    = '5.1E-13*pwr(2,x_jsw_d_hvt)'   CJ     = '1.472E-03*cj_d_hvt'     PJ     = 7.2E-4
+ MJ     = 0.5               FC     = 0                  CJSW   = '9.5E-11*cjsw_d_hvt'
+ AREA   = 3.08E-8           MJSW   = 0.05               TLEVC  = 1
+ CTA    = 7.73E-04          CTP    = 5E-04           TRS    = 2.5E-3
+ TCV    = -0.90E-03         TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.48                PB     = 1.02
+ IK     = 1E20              TPB    = 1.5E-3             TREF   = 25
+ TPHP   = 1.8E-03          FCS    = 0                  )
***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************
.MODEL PDIO_hvt D (                                          LEVEL  = 3
+ IS     = '2.01E-07*is_d_hvt'  IKR    = 1E10                RS     = '1.0E-10*rs_d_hvt'
+ N      = '1.00*n_d_hvt'        BV     = 9.4                IBV    = 0.03
+ JSW    = '2.13E-13*pwr(2,x_jsw_d_hvt)'  CJ     = '1.091E-03*cj_d_hvt'      PJ     = 7.2E-4
+ MJ     = 0.42              FC     = 0                  CJSW   = '6.4E-11*cjsw_d_hvt'
+ AREA   = 3.08E-8           MJSW   = 0.04               TLEVC  = 1
+ CTA    = 8.77E-04          CTP    = 2.04E-04           TRS    = 2.5E-3
+ TCV    = -7.4E-04         TLEV   = 1                   XTI    = 3
+ EG     = 1.17              PHP    = 0.48                PB     = 1.02
+ IK     = 1E20              TPB    = 2.3E-3               TREF   = 25
+ TPHP   = 1.6E-03          FCS    = 0                  )


.ENDL DIO_HVT







***************************************************************
*                                                             *
*          mLow-vt Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.lib mc_dio_mlvt
.param
*+par1_dio_mlvt=AGAUSS(0,1,3) 
+A1_dio_mlvt='par1_bip_dio*2.4495e+000*3/3' 

+is_d_mlvt       = '1.0000e+000+(-1.2247e-001)*A1_dio_mlvt'
+x_jsw_d_mlvt    = '0.0000e+000+(-4.0825e-001)*A1_dio_mlvt'
+n_d_mlvt        = '1.0000e+000+(-1.0206e-003)*A1_dio_mlvt'
+rs_d_mlvt       = '1.0000e+000+(8.1650e-002)*A1_dio_mlvt'
+cj_d_mlvt       = '1.0000e+000+(2.8577e-002)*A1_dio_mlvt'
+cjsw_d_mlvt     = '1.0000e+000+(2.8577e-002)*A1_dio_mlvt'


.lib 'crn65lp_v1d5.l' DIO_mlvt
.endl mc_dio_mlvt








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_mlvt
.param
+is_d_mlvt= 1         x_jsw_d_mlvt= 0         n_d_mlvt= 1         rs_d_mlvt= 1
+cj_d_mlvt= 1         cjsw_d_mlvt= 1
.lib 'crn65lp_v1d5.l' DIO_mlvt
.ENDL TT_DIO_mlvt







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_mlvt
.param
+is_d_mlvt= 0.7       x_jsw_d_mlvt= -1       n_d_mlvt= 0.9975         rs_d_mlvt= 1.2
+cj_d_mlvt= 1.07      cjsw_d_mlvt= 1.07
.lib 'crn65lp_v1d5.l' DIO_mlvt
.ENDL SS_DIO_mlvt







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_mlvt
.param
+is_d_mlvt= 1.3        x_jsw_d_mlvt= 1        n_d_mlvt= 1.0025         rs_d_mlvt= 0.8
+cj_d_mlvt= 0.93       cjsw_d_mlvt= 0.93
.lib 'crn65lp_v1d5.l' DIO_mlvt
.ENDL FF_DIO_mlvt







***************************************************************
*                                                             *
*          mLow-vt Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.LIB DIO_mlvt
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************
.MODEL NDIO_mlvt D (                                          LEVEL  = 3
+ IS     = '2.01E-07*is_d_mlvt'   IKR    = 1E10               RS     = '1.0E-10*rs_d_mlvt'
+ N      = '1.02*n_d_mlvt'        BV     = 9.10               IBV    = 0.03
+ JSW    = '4.17E-13*pwr(2,x_jsw_d_mlvt)'  CJ     = '1.251E-03*cj_d_mlvt'    PJ     = 7.2E-4
+ MJ     = 0.40              FC     = 0                  CJSW   = '9.5e-011*cjsw_d_mlvt'
+ AREA   = 3.08E-8           MJSW   = 0.005              TLEVC  = 1
+ CTA    = 7.00E-04          CTP    = 5.00E-04           TRS    = 2.5E-3
+ TCV    = -0.90E-03         TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 1                  PB     = 1
+ IK     = 1E20              TPB    = 2.0E-3             TREF   = 25
+ TPHP   = 4E-04             FCS    = 0                  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************
.MODEL PDIO_mlvt D (                                          LEVEL  = 3
+ IS     = '1.82E-07*is_d_mlvt'  IKR    = 1E10                RS     = '1.0E-10*rs_d_mlvt'
+ N      = '1.00*n_d_mlvt'        BV     = 9.4                IBV    = 0.03
+ JSW    = '2.71E-13*pwr(2,x_jsw_d_mlvt)'  CJ     = '1.077E-03*cj_d_mlvt'   PJ     = 7.2E-4
+ MJ     = 0.4              FC     = 0                  CJSW   = '7.5e-011*cjsw_d_mlvt'
+ AREA   = 3.08E-8           MJSW   = 0.062              TLEVC  = 1
+ CTA    = 1.05E-03          CTP    = 2E-04           TRS    = 2.5E-3
+ TCV    = -8.5E-04         TLEV   = 1                   XTI    = 3
+ EG     = 1.17              PHP    = 1               PB     = 1
+ IK     = 1E20              TPB    = 3E-3               TREF   = 25
+ TPHP   = 2E-03          FCS    = 0                  )

.ENDL DIO_mlvt







***************************************************************
*                                                             *
*          Low-vt Junction DIODE MODELS                       *
*                                                             *
***************************************************************
.lib mc_dio_lvt
.param
*+par1_dio_lvt=AGAUSS(0,1,3) 
+A1_dio_lvt='par1_bip_dio*2.4495e+000*3/3' 

+is_d_lvt        = '1.0000e+000+(-1.2247e-001)*A1_dio_lvt'
+x_jsw_d_lvt     = '0.0000e+000+(-4.0825e-001)*A1_dio_lvt'
+n_d_lvt         = '1.0000e+000+(-1.0206e-003)*A1_dio_lvt'
+rs_d_lvt        = '1.0000e+000+(8.1650e-002)*A1_dio_lvt'
+cj_d_lvt        = '1.0000e+000+(2.8577e-002)*A1_dio_lvt'
+cjsw_d_lvt      = '1.0000e+000+(2.8577e-002)*A1_dio_lvt'


.lib 'crn65lp_v1d5.l' DIO_lvt
.endl mc_dio_lvt








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_lvt
.param
+is_d_lvt = 1.0     x_jsw_d_lvt = 0      n_d_lvt    = 1.000
+rs_d_lvt = 1.0     cj_d_lvt  = 1.00     cjsw_d_lvt = 1.00
.lib 'crn65lp_v1d5.l' DIO_lvt
.ENDL TT_DIO_lvt







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_lvt
.param
+is_d_lvt = 0.7     x_jsw_d_lvt = -1      n_d_lvt    = 0.9975
+rs_d_lvt = 1.2     cj_d_lvt  = 1.07     cjsw_d_lvt = 1.07
.lib 'crn65lp_v1d5.l' DIO_lvt
.ENDL SS_DIO_lvt







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_lvt
.param
+is_d_lvt = 1.3     x_jsw_d_lvt = 1.0      n_d_lvt    = 1.0025
+rs_d_lvt = 0.8     cj_d_lvt  = 0.93     cjsw_d_lvt = 0.93
.lib 'crn65lp_v1d5.l' DIO_lvt
.ENDL FF_DIO_lvt







***************************************************************
*                                                             *
*          Low-vt Junction DIODE MODELS                       *
*                                                             *
***************************************************************
.LIB DIO_lvt
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_lvt D (
+ IS   = '1.7E-7*is_d_lvt'       JSW   = '2.8E-13*pwr(2,x_jsw_d_lvt)'
+ RS   = '1.0E-10*rs_d_lvt'      N     = '1.005*n_d_lvt'
+ CJ   = '1.185E-03*cj_d_lvt'    CJSW  = '9.4E-11*cjsw_d_lvt'
+ BV   = 9.3                      AREA  = 3.92e-8         PJ    = 8.4E-4
+ MJ   = 0.31                  MJSW  = 0.08            PB    = 0.7
+ PHP  = 0.5                    TRS   = 2.5E-3          TCV   = -8.00E-04
+ CTA  = 7.30E-04               CTP   = 3.0E-04         TPB   = 1.5E-03
+ TPHP = 1.0E-03                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************

.MODEL PDIO_lvt D (
+ IS   = '1.15E-07*is_d_lvt'      JSW   = '1.7E-13*pwr(2,x_jsw_d_lvt)'
+ RS   = '1.0E-10*rs_d_lvt'      N     = '1.005*n_d_lvt'
+ CJ   = '1.068E-03*cj_d_lvt'    CJSW  = '7.6E-11*cjsw_d_lvt'
+ BV   = 9.4                    AREA  = 3.92e-8         PJ    = 8.4E-4
+ MJ   = 0.31                   MJSW  = 0.06            PB    = 0.7
+ PHP  = 0.9                    TRS   = 2.5E-3          TCV   = -8.0E-04
+ CTA  = 9.1E-04               CTP   = 2.2E-04         TPB   = 1.7E-03
+ TPHP = 3E-03                  IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_lvt







***************************************************************
*                                                             *
*          1.8V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.lib mc_dio_18
.param
*+par1_dio_18=AGAUSS(0,1,3) 
+A1_dio_18='par1_bip_dio*2.4495e+000*3/2.9' 

+is_d_18         = '1.0000e+000+(-1.2247e-001)*A1_dio_18'
+x_jsw_d_18      = '0.0000e+000+(-4.0825e-001)*A1_dio_18'
+n_d_18          = '1.0000e+000+(-1.0206e-003)*A1_dio_18'
+rs_d_18         = '1.0000e+000+(8.1650e-002)*A1_dio_18'
+cj_d_18         = '1.0000e+000+(2.8577e-002)*A1_dio_18'
+cjsw_d_18       = '1.0000e+000+(2.8577e-002)*A1_dio_18'


.lib 'crn65lp_v1d5.l' DIO_18
.endl mc_dio_18








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_18
.param
+is_d_18 = 1.0     x_jsw_d_18 = 0      n_d_18    = 1.000
+rs_d_18 = 1.0     cj_d_18  = 1.00     cjsw_d_18 = 1.00
.lib 'crn65lp_v1d5.l' DIO_18
.ENDL TT_DIO_18







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_18
.param
+is_d_18 = 0.7     x_jsw_d_18 = -1      n_d_18    = 0.9975
+rs_d_18 = 1.2     cj_d_18  = 1.07     cjsw_d_18 = 1.07
.lib 'crn65lp_v1d5.l' DIO_18
.ENDL SS_DIO_18







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_18
.param
+is_d_18 = 1.3     x_jsw_d_18 = 1.0      n_d_18    = 1.0025
+rs_d_18 = 0.8     cj_d_18  = 0.93     cjsw_d_18 = 0.93
.lib 'crn65lp_v1d5.l' DIO_18
.ENDL FF_DIO_18







***************************************************************
*                                                             *
*          1.8V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.LIB DIO_18
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_18 D (
+ IS   = '1.399E-7*is_d_18'     JSW   = '5.685E-13*pwr(2,x_jsw_d_18)'
+ RS   = '1.0E-10*rs_d_18'      N     = '1.02*n_d_18'
+ CJ   = '1.195E-03*cj_d_18'    CJSW  = '1.65E-10*cjsw_d_18'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.12            PB    = 0.7
+ PHP  = 0.48                   TRS   = 2.5E-3          TCV   = -8.80E-04
+ CTA  = 8.62E-04               CTP   = 3.52E-04        TPB   = 1.70E-03
+ TPHP = 1.10E-03               IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************

.MODEL PDIO_18 D (
+ IS   = '1.13E-07*is_d_18'     JSW   = '2.70E-13*pwr(2,x_jsw_d_18)'
+ RS   = '1.0E-10*rs_d_18'      N     = '1.005*n_d_18'
+ CJ   = '1.111E-03*cj_d_18'    CJSW  = '9.7E-11*cjsw_d_18'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.082           PB    = 0.7
+ PHP  = 0.50                   TRS   = 2.5E-3          TCV   = -8.5E-04
+ CTA  = 8.78E-04               CTP   = 3.16E-04        TPB   = 1.60E-03
+ TPHP = 1.5E-03                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_18







***************************************************************
*                                                             *
*          2.5V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.lib mc_dio_25
.param
*+par1_dio_25=AGAUSS(0,1,3) 
+A1_dio_25='par1_bip_dio*2.4495e+000*3/2.9' 

+is_d_25         = '1.0000e+000+(-1.2247e-001)*A1_dio_25'
+x_jsw_d_25      = '0.0000e+000+(-4.0825e-001)*A1_dio_25'
+n_d_25          = '1.0000e+000+(-1.0206e-003)*A1_dio_25'
+rs_d_25         = '1.0000e+000+(8.1650e-002)*A1_dio_25'
+cj_d_25         = '1.0000e+000+(2.8577e-002)*A1_dio_25'
+cjsw_d_25       = '1.0000e+000+(2.8577e-002)*A1_dio_25'


.lib 'crn65lp_v1d5.l' DIO_25
.endl mc_dio_25








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_25
.param
+is_d_25 = 1.0     x_jsw_d_25 = 0      n_d_25    = 1.000
+rs_d_25 = 1.0     cj_d_25  = 1.00     cjsw_d_25 = 1.00
.lib 'crn65lp_v1d5.l' DIO_25
.ENDL TT_DIO_25







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_25
.param
+is_d_25 = 0.7     x_jsw_d_25 = -1      n_d_25    = 0.9975
+rs_d_25 = 1.2     cj_d_25  = 1.07     cjsw_d_25 = 1.07
.lib 'crn65lp_v1d5.l' DIO_25
.ENDL SS_DIO_25







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_25
.param
+is_d_25 = 1.3     x_jsw_d_25 = 1.0      n_d_25    = 1.0025
+rs_d_25 = 0.8     cj_d_25  = 0.93     cjsw_d_25 = 0.93
.lib 'crn65lp_v1d5.l' DIO_25
.ENDL FF_DIO_25







***************************************************************
*                                                             *
*          2.5V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.LIB DIO_25
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_25 D (
+ IS   = '1.399E-7*is_d_25'     JSW   = '5.685E-13*pwr(2,x_jsw_d_25)'
+ RS   = '1.0E-10*rs_d_25'      N     = '1.02*n_d_25'
+ CJ   = '1.195E-03*cj_d_25'    CJSW  = '1.65E-10*cjsw_d_25'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.12            PB    = 0.7
+ PHP  = 0.48                   TRS   = 2.5E-3          TCV   = -8.80E-04
+ CTA  = 8.62E-04               CTP   = 3.52E-04        TPB   = 1.70E-03
+ TPHP = 1.10E-03               IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************

.MODEL PDIO_25 D (
+ IS   = '1.13E-07*is_d_25'     JSW   = '2.70E-13*pwr(2,x_jsw_d_25)'
+ RS   = '1.0E-10*rs_d_25'      N     = '1.005*n_d_25'
+ CJ   = '1.111E-03*cj_d_25'    CJSW  = '9.7E-11*cjsw_d_25'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.082           PB    = 0.7
+ PHP  = 0.50                   TRS   = 2.5E-3          TCV   = -8.5E-04
+ CTA  = 8.78E-04               CTP   = 3.16E-04        TPB   = 1.60E-03
+ TPHP = 1.5E-03                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_25







***************************************************************
*                                                             *
*          3.3V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.lib mc_dio_33
.param
*+par1_dio_33=AGAUSS(0,1,3) 
+A1_dio_33='par1_bip_dio*2.4495e+000*3/2.9' 

+is_d_33         = '1.0000e+000+(-1.2247e-001)*A1_dio_33'
+x_jsw_d_33      = '0.0000e+000+(-4.0825e-001)*A1_dio_33'
+n_d_33          = '1.0000e+000+(-1.0206e-003)*A1_dio_33'
+rs_d_33         = '1.0000e+000+(8.1650e-002)*A1_dio_33'
+cj_d_33         = '1.0000e+000+(2.8577e-002)*A1_dio_33'
+cjsw_d_33       = '1.0000e+000+(2.8577e-002)*A1_dio_33'


.lib 'crn65lp_v1d5.l' DIO_33
.endl mc_dio_33








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_33
.param
+is_d_33 = 1.0     x_jsw_d_33 = 0      n_d_33    = 1.000
+rs_d_33 = 1.0     cj_d_33  = 1.00     cjsw_d_33 = 1.00
.lib 'crn65lp_v1d5.l' DIO_33
.ENDL TT_DIO_33







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_33
.param
+is_d_33 = 0.7     x_jsw_d_33 = -1      n_d_33    = 0.9975
+rs_d_33 = 1.2     cj_d_33  = 1.07     cjsw_d_33 = 1.07
.lib 'crn65lp_v1d5.l' DIO_33
.ENDL SS_DIO_33







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_33
.param
+is_d_33 = 1.3     x_jsw_d_33 = 1.0      n_d_33    = 1.0025
+rs_d_33 = 0.8     cj_d_33  = 0.93     cjsw_d_33 = 0.93
.lib 'crn65lp_v1d5.l' DIO_33
.ENDL FF_DIO_33







***************************************************************
*                                                             *
*          3.3V IO Junction DIODE MODELS                      *
*                                                             *
***************************************************************
.LIB DIO_33
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_33 D (
+ IS   = '1.399E-7*is_d_33'     JSW   = '5.685E-13*pwr(2,x_jsw_d_33)'
+ RS   = '1.0E-10*rs_d_33'      N     = '1.02*n_d_33'
+ CJ   = '1.195E-03*cj_d_33'    CJSW  = '1.65E-10*cjsw_d_33'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.12            PB    = 0.7
+ PHP  = 0.48                   TRS   = 2.5E-3          TCV   = -8.80E-04
+ CTA  = 8.62E-04               CTP   = 3.52E-04        TPB   = 1.70E-03
+ TPHP = 1.10E-03               IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

***************************************************************
*                      MODEL OF P+/NW DIODE                   *
*                                                             *
***************************************************************

.MODEL PDIO_33 D (
+ IS   = '1.13E-07*is_d_33'     JSW   = '2.70E-13*pwr(2,x_jsw_d_33)'
+ RS   = '1.0E-10*rs_d_33'      N     = '1.005*n_d_33'
+ CJ   = '1.111E-03*cj_d_33'    CJSW  = '9.7E-11*cjsw_d_33'
+ BV   = 9.0                    AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.31                   MJSW  = 0.082           PB    = 0.7
+ PHP  = 0.50                   TRS   = 2.5E-3          TCV   = -8.5E-04
+ CTA  = 8.78E-04               CTP   = 3.16E-04        TPB   = 1.60E-03
+ TPHP = 1.5E-03                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_33







***************************************************************
*                                                             *
*          Native Junction DIODE MODELS                       *
*                                                             *
***************************************************************
.lib mc_dio_na
.param
*+par1_dio_na=AGAUSS(0,1,3) 
+A1_dio_na='par1_bip_dio*2.4495e+000*3/3.05' 

+is_d_na         = '1.0000e+000+(-1.2247e-001)*A1_dio_na'
+x_jsw_d_na      = '0.0000e+000+(-4.0825e-001)*A1_dio_na'
+n_d_na          = '1.0000e+000+(-1.0206e-003)*A1_dio_na'
+rs_d_na         = '1.0000e+000+(8.1650e-002)*A1_dio_na'
+cj_d_na         = '1.0000e+000+(2.8577e-002)*A1_dio_na'
+cjsw_d_na       = '1.0000e+000+(2.8577e-002)*A1_dio_na'


.lib 'crn65lp_v1d5.l' DIO_na
.endl mc_dio_na








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_na
.param
+is_d_na = 1.0     x_jsw_d_na = 0      n_d_na    = 1.000
+rs_d_na = 1.0     cj_d_na  = 1.00     cjsw_d_na = 1.00
.lib 'crn65lp_v1d5.l' DIO_na
.ENDL TT_DIO_na







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_na
.param
+is_d_na = 0.7     x_jsw_d_na = -1      n_d_na    = 0.9975
+rs_d_na = 1.2     cj_d_na  = 1.07     cjsw_d_na = 1.07
.lib 'crn65lp_v1d5.l' DIO_na
.ENDL SS_DIO_na







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_na
.param
+is_d_na = 1.3     x_jsw_d_na = 1.0      n_d_na    = 1.0025
+rs_d_na = 0.8     cj_d_na  = 0.93     cjsw_d_na = 0.93
.lib 'crn65lp_v1d5.l' DIO_na
.ENDL FF_DIO_na







***************************************************************
*                                                             *
*          Native Junction DIODE MODELS                       *
*                                                             *
***************************************************************
.LIB DIO_na
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_na D (
+ IS   = '5.11E-6*is_d_na'       JSW   = '5.46E-12*pwr(2,x_jsw_d_na)'
+ RS   = '1.0E-10*rs_d_na'      N     = '1.02*n_d_na'
+ CJ   = '1.55E-04*cj_d_na'     CJSW  = '1.82E-10*cjsw_d_na'
+ BV   = 19                   AREA  = 3.08E-8         PJ    = 7.2E-4
+ MJ   = 0.24                   MJSW  = 0.01          PB    = 0.25
+ PHP  = 1                   TRS   = 2.5E-3          TCV   = -6.550E-04
+ CTA  = 1.68e-3                CTP   = 1E-04         TPB   = 1.0e-3
+ TPHP = 1E-03                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_na







***************************************************************
*                                                             *
*          Native 2.5V IO Junction DIODE MODELS               *
*                                                             *
***************************************************************
.lib mc_dio_na25
.param
*+par1_dio_na25=AGAUSS(0,1,3) 
+A1_dio_na25='par1_bip_dio*2.4495e+000*3/3' 

+is_d_na25       = '1.0000e+000+(-1.2247e-001)*A1_dio_na25'
+x_jsw_d_na25    = '0.0000e+000+(-4.0825e-001)*A1_dio_na25'
+n_d_na25        = '1.0000e+000+(-1.0206e-003)*A1_dio_na25'
+rs_d_na25       = '1.0000e+000+(8.1650e-002)*A1_dio_na25'
+cj_d_na25       = '1.0000e+000+(2.8577e-002)*A1_dio_na25'
+cjsw_d_na25     = '1.0000e+000+(2.8577e-002)*A1_dio_na25'


.lib 'crn65lp_v1d5.l' DIO_na25
.endl mc_dio_na25








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_na25
.param
+is_d_na25 = 1.0     x_jsw_d_na25 = 0.0      n_d_na25    = 1.000
+rs_d_na25 = 1.0     cj_d_na25  = 1.00     cjsw_d_na25 = 1.00
.lib 'crn65lp_v1d5.l' DIO_na25
.ENDL TT_DIO_na25







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_na25
.param
+is_d_na25 = 0.7     x_jsw_d_na25 = -1      n_d_na25    = 0.9975
+rs_d_na25 = 1.2     cj_d_na25  = 1.07     cjsw_d_na25 = 1.07
.lib 'crn65lp_v1d5.l' DIO_na25
.ENDL SS_DIO_na25







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_na25
.param
+is_d_na25 = 1.3     x_jsw_d_na25 = 1.0      n_d_na25    = 1.0025
+rs_d_na25 = 0.8     cj_d_na25  = 0.93     cjsw_d_na25 = 0.93
.lib 'crn65lp_v1d5.l' DIO_na25
.ENDL FF_DIO_na25







***************************************************************
*                                                             *
*          Native 2.5V IO Junction DIODE MODELS               *
*                                                             *
***************************************************************
.LIB DIO_na25
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_na25 D (
+ IS   = '8.43e-7*is_d_na25'    JSW   = '1.36E-12*pwr(2,x_jsw_d_na25)'
+ RS   = '1.0E-10*rs_d_na25'    N     = '1.02*n_d_na25'
+ CJ   = '1.4516E-04*cj_d_na25' CJSW  = '1.935E-10*cjsw_d_na25'
+ BV   = 17.8                   AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.39                   MJSW  = 0.01            PB    = 0.7
+ PHP  = 0.7                    TRS   = 1.3E-3          TCV   = -7.00E-04
+ CTA  = 1.34E-03               CTP   = 3.0E-04         TPB   = 2.01E-03
+ TPHP = 4.0E-04                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_na25



*******************************************************************************
*                                                                             *
*          Native 2.5V over-drive 3.3V IO Junction DIODE MODELS               *
*                                                                             *
*******************************************************************************
***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_na25od33
.param
+is_d_na25od33 = 1.0     jsw_d_na25od33 = 1.0      n_d_na25od33    = 1.000
+rs_d_na25od33 = 1.0     cj_d_na25od33  = 1.00     cjsw_d_na25od33 = 1.00
.lib 'crn65lp_v1d5.l' DIO_na25od33
.ENDL TT_DIO_na25od33

***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_na25od33
.param
+is_d_na25od33 = 0.7     jsw_d_na25od33 = 0.5      n_d_na25od33    = 0.9975
+rs_d_na25od33 = 1.2     cj_d_na25od33  = 1.07     cjsw_d_na25od33 = 1.07
.lib 'crn65lp_v1d5.l' DIO_na25od33
.ENDL SS_DIO_na25od33

***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_na25od33
.param
+is_d_na25od33 = 1.3     jsw_d_na25od33 = 2.0      n_d_na25od33    = 1.0025
+rs_d_na25od33 = 0.8     cj_d_na25od33  = 0.93     cjsw_d_na25od33 = 0.93
.lib 'crn65lp_v1d5.l' DIO_na25od33
.ENDL FF_DIO_na25od33

*******************************************************************************
*                                                                             *
*          Native 2.5V over-drive 3.3V IO Junction DIODE MODELS               *
*                                                                             *
*******************************************************************************
.LIB DIO_na25od33
*
***************************************************************
*                      MODEL OF N+/PW DIODE                   *
*                                                             *
***************************************************************

.MODEL NDIO_na25od33 D (
+ IS   = '8.43e-7*is_d_na25od33'    JSW   = '1.36E-12*jsw_d_na25od33'
+ RS   = '1.0E-10*rs_d_na25od33'    N     = '1.02*n_d_na25od33'
+ CJ   = '1.4516E-04*cj_d_na25od33' CJSW  = '1.935E-10*cjsw_d_na25od33'
+ BV   = 17.8                   AREA  = 3.08e-8         PJ    = 7.2E-4
+ MJ   = 0.39                   MJSW  = 0.01            PB    = 0.7
+ PHP  = 0.7                    TRS   = 1.3E-3          TCV   = -7.00E-04
+ CTA  = 1.34E-03               CTP   = 3.0E-04         TPB   = 2.01E-03
+ TPHP = 4.0E-04                IK    = 1E20            IKR   = 1E10		
+ IBV  = 0.03                   TREF  = 25              FC    = 0
+ FCS  = 0                      TLEV  = 1               TLEVC = 1
+ XTI  = 3                      EG    = 1.17            LEVEL = 3  )

.ENDL DIO_na25od33

***************************************************************
*                                                             *
*          DNW Junction DIODE MODELS                          *
*                                                             *
***************************************************************
.lib mc_dio_DNW
.param
*+par1_dio_DNW=AGAUSS(0,1,3) 
+A1_dio_DNW='par1_bip_dio*2.4495e+000*3/2.95' 

+is_d_dnw        = '1.0000e+000+(-1.2247e-001)*A1_dio_DNW'
+x_jsw_d_dnw     = '0.0000e+000+(-4.0825e-001)*A1_dio_DNW'
+n_d_dnw         = '1.0000e+000+(-1.0206e-003)*A1_dio_DNW'
+rs_d_dnw        = '1.0000e+000+(8.1650e-002)*A1_dio_DNW'
+cj_d_dnw        = '1.0000e+000+(2.8577e-002)*A1_dio_DNW'
+cjsw_d_dnw      = '1.0000e+000+(2.8577e-002)*A1_dio_DNW'


.lib 'crn65lp_v1d5.l' DIO_DNW
.endl mc_dio_DNW








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_DNW
.param
+is_d_dnw= 1         x_jsw_d_dnw= 0         n_d_dnw= 1         rs_d_dnw= 1
+cj_d_dnw= 1         cjsw_d_dnw= 1
.lib 'crn65lp_v1d5.l' DIO_DNW
.ENDL TT_DIO_DNW







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_DNW
.param
+is_d_dnw= 0.7         x_jsw_d_dnw= -1         n_d_dnw= 0.9975        rs_d_dnw= 1.2
+cj_d_dnw= 1.07        cjsw_d_dnw= 1.07
.lib 'crn65lp_v1d5.l' DIO_DNW
.ENDL SS_DIO_DNW







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_DNW
.param
+is_d_dnw= 1.3         x_jsw_d_dnw= 1         n_d_dnw= 1.0025        rs_d_dnw= 0.8
+cj_d_dnw= 0.93        cjsw_d_dnw= 0.93
.lib 'crn65lp_v1d5.l' DIO_DNW
.ENDL FF_DIO_DNW







***************************************************************
*                                                             *
*          DNW Junction DIODE MODELS                          *
*                                                             *
***************************************************************
.LIB DIO_DNW
*
***************************************************************
*                     MODEL OF PW/DNW DIODE                   *
*                                                             *
***************************************************************

.MODEL PWDNW D (                                               LEVEL  = 3
+ IS     = '3.6E-06*is_d_dnw'   IKR    = 1E10                 RS     = '1.0E-10*rs_d_dnw'
+ N      = '1.02*n_d_dnw'        BV     = 12.31                IBV    = 0.03
+ JSW    = '1.3E-13*pwr(2,x_jsw_d_dnw)'  CJ     = '7.31E-04*cj_d_dnw'  PJ     = 6.824E-4
+ MJ     = 0.47                  FC     = 0                    CJSW   = '6.46E-10*cjsw_d_dnw'
+ AREA   = 2.820436E-8           MJSW   = 0.36                 TLEVC  = 1
+ CTA    = 1.5E-03               CTP    = 9.0E-04             TRS    = 2.5E-3
+ TCV    = -9.00E-04             TLEV   = 1                    XTI    = 3
+ EG     = 1.17                  PHP    = 0.65                 PB     = 1.15
+ IK     = 1E20                  TPB    = 5.0E-03              TREF   = 25
+ TPHP   = 1.5E-03               FCS    = 0                  )

***************************************************************
*                     MODEL OF DNW/PSUB DIODE                 *
*                                                             *
***************************************************************

.MODEL DNWPSUB D (                                            LEVEL  = 3
+ IS     = '3.68E-06*is_d_dnw'   IKR    = 1E10                RS     = '1E-10*rs_d_dnw'
+ N      = '1.02*n_d_dnw'        BV     = 11.92               IBV    = 0.03
+ JSW    = '8.80E-12*pwr(2,x_jsw_d_dnw)'  CJ     = '1.15E-04*cj_d_dnw' PJ     = 7.24E-4
+ MJ     = 0.36                  FC     = 0                   CJSW   = '1.33E-09*cjsw_d_dnw'
+ AREA   = 3.1161E-8             MJSW   = 0.355                TLEVC  = 1
+ CTA    = 2.2E-03               CTP    = 1.2E-03            TRS    = 2.5E-3
+ TCV    = -9.50E-04             TLEV   = 1                   XTI    = 3
+ EG     = 1.17                  PHP    = 0.77                PB     = 0.64
+ IK     = 1E20                  TPB    = 3.5E-03            TREF   = 25
+ TPHP   = 2.60E-03              FCS    = 0                  )


.ENDL DIO_DNW







***************************************************************
*                                                             *
*          ESD Junction DIODE MODELS                          *
*                                                             *
***************************************************************
.lib mc_dio_ESD
.param
*+par1_dio_ESD=AGAUSS(0,1,3) 
+A1_dio_ESD='par1_bip_dio*2.4495e+000*3/3' 

+is_d_esd        = '1.0000e+000+(-1.2247e-001)*A1_dio_ESD'
+x_jsw_d_esd     = '0.0000e+000+(-4.0825e-001)*A1_dio_ESD'
+n_d_esd         = '1.0000e+000+(-1.0206e-003)*A1_dio_ESD'
+rs_d_esd        = '1.0000e+000+(8.1650e-002)*A1_dio_ESD'
+cj_d_esd        = '1.0000e+000+(2.8577e-002)*A1_dio_ESD'
+cjsw_d_esd      = '1.0000e+000+(2.8577e-002)*A1_dio_ESD'


.lib 'crn65lp_v1d5.l' DIO_ESD
.endl mc_dio_ESD








***************     CORNER_LIB OF TYPICAL MODEL     ***************
.LIB TT_DIO_ESD
.param
+is_d_esd= 1         x_jsw_d_esd= 0         n_d_esd= 1         rs_d_esd= 1
+cj_d_esd= 1         cjsw_d_esd= 1
.lib 'crn65lp_v1d5.l' DIO_ESD
.ENDL TT_DIO_ESD







***************     CORNER_LIB OF SLOW MODEL     ***************
.LIB SS_DIO_ESD
.param
+is_d_esd= 0.7         x_jsw_d_esd= -1         n_d_esd= 0.9975        rs_d_esd= 1.2
+cj_d_esd= 1.07        cjsw_d_esd= 1.07
.lib 'crn65lp_v1d5.l' DIO_ESD
.ENDL SS_DIO_ESD







***************     CORNER_LIB OF FAST MODEL     ***************
.LIB FF_DIO_ESD
.param
+is_d_esd= 1.3         x_jsw_d_esd= 1         n_d_esd= 1.0025        rs_d_esd= 0.8
+cj_d_esd= 0.93        cjsw_d_esd= 0.93
.lib 'crn65lp_v1d5.l' DIO_ESD
.ENDL FF_DIO_ESD







***************************************************************
*                                                             *
*          ESD Junction DIODE MODELS                          *
*                                                             *
***************************************************************
.LIB DIO_ESD
*
***************************************************************
*                      MODEL OF ESD DIODE                     *
*                                                             *
***************************************************************

.MODEL NDIO_ESD D (                                           LEVEL  = 3
+ IS     = '5.7E-07*is_d_esd'   IKR    = 1E10               RS     = '1E-10*rs_d_esd'
+ N      = '1.02*n_d_esd'        BV     = 6.0               IBV    = 0.03
+ JSW    = '6.5E-13*pwr(2,x_jsw_d_esd)'  CJ     = '2.11E-03*cj_d_esd'    PJ     = 7.24E-4
+ MJ     = 0.36              FC     = 0                  CJSW   = '1.15E-10*cjsw_d_esd'
+ AREA   = 3.1161E-8         MJSW   = 0.06               TLEVC  = 1
+ CTA    = 8.0E-04          CTP    = 2E-04           TRS    = 2.5E-3
+ TCV    = -7.4E-04         TLEV   = 1                  XTI    = 3
+ EG     = 1.17              PHP    = 0.79                PB     = 0.89
+ IK     = 1E20              TPB    = 2.3E-03           TREF   = 25
+ TPHP   = 2.0E-03          FCS    = 0                  )


.ENDL DIO_ESD







.lib mc_mos_cap
.param
*+par1_var=AGAUSS(0,1,3) par2_var=AGAUSS(0,1,3) 
+parmvar=AGAUSS(0,1,1)
+A1_var='-par1*2.2203e+000*3/3' 
+A2_var='-par2*2.6509e-001*3/3' 

+Cgmin_Var       = '1.0000e+000+(4.4963e-002)*A1_var+(2.1870e-002)*A2_var'
+dCg_Var         = '1.0000e+000+(1.7086e-002)*A1_var+(8.3107e-003)*A2_var'
+dxL_Var         = '0.0000e+000+(-3.3722e-009)*A1_var+(-1.6403e-009)*A2_var'
+dxW_Var         = '0.0000e+000+(5.3956e-009)*A1_var+(2.6244e-009)*A2_var'
+fac_var         = '1.0000e+000+(6.8651e-001)*A1_var+(-1.4114e+000)*A2_var'

.lib 'crn65lp_v1d5.l' MOS_CAP
.endl mc_mos_cap



***************************     CORNER_LIB OF TYPICAL MODEL     ***************************
.LIB TT_MOS_CAP
.param
+parmvar=AGAUSS(0,1,1)
+Cgmin_Var= 1        dCg_Var= 1         dxL_Var= 0            dxW_Var= 0
+fac_var  = 1
.lib 'crn65lp_v1d5.l' MOS_CAP
.ENDL TT_MOS_CAP



***************************     CORNER_LIB OF SLOW MODEL     ***************************
.LIB SS_MOS_CAP
.param
+parmvar=AGAUSS(0,1,1)
+Cgmin_Var= 0.9      dCg_Var= 0.962     dxL_Var= 7.5E-09      dxW_Var= -12.0E-09
+fac_var  = 0.3
.lib 'crn65lp_v1d5.l' MOS_CAP
.ENDL SS_MOS_CAP



***************************     CORNER_LIB OF FAST MODEL     ***************************
.LIB FF_MOS_CAP
.param
+parmvar=AGAUSS(0,1,1)
+Cgmin_Var= 1.1      dCg_Var= 1.038     dxL_Var= -7.5E-09     dxW_Var= 12.0E-09
+fac_var  = 3.3
.lib 'crn65lp_v1d5.l' MOS_CAP
.ENDL FF_MOS_CAP



**************************************************************************
*                                                                        *
*              NMOS in N-Well varactor MODEL                             *
*                                                                        *
**************************************************************************
.LIB MOS_CAP
*
.subckt nmoscap ng nds lr=1E-6 wr=1E-6 scale=1 mismatchflag=0
.param XL=3.46E-08
.param XW=-1.60E-08
.param area='(lr*scale-XL+dxL_Var)*(wr*scale-XW+dxW_Var)'
.param Cgmin='3.09E-10*Cgmin_Var*2*(wr*scale-XW+dxW_Var)+2.19E-10*Cgmin_Var*2*(lr*scale-XL+dxL_Var)+1.61E-03*Cgmin_Var*area'
.param dCg='60E-12*dCg_Var*2*(wr*scale-XW+dxW_Var)-5E-12*dCg_Var*2*(lr*scale-XL+dxL_Var)+5.704E-03*dCg_Var*area'
.param dVgs='-0.09-1.0E-04*(temper-25)'
.param Vgnorm='0.39+6.0E-04*(temper-25)'
.param geo_fac='sqrt(2)/sqrt(lr*wr*1e12)'

cg ng nds 'Cgmin*(1+0.01*geo_fac*parmvar*mismatchflag*(0.092+0.151*(1-tanh((v(ng,nds)-0.09)/0.39))))+dCg*(1.0+tanh((v(ng,nds)-dVgs)/Vgnorm))*(1+0.00092*geo_fac*parmvar*mismatchflag)'

.param for_eff='110'
.param gtmp='2.0E-12'
.param varbf='3'
.param rev_eff='4.3'
.param varbr='-0.6'

GDF1 ng nds Cur="scale*fac_var*(for_eff*area*pwr((abs(v(ng,nds))+v(ng,nds))/2,varbf+2)+gtmp*(abs(v(ng,nds))+v(ng,nds))-rev_eff*area*pwr((abs(v(ng,nds))-v(ng,nds))/2,varbr+2))"

.ends nmosCAP

.ENDL MOS_CAP





*************************Varactor IO *****************************************************
.lib mc_mos_cap_25
.param
*+par1_var_25=AGAUSS(0,1,3) 
+parmvar_25=AGAUSS(0,1,1)
+A1_var_25='-par6*2.0000e+000*3/2.9' 

+Cgmin_Var25     = '1.0000e+000+(-5.0000e-002)*A1_var_25'
+dCg_Var25       = '1.0000e+000+(-2.6800e-002)*A1_var_25'
+dxL_Var25       = '0.0000e+000+(5.0000e-009)*A1_var_25'
+dxW_Var25       = '0.0000e+000+(-6.0000e-009)*A1_var_25'

.lib 'crn65lp_v1d5.l' MOS_CAP_25
.endl mc_mos_cap_25



***************************     CORNER_LIB OF TYPICAL MODEL     ***************************
.LIB TT_MOS_CAP_25
.param
+parmvar_25=AGAUSS(0,1,1)
+Cgmin_Var25= 1     dCg_Var25= 1     dxL_Var25= 0     dxW_Var25= 0
.lib 'crn65lp_v1d5.l' MOS_CAP_25
.ENDL TT_MOS_CAP_25



***************************     CORNER_LIB OF SLOW MODEL     ***************************
.LIB SS_MOS_CAP_25
.param
+parmvar_25=AGAUSS(0,1,1)
+Cgmin_Var25= 0.9     dCg_Var25= 0.9464     dxL_Var25= 1.0E-08     dxW_Var25= -1.2E-08
.lib 'crn65lp_v1d5.l' MOS_CAP_25
.ENDL SS_MOS_CAP_25



***************************     CORNER_LIB OF FAST MODEL     ***************************
.LIB FF_MOS_CAP_25
.param
+parmvar_25=AGAUSS(0,1,1)
+Cgmin_Var25= 1.1     dCg_Var25= 1.0536     dxL_Var25= -1.0E-08     dxW_Var25= 1.2E-08
.lib 'crn65lp_v1d5.l' MOS_CAP_25
.ENDL FF_MOS_CAP_25



**************************************************************************
*                                                                        *
*              2.5V IO NMOS in N-Well varactor MODEL                     *
*                                                                        *
**************************************************************************
.LIB MOS_CAP_25
*
.subckt nmoscap_25 ng nds lr=1E-6 wr=1E-6 scale=1 mismatchflag=0
.param XL=1.5E-08
.param XW=-7.0E-09
.param area='(lr*scale-XL+dxL_Var25)*(wr*scale-XW+dxW_Var25)'
.param Cgmin='1.2E-10*Cgmin_Var25*2*(wr*scale-XW+dxW_Var25)+3.10E-10*Cgmin_Var25*2*(lr*scale-XL+dxL_Var25)+9.6E-04*Cgmin_Var25*area'
.param dCg='1.0E-11*dCg_Var25*2*(wr*scale-XW+dxW_Var25)+4.0E-12*dCg_Var25*2*(lr*scale-XL+dxL_Var25)+2.54E-03*dCg_Var25*area'
.param dVgs='-0.16-2.000E-04*(temper-25)'
.param Vgnorm='0.55+1.0E-03*(temper-25)'
.param geo_fac='sqrt(2)/sqrt(lr*wr*1e12)'

cg ng nds 'Cgmin*(1+0.01*geo_fac*parmvar_25*mismatchflag*(0.081+0.351*(1-tanh((v(ng,nds)-0.16)/0.55))))+dCg*(1.0+tanh((v(ng,nds)-dVgs)/Vgnorm))*(1+0.00081*geo_fac*parmvar_25*mismatchflag)'

.ends nmoscap_25
.ENDL MOS_CAP_25


















**************************************************************************
*
*   RESISTANCE MODEL
*
**************************************************************************
.lib mc_res
.lib 'crn65lp_v1d5.l' noiseflag_res
.Param
+par_res=AGAUSS(0,1,1)
+A1_res_SAL='par1_res*3.4218e+000*3/3.1' 
+A2_res_SAL='par2_res*5.3941e-001*3/3.1' 
+A1_res_RPO='par3_res*3.4546e+000*3/3.2' 
+A1_res_NW='par4_res*1.4142e+000*3/3' 

+r_rppolyl       = '1.4926e+001+(1.3027e+000)*A1_res_SAL+(-7.8588e-001)*A2_res_SAL'
+r_rppolys       = '1.4926e+001+(1.6180e+000)*A1_res_SAL+(-1.0884e+000)*A2_res_SAL'
+dxw_rppolys     = '0.0000e+000+(4.2404e-009)*A1_res_SAL+(5.7744e-009)*A2_res_SAL'
+r_rnpolyl       = '1.5062e+001+(1.3146e+000)*A1_res_SAL+(-7.9306e-001)*A2_res_SAL'
+r_rnpolys       = '1.5062e+001+(1.6189e+000)*A1_res_SAL+(-1.1386e+000)*A2_res_SAL'
+dxw_rnpolys     = '0.0000e+000+(4.3955e-009)*A1_res_SAL+(6.3260e-009)*A2_res_SAL'
+r_rnodl         = '1.5522e+001+(1.3547e+000)*A1_res_SAL+(-8.1728e-001)*A2_res_SAL'
+r_rnods         = '1.5522e+001+(1.3949e+000)*A1_res_SAL+(-1.1753e+000)*A2_res_SAL'
+dxw_rnods       = '0.0000e+000+(9.1052e-009)*A1_res_SAL+(1.3156e-008)*A2_res_SAL'
+r_rpodl         = '1.4551e+001+(1.2700e+000)*A1_res_SAL+(-7.6617e-001)*A2_res_SAL'
+r_rpods         = '1.4551e+001+(1.3277e+000)*A1_res_SAL+(-1.1921e+000)*A2_res_SAL'
+dxw_rpods       = '0.0000e+000+(9.2788e-009)*A1_res_SAL+(1.3863e-008)*A2_res_SAL'
+r_rnodwo        = '1.2000e+002+(6.6430e+000)*A1_res_RPO'
+rend_rnodwo     = '5.7300e-006+(8.2839e-007)*A1_res_RPO'
+dxw_rnodwo      = '0.0000e+000+(9.3163e-009)*A1_res_RPO'
+r_rpodwo        = '2.4522e+002+(1.1689e+001)*A1_res_RPO'
+rend_rpodwo     = '2.8800e-006+(4.1636e-007)*A1_res_RPO'
+dxw_rpodwo      = '0.0000e+000+(2.4333e-008)*A1_res_RPO'
+r_rnpolywo      = '1.5341e+002+(7.9845e+000)*A1_res_RPO'
+rend_rnpolywo   = '3.0300e-006+(4.3805e-007)*A1_res_RPO'
+dxw_rnpolywo    = '0.0000e+000+(1.6022e-008)*A1_res_RPO'
+r_rppolywo      = '6.9002e+002+(2.4734e+001)*A1_res_RPO'
+rend_rppolywo   = '1.0400e-006+(1.5035e-007)*A1_res_RPO'
+dxw_rppolywo    = '0.0000e+000+(3.6342e-009)*A1_res_RPO'

+dxl_rnodwo      = '0.0000e+000'
+dxl_rpodwo      = '0.0000e+000'
+dxl_rnpolywo    = '0.0000e+000'
+dxl_rppolywo    = '0.0000e+000'

+r_rnwod         = '3.2680e+002+(4.6217e+001)*A1_res_NW'
+r_rnwsti        = '5.9517e+002+(8.4170e+001)*A1_res_NW'

+r_rm1l            = 0.0868            
+r_rm1s            = 0.16              r_rm1w            = 0.137             r_rm2l            = 0.0778            
+r_rm2s            = 0.1399            r_rm2w            = 0.119             r_rm3l            = 0.0778            
+r_rm3s            = 0.1399            r_rm3w            = 0.119             r_rm4l            = 0.0778            
+r_rm4s            = 0.1399            r_rm4w            = 0.119             r_rm5l            = 0.0778            
+r_rm5s            = 0.1399            r_rm5w            = 0.119             r_rm6l            = 0.0778            
+r_rm6s            = 0.1399            r_rm6w            = 0.119             r_rm7l            = 0.0778            
+r_rm7s            = 0.1399            r_rm7w            = 0.119             r_rm8l            = 0.0215            
+r_rm8s            = 0.0218            r_rm8w            = 0.0227            r_rm9l            = 0.0215            
+r_rm9s            = 0.0218            r_rm9w            = 0.0227            r_rm10            = 0.021             
+r_rmxl            = 0.0778            r_rmxs            = 0.1399            r_rmxw            = 0.119             
+r_rmyl            = 0.0326            r_rmys            = 0.0380            r_rmyw            = 0.0365
+r_rmzl            = 0.0215            r_rmzs            = 0.0218            r_rmzw            = 0.0227            
+r_rmrl            = 0.0145            r_rmrs            = 0.0147            r_rmrw            = 0.0178
+r_rmap            = 0.021             r_rmap_ut         = 0.011
+r_rmt=0.005

+a1_rnpolywo=1.085E-22        a1_rppolywo=6.3E-23 
+b1_rnpolywo=-3.550E-23     b1_rppolywo=-2.35E-23  
+c1_rnpolywo=1.13E-22        c1_rppolywo=7.5E-23  
+KF_rnpolywo='a1_rnpolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rnpolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rnpolywo'
+KF_rppolywo='a1_rppolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rppolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rppolywo'
.lib 'crn65lp_v1d5.l' RES
.endl mc_res







.LIB TT_RES
.lib 'crn65lp_v1d5.l' noiseflag_res
.Param
+par_res=AGAUSS(0,1,1)
+r_rnodwo          = 120.0       rend_rnodwo       = 5.73E-06          dxw_rnodwo        = 0                 dxl_rnodwo        = 0.0u              
+r_rpodwo          = 245.2236546       rend_rpodwo       = 2.88E-06          dxw_rpodwo        = 0                 dxl_rpodwo        = 0.0u              
+r_rnpolywo        = 153.4133674       rend_rnpolywo     = 3.03E-06          dxw_rnpolywo      = 0                 dxl_rnpolywo      = 0.0u              
+r_rppolywo        = 690.0226806       rend_rppolywo     = 1.04E-06          dxw_rppolywo      = 0                 dxl_rppolywo      = 0.0u              
+r_rppolyl         = 14.9255297        r_rppolys         = 14.9255297        dxw_rppolys       = 0                 
+r_rnpolyl         = 15.0618623        r_rnpolys         = 15.0618623        dxw_rnpolys       = 0                 
+r_rnodl           = 15.52195217       r_rnods           = 15.52195217       dxw_rnods         = 0                 
+r_rpodl           = 14.55118032       r_rpods           = 14.55118032       dxw_rpods         = 0                 
+r_rnwod           = 326.8034772       r_rnwsti          = 595.1748005       r_rm1l            = 0.0868            
+r_rm1s            = 0.16              r_rm1w            = 0.137             r_rm2l            = 0.0778            
+r_rm2s            = 0.1399            r_rm2w            = 0.119             r_rm3l            = 0.0778            
+r_rm3s            = 0.1399            r_rm3w            = 0.119             r_rm4l            = 0.0778            
+r_rm4s            = 0.1399            r_rm4w            = 0.119             r_rm5l            = 0.0778            
+r_rm5s            = 0.1399            r_rm5w            = 0.119             r_rm6l            = 0.0778            
+r_rm6s            = 0.1399            r_rm6w            = 0.119             r_rm7l            = 0.0778            
+r_rm7s            = 0.1399            r_rm7w            = 0.119             r_rm8l            = 0.0215            
+r_rm8s            = 0.0218            r_rm8w            = 0.0227            r_rm9l            = 0.0215            
+r_rm9s            = 0.0218            r_rm9w            = 0.0227            r_rm10            = 0.021             
+r_rmxl            = 0.0778            r_rmxs            = 0.1399            r_rmxw            = 0.119             
+r_rmyl            = 0.0326            r_rmys            = 0.0380            r_rmyw            = 0.0365
+r_rmzl            = 0.0215            r_rmzs            = 0.0218            r_rmzw            = 0.0227            
+r_rmrl            = 0.0145            r_rmrs            = 0.0147            r_rmrw            = 0.0178
+r_rmap            = 0.021             r_rmap_ut         = 0.011
+r_rmt=0.005

+a1_rnpolywo=1.085E-22        a1_rppolywo=6.3E-23 
+b1_rnpolywo=-3.550E-23     b1_rppolywo=-2.35E-23  
+c1_rnpolywo=1.13E-22        c1_rppolywo=7.5E-23  
+KF_rnpolywo='a1_rnpolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rnpolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rnpolywo'
+KF_rppolywo='a1_rppolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rppolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rppolywo'
.lib 'crn65lp_v1d5.l' RES
.ENDL TT_RES







.LIB SS_RES
.lib 'crn65lp_v1d5.l' noiseflag_res
.Param
+par_res=AGAUSS(0,1,1)
+r_rnodwo          = '120.0 * 1.193' rend_rnodwo       = '5.73E-06 * 1.50' dxw_rnodwo        = '0 + 0.024u'      dxl_rnodwo        = '0.0u + 0.0u'     
+r_rpodwo          = '245.2236546 * 1.17' rend_rpodwo       = '2.88E-06 * 1.50' dxw_rpodwo        = '0 + 0.056u'      dxl_rpodwo        = '0.0u + 0.0u'     
+r_rnpolywo        = '153.4133674 * 1.18' rend_rnpolywo     = '3.03E-06 * 1.50' dxw_rnpolywo      = '0 + 0.040u'      dxl_rnpolywo      = '0.0u + 0.0u'     
+r_rppolywo        = '690.0226806 * 1.125' rend_rppolywo     = '1.04E-06 * 1.50' dxw_rppolywo      = '0 + 0.01u'     dxl_rppolywo      = '0.0u + 0.0u'     
+r_rppolyl         = '14.9255297 * 1.30' r_rppolys         = '14.9255297 * 1.38' dxw_rppolys       = '0 + 0.0064u'     
+r_rnpolyl         = '15.0618623 * 1.30' r_rnpolys         = '15.0618623 * 1.38' dxw_rnpolys       = '0 + 0.0063u'     
+r_rnodl           = '15.52195217 * 1.30' r_rnods           = '15.52195217 * 1.33' dxw_rnods         = '0 + 0.013u'      
+r_rpodl           = '14.55118032 * 1.30' r_rpods           = '14.55118032 * 1.34' dxw_rpods         = '0 + 0.0128u'     
+r_rnwod           = '326.8034772 * 1.20' r_rnwsti          = '595.1748005 * 1.20' r_rm1l          = '0.0868 * 1.2707'   
+r_rm1s          = '0.16 * 1.3188'   r_rm1w          = '0.137 * 1.2489'  r_rm2l          = '0.0778 * 1.2506'
+r_rm2s          = '0.1399 * 1.2966' r_rm2w          = '0.119 * 1.2244'  r_rm3l          = '0.0778 * 1.2506'
+r_rm3s          = '0.1399 * 1.2966' r_rm3w          = '0.119 * 1.2244'  r_rm4l          = '0.0778 * 1.2506'
+r_rm4s          = '0.1399 * 1.2966' r_rm4w          = '0.119 * 1.2244'  r_rm5l          = '0.0778 * 1.2506'
+r_rm5s          = '0.1399 * 1.2966' r_rm5w          = '0.119 * 1.2244'  r_rm6l          = '0.0778 * 1.2506'
+r_rm6s          = '0.1399 * 1.2966' r_rm6w          = '0.119 * 1.2244'  r_rm7l          = '0.0778 * 1.2506'
+r_rm7s          = '0.1399 * 1.2966' r_rm7w          = '0.119 * 1.2244'  r_rm8l          = '0.0215 * 1.20'
+r_rm8s          = '0.0218 * 1.1972' r_rm8w          = '0.0227 * 1.1322' r_rm9l          = '0.0215 * 1.20'
+r_rm9s          = '0.0218 * 1.1972' r_rm9w          = '0.0227 * 1.1322' r_rm10          = '0.021 * 1.162'
+r_rmxl          = '0.0778 * 1.2506' r_rmxs          = '0.1399 * 1.2966' r_rmxw          = '0.119 * 1.2244'
+r_rmyl          = '0.0326 * 1.227'  r_rmys          = '0.0380 * 1.239'  r_rmyw          = '0.0365 * 1.181'
+r_rmzl          = '0.0215 * 1.20'   r_rmzs          = '0.0218 * 1.1972' r_rmzw          = '0.0227 * 1.1322'
+r_rmrl          = '0.0145 * 1.1931' r_rmrs          = '0.0147 * 1.1973' r_rmrw          = '0.0178 * 1.1404'
+r_rmap          = '0.021 * 1.162'   r_rmap_ut       = '0.011 * 1.1727'
+r_rmt='0.005*1.2'

+a1_rnpolywo=1.085E-22        a1_rppolywo=6.3E-23 
+b1_rnpolywo=-3.550E-23     b1_rppolywo=-2.35E-23  
+c1_rnpolywo=1.13E-22        c1_rppolywo=7.5E-23  
+KF_rnpolywo='a1_rnpolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rnpolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rnpolywo'
+KF_rppolywo='a1_rppolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rppolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rppolywo'
.lib 'crn65lp_v1d5.l' RES
.ENDL SS_RES







.LIB FF_RES
.lib 'crn65lp_v1d5.l' noiseflag_res
.Param
+par_res=AGAUSS(0,1,1)
+r_rnodwo          = '120.0 * 0.81' rend_rnodwo       = '5.73E-06 * 0.50' dxw_rnodwo        = '0 - 0.040u'      dxl_rnodwo        = '0.0u + 0.0u'     
+r_rpodwo          = '245.2236546 * 0.84' rend_rpodwo       = '2.88E-06 * 0.50' dxw_rpodwo        = '0 - 0.1108u'     dxl_rpodwo        = '0.0u + 0.0u'     
+r_rnpolywo        = '153.4133674 * 0.82' rend_rnpolywo     = '3.03E-06 * 0.50' dxw_rnpolywo      = '0 - 0.07u'      dxl_rnpolywo      = '0.0u + 0.0u'     
+r_rppolywo        = '690.0226806 * 0.877' rend_rppolywo     = '1.04E-06 * 0.50' dxw_rppolywo      = '0 - 0.015u'      dxl_rppolywo      = '0.0u + 0.0u'     
+r_rppolyl         = '14.9255297 * 0.70' r_rppolys         = '14.9255297 * 0.634' dxw_rppolys       = '0 - 0.0219u'     
+r_rnpolyl         = '15.0618623 * 0.70' r_rnpolys         = '15.0618623 * 0.64' dxw_rnpolys       = '0 - 0.023u'      
+r_rnodl           = '15.52195217 * 0.70' r_rnods           = '15.52195217 * 0.71' dxw_rnods         = '0 - 0.04769u'    
+r_rpodl           = '14.55118032 * 0.70' r_rpods           = '14.55118032 * 0.71' dxw_rpods         = '0 - 0.049u'      
+r_rnwod           = '326.8034772 * 0.80' r_rnwsti          = '595.1748005 * 0.80' r_rm1l          = '0.0868 * 0.8065'   
+r_rm1s          = '0.16 * 0.7838'   r_rm1w          = '0.137 * 0.8182'  r_rm2l          = '0.0778 * 0.8162'
+r_rm2s          = '0.1399 * 0.7927' r_rm2w          = '0.119 * 0.8303'  r_rm3l          = '0.0778 * 0.8162'
+r_rm3s          = '0.1399 * 0.7927' r_rm3w          = '0.119 * 0.8303'  r_rm4l          = '0.0778 * 0.8162'
+r_rm4s          = '0.1399 * 0.7927' r_rm4w          = '0.119 * 0.8303'  r_rm5l          = '0.0778 * 0.8162'
+r_rm5s          = '0.1399 * 0.7927' r_rm5w          = '0.119 * 0.8303'  r_rm6l          = '0.0778 * 0.8162'
+r_rm6s          = '0.1399 * 0.7927' r_rm6w          = '0.119 * 0.8303'  r_rm7l          = '0.0778 * 0.8162'
+r_rm7s          = '0.1399 * 0.7927' r_rm7w          = '0.119 * 0.8303'  r_rm8l          = '0.0215 * 0.8419'
+r_rm8s          = '0.0218 * 0.8440' r_rm8w          = '0.0227 * 0.8855' r_rm9l          = '0.0215 * 0.8419'
+r_rm9s          = '0.0218 * 0.8440' r_rm9w          = '0.0227 * 0.8855' r_rm10          = '0.021 * 0.843'
+r_rmxl          = '0.0778 * 0.8162' r_rmxs          = '0.1399 * 0.7927' r_rmxw          = '0.119 * 0.8303'
+r_rmyl          = '0.0326 * 0.828'  r_rmys          = '0.0380 * 0.824'  r_rmyw          = '0.0365 * 0.855'
+r_rmzl          = '0.0215 * 0.8419' r_rmzs          = '0.0218 * 0.8440' r_rmzw          = '0.0227 * 0.8855'
+r_rmrl          = '0.0145 * 0.8414' r_rmrs          = '0.0147 * 0.8435' r_rmrw          = '0.0178 * 0.882'
+r_rmap          = '0.021 * 0.843'   r_rmap_ut       = '0.011 * 0.8364'
+r_rmt='0.005*0.8'

+a1_rnpolywo=1.085E-22        a1_rppolywo=6.3E-23 
+b1_rnpolywo=-3.550E-23     b1_rppolywo=-2.35E-23  
+c1_rnpolywo=1.13E-22        c1_rppolywo=7.5E-23  
+KF_rnpolywo='a1_rnpolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rnpolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rnpolywo'
+KF_rppolywo='a1_rppolywo*(abs(rnoiseflag_res)+rnoiseflag_res)+b1_rppolywo*(abs(rnoiseflag_res)-rnoiseflag_res)+c1_rppolywo'
.lib 'crn65lp_v1d5.l' RES
.ENDL FF_RES







.LIB RES

***********************************     N+OD w/o silicide resistor     ***********************************
.subckt rnodwo n1 n2 l=length w=width scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.002*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnodwo*(1+factmis)'  Rendsh='rend_rnodwo*2*1e6*(1+factmis)'
.param Dw = '(-0.00009u + dxw_rnodwo)*1e6'  Dwend='(-0.00009u + dxw_rnodwo)*1e6'  Dl=0
.param Jc1_0 = 0.106424864190149  Jc1_w=0.164977240163601  Jc1_n=0.0110803345857938
.param Jc1end_0 = 5.13022042122399  Jc1end_w=0
.param Tc1_0 = 0.0016375645345203  Tc1_w=-1.06236946256314E-05
.param Tc2_0 = 5.58760711472759E-07  Tc2_w=8.17454452868088E-08
.param Tc1end_0 = 0.000858024695509284  Tc1end_w=0.000108897460150394
.param Tc2end_0 = 7.01952799620945E-07  Tc2end_w=-4.5518169088131E-07
.param Jct_0 = 0.00244689689527551  Jct_w=-0.00164118315706858
.param Jctend_0 = -0.00280558922243977  Jctend_w=0.00230548862908327
.param Delta_T = 'temper - 25'
.param lum = 'l*scale*1e6'   wum = 'w*scale*1e6'   nsqr=l/w
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w * wum'   Tc2end = 'Tc2end_0 + Tc2end_w * wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend n1 1 'max(min(Rendo/2*(1+1/(1+Jc1end*v(n1,1)*v(n1,1))), Rendo*1.5), Rendo/2)'
Rmain 1 n2 'max(min(Ro/2*(3-1/(1+Jc1*v(1,n2)*v(1,n2))), Ro*1.5), Ro/2)'
.ends rnodwo

***********************************     P+OD w/o silicide resistor     ***********************************
.subckt rpodwo n1 n2 l=length w=width scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0033*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rpodwo*(1+factmis)'  Rendsh='rend_rpodwo*2*1e6*(1+factmis)'
.param Dw = '(0.00168u + dxw_rpodwo)*1e6'  Dwend='(0.00168u + dxw_rpodwo)*1e6'  Dl=0
.param Jc1_0 = 0.111676986150315  Jc1_w=0.152379354165086  Jc1_n=-0.00253193199710238
.param Jc1end_0 = 30.8120320049789  Jc1end_w=0
.param Tc1_0 = 0.00134516723460811  Tc1_w=-1.93197505178018E-06
.param Tc2_0 = 6.91556298384702E-07  Tc2_w=5.99375320579376E-08
.param Tc1end_0 = 7.97874855197876E-05  Tc1end_w=4.99324114654573E-05
.param Tc2end_0 = -2.22863924323114E-07  Tc2end_w=-4.11818902290053E-08
.param Jct_0 = 0.00119863544617091  Jct_w=-0.00096981387975331
.param Jctend_0 = 0.00951466816029306  Jctend_w=-0.00277001356063046
.param Delta_T = 'temper - 25'
.param lum = 'l*scale*1e6'   wum = 'w*scale*1e6'   nsqr=l/w
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w / wum'   Tc2end = 'Tc2end_0 + Tc2end_w / wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend n1 1 'max(min(Rendo/2*(1+1/(1+Jc1end*v(n1,1)*v(n1,1))), Rendo*1.5), Rendo/2)'
Rmain 1 n2 'max(min(Ro/2*(3-1/(1+Jc1*v(1,n2)*v(1,n2))), Ro*1.5), Ro/2)'
.ends rpodwo

***********************************     N+POLY w/o silicide resistor     ***********************************
.subckt rnpolywo n1 n2 l=length w=width scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.027*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnpolywo*(1+factmis)'  Rendsh='rend_rnpolywo*2*1e6*(1+factmis)'
.param Dw = '(0.06094u + dxw_rnpolywo)*1e6'  Dwend='(0.06094u + dxw_rnpolywo)*1e6'  Dl=0
.param Jc1_0 = 0.468910868642278  Jc1_w=-0.112938447121681  Jc1_n=0.00691776661634369
.param Jc1end_0 = 21.876715834462  Jc1end_w=0
.param Tc1_0 = 0.000146777758646609  Tc1_w=-3.23409625208756E-05
.param Tc2_0 = 1.89557340140836E-07  Tc2_w=8.47296898658068E-08
.param Tc1end_0 = 0.000876816730930428  Tc1end_w=0.00036855776757363
.param Tc2end_0 = 5.63556101704174E-07  Tc2end_w=-3.50561057125037E-07
.param Jct_0 = 0.00382604564786152  Jct_w=-0.00234776917199985
.param Jctend_0 = 0.00297141058822875  Jctend_w=-0.00196020344135713
.param Delta_T = 'temper - 25'
.param lum = 'l*scale*1e6'   wum = 'w*scale*1e6'   nsqr=l/w
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w / wum'   Tc2end = 'Tc2end_0 + Tc2end_w / wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w / wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend n1 1 'max(min(Rendo/2*(1+1/(1+Jc1end*v(n1,1)*v(n1,1))), Rendo*1.5), Rendo/2)'
Rmain 1 n2 Rnpoly 'max(min(Ro/2*(3-1/(1+Jc1*v(1,n2)*v(1,n2))), Ro*1.5), Ro/2)'
.model Rnpoly r L='(lum-Dl)*1e-6/1' W='mf*(wum-Dw)*1e-6' KF='KF_rnpolywo' AF=2 EF=0.88 WF=1 LF=1
.ends rnpolywo

***********************************     P+POLY w/o silicide resistor     ***********************************
.subckt rppolywo n1 n2 l=length w=width scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.006*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rppolywo*(1+factmis)'  Rendsh='rend_rppolywo*2*1e6*(1+factmis)'
.param Dw = '(0.03685u + dxw_rppolywo)*1e6'  Dwend='(0.03685u + dxw_rppolywo)*1e6'  Dl=0
.param Jc1_0 = 0.0695053510675811  Jc1_w=0.0269845671346735  Jc1_n=0.000714977117664719
.param Jc1end_0 = 27.900361735252  Jc1end_w=0
.param Tc1_0 = -0.000326161317630646  Tc1_w=3.10855059871834E-06
.param Tc2_0 = 8.05172629127237E-07  Tc2_w=-2.79415787596679E-08
.param Tc1end_0 = -0.00141906402431781  Tc1end_w=1.51517802655145E-05
.param Tc2end_0 = 1.19263050938459E-06  Tc2end_w=5.77755688915007E-07
.param Jct_0 = -0.00425159480565355  Jct_w=2.26507523320411E-05
.param Jctend_0 = -0.00141455931220154  Jctend_w=0.000920093941015092
.param Delta_T = 'temper - 25'
.param lum = 'l*scale*1e6'   wum = 'w*scale*1e6'   nsqr=l/w
.param Tc1 = 'Tc1_0 + Tc1_w * wum'   Tc2 = 'Tc2_0 + Tc2_w * wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w * wum'   Tc2end = 'Tc2end_0 + Tc2end_w * wum'
.param Jct = 'Jct_0 + Jct_w * wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend n1 1 'max(min(Rendo/2*(3-1/(1+Jc1end*v(n1,1)*v(n1,1))), Rendo*1.5), Rendo/2)'
Rmain 1 n2 Rppoly 'max(min(Ro/2*(1+1/(1+Jc1*v(1,n2)*v(1,n2))), Ro*1.5), Ro/2)'
.model Rppoly r L='(lum-Dl)*1e-6/1' W='mf*(wum-Dw)*1e-6' KF='KF_rppolywo' AF=2 EF=0.9 WF=1 LF=1
.ends rppolywo

***********************************     P+POLY silicide resistor (W>=2.0um)     ***********************************
.subckt rppolyl n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0143*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rppolyl*(1+factmis)'
.param dw = -0.023u  
.param pvc1 = 8.25E-07   pvc2 = 1.38E-11   ptc1 = 0.002250708   ptc2 = -9.32E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rppolyl

***********************************     P+POLY silicide resistor (W<2.0um)     ***********************************
.subckt rppolys n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0143*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rppolys*(1+factmis)'
.param dw = '-0.023u + dxw_rppolys'  
.param pvc1 = 8.54E-08   pvc2 = 4.18E-12   ptc1 = 0.002371857   ptc2 = -6.16E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rppolys

***********************************     N+POLY silicide resistor (W>=2.0um)     ***********************************
.subckt rnpolyl n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0082*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnpolyl*(1+factmis)'
.param dw = -0.0211u  
.param pvc1 = 6.54E-07   pvc2 = 1.17E-11   ptc1 = 0.001887444   ptc2 = -6.41E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rnpolyl

***********************************     N+POLY silicide resistor (W<2.0um)     ***********************************
.subckt rnpolys n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0082*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnpolys*(1+factmis)'
.param dw = '-0.0211u + dxw_rnpolys'  
.param pvc1 = 2.63E-08   pvc2 = 4.19E-12   ptc1 = 0.002162497   ptc2 = -7.21E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rnpolys

***********************************     N+OD silicide resistor (W>=2.0um)     ***********************************
.subckt rnodl n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0062*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnodl*(1+factmis)'
.param dw = -0.02542u  
.param pvc1 = -5.30E-08   pvc2 = 3.23E-12   ptc1 = 0.001905463   ptc2 = -5.99E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rnodl

***********************************     N+OD silicide resistor (W<2.0um)     ***********************************
.subckt rnods n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0062*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rnods*(1+factmis)'
.param dw = '-0.02542u + dxw_rnods'  
.param pvc1 = 4.83E-08   pvc2 = 9.73E-13   ptc1 = 0.002172012   ptc2 = -5.47E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rnods

***********************************     P+OD silicide resistor (W>=2.0um)     ***********************************
.subckt rpodl n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0131*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rpodl*(1+factmis)'
.param dw = -0.03046u  
.param pvc1 = -7.28E-09   pvc2 = 3.46E-12   ptc1 = 0.002132422   ptc2 = -9.32E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rpodl

***********************************     P+OD silicide resistor (W<2.0um)     ***********************************
.subckt rpods n1 n2 l=length w=width  scale=1 mf=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*l*scale*w*scale*1e12)'
.param factmis='0.0131*geo_fac*par_res*mismatchflag'
.param Rsh = 'r_rpods*(1+factmis)'
.param dw = '-0.03046u + dxw_rpods'  
.param pvc1 = -4.25E-09   pvc2 = 1.37E-12   ptc1 = 0.002370563   ptc2 = -7.40E-07   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rpods

***********************************     N-Well under OD resistor     ***********************************
.subckt rnwod n1 n2 l=length w=width  scale=1 mf=1
.param rsh = r_rnwod
.param dw = 0.24916u  
.param pvc1 = 0.002118977   pvc2 = 0.000515843   ptc1 = 2.43E-03   ptc2 = 9.20E-06   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
.ends rnwod

***********************************     N-well under STI resistor     ***********************************
.subckt rnwsti n1 n2 l=length w=width  scale=1 mf=1
.param rsh = r_rnwsti
.param dw = 0.31243u  
.param pvc1 = 0.003817735   pvc2 = 1.03E-04   ptc1 = 2.02E-03   ptc2 = 9.94E-06   
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
.ends rnwsti

***********************************     Metal 1 with W/S=0.09/0.45     ***********************************
.subckt rm1l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm1l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.650E-03   ptc2 = -2.641E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm1l
***********************************     Metal 1 with W/S=0.09/0.09     ***********************************
.subckt rm1s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm1s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.650E-03   ptc2 = -2.641E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm1s
***********************************     Metal 1 with W/S=0.27/0.135     ***********************************
.subckt rm1w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm1w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.650E-03   ptc2 = -2.641E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm1w
***********************************     Metal 2with W/S=0.1/0.5     ***********************************
.subckt rm2l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm2l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm2l
***********************************     Metal 2 with W/S=0.1/0.1     ***********************************
.subckt rm2s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm2s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm2s
***********************************     Metal 2 with W/S=0.3/0.13     ***********************************
.subckt rm2w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm2w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm2w
***********************************     Metal 3 with W/S=0.1/0.5     ***********************************
.subckt rm3l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm3l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm3l
***********************************     Metal 3 with W/S=0.1/0.1     ***********************************
.subckt rm3s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm3s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm3s
***********************************     Metal 3 with W/S=0.3/0.13     ***********************************
.subckt rm3w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm3w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm3w
***********************************     Metal 4 with W/S=0.1/0.5     ***********************************
.subckt rm4l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm4l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm4l
***********************************     Metal 4 with W/S=0.1/0.1     ***********************************
.subckt rm4s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm4s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm4s
***********************************     Metal 4 with W/S=0.3/0.13     ***********************************
.subckt rm4w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm4w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm4w
***********************************     Metal 5 with W/S=0.1/0.5     ***********************************
.subckt rm5l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm5l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm5l
***********************************     Metal 5 with W/S=0.1/0.1     ***********************************
.subckt rm5s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm5s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm5s
***********************************     Metal 5 with W/S=0.3/0.13     ***********************************
.subckt rm5w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm5w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm5w
***********************************     Metal 6 with W/S=0.1/0.5     ***********************************
.subckt rm6l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm6l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm6l
***********************************     Metal 6 with W/S=0.1/0.1     ***********************************
.subckt rm6s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm6s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm6s
***********************************     Metal 6 with W/S=0.3/0.13     ***********************************
.subckt rm6w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm6w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm6w
***********************************     Metal 7 with W/S=0.1/0.5     ***********************************
.subckt rm7l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm7l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm7l
***********************************     Metal 7 with W/S=0.1/0.1     ***********************************
.subckt rm7s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm7s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm7s
***********************************     Metal 7 with W/S=0.3/0.13     ***********************************
.subckt rm7w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm7w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm7w
***********************************     Metal 8 with W/S=0.4/1.5     ***********************************
.subckt rm8l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm8l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm8l
***********************************     Metal 8 with W/S=0.4/0.4     ***********************************
.subckt rm8s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm8s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm8s
***********************************     Metal 8 with W/S=1.5/0.4     ***********************************
.subckt rm8w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm8w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm8w
***********************************     Metal 9 with W/S=0.4/1.5     ***********************************
.subckt rm9l n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm9l
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm9l
***********************************     Metal 9 with W/S=0.4/0.4     ***********************************
.subckt rm9s n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm9s
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm9s
***********************************     Metal 9 with W/S=1.5/0.4     ***********************************
.subckt rm9w n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm9w
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm9w
***********************************     Metal 10 (AL_RDL) with W/S=3/2     ***********************************
.subckt rm10 n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rm10
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.890E-03   ptc2 = -1.500E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rm10
***********************************     Thick Metal (UTM)     ***********************************
.subckt rmt n1 n2 l=length w=width scale=1 mf=1
.param rsh= r_rmt dw=0 ptc1=3.41E-03 ptc2=3.69E-06 pvc1=0 pvc2=0 pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmt
***********************************     Metal x with W/S=0.1/0.5     ***********************************
.subckt rmxl n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmxl
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmxl
***********************************     Metal x with W/S=0.1/0.1     ***********************************
.subckt rmxs n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmxs
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmxs
***********************************     Metal x with W/S=0.3/0.13     ***********************************
.subckt rmxw n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmxw
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 2.709E-03   ptc2 = -3.483E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmxw
***********************************     Metal y with W/S=0.2/1     ***********************************
.subckt rmyl n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmyl
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.335e-3   ptc2 = -1.142e-7
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmyl

***********************************     Metal y with W/S=0.2/0.2     ***********************************
.subckt rmys n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmys
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.335e-3   ptc2 = -1.142e-7
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmys

***********************************     Metal y with W/S=0.6/0.3     ***********************************
.subckt rmyw n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmyw
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.335e-3   ptc2 = -1.142e-7
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmyw
***********************************     Metal z with W/S=0.4/1.5     ***********************************
.subckt rmzl n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmzl
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmzl
***********************************     Metal z with W/S=0.4/0.4     ***********************************
.subckt rmzs n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmzs
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmzs
***********************************     Metal z with W/S=1.5/0.4     ***********************************
.subckt rmzw n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmzw
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.625E-03   ptc2 = -1.393E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmzw
***********************************     Metal r with W/S=0.5/1.2     ***********************************
.subckt rmrl n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmrl
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.273E-03   ptc2 = -3.876E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmrl
***********************************     Metal r with W/S=0.5/0.5     ***********************************
.subckt rmrs n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmrs
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.273E-03   ptc2 = -3.876E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmrs
***********************************     Metal r with W/S=1.2/0.5     ***********************************
.subckt rmrw n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmrw
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.273E-03   ptc2 = -3.876E-06
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmrw
***********************************     Metal ap (AL_RDL) with W/S=3/2     ***********************************
.subckt rmap n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmap
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.890E-03   ptc2 = -1.500E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmap
***********************************     Metal ap_ut (AL_RDL) with W/S=3/2     ***********************************
.subckt rmap_ut n1 n2 l=length w=width scale=1 mf=1
.param Rsh = r_rmap_ut
.param dw = 0
.param pvc1 = 0   pvc2 = 0   ptc1 = 3.890E-03   ptc2 = -1.500E-07
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
.param pt='temper'
r1 n1 n2 'rsh/mf*l*scale/(w*scale-dw)*(1+pvc1*(abs(v(n2,n1))/l/scale)+pvc2*(v(n2,n1)/l/scale)*(v(n2,n1)/l/scale))*tfac'
.ends rmap_ut


.ENDL RES



**************************************************************************
*
*  3T RESISTANCE MODEL
*
**************************************************************************
.lib mc_disres
.lib 'crn65lp_v1d5.l' noiseflag_disres
.Param
+par_res_m=AGAUSS(0,1,1)
+A1_disres_sal='par1_res*3.8313e+000*3/3.3' 
+A2_disres_sal='par2_res*5.6657e-001*3/3.3' 
+A1_disres_rpo='par3_res*3.8628e+000*3/3.1' 
+A1_disres_nw='par4_res*1.4142e+000*3/3.1' 


+r_rnodl_m       = '1.5522e+001+(1.2121e+000)*A1_disres_sal+(6.0814e-001)*A2_disres_sal'
+r_rnods_m       = '1.5522e+001+(1.2490e+000)*A1_disres_sal+(9.4389e-001)*A2_disres_sal'
+dxw_rnods_m     = '0.0000e+000+(8.0919e-009)*A1_disres_sal+(-1.3664e-008)*A2_disres_sal'
+r_rpodl_m       = '1.4551e+001+(1.1363e+000)*A1_disres_sal+(5.7010e-001)*A2_disres_sal'
+r_rpods_m       = '1.4551e+001+(1.1890e+000)*A1_disres_sal+(9.6829e-001)*A2_disres_sal'
+dxw_rpods_m     = '0.0000e+000+(8.2448e-009)*A1_disres_sal+(-1.4359e-008)*A2_disres_sal'
+r_rnpolyl_m     = '1.5062e+001+(1.1761e+000)*A1_disres_sal+(5.9011e-001)*A2_disres_sal'
+r_rnpolys_m     = '1.5062e+001+(1.4489e+000)*A1_disres_sal+(8.8087e-001)*A2_disres_sal'
+dxw_rnpolys_m   = '0.0000e+000+(3.9064e-009)*A1_disres_sal+(-6.5724e-009)*A2_disres_sal'
+r_rppolyl_m     = '1.4926e+001+(1.1655e+000)*A1_disres_sal+(5.8477e-001)*A2_disres_sal'
+r_rppolys_m     = '1.4926e+001+(1.4479e+000)*A1_disres_sal+(8.3324e-001)*A2_disres_sal'
+dxw_rppolys_m   = '0.0000e+000+(3.7695e-009)*A1_disres_sal+(-6.0279e-009)*A2_disres_sal'
+ca_pofox        = '1.0770e-016+(2.4730e-018)*A1_disres_sal+(2.4159e-018)*A2_disres_sal'
+cf_polfox       = '5.3500e-017+(4.4361e-019)*A1_disres_sal+(1.2039e-019)*A2_disres_sal'
+cf_posfox       = '4.2800e-017+(4.0401e-019)*A1_disres_sal+(1.5161e-019)*A2_disres_sal'

+r_rnodwo_m      = '1.2000e+002+(5.9440e+000)*A1_disres_rpo'
+dxw_rnodwo_m    = '0.0000e+000+(8.3227e-009)*A1_disres_rpo'
+rend_rnodwo_m   = '5.7300e-006+(7.4118e-007)*A1_disres_rpo'
+r_rpodwo_m      = '2.4522e+002+(1.0461e+001)*A1_disres_rpo'
+dxw_rpodwo_m    = '0.0000e+000+(2.1727e-008)*A1_disres_rpo'
+rend_rpodwo_m   = '2.8800e-006+(3.7253e-007)*A1_disres_rpo'
+r_rnpolywo_m    = '1.5341e+002+(7.1439e+000)*A1_disres_rpo'
+dxw_rnpolywo_m  = '0.0000e+000+(1.4312e-008)*A1_disres_rpo'
+rend_rnpolywo_m = '3.0300e-006+(3.9193e-007)*A1_disres_rpo'
+r_rppolywo_m    = '6.9002e+002+(2.2132e+001)*A1_disres_rpo'
+dxw_rppolywo_m  = '0.0000e+000+(3.2476e-009)*A1_disres_rpo'
+rend_rppolywo_m = '1.0400e-006+(1.3453e-007)*A1_disres_rpo'
+ca_pofox_r      = '1.0770e-016+(2.4643e-018)*A1_disres_rpo'
+cf_polfox_r     = '5.3500e-017+(4.4035e-019)*A1_disres_rpo'
+cf_posfox_r     = '4.2800e-017+(4.0127e-019)*A1_disres_rpo'

+dxl_rnodwo_m    = '0.0000e+000'
+dxl_rpodwo_m    = '0.0000e+000'
+dxl_rnpolywo_m  = '0.0000e+000'
+dxl_rppolywo_m  = '0.0000e+000'

+r_rnwod_m       = '3.2680e+002+(4.6217e+001)*A1_disres_nw'
+r_rnwsti_m      = '5.9517e+002+(8.4170e+001)*A1_disres_nw'


+a1_rnpolywo_dis=1.085E-22        a1_rppolywo_dis=6.3E-23 
+b1_rnpolywo_dis=-3.550E-23     b1_rppolywo_dis=-2.35E-23  
+c1_rnpolywo_dis=1.13E-22        c1_rppolywo_dis=7.5E-23  
+KF_rnpolywo_dis='a1_rnpolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rnpolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rnpolywo_dis'
+KF_rppolywo_dis='a1_rppolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rppolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rppolywo_dis'


.lib 'crn65lp_v1d5.l' DISRES
.endl mc_disres





*******************************************************************************************

**************************************************************************
*
*   RESISTANCE MODEL
*
**************************************************************************
.LIB TT_DISRES
.lib 'crn65lp_v1d5.l' noiseflag_disres
.Param
+par_res_m=AGAUSS(0,1,1)
+r_rnwod_m         = 326.8034772       r_rnwsti_m        = 595.1748005       r_rnodl_m         = 15.52195217       
+r_rnods_m         = 15.52195217       dxw_rnods_m       = 0                 
+r_rnodwo_m        = 120               dxw_rnodwo_m      = 0                 rend_rnodwo_m     = 5.73E-06          dxl_rnodwo_m      = 0                 
+r_rpodl_m         = 14.55118032       r_rpods_m         = 14.55118032       dxw_rpods_m       = 0                 
+r_rpodwo_m        = 245.2236546       dxw_rpodwo_m      = 0                 rend_rpodwo_m     = 2.88E-06          dxl_rpodwo_m      = 0                 
+r_rnpolyl_m       = 15.0618623        r_rnpolys_m       = 15.0618623        dxw_rnpolys_m     = 0                 
+r_rnpolywo_m      = 153.4133674       dxw_rnpolywo_m    = 0                 rend_rnpolywo_m   = 3.03E-06          dxl_rnpolywo_m    = 0                 
+r_rppolyl_m       = 14.9255297        r_rppolys_m       = 14.9255297        dxw_rppolys_m     = 0                 
+r_rppolywo_m      = 690.0226806       dxw_rppolywo_m    = 0                 rend_rppolywo_m   = 1.04E-06          dxl_rppolywo_m    = 0                 
+ca_pofox=10.77e-17  cf_polfox=5.35e-17 cf_posfox=4.28e-17
+ca_pofox_r=10.77e-17  cf_polfox_r=5.35e-17 cf_posfox_r=4.28e-17
+a1_rnpolywo_dis=1.085E-22        a1_rppolywo_dis=6.3E-23 
+b1_rnpolywo_dis=-3.550E-23     b1_rppolywo_dis=-2.35E-23  
+c1_rnpolywo_dis=1.13E-22        c1_rppolywo_dis=7.5E-23  
+KF_rnpolywo_dis='a1_rnpolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rnpolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rnpolywo_dis'
+KF_rppolywo_dis='a1_rppolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rppolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rppolywo_dis'

.lib 'crn65lp_v1d5.l' DISRES
.ENDL TT_DISRES









.LIB SS_DISRES
.lib 'crn65lp_v1d5.l' noiseflag_disres
.Param
+par_res_m=AGAUSS(0,1,1)
+r_rnwod_m         = '326.8034772 * 1.20' r_rnwsti_m        = '595.1748005 * 1.20' r_rnodl_m         = '15.52195217 * 1.30' 
+r_rnods_m         = '15.52195217 * 1.33' dxw_rnods_m       = '0 + 0.013u'      
+r_rnodwo_m        = '120 * 1.193'      dxw_rnodwo_m      = '0 + 0.024u'      rend_rnodwo_m     = '5.73E-06 * 1.50' dxl_rnodwo_m      = '0 + 0.0u'        
+r_rpodl_m         = '14.55118032 * 1.30' r_rpods_m         = '14.55118032 * 1.34' dxw_rpods_m       = '0 + 0.0128u'     
+r_rpodwo_m        = '245.2236546 * 1.17' dxw_rpodwo_m      = '0 + 0.056u'      rend_rpodwo_m     = '2.88E-06 * 1.50' dxl_rpodwo_m      = '0 + 0.0u'        
+r_rnpolyl_m       = '15.0618623 * 1.30' r_rnpolys_m       = '15.0618623 * 1.38' dxw_rnpolys_m     = '0 + 0.0063u'     
+r_rnpolywo_m      = '153.4133674 * 1.18' dxw_rnpolywo_m    = '0 + 0.040u'      rend_rnpolywo_m   = '3.03E-06 * 1.50' dxl_rnpolywo_m    = '0 + 0.0u'        
+r_rppolyl_m       = '14.9255297 * 1.30' r_rppolys_m       = '14.9255297 * 1.38' dxw_rppolys_m     = '0 + 0.0064u'     
+r_rppolywo_m      = '690.0226806 * 1.125' dxw_rppolywo_m    = '0 + 0.010u'     rend_rppolywo_m   = '1.04E-06 * 1.50' dxl_rppolywo_m    = '0 + 0.0u'        
+ca_pofox=11.84e-17  cf_polfox=5.51e-17 cf_posfox=4.43e-17
+ca_pofox_r=11.84e-17  cf_polfox_r=5.51e-17 cf_posfox_r=4.43e-17
+a1_rnpolywo_dis=1.085E-22        a1_rppolywo_dis=6.3E-23 
+b1_rnpolywo_dis=-3.550E-23     b1_rppolywo_dis=-2.35E-23  
+c1_rnpolywo_dis=1.13E-22        c1_rppolywo_dis=7.5E-23  
+KF_rnpolywo_dis='a1_rnpolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rnpolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rnpolywo_dis'
+KF_rppolywo_dis='a1_rppolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rppolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rppolywo_dis'

.lib 'crn65lp_v1d5.l' DISRES
.ENDL SS_DISRES









.LIB FF_DISRES
.lib 'crn65lp_v1d5.l' noiseflag_disres
.Param
+par_res_m=AGAUSS(0,1,1)
+r_rnwod_m         = '326.8034772 * 0.80' r_rnwsti_m        = '595.1748005 * 0.80' r_rnodl_m         = '15.52195217 * 0.70' 
+r_rnods_m         = '15.52195217 * 0.71' dxw_rnods_m       = '0 - 0.04769u'    
+r_rnodwo_m        = '120 * 0.81'      dxw_rnodwo_m      = '0 - 0.040u'      rend_rnodwo_m     = '5.73E-06 * 0.50' dxl_rnodwo_m      = '0 - 0.0u'        
+r_rpodl_m         = '14.55118032 * 0.70' r_rpods_m         = '14.55118032 * 0.71' dxw_rpods_m       = '0 - 0.049u'      
+r_rpodwo_m        = '245.2236546 * 0.84' dxw_rpodwo_m      = '0 - 0.1108u'     rend_rpodwo_m     = '2.88E-06 * 0.50' dxl_rpodwo_m      = '0 - 0.0u'        
+r_rnpolyl_m       = '15.0618623 * 0.70' r_rnpolys_m       = '15.0618623 * 0.64' dxw_rnpolys_m     = '0 - 0.023u'      
+r_rnpolywo_m      = '153.4133674 * 0.82' dxw_rnpolywo_m    = '0 - 0.07u'       rend_rnpolywo_m   = '3.03E-06 * 0.50' dxl_rnpolywo_m    = '0 - 0.0u'        
+r_rppolyl_m       = '14.9255297 * 0.70' r_rppolys_m       = '14.9255297 * 0.634' dxw_rppolys_m     = '0 - 0.0219u'     
+r_rppolywo_m      = '690.0226806 * 0.877' dxw_rppolywo_m    = '0 - 0.015u'      rend_rppolywo_m   = '1.04E-06 * 0.50' dxl_rppolywo_m    = '0 - 0.0u'        
+ca_pofox=9.93e-17  cf_polfox=5.17e-17 cf_posfox=4.12e-17
+ca_pofox_r=9.93e-17  cf_polfox_r=5.17e-17 cf_posfox_r=4.12e-17
+a1_rnpolywo_dis=1.085E-22        a1_rppolywo_dis=6.3E-23 
+b1_rnpolywo_dis=-3.550E-23     b1_rppolywo_dis=-2.35E-23  
+c1_rnpolywo_dis=1.13E-22        c1_rppolywo_dis=7.5E-23  
+KF_rnpolywo_dis='a1_rnpolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rnpolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rnpolywo_dis'
+KF_rppolywo_dis='a1_rppolywo_dis*(abs(rnoiseflag_disres)+rnoiseflag_disres)+b1_rppolywo_dis*(abs(rnoiseflag_disres)-rnoiseflag_disres)+c1_rppolywo_dis'
.lib 'crn65lp_v1d5.l' DISRES
.ENDL FF_DISRES









.LIB DISRES

***********************************     N-Well under OD resistor     ***********************************
.subckt rnwod_m n2 n1 body lr=l wr=w mf=1 scale=1
.param rsh = r_rnwod_m
.param dw = 0.24916u  
.param pvc1 = 0.002118977   pvc2 = 0.000515843   ptc1 = 2.43E-03   ptc2 = 9.20E-06   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
d1 body n2 nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 body nm nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 body nn nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 body nx nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 body n1 nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rnwod_m

***********************************     N-well under STI resistor     ***********************************
.subckt rnwsti_m n2 n1 body lr=l wr=w mf=1 scale=1
.param rsh = r_rnwsti_m
.param dw = 0.31243u  
.param pvc1 = 0.003817735   pvc2 = 1.03E-04   ptc1 = 2.02E-03   ptc2 = 9.94E-06   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25.0)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs(v(n2,n1))+pvc2*v(n2,n1)*v(n2,n1))*tfac'
d1 body n2 nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 body nm nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 body nn nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 body nx nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 body n1 nwdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rnwsti_m

***********************************     N+OD silicide resistor (W>2um)     ***********************************
.subckt rnodl_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0062*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rnodl_m*(1+factmis)'
.param dw = -0.02542u  
.param pvc1 = -5.30E-08   pvc2 = 3.23E-12   ptc1 = 0.001905463   ptc2 = -5.99E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
d1 body n2 ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 body nm ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 body nn ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 body nx ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 body n1 ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rnodl_m

***********************************     N+OD silicide resistor (W<2um)     ***********************************
.subckt rnods_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0062*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rnods_m*(1+factmis)'
.param dw = '-0.02542u + dxw_rnods_m'  
.param pvc1 = 4.83E-08   pvc2 = 9.73E-13   ptc1 = 0.002172012   ptc2 = -5.47E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
d1 body n2 ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 body nm ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 body nn ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 body nx ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 body n1 ndio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rnods_m

***********************************     N+OD w/o silicide resistor     ***********************************
.subckt rnodwo_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.002*geo_fac*par_res_m*mismatchflag'
.param Rsh = 'r_rnodwo_m/4*(1+factmis)'  Rendsh='rend_rnodwo_m*1e6*(1+factmis)'
.param Dw = '(-0.00009u + dxw_rnodwo_m)*1e6'  Dwend='(-0.00009u + dxw_rnodwo_m)*1e6'  Dl=0
.param Jc1_0 = 0.106424864190149  Jc1_w=0.164977240163601  Jc1_n=0.0110803345857938
.param Jc1end_0 = 5.13022042122399  Jc1end_w=0
.param Tc1_0 = 0.0016375645345203  Tc1_w=-1.06236946256314E-05
.param Tc2_0 = 5.58760711472759E-07  Tc2_w=8.17454452868088E-08
.param Tc1end_0 = 0.000858024695509284  Tc1end_w=0.000108897460150394
.param Tc2end_0 = 7.01952799620945E-07  Tc2end_w=-4.5518169088131E-07
.param Jct_0 = 0.00244689689527551  Jct_w=-0.00164118315706858
.param Jctend_0 = -0.00280558922243977  Jctend_w=0.00230548862908327
.param Delta_T = 'temper - 25'
.param lum = 'lr*scale*1e6'   wum = 'wr*scale*1e6'   nsqr=lr/wr
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w * wum'   Tc2end = 'Tc2end_0 + Tc2end_w * wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1_r = 'Jc1*16' Jc1end_r='Jc1end*4'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend1 n2 ns 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(n2,ns)*v(n2,ns))), Rendo*1.5), Rendo/2)'
R1 ns nm 'max(min(Ro/2*(3-1/(1+Jc1_r*v(ns,nm)*v(ns,nm))), Ro*1.5), Ro/2)'
R2 nm nn 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nm,nn)*v(nm,nn))), Ro*1.5), Ro/2)'
R3 nn nx 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nn,nx)*v(nn,nx))), Ro*1.5), Ro/2)'
R4 nx ne 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nx,ne)*v(nx,ne))), Ro*1.5), Ro/2)'
Rend2 ne n1 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(ne,n1)*v(ne,n1))), Rendo*1.5), Rendo/2)'
d1 body ns ndio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*((wr*scale-dw*1e-6)+2.0*(lr*scale-dl*1e-6)/5.0)'
d2 body nm ndio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d3 body nn ndio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d4 body nx ndio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d5 body ne ndio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*((wr*scale-dw*1e-6)+2.0*(lr*scale-dl*1e-6)/5.0)'

.ends rnodwo_m

***********************************     P+OD silicide resistor (W>2um)     ***********************************
.subckt rpodl_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0131*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rpodl_m*(1+factmis)'
.param dw = -0.03046u  
.param pvc1 = -7.28E-09   pvc2 = 3.46E-12   ptc1 = 0.002132422   ptc2 = -9.32E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
d1 n2 body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 nm body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 nn body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 nx body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 n1 body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rpodl_m

***********************************     P+OD silicide resistor (W<2um)     ***********************************
.subckt rpods_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0131*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rpods_m*(1+factmis)'
.param dw = '-0.03046u + dxw_rpods_m'  
.param pvc1 = -4.25E-09   pvc2 = 1.37E-12   ptc1 = 0.002370563   ptc2 = -7.40E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
d1 n2 body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
d2 nm body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d3 nn body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d4 nx body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*2.0*lr*scale/5.0'
d5 n1 body pdio area='mf*((wr*scale-dw)*lr*scale/5.0)' pj='mf*((wr*scale-dw)+2.0*lr*scale/5.0)'
.ends rpods_m

***********************************     P+OD w/o silicide resistor     ***********************************
.subckt rpodwo_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0033*geo_fac*par_res_m*mismatchflag'
.param Rsh = 'r_rpodwo_m/4*(1+factmis)'  Rendsh='rend_rpodwo_m*1e6*(1+factmis)'
.param Dw = '(0.00168u + dxw_rpodwo_m)*1e6'  Dwend='(0.00168u + dxw_rpodwo_m)*1e6'  Dl=0
.param Jc1_0 = 0.111676986150315  Jc1_w=0.152379354165086  Jc1_n=-0.00253193199710238
.param Jc1end_0 = 30.8120320049789  Jc1end_w=0
.param Tc1_0 = 0.00134516723460811  Tc1_w=-1.93197505178018E-06
.param Tc2_0 = 6.91556298384702E-07  Tc2_w=5.99375320579376E-08
.param Tc1end_0 = 7.97874855197876E-05  Tc1end_w=4.99324114654573E-05
.param Tc2end_0 = -2.22863924323114E-07  Tc2end_w=-4.11818902290053E-08
.param Jct_0 = 0.00119863544617091  Jct_w=-0.00096981387975331
.param Jctend_0 = 0.00951466816029306  Jctend_w=-0.00277001356063046
.param Delta_T = 'temper - 25'
.param lum = 'lr*scale*1e6'   wum = 'wr*scale*1e6'   nsqr=lr/wr
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w / wum'   Tc2end = 'Tc2end_0 + Tc2end_w / wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1_r = 'Jc1*16' Jc1end_r='Jc1end*4'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
Rend1 n2 ns 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(n2,ns)*v(n2,ns))), Rendo*1.5), Rendo/2)'
R1 ns nm 'max(min(Ro/2*(3-1/(1+Jc1_r*v(ns,nm)*v(ns,nm))), Ro*1.5), Ro/2)'
R2 nm nn 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nm,nn)*v(nm,nn))), Ro*1.5), Ro/2)'
R3 nn nx 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nn,nx)*v(nn,nx))), Ro*1.5), Ro/2)'
R4 nx ne 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nx,ne)*v(nx,ne))), Ro*1.5), Ro/2)'
Rend2 ne n1 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(ne,n1)*v(ne,n1))), Rendo*1.5), Rendo/2)'
d1 ns body pdio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*((wr*scale-dw*1e-6)+2.0*(lr*scale-dl*1e-6)/5.0)'
d2 nm body pdio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d3 nn body pdio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d4 nx body pdio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*(2.0*(lr*scale-dl*1e-6)/5.0)'
d5 ne body pdio area='mf*((wr*scale-dw*1e-6)*(lr*scale-dl*1e-6)/5.0)' pj='mf*((wr*scale-dw*1e-6)+2.0*(lr*scale-dl*1e-6)/5.0)'

.ends rpodwo_m

***********************************     N+POLY silicide resistor (W>2um)     ***********************************
.subckt rnpolyl_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0082*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rnpolyl_m*(1+factmis)'
.param dw = -0.0211u  
.param pvc1 = 6.54E-07   pvc2 = 1.17E-11   ptc1 = 0.001887444   ptc2 = -6.41E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
.param Ca='ca_pofox' Cf='cf_polfox'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
c1 body n2 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body n1 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.ends rnpolyl_m

***********************************     N+POLY silicide resistor (W<2um)     ***********************************
.subckt rnpolys_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0082*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rnpolys_m*(1+factmis)'
.param dw = '-0.0211u + dxw_rnpolys_m'  
.param pvc1 = 2.63E-08   pvc2 = 4.19E-12   ptc1 = 0.002162497   ptc2 = -7.21E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
.param Ca='ca_pofox' Cf='cf_posfox'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
c1 body n2 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body n1 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.ends rnpolys_m

***********************************     N+POLY w/o silicide resistor     ***********************************
.subckt rnpolywo_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.027*geo_fac*par_res_m*mismatchflag'
.param Rsh = 'r_rnpolywo_m/4*(1+factmis)'  Rendsh='rend_rnpolywo_m*1e6*(1+factmis)'
.param Dw = '(0.06094u + dxw_rnpolywo_m)*1e6'  Dwend='(0.06094u + dxw_rnpolywo_m)*1e6'  Dl=0
.param Jc1_0 = 0.468910868642278  Jc1_w=-0.112938447121681  Jc1_n=0.00691776661634369
.param Jc1end_0 = 21.876715834462  Jc1end_w=0
.param Tc1_0 = 0.000146777758646609  Tc1_w=-3.23409625208756E-05
.param Tc2_0 = 1.89557340140836E-07  Tc2_w=8.47296898658068E-08
.param Tc1end_0 = 0.000876816730930428  Tc1end_w=0.00036855776757363
.param Tc2end_0 = 5.63556101704174E-07  Tc2end_w=-3.50561057125037E-07
.param Jct_0 = 0.00382604564786152  Jct_w=-0.00234776917199985
.param Jctend_0 = 0.00297141058822875  Jctend_w=-0.00196020344135713
.param Delta_T = 'temper - 25'
.param lum = 'lr*scale*1e6'   wum = 'wr*scale*1e6'   nsqr=lr/wr
.param Tc1 = 'Tc1_0 + Tc1_w / wum'   Tc2 = 'Tc2_0 + Tc2_w / wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w / wum'   Tc2end = 'Tc2end_0 + Tc2end_w / wum'
.param Jct = 'Jct_0 + Jct_w / wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w / wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1_r = 'Jc1*16' Jc1end_r='Jc1end*4'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
.param Ca='ca_pofox_r' Cf='cf_polfox_r'
Rend1 n2 ns 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(n2,ns)*v(n2,ns))), Rendo*1.5), Rendo/2)'
R1 ns nm Rnpoly 'max(min(Ro/2*(3-1/(1+Jc1_r*v(ns,nm)*v(ns,nm))), Ro*1.5), Ro/2)'
R2 nm nn Rnpoly 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nm,nn)*v(nm,nn))), Ro*1.5), Ro/2)'
R3 nn nx Rnpoly 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nn,nx)*v(nn,nx))), Ro*1.5), Ro/2)'
R4 nx ne Rnpoly 'max(min(Ro/2*(3-1/(1+Jc1_r*v(nx,ne)*v(nx,ne))), Ro*1.5), Ro/2)'
Rend2 ne n1 'max(min(Rendo/2*(1+1/(1+Jc1end_r*v(ne,n1)*v(ne,n1))), Rendo*1.5), Rendo/2)'
c1 body ns 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body ne 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.model Rnpoly r L='(lum-Dl)*1e-6/4' W='mf*(wum-Dw)*1e-6' KF='KF_rnpolywo_dis' AF=2 EF=0.88 WF=1 LF=1
.ends rnpolywo_m

***********************************     P+POLY silicide resistor (W>2um)     ***********************************
.subckt rppolyl_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0143*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rppolyl_m*(1+factmis)'
.param dw = -0.023u  
.param pvc1 = 8.25E-07   pvc2 = 1.38E-11   ptc1 = 0.002250708   ptc2 = -9.32E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
.param Ca='ca_pofox' Cf='cf_polfox'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
c1 body n2 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body n1 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.ends rppolyl_m

***********************************     P+POLY silicide resistor (W<2um)     ***********************************
.subckt rppolys_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.0143*geo_fac*par_res_m*mismatchflag'
.param rsh = 'r_rppolys_m*(1+factmis)'
.param dw = '-0.023u + dxw_rppolys_m'  
.param pvc1 = 8.54E-08   pvc2 = 4.18E-12   ptc1 = 0.002371857   ptc2 = -6.16E-07   
.param pt='temper'
.param tfac='1.0+ptc1*(pt-25.0)+ptc2*(pt-25.0)*(pt-25)'
.param Ca='ca_pofox' Cf='cf_posfox'
r1 n2 nm 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r2 nm nn 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r3 nn nx 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
r4 nx n1 'rsh/mf*lr*scale/(4.0*(wr*scale-dw))*(1+pvc1*abs((v(n2,n1)/lr/scale))+pvc2*(v(n2,n1)/lr/scale)*(v(n2,n1)/lr/scale))*tfac'
c1 body n2 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body n1 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.ends rppolys_m

***********************************     P+POLY w/o silicide resistor     ***********************************
.subckt rppolywo_m n2 n1 body lr=l wr=w mf=1 scale=1 mismatchflag=0
.param geo_fac ='1/sqrt(mf*lr*scale*wr*scale*1e12)'
.param factmis='0.006*geo_fac*par_res_m*mismatchflag'
.param Rsh = 'r_rppolywo_m/4*(1+factmis)'  Rendsh='rend_rppolywo_m*1e6*(1+factmis)'
.param Dw = '(0.03685u + dxw_rppolywo_m)*1e6'  Dwend='(0.03685u + dxw_rppolywo_m)*1e6'  Dl=0
.param Jc1_0 = 0.0695053510675811  Jc1_w=0.0269845671346735  Jc1_n=0.000714977117664719
.param Jc1end_0 = 27.900361735252  Jc1end_w=0
.param Tc1_0 = -0.000326161317630646  Tc1_w=3.10855059871834E-06
.param Tc2_0 = 8.05172629127237E-07  Tc2_w=-2.79415787596679E-08
.param Tc1end_0 = -0.00141906402431781  Tc1end_w=1.51517802655145E-05
.param Tc2end_0 = 1.19263050938459E-06  Tc2end_w=5.77755688915007E-07
.param Jct_0 = -0.00425159480565355  Jct_w=2.26507523320411E-05
.param Jctend_0 = -0.00141455931220154  Jctend_w=0.000920093941015092
.param Delta_T = 'temper - 25'
.param lum = 'lr*scale*1e6'   wum = 'wr*scale*1e6'   nsqr=lr/wr
.param Tc1 = 'Tc1_0 + Tc1_w * wum'   Tc2 = 'Tc2_0 + Tc2_w * wum'
.param Tc1end = 'Tc1end_0 + Tc1end_w * wum'   Tc2end = 'Tc2end_0 + Tc2end_w * wum'
.param Jct = 'Jct_0 + Jct_w * wum'
.param Jctend = 'Jctend_0 + Jctend_w * wum'
.param Jc1 = '(Jc1_0 + Jc1_w * wum + Jc1_n * nsqr) * (1 + Jct * Delta_T) / (lum-Dl) / (lum-Dl)'
.param Jc1_r = 'Jc1*16' Jc1end_r='Jc1end*4'
.param Jc1end = '(Jc1end_0 + Jc1end_w * wum) * (1 + Jctend * Delta_T)'
.param Tfac = '1 + Tc1 * Delta_T + Tc2 * Delta_T * Delta_T'
.param Tfacend = '1 + Tc1end * Delta_T + Tc2end * Delta_T * Delta_T'
.param Rendo = 'Rendsh/mf/(wum-Dwend)*Tfacend'
.param Ro = 'Rsh/mf*(lum-Dl)/(wum-Dw)*Tfac'
.param Ca='ca_pofox_r' Cf='cf_polfox_r'
Rend1 n2 ns 'max(min(Rendo/2*(3-1/(1+Jc1end_r*v(n2,ns)*v(n2,ns))), Rendo*1.5), Rendo/2)'
R1 ns nm Rppoly 'max(min(Ro/2*(1+1/(1+Jc1_r*v(ns,nm)*v(ns,nm))), Ro*1.5), Ro/2)'
R2 nm nn Rppoly 'max(min(Ro/2*(1+1/(1+Jc1_r*v(nm,nn)*v(nm,nn))), Ro*1.5), Ro/2)'
R3 nn nx Rppoly 'max(min(Ro/2*(1+1/(1+Jc1_r*v(nn,nx)*v(nn,nx))), Ro*1.5), Ro/2)'
R4 nx ne Rppoly 'max(min(Ro/2*(1+1/(1+Jc1_r*v(nx,ne)*v(nx,ne))), Ro*1.5), Ro/2)'
Rend2 ne n1 'max(min(Rendo/2*(3-1/(1+Jc1end_r*v(ne,n1)*v(ne,n1))), Rendo*1.5), Rendo/2)'
c1 body ns 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c2 body nm 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c3 body nn 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c4 body nx 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
c5 body ne 'mf*(Ca*((wr*scale-0.02u)*lr*scale/5.0)*1e12+2*Cf*lr*scale/5.0*1e6)'
.model Rppoly r L='(lum-Dl)*1e-6/4' W='mf*(wum-Dw)*1e-6' KF='KF_rppolywo_dis' AF=2 EF=0.9 WF=1 LF=1
.ends rppolywo_m

.ENDL DISRES


*******************************************************************************************

*************************************************************************************************
*                   Metal Probe Subckt								*
*												*
* Please note that this probe model is for CAD purpose only.					*
*************************************************************************************************
.LIB PROBE

* For CAD purpose only
* M1
.subckt probe1 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe1

* M2
.subckt probe2 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe2

* M3
.subckt probe3 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe3

* M4
.subckt probe4 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe4

* M5
.subckt probe5 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe5

* M6
.subckt probe6 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe6

* M7
.subckt probe7 n1 n2 A=ar PJ=pjv
.param ca1=8.40F
.param ar1=144E-12
c1 n1 n2 'ca1/ar1*A'
.ends probe7

.ENDL PROBE



.LIB MC_MIM
.param
+ par_mim=AGAUSS(0,1,1)
+ A1_mim='par1_mim*1.0000e+000' 
+ cmimbb_mimfac     = '1.0000e+000+(1.0000e-001)*A1_mim'
+ cmimbb2p0_mimfac  = '1.0000e+000+(1.5000e-001)*A1_mim'
+ cm5bb_mimfac      = 1.0
.lib 'crn65lp_v1d5.l' MIM
.ENDL MC_MIM



********************************************************
**************** MIM Corner Parameters *****************
********************************************************
.LIB TT_MIM
.param
+ par_mim=AGAUSS(0,1,1)
+ cmimbb_mimfac     = 1.0
+ cmimbb2p0_mimfac  = 1.0
+ cm5bb_mimfac      = 1.0
.lib 'crn65lp_v1d5.l' MIM
.ENDL TT_MIM



.LIB FF_MIM
.param
+ par_mim=AGAUSS(0,1,1)
+ cmimbb_mimfac     = 0.9
+ cmimbb2p0_mimfac  = 0.85
+ cm5bb_mimfac      = 0.931
.lib 'crn65lp_v1d5.l' MIM
.ENDL FF_MIM



.LIB SS_MIM
.param
+ par_mim=AGAUSS(0,1,1)
+ cmimbb_mimfac     = 1.1
+ cmimbb2p0_mimfac  = 1.15
+ cm5bb_mimfac      = 1.074
.lib 'crn65lp_v1d5.l' MIM
.ENDL SS_MIM



**************************************************************************************************
*     MIM CAPACITOR MODEL :
*
*
*     ## library files:
*
*     1. The 2T base band MIM capacitors with sub-circuit 'mimcap_sin'
*        a. mimflag=1 for 2T base band 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2 for 2T base band 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3 for 2T base band 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     2. The 3T base band MIM capacitors with sub-circuit 'mimcap_sin_3t'
*        a. mimflag=1 for 3T base band 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2 for 3T base band 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3 for 3T base band 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     3. The 2T base band UTM direct contact MIM capacitors with sub-circuit 'mimcap_sin_udc'
*        a. mimflag=1 for 2T base band 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2 for 2T base band 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3 for 2T base band 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*     4. The 3T base band UTM direct contact MIM capacitors with sub-circuit 'mimcap_sin_udc_3t'
*        a. mimflag=1 for 3T base band 1.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=1 for mismatch
*        b. mimflag=2 for 3T base band 1.5fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=2 for mismatch
*        c. mimflag=3 for 3T base band 2.0fF MIM capacitors ,and mismatchflag==0 for no mismatch mismatchflag=3 for mismatch
*
*       
*
*     Model name              lt             wt
*                             low    high    low    high
*     --------------------------------------------------
*     mimcap_sin            (um)   2     100      2     100
*     mimcap_sin_3t         (um)   2     100      2     100
*     mimcap_sin_udc        (um)   2     100      2     100
*     mimcap_sin_udc_3t     (um)   2     100      2     100
*     --------------------------------------------------
*            **lt: length dimension of top metal (CTM) 
*            **wt: width dimension of top metal (CTM) 
*            **lay: the number of metal layer under MIM, ex. for MIM is between M7 and M8, lay=7
*            **MIM is between Mz and Mx      
**************************************************************************************************
.LIB MIM
*
.subckt mimcap_sin top bottom lt=10u wt=10u scale=1 mf=1 mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt(mf*lt*scale*wt*scale*1e12)'
.param factmis='mis*geo_fac*par_mim'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmimbb_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmimbb2p0_mimfac))'
.param cmim_para ='(1+factmis)*(((wt*scale+mim_a)*(lt*scale+mim_a)*1e12*mim_b)+2*((wt*scale+mim_a)+(lt*scale+mim_a))*1e6*mim_c)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
*
cmim top bottom 'cmim_para*(1+v(top,bottom)*vcc1+(abs(v(top,bottom))**2)*vcc2)*cmimbb_corner*mf'
*
.ends mimcap_sin
*
.subckt mimcap_sin_udc top bottom lt=10u wt=10u scale=1 mf=1 mismatchflag=0 mimflag=1 
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt(mf*lt*scale*wt*scale*1e12)'
.param factmis='mis*geo_fac*par_mim'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmimbb_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmimbb2p0_mimfac))'
.param cmim_para ='(1+factmis)*(((wt*scale+mim_a)*(lt*scale+mim_a)*1e12*mim_b)+2*((wt*scale+mim_a)+(lt*scale+mim_a))*1e6*mim_c)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
*
cmim top bottom 'cmim_para*(1+v(top,bottom)*vcc1+(abs(v(top,bottom))**2)*vcc2)*cmimbb_corner*mf'
*
.ends mimcap_sin_udc
*
*
.subckt mimcap_sin_3t top bottom gnode lt=10u wt=10u scale=1 mf=1 mismatchflag=0 lay=9 mimflag=1  
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt(mf*lt*scale*wt*scale*1e12)'
.param factmis='mis*geo_fac*par_mim'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmimbb_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmimbb2p0_mimfac))'
.param cmim_para ='(1+factmis)*(((wt*scale+mim_a)*(lt*scale+mim_a)*1e12*mim_b)+2*((wt*scale+mim_a)+(lt*scale+mim_a))*1e6*mim_c)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='((lt*scale*1e6+4.8)*(wt*scale*1e6+0.8)*2.56e-02/2.8+2*((lt*scale*1e6+4.8)+(wt*scale*1e6+0.8))*0.0137)*1e-15'
*
cmim top bottom 'cmim_para*(1+v(top,bottom)*vcc1+(abs(v(top,bottom))**2)*vcc2)*cmimbb_corner*mf'
cox bottom gnode 'cox_para*((1/(4.35717+(1.42106)*(lay-2)))/0.0872414)*cm5bb_mimfac*mf'
*
.ends mimcap_sin_3t
*
.subckt mimcap_sin_udc_3t top bottom gnode lt=10u wt=10u scale=1 mf=1 mismatchflag=0 lay=9 mimflag=1  
.param mis='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.007083)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.006203)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.006082))'
.param geo_fac ='1/sqrt(mf*lt*scale*wt*scale*1e12)'
.param factmis='mis*geo_fac*par_mim'
.param mim_a='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.029u)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.049u)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.037u))'
.param mim_b='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(1.03)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(1.485)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(2.014))'
.param mim_c='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(0.207)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(0.21)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(0.218))'
.param tcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-5.11e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-5.365e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-1.573e-5))'
.param tcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-0.03e-6)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-0.052e-6)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-0.018e-6))'
.param vcc1='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(3.66e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(4.335e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.9e-5))'
.param vcc2='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(-1.84e-5)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(-4.23e-5)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(-2.97e-5))'
.param cmimbb_corner='((mimflag-2)*(mimflag-3)/(1-2)/(1-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-3)/(2-1)/(2-3)*(cmimbb_mimfac)+(mimflag-1)*(mimflag-2)/(3-1)/(3-2)*(cmimbb2p0_mimfac))'
.param cmim_para ='(1+factmis)*(((wt*scale+mim_a)*(lt*scale+mim_a)*1e12*mim_b)+2*((wt*scale+mim_a)+(lt*scale+mim_a))*1e6*mim_c)*1e-15*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)'
.param cox_para  ='((lt*scale*1e6+7.66)*(wt*scale*1e6+0.8)*2.56e-02/2.8+2*((lt*scale*1e6+7.66)+(wt*scale*1e6+0.8))*0.0137)*1e-15'
*
cmim top bottom 'cmim_para*(1+v(top,bottom)*vcc1+(abs(v(top,bottom))**2)*vcc2)*cmimbb_corner*mf'
cox bottom gnode 'cox_para*((1/(4.35717+(1.42106)*(lay-2)))/0.0872414)*cm5bb_mimfac*mf'
*
.ends mimcap_sin_udc_3t
*
*
*
.ENDL MIM




***********************************************************************
*                           RTMOM                                     *
***********************************************************************
************* Library of Monte Coral **********************************

.lib mc_rtmom
.param
+par_mom=AGAUSS(0,1,1)
+A1_rtmom='par1_mom*1.4142/3'
+rtmom_fac      ='1+(0.10607)*A1_rtmom'
+rtmom_fac2     ='1+(0.28284)*A1_rtmom'
.lib 'crn65lp_v1d5.l' rtmom
.endl mc_rtmom
************* Library of typical corner *******************************

.LIB TT_RTMOM
.param RTMOM_fac= 1 
.param RTMOM_fac2= 1
+ par_mom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RTMOM
.ENDL TT_RTMOM

************* Library of slow corner **********************************

.LIB SS_RTMOM
.param RTMOM_fac= 1.15
.param RTMOM_fac2= 1.4
+ par_mom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RTMOM
.ENDL SS_RTMOM

************* Library of fast corner **********************************

.LIB FF_RTMOM
.param RTMOM_fac= 0.85
.param RTMOM_fac2= 0.6
+ par_mom=AGAUSS(0,1,1)
.lib 'crn65lp_v1d5.l' RTMOM
.ENDL FF_RTMOM


************************************************************************

.LIB RTMOM

******************************************************************************************
*                                                                                        *
*           65nm BB RTMOM                                                                *
*                                                                                        *
*           parameter range: nv : 6~288, nh : 6~288                                      *
*                            nv and nh should be even fingers                            *
*                            w(width):0.1u ~ 0.16u                                       *
*                            s(spacing):0.1u ~ 0.16u                                     *
*                            stm(start metal layer):M1,M2,M3,M4,M5                       *
*                            spm(stop metal layer):M3,M4,M5,M6,M7                        *
*                            Total metal is at least 3 layers stacked with ploy shield   *
*                            Bus metal width: 0.18um and Ftip: 0.2um are not scalable    *
*                            mismatchflag=0 for no mismatch                              *
*                            mismatchflag=1 for parallel                                 *
*                                                                                        *
******************************************************************************************
.subckt crtmom a b p nv=288 nh=288 w=0.1u s=0.1u stm=1 spm=7 scale=1 mf=1 mismatchflag=0
.param 

+ layno   = 'spm-stm+1'
+ laym1   = 'INT(layno/spm)'
+ layodd  = 'INT((layno+j1+j3+j5)/2)-laym1'
+ layeven = 'INT((layno+j2+j4)/2)'
+ r   = '0.92'
+ dw  = '((0.228495016028492)*(w*scale*1e6)+(0.864862940554024)*(s*scale*1e6)+(-4.46733713068237)*(s*scale*1e6)*(w*scale*1e6)+(-6.35923905319406E-02))*(1e-6)'
+ ww  = 'w*scale+dw'
+ ss  = 's*scale-dw'
+ wb  = '0.18u+dw'
+ sb  = '0.2u-dw'
+ lnv = 'nh*(ww+ss)-ss'
+ lnh = 'nv*(ww+ss)-ss'
+ tcc1  = '-12.4*1e-6'
+ tcc2  = '0.0133*1e-6'
+ vcc1  = '-0.1*1e-6'
+ vcc2  = '0.8*1e-6'
+ j1 = '(stm-2)*(stm-3)*(stm-4)*(stm-5)/(1-2)/(1-3)/(1-4)/(1-5)'
+ j2 = '(stm-1)*(stm-3)*(stm-4)*(stm-5)/(2-1)/(2-3)/(2-4)/(2-5)'
+ j3 = '(stm-1)*(stm-2)*(stm-4)*(stm-5)/(3-1)/(3-2)/(3-4)/(3-5)'
+ j4 = '(stm-1)*(stm-2)*(stm-3)*(stm-5)/(4-1)/(4-2)/(4-3)/(4-5)'
+ j5 = '(stm-1)*(stm-2)*(stm-3)*(stm-4)/(5-1)/(5-2)/(5-3)/(5-4)'
*
+ Edg ='((layodd+r*laym1)*(nv-1)*lnv+layeven*(nh-1)*lnh)'
+ AREA='nv*nh/2*ww*(layno-1)'
+ FRI1='(2*nh*nv*ww)*(layno-1)'
+ FRI2='(layodd+r*laym1)*lnv*2+layeven*(lnh+sb)*2+((layodd+r*laym1)*nv*ww+layeven*nh*ww)+layno*wb*2'
+ Abm ='((lnh+(wb+sb)*2)+(lnv+sb))*wb/ww*(1.7*j1+8*j2+8*(j3+j4+j5))'
+ Afm ='(j1+j3+j5)*(nv*(lnv+sb))/2+(j2+j4)*(nh*(lnh+sb))/2'
+ Pf  ='(j1+j3+j5)*nv*(lnv+sb)+(j2+j4)*nh*(lnh+sb)+2*(lnv+lnh)+6*wb+6*sb'
+ Pfb ='j1*(lnv+2*wb+sb)*1'
*
+ Cc1 ='((3.31778571428518E-03)/(w*scale*1e6)+(4.58367293233029E-03)/(s*scale*1e6)+(3.33151365255902E-05)/(s*scale*1e6)/(w*scale*1e6)+(3.18642857143291E-03))*1.0005'
+ Cc2 ='(0.0471)*1.49'
+ Cf  ='((0.217378960485214)*(w*scale*1e6)+(0.152520469919126)*(s*scale*1e6)+(-0.787958348173258)*(s*scale*1e6)*(w*scale*1e6)+(-1.11529681382862E-02))*0.7'
+ Ca  ='(((-7.4178977970751E-03)*(w*scale*1e6)+(1.64193663145724E-02)*(s*scale*1e6)+(0.22479975089191)*(s*scale*1e6)*(w*scale*1e6)+(5.00430980214061E-03))*0.5)'
*
+ ca_p_a='(j1*(0.228499695208201)*0.6308+j2*(9.21578947359392E-02)*0.4976+j3*(4.63684210684769E-02)*0.4055+j4*(2.64537201083299E-02)*0.4055+j5*(2.00000889208476E-02)*0.4055)'
+ ca_p_b='(j1*(9.07506717796861E-02)*0.6308+j2*(5.95789473675215E-02)*0.4976+j3*(3.06315789633253E-02)*0.4055+j4*(2.07273050345198E-02)*0.4055+j5*(1.56699002205504E-02)*0.4055)'
+ ca_p_c='(j1*(-0.377728701830403)*0.6308+j2*(-0.354986149577421)*0.4976+j3*(-0.176869806250642)*0.4055+j4*(-0.105731576687923)*0.4055+j5*(-7.99127797182435E-02)*0.4055)'
+ ca_p_d='(j1*(-8.09567284527284E-03)*0.6308+j2*(-6.66999999988505E-03)*0.4976+j3*(-3.22000000149291E-03)*0.4055+j4*(-1.82074224563325E-03)*0.4055+j5*(-1.36635723238263E-03)*0.4055)'
*
+ cf_p_a='(j1*(3.92322184993517E-03)*0.6308+j2*(9.73684223713357E-04)*0.4976+j3*(0.008631579009041)*0.4055+j4*(-1.35697747026833E-03)*0.4055+j5*(-1.38305409476152E-04)*0.4055)'
+ cf_p_b='(j1*(5.26195109392581E-02)*0.6308+j2*(6.47368422147126E-03)*0.4976+j3*(8.02631583671123E-03)*0.4055+j4*(2.91660738192766E-03)*0.4055+j5*(3.3899964647692E-03)*0.4055)'
+ cf_p_c='(j1*(0.095762967753077)*0.6308+j2*(0.121952908482245)*0.4976+j3*(4.46675895930827E-02)*0.4055+j4*(0.055633676966577)*0.4055+j5*(4.34229260807518E-02)*0.4055)'
+ cf_p_d='(j1*(8.54632956062667E-03)*0.6308+j2*(5.82999999863725E-03)*0.4976+j3*(4.2199999931874E-03)*0.4055+j4*(5.05353060446388E-03)*0.4055+j5*(4.65741277617021E-03)*0.4055)'
*
+ Ca_p ='(ca_p_a*(w*scale*1e6)+ca_p_b*(s*scale*1e6)+ca_p_c*(s*scale*1e6)*(w*scale*1e6)+ca_p_d)*1'
+ Cf_p ='(cf_p_a*(w*scale*1e6)+cf_p_b*(s*scale*1e6)+cf_p_c*(s*scale*1e6)*(w*scale*1e6)+cf_p_d)*1'
+ Cc_p ='(0.017)*4'
*
*
+ mis_a='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.32)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.28)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.165))'
+ mis_b='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.027)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.0125)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.0068))'
+ mis_c='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(2.4)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(3.3)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(3.5))'
+ mis_d='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.084)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-3)/(2-0)/(2-1)/(2-3)*(0.043)+(mismatchflag-0)*(mismatchflag-1)*(mismatchflag-2)/(3-0)/(3-1)/(3-2)*(0.024))'
*
+ geo_fac ='1/sqrt((Cc1*Edg*1e-9+Cf*1e-9*FRI1+Ca*1e-9*AREA+Cc2*1e-9*FRI2)*1e15*mf)'
+ mis='mis_a*(((geo_fac-mis_b)**2+0.000000000000000001)**0.5+geo_fac)+mis_c*(((geo_fac-mis_b)**2+0.000000000000000001)**0.5-geo_fac)+mis_d'
+ factmis='mis/1.414/100*par_mom'
*
*
Cab a b '(1+factmis)*(Cc1*Edg+Cf*FRI1+Ca*AREA+Cc2*FRI2)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a,b)+vcc2*v(a,b)*v(a,b))*mf*RTMOM_fac'
Cpa a p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a,p)+vcc2*v(a,p)*v(a,p))*mf*RTMOM_fac2'
Cpb b p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(b,p)+vcc2*v(b,p)*v(b,p))*mf*RTMOM_fac2'

.ends crtmom



 

******************************************************************************************
*                                                                                        *
*           65nm BB 5T RTMOM FOR MULTI-X-COUPLE MISMATCH APPLICATION                     *
*                                                                                        *
*           parameter range: nv : 6~288, nh : 6~288                                      *
*                            nv and nh should be even fingers                            *
*                            w(width):0.1u ~ 0.16u                                       *
*                            s(spacing):0.1u ~ 0.16u                                     *
*                            stm(start metal layer):M1,M2,M3,M4,M5                       *
*                            spm(stop metal layer):M3,M4,M5,M6,M7                        *
*                            Total metal is at least 3 layers stacked with ploy shield   *
*                            Bus metal width: 0.18um and Ftip: 0.2um are not scalable    *
*                            mismatchflag=0 for no mismatch                              *
*                            mismatchflag=1 for multi-x-couple                           *
*                                                                                        *
******************************************************************************************
.subckt crtmom_mx a b a1 b1 p nv=288 nh=288 w=0.1u s=0.1u stm=1 spm=7 scale=1 mf=1 mismatchflag=0
.param 

+ layno   = 'spm-stm+1'
+ laym1   = 'INT(layno/spm)'
+ layodd  = 'INT((layno+j1+j3+j5)/2)-laym1'
+ layeven = 'INT((layno+j2+j4)/2)'
+ r   = '0.92'
+ dw  = '((0.228495016028492)*(w*scale*1e6)+(0.864862940554024)*(s*scale*1e6)+(-4.46733713068237)*(s*scale*1e6)*(w*scale*1e6)+(-6.35923905319406E-02))*(1e-6)'
+ ww  = 'w*scale+dw'
+ ss  = 's*scale-dw'
+ wb  = '0.18u+dw'
+ sb  = '0.2u-dw'
+ lnv = 'nh*(ww+ss)-ss'
+ lnh = 'nv*(ww+ss)-ss'
+ tcc1  = '-12.4*1e-6'
+ tcc2  = '0.0133*1e-6'
+ vcc1  = '-0.1*1e-6'
+ vcc2  = '0.8*1e-6'
+ j1 = '(stm-2)*(stm-3)*(stm-4)*(stm-5)/(1-2)/(1-3)/(1-4)/(1-5)'
+ j2 = '(stm-1)*(stm-3)*(stm-4)*(stm-5)/(2-1)/(2-3)/(2-4)/(2-5)'
+ j3 = '(stm-1)*(stm-2)*(stm-4)*(stm-5)/(3-1)/(3-2)/(3-4)/(3-5)'
+ j4 = '(stm-1)*(stm-2)*(stm-3)*(stm-5)/(4-1)/(4-2)/(4-3)/(4-5)'
+ j5 = '(stm-1)*(stm-2)*(stm-3)*(stm-4)/(5-1)/(5-2)/(5-3)/(5-4)'
*
+ Edg ='((layodd+r*laym1)*(nv-1)*lnv+layeven*(nh-1)*lnh)'
+ AREA='nv*nh/2*ww*(layno-1)'
+ FRI1='(2*nh*nv*ww)*(layno-1)'
+ FRI2='(layodd+r*laym1)*lnv*2+layeven*(lnh+sb)*2+((layodd+r*laym1)*nv*ww+layeven*nh*ww)+layno*wb*2'
+ Abm ='((lnh+(wb+sb)*2)+(lnv+sb))*wb/ww*(1.7*j1+8*j2+8*(j3+j4+j5))'
+ Afm ='(j1+j3+j5)*(nv*(lnv+sb))/2+(j2+j4)*(nh*(lnh+sb))/2'
+ Pf  ='(j1+j3+j5)*nv*(lnv+sb)+(j2+j4)*nh*(lnh+sb)+2*(lnv+lnh)+6*wb+6*sb'
+ Pfb ='j1*(lnv+2*wb+sb)*1'
*
+ Cc1 ='((3.31778571428518E-03)/(w*scale*1e6)+(4.58367293233029E-03)/(s*scale*1e6)+(3.33151365255902E-05)/(s*scale*1e6)/(w*scale*1e6)+(3.18642857143291E-03))*1.0005'
+ Cc2 ='(0.0471)*1.49'
+ Cf  ='((0.217378960485214)*(w*scale*1e6)+(0.152520469919126)*(s*scale*1e6)+(-0.787958348173258)*(s*scale*1e6)*(w*scale*1e6)+(-1.11529681382862E-02))*0.7'
+ Ca  ='(((-7.4178977970751E-03)*(w*scale*1e6)+(1.64193663145724E-02)*(s*scale*1e6)+(0.22479975089191)*(s*scale*1e6)*(w*scale*1e6)+(5.00430980214061E-03))*0.5)'
*
+ ca_p_a='(j1*(0.228499695208201)*0.6308+j2*(9.21578947359392E-02)*0.4976+j3*(4.63684210684769E-02)*0.4055+j4*(2.64537201083299E-02)*0.4055+j5*(2.00000889208476E-02)*0.4055)'
+ ca_p_b='(j1*(9.07506717796861E-02)*0.6308+j2*(5.95789473675215E-02)*0.4976+j3*(3.06315789633253E-02)*0.4055+j4*(2.07273050345198E-02)*0.4055+j5*(1.56699002205504E-02)*0.4055)'
+ ca_p_c='(j1*(-0.377728701830403)*0.6308+j2*(-0.354986149577421)*0.4976+j3*(-0.176869806250642)*0.4055+j4*(-0.105731576687923)*0.4055+j5*(-7.99127797182435E-02)*0.4055)'
+ ca_p_d='(j1*(-8.09567284527284E-03)*0.6308+j2*(-6.66999999988505E-03)*0.4976+j3*(-3.22000000149291E-03)*0.4055+j4*(-1.82074224563325E-03)*0.4055+j5*(-1.36635723238263E-03)*0.4055)'
*
+ cf_p_a='(j1*(3.92322184993517E-03)*0.6308+j2*(9.73684223713357E-04)*0.4976+j3*(0.008631579009041)*0.4055+j4*(-1.35697747026833E-03)*0.4055+j5*(-1.38305409476152E-04)*0.4055)'
+ cf_p_b='(j1*(5.26195109392581E-02)*0.6308+j2*(6.47368422147126E-03)*0.4976+j3*(8.02631583671123E-03)*0.4055+j4*(2.91660738192766E-03)*0.4055+j5*(3.3899964647692E-03)*0.4055)'
+ cf_p_c='(j1*(0.095762967753077)*0.6308+j2*(0.121952908482245)*0.4976+j3*(4.46675895930827E-02)*0.4055+j4*(0.055633676966577)*0.4055+j5*(4.34229260807518E-02)*0.4055)'
+ cf_p_d='(j1*(8.54632956062667E-03)*0.6308+j2*(5.82999999863725E-03)*0.4976+j3*(4.2199999931874E-03)*0.4055+j4*(5.05353060446388E-03)*0.4055+j5*(4.65741277617021E-03)*0.4055)'
*
+ Ca_p ='(ca_p_a*(w*scale*1e6)+ca_p_b*(s*scale*1e6)+ca_p_c*(s*scale*1e6)*(w*scale*1e6)+ca_p_d)*1'
+ Cf_p ='(cf_p_a*(w*scale*1e6)+cf_p_b*(s*scale*1e6)+cf_p_c*(s*scale*1e6)*(w*scale*1e6)+cf_p_d)*1'
+ Cc_p ='(0.017)*4'
*
*
+ mis_a='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.165))'
+ mis_b='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.0068))'
+ mis_c='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(3.5))'
+ mis_d='((mismatchflag-1)*(mismatchflag-2)*(mismatchflag-3)/(0-1)/(0-2)/(0-3)*(0)+(mismatchflag-0)*(mismatchflag-2)*(mismatchflag-3)/(1-0)/(1-2)/(1-3)*(0.024))'
*
+ geo_fac ='1/sqrt((Cc1*Edg*1e-9+Cf*1e-9*FRI1+Ca*1e-9*AREA+Cc2*1e-9*FRI2)*1e15*mf)'
+ mis='mis_a*(((geo_fac-mis_b)**2+0.000000000000000001)**0.5+geo_fac)+mis_c*(((geo_fac-mis_b)**2+0.000000000000000001)**0.5-geo_fac)+mis_d'
+ factmis='mis/1.414/100*par_mom'
*
*
Cab a b '(1+factmis)*(Cc1*Edg+Cf*FRI1+Ca*AREA+Cc2*FRI2)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a,b)+vcc2*v(a,b)*v(a,b))*mf*RTMOM_fac'
Cpa a p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a,p)+vcc2*v(a,p)*v(a,p))*mf*RTMOM_fac2'
Cpb b p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(b,p)+vcc2*v(b,p)*v(b,p))*mf*RTMOM_fac2'
Ca1b1 a1 b1 '(1+factmis)*(Cc1*Edg+Cf*FRI1+Ca*AREA+Cc2*FRI2)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a1,b1)+vcc2*v(a1,b1)*v(a1,b1))*mf*RTMOM_fac'
Cpa1 a1 p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(a1,p)+vcc2*v(a1,p)*v(a1,p))*mf*RTMOM_fac2'
Cpb1 b1 p '(Ca_p*(Abm+Afm)+Cf_p*Pf+Cc_p*Pfb)*1e-9*(1+(temper-25)*tcc1+(temper-25)*(temper-25)*tcc2)*(1+vcc1*v(b1,p)+vcc2*v(b1,p)*v(b1,p))*mf*RTMOM_fac2'

.ends crtmom_mx


.ENDL RTMOM







